'''
# IAM Floyd

[![Source](https://img.shields.io/github/stars/udondan/iam-floyd?logo=github&label=GitHub%20Stars)](https://github.com/udondan/iam-floyd)
[![iam-floyd](https://img.shields.io/github/v/release/udondan/iam-floyd)](https://github.com/udondan/iam-floyd)
[![Twitter](https://badgen.net/twitter/follow/heyiamfloyd?icon=twitter)](https://twitter.com/heyiamfloyd)
[![libraries.io](https://img.shields.io/badge/packages-libraries.io-yellow)](https://libraries.io/search?q=iam-floyd)
[![Documentation](https://img.shields.io/badge/Documentation-Read%20the%20Docs-orange)](https://iam-floyd.readthedocs.io/en/latest/)
[![GitHub](https://img.shields.io/github/license/udondan/iam-floyd)](https://github.com/udondan/iam-floyd/blob/main/LICENSE)
[![Maintainability](https://api.codeclimate.com/v1/badges/cdb84b5646c6805b1a23/maintainability)](https://codeclimate.com/github/udondan/iam-floyd/maintainability)

<!-- put back - when we actually have tests
[![Test Coverage](https://api.codeclimate.com/v1/badges/cdb84b5646c6805b1a23/test_coverage)](https://codeclimate.com/github/udondan/iam-floyd/test_coverage)
-->

**AWS [IAM policy statement](https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_statement.html) generator with fluent interface.**

<!-- stats -->

Support for:

* 340 Services
* 13611 Actions
* 1447 Resource Types
* 1460 Condition keys

<!-- /stats -->

![EXPERIMENTAL](https://img.shields.io/badge/stability-experimantal-orange?style=for-the-badge)**<br>This is an early version of the package. The API will change while I implement new features. Therefore make sure you use an exact version in your `package.json` before it reaches 1.0.0.**

## Documentation

Find the documentation at [Read the Docs](https://iam-floyd.readthedocs.io/en/latest/).

[![Auto completion demo](https://raw.githubusercontent.com/udondan/iam-floyd/main/docs/movie-preview.png)](https://www.youtube.com/watch?v=4dHY8qPHbKA)

## Packages

There are two different package variants available:

* **iam-floyd**: Can be used in AWS SDK, Boto 3 or for whatever you need an IAM policy statement for <br>[![npm](https://img.shields.io/npm/dt/iam-floyd?label=npm&color=blueviolet)](https://www.npmjs.com/package/iam-floyd)
  [![PyPI](https://img.shields.io/pypi/dm/iam-floyd?label=pypi&color=blueviolet)](https://pypi.org/project/iam-floyd/)
* **cdk-iam-floyd**: Integrates into [AWS CDK](https://aws.amazon.com/cdk/) and extends [`iam.PolicyStatement`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-iam.PolicyStatement.html)<br>[![npm](https://img.shields.io/npm/dt/cdk-iam-floyd?label=npm&color=orange)](https://www.npmjs.com/package/cdk-iam-floyd)
  [![PyPI](https://img.shields.io/pypi/dm/cdk-iam-floyd?label=pypi&color=orange)](https://pypi.org/project/cdk-iam-floyd/)

  **Starting with version 0.300.0, the packages are compatible with CDK v2.** For CDK v1 you can use any version up to:<br>
  [![npm CDK v1](https://img.shields.io/badge/npm-0.286.0-yellow)](https://www.npmjs.com/package/cdk-iam-floyd/v/0.286.0)
  [![PyPI CDK v1](https://img.shields.io/badge/pypi-0.286.0-yellow)](https://pypi.org/project/cdk-iam-floyd/0.286.0/)

  Find them all on [libraries.io](https://libraries.io/search?q=iam-floyd).

## CDK Compatibility Matrix

| CDK        | cdk-iam-floyd              |
| ---------- | -------------              |
| <= 1.151.0 | <= 0.285.0                 |
| >= 1.152.0 | 0.286.0                    |
| >= 1.158.0 | **No compatible version!** |
| >= 2.0.0   | >= 0.300.0                 |
| >= 2.20.0  | >= 0.351.0                 |
| >= 2.26.0  | >= 0.377.0                 |
| 2.29.x     | **No compatible version!** |
| >= 2.30.0  | >= 0.391.0                 |

---


## Legal

The code contained in the [lib/generated](https://github.com/udondan/iam-floyd/tree/main/lib/generated) folder is generated from the [AWS documentation](https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_actions-resources-contextkeys.html). The class- and function-names and their description therefore are property of AWS.

AWS and their services are trademarks, registered trademarks or trade dress of AWS in the U.S. and/or other countries.

This project is not affiliated, funded, or in any way associated with AWS.

IAM Floyd is licensed under [Apache License 2.0](https://github.com/udondan/iam-floyd/blob/main/LICENSE). Dependencies might be released under different licenses. Especially the bundled packages [regex-parser](https://www.npmjs.com/package/regex-parser) and [common-substrings](https://www.npmjs.com/package/common-substrings) are released under the MIT License.
'''
import abc
import builtins
import datetime
import enum
import typing

import jsii
import publication
import typing_extensions

from typeguard import check_type

from ._jsii import *

import aws_cdk.aws_iam as _aws_cdk_aws_iam_ceddda9d


@jsii.data_type(
    jsii_type="cdk-iam-floyd.AccessLevelList",
    jsii_struct_bases=[],
    name_mapping={},
)
class AccessLevelList:
    def __init__(self) -> None:
        '''
        :stability: experimental
        '''
        self._values: typing.Dict[builtins.str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AccessLevelList(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class Collection(metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Collection"):
    '''
    :stability: experimental
    '''

    def __init__(self) -> None:
        '''
        :stability: experimental
        '''
        jsii.create(self.__class__, self, [])

    @jsii.member(jsii_name="allowEc2InstanceDeleteByOwner")
    def allow_ec2_instance_delete_by_owner(self) -> typing.List["Ec2"]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.List["Ec2"], jsii.invoke(self, "allowEc2InstanceDeleteByOwner", []))


@jsii.data_type(
    jsii_type="cdk-iam-floyd.Conditions",
    jsii_struct_bases=[],
    name_mapping={},
)
class Conditions:
    def __init__(self) -> None:
        '''(experimental) A collection of Condition's.

        :stability: experimental
        '''
        self._values: typing.Dict[builtins.str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "Conditions(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class Operator(metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Operator"):
    '''(experimental) Use condition operators in the ``Condition`` element to match the condition key and value in the policy against values in the request context.

    For more information about the ``Condition`` element, see `IAM JSON Policy Elements: Condition <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition.html>`_.

    The condition operator that you can use in a policy depends on the condition key you choose. You can choose a global condition key or a service-specific condition key. To learn which condition operator you can use for a global condition key, see `AWS Global Condition Context Keys <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_condition-keys.html>`_. To learn which condition operator you can use for a service-specific condition key, see `Actions, Resources, and Condition Keys for AWS Services <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_actions-resources-contextkeys.html>`_ and choose the service that you want to view.

    https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html

    :stability: experimental
    '''

    def __init__(self) -> None:
        '''
        :stability: experimental
        '''
        jsii.create(self.__class__, self, [])

    @jsii.member(jsii_name="arnEquals")
    def arn_equals(self) -> "Operator":
        '''(experimental) Match of the ARN, case sensitive.

        Each of the six colon-delimited components of the ARN is checked separately and each can include a multi-character match wildcard (``*``) or a single-character match wildcard (``?``).

        ``ArnEquals`` and ``ArnLike`` behave identical.

        :stability: experimental
        '''
        return typing.cast("Operator", jsii.invoke(self, "arnEquals", []))

    @jsii.member(jsii_name="arnLike")
    def arn_like(self) -> "Operator":
        '''(experimental) Match of the ARN, case sensitive.

        Each of the six colon-delimited components of the ARN is checked separately and each can include a multi-character match wildcard (``*``) or a single-character match wildcard (``?``).

        :stability: experimental
        '''
        return typing.cast("Operator", jsii.invoke(self, "arnLike", []))

    @jsii.member(jsii_name="arnNotEquals")
    def arn_not_equals(self) -> "Operator":
        '''(experimental) Negated match of the ARN, case sensitive.

        Each of the six colon-delimited components of the ARN is checked separately and each can include a multi-character match wildcard (``*``) or a single-character match wildcard (``?``).

        ``ArnNotEquals`` and ``ArnNotLike`` behave identical.

        :stability: experimental
        '''
        return typing.cast("Operator", jsii.invoke(self, "arnNotEquals", []))

    @jsii.member(jsii_name="arnNotLike")
    def arn_not_like(self) -> "Operator":
        '''(experimental) Negated match of the ARN, case sensitive.

        Each of the six colon-delimited components of the ARN is checked separately and each can include a multi-character match wildcard (``*``) or a single-character match wildcard (``?``).

        ``ArnNotEquals`` and ``ArnNotLike`` behave identical.

        :stability: experimental
        '''
        return typing.cast("Operator", jsii.invoke(self, "arnNotLike", []))

    @jsii.member(jsii_name="binaryEquals")
    def binary_equals(self) -> "Operator":
        '''(experimental) The BinaryEquals condition operator lets you construct Condition elements that test key values that are in binary format.

        It compares the value of the specified key byte for byte against a `base-64 <https://en.wikipedia.org/wiki/Base64>`_ encoded representation of the binary value in the policy.

        :stability: experimental
        '''
        return typing.cast("Operator", jsii.invoke(self, "binaryEquals", []))

    @jsii.member(jsii_name="bool")
    def bool(self) -> "Operator":
        '''(experimental) Boolean match.

        :stability: experimental
        '''
        return typing.cast("Operator", jsii.invoke(self, "bool", []))

    @jsii.member(jsii_name="dateEquals")
    def date_equals(self) -> "Operator":
        '''(experimental) Match a specific date: ``=``.

        :stability: experimental
        '''
        return typing.cast("Operator", jsii.invoke(self, "dateEquals", []))

    @jsii.member(jsii_name="dateGreaterThan")
    def date_greater_than(self) -> "Operator":
        '''(experimental) Match after a specific a date and time: ``>``.

        :stability: experimental
        '''
        return typing.cast("Operator", jsii.invoke(self, "dateGreaterThan", []))

    @jsii.member(jsii_name="dateGreaterThanEquals")
    def date_greater_than_equals(self) -> "Operator":
        '''(experimental) Match at or after a specific date and time: ``>=``.

        :stability: experimental
        '''
        return typing.cast("Operator", jsii.invoke(self, "dateGreaterThanEquals", []))

    @jsii.member(jsii_name="dateLessThan")
    def date_less_than(self) -> "Operator":
        '''(experimental) Match before a specific date and time: ``<``.

        :stability: experimental
        '''
        return typing.cast("Operator", jsii.invoke(self, "dateLessThan", []))

    @jsii.member(jsii_name="dateLessThanEquals")
    def date_less_than_equals(self) -> "Operator":
        '''(experimental) Match at or before a specific date and time: ``<=``.

        :stability: experimental
        '''
        return typing.cast("Operator", jsii.invoke(self, "dateLessThanEquals", []))

    @jsii.member(jsii_name="dateNotEquals")
    def date_not_equals(self) -> "Operator":
        '''(experimental) Negated match for a specific date: ``!=``.

        :stability: experimental
        '''
        return typing.cast("Operator", jsii.invoke(self, "dateNotEquals", []))

    @jsii.member(jsii_name="forAllValues")
    def for_all_values(self) -> "Operator":
        '''(experimental) Tests whether the value of every member of the request set is a subset of the condition key set.

        The condition returns true if every key value in the request matches at least one value in the policy. It also returns true if there are no keys in the request, or if the key values resolve to a null data set, such as an empty string.

        :stability: experimental
        '''
        return typing.cast("Operator", jsii.invoke(self, "forAllValues", []))

    @jsii.member(jsii_name="forAnyValue")
    def for_any_value(self) -> "Operator":
        '''(experimental) Tests whether at least one member of the set of request values matches at least one member of the set of condition key values.

        The condition returns true if any one of the key values in the request matches any one of the condition values in the policy. For no matching key or a null dataset, the condition returns false.

        :stability: experimental
        '''
        return typing.cast("Operator", jsii.invoke(self, "forAnyValue", []))

    @jsii.member(jsii_name="ifExists")
    def if_exists(self) -> "Operator":
        '''(experimental) You can add ``IfExists`` to the end of any condition operator name except the ``Null`` condition.

        For example, ``StringLikeIfExists``. You do this to say "If the policy key is present in the context of the request, process the key as specified in the policy. If the key is not present, evaluate the condition element as true." Other condition elements in the statement can still result in a nonmatch, but not a missing key when checked with ``...IfExists``.

        :stability: experimental
        '''
        return typing.cast("Operator", jsii.invoke(self, "ifExists", []))

    @jsii.member(jsii_name="ipAddress")
    def ip_address(self) -> "Operator":
        '''(experimental) Match an IP address or range: ``=``.

        :stability: experimental
        '''
        return typing.cast("Operator", jsii.invoke(self, "ipAddress", []))

    @jsii.member(jsii_name="notIpAddress")
    def not_ip_address(self) -> "Operator":
        '''(experimental) All IP addresses except the specified IP address or range ``!=``.

        :stability: experimental
        '''
        return typing.cast("Operator", jsii.invoke(self, "notIpAddress", []))

    @jsii.member(jsii_name="null")
    def null(self) -> "Operator":
        '''(experimental) Check if a key is present at the time of authorization.

        In the policy statement, use either true (the key doesn't exist — it is null) or false (the key exists and its value is not null).

        :stability: experimental
        '''
        return typing.cast("Operator", jsii.invoke(self, "null", []))

    @jsii.member(jsii_name="numericEquals")
    def numeric_equals(self) -> "Operator":
        '''(experimental) Exact match.

        :stability: experimental
        '''
        return typing.cast("Operator", jsii.invoke(self, "numericEquals", []))

    @jsii.member(jsii_name="numericGreaterThan")
    def numeric_greater_than(self) -> "Operator":
        '''(experimental) Match numbers higher than value: ``>``.

        :stability: experimental
        '''
        return typing.cast("Operator", jsii.invoke(self, "numericGreaterThan", []))

    @jsii.member(jsii_name="numericGreaterThanEquals")
    def numeric_greater_than_equals(self) -> "Operator":
        '''(experimental) Match numbers higher or equal value: ``>=``.

        :stability: experimental
        '''
        return typing.cast("Operator", jsii.invoke(self, "numericGreaterThanEquals", []))

    @jsii.member(jsii_name="numericLessThan")
    def numeric_less_than(self) -> "Operator":
        '''(experimental) Match numbers lower than value: ``<``.

        :stability: experimental
        '''
        return typing.cast("Operator", jsii.invoke(self, "numericLessThan", []))

    @jsii.member(jsii_name="numericLessThanEquals")
    def numeric_less_than_equals(self) -> "Operator":
        '''(experimental) Match numbers lower or equal to value: ``<=``.

        :stability: experimental
        '''
        return typing.cast("Operator", jsii.invoke(self, "numericLessThanEquals", []))

    @jsii.member(jsii_name="numericNotEquals")
    def numeric_not_equals(self) -> "Operator":
        '''(experimental) Negated exact match.

        :stability: experimental
        '''
        return typing.cast("Operator", jsii.invoke(self, "numericNotEquals", []))

    @jsii.member(jsii_name="stringEquals")
    def string_equals(self) -> "Operator":
        '''(experimental) Exact match, case sensitive.

        :stability: experimental
        '''
        return typing.cast("Operator", jsii.invoke(self, "stringEquals", []))

    @jsii.member(jsii_name="stringEqualsIgnoreCase")
    def string_equals_ignore_case(self) -> "Operator":
        '''(experimental) Exact match, ignore case.

        :stability: experimental
        '''
        return typing.cast("Operator", jsii.invoke(self, "stringEqualsIgnoreCase", []))

    @jsii.member(jsii_name="stringLike")
    def string_like(self) -> "Operator":
        '''(experimental) Case-sensitive match.

        The values can include a multi-character match wildcard (``*``) or a single-character match wildcard (``?``) anywhere in the string.

        :stability: experimental
        '''
        return typing.cast("Operator", jsii.invoke(self, "stringLike", []))

    @jsii.member(jsii_name="stringNotEquals")
    def string_not_equals(self) -> "Operator":
        '''(experimental) Negated exact match, case sensitive.

        :stability: experimental
        '''
        return typing.cast("Operator", jsii.invoke(self, "stringNotEquals", []))

    @jsii.member(jsii_name="stringNotEqualsIgnoreCase")
    def string_not_equals_ignore_case(self) -> "Operator":
        '''(experimental) Exact exact match, ignore case.

        :stability: experimental
        '''
        return typing.cast("Operator", jsii.invoke(self, "stringNotEqualsIgnoreCase", []))

    @jsii.member(jsii_name="stringNotLike")
    def string_not_like(self) -> "Operator":
        '''(experimental) Negated case-sensitive matching.

        The values can include a multi-character match wildcard (``*``) or a single-character match wildcard (``?``) anywhere in the string.

        :stability: experimental
        '''
        return typing.cast("Operator", jsii.invoke(self, "stringNotLike", []))

    @jsii.member(jsii_name="toString")
    def to_string(self) -> builtins.str:
        '''
        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.invoke(self, "toString", []))


class PolicyStatementBase(
    _aws_cdk_aws_iam_ceddda9d.PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.PolicyStatementBase",
):
    '''(experimental) Base class for the Policy Statement.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.python.classproperty
    @jsii.member(jsii_name="defaultPartition")
    def DEFAULT_PARTITION(cls) -> builtins.str:
        '''(experimental) The default partition for ARNs (such as one of [aws, aws-us-gov, aws-cn]).

        In
        CDK applications, this is a reference to the current partition, otherwise, 'aws'.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.sget(cls, "defaultPartition"))

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__579949f48c7b4f1c10967e9f3b640d8e6ca1a9fd1e941f1920563b132e0996b6)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class PolicyStatementWithCondition(
    PolicyStatementBase,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.PolicyStatementWithCondition",
):
    '''(experimental) Adds "condition" functionality to the Policy Statement.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="freeze")
    def freeze(self) -> _aws_cdk_aws_iam_ceddda9d.PolicyStatement:
        '''(experimental) Make the PolicyStatement immutable.

        After calling this, any of the ``addXxx()`` methods will throw an exception.

        Libraries that lazily generate statement bodies can override this method to
        fill the actual PolicyStatement fields. Be aware that this method may be called
        multiple times.

        :stability: experimental
        '''
        return typing.cast(_aws_cdk_aws_iam_ceddda9d.PolicyStatement, jsii.invoke(self, "freeze", []))

    @jsii.member(jsii_name="hasConditions")
    def has_conditions(self) -> builtins.bool:
        '''(experimental) Checks weather a condition was applied to the policy.

        :stability: experimental
        '''
        return typing.cast(builtins.bool, jsii.invoke(self, "hasConditions", []))

    @jsii.member(jsii_name="if")
    def if_(
        self,
        key: builtins.str,
        value: typing.Any,
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "PolicyStatementWithCondition":
        '''(experimental) Adds a condition to the statement.

        :param key: The key of the condition.
        :param value: The value(s) to check for.
        :param operator: `Operator <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html>`_ of the condition. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4acac607a06bf55f5c43e877cfca00295ffcc1e9945c156974d01171dcb2db3d)
            check_type(argname="argument key", value=key, expected_type=type_hints["key"])
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("PolicyStatementWithCondition", jsii.invoke(self, "if", [key, value, operator]))

    @jsii.member(jsii_name="ifAwsCalledVia")
    def if_aws_called_via(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "PolicyStatementWithCondition":
        '''(experimental) Compare the services with the services that made requests on behalf of the IAM principal (user or role).

        When a principal makes a request to an AWS service, that service might use the principal's credentials to make subsequent requests to other services.

        The ``aws:CalledVia`` key contains an ordered list of each service in the chain that made requests on the principal's behalf.

        **Availability:** This key is present in the request when a service that supports aws:CalledVia uses the credentials of an IAM principal to make a request to another service. This key is not present if the service uses a `service role <https://docs.aws.amazon.com/IAM/latest/UserGuide/id_roles_terms-and-concepts.html#iam-term-service-role>`_ or `service-linked role <https://docs.aws.amazon.com/IAM/latest/UserGuide/id_roles_terms-and-concepts.html#iam-term-service-linked-role>`_ to make a call on the principal's behalf. This key is also not present when the principal makes the call directly.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_condition-keys.html#condition-keys-calledvia

        :param value: The service(s) to check for.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``ForAnyValue:StringEquals``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e10b52e16dcfac79efc9ea923d674c81ffd2dabec0e7822c586ca8f8f9de7896)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("PolicyStatementWithCondition", jsii.invoke(self, "ifAwsCalledVia", [value, operator]))

    @jsii.member(jsii_name="ifAwsCalledViaFirst")
    def if_aws_called_via_first(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "PolicyStatementWithCondition":
        '''(experimental) Compare the services with the first service that made a request on behalf of the IAM principal (user or role).

        For more information, see `aws:CalledVia <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_condition-keys.html#condition-keys-calledvia>`_.

        **Availability:** This key is present in the request when a service that supports aws:CalledVia uses the credentials of an IAM principal to make a request to another service. This key is not present if the service uses a `service role <https://docs.aws.amazon.com/IAM/latest/UserGuide/id_roles_terms-and-concepts.html#iam-term-service-role>`_ or `service-linked role <https://docs.aws.amazon.com/IAM/latest/UserGuide/id_roles_terms-and-concepts.html#iam-term-service-linked-role>`_ to make a call on the principal's behalf. This key is also not present when the principal makes the call directly.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_condition-keys.html#condition-keys-calledviafirst

        :param value: The service(s) to check for.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__77a3d31809a5ad76d6f10fc028393f2e65dc80e4c2be672bf46f7f7e9dd7a674)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("PolicyStatementWithCondition", jsii.invoke(self, "ifAwsCalledViaFirst", [value, operator]))

    @jsii.member(jsii_name="ifAwsCalledViaLast")
    def if_aws_called_via_last(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "PolicyStatementWithCondition":
        '''(experimental) Compare the services with the last service that made a request on behalf of the IAM principal (user or role).

        For more information, see `aws:CalledVia <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_condition-keys.html#condition-keys-calledvia>`_.

        **Availability:** This key is present in the request when a service that supports aws:CalledVia uses the credentials of an IAM principal to make a request to another service. This key is not present if the service uses a `service role <https://docs.aws.amazon.com/IAM/latest/UserGuide/id_roles_terms-and-concepts.html#iam-term-service-role>`_ or `service-linked role <https://docs.aws.amazon.com/IAM/latest/UserGuide/id_roles_terms-and-concepts.html#iam-term-service-linked-role>`_ to make a call on the principal's behalf. This key is also not present when the principal makes the call directly.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_condition-keys.html#condition-keys-calledvialast

        :param value: The service(s) to check for.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__91893d077bf626c48feb45612371bcb5407e81ef25b37d109f8ce87e79e95d7c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("PolicyStatementWithCondition", jsii.invoke(self, "ifAwsCalledViaLast", [value, operator]))

    @jsii.member(jsii_name="ifAwsCurrentTime")
    def if_aws_current_time(
        self,
        value: typing.Union[builtins.str, datetime.datetime, typing.Sequence[typing.Union[builtins.str, datetime.datetime]]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "PolicyStatementWithCondition":
        '''(experimental) Compare the date and time of the request with the date and time that you specify.

        To view an example policy that uses this condition key, see `AWS: Allows Access Within Specific Dates <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_examples_aws-dates.html>`_.

        **Availability:** This key is always included in the request context.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_condition-keys.html#condition-keys-currenttime

        :param value: The date and time to check for. Can be a string in one of the `W3C implementations of the ISO 8601 date <https://www.w3.org/TR/NOTE-datetime>`_ (e.g. ``2020-04-01T00:00:00Z``) or in epoch (UNIX) time or a ``Date()`` object (JavaScript only)
        :param operator: Works with `date operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_Date>`_. **Default:** ``DateLessThanEquals``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6938b62e6c8390e9ada92580158b4619670cd8f303c244d8887ad623658f5646)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("PolicyStatementWithCondition", jsii.invoke(self, "ifAwsCurrentTime", [value, operator]))

    @jsii.member(jsii_name="ifAwsEpochTime")
    def if_aws_epoch_time(
        self,
        value: typing.Union[builtins.str, jsii.Number, datetime.datetime, typing.Sequence[typing.Union[builtins.str, jsii.Number, datetime.datetime]]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "PolicyStatementWithCondition":
        '''(experimental) Compare the date and time of the request in epoch or Unix time with the value that you specify.

        This key also accepts the number of seconds since January 1, 1970.

        **Availability:** This key is always included in the request context.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_condition-keys.html#condition-keys-epochtime

        :param value: The date and time to check for. Can be a string in one of the `W3C implementations of the ISO 8601 date <https://www.w3.org/TR/NOTE-datetime>`_ (e.g. ``2020-04-01T00:00:00Z``) or in epoch (UNIX) time or a ``Date()`` object (JavaScript only)
        :param operator: Works with `date <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_Date>`_ and `numeric operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_Numeric>`_. **Default:** ``DateLessThanEquals``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5e336602a5b626c2dfa6e0b085d1e72345a583c6a8b2164c968a014a9511da50)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("PolicyStatementWithCondition", jsii.invoke(self, "ifAwsEpochTime", [value, operator]))

    @jsii.member(jsii_name="ifAwsMultiFactorAuthAge")
    def if_aws_multi_factor_auth_age(
        self,
        value: typing.Union[jsii.Number, typing.Sequence[jsii.Number]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "PolicyStatementWithCondition":
        '''(experimental) Compare the number of seconds since the requesting principal was authorized using MFA with the number that you specify.

        For more information about MFA, see `Using Multi-Factor Authentication (MFA) in AWS <https://docs.aws.amazon.com/IAM/latest/UserGuide/id_credentials_mfa.html>`_.

        **Availability:** This key is included in the request context only if the principal was authenticated using MFA. If MFA was not used, this key is not present.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_condition-keys.html#condition-keys-multifactorauthage

        :param value: Number of seconds.
        :param operator: Works with `numeric operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_Numeric>`_. **Default:** ``NumericLessThan``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__71739ebf855c9fadf72a940b00213ac4581e5309b2045f79cda3f40a4fa80df0)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("PolicyStatementWithCondition", jsii.invoke(self, "ifAwsMultiFactorAuthAge", [value, operator]))

    @jsii.member(jsii_name="ifAwsMultiFactorAuthPresent")
    def if_aws_multi_factor_auth_present(
        self,
        value: typing.Optional[builtins.bool] = None,
    ) -> "PolicyStatementWithCondition":
        '''(experimental) Check whether multi-factor authentication (MFA) was used to validate the temporary security credentials that made the request.

        **Availability:** This key is included in the request context only when the principal uses temporary credentials to make the request. The key is not present in AWS CLI, AWS API, or AWS SDK requests that are made using long-term credentials.

        Temporary credentials are used to authenticate IAM roles, federated users, IAM users with temporary tokens from ``sts:GetSessionToken``, and users of the AWS Management Console. IAM users in the AWS Management Console unknowingly use temporary credentials. Users sign into the console using their user name and password, which are long-term credentials. However, in the background, the console generates temporary credentials on behalf of the user. To learn which services support using temporary credentials, see `AWS Services That Work with IAM <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_aws-services-that-work-with-iam.html>`_.

        The ``aws:MultiFactorAuthPresent`` key is not present when an API or CLI command is called with long-term credentials, such as user access key pairs. Therefore we recommend that when you check for this key that you use the `...IfExists <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_IfExists>`_ versions of the condition operators.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_condition-keys.html#condition-keys-multifactorauthpresent

        :param value: Weather the MFA should be present or absent. **Default:** ``true``

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__abda858b8dd2b0e6c9adf876576eed0b720a4c9c2f6dea69727206b80396936a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast("PolicyStatementWithCondition", jsii.invoke(self, "ifAwsMultiFactorAuthPresent", [value]))

    @jsii.member(jsii_name="ifAwsPrincipalAccount")
    def if_aws_principal_account(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "PolicyStatementWithCondition":
        '''(experimental) Compare the account to which the requesting principal belongs with the account identifier that you specify.

        **Availability:** This key is always included in the request context.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_condition-keys.html#condition-keys-principalaccount

        :param value: Account identifier(s).
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e4de3fd3e2a1957285db40def17a862d61d311316e98a72c4ef86192b5488b51)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("PolicyStatementWithCondition", jsii.invoke(self, "ifAwsPrincipalAccount", [value, operator]))

    @jsii.member(jsii_name="ifAwsPrincipalArn")
    def if_aws_principal_arn(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "PolicyStatementWithCondition":
        '''(experimental) Compare the `Amazon Resource Name <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_identifiers.html#identifiers-arns>`_ (ARN) of the principal that made the request with the ARN that you specify.

        For IAM roles, the request context returns the ARN of the role, not the ARN of the user that assumed the role. To learn which types of principals you can specify in this condition key, see `Specifying a Principal <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_principal.html#Principal_specifying>`_.

        **Availability:** This key is always included in the request context.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_condition-keys.html#condition-keys-principalarn

        :param value: Principle ARN(s).
        :param operator: Works with `ARN operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_ARN>`_ and `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``ArnLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__545ee3520b072cf7617ddaece58cf66cf06cd058b5cd7f63ed950d865bccf21f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("PolicyStatementWithCondition", jsii.invoke(self, "ifAwsPrincipalArn", [value, operator]))

    @jsii.member(jsii_name="ifAwsPrincipalIsAWSService")
    def if_aws_principal_is_aws_service(
        self,
        value: typing.Optional[builtins.bool] = None,
    ) -> "PolicyStatementWithCondition":
        '''(experimental) Check whether the call to your resource is being made directly by an AWS `service principal <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_principal.html#principal-services>`_. For example, AWS CloudTrail uses the service principal ``cloudtrail.amazonaws.com`` to write logs to your Amazon S3 bucket. The request context key is set to true when a service uses a service principal to perform a direct action on your resources. The context key is set to false if the service uses the credentials of an IAM principal to make a request on the principal's behalf. It is also set to false if the service uses a `service role <https://docs.aws.amazon.com/IAM/latest/UserGuide/id_roles_terms-and-concepts.html#iam-term-service-role>`_ or `service-linked role <https://docs.aws.amazon.com/IAM/latest/UserGuide/id_roles_terms-and-concepts.html#iam-term-service-linked-role>`_ to make a call on the principal's behalf.

        **Availability:** This key is present in the request context for all signed API requests that use AWS credentials.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_condition-keys.html#condition-keys-principalisawsservice

        :param value: Weather the call to your resource is being made directly by an AWS service principal. **Default:** ``true``

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f2a13889bc1e8659e6e30524bfcba2b883970377bf5c420d76fd0856c03d2fd3)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast("PolicyStatementWithCondition", jsii.invoke(self, "ifAwsPrincipalIsAWSService", [value]))

    @jsii.member(jsii_name="ifAwsPrincipalOrgID")
    def if_aws_principal_org_id(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "PolicyStatementWithCondition":
        '''(experimental) Compare the identifier of the organization in AWS Organizations to which the requesting principal belongs with the identifier you specify.

        **Availability:** This key is included in the request context only if the principal is a member of an organization.

        This global key provides an alternative to listing all the account IDs for all AWS accounts in an organization. You can use this condition key to simplify specifying the ``Principal`` element in a resource-based policy. You can specify the organization ID in the condition element. When you add and remove accounts, policies that include the ``aws:PrincipalOrgID`` key automatically include the correct accounts and don't require manual updating.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_condition-keys.html#condition-keys-principalorgid

        :param value: Organization ID(s) in format ``o-xxxxxxxxxxx``.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bbcb97bb3d386c1d9e1d5557052e4f49372985dd0397c74431d35d706bf57668)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("PolicyStatementWithCondition", jsii.invoke(self, "ifAwsPrincipalOrgID", [value, operator]))

    @jsii.member(jsii_name="ifAwsPrincipalOrgPaths")
    def if_aws_principal_org_paths(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "PolicyStatementWithCondition":
        '''(experimental) Compare the AWS Organizations path for the principal who is making the request to the path you provide.

        That principal can be an IAM user, IAM role, federated user, or AWS account root user.

        This condition ensures that the requester is an account member within the specified organization root or organizational units (OUs) in AWS Organizations. An AWS Organizations path is a text representation of the structure of an Organizations entity. For more information about using and understanding paths, see Understand the `AWS Organizations Entity Path <https://docs.aws.amazon.com/IAM/latest/UserGuide/access_policies_access-advisor-view-data-orgs.html#access_policies_access-advisor-viewing-orgs-entity-path>`_.

        **Availability:** This key is included in the request context only if the principal is a member of an organization.

        **Note:** Organization IDs are globally unique but OU IDs and root IDs are unique only within an organization. This means that no two organizations share the same organization ID. However, another organization might have an OU or root with the same ID as yours. We recommend that you always include the organization ID when you specify an OU or root.

        ``aws:PrincipalOrgPaths`` is a multivalued condition key. Multivalued keys include one or more values in a list format. The result is a logical ``OR``. When you use multiple values with the ``ForAnyValue:`` condition operator, the principal's path must match one of the paths provided. For policies that include multiple values for a single key, you must enclose the conditions within brackets like an array (``"Key":["Value1", "Value2"]``). You should also include these brackets when there is a single value. For more information about multivalued condition keys, see `Creating a Condition with Multiple Keys or Values <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_multi-value-conditions.html>`_.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_condition-keys.html#condition-keys-principalorgpaths

        :param value: Organization path(s) in the format of ``o-xxxxxxxxxxx/r-xxxxxxxxxx/ou-xxxx-xxxxxxxx/ou-xxxx-xxxxxxxx/``.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringEquals``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7a1a3d666a5661c5fa9395378496d8c3b6d977982e97fd2c935e2ef07eacc814)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("PolicyStatementWithCondition", jsii.invoke(self, "ifAwsPrincipalOrgPaths", [value, operator]))

    @jsii.member(jsii_name="ifAwsPrincipalServiceName")
    def if_aws_principal_service_name(
        self,
        value: builtins.str,
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "PolicyStatementWithCondition":
        '''(experimental) Compare the `service principal <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_principal.html#principal-services>`_ name in the policy with the service principal that is making requests to your resources. You can use this key to check whether this call is made by a specific service principal. When a service principal makes a direct request to your resource, the ``aws:PrincipalServiceName`` key contains the name of the service principal. For example, the AWS CloudTrail service principal name is ``cloudtrail.amazonaws.com``.

        **Availability:** This key is present in the request when the call is made by an AWS service principal. This key is not present in any other situation, including the following:

        - If the service uses a `service role <https://docs.aws.amazon.com/IAM/latest/UserGuide/id_roles_terms-and-concepts.html#iam-term-service-role>`_ or `service-linked role <https://docs.aws.amazon.com/IAM/latest/UserGuide/id_roles_terms-and-concepts.html#iam-term-service-linked-role>`_ to make a call on the principal's behalf.
        - If the service uses the credentials of an IAM principal to make a request on the principal's behalf.
        - If the call is made directly by an IAM principal.

        You can use this condition key to limit access to your trusted identities and expected network locations, while safely granting access to an AWS service.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_condition-keys.html#condition-keys-principalservicename

        :param value: AWS service name, e.g. ``cloudtrail.amazonaws.com``.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c7b8f923048816d47ebceb8d4338ca96d7a82661eff87edc6e8963e6f28bda7c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("PolicyStatementWithCondition", jsii.invoke(self, "ifAwsPrincipalServiceName", [value, operator]))

    @jsii.member(jsii_name="ifAwsPrincipalServiceNamesList")
    def if_aws_principal_service_names_list(
        self,
        value: typing.Sequence[builtins.str],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "PolicyStatementWithCondition":
        '''(experimental) This key provides a list of all `service principal <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_principal.html#principal-services>`_ names that belong to the service. This is an advanced condition key. You can use it to restrict the service from accessing your resource from a specific Region only. Some services may create Regional service principals to indicate a particular instance of the service within a specific Region. You can limit access to a resource to a particular instance of the service. When a service principal makes a direct request to your resource, the ``aws:PrincipalServiceNamesList`` contains an unordered list of all service principal names associated with the Regional instance of the service.

        **Availability:** This key is present in the request when the call is made by an AWS service principal. This key is not present in any other situation, including the following:

        - If the service uses a `service role <https://docs.aws.amazon.com/IAM/latest/UserGuide/id_roles_terms-and-concepts.html#iam-term-service-role>`_ or `service-linked role <https://docs.aws.amazon.com/IAM/latest/UserGuide/id_roles_terms-and-concepts.html#iam-term-service-linked-role>`_ to make a call on the principal's behalf.
        - If the service uses the credentials of an IAM principal to make a request on the principal's behalf.
        - If the call is made directly by an IAM principal.

        ``aws:PrincipalServiceNamesList`` is a multivalued condition key. Multivalued keys include one or more values in a list format. The result is a logical ``OR``. You must use the ``ForAnyValue`` or ``ForAllValues`` set operators with the ``StringLike`` `condition operator <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_ when you use this key. For policies that include multiple values for a single key, you must enclose the conditions within brackets like an array, such as ``("Key":["Value1", "Value2"])``. You should also include these brackets when there is a single value. For more information about multivalued condition keys, see `Using multiple keys and values <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_multi-value-conditions.html#reference_policies_multi-key-or-value-conditions>`_.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_condition-keys.html#condition-keys-principalservicenameslist

        :param value: AWS service name list.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``ForAnyValue:StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5119b5010474e05d588b96102c39a318ca8515112eec50b3cd9906d9807e2a02)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("PolicyStatementWithCondition", jsii.invoke(self, "ifAwsPrincipalServiceNamesList", [value, operator]))

    @jsii.member(jsii_name="ifAwsPrincipalTag")
    def if_aws_principal_tag(
        self,
        key: builtins.str,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "PolicyStatementWithCondition":
        '''(experimental) Compare the tag attached to the principal making the request with the tag that you specify.

        If the principal has more than one tag attached, the request context includes one aws:PrincipalTag key for each attached tag key.

        **Availability:** This key is included in the request context if the principal is using an IAM user with attached tags. It is included for a principal using an IAM role with attached tags or `session tags <https://docs.aws.amazon.com/IAM/latest/UserGuide/id_session-tags.html>`_.

        You can add custom attributes to a user or role in the form of a key-value pair. For more information about IAM tags, see `Tagging IAM Users and Roles <https://docs.aws.amazon.com/IAM/latest/UserGuide/id_tags.html>`_. You can use ``aws:PrincipalTag`` to `control access <https://docs.aws.amazon.com/IAM/latest/UserGuide/access_iam-tags.html#access_iam-tags_control-resources>`_ for AWS principals.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_condition-keys.html#condition-keys-principaltag

        :param key: The tag key to check.
        :param value: The tag value(s) to check against.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a3dd9dfa4ff3b13e2ad35f4eb3ab4ec96b2ba8e5256e9ec5df9b0ddb6b8e2200)
            check_type(argname="argument key", value=key, expected_type=type_hints["key"])
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("PolicyStatementWithCondition", jsii.invoke(self, "ifAwsPrincipalTag", [key, value, operator]))

    @jsii.member(jsii_name="ifAwsPrincipalType")
    def if_aws_principal_type(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "PolicyStatementWithCondition":
        '''(experimental) Compare the type of principal making the request with the principal type that you specify.

        For details about how the information appears in the request context for different principals, see `Specifying a Principal <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_principal.html#Principal_specifying>`_.

        **Availability:** This key is always included in the request context.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_condition-keys.html#condition-keys-principaltype

        :param value: The principal type(s). Any of ``Account``, ``User``, ``FederatedUser``, ``AssumedRole``, ``Anonymous``
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringEquals``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c6adf16796fa9edee7366bce0c01aa700f2b3e1847204e40f074fdf651a1fb1f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("PolicyStatementWithCondition", jsii.invoke(self, "ifAwsPrincipalType", [value, operator]))

    @jsii.member(jsii_name="ifAwsReferer")
    def if_aws_referer(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "PolicyStatementWithCondition":
        '''(experimental) Compare who referred the request in the client browser with the referer that you specify.

        The ``aws:referer`` request context value is provided by the caller in an HTTP header.

        **Availability:** This key is included in the request context only if the request was invoked using a URL in the browser.

        For example, you can call `Amazon S3 API operations directly using a web browser <https://docs.aws.amazon.com/AmazonS3/latest/dev/example-bucket-policies.html#example-bucket-policies-use-case-4>`_. This means that you can view S3 objects, such as images and documents, directly through a web browser. The ``aws:referer`` condition allows you to restrict access to specific values in the HTTP or HTTPS request based on the value of the referrer header.

        **Warning:** This condition should be used carefully. It is dangerous to include a publicly known referer header value. Unauthorized parties can use modified or custom browsers to provide any ``aws:referer`` value that they choose. As a result, ``aws:referer`` should not be used to prevent unauthorized parties from making direct AWS requests. It is offered only to allow customers to protect their digital content, such as content stored in Amazon S3, from being referenced on unauthorized third-party sites.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_condition-keys.html#condition-keys-referer

        :param value: The referer url(s).
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c252618b1d8c3ba69e31759bc4792eec37911a633871e1d2370c0d757afba984)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("PolicyStatementWithCondition", jsii.invoke(self, "ifAwsReferer", [value, operator]))

    @jsii.member(jsii_name="ifAwsRequestedRegion")
    def if_aws_requested_region(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "PolicyStatementWithCondition":
        '''(experimental) Compare the AWS Region that was called in the request with the Region that you specify.

        You can use this global condition key to control which Regions can be requested. To view the AWS Regions for each service, see `Service endpoints and quotas <https://docs.aws.amazon.com/general/latest/gr/aws-service-information.html>`_ in the Amazon Web Services General Reference.

        **Availability:** This key is always included in the request context.

        Some global services, such as IAM, have a single endpoint. Because this endpoint is physically located in the US East (N. Virginia) Region, IAM calls are always made to the us-east-1 Region. For example, if you create a policy that denies access to all services if the requested Region is not us-west-2, then IAM calls always fail. To view an example of how to work around this, see `NotAction with Deny <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_notaction.html>`_.

        **Note:** The ``aws:RequestedRegion`` condition key allows you to control which endpoint of a service is invoked but does not control the impact of the operation. Some services have cross-Region impacts. For example, Amazon S3 has API operations that control cross-Region replication. You can invoke ``s3:PutBucketReplication`` in one Region (which is affected by the ``aws:RequestedRegion`` condition key), but other Regions are affected based on the replications configuration settings.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_condition-keys.html#condition-keys-requestedregion

        :param value: The region(s).
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringEquals``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fd80f1e59171cdaef4e7a050252718eeaf45802d248593d168b4013f07fd1baa)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("PolicyStatementWithCondition", jsii.invoke(self, "ifAwsRequestedRegion", [value, operator]))

    @jsii.member(jsii_name="ifAwsRequestTag")
    def if_aws_request_tag(
        self,
        key: builtins.str,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "PolicyStatementWithCondition":
        '''(experimental) Compare the tag key-value pair that was passed in the request with the tag pair that you specify.

        For example, you could check whether the request includes the tag key ``Dept`` and that it has the value ``Accounting``. For more information, see `Controlling Access During AWS Requests <https://docs.aws.amazon.com/IAM/latest/UserGuide/access_tags.html#access_tags_control-requests>`_.

        **Availability:** This key is included in the request context when tags are passed in the request. When multiple tags are passed in the request, there is one context key for each tag key-value pair.

        Because you can include multiple tag key-value pairs in a request, the request content could be a multivalued request. In this case, you should consider using the ``ForAllValues`` or ``ForAnyValue`` set operators. For more information, see `Using Multiple Keys and Values <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_multi-value-conditions.html#reference_policies_multi-key-or-value-conditions>`_.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_condition-keys.html#condition-keys-requesttag

        :param key: The tag key to check.
        :param value: The tag value(s) to check against.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4ce7be33b6db69996ee0536555f56937e600dcef3d37890a1c9dc331155f098e)
            check_type(argname="argument key", value=key, expected_type=type_hints["key"])
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("PolicyStatementWithCondition", jsii.invoke(self, "ifAwsRequestTag", [key, value, operator]))

    @jsii.member(jsii_name="ifAwsResourceTag")
    def if_aws_resource_tag(
        self,
        key: builtins.str,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "PolicyStatementWithCondition":
        '''(experimental) Compare the tag key-value pair that you specify with the key-value pair that is attached to the resource.

        For example, you could require that access to a resource is allowed only if the resource has the attached tag key ``Dept`` with the value ``Marketing``. For more information, see `Controlling Access to AWS Resources <https://docs.aws.amazon.com/IAM/latest/UserGuide/access_tags.html#access_tags_control-resources>`_.

        **Availability:** This key is included in the request context when the requested resource already has attached tags. This key is returned only for resources that `support authorization based on tags <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_aws-services-that-work-with-iam.html>`_. There is one context key for each tag key-value pair.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_condition-keys.html#condition-keys-resourcetag

        :param key: The tag key to check.
        :param value: The tag value(s) to check against.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__77574925161ac75d69e4783281751d06ead48182e52515e21c934b117a2ce4c3)
            check_type(argname="argument key", value=key, expected_type=type_hints["key"])
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("PolicyStatementWithCondition", jsii.invoke(self, "ifAwsResourceTag", [key, value, operator]))

    @jsii.member(jsii_name="ifAwsSecureTransport")
    def if_aws_secure_transport(
        self,
        value: typing.Optional[builtins.bool] = None,
    ) -> "PolicyStatementWithCondition":
        '''(experimental) Check whether the request was sent using SSL.

        The request context returns ``true`` or ``false``. In a policy, you can allow specific actions only if the request is sent using SSL.

        **Availability:** This key is always included in the request context.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_condition-keys.html#condition-keys-securetransport

        :param value: Weather request was sent using SSL. **Default:** ``true``

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__26c2d255a4532cdf69c90e71a07b59e34532a6499449e90b967406350ff36709)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast("PolicyStatementWithCondition", jsii.invoke(self, "ifAwsSecureTransport", [value]))

    @jsii.member(jsii_name="ifAwsSourceAccount")
    def if_aws_source_account(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "PolicyStatementWithCondition":
        '''(experimental) Compare the account ID of the resource making a service-to-service request with the account ID that you specify.

        **Availability:** This key is included in the request context only if accessing a resource triggers an AWS service to call another service on behalf of the resource owner. The calling service must pass the resource ARN of the source to the called service. This ARN includes the source account ID.

        You can use this condition key to check that Amazon S3 is not being used as a `confused deputy <https://docs.aws.amazon.com/IAM/latest/UserGuide/id_roles_create_for-user_externalid.html#confused-deputy>`_. For example, when an Amazon S3 bucket update triggers an Amazon SNS topic post, the Amazon S3 service invokes the ``sns:Publish`` API operation. The bucket is considered the source of the SNS request and the value of the key is the account ID from the bucket's ARN.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_condition-keys.html#condition-keys-sourceaccount

        :param value: The account ID(s).
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f405148df33289680f21ae809ea41cb3d1af04fa48caf4ff026f1d07353af40f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("PolicyStatementWithCondition", jsii.invoke(self, "ifAwsSourceAccount", [value, operator]))

    @jsii.member(jsii_name="ifAwsSourceArn")
    def if_aws_source_arn(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "PolicyStatementWithCondition":
        '''(experimental) Compare the `Amazon Resource Name (ARN) <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_identifiers.html#identifiers-arns>`_ of the resource making a service-to-service request with the ARN that you specify.

        This key does not work with the ARN of the principal making the request. Instead, use `aws:PrincipalArn <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_condition-keys.html#condition-keys-principalarn>`_. The source's ARN includes the account ID, so it is not necessary to use ``aws:SourceAccount`` with ``aws:SourceArn``.

        **Availability:** This key is included in the request context only if accessing a resource triggers an AWS service to call another service on behalf of the resource owner. The calling service must pass the ARN of the original resource to the called service.

        You can use this condition key to check that Amazon S3 is not being used as a `confused deputy <https://docs.aws.amazon.com/IAM/latest/UserGuide/id_roles_create_for-user_externalid.html#confused-deputy>`_. For example, when an Amazon S3 bucket update triggers an Amazon SNS topic post, the Amazon S3 service invokes the ``sns:Publish`` API operation. The bucket is considered the source of the SNS request and the value of the key is the bucket's ARN.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_condition-keys.html#condition-keys-sourcearn

        :param value: The source ARN(s).
        :param operator: Works with `ARN operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_ARN>`_ and `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``ArnLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__da13e0098396083cf25f2bf190ea6f5f5f9c8f7ce3e1a89069b0e95c7fd186c9)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("PolicyStatementWithCondition", jsii.invoke(self, "ifAwsSourceArn", [value, operator]))

    @jsii.member(jsii_name="ifAwsSourceIdentity")
    def if_aws_source_identity(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "PolicyStatementWithCondition":
        '''(experimental) Compare the source identity that was set by the principal with the source identity that you specify in the policy.

        **Availability:** This key is included in the request context after a source identity has been set when a role is assumed using any AWS STS assume-role CLI command, or AWS STS ``AssumeRole`` API operation.

        You can use this key in a policy to allow actions in AWS by principals that have set a source identity when assuming a role. Activity for the role's specified source identity appears in `AWS CloudTrail <https://docs.aws.amazon.com/IAM/latest/UserGuide/cloudtrail-integration.html#cloudtrail-integration_signin-tempcreds>`_. This makes it easier for administrators to determine who or what performed actions with a role in AWS.

        Unlike `sts:RoleSessionName <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_iam-condition-keys.html#ck_rolesessionname>`_, after the source identity is set, the value cannot be changed. It is present in the request context for all actions taken by the role. The value persists into subsequent role sessions when you use the session credentials to assume another role. Assuming one role from another is called `role chaining <https://docs.aws.amazon.com/IAM/latest/UserGuide/id_roles_terms-and-concepts.html#iam-term-role-chaining>`_.

        The `sts:SourceIdentity <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_iam-condition-keys.html#ck_sourceidentity>`_ key is present in the request when the principal initially sets a source identity while assuming a role using any AWS STS assume-role CLI command, or AWS STS ``AssumeRole`` API operation. The ``aws:SourceIdentity`` key is present in the request for any actions that are taken with a role session that has a source identity set.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_condition-keys.html#condition-keys-sourceidentity

        :param value: The source identity.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__19e1f1ea56b9049f0c9d51b8b2abec0dc02e9c124237b27f5b83631e481bc21c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("PolicyStatementWithCondition", jsii.invoke(self, "ifAwsSourceIdentity", [value, operator]))

    @jsii.member(jsii_name="ifAwsSourceIp")
    def if_aws_source_ip(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "PolicyStatementWithCondition":
        '''(experimental) Compare the requester's IP address with the IP address that you specify.

        **Availability:** This key is included in the request context, except when the requester uses a VPC endpoint to make the request.

        The ``aws:SourceIp`` condition key can be used in a policy to allow principals to make requests only from within a specified IP range. However, this policy denies access if an AWS service makes calls on the principal's behalf. In this case, you can use ``aws:SourceIp`` with the `aws:ViaAWSService <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_condition-keys.html#condition-keys-viaawsservice>`_ key to ensure that the source IP restriction applies only to requests made directly by a principal.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_condition-keys.html#condition-keys-sourceip

        :param value: The source IP(s).
        :param operator: Works with IP `address operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_IPAddress>`_. **Default:** ``IpAddress``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__149e746a4a92c4008590bf34380ff8846e67bfde3493e9aabdd14607cd2c778f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("PolicyStatementWithCondition", jsii.invoke(self, "ifAwsSourceIp", [value, operator]))

    @jsii.member(jsii_name="ifAwsSourceVpc")
    def if_aws_source_vpc(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "PolicyStatementWithCondition":
        '''(experimental) Check whether the request comes from the VPC that you specify.

        In a policy, you can use this condition to allow access to only a specific VPC. For more information, see `Restricting Access to a Specific VPC <https://docs.aws.amazon.com/AmazonS3/latest/dev/example-bucket-policies-vpc-endpoint.html#example-bucket-policies-restrict-access-vpc>`_ in the *Amazon Simple Storage Service Developer Guide*.

        **Availability:** This key is included in the request context only if the requester uses a VPC endpoint to make the request.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_condition-keys.html#condition-keys-sourcevpc

        :param value: The VPS ID(s).
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringEquals``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2813df0980c3415210198c2b2c6ed7e075b4b4314165d7d618eb0711433a752b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("PolicyStatementWithCondition", jsii.invoke(self, "ifAwsSourceVpc", [value, operator]))

    @jsii.member(jsii_name="ifAwsSourceVpce")
    def if_aws_source_vpce(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "PolicyStatementWithCondition":
        '''(experimental) Compare the VPC endpoint identifier of the request with the endpoint ID that you specify.

        In a policy, you can use this condition to restrict access to a specific VPC endpoint. For more information, see `Restricting Access to a Specific VPC Endpoint <https://docs.aws.amazon.com/AmazonS3/latest/dev/example-bucket-policies-vpc-endpoint.html#example-bucket-policies-restrict-access-vpc-endpoint>`_ in the *Amazon Simple Storage Service Developer Guide*.

        **Availability:** This key is included in the request context only if the requester uses a VPC endpoint to make the request.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_condition-keys.html#condition-keys-sourcevpce

        :param value: The VPC Endpoint ID(s).
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__935566b2d494943945611d0a7eb7d62f40ef4638d78e4a63029abb0e0934e500)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("PolicyStatementWithCondition", jsii.invoke(self, "ifAwsSourceVpce", [value, operator]))

    @jsii.member(jsii_name="ifAwsTagKeys")
    def if_aws_tag_keys(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "PolicyStatementWithCondition":
        '''(experimental) Compare the tag keys in a request with the keys that you specify.

        As a best practice when you use policies to control access using tags, use the ``aws:TagKeys`` condition key to define what tag keys are allowed. For example policies and more information, see `Controlling Access Based on Tag Keys <https://docs.aws.amazon.com/IAM/latest/UserGuide/access_tags.html#access_tags_control-tag-keys>`_.

        **Availability:** This key is included in the request context only if the operation supports attaching tags to resources.

        Because you can include multiple tag key-value pairs in a request, the request content could be a `multivalued <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_multi-value-conditions.html>`_ request. In this case, you should consider using the ``ForAllValues`` or ``ForAnyValue`` set operators. For more information, see Using Multiple Keys and Values.

        Some services support tagging with resource operations, such as creating, modifying, or deleting a resource. To allow tagging and operations as a single call, you must create a policy that includes both the tagging action and the resource-modifying action. You can then use the ``aws:TagKeys`` condition key to enforce using specific tag keys in the request. For example, to limit tags when someone creates an Amazon EC2 snapshot, you must include the ``ec2:CreateSnapshot`` creation action ***and*** the ``ec2:CreateTags`` tagging action in the policy. To view a policy for this scenario that uses ``aws:TagKeys``, see `Creating a Snapshot with Tags <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ExamplePolicies_EC2.html#iam-creating-snapshot-with-tags>`_ in the *Amazon EC2 User Guide for Linux Instances*.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_condition-keys.html#condition-keys-tagkeys

        :param value: The tag key(s).
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b6b5b81ccf9fc0cc775c13aa86d12a487c6115ad2c1c8d05ce07d17ed125027f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("PolicyStatementWithCondition", jsii.invoke(self, "ifAwsTagKeys", [value, operator]))

    @jsii.member(jsii_name="ifAwsTokenIssueTime")
    def if_aws_token_issue_time(
        self,
        value: typing.Union[builtins.str, datetime.datetime],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "PolicyStatementWithCondition":
        '''(experimental) Compare the date and time that temporary security credentials were issued with the date and time that you specify.

        **Availability:** This key is included in the request context only when the principal uses temporary credentials to make the request. They key is not present in AWS CLI, AWS API, or AWS SDK requests that are made using access keys.

        To learn which services support using temporary credentials, see `AWS Services That Work with IAM <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_aws-services-that-work-with-iam.html>`_.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_condition-keys.html#condition-keys-tokenissuetime

        :param value: The date and time to check for. Can be a string in one of the `W3C implementations of the ISO 8601 date <https://www.w3.org/TR/NOTE-datetime>`_ (e.g. ``2020-04-01T00:00:00Z``) or in epoch (UNIX) time or a ``Date()`` object (JavaScript only)
        :param operator: Works with `date operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_Date>`_. **Default:** ``DateGreaterThanEquals``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f3df45da6adf87ea8cab5f09ed2fa144df7e42fabaaab2da35db5d4ee665bf2c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("PolicyStatementWithCondition", jsii.invoke(self, "ifAwsTokenIssueTime", [value, operator]))

    @jsii.member(jsii_name="ifAwsUserAgent")
    def if_aws_user_agent(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "PolicyStatementWithCondition":
        '''(experimental) Compare the requester's client application with the application that you specify.

        **Availability:** This key is always included in the request context.

        **Warning:** This key should be used carefully. Since the ``aws:UserAgent`` value is provided by the caller in an HTTP header, unauthorized parties can use modified or custom browsers to provide any ``aws:UserAgent`` value that they choose. As a result, ``aws:UserAgent`` should not be used to prevent unauthorized parties from making direct AWS requests. You can use it to allow only specific client applications, and only after testing your policy.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_condition-keys.html#condition-keys-useragent

        :param value: The User Agent string(s).
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5325d219d3e0d2b37eb851625320a8e810a9acf8d01a892beba99c9dfa3bcefe)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("PolicyStatementWithCondition", jsii.invoke(self, "ifAwsUserAgent", [value, operator]))

    @jsii.member(jsii_name="ifAwsUserid")
    def if_aws_userid(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "PolicyStatementWithCondition":
        '''(experimental) Compare the requester's principal identifier with the ID that you specify.

        For IAM users, the request context value is the user ID. For IAM roles, this value format can vary. For details about how the information appears for different principals, see `Specifying a Principal <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_principal.html#Principal_specifying>`_.

        **Availability:** This key is included in the request context for all signed requests. Anonymous requests do not include this key.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_condition-keys.html#condition-keys-userid

        :param value: The principal identifier(s).
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__dee3b7f069b307fc3df14ca752871945fdf57dbba451be0238d9560a10ba6fca)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("PolicyStatementWithCondition", jsii.invoke(self, "ifAwsUserid", [value, operator]))

    @jsii.member(jsii_name="ifAwsUsername")
    def if_aws_username(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "PolicyStatementWithCondition":
        '''(experimental) Compare the requester's user name with the user name that you specify.

        For details about how the information appears for different principals, see `Specifying a Principal <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_principal.html#Principal_specifying>`_.

        **Availability:** This key is always included in the request context for IAM users. Anonymous requests and requests that are made using the AWS account root user or IAM roles do not include this key.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_condition-keys.html#condition-keys-username

        :param value: The user name(s).
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__34f8d87031b10108d53094ddbe0c4b69bf79a3960b0a2d847ba1175a4bb6e52e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("PolicyStatementWithCondition", jsii.invoke(self, "ifAwsUsername", [value, operator]))

    @jsii.member(jsii_name="ifAwsViaAWSService")
    def if_aws_via_aws_service(
        self,
        value: typing.Optional[builtins.bool] = None,
    ) -> "PolicyStatementWithCondition":
        '''(experimental) Check whether an AWS service makes a request to another service on your behalf.

        The request context key returns ``true`` when a service uses the credentials of an IAM principal to make a request on behalf of the principal. The context key returns ``false`` if the service uses a `service role <https://docs.aws.amazon.com/IAM/latest/UserGuide/id_roles_terms-and-concepts.html#iam-term-service-role>`_ or `service-linked role <https://docs.aws.amazon.com/IAM/latest/UserGuide/id_roles_terms-and-concepts.html#iam-term-service-linked-role>`_ to make a call on the principal's behalf. The request context key also returns ``false`` when the principal makes the call directly.

        **Availability:** This key is always included in the request context for most services.

        The following services do not currently support ``aws:ViaAWSService``:

        - Amazon EC2
        - AWS Glue
        - AWS Lake Formation
        - AWS OpsWorks

        You can use this condition key to allow or deny access based on whether a request was made by a service. To view an example policy, see `AWS: Denies Access to AWS Based on the Source IP <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_examples_aws_deny-ip.html>`_.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_condition-keys.html#condition-keys-viaawsservice

        :param value: Whether a request was made by a service. **Default:** ``true``

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__51e9c642e90e85a28ee4c84d88d46808c309d9c0f81d52921cfe3fece838f2f9)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast("PolicyStatementWithCondition", jsii.invoke(self, "ifAwsViaAWSService", [value]))

    @jsii.member(jsii_name="ifAwsVpcSourceIp")
    def if_aws_vpc_source_ip(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "PolicyStatementWithCondition":
        '''(experimental) Compare the IP address from which a request was made with the IP address that you specify.

        In a policy, the key matches only if the request originates from the specified IP address and it goes through a VPC endpoint.

        **Availability:** This key is included in the request context only if the request is made using a VPC endpoint.

        For more information, see `Controlling Access to Services with VPC Endpoints <https://docs.aws.amazon.com/vpc/latest/userguide/vpc-endpoints-access.html>`_ in the *Amazon VPC User Guide*.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_condition-keys.html#condition-keys-vpcsourceip

        :param value: The VPC source IP(s).
        :param operator: Works with IP `address operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_IPAddress>`_. **Default:** ``IpAddress``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f7123410883271971ad6aa7d7444820711a6ec350c757f2676a9bda361623dc5)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("PolicyStatementWithCondition", jsii.invoke(self, "ifAwsVpcSourceIp", [value, operator]))

    @jsii.member(jsii_name="toJSON")
    def to_json(self) -> typing.Any:
        '''(experimental) Injects conditions into the statement.

        Only relevant for the main package. In CDK mode this only calls super.

        :stability: experimental
        '''
        return typing.cast(typing.Any, jsii.invoke(self, "toJSON", []))

    @jsii.member(jsii_name="toStatementJson")
    def to_statement_json(self) -> typing.Any:
        '''(experimental) JSON-ify the policy statement.

        Used when JSON.stringify() is called

        :stability: experimental
        '''
        return typing.cast(typing.Any, jsii.invoke(self, "toStatementJson", []))

    @builtins.property
    @jsii.member(jsii_name="floydConditions")
    def _floyd_conditions(self) -> Conditions:
        '''
        :stability: experimental
        '''
        return typing.cast(Conditions, jsii.get(self, "floydConditions"))

    @_floyd_conditions.setter
    def _floyd_conditions(self, value: Conditions) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bd17871dd5791c2ddfc16aed89364d3cd00a3b40b5bc8f1d1622bea99c46c1ef)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "floydConditions", value)


@jsii.data_type(
    jsii_type="cdk-iam-floyd.Principals",
    jsii_struct_bases=[],
    name_mapping={},
)
class Principals:
    def __init__(self) -> None:
        '''(experimental) A collection of Principal's.

        :stability: experimental
        '''
        self._values: typing.Dict[builtins.str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "Principals(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="cdk-iam-floyd.ResourceTypes",
    jsii_struct_bases=[],
    name_mapping={},
)
class ResourceTypes:
    def __init__(self) -> None:
        '''
        :stability: experimental
        '''
        self._values: typing.Dict[builtins.str, typing.Any] = {}

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ResourceTypes(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PolicyStatementWithActions(
    PolicyStatementWithCondition,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.PolicyStatementWithActions",
):
    '''(experimental) Adds "action" functionality to the Policy Statement.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="allActions")
    def all_actions(self) -> "PolicyStatementWithActions":
        '''(experimental) Adds all actions of the statement provider to the statement, e.g. ``actions: 'ec2:*'``.

        :stability: experimental
        '''
        return typing.cast("PolicyStatementWithActions", jsii.invoke(self, "allActions", []))

    @jsii.member(jsii_name="allListActions")
    def all_list_actions(self) -> "PolicyStatementWithActions":
        '''(experimental) Adds all actions with `access level <https://docs.aws.amazon.com/IAM/latest/UserGuide/access_policies_understand-policy-summary-access-level-summaries.html#access_policies_access-level>`_ LIST to the statement.

        Permission to list resources within the service to determine whether an object exists.

        Actions with this level of access can list objects but cannot see the contents of a resource.

        For example, the Amazon S3 action ``ListBucket`` has the List access level.

        :stability: experimental
        '''
        return typing.cast("PolicyStatementWithActions", jsii.invoke(self, "allListActions", []))

    @jsii.member(jsii_name="allMatchingActions")
    def all_matching_actions(
        self,
        *expressions: builtins.str,
    ) -> "PolicyStatementWithActions":
        '''(experimental) Adds all actions that match one of the given regular expressions.

        :param expressions: One or more regular expressions. The regular expressions need to be in `Perl/JavaScript literal style <https://developer.mozilla.org/en-US/docs/Web/JavaScript/Guide/Regular_Expressions>`_ and need to be passed as strings, For example:: allMatchingActions('/vpn/i')

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1cf6892a5b291a682363a39fda717f045e02342ae3e6d11a6e8db52747e40eb8)
            check_type(argname="argument expressions", value=expressions, expected_type=typing.Tuple[type_hints["expressions"], ...]) # pyright: ignore [reportGeneralTypeIssues]
        return typing.cast("PolicyStatementWithActions", jsii.invoke(self, "allMatchingActions", [*expressions]))

    @jsii.member(jsii_name="allPermissionManagementActions")
    def all_permission_management_actions(self) -> "PolicyStatementWithActions":
        '''(experimental) Adds all actions with `access level <https://docs.aws.amazon.com/IAM/latest/UserGuide/access_policies_understand-policy-summary-access-level-summaries.html#access_policies_access-level>`_ PERMISSION MANAGEMENT to the statement.

        Permission to grant or modify resource permissions in the service.

        For example, most IAM and AWS Organizations actions, as well as actions like the Amazon S3 actions ``PutBucketPolicy`` and ``DeleteBucketPolicy`` have the Permissions management access level.

        :stability: experimental
        '''
        return typing.cast("PolicyStatementWithActions", jsii.invoke(self, "allPermissionManagementActions", []))

    @jsii.member(jsii_name="allReadActions")
    def all_read_actions(self) -> "PolicyStatementWithActions":
        '''(experimental) Adds all actions with `access level <https://docs.aws.amazon.com/IAM/latest/UserGuide/access_policies_understand-policy-summary-access-level-summaries.html#access_policies_access-level>`_ READ to the statement.

        Permission to read but not edit the contents and attributes of resources in the service.

        For example, the Amazon S3 actions ``GetObject`` and ``GetBucketLocation`` have the Read access level.

        :stability: experimental
        '''
        return typing.cast("PolicyStatementWithActions", jsii.invoke(self, "allReadActions", []))

    @jsii.member(jsii_name="allTaggingActions")
    def all_tagging_actions(self) -> "PolicyStatementWithActions":
        '''(experimental) Adds all actions with `access level <https://docs.aws.amazon.com/IAM/latest/UserGuide/access_policies_understand-policy-summary-access-level-summaries.html#access_policies_access-level>`_ TAGGING to the statement.

        Permission to perform actions that only change the state of resource tags.

        For example, the IAM actions ``TagRole`` and ``UntagRole`` have the Tagging access level because they allow only tagging or untagging a role. However, the ``CreateRole`` action allows tagging a role resource when you create that role. Because the action does not only add a tag, it has the Write access level.

        :stability: experimental
        '''
        return typing.cast("PolicyStatementWithActions", jsii.invoke(self, "allTaggingActions", []))

    @jsii.member(jsii_name="allWriteActions")
    def all_write_actions(self) -> "PolicyStatementWithActions":
        '''(experimental) Adds all actions with `access level <https://docs.aws.amazon.com/IAM/latest/UserGuide/access_policies_understand-policy-summary-access-level-summaries.html#access_policies_access-level>`_ WRITE to the statement.

        Permission to create, delete, or modify resources in the service.

        For example, the Amazon S3 actions ``CreateBucket``, ``DeleteBucket`` and ``PutObject`` have the Write access level.

        Write actions might also allow modifying a resource tag. However, an action that allows only changes to tags has the Tagging access level.

        :stability: experimental
        '''
        return typing.cast("PolicyStatementWithActions", jsii.invoke(self, "allWriteActions", []))

    @jsii.member(jsii_name="compact")
    def compact(self) -> "PolicyStatementWithActions":
        '''(experimental) Condense action list down to a list of patterns.

        Using this method can help to reduce the policy size.

        For example, all actions with access level ``list`` could be reduced to a small pattern ``List*``.

        :stability: experimental
        '''
        return typing.cast("PolicyStatementWithActions", jsii.invoke(self, "compact", []))

    @jsii.member(jsii_name="freeze")
    def freeze(self) -> _aws_cdk_aws_iam_ceddda9d.PolicyStatement:
        '''(experimental) Make the PolicyStatement immutable.

        After calling this, any of the ``addXxx()`` methods will throw an exception.

        Libraries that lazily generate statement bodies can override this method to
        fill the actual PolicyStatement fields. Be aware that this method may be called
        multiple times.

        :stability: experimental
        '''
        return typing.cast(_aws_cdk_aws_iam_ceddda9d.PolicyStatement, jsii.invoke(self, "freeze", []))

    @jsii.member(jsii_name="hasActions")
    def has_actions(self) -> builtins.bool:
        '''(experimental) Checks weather actions have been applied to the policy.

        :stability: experimental
        '''
        return typing.cast(builtins.bool, jsii.invoke(self, "hasActions", []))

    @jsii.member(jsii_name="notAction")
    def not_action(self) -> "PolicyStatementWithActions":
        '''(experimental) Switches the statement to use ```NotAction`` <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_notaction.html>`_.

        :stability: experimental
        '''
        return typing.cast("PolicyStatementWithActions", jsii.invoke(self, "notAction", []))

    @jsii.member(jsii_name="to")
    def to(self, action: builtins.str) -> "PolicyStatementWithActions":
        '''(experimental) Adds actions by name.

        Depending on the "mode", actions will be either added to the list of ```Actions`` <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_action.html>`_ or ```NotAction`` <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_notaction.html>`_.

        The mode can be switched by calling ``notAction()``.

        If the action does not contain a colon, the action will be prefixed with the service prefix of the class, e.g. ``ec2:``

        :param action: Actions that will be added to the statement.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b285e0c40b17308307de63582a74aa529a455e1abee436409cd8cf824a35cfdd)
            check_type(argname="argument action", value=action, expected_type=type_hints["action"])
        return typing.cast("PolicyStatementWithActions", jsii.invoke(self, "to", [action]))

    @jsii.member(jsii_name="toJSON")
    def to_json(self) -> typing.Any:
        '''(experimental) Injects actions into the statement.

        Only relevant for the main package. In CDK mode this only calls super.

        :stability: experimental
        '''
        return typing.cast(typing.Any, jsii.invoke(self, "toJSON", []))

    @jsii.member(jsii_name="toStatementJson")
    def to_statement_json(self) -> typing.Any:
        '''(experimental) JSON-ify the policy statement.

        Used when JSON.stringify() is called

        :stability: experimental
        '''
        return typing.cast(typing.Any, jsii.invoke(self, "toStatementJson", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2e49c83c92d9689b52d2f1c44053ab77a2a7c5db7494e866d4758bbd8954bb86)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="floydActions")
    def _floyd_actions(self) -> typing.List[builtins.str]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.List[builtins.str], jsii.get(self, "floydActions"))

    @_floyd_actions.setter
    def _floyd_actions(self, value: typing.List[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__deaf43b85fb80cc5908ce05c802c528383e9410b7d5b836be0bf73b3177014e4)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "floydActions", value)


class PolicyStatementWithResources(
    PolicyStatementWithActions,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.PolicyStatementWithResources",
):
    '''(experimental) Adds "resource" functionality to the Policy Statement.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="freeze")
    def freeze(self) -> _aws_cdk_aws_iam_ceddda9d.PolicyStatement:
        '''(experimental) Make the PolicyStatement immutable.

        After calling this, any of the ``addXxx()`` methods will throw an exception.

        Libraries that lazily generate statement bodies can override this method to
        fill the actual PolicyStatement fields. Be aware that this method may be called
        multiple times.

        :stability: experimental
        '''
        return typing.cast(_aws_cdk_aws_iam_ceddda9d.PolicyStatement, jsii.invoke(self, "freeze", []))

    @jsii.member(jsii_name="hasResources")
    def has_resources(self) -> builtins.bool:
        '''(experimental) Checks weather any resource was applied to the policy.

        :stability: experimental
        '''
        return typing.cast(builtins.bool, jsii.invoke(self, "hasResources", []))

    @jsii.member(jsii_name="notResource")
    def not_resource(self) -> "PolicyStatementWithResources":
        '''(experimental) Switches the statement to use ```NotResource`` <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_notresource.html>`_.

        :stability: experimental
        '''
        return typing.cast("PolicyStatementWithResources", jsii.invoke(self, "notResource", []))

    @jsii.member(jsii_name="on")
    def on(self, *arns: builtins.str) -> "PolicyStatementWithResources":
        '''(experimental) Limit statement to specified resources.

        To allow all resources, pass ``*``

        :param arns: -

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0d2a094e0565cff64c6bc666f411d297277df95721cab1ad6d9d3d3b3878ff1f)
            check_type(argname="argument arns", value=arns, expected_type=typing.Tuple[type_hints["arns"], ...]) # pyright: ignore [reportGeneralTypeIssues]
        return typing.cast("PolicyStatementWithResources", jsii.invoke(self, "on", [*arns]))

    @jsii.member(jsii_name="onAllResources")
    def on_all_resources(self) -> "PolicyStatementWithResources":
        '''(experimental) Add all resources (``*``) to the statement.

        This is the default behavior, unless the statement has principals.

        :stability: experimental
        '''
        return typing.cast("PolicyStatementWithResources", jsii.invoke(self, "onAllResources", []))

    @jsii.member(jsii_name="toJSON")
    def to_json(self) -> typing.Any:
        '''(experimental) Injects resources into the statement.

        Only relevant for the main package. In CDK mode this only calls super.

        :stability: experimental
        '''
        return typing.cast(typing.Any, jsii.invoke(self, "toJSON", []))

    @jsii.member(jsii_name="toStatementJson")
    def to_statement_json(self) -> typing.Any:
        '''(experimental) JSON-ify the policy statement.

        Used when JSON.stringify() is called

        :stability: experimental
        '''
        return typing.cast(typing.Any, jsii.invoke(self, "toStatementJson", []))

    @builtins.property
    @jsii.member(jsii_name="floydResources")
    def _floyd_resources(self) -> typing.List[builtins.str]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.List[builtins.str], jsii.get(self, "floydResources"))

    @_floyd_resources.setter
    def _floyd_resources(self, value: typing.List[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a7b6f6b41926dae8edb1e42a14801d7dfd79995f20e0390d82ad0d37ca96a4ee)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "floydResources", value)

    @builtins.property
    @jsii.member(jsii_name="skipAutoResource")
    def _skip_auto_resource(self) -> builtins.bool:
        '''
        :stability: experimental
        '''
        return typing.cast(builtins.bool, jsii.get(self, "skipAutoResource"))

    @_skip_auto_resource.setter
    def _skip_auto_resource(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3aa2cab3468e7acbf0579765ddbb7e70f0c36ee6ac053982c0c5471e125d7cc8)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "skipAutoResource", value)


class PolicyStatementWithEffect(
    PolicyStatementWithResources,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.PolicyStatementWithEffect",
):
    '''(experimental) Adds "effect" functionality to the Policy Statement.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="allow")
    def allow(self) -> "PolicyStatementWithEffect":
        '''(experimental) Allow the actions in this statement.

        :stability: experimental
        '''
        return typing.cast("PolicyStatementWithEffect", jsii.invoke(self, "allow", []))

    @jsii.member(jsii_name="deny")
    def deny(self) -> "PolicyStatementWithEffect":
        '''(experimental) Deny the actions in this statement.

        :stability: experimental
        '''
        return typing.cast("PolicyStatementWithEffect", jsii.invoke(self, "deny", []))

    @jsii.member(jsii_name="toJSON")
    def to_json(self) -> typing.Any:
        '''(experimental) Injects effect into the statement.

        Only relevant for the main package. In CDK mode this only calls super.

        :stability: experimental
        '''
        return typing.cast(typing.Any, jsii.invoke(self, "toJSON", []))


class PolicyStatementWithPrincipal(
    PolicyStatementWithEffect,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.PolicyStatementWithPrincipal",
):
    '''(experimental) Adds "principal" functionality to the Policy Statement.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="addPrincipal")
    def _add_principal(
        self,
        prefix: builtins.str,
        principal: builtins.str,
    ) -> "PolicyStatementWithPrincipal":
        '''(experimental) Adds a principal to the statement.

        :param prefix: One of **AWS**, **Federated**, **CanonicalUser** or **Service**.
        :param principal: The principal string.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f07540633ebc00771025b4ccdaa1d1f2a71623c7328202ed91842e3d49650dd6)
            check_type(argname="argument prefix", value=prefix, expected_type=type_hints["prefix"])
            check_type(argname="argument principal", value=principal, expected_type=type_hints["principal"])
        return typing.cast("PolicyStatementWithPrincipal", jsii.invoke(self, "addPrincipal", [prefix, principal]))

    @jsii.member(jsii_name="cdkApplyPrincipals")
    def _cdk_apply_principals(self) -> None:
        '''
        :stability: experimental
        '''
        return typing.cast(None, jsii.invoke(self, "cdkApplyPrincipals", []))

    @jsii.member(jsii_name="for")
    def for_(
        self,
        arn: builtins.str,
        prefix: typing.Optional[builtins.str] = None,
    ) -> "PolicyStatementWithPrincipal":
        '''(experimental) Adds any principal to the statement.

        :param arn: The ARN of the principal.
        :param prefix: One of **AWS**, **Federated**, **CanonicalUser** or **Service** - Default: **AWS**.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2d34e335619e76f101d439fe9e03e55873ed39985dfc982abd84c2cb508dccf5)
            check_type(argname="argument arn", value=arn, expected_type=type_hints["arn"])
            check_type(argname="argument prefix", value=prefix, expected_type=type_hints["prefix"])
        return typing.cast("PolicyStatementWithPrincipal", jsii.invoke(self, "for", [arn, prefix]))

    @jsii.member(jsii_name="forAccount")
    def for_account(self, *accounts: builtins.str) -> "PolicyStatementWithPrincipal":
        '''(experimental) Adds one or more account principals to the statement.

        :param accounts: ID of the AWS account.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__45021adb9aba562bfefdec8af51014b59ad66b5d9d2ea65d5ad8e46359ff2cd3)
            check_type(argname="argument accounts", value=accounts, expected_type=typing.Tuple[type_hints["accounts"], ...]) # pyright: ignore [reportGeneralTypeIssues]
        return typing.cast("PolicyStatementWithPrincipal", jsii.invoke(self, "forAccount", [*accounts]))

    @jsii.member(jsii_name="forAssumedRoleSession")
    def for_assumed_role_session(
        self,
        account: builtins.str,
        role_name: builtins.str,
        *session_names: builtins.str,
    ) -> "PolicyStatementWithPrincipal":
        '''(experimental) Adds one or more specific assumed role session principals to the statement.

        :param account: ID of the AWS account.
        :param role_name: Name of the IAM role.
        :param session_names: Name of the session. You cannot use a wildcard (``*``) to mean *all sessions*. Principals must always name a specific session

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a35284fda156068cc6bc491abd471ea5fba7e5ca17e747622a5631b526d00c4f)
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument role_name", value=role_name, expected_type=type_hints["role_name"])
            check_type(argname="argument session_names", value=session_names, expected_type=typing.Tuple[type_hints["session_names"], ...]) # pyright: ignore [reportGeneralTypeIssues]
        return typing.cast("PolicyStatementWithPrincipal", jsii.invoke(self, "forAssumedRoleSession", [account, role_name, *session_names]))

    @jsii.member(jsii_name="forCanonicalUser")
    def for_canonical_user(
        self,
        *user_i_ds: builtins.str,
    ) -> "PolicyStatementWithPrincipal":
        '''(experimental) Adds one or more canonical user principals to the statement.

        :param user_i_ds: The user ID. You can `find the canonical user ID <https://docs.aws.amazon.com/general/latest/gr/acct-identifiers.html#FindingCanonicalId>`_ for your AWS account in the AWS Management Console. The canonical user ID for an AWS account is specific to the account. You can retrieve the canonical user ID for your AWS account as either the root user or an IAM user.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__940296438549c30700e0baa1596d21c76e9d72291ccd4f12d8a055f2ce91487b)
            check_type(argname="argument user_i_ds", value=user_i_ds, expected_type=typing.Tuple[type_hints["user_i_ds"], ...]) # pyright: ignore [reportGeneralTypeIssues]
        return typing.cast("PolicyStatementWithPrincipal", jsii.invoke(self, "forCanonicalUser", [*user_i_ds]))

    @jsii.member(jsii_name="forFederated")
    def for_federated(self, *providers: builtins.str) -> "PolicyStatementWithPrincipal":
        '''(experimental) Adds one or more `federated <https://aws.amazon.com/identity/federation/>`_ (web identity) principals to the statement.

        :param providers: ID of the AWS account.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__07ac586aa94a2f6759cc8628a4311b4ccaf53e4f2d761612edc82da58758ecb0)
            check_type(argname="argument providers", value=providers, expected_type=typing.Tuple[type_hints["providers"], ...]) # pyright: ignore [reportGeneralTypeIssues]
        return typing.cast("PolicyStatementWithPrincipal", jsii.invoke(self, "forFederated", [*providers]))

    @jsii.member(jsii_name="forFederatedAmazon")
    def for_federated_amazon(self) -> "PolicyStatementWithPrincipal":
        '''(experimental) Adds a federated `Amazon <https://login.amazon.com/>`_ principal to the statement.

        :stability: experimental
        '''
        return typing.cast("PolicyStatementWithPrincipal", jsii.invoke(self, "forFederatedAmazon", []))

    @jsii.member(jsii_name="forFederatedCognito")
    def for_federated_cognito(self) -> "PolicyStatementWithPrincipal":
        '''(experimental) Adds a federated `AWS Cognito <https://docs.aws.amazon.com/IAM/latest/UserGuide/id_roles_providers_oidc_cognito.html>`_ principal to the statement.

        :stability: experimental
        '''
        return typing.cast("PolicyStatementWithPrincipal", jsii.invoke(self, "forFederatedCognito", []))

    @jsii.member(jsii_name="forFederatedFacebook")
    def for_federated_facebook(self) -> "PolicyStatementWithPrincipal":
        '''(experimental) Adds a federated `Facebook <https://developers.facebook.com/docs/facebook-login>`_ principal to the statement.

        :stability: experimental
        '''
        return typing.cast("PolicyStatementWithPrincipal", jsii.invoke(self, "forFederatedFacebook", []))

    @jsii.member(jsii_name="forFederatedGoogle")
    def for_federated_google(self) -> "PolicyStatementWithPrincipal":
        '''(experimental) Adds a federated `Google <https://developers.google.com/identity/protocols/oauth2/openid-connect>`_ principal to the statement.

        :stability: experimental
        '''
        return typing.cast("PolicyStatementWithPrincipal", jsii.invoke(self, "forFederatedGoogle", []))

    @jsii.member(jsii_name="forPublic")
    def for_public(self) -> "PolicyStatementWithPrincipal":
        '''(experimental) Grants public asses.

        **EVERYONE IN THE WORLD HAS ACCESS**

        We strongly recommend that you do not use a wildcard in the Principal element in a role's trust policy unless you otherwise restrict access through a Condition element in the policy. Otherwise, any IAM user in any account in your partition can access the role.

        :stability: experimental
        '''
        return typing.cast("PolicyStatementWithPrincipal", jsii.invoke(self, "forPublic", []))

    @jsii.member(jsii_name="forRole")
    def for_role(
        self,
        account: builtins.str,
        *roles: builtins.str,
    ) -> "PolicyStatementWithPrincipal":
        '''(experimental) Adds one or more IAM role principals to the statement.

        :param account: ID of the AWS account.
        :param roles: Name of the IAM role.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a3af9f5cf3ca7932bf24eedcbaa45512468b6cbb659afa8ad3a1b1ff3123c191)
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument roles", value=roles, expected_type=typing.Tuple[type_hints["roles"], ...]) # pyright: ignore [reportGeneralTypeIssues]
        return typing.cast("PolicyStatementWithPrincipal", jsii.invoke(self, "forRole", [account, *roles]))

    @jsii.member(jsii_name="forSaml")
    def for_saml(
        self,
        account: builtins.str,
        *provider_names: builtins.str,
    ) -> "PolicyStatementWithPrincipal":
        '''(experimental) Adds one or more federated SAML principals to the statement.

        :param account: ID of the AWS account.
        :param provider_names: Name of the SAML provider.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2ab734231ff0665034afd1112a3d4873c6a222b9be4f552b8fb3d1361546b4ad)
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument provider_names", value=provider_names, expected_type=typing.Tuple[type_hints["provider_names"], ...]) # pyright: ignore [reportGeneralTypeIssues]
        return typing.cast("PolicyStatementWithPrincipal", jsii.invoke(self, "forSaml", [account, *provider_names]))

    @jsii.member(jsii_name="forService")
    def for_service(self, *services: builtins.str) -> "PolicyStatementWithPrincipal":
        '''(experimental) Adds one or more service principals to the statement.

        :param services: Long version of the service name. Usually in the format: ``long_service-name.amazonaws.com``. The service principal is defined by the service. To learn the service principal for a service, see the documentation for that service. For some services, see `AWS Services That Work with IAM <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_aws-services-that-work-with-iam.html>`_ and look for the services that have **Yes** in the **Service-Linked Role** column. Choose a **Yes** with a link to view the service-linked role documentation for that service. View the **Service-Linked Role Permissions** section for that service to view the service principal.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__46df73c4fb1b40827b40b23ef188546ea0f42ae4a945c4aa12b5e2e62d854876)
            check_type(argname="argument services", value=services, expected_type=typing.Tuple[type_hints["services"], ...]) # pyright: ignore [reportGeneralTypeIssues]
        return typing.cast("PolicyStatementWithPrincipal", jsii.invoke(self, "forService", [*services]))

    @jsii.member(jsii_name="forUser")
    def for_user(
        self,
        account: builtins.str,
        *users: builtins.str,
    ) -> "PolicyStatementWithPrincipal":
        '''(experimental) Adds one or more IAM user principals to the statement.

        :param account: ID of the AWS account.
        :param users: Name of the IAM user.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b6ddff4cbd8aa1d1bd88c62e23b8671eda3733f0ce372dd3a758d8e88a62e169)
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument users", value=users, expected_type=typing.Tuple[type_hints["users"], ...]) # pyright: ignore [reportGeneralTypeIssues]
        return typing.cast("PolicyStatementWithPrincipal", jsii.invoke(self, "forUser", [account, *users]))

    @jsii.member(jsii_name="freeze")
    def freeze(self) -> _aws_cdk_aws_iam_ceddda9d.PolicyStatement:
        '''(experimental) Make the PolicyStatement immutable.

        After calling this, any of the ``addXxx()`` methods will throw an exception.

        Libraries that lazily generate statement bodies can override this method to
        fill the actual PolicyStatement fields. Be aware that this method may be called
        multiple times.

        :stability: experimental
        '''
        return typing.cast(_aws_cdk_aws_iam_ceddda9d.PolicyStatement, jsii.invoke(self, "freeze", []))

    @jsii.member(jsii_name="hasPrincipals")
    def has_principals(self) -> builtins.bool:
        '''(experimental) Checks weather a principal was applied to the policy.

        :stability: experimental
        '''
        return typing.cast(builtins.bool, jsii.invoke(self, "hasPrincipals", []))

    @jsii.member(jsii_name="notPrincipal")
    def not_principal(self) -> "PolicyStatementWithPrincipal":
        '''(experimental) Switches the statement to use ```notPrincipal`` <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_notprincipal.html>`_.

        :stability: experimental
        '''
        return typing.cast("PolicyStatementWithPrincipal", jsii.invoke(self, "notPrincipal", []))

    @jsii.member(jsii_name="toJSON")
    def to_json(self) -> typing.Any:
        '''(experimental) Injects principals into the statement.

        Only relevant for the main package. In CDK mode this only calls super.

        :stability: experimental
        '''
        return typing.cast(typing.Any, jsii.invoke(self, "toJSON", []))

    @jsii.member(jsii_name="toStatementJson")
    def to_statement_json(self) -> typing.Any:
        '''(experimental) JSON-ify the policy statement.

        Used when JSON.stringify() is called

        :stability: experimental
        '''
        return typing.cast(typing.Any, jsii.invoke(self, "toStatementJson", []))

    @builtins.property
    @jsii.member(jsii_name="myPrincipals")
    def _my_principals(self) -> Principals:
        '''
        :stability: experimental
        '''
        return typing.cast(Principals, jsii.get(self, "myPrincipals"))

    @_my_principals.setter
    def _my_principals(self, value: Principals) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__58c30ebc2e9971817b228909d84ebb56798115985acb807e216605b8c4951a6c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "myPrincipals", value)

    @builtins.property
    @jsii.member(jsii_name="useNotPrincipal")
    def _use_not_principal(self) -> builtins.bool:
        '''
        :stability: experimental
        '''
        return typing.cast(builtins.bool, jsii.get(self, "useNotPrincipal"))

    @_use_not_principal.setter
    def _use_not_principal(self, value: builtins.bool) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__648b2dfe516763983ec490a8d19d34a236e6606570ad2647f35ae64bd40bc2e8)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "useNotPrincipal", value)


class PolicyStatementWithCDKPrincipal(
    PolicyStatementWithPrincipal,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.PolicyStatementWithCDKPrincipal",
):
    '''(experimental) Adds CDK specific "principal" functionality to the Policy Statement.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="cdkApplyPrincipals")
    def _cdk_apply_principals(self) -> None:
        '''
        :stability: experimental
        '''
        return typing.cast(None, jsii.invoke(self, "cdkApplyPrincipals", []))

    @jsii.member(jsii_name="forCdkPrincipal")
    def for_cdk_principal(
        self,
        *principals: _aws_cdk_aws_iam_ceddda9d.IPrincipal,
    ) -> "PolicyStatementWithCDKPrincipal":
        '''(experimental) Adds any number of CDK principals to the statement.

        :param principals: Principals to add to the statement.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__90f4f9111d9a2e9f78495bd2be4f9ac3204df45cb40f6eb6d821a21162ee0483)
            check_type(argname="argument principals", value=principals, expected_type=typing.Tuple[type_hints["principals"], ...]) # pyright: ignore [reportGeneralTypeIssues]
        return typing.cast("PolicyStatementWithCDKPrincipal", jsii.invoke(self, "forCdkPrincipal", [*principals]))

    @builtins.property
    @jsii.member(jsii_name="cdkPrincipals")
    def _cdk_principals(self) -> typing.List[_aws_cdk_aws_iam_ceddda9d.IPrincipal]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.List[_aws_cdk_aws_iam_ceddda9d.IPrincipal], jsii.get(self, "cdkPrincipals"))

    @_cdk_principals.setter
    def _cdk_principals(
        self,
        value: typing.List[_aws_cdk_aws_iam_ceddda9d.IPrincipal],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3b0d59f37f904814af1adedf568162488cb245bdf6b646df1f95bb25074366c8)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "cdkPrincipals", value)


class PolicyStatement(
    PolicyStatementWithCDKPrincipal,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.PolicyStatement",
):
    '''(experimental) Represents a statement in an IAM policy document.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])


class Polly(PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Polly"):
    '''(experimental) Statement provider for service `polly <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonpolly.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `polly <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonpolly.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onLexicon")
    def on_lexicon(
        self,
        lexicon_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Polly":
        '''(experimental) Adds a resource of type lexicon to the statement.

        https://docs.aws.amazon.com/polly/latest/dg/managing-lexicons.html

        :param lexicon_name: - Identifier for the lexiconName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2b0819564f88353b107e8e38ff4a9097def3907ac2b649507cad8e7ad2b0ec53)
            check_type(argname="argument lexicon_name", value=lexicon_name, expected_type=type_hints["lexicon_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Polly", jsii.invoke(self, "onLexicon", [lexicon_name, account, region, partition]))

    @jsii.member(jsii_name="toDeleteLexicon")
    def to_delete_lexicon(self) -> "Polly":
        '''(experimental) Grants permissions to delete the specified pronunciation lexicon stored in an AWS Region.

        Access Level: Write

        https://docs.aws.amazon.com/polly/latest/dg/API_DeleteLexicon.html

        :stability: experimental
        '''
        return typing.cast("Polly", jsii.invoke(self, "toDeleteLexicon", []))

    @jsii.member(jsii_name="toDescribeVoices")
    def to_describe_voices(self) -> "Polly":
        '''(experimental) Grants permissions to describe the list of voices that are available for use when requesting speech synthesis.

        Access Level: List

        https://docs.aws.amazon.com/polly/latest/dg/API_DescribeVoices.html

        :stability: experimental
        '''
        return typing.cast("Polly", jsii.invoke(self, "toDescribeVoices", []))

    @jsii.member(jsii_name="toGetLexicon")
    def to_get_lexicon(self) -> "Polly":
        '''(experimental) Grants permissions to retrieve the content of the specified pronunciation lexicon stored in an AWS Region.

        Access Level: Read

        https://docs.aws.amazon.com/polly/latest/dg/API_GetLexicon.html

        :stability: experimental
        '''
        return typing.cast("Polly", jsii.invoke(self, "toGetLexicon", []))

    @jsii.member(jsii_name="toGetSpeechSynthesisTask")
    def to_get_speech_synthesis_task(self) -> "Polly":
        '''(experimental) Grants permissions to get information about specific speech synthesis task.

        Access Level: Read

        https://docs.aws.amazon.com/polly/latest/dg/API_GetSpeechSynthesisTask.html

        :stability: experimental
        '''
        return typing.cast("Polly", jsii.invoke(self, "toGetSpeechSynthesisTask", []))

    @jsii.member(jsii_name="toListLexicons")
    def to_list_lexicons(self) -> "Polly":
        '''(experimental) Grants permisions to list the pronunciation lexicons stored in an AWS Region.

        Access Level: List

        https://docs.aws.amazon.com/polly/latest/dg/API_ListLexicons.html

        :stability: experimental
        '''
        return typing.cast("Polly", jsii.invoke(self, "toListLexicons", []))

    @jsii.member(jsii_name="toListSpeechSynthesisTasks")
    def to_list_speech_synthesis_tasks(self) -> "Polly":
        '''(experimental) Grants permissions to list requested speech synthesis tasks.

        Access Level: List

        https://docs.aws.amazon.com/polly/latest/dg/API_ListSpeechSynthesisTasks.html

        :stability: experimental
        '''
        return typing.cast("Polly", jsii.invoke(self, "toListSpeechSynthesisTasks", []))

    @jsii.member(jsii_name="toPutLexicon")
    def to_put_lexicon(self) -> "Polly":
        '''(experimental) Grants permissions to store a pronunciation lexicon in an AWS Region.

        Access Level: Write

        https://docs.aws.amazon.com/polly/latest/dg/API_PutLexicon.html

        :stability: experimental
        '''
        return typing.cast("Polly", jsii.invoke(self, "toPutLexicon", []))

    @jsii.member(jsii_name="toStartSpeechSynthesisTask")
    def to_start_speech_synthesis_task(self) -> "Polly":
        '''(experimental) Grants permissions to synthesize long inputs to the provided S3 location.

        Access Level: Write

        Dependent actions:

        - s3:PutObject

        https://docs.aws.amazon.com/polly/latest/dg/API_StartSpeechSynthesisTask.html

        :stability: experimental
        '''
        return typing.cast("Polly", jsii.invoke(self, "toStartSpeechSynthesisTask", []))

    @jsii.member(jsii_name="toSynthesizeSpeech")
    def to_synthesize_speech(self) -> "Polly":
        '''(experimental) Grants permissions to synthesize speech.

        Access Level: Read

        https://docs.aws.amazon.com/polly/latest/dg/API_SynthesizeSpeech.html

        :stability: experimental
        '''
        return typing.cast("Polly", jsii.invoke(self, "toSynthesizeSpeech", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9b0754818c413e5991f91abbf5876f668bdda0fe78a3434ab79005824dd1c322)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8ebc8e7db5b232faa2f9578339525878a162cb37e687d6bd67813c55cc827bb8)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Pricing(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Pricing",
):
    '''(experimental) Statement provider for service `pricing <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awspricelist.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `pricing <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awspricelist.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="toDescribeServices")
    def to_describe_services(self) -> "Pricing":
        '''(experimental) Grants permission to retrieve service details for all (paginated) services (if serviceCode is not set) or service detail for a particular service (if given serviceCode).

        Access Level: Read

        https://docs.aws.amazon.com/aws-cost-management/latest/APIReference/API_pricing_DescribeServices.html

        :stability: experimental
        '''
        return typing.cast("Pricing", jsii.invoke(self, "toDescribeServices", []))

    @jsii.member(jsii_name="toGetAttributeValues")
    def to_get_attribute_values(self) -> "Pricing":
        '''(experimental) Grants permission to retrieve all (paginated) possible values for a given attribute.

        Access Level: Read

        https://docs.aws.amazon.com/aws-cost-management/latest/APIReference/API_pricing_GetAttributeValues.html

        :stability: experimental
        '''
        return typing.cast("Pricing", jsii.invoke(self, "toGetAttributeValues", []))

    @jsii.member(jsii_name="toGetProducts")
    def to_get_products(self) -> "Pricing":
        '''(experimental) Grants permission to retrieve all matching products with given search criteria.

        Access Level: Read

        https://docs.aws.amazon.com/aws-cost-management/latest/APIReference/API_pricing_GetProducts.html

        :stability: experimental
        '''
        return typing.cast("Pricing", jsii.invoke(self, "toGetProducts", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__579219d1f1d7d3c04df3616f51b8a737dd785e2d387227384042694192969225)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1b8d8acc144f5df3506445322472a5b983c289e3c8fc01a6252ac76866b16c3e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class PrivateNetworks(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.PrivateNetworks",
):
    '''(experimental) Statement provider for service `private-networks <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsserviceprovidingmanagedprivatenetworks.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `private-networks <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsserviceprovidingmanagedprivatenetworks.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onDeviceIdentifier")
    def on_device_identifier(
        self,
        network_name: builtins.str,
        device_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "PrivateNetworks":
        '''(experimental) Adds a resource of type device-identifier to the statement.

        https://docs.aws.amazon.com/private-networks/latest/userguide/identity-access-management.html

        :param network_name: - Identifier for the networkName.
        :param device_id: - Identifier for the deviceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c78495541eba8ce3f162863520d8556ea6297727ed59a9165602e310e6f3996d)
            check_type(argname="argument network_name", value=network_name, expected_type=type_hints["network_name"])
            check_type(argname="argument device_id", value=device_id, expected_type=type_hints["device_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("PrivateNetworks", jsii.invoke(self, "onDeviceIdentifier", [network_name, device_id, account, region, partition]))

    @jsii.member(jsii_name="onNetwork")
    def on_network(
        self,
        network_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "PrivateNetworks":
        '''(experimental) Adds a resource of type network to the statement.

        https://docs.aws.amazon.com/private-networks/latest/userguide/identity-access-management.html

        :param network_name: - Identifier for the networkName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b8988d6e372bf98d5f59f13149c9d73f7c2a1f378c25780175d7a2ac11c557e6)
            check_type(argname="argument network_name", value=network_name, expected_type=type_hints["network_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("PrivateNetworks", jsii.invoke(self, "onNetwork", [network_name, account, region, partition]))

    @jsii.member(jsii_name="onNetworkResource")
    def on_network_resource(
        self,
        network_name: builtins.str,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "PrivateNetworks":
        '''(experimental) Adds a resource of type network-resource to the statement.

        https://docs.aws.amazon.com/private-networks/latest/userguide/identity-access-management.html

        :param network_name: - Identifier for the networkName.
        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c601c443fde2b826ef47e6e42b92bf978ff4cc6b09e354731b177d3562afc1b8)
            check_type(argname="argument network_name", value=network_name, expected_type=type_hints["network_name"])
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("PrivateNetworks", jsii.invoke(self, "onNetworkResource", [network_name, resource_id, account, region, partition]))

    @jsii.member(jsii_name="onNetworkSite")
    def on_network_site(
        self,
        network_name: builtins.str,
        network_site_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "PrivateNetworks":
        '''(experimental) Adds a resource of type network-site to the statement.

        https://docs.aws.amazon.com/private-networks/latest/userguide/identity-access-management.html

        :param network_name: - Identifier for the networkName.
        :param network_site_name: - Identifier for the networkSiteName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bd74a71f107e2bdb9c47322903123b40009621685b5e5e9218eaa814f1c9f6c9)
            check_type(argname="argument network_name", value=network_name, expected_type=type_hints["network_name"])
            check_type(argname="argument network_site_name", value=network_site_name, expected_type=type_hints["network_site_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("PrivateNetworks", jsii.invoke(self, "onNetworkSite", [network_name, network_site_name, account, region, partition]))

    @jsii.member(jsii_name="onOrder")
    def on_order(
        self,
        network_name: builtins.str,
        order_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "PrivateNetworks":
        '''(experimental) Adds a resource of type order to the statement.

        https://docs.aws.amazon.com/private-networks/latest/userguide/identity-access-management.html

        :param network_name: - Identifier for the networkName.
        :param order_id: - Identifier for the orderId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__87f423fa11d621ef5e282c21fb22e43f063ed9f7450e1b0270299bdfceb11567)
            check_type(argname="argument network_name", value=network_name, expected_type=type_hints["network_name"])
            check_type(argname="argument order_id", value=order_id, expected_type=type_hints["order_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("PrivateNetworks", jsii.invoke(self, "onOrder", [network_name, order_id, account, region, partition]))

    @jsii.member(jsii_name="toAcknowledgeOrderReceipt")
    def to_acknowledge_order_receipt(self) -> "PrivateNetworks":
        '''(experimental) Grants permission to acknowledge that an order has been received.

        Access Level: Write

        https://docs.aws.amazon.com/private-networks/latest/APIReference/API_AcknowledgeOrderReceipt.html

        :stability: experimental
        '''
        return typing.cast("PrivateNetworks", jsii.invoke(self, "toAcknowledgeOrderReceipt", []))

    @jsii.member(jsii_name="toActivateDeviceIdentifier")
    def to_activate_device_identifier(self) -> "PrivateNetworks":
        '''(experimental) Grants permission to activate a device identifier.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/private-networks/latest/APIReference/API_ActivateDeviceIdentifier.html

        :stability: experimental
        '''
        return typing.cast("PrivateNetworks", jsii.invoke(self, "toActivateDeviceIdentifier", []))

    @jsii.member(jsii_name="toActivateNetworkSite")
    def to_activate_network_site(self) -> "PrivateNetworks":
        '''(experimental) Grants permission to activate a network site.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/private-networks/latest/APIReference/API_ActivateNetworkSite.html

        :stability: experimental
        '''
        return typing.cast("PrivateNetworks", jsii.invoke(self, "toActivateNetworkSite", []))

    @jsii.member(jsii_name="toConfigureAccessPoint")
    def to_configure_access_point(self) -> "PrivateNetworks":
        '''(experimental) Grants permission to configure an access point.

        Access Level: Write

        https://docs.aws.amazon.com/private-networks/latest/APIReference/API_ConfigureAccessPoint.html

        :stability: experimental
        '''
        return typing.cast("PrivateNetworks", jsii.invoke(self, "toConfigureAccessPoint", []))

    @jsii.member(jsii_name="toCreateNetwork")
    def to_create_network(self) -> "PrivateNetworks":
        '''(experimental) Grants permission to create a network.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/private-networks/latest/APIReference/API_CreateNetwork.html

        :stability: experimental
        '''
        return typing.cast("PrivateNetworks", jsii.invoke(self, "toCreateNetwork", []))

    @jsii.member(jsii_name="toCreateNetworkSite")
    def to_create_network_site(self) -> "PrivateNetworks":
        '''(experimental) Grants permission to create a network site.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/private-networks/latest/APIReference/API_CreateNetworkSite.html

        :stability: experimental
        '''
        return typing.cast("PrivateNetworks", jsii.invoke(self, "toCreateNetworkSite", []))

    @jsii.member(jsii_name="toDeactivateDeviceIdentifier")
    def to_deactivate_device_identifier(self) -> "PrivateNetworks":
        '''(experimental) Grants permission to deactivate a device identifier.

        Access Level: Write

        https://docs.aws.amazon.com/private-networks/latest/APIReference/API_DeactivateDeviceIdentifier.html

        :stability: experimental
        '''
        return typing.cast("PrivateNetworks", jsii.invoke(self, "toDeactivateDeviceIdentifier", []))

    @jsii.member(jsii_name="toDeleteNetwork")
    def to_delete_network(self) -> "PrivateNetworks":
        '''(experimental) Grants permission to delete a network.

        Access Level: Write

        https://docs.aws.amazon.com/private-networks/latest/APIReference/API_DeleteNetwork.html

        :stability: experimental
        '''
        return typing.cast("PrivateNetworks", jsii.invoke(self, "toDeleteNetwork", []))

    @jsii.member(jsii_name="toDeleteNetworkSite")
    def to_delete_network_site(self) -> "PrivateNetworks":
        '''(experimental) Grants permission to delete a network site.

        Access Level: Write

        https://docs.aws.amazon.com/private-networks/latest/APIReference/API_DeleteNetworkSite.html

        :stability: experimental
        '''
        return typing.cast("PrivateNetworks", jsii.invoke(self, "toDeleteNetworkSite", []))

    @jsii.member(jsii_name="toGetDeviceIdentifier")
    def to_get_device_identifier(self) -> "PrivateNetworks":
        '''(experimental) Grants permission to get a device identifier.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/private-networks/latest/APIReference/API_GetDeviceIdentifier.html

        :stability: experimental
        '''
        return typing.cast("PrivateNetworks", jsii.invoke(self, "toGetDeviceIdentifier", []))

    @jsii.member(jsii_name="toGetNetwork")
    def to_get_network(self) -> "PrivateNetworks":
        '''(experimental) Grants permission to get a network.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/private-networks/latest/APIReference/API_GetNetwork.html

        :stability: experimental
        '''
        return typing.cast("PrivateNetworks", jsii.invoke(self, "toGetNetwork", []))

    @jsii.member(jsii_name="toGetNetworkResource")
    def to_get_network_resource(self) -> "PrivateNetworks":
        '''(experimental) Grants permission to get a network resource.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/private-networks/latest/APIReference/API_GetNetworkResource.html

        :stability: experimental
        '''
        return typing.cast("PrivateNetworks", jsii.invoke(self, "toGetNetworkResource", []))

    @jsii.member(jsii_name="toGetNetworkSite")
    def to_get_network_site(self) -> "PrivateNetworks":
        '''(experimental) Grants permission to get a network site.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/private-networks/latest/APIReference/API_GetNetworkSite.html

        :stability: experimental
        '''
        return typing.cast("PrivateNetworks", jsii.invoke(self, "toGetNetworkSite", []))

    @jsii.member(jsii_name="toGetOrder")
    def to_get_order(self) -> "PrivateNetworks":
        '''(experimental) Grants permission to get a network order.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/private-networks/latest/APIReference/API_GetOrder.html

        :stability: experimental
        '''
        return typing.cast("PrivateNetworks", jsii.invoke(self, "toGetOrder", []))

    @jsii.member(jsii_name="toListDeviceIdentifiers")
    def to_list_device_identifiers(self) -> "PrivateNetworks":
        '''(experimental) Grants permission to list device identifiers.

        Access Level: List

        https://docs.aws.amazon.com/private-networks/latest/APIReference/API_ListDeviceIdentifiers.html

        :stability: experimental
        '''
        return typing.cast("PrivateNetworks", jsii.invoke(self, "toListDeviceIdentifiers", []))

    @jsii.member(jsii_name="toListNetworkResources")
    def to_list_network_resources(self) -> "PrivateNetworks":
        '''(experimental) Grants permission to list network resources.

        Access Level: List

        https://docs.aws.amazon.com/private-networks/latest/APIReference/API_ListNetworkResources.html

        :stability: experimental
        '''
        return typing.cast("PrivateNetworks", jsii.invoke(self, "toListNetworkResources", []))

    @jsii.member(jsii_name="toListNetworks")
    def to_list_networks(self) -> "PrivateNetworks":
        '''(experimental) Grants permission to list networks.

        Access Level: List

        https://docs.aws.amazon.com/private-networks/latest/APIReference/API_ListNetworks.html

        :stability: experimental
        '''
        return typing.cast("PrivateNetworks", jsii.invoke(self, "toListNetworks", []))

    @jsii.member(jsii_name="toListNetworkSites")
    def to_list_network_sites(self) -> "PrivateNetworks":
        '''(experimental) Grants permission to list network sites.

        Access Level: List

        https://docs.aws.amazon.com/private-networks/latest/APIReference/API_ListNetworkSites.html

        :stability: experimental
        '''
        return typing.cast("PrivateNetworks", jsii.invoke(self, "toListNetworkSites", []))

    @jsii.member(jsii_name="toListOrders")
    def to_list_orders(self) -> "PrivateNetworks":
        '''(experimental) Grants permission to list network orders.

        Access Level: List

        https://docs.aws.amazon.com/private-networks/latest/APIReference/API_ListOrders.html

        :stability: experimental
        '''
        return typing.cast("PrivateNetworks", jsii.invoke(self, "toListOrders", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "PrivateNetworks":
        '''(experimental) Grants permission to return a list of tags for a resource.

        Access Level: List

        https://docs.aws.amazon.com/private-networks/latest/APIReference/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("PrivateNetworks", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toPing")
    def to_ping(self) -> "PrivateNetworks":
        '''(experimental) Grants permission to check the health of the service.

        Access Level: Read

        https://docs.aws.amazon.com/private-networks/latest/APIReference/API_Ping.html

        :stability: experimental
        '''
        return typing.cast("PrivateNetworks", jsii.invoke(self, "toPing", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "PrivateNetworks":
        '''(experimental) Grants permission to adds tags to the specified resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/private-networks/latest/APIReference/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("PrivateNetworks", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "PrivateNetworks":
        '''(experimental) Grants permission to removes tags from the specified resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/private-networks/latest/APIReference/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("PrivateNetworks", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateNetworkSite")
    def to_update_network_site(self) -> "PrivateNetworks":
        '''(experimental) Grants permission to update a network site.

        Access Level: Write

        https://docs.aws.amazon.com/private-networks/latest/APIReference/API_UpdateNetworkSite.html

        :stability: experimental
        '''
        return typing.cast("PrivateNetworks", jsii.invoke(self, "toUpdateNetworkSite", []))

    @jsii.member(jsii_name="toUpdateNetworkSitePlan")
    def to_update_network_site_plan(self) -> "PrivateNetworks":
        '''(experimental) Grants permission to update a plan at a network site.

        Access Level: Write

        https://docs.aws.amazon.com/private-networks/latest/APIReference/API_UpdateNetworkSitePlan.html

        :stability: experimental
        '''
        return typing.cast("PrivateNetworks", jsii.invoke(self, "toUpdateNetworkSitePlan", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c2d0cf42c184a7600601eb968b7bef294c9c217f4a73e70c4c39ee21679a38f1)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3db20039c24b1fca0e617652c99a59363725ec80f33c416d68061f47a77e2e30)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Profile(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Profile",
):
    '''(experimental) Statement provider for service `profile <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonconnectcustomerprofiles.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `profile <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonconnectcustomerprofiles.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onDomains")
    def on_domains(
        self,
        domain_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Profile":
        '''(experimental) Adds a resource of type domains to the statement.

        https://docs.aws.amazon.com/customerprofiles/latest/APIReference/

        :param domain_name: - Identifier for the domainName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a2b1f199d6547ed3dafa4f7705c841822ccec77c8adb17fc93e8295e4e0ead02)
            check_type(argname="argument domain_name", value=domain_name, expected_type=type_hints["domain_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Profile", jsii.invoke(self, "onDomains", [domain_name, account, region, partition]))

    @jsii.member(jsii_name="onIntegrations")
    def on_integrations(
        self,
        domain_name: builtins.str,
        uri: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Profile":
        '''(experimental) Adds a resource of type integrations to the statement.

        https://docs.aws.amazon.com/customerprofiles/latest/APIReference/

        :param domain_name: - Identifier for the domainName.
        :param uri: - Identifier for the uri.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1913581cf99ed8d12e80c4fba16ba6e642a456e3601b0b5d1d2669e62091cf2a)
            check_type(argname="argument domain_name", value=domain_name, expected_type=type_hints["domain_name"])
            check_type(argname="argument uri", value=uri, expected_type=type_hints["uri"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Profile", jsii.invoke(self, "onIntegrations", [domain_name, uri, account, region, partition]))

    @jsii.member(jsii_name="onObjectTypes")
    def on_object_types(
        self,
        domain_name: builtins.str,
        object_type_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Profile":
        '''(experimental) Adds a resource of type object-types to the statement.

        https://docs.aws.amazon.com/customerprofiles/latest/APIReference/

        :param domain_name: - Identifier for the domainName.
        :param object_type_name: - Identifier for the objectTypeName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6df7788c5fe51db7a446c135e4d724112636a7017669bd996e3e6f493d1deb7f)
            check_type(argname="argument domain_name", value=domain_name, expected_type=type_hints["domain_name"])
            check_type(argname="argument object_type_name", value=object_type_name, expected_type=type_hints["object_type_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Profile", jsii.invoke(self, "onObjectTypes", [domain_name, object_type_name, account, region, partition]))

    @jsii.member(jsii_name="toAddProfileKey")
    def to_add_profile_key(self) -> "Profile":
        '''(experimental) Grants permission to add a profile key.

        Access Level: Write

        https://docs.aws.amazon.com/customerprofiles/latest/APIReference/API_AddProfileKey.html

        :stability: experimental
        '''
        return typing.cast("Profile", jsii.invoke(self, "toAddProfileKey", []))

    @jsii.member(jsii_name="toCreateDomain")
    def to_create_domain(self) -> "Profile":
        '''(experimental) Grants permission to create a Domain.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/customerprofiles/latest/APIReference/API_CreateDomain.html

        :stability: experimental
        '''
        return typing.cast("Profile", jsii.invoke(self, "toCreateDomain", []))

    @jsii.member(jsii_name="toCreateIntegrationWorkflow")
    def to_create_integration_workflow(self) -> "Profile":
        '''(experimental) Grants permission to create an integration workflow in a domain.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/customerprofiles/latest/APIReference/API_CreateIntegrationWorkflow.html

        :stability: experimental
        '''
        return typing.cast("Profile", jsii.invoke(self, "toCreateIntegrationWorkflow", []))

    @jsii.member(jsii_name="toCreateProfile")
    def to_create_profile(self) -> "Profile":
        '''(experimental) Grants permission to create a profile in the domain.

        Access Level: Write

        https://docs.aws.amazon.com/customerprofiles/latest/APIReference/API_CreateProfile.html

        :stability: experimental
        '''
        return typing.cast("Profile", jsii.invoke(self, "toCreateProfile", []))

    @jsii.member(jsii_name="toDeleteDomain")
    def to_delete_domain(self) -> "Profile":
        '''(experimental) Grants permission to delete a Domain.

        Access Level: Write

        https://docs.aws.amazon.com/customerprofiles/latest/APIReference/API_DeleteDomain.html

        :stability: experimental
        '''
        return typing.cast("Profile", jsii.invoke(self, "toDeleteDomain", []))

    @jsii.member(jsii_name="toDeleteIntegration")
    def to_delete_integration(self) -> "Profile":
        '''(experimental) Grants permission to delete a integration in a domain.

        Access Level: Write

        https://docs.aws.amazon.com/customerprofiles/latest/APIReference/API_DeleteIntegration.html

        :stability: experimental
        '''
        return typing.cast("Profile", jsii.invoke(self, "toDeleteIntegration", []))

    @jsii.member(jsii_name="toDeleteProfile")
    def to_delete_profile(self) -> "Profile":
        '''(experimental) Grants permission to delete a profile.

        Access Level: Write

        https://docs.aws.amazon.com/customerprofiles/latest/APIReference/API_DeleteProfile.html

        :stability: experimental
        '''
        return typing.cast("Profile", jsii.invoke(self, "toDeleteProfile", []))

    @jsii.member(jsii_name="toDeleteProfileKey")
    def to_delete_profile_key(self) -> "Profile":
        '''(experimental) Grants permission to delete a profile key.

        Access Level: Write

        https://docs.aws.amazon.com/customerprofiles/latest/APIReference/API_DeleteProfileKey.html

        :stability: experimental
        '''
        return typing.cast("Profile", jsii.invoke(self, "toDeleteProfileKey", []))

    @jsii.member(jsii_name="toDeleteProfileObject")
    def to_delete_profile_object(self) -> "Profile":
        '''(experimental) Grants permission to delete a profile object.

        Access Level: Write

        https://docs.aws.amazon.com/customerprofiles/latest/APIReference/API_DeleteProfileObject.html

        :stability: experimental
        '''
        return typing.cast("Profile", jsii.invoke(self, "toDeleteProfileObject", []))

    @jsii.member(jsii_name="toDeleteProfileObjectType")
    def to_delete_profile_object_type(self) -> "Profile":
        '''(experimental) Grants permission to delete a specific profile object type in the domain.

        Access Level: Write

        https://docs.aws.amazon.com/customerprofiles/latest/APIReference/API_DeleteProfileObjectType.html

        :stability: experimental
        '''
        return typing.cast("Profile", jsii.invoke(self, "toDeleteProfileObjectType", []))

    @jsii.member(jsii_name="toDeleteWorkflow")
    def to_delete_workflow(self) -> "Profile":
        '''(experimental) Grants permission to delete a workflow in a domain.

        Access Level: Write

        https://docs.aws.amazon.com/customerprofiles/latest/APIReference/API_DeleteWorkflow.html

        :stability: experimental
        '''
        return typing.cast("Profile", jsii.invoke(self, "toDeleteWorkflow", []))

    @jsii.member(jsii_name="toGetAutoMergingPreview")
    def to_get_auto_merging_preview(self) -> "Profile":
        '''(experimental) Grants permission to get a preview of auto merging in a domain.

        Access Level: Read

        https://docs.aws.amazon.com/customerprofiles/latest/APIReference/API_GetAutoMergingPreview.html

        :stability: experimental
        '''
        return typing.cast("Profile", jsii.invoke(self, "toGetAutoMergingPreview", []))

    @jsii.member(jsii_name="toGetDomain")
    def to_get_domain(self) -> "Profile":
        '''(experimental) Grants permission to get a specific domain in an account.

        Access Level: Read

        https://docs.aws.amazon.com/customerprofiles/latest/APIReference/API_GetDomain.html

        :stability: experimental
        '''
        return typing.cast("Profile", jsii.invoke(self, "toGetDomain", []))

    @jsii.member(jsii_name="toGetIdentityResolutionJob")
    def to_get_identity_resolution_job(self) -> "Profile":
        '''(experimental) Grants permission to get an identity resolution job in a domain.

        Access Level: Read

        https://docs.aws.amazon.com/customerprofiles/latest/APIReference/API_GetIdentityResolutionJob.html

        :stability: experimental
        '''
        return typing.cast("Profile", jsii.invoke(self, "toGetIdentityResolutionJob", []))

    @jsii.member(jsii_name="toGetIntegration")
    def to_get_integration(self) -> "Profile":
        '''(experimental) Grants permission to get a specific integrations in a domain.

        Access Level: Read

        https://docs.aws.amazon.com/customerprofiles/latest/APIReference/API_GetIntegration.html

        :stability: experimental
        '''
        return typing.cast("Profile", jsii.invoke(self, "toGetIntegration", []))

    @jsii.member(jsii_name="toGetMatches")
    def to_get_matches(self) -> "Profile":
        '''(experimental) Grants permission to get profile matches in a domain.

        Access Level: List

        https://docs.aws.amazon.com/customerprofiles/latest/APIReference/API_GetMatches.html

        :stability: experimental
        '''
        return typing.cast("Profile", jsii.invoke(self, "toGetMatches", []))

    @jsii.member(jsii_name="toGetProfileObjectType")
    def to_get_profile_object_type(self) -> "Profile":
        '''(experimental) Grants permission to get a specific profile object type in the domain.

        Access Level: Read

        https://docs.aws.amazon.com/customerprofiles/latest/APIReference/API_GetProfileObjectType.html

        :stability: experimental
        '''
        return typing.cast("Profile", jsii.invoke(self, "toGetProfileObjectType", []))

    @jsii.member(jsii_name="toGetProfileObjectTypeTemplate")
    def to_get_profile_object_type_template(self) -> "Profile":
        '''(experimental) Grants permission to get a specific object type template.

        Access Level: Read

        https://docs.aws.amazon.com/customerprofiles/latest/APIReference/API_GetProfileObjectTypeTemplate.html

        :stability: experimental
        '''
        return typing.cast("Profile", jsii.invoke(self, "toGetProfileObjectTypeTemplate", []))

    @jsii.member(jsii_name="toGetWorkflow")
    def to_get_workflow(self) -> "Profile":
        '''(experimental) Grants permission to get workflow details in a domain.

        Access Level: Read

        https://docs.aws.amazon.com/customerprofiles/latest/APIReference/API_GetWorkflow.html

        :stability: experimental
        '''
        return typing.cast("Profile", jsii.invoke(self, "toGetWorkflow", []))

    @jsii.member(jsii_name="toGetWorkflowSteps")
    def to_get_workflow_steps(self) -> "Profile":
        '''(experimental) Grants permission to get workflow step details in a domain.

        Access Level: Read

        https://docs.aws.amazon.com/customerprofiles/latest/APIReference/API_GetWorkflowSteps.html

        :stability: experimental
        '''
        return typing.cast("Profile", jsii.invoke(self, "toGetWorkflowSteps", []))

    @jsii.member(jsii_name="toListAccountIntegrations")
    def to_list_account_integrations(self) -> "Profile":
        '''(experimental) Grants permission to list all the integrations in the account.

        Access Level: List

        https://docs.aws.amazon.com/customerprofiles/latest/APIReference/API_ListAccountIntegrations.html

        :stability: experimental
        '''
        return typing.cast("Profile", jsii.invoke(self, "toListAccountIntegrations", []))

    @jsii.member(jsii_name="toListDomains")
    def to_list_domains(self) -> "Profile":
        '''(experimental) Grants permission to list all the domains in an account.

        Access Level: List

        https://docs.aws.amazon.com/customerprofiles/latest/APIReference/API_ListDomains.html

        :stability: experimental
        '''
        return typing.cast("Profile", jsii.invoke(self, "toListDomains", []))

    @jsii.member(jsii_name="toListIdentityResolutionJobs")
    def to_list_identity_resolution_jobs(self) -> "Profile":
        '''(experimental) Grants permission to list identity resolution jobs in a domain.

        Access Level: List

        https://docs.aws.amazon.com/customerprofiles/latest/APIReference/API_ListIdentityResolutionJobs.html

        :stability: experimental
        '''
        return typing.cast("Profile", jsii.invoke(self, "toListIdentityResolutionJobs", []))

    @jsii.member(jsii_name="toListIntegrations")
    def to_list_integrations(self) -> "Profile":
        '''(experimental) Grants permission to list all the integrations in a specific domain.

        Access Level: List

        https://docs.aws.amazon.com/customerprofiles/latest/APIReference/API_ListIntegrations.html

        :stability: experimental
        '''
        return typing.cast("Profile", jsii.invoke(self, "toListIntegrations", []))

    @jsii.member(jsii_name="toListProfileObjects")
    def to_list_profile_objects(self) -> "Profile":
        '''(experimental) Grants permission to list all the profile objects for a profile.

        Access Level: List

        https://docs.aws.amazon.com/customerprofiles/latest/APIReference/API_ListProfileObjects.html

        :stability: experimental
        '''
        return typing.cast("Profile", jsii.invoke(self, "toListProfileObjects", []))

    @jsii.member(jsii_name="toListProfileObjectTypes")
    def to_list_profile_object_types(self) -> "Profile":
        '''(experimental) Grants permission to list all the profile object types in the domain.

        Access Level: List

        https://docs.aws.amazon.com/customerprofiles/latest/APIReference/API_ListProfileObjectTypes.html

        :stability: experimental
        '''
        return typing.cast("Profile", jsii.invoke(self, "toListProfileObjectTypes", []))

    @jsii.member(jsii_name="toListProfileObjectTypeTemplates")
    def to_list_profile_object_type_templates(self) -> "Profile":
        '''(experimental) Grants permission to list all the profile object type templates in the account.

        Access Level: List

        https://docs.aws.amazon.com/customerprofiles/latest/APIReference/API_ListProfileObjectTypeTemplates.html

        :stability: experimental
        '''
        return typing.cast("Profile", jsii.invoke(self, "toListProfileObjectTypeTemplates", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Profile":
        '''(experimental) Grants permission to list tags for a resource.

        Access Level: Read

        https://docs.aws.amazon.com/customerprofiles/latest/APIReference/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("Profile", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toListWorkflows")
    def to_list_workflows(self) -> "Profile":
        '''(experimental) Grants permission to list all the workflows in a specific domain.

        Access Level: List

        https://docs.aws.amazon.com/customerprofiles/latest/APIReference/API_ListWorkflows.html

        :stability: experimental
        '''
        return typing.cast("Profile", jsii.invoke(self, "toListWorkflows", []))

    @jsii.member(jsii_name="toMergeProfiles")
    def to_merge_profiles(self) -> "Profile":
        '''(experimental) Grants permission to merge profiles in a domain.

        Access Level: Write

        https://docs.aws.amazon.com/customerprofiles/latest/APIReference/API_MergeProfiles.html

        :stability: experimental
        '''
        return typing.cast("Profile", jsii.invoke(self, "toMergeProfiles", []))

    @jsii.member(jsii_name="toPutIntegration")
    def to_put_integration(self) -> "Profile":
        '''(experimental) Grants permission to put a integration in a domain.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/customerprofiles/latest/APIReference/API_PutIntegration.html

        :stability: experimental
        '''
        return typing.cast("Profile", jsii.invoke(self, "toPutIntegration", []))

    @jsii.member(jsii_name="toPutProfileObject")
    def to_put_profile_object(self) -> "Profile":
        '''(experimental) Grants permission to put an object for a profile.

        Access Level: Write

        https://docs.aws.amazon.com/customerprofiles/latest/APIReference/API_PutProfileObject.html

        :stability: experimental
        '''
        return typing.cast("Profile", jsii.invoke(self, "toPutProfileObject", []))

    @jsii.member(jsii_name="toPutProfileObjectType")
    def to_put_profile_object_type(self) -> "Profile":
        '''(experimental) Grants permission to put a specific profile object type in the domain.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/customerprofiles/latest/APIReference/API_PutProfileObjectType.html

        :stability: experimental
        '''
        return typing.cast("Profile", jsii.invoke(self, "toPutProfileObjectType", []))

    @jsii.member(jsii_name="toSearchProfiles")
    def to_search_profiles(self) -> "Profile":
        '''(experimental) Grants permission to search for profiles in a domain.

        Access Level: Read

        https://docs.aws.amazon.com/customerprofiles/latest/APIReference/API_SearchProfiles.html

        :stability: experimental
        '''
        return typing.cast("Profile", jsii.invoke(self, "toSearchProfiles", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Profile":
        '''(experimental) Grants permission to adds tags to a resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/customerprofiles/latest/APIReference/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("Profile", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Profile":
        '''(experimental) Grants permission to remove tags from a resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/customerprofiles/latest/APIReference/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("Profile", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateDomain")
    def to_update_domain(self) -> "Profile":
        '''(experimental) Grants permission to update a Domain.

        Access Level: Write

        https://docs.aws.amazon.com/customerprofiles/latest/APIReference/API_UpdateDomain.html

        :stability: experimental
        '''
        return typing.cast("Profile", jsii.invoke(self, "toUpdateDomain", []))

    @jsii.member(jsii_name="toUpdateProfile")
    def to_update_profile(self) -> "Profile":
        '''(experimental) Grants permission to update a profile in the domain.

        Access Level: Write

        https://docs.aws.amazon.com/customerprofiles/latest/APIReference/API_UpdateProfile.html

        :stability: experimental
        '''
        return typing.cast("Profile", jsii.invoke(self, "toUpdateProfile", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2dd1139bc8aad0fb1281254d9465dbc85c428d2c7b9dd8e5d7b47b4c0733ab22)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e0e8f7cded78b5fbc9a2dd172d00c9aeab9e06ba28a4d4846aab0148395a789f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Proton(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Proton",
):
    '''(experimental) Statement provider for service `proton <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsproton.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `proton <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsproton.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="ifEnvironmentTemplate")
    def if_environment_template(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Proton":
        '''(experimental) Filters access by specified environment template related to resource.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_condition-keys.html

        Applies to actions:

        - .toCancelEnvironmentDeployment()
        - .toCreateEnvironment()
        - .toDeleteEnvironment()
        - .toUpdateEnvironment()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2bc9285af8b9aa13d6fdf1c34fdf665b54005c730da65437334b7a1b843bd20e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Proton", jsii.invoke(self, "ifEnvironmentTemplate", [value, operator]))

    @jsii.member(jsii_name="ifServiceTemplate")
    def if_service_template(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Proton":
        '''(experimental) Filters access by specified service template related to resource.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_condition-keys.html

        Applies to actions:

        - .toCancelServiceInstanceDeployment()
        - .toCancelServicePipelineDeployment()
        - .toCreateService()
        - .toDeleteService()
        - .toUpdateService()
        - .toUpdateServiceInstance()
        - .toUpdateServicePipeline()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ea8a40ac549e481caf71d50c7fe20129aa38492f3340750665b44188e8003c94)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Proton", jsii.invoke(self, "ifServiceTemplate", [value, operator]))

    @jsii.member(jsii_name="onComponent")
    def on_component(
        self,
        id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Proton":
        '''(experimental) Adds a resource of type component to the statement.

        https://docs.aws.amazon.com/proton/latest/adminguide/ag-components.html

        :param id: - Identifier for the id.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ac48f004ce74c4e213acb5b8c1aa544f6dc1bc0b47ec33e4a45cc761f1329699)
            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Proton", jsii.invoke(self, "onComponent", [id, account, region, partition]))

    @jsii.member(jsii_name="onEnvironment")
    def on_environment(
        self,
        name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Proton":
        '''(experimental) Adds a resource of type environment to the statement.

        https://docs.aws.amazon.com/proton/latest/adminguide/ag-environments.html

        :param name: - Identifier for the name.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c747f08251a7fa27085e31386122e7934a07c09c714495732d1e0cf076f8d232)
            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Proton", jsii.invoke(self, "onEnvironment", [name, account, region, partition]))

    @jsii.member(jsii_name="onEnvironmentAccountConnection")
    def on_environment_account_connection(
        self,
        id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Proton":
        '''(experimental) Adds a resource of type environment-account-connection to the statement.

        https://docs.aws.amazon.com/proton/latest/adminguide/ag-env-account-connections.html

        :param id: - Identifier for the id.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__70a9b8ec9135fd0b5caca910079cad0e13419770b4bb0be274078fb0be575319)
            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Proton", jsii.invoke(self, "onEnvironmentAccountConnection", [id, account, region, partition]))

    @jsii.member(jsii_name="onEnvironmentTemplate")
    def on_environment_template(
        self,
        name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Proton":
        '''(experimental) Adds a resource of type environment-template to the statement.

        https://docs.aws.amazon.com/proton/latest/adminguide/ag-env-templates.html

        :param name: - Identifier for the name.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__dbd0c2b60e79fc1ca75d46486fdd12e2994b79ef7cc05748820b764db0637c83)
            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Proton", jsii.invoke(self, "onEnvironmentTemplate", [name, account, region, partition]))

    @jsii.member(jsii_name="onEnvironmentTemplateMajorVersion")
    def on_environment_template_major_version(
        self,
        template_name: builtins.str,
        major_version_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Proton":
        '''(experimental) Adds a resource of type environment-template-major-version to the statement.

        https://docs.aws.amazon.com/proton/latest/adminguide/ag-env-templates.html

        :param template_name: - Identifier for the templateName.
        :param major_version_id: - Identifier for the majorVersionId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6545ec5b0ee2859985a7c9469635b72041924871a04bcce4b782fc253b6ce27c)
            check_type(argname="argument template_name", value=template_name, expected_type=type_hints["template_name"])
            check_type(argname="argument major_version_id", value=major_version_id, expected_type=type_hints["major_version_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Proton", jsii.invoke(self, "onEnvironmentTemplateMajorVersion", [template_name, major_version_id, account, region, partition]))

    @jsii.member(jsii_name="onEnvironmentTemplateMinorVersion")
    def on_environment_template_minor_version(
        self,
        template_name: builtins.str,
        major_version_id: builtins.str,
        minor_version_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Proton":
        '''(experimental) Adds a resource of type environment-template-minor-version to the statement.

        https://docs.aws.amazon.com/proton/latest/adminguide/ag-env-templates.html

        :param template_name: - Identifier for the templateName.
        :param major_version_id: - Identifier for the majorVersionId.
        :param minor_version_id: - Identifier for the minorVersionId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__37d6a6285ef1c28c32c98c087d2c5caafd0459b60ca6d7b6ccf4dae2d55ddee4)
            check_type(argname="argument template_name", value=template_name, expected_type=type_hints["template_name"])
            check_type(argname="argument major_version_id", value=major_version_id, expected_type=type_hints["major_version_id"])
            check_type(argname="argument minor_version_id", value=minor_version_id, expected_type=type_hints["minor_version_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Proton", jsii.invoke(self, "onEnvironmentTemplateMinorVersion", [template_name, major_version_id, minor_version_id, account, region, partition]))

    @jsii.member(jsii_name="onEnvironmentTemplateVersion")
    def on_environment_template_version(
        self,
        template_name: builtins.str,
        major_version: builtins.str,
        minor_version: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Proton":
        '''(experimental) Adds a resource of type environment-template-version to the statement.

        https://docs.aws.amazon.com/proton/latest/adminguide/ag-env-templates.html

        :param template_name: - Identifier for the templateName.
        :param major_version: - Identifier for the majorVersion.
        :param minor_version: - Identifier for the minorVersion.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e73ce180fb6471ed013317b8402491634d48a378167b9ee45651ca6f340865da)
            check_type(argname="argument template_name", value=template_name, expected_type=type_hints["template_name"])
            check_type(argname="argument major_version", value=major_version, expected_type=type_hints["major_version"])
            check_type(argname="argument minor_version", value=minor_version, expected_type=type_hints["minor_version"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Proton", jsii.invoke(self, "onEnvironmentTemplateVersion", [template_name, major_version, minor_version, account, region, partition]))

    @jsii.member(jsii_name="onRepository")
    def on_repository(
        self,
        provider: builtins.str,
        name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Proton":
        '''(experimental) Adds a resource of type repository to the statement.

        https://docs.aws.amazon.com/proton/latest/adminguide/ag-repositories.html

        :param provider: - Identifier for the provider.
        :param name: - Identifier for the name.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2c7f37bbef0c789ca7218f6b5979db3c6151e853f853a076b35b7e2d433efa10)
            check_type(argname="argument provider", value=provider, expected_type=type_hints["provider"])
            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Proton", jsii.invoke(self, "onRepository", [provider, name, account, region, partition]))

    @jsii.member(jsii_name="onService")
    def on_service(
        self,
        name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Proton":
        '''(experimental) Adds a resource of type service to the statement.

        https://docs.aws.amazon.com/proton/latest/adminguide/ag-services.html

        :param name: - Identifier for the name.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f24eb7d5d6d9b2df44ca8f9e7fd7a837ad383c93e3019f3a344377deb41f6240)
            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Proton", jsii.invoke(self, "onService", [name, account, region, partition]))

    @jsii.member(jsii_name="onServiceInstance")
    def on_service_instance(
        self,
        service_name: builtins.str,
        name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Proton":
        '''(experimental) Adds a resource of type service-instance to the statement.

        https://docs.aws.amazon.com/proton/latest/adminguide/ag-services.html

        :param service_name: - Identifier for the serviceName.
        :param name: - Identifier for the name.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fe741a27570e60fb05460171f7696967e4925abbf3a29b46ef9b8a0b8dd80ab0)
            check_type(argname="argument service_name", value=service_name, expected_type=type_hints["service_name"])
            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Proton", jsii.invoke(self, "onServiceInstance", [service_name, name, account, region, partition]))

    @jsii.member(jsii_name="onServiceTemplate")
    def on_service_template(
        self,
        name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Proton":
        '''(experimental) Adds a resource of type service-template to the statement.

        https://docs.aws.amazon.com/proton/latest/adminguide/managing-svc-templates.html

        :param name: - Identifier for the name.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ffd69e8ba1e5acdbf19cd5ee4454845bb48c9fbdbab24c854019e5e8ada9a5c8)
            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Proton", jsii.invoke(self, "onServiceTemplate", [name, account, region, partition]))

    @jsii.member(jsii_name="onServiceTemplateMajorVersion")
    def on_service_template_major_version(
        self,
        template_name: builtins.str,
        major_version_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Proton":
        '''(experimental) Adds a resource of type service-template-major-version to the statement.

        https://docs.aws.amazon.com/proton/latest/adminguide/managing-svc-templates.html

        :param template_name: - Identifier for the templateName.
        :param major_version_id: - Identifier for the majorVersionId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__68e56a77582bf90c342b558e1f4bd7084abd407d41bf6289be5066daab3bcb7a)
            check_type(argname="argument template_name", value=template_name, expected_type=type_hints["template_name"])
            check_type(argname="argument major_version_id", value=major_version_id, expected_type=type_hints["major_version_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Proton", jsii.invoke(self, "onServiceTemplateMajorVersion", [template_name, major_version_id, account, region, partition]))

    @jsii.member(jsii_name="onServiceTemplateMinorVersion")
    def on_service_template_minor_version(
        self,
        template_name: builtins.str,
        major_version_id: builtins.str,
        minor_version_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Proton":
        '''(experimental) Adds a resource of type service-template-minor-version to the statement.

        https://docs.aws.amazon.com/proton/latest/adminguide/managing-svc-templates.html

        :param template_name: - Identifier for the templateName.
        :param major_version_id: - Identifier for the majorVersionId.
        :param minor_version_id: - Identifier for the minorVersionId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7645969471d50d60fade3029686d2f7475352b37b21faef8890d885614ffd691)
            check_type(argname="argument template_name", value=template_name, expected_type=type_hints["template_name"])
            check_type(argname="argument major_version_id", value=major_version_id, expected_type=type_hints["major_version_id"])
            check_type(argname="argument minor_version_id", value=minor_version_id, expected_type=type_hints["minor_version_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Proton", jsii.invoke(self, "onServiceTemplateMinorVersion", [template_name, major_version_id, minor_version_id, account, region, partition]))

    @jsii.member(jsii_name="onServiceTemplateVersion")
    def on_service_template_version(
        self,
        template_name: builtins.str,
        major_version: builtins.str,
        minor_version: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Proton":
        '''(experimental) Adds a resource of type service-template-version to the statement.

        https://docs.aws.amazon.com/proton/latest/adminguide/managing-svc-templates.html

        :param template_name: - Identifier for the templateName.
        :param major_version: - Identifier for the majorVersion.
        :param minor_version: - Identifier for the minorVersion.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__445ca55f3243cde309fee2aad41b5fcdae53b340c6cc0ed496667bfbca4b0925)
            check_type(argname="argument template_name", value=template_name, expected_type=type_hints["template_name"])
            check_type(argname="argument major_version", value=major_version, expected_type=type_hints["major_version"])
            check_type(argname="argument minor_version", value=minor_version, expected_type=type_hints["minor_version"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Proton", jsii.invoke(self, "onServiceTemplateVersion", [template_name, major_version, minor_version, account, region, partition]))

    @jsii.member(jsii_name="toAcceptEnvironmentAccountConnection")
    def to_accept_environment_account_connection(self) -> "Proton":
        '''(experimental) Grants permission to reject an environment account connection request from another environment account.

        Access Level: Write

        https://docs.aws.amazon.com/proton/latest/APIReference/API_AcceptEnvironmentAccountConnection.html

        :stability: experimental
        '''
        return typing.cast("Proton", jsii.invoke(self, "toAcceptEnvironmentAccountConnection", []))

    @jsii.member(jsii_name="toCancelComponentDeployment")
    def to_cancel_component_deployment(self) -> "Proton":
        '''(experimental) Grants permission to cancel component deployment.

        Access Level: Write

        https://docs.aws.amazon.com/proton/latest/APIReference/API_CancelComponentDeployment.html

        :stability: experimental
        '''
        return typing.cast("Proton", jsii.invoke(self, "toCancelComponentDeployment", []))

    @jsii.member(jsii_name="toCancelEnvironmentDeployment")
    def to_cancel_environment_deployment(self) -> "Proton":
        '''(experimental) Grants permission to cancel an environment deployment.

        Access Level: Write

        Possible conditions:

        - .ifEnvironmentTemplate()

        https://docs.aws.amazon.com/proton/latest/APIReference/API_CancelEnvironmentDeployment.html

        :stability: experimental
        '''
        return typing.cast("Proton", jsii.invoke(self, "toCancelEnvironmentDeployment", []))

    @jsii.member(jsii_name="toCancelServiceInstanceDeployment")
    def to_cancel_service_instance_deployment(self) -> "Proton":
        '''(experimental) Grants permission to cancel a service instance deployment.

        Access Level: Write

        Possible conditions:

        - .ifServiceTemplate()

        https://docs.aws.amazon.com/proton/latest/APIReference/API_CancelServiceInstanceDeployment.html

        :stability: experimental
        '''
        return typing.cast("Proton", jsii.invoke(self, "toCancelServiceInstanceDeployment", []))

    @jsii.member(jsii_name="toCancelServicePipelineDeployment")
    def to_cancel_service_pipeline_deployment(self) -> "Proton":
        '''(experimental) Grants permission to cancel a service pipeline deployment.

        Access Level: Write

        Possible conditions:

        - .ifServiceTemplate()

        https://docs.aws.amazon.com/proton/latest/APIReference/API_CancelServicePipelineDeployment.html

        :stability: experimental
        '''
        return typing.cast("Proton", jsii.invoke(self, "toCancelServicePipelineDeployment", []))

    @jsii.member(jsii_name="toCreateComponent")
    def to_create_component(self) -> "Proton":
        '''(experimental) Grants permission to create component.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/proton/latest/APIReference/API_CreateComponent.html

        :stability: experimental
        '''
        return typing.cast("Proton", jsii.invoke(self, "toCreateComponent", []))

    @jsii.member(jsii_name="toCreateEnvironment")
    def to_create_environment(self) -> "Proton":
        '''(experimental) Grants permission to create an environment.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()
        - .ifEnvironmentTemplate()

        Dependent actions:

        - iam:PassRole

        https://docs.aws.amazon.com/proton/latest/APIReference/API_CreateEnvironment.html

        :stability: experimental
        '''
        return typing.cast("Proton", jsii.invoke(self, "toCreateEnvironment", []))

    @jsii.member(jsii_name="toCreateEnvironmentAccountConnection")
    def to_create_environment_account_connection(self) -> "Proton":
        '''(experimental) Grants permission to create an environment account connection.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/proton/latest/APIReference/API_CreateEnvironmentAccountConnection.html

        :stability: experimental
        '''
        return typing.cast("Proton", jsii.invoke(self, "toCreateEnvironmentAccountConnection", []))

    @jsii.member(jsii_name="toCreateEnvironmentTemplate")
    def to_create_environment_template(self) -> "Proton":
        '''(experimental) Grants permission to create an environment template.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/proton/latest/APIReference/API_CreateEnvironmentTemplate.html

        :stability: experimental
        '''
        return typing.cast("Proton", jsii.invoke(self, "toCreateEnvironmentTemplate", []))

    @jsii.member(jsii_name="toCreateEnvironmentTemplateMajorVersion")
    def to_create_environment_template_major_version(self) -> "Proton":
        '''(experimental) Grants permission to create an environment template major version. DEPRECATED - use CreateEnvironmentTemplateVersion instead.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/proton/latest/APIReference/API_CreateEnvironmentTemplateMajorVersion.html

        :stability: experimental
        '''
        return typing.cast("Proton", jsii.invoke(self, "toCreateEnvironmentTemplateMajorVersion", []))

    @jsii.member(jsii_name="toCreateEnvironmentTemplateMinorVersion")
    def to_create_environment_template_minor_version(self) -> "Proton":
        '''(experimental) Grants permission to create an environment template minor version. DEPRECATED - use CreateEnvironmentTemplateVersion instead.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/proton/latest/APIReference/API_CreateEnvironmentTemplateMinorVersion.html

        :stability: experimental
        '''
        return typing.cast("Proton", jsii.invoke(self, "toCreateEnvironmentTemplateMinorVersion", []))

    @jsii.member(jsii_name="toCreateEnvironmentTemplateVersion")
    def to_create_environment_template_version(self) -> "Proton":
        '''(experimental) Grants permission to create an environment template version.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/proton/latest/APIReference/API_CreateEnvironmentTemplateVersion.html

        :stability: experimental
        '''
        return typing.cast("Proton", jsii.invoke(self, "toCreateEnvironmentTemplateVersion", []))

    @jsii.member(jsii_name="toCreateRepository")
    def to_create_repository(self) -> "Proton":
        '''(experimental) Grants permission to create a repository.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/proton/latest/APIReference/API_CreateRepository.html

        :stability: experimental
        '''
        return typing.cast("Proton", jsii.invoke(self, "toCreateRepository", []))

    @jsii.member(jsii_name="toCreateService")
    def to_create_service(self) -> "Proton":
        '''(experimental) Grants permission to create a service.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()
        - .ifServiceTemplate()

        Dependent actions:

        - codestar-connections:PassConnection

        https://docs.aws.amazon.com/proton/latest/APIReference/API_CreateService.html

        :stability: experimental
        '''
        return typing.cast("Proton", jsii.invoke(self, "toCreateService", []))

    @jsii.member(jsii_name="toCreateServiceTemplate")
    def to_create_service_template(self) -> "Proton":
        '''(experimental) Grants permission to create a service template.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/proton/latest/APIReference/API_CreateServiceTemplate.html

        :stability: experimental
        '''
        return typing.cast("Proton", jsii.invoke(self, "toCreateServiceTemplate", []))

    @jsii.member(jsii_name="toCreateServiceTemplateMajorVersion")
    def to_create_service_template_major_version(self) -> "Proton":
        '''(experimental) Grants permission to create a service template major version. DEPRECATED - use CreateServiceTemplateVersion instead.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/proton/latest/APIReference/API_CreateServiceTemplateMajorVersion.html

        :stability: experimental
        '''
        return typing.cast("Proton", jsii.invoke(self, "toCreateServiceTemplateMajorVersion", []))

    @jsii.member(jsii_name="toCreateServiceTemplateMinorVersion")
    def to_create_service_template_minor_version(self) -> "Proton":
        '''(experimental) Grants permission to create a service template minor version. DEPRECATED - use CreateServiceTemplateVersion instead.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/proton/latest/APIReference/API_CreateServiceTemplateMinorVersion.html

        :stability: experimental
        '''
        return typing.cast("Proton", jsii.invoke(self, "toCreateServiceTemplateMinorVersion", []))

    @jsii.member(jsii_name="toCreateServiceTemplateVersion")
    def to_create_service_template_version(self) -> "Proton":
        '''(experimental) Grants permission to create a service template version.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/proton/latest/APIReference/API_CreateServiceTemplateVersion.html

        :stability: experimental
        '''
        return typing.cast("Proton", jsii.invoke(self, "toCreateServiceTemplateVersion", []))

    @jsii.member(jsii_name="toCreateTemplateSyncConfig")
    def to_create_template_sync_config(self) -> "Proton":
        '''(experimental) Grants permission to create a template sync config.

        Access Level: Write

        https://docs.aws.amazon.com/proton/latest/APIReference/API_CreateTemplateSyncConfig.html

        :stability: experimental
        '''
        return typing.cast("Proton", jsii.invoke(self, "toCreateTemplateSyncConfig", []))

    @jsii.member(jsii_name="toDeleteAccountRoles")
    def to_delete_account_roles(self) -> "Proton":
        '''(experimental) Grants permission to delete account roles. DEPRECATED - use UpdateAccountSettings instead.

        Access Level: Write

        https://docs.aws.amazon.com/proton/latest/APIReference/API_DeleteAccountRoles.html

        :stability: experimental
        '''
        return typing.cast("Proton", jsii.invoke(self, "toDeleteAccountRoles", []))

    @jsii.member(jsii_name="toDeleteComponent")
    def to_delete_component(self) -> "Proton":
        '''(experimental) Grants permission to delete component.

        Access Level: Write

        https://docs.aws.amazon.com/proton/latest/APIReference/API_DeleteComponent.html

        :stability: experimental
        '''
        return typing.cast("Proton", jsii.invoke(self, "toDeleteComponent", []))

    @jsii.member(jsii_name="toDeleteEnvironment")
    def to_delete_environment(self) -> "Proton":
        '''(experimental) Grants permission to delete an environment.

        Access Level: Write

        Possible conditions:

        - .ifEnvironmentTemplate()

        https://docs.aws.amazon.com/proton/latest/APIReference/API_DeleteEnvironment.html

        :stability: experimental
        '''
        return typing.cast("Proton", jsii.invoke(self, "toDeleteEnvironment", []))

    @jsii.member(jsii_name="toDeleteEnvironmentAccountConnection")
    def to_delete_environment_account_connection(self) -> "Proton":
        '''(experimental) Grants permission to delete an environment account connection.

        Access Level: Write

        https://docs.aws.amazon.com/proton/latest/APIReference/API_DeleteEnvironmentAccountConnection.html

        :stability: experimental
        '''
        return typing.cast("Proton", jsii.invoke(self, "toDeleteEnvironmentAccountConnection", []))

    @jsii.member(jsii_name="toDeleteEnvironmentTemplate")
    def to_delete_environment_template(self) -> "Proton":
        '''(experimental) Grants permission to delete an environment template.

        Access Level: Write

        https://docs.aws.amazon.com/proton/latest/APIReference/API_DeleteEnvironmentTemplate.html

        :stability: experimental
        '''
        return typing.cast("Proton", jsii.invoke(self, "toDeleteEnvironmentTemplate", []))

    @jsii.member(jsii_name="toDeleteEnvironmentTemplateMajorVersion")
    def to_delete_environment_template_major_version(self) -> "Proton":
        '''(experimental) Grants permission to delete an environment template major version. DEPRECATED - use DeleteEnvironmentTemplateVersion instead.

        Access Level: Write

        https://docs.aws.amazon.com/proton/latest/APIReference/API_DeleteEnvironmentTemplateMajorVersion.html

        :stability: experimental
        '''
        return typing.cast("Proton", jsii.invoke(self, "toDeleteEnvironmentTemplateMajorVersion", []))

    @jsii.member(jsii_name="toDeleteEnvironmentTemplateMinorVersion")
    def to_delete_environment_template_minor_version(self) -> "Proton":
        '''(experimental) Grants permission to delete an environment template minor version. DEPRECATED - use DeleteEnvironmentTemplateVersion instead.

        Access Level: Write

        https://docs.aws.amazon.com/proton/latest/APIReference/API_DeleteEnvironmentTemplateMinorVersion.html

        :stability: experimental
        '''
        return typing.cast("Proton", jsii.invoke(self, "toDeleteEnvironmentTemplateMinorVersion", []))

    @jsii.member(jsii_name="toDeleteEnvironmentTemplateVersion")
    def to_delete_environment_template_version(self) -> "Proton":
        '''(experimental) Grants permission to delete an environment template version.

        Access Level: Write

        https://docs.aws.amazon.com/proton/latest/APIReference/API_DeleteEnvironmentTemplateVersion.html

        :stability: experimental
        '''
        return typing.cast("Proton", jsii.invoke(self, "toDeleteEnvironmentTemplateVersion", []))

    @jsii.member(jsii_name="toDeleteRepository")
    def to_delete_repository(self) -> "Proton":
        '''(experimental) Grants permission to delete a repository.

        Access Level: Write

        https://docs.aws.amazon.com/proton/latest/APIReference/API_DeleteRepository.html

        :stability: experimental
        '''
        return typing.cast("Proton", jsii.invoke(self, "toDeleteRepository", []))

    @jsii.member(jsii_name="toDeleteService")
    def to_delete_service(self) -> "Proton":
        '''(experimental) Grants permission to delete a service.

        Access Level: Write

        Possible conditions:

        - .ifServiceTemplate()

        https://docs.aws.amazon.com/proton/latest/APIReference/API_DeleteService.html

        :stability: experimental
        '''
        return typing.cast("Proton", jsii.invoke(self, "toDeleteService", []))

    @jsii.member(jsii_name="toDeleteServiceTemplate")
    def to_delete_service_template(self) -> "Proton":
        '''(experimental) Grants permission to delete a service template.

        Access Level: Write

        https://docs.aws.amazon.com/proton/latest/APIReference/API_DeleteServiceTemplate.html

        :stability: experimental
        '''
        return typing.cast("Proton", jsii.invoke(self, "toDeleteServiceTemplate", []))

    @jsii.member(jsii_name="toDeleteServiceTemplateMajorVersion")
    def to_delete_service_template_major_version(self) -> "Proton":
        '''(experimental) Grants permission to delete a service template major version. DEPRECATED - use DeleteServiceTemplateVersion instead.

        Access Level: Write

        https://docs.aws.amazon.com/proton/latest/APIReference/API_DeleteServiceTemplateMajorVersion.html

        :stability: experimental
        '''
        return typing.cast("Proton", jsii.invoke(self, "toDeleteServiceTemplateMajorVersion", []))

    @jsii.member(jsii_name="toDeleteServiceTemplateMinorVersion")
    def to_delete_service_template_minor_version(self) -> "Proton":
        '''(experimental) Grants permission to delete a service template minor version. DEPRECATED - use DeleteServiceTemplateVersion instead.

        Access Level: Write

        https://docs.aws.amazon.com/proton/latest/APIReference/API_DeleteServiceTemplateMinorVersion.html

        :stability: experimental
        '''
        return typing.cast("Proton", jsii.invoke(self, "toDeleteServiceTemplateMinorVersion", []))

    @jsii.member(jsii_name="toDeleteServiceTemplateVersion")
    def to_delete_service_template_version(self) -> "Proton":
        '''(experimental) Grants permission to delete a service template version.

        Access Level: Write

        https://docs.aws.amazon.com/proton/latest/APIReference/API_DeleteServiceTemplateVersion.html

        :stability: experimental
        '''
        return typing.cast("Proton", jsii.invoke(self, "toDeleteServiceTemplateVersion", []))

    @jsii.member(jsii_name="toDeleteTemplateSyncConfig")
    def to_delete_template_sync_config(self) -> "Proton":
        '''(experimental) Grants permission to delete a TemplateSyncConfig.

        Access Level: Write

        https://docs.aws.amazon.com/proton/latest/APIReference/API_DeleteTemplateSyncConfig.html

        :stability: experimental
        '''
        return typing.cast("Proton", jsii.invoke(self, "toDeleteTemplateSyncConfig", []))

    @jsii.member(jsii_name="toGetAccountRoles")
    def to_get_account_roles(self) -> "Proton":
        '''(experimental) Grants permission to get account roles. DEPRECATED - use GetAccountSettings instead.

        Access Level: Read

        https://docs.aws.amazon.com/proton/latest/APIReference/API_GetAccountRoles.html

        :stability: experimental
        '''
        return typing.cast("Proton", jsii.invoke(self, "toGetAccountRoles", []))

    @jsii.member(jsii_name="toGetAccountSettings")
    def to_get_account_settings(self) -> "Proton":
        '''(experimental) Grants permission to describe the account settings.

        Access Level: Read

        https://docs.aws.amazon.com/proton/latest/APIReference/API_GetAccountSettings.html

        :stability: experimental
        '''
        return typing.cast("Proton", jsii.invoke(self, "toGetAccountSettings", []))

    @jsii.member(jsii_name="toGetComponent")
    def to_get_component(self) -> "Proton":
        '''(experimental) Grants permission to describe a component.

        Access Level: Read

        https://docs.aws.amazon.com/proton/latest/APIReference/API_GetComponent.html

        :stability: experimental
        '''
        return typing.cast("Proton", jsii.invoke(self, "toGetComponent", []))

    @jsii.member(jsii_name="toGetEnvironment")
    def to_get_environment(self) -> "Proton":
        '''(experimental) Grants permission to describe an environment.

        Access Level: Read

        https://docs.aws.amazon.com/proton/latest/APIReference/API_GetEnvironment.html

        :stability: experimental
        '''
        return typing.cast("Proton", jsii.invoke(self, "toGetEnvironment", []))

    @jsii.member(jsii_name="toGetEnvironmentAccountConnection")
    def to_get_environment_account_connection(self) -> "Proton":
        '''(experimental) Grants permission to describe an environment account connection.

        Access Level: Read

        https://docs.aws.amazon.com/proton/latest/APIReference/API_GetEnvironmentAccountConnection.html

        :stability: experimental
        '''
        return typing.cast("Proton", jsii.invoke(self, "toGetEnvironmentAccountConnection", []))

    @jsii.member(jsii_name="toGetEnvironmentTemplate")
    def to_get_environment_template(self) -> "Proton":
        '''(experimental) Grants permission to describe an environment template.

        Access Level: Read

        https://docs.aws.amazon.com/proton/latest/APIReference/API_GetEnvironmentTemplate.html

        :stability: experimental
        '''
        return typing.cast("Proton", jsii.invoke(self, "toGetEnvironmentTemplate", []))

    @jsii.member(jsii_name="toGetEnvironmentTemplateMajorVersion")
    def to_get_environment_template_major_version(self) -> "Proton":
        '''(experimental) Grants permission to get an environment template major version. DEPRECATED - use GetEnvironmentTemplateVersion instead.

        Access Level: Read

        https://docs.aws.amazon.com/proton/latest/APIReference/API_GetEnvironmentTemplateMajorVersion.html

        :stability: experimental
        '''
        return typing.cast("Proton", jsii.invoke(self, "toGetEnvironmentTemplateMajorVersion", []))

    @jsii.member(jsii_name="toGetEnvironmentTemplateMinorVersion")
    def to_get_environment_template_minor_version(self) -> "Proton":
        '''(experimental) Grants permission to get an environment template minor version. DEPRECATED - use GetEnvironmentTemplateVersion instead.

        Access Level: Read

        https://docs.aws.amazon.com/proton/latest/APIReference/API_GetEnvironmentTemplateMinorVersion.html

        :stability: experimental
        '''
        return typing.cast("Proton", jsii.invoke(self, "toGetEnvironmentTemplateMinorVersion", []))

    @jsii.member(jsii_name="toGetEnvironmentTemplateVersion")
    def to_get_environment_template_version(self) -> "Proton":
        '''(experimental) Grants permission to describe an environment template version.

        Access Level: Read

        https://docs.aws.amazon.com/proton/latest/APIReference/API_GetEnvironmentTemplateVersion.html

        :stability: experimental
        '''
        return typing.cast("Proton", jsii.invoke(self, "toGetEnvironmentTemplateVersion", []))

    @jsii.member(jsii_name="toGetRepository")
    def to_get_repository(self) -> "Proton":
        '''(experimental) Grants permission to describe a repository.

        Access Level: Read

        https://docs.aws.amazon.com/proton/latest/APIReference/API_GetRepository.html

        :stability: experimental
        '''
        return typing.cast("Proton", jsii.invoke(self, "toGetRepository", []))

    @jsii.member(jsii_name="toGetRepositorySyncStatus")
    def to_get_repository_sync_status(self) -> "Proton":
        '''(experimental) Grants permission to get the latest sync status for a repository.

        Access Level: Read

        https://docs.aws.amazon.com/proton/latest/APIReference/API_GetRepositorySyncStatus.html

        :stability: experimental
        '''
        return typing.cast("Proton", jsii.invoke(self, "toGetRepositorySyncStatus", []))

    @jsii.member(jsii_name="toGetResourcesSummary")
    def to_get_resources_summary(self) -> "Proton":
        '''(experimental) Grants permission to get resources summary.

        Access Level: Read

        https://docs.aws.amazon.com/proton/latest/APIReference/API_GetResourcesSummary.html

        :stability: experimental
        '''
        return typing.cast("Proton", jsii.invoke(self, "toGetResourcesSummary", []))

    @jsii.member(jsii_name="toGetResourceTemplateVersionStatusCounts")
    def to_get_resource_template_version_status_counts(self) -> "Proton":
        '''(experimental) Grants permission to list resource template version status counts.

        Access Level: Read

        https://docs.aws.amazon.com/proton/latest/APIReference/API_GetResourceTemplateVersionStatusCounts.html

        :stability: experimental
        '''
        return typing.cast("Proton", jsii.invoke(self, "toGetResourceTemplateVersionStatusCounts", []))

    @jsii.member(jsii_name="toGetService")
    def to_get_service(self) -> "Proton":
        '''(experimental) Grants permission to describe a service.

        Access Level: Read

        https://docs.aws.amazon.com/proton/latest/APIReference/API_GetService.html

        :stability: experimental
        '''
        return typing.cast("Proton", jsii.invoke(self, "toGetService", []))

    @jsii.member(jsii_name="toGetServiceInstance")
    def to_get_service_instance(self) -> "Proton":
        '''(experimental) Grants permission to describe a service instance.

        Access Level: Read

        https://docs.aws.amazon.com/proton/latest/APIReference/API_GetServiceInstance.html

        :stability: experimental
        '''
        return typing.cast("Proton", jsii.invoke(self, "toGetServiceInstance", []))

    @jsii.member(jsii_name="toGetServiceTemplate")
    def to_get_service_template(self) -> "Proton":
        '''(experimental) Grants permission to describe a service template.

        Access Level: Read

        https://docs.aws.amazon.com/proton/latest/APIReference/API_GetServiceTemplate.html

        :stability: experimental
        '''
        return typing.cast("Proton", jsii.invoke(self, "toGetServiceTemplate", []))

    @jsii.member(jsii_name="toGetServiceTemplateMajorVersion")
    def to_get_service_template_major_version(self) -> "Proton":
        '''(experimental) Grants permission to get a service template major version. DEPRECATED - use GetServiceTemplateVersion instead.

        Access Level: Read

        https://docs.aws.amazon.com/proton/latest/APIReference/API_GetServiceTemplateMajorVersion.html

        :stability: experimental
        '''
        return typing.cast("Proton", jsii.invoke(self, "toGetServiceTemplateMajorVersion", []))

    @jsii.member(jsii_name="toGetServiceTemplateMinorVersion")
    def to_get_service_template_minor_version(self) -> "Proton":
        '''(experimental) Grants permission to get a service template minor version. DEPRECATED - use GetServiceTemplateVersion instead.

        Access Level: Read

        https://docs.aws.amazon.com/proton/latest/APIReference/API_GetServiceTemplateMinorVersion.html

        :stability: experimental
        '''
        return typing.cast("Proton", jsii.invoke(self, "toGetServiceTemplateMinorVersion", []))

    @jsii.member(jsii_name="toGetServiceTemplateVersion")
    def to_get_service_template_version(self) -> "Proton":
        '''(experimental) Grants permission to describe a service template version.

        Access Level: Read

        https://docs.aws.amazon.com/proton/latest/APIReference/API_GetServiceTemplateVersion.html

        :stability: experimental
        '''
        return typing.cast("Proton", jsii.invoke(self, "toGetServiceTemplateVersion", []))

    @jsii.member(jsii_name="toGetTemplateSyncConfig")
    def to_get_template_sync_config(self) -> "Proton":
        '''(experimental) Grants permission to describe a TemplateSyncConfig.

        Access Level: Read

        https://docs.aws.amazon.com/proton/latest/APIReference/API_GetTemplateSyncConfig.html

        :stability: experimental
        '''
        return typing.cast("Proton", jsii.invoke(self, "toGetTemplateSyncConfig", []))

    @jsii.member(jsii_name="toGetTemplateSyncStatus")
    def to_get_template_sync_status(self) -> "Proton":
        '''(experimental) Grants permission to describe the sync status of a template.

        Access Level: Read

        https://docs.aws.amazon.com/proton/latest/APIReference/API_GetTemplateSyncStatus.html

        :stability: experimental
        '''
        return typing.cast("Proton", jsii.invoke(self, "toGetTemplateSyncStatus", []))

    @jsii.member(jsii_name="toListComponentOutputs")
    def to_list_component_outputs(self) -> "Proton":
        '''(experimental) Grants permission to list component outputs.

        Access Level: List

        https://docs.aws.amazon.com/proton/latest/APIReference/API_ListComponentOutputs.html

        :stability: experimental
        '''
        return typing.cast("Proton", jsii.invoke(self, "toListComponentOutputs", []))

    @jsii.member(jsii_name="toListComponentProvisionedResources")
    def to_list_component_provisioned_resources(self) -> "Proton":
        '''(experimental) Grants permission to list component provisioned resources.

        Access Level: List

        https://docs.aws.amazon.com/proton/latest/APIReference/API_ListComponentProvisionedResources.html

        :stability: experimental
        '''
        return typing.cast("Proton", jsii.invoke(self, "toListComponentProvisionedResources", []))

    @jsii.member(jsii_name="toListComponents")
    def to_list_components(self) -> "Proton":
        '''(experimental) Grants permission to list components.

        Access Level: List

        https://docs.aws.amazon.com/proton/latest/APIReference/API_ListComponents.html

        :stability: experimental
        '''
        return typing.cast("Proton", jsii.invoke(self, "toListComponents", []))

    @jsii.member(jsii_name="toListEnvironmentAccountConnections")
    def to_list_environment_account_connections(self) -> "Proton":
        '''(experimental) Grants permission to list environment account connections.

        Access Level: List

        https://docs.aws.amazon.com/proton/latest/APIReference/API_ListEnvironmentAccountConnections.html

        :stability: experimental
        '''
        return typing.cast("Proton", jsii.invoke(self, "toListEnvironmentAccountConnections", []))

    @jsii.member(jsii_name="toListEnvironmentOutputs")
    def to_list_environment_outputs(self) -> "Proton":
        '''(experimental) Grants permission to list environment outputs.

        Access Level: List

        https://docs.aws.amazon.com/proton/latest/APIReference/API_ListEnvironmentOutputs.html

        :stability: experimental
        '''
        return typing.cast("Proton", jsii.invoke(self, "toListEnvironmentOutputs", []))

    @jsii.member(jsii_name="toListEnvironmentProvisionedResources")
    def to_list_environment_provisioned_resources(self) -> "Proton":
        '''(experimental) Grants permission to list environment provisioned resources.

        Access Level: List

        https://docs.aws.amazon.com/proton/latest/APIReference/API_ListEnvironmentProvisionedResources.html

        :stability: experimental
        '''
        return typing.cast("Proton", jsii.invoke(self, "toListEnvironmentProvisionedResources", []))

    @jsii.member(jsii_name="toListEnvironments")
    def to_list_environments(self) -> "Proton":
        '''(experimental) Grants permission to list environments.

        Access Level: List

        https://docs.aws.amazon.com/proton/latest/APIReference/API_ListEnvironments.html

        :stability: experimental
        '''
        return typing.cast("Proton", jsii.invoke(self, "toListEnvironments", []))

    @jsii.member(jsii_name="toListEnvironmentTemplateMajorVersions")
    def to_list_environment_template_major_versions(self) -> "Proton":
        '''(experimental) Grants permission to list environment template major versions. DEPRECATED - use ListEnvironmentTemplateVersions instead.

        Access Level: List

        https://docs.aws.amazon.com/proton/latest/APIReference/API_ListEnvironmentTemplateMajorVersions.html

        :stability: experimental
        '''
        return typing.cast("Proton", jsii.invoke(self, "toListEnvironmentTemplateMajorVersions", []))

    @jsii.member(jsii_name="toListEnvironmentTemplateMinorVersions")
    def to_list_environment_template_minor_versions(self) -> "Proton":
        '''(experimental) Grants permission to list an environment template minor versions. DEPRECATED - use ListEnvironmentTemplateVersions instead.

        Access Level: List

        https://docs.aws.amazon.com/proton/latest/APIReference/API_ListEnvironmentTemplateMinorVersions.html

        :stability: experimental
        '''
        return typing.cast("Proton", jsii.invoke(self, "toListEnvironmentTemplateMinorVersions", []))

    @jsii.member(jsii_name="toListEnvironmentTemplates")
    def to_list_environment_templates(self) -> "Proton":
        '''(experimental) Grants permission to list environment templates.

        Access Level: List

        https://docs.aws.amazon.com/proton/latest/APIReference/API_ListEnvironmentTemplates.html

        :stability: experimental
        '''
        return typing.cast("Proton", jsii.invoke(self, "toListEnvironmentTemplates", []))

    @jsii.member(jsii_name="toListEnvironmentTemplateVersions")
    def to_list_environment_template_versions(self) -> "Proton":
        '''(experimental) Grants permission to list environment template versions.

        Access Level: List

        https://docs.aws.amazon.com/proton/latest/APIReference/API_ListEnvironmentTemplateVersions.html

        :stability: experimental
        '''
        return typing.cast("Proton", jsii.invoke(self, "toListEnvironmentTemplateVersions", []))

    @jsii.member(jsii_name="toListRepositories")
    def to_list_repositories(self) -> "Proton":
        '''(experimental) Grants permission to list repositories.

        Access Level: List

        https://docs.aws.amazon.com/proton/latest/APIReference/API_ListRepositories.html

        :stability: experimental
        '''
        return typing.cast("Proton", jsii.invoke(self, "toListRepositories", []))

    @jsii.member(jsii_name="toListRepositorySyncDefinitions")
    def to_list_repository_sync_definitions(self) -> "Proton":
        '''(experimental) Grants permission to list repository sync definitions.

        Access Level: List

        https://docs.aws.amazon.com/proton/latest/APIReference/API_ListRepositorySyncDefinitions.html

        :stability: experimental
        '''
        return typing.cast("Proton", jsii.invoke(self, "toListRepositorySyncDefinitions", []))

    @jsii.member(jsii_name="toListServiceInstanceOutputs")
    def to_list_service_instance_outputs(self) -> "Proton":
        '''(experimental) Grants permission to list service instance outputs.

        Access Level: List

        https://docs.aws.amazon.com/proton/latest/APIReference/API_ListServiceInstanceOutputs.html

        :stability: experimental
        '''
        return typing.cast("Proton", jsii.invoke(self, "toListServiceInstanceOutputs", []))

    @jsii.member(jsii_name="toListServiceInstanceProvisionedResources")
    def to_list_service_instance_provisioned_resources(self) -> "Proton":
        '''(experimental) Grants permission to list service instance provisioned resources.

        Access Level: List

        https://docs.aws.amazon.com/proton/latest/APIReference/API_ListServiceInstanceProvisionedResources.html

        :stability: experimental
        '''
        return typing.cast("Proton", jsii.invoke(self, "toListServiceInstanceProvisionedResources", []))

    @jsii.member(jsii_name="toListServiceInstances")
    def to_list_service_instances(self) -> "Proton":
        '''(experimental) Grants permission to list service instances.

        Access Level: List

        https://docs.aws.amazon.com/proton/latest/APIReference/API_ListServiceInstances.html

        :stability: experimental
        '''
        return typing.cast("Proton", jsii.invoke(self, "toListServiceInstances", []))

    @jsii.member(jsii_name="toListServicePipelineOutputs")
    def to_list_service_pipeline_outputs(self) -> "Proton":
        '''(experimental) Grants permission to list service pipeline outputs.

        Access Level: List

        https://docs.aws.amazon.com/proton/latest/APIReference/API_ListServicePipelineOutputs.html

        :stability: experimental
        '''
        return typing.cast("Proton", jsii.invoke(self, "toListServicePipelineOutputs", []))

    @jsii.member(jsii_name="toListServicePipelineProvisionedResources")
    def to_list_service_pipeline_provisioned_resources(self) -> "Proton":
        '''(experimental) Grants permission to list service pipeline provisioned resources.

        Access Level: List

        https://docs.aws.amazon.com/proton/latest/APIReference/API_ListServicePipelineProvisionedResources.html

        :stability: experimental
        '''
        return typing.cast("Proton", jsii.invoke(self, "toListServicePipelineProvisionedResources", []))

    @jsii.member(jsii_name="toListServices")
    def to_list_services(self) -> "Proton":
        '''(experimental) Grants permission to list services.

        Access Level: List

        https://docs.aws.amazon.com/proton/latest/APIReference/API_ListServices.html

        :stability: experimental
        '''
        return typing.cast("Proton", jsii.invoke(self, "toListServices", []))

    @jsii.member(jsii_name="toListServiceTemplateMajorVersions")
    def to_list_service_template_major_versions(self) -> "Proton":
        '''(experimental) Grants permission to list service template major versions. DEPRECATED - use ListServiceTemplateVersions instead.

        Access Level: List

        https://docs.aws.amazon.com/proton/latest/APIReference/API_ListServiceTemplateMajorVersions.html

        :stability: experimental
        '''
        return typing.cast("Proton", jsii.invoke(self, "toListServiceTemplateMajorVersions", []))

    @jsii.member(jsii_name="toListServiceTemplateMinorVersions")
    def to_list_service_template_minor_versions(self) -> "Proton":
        '''(experimental) Grants permission to list service template minor versions. DEPRECATED - use ListServiceTemplateVersions instead.

        Access Level: List

        https://docs.aws.amazon.com/proton/latest/APIReference/API_ListServiceTemplateMinorVersions.html

        :stability: experimental
        '''
        return typing.cast("Proton", jsii.invoke(self, "toListServiceTemplateMinorVersions", []))

    @jsii.member(jsii_name="toListServiceTemplates")
    def to_list_service_templates(self) -> "Proton":
        '''(experimental) Grants permission to list service templates.

        Access Level: List

        https://docs.aws.amazon.com/proton/latest/APIReference/API_ListServiceTemplates.html

        :stability: experimental
        '''
        return typing.cast("Proton", jsii.invoke(self, "toListServiceTemplates", []))

    @jsii.member(jsii_name="toListServiceTemplateVersions")
    def to_list_service_template_versions(self) -> "Proton":
        '''(experimental) Grants permission to list service template versions.

        Access Level: List

        https://docs.aws.amazon.com/proton/latest/APIReference/API_ListServiceTemplateVersions.html

        :stability: experimental
        '''
        return typing.cast("Proton", jsii.invoke(self, "toListServiceTemplateVersions", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Proton":
        '''(experimental) Grants permission to list tags of a resource.

        Access Level: Read

        https://docs.aws.amazon.com/proton/latest/APIReference/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("Proton", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toNotifyResourceDeploymentStatusChange")
    def to_notify_resource_deployment_status_change(self) -> "Proton":
        '''(experimental) Grants permission to notify Proton of resource deployment status changes.

        Access Level: Write

        https://docs.aws.amazon.com/proton/latest/APIReference/API_NotifyResourceDeploymentStatusChange.html

        :stability: experimental
        '''
        return typing.cast("Proton", jsii.invoke(self, "toNotifyResourceDeploymentStatusChange", []))

    @jsii.member(jsii_name="toRejectEnvironmentAccountConnection")
    def to_reject_environment_account_connection(self) -> "Proton":
        '''(experimental) Grants permission to reject an environment account connection request from another environment account.

        Access Level: Write

        https://docs.aws.amazon.com/proton/latest/APIReference/API_RejectEnvironmentAccountConnection.html

        :stability: experimental
        '''
        return typing.cast("Proton", jsii.invoke(self, "toRejectEnvironmentAccountConnection", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Proton":
        '''(experimental) Grants permission to add tags to a resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/proton/latest/APIReference/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("Proton", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Proton":
        '''(experimental) Grants permission to remove tags from a resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/proton/latest/APIReference/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("Proton", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateAccountRoles")
    def to_update_account_roles(self) -> "Proton":
        '''(experimental) Grants permission to update account roles. DEPRECATED - use UpdateAccountSettings instead.

        Access Level: Write

        Dependent actions:

        - iam:PassRole

        https://docs.aws.amazon.com/proton/latest/APIReference/API_UpdateAccountRoles.html

        :stability: experimental
        '''
        return typing.cast("Proton", jsii.invoke(self, "toUpdateAccountRoles", []))

    @jsii.member(jsii_name="toUpdateAccountSettings")
    def to_update_account_settings(self) -> "Proton":
        '''(experimental) Grants permission to update the account settings.

        Access Level: Write

        Dependent actions:

        - iam:PassRole

        https://docs.aws.amazon.com/proton/latest/APIReference/API_UpdateAccountSettings.html

        :stability: experimental
        '''
        return typing.cast("Proton", jsii.invoke(self, "toUpdateAccountSettings", []))

    @jsii.member(jsii_name="toUpdateComponent")
    def to_update_component(self) -> "Proton":
        '''(experimental) Grants permission to update component.

        Access Level: Write

        https://docs.aws.amazon.com/proton/latest/APIReference/API_UpdateComponent.html

        :stability: experimental
        '''
        return typing.cast("Proton", jsii.invoke(self, "toUpdateComponent", []))

    @jsii.member(jsii_name="toUpdateEnvironment")
    def to_update_environment(self) -> "Proton":
        '''(experimental) Grants permission to update an environment.

        Access Level: Write

        Possible conditions:

        - .ifEnvironmentTemplate()

        Dependent actions:

        - iam:PassRole

        https://docs.aws.amazon.com/proton/latest/APIReference/API_UpdateEnvironment.html

        :stability: experimental
        '''
        return typing.cast("Proton", jsii.invoke(self, "toUpdateEnvironment", []))

    @jsii.member(jsii_name="toUpdateEnvironmentAccountConnection")
    def to_update_environment_account_connection(self) -> "Proton":
        '''(experimental) Grants permission to update an environment account connection.

        Access Level: Write

        https://docs.aws.amazon.com/proton/latest/APIReference/API_UpdateEnvironmentAccountConnection.html

        :stability: experimental
        '''
        return typing.cast("Proton", jsii.invoke(self, "toUpdateEnvironmentAccountConnection", []))

    @jsii.member(jsii_name="toUpdateEnvironmentTemplate")
    def to_update_environment_template(self) -> "Proton":
        '''(experimental) Grants permission to update an environment template.

        Access Level: Write

        https://docs.aws.amazon.com/proton/latest/APIReference/API_UpdateEnvironmentTemplate.html

        :stability: experimental
        '''
        return typing.cast("Proton", jsii.invoke(self, "toUpdateEnvironmentTemplate", []))

    @jsii.member(jsii_name="toUpdateEnvironmentTemplateMajorVersion")
    def to_update_environment_template_major_version(self) -> "Proton":
        '''(experimental) Grants permission to update an environment template major version. DEPRECATED - use UpdateEnvironmentTemplateVersion instead.

        Access Level: Write

        https://docs.aws.amazon.com/proton/latest/APIReference/API_UpdateEnvironmentTemplateMajorVersion.html

        :stability: experimental
        '''
        return typing.cast("Proton", jsii.invoke(self, "toUpdateEnvironmentTemplateMajorVersion", []))

    @jsii.member(jsii_name="toUpdateEnvironmentTemplateMinorVersion")
    def to_update_environment_template_minor_version(self) -> "Proton":
        '''(experimental) Grants permission to update an environment template minor version. DEPRECATED - use UpdateEnvironmentTemplateVersion instead.

        Access Level: Write

        https://docs.aws.amazon.com/proton/latest/APIReference/API_UpdateEnvironmentTemplateMinorVersion.html

        :stability: experimental
        '''
        return typing.cast("Proton", jsii.invoke(self, "toUpdateEnvironmentTemplateMinorVersion", []))

    @jsii.member(jsii_name="toUpdateEnvironmentTemplateVersion")
    def to_update_environment_template_version(self) -> "Proton":
        '''(experimental) Grants permission to update an environment template version.

        Access Level: Write

        https://docs.aws.amazon.com/proton/latest/APIReference/API_UpdateEnvironmentTemplateVersion.html

        :stability: experimental
        '''
        return typing.cast("Proton", jsii.invoke(self, "toUpdateEnvironmentTemplateVersion", []))

    @jsii.member(jsii_name="toUpdateService")
    def to_update_service(self) -> "Proton":
        '''(experimental) Grants permission to update a service.

        Access Level: Write

        Possible conditions:

        - .ifServiceTemplate()

        https://docs.aws.amazon.com/proton/latest/APIReference/API_UpdateService.html

        :stability: experimental
        '''
        return typing.cast("Proton", jsii.invoke(self, "toUpdateService", []))

    @jsii.member(jsii_name="toUpdateServiceInstance")
    def to_update_service_instance(self) -> "Proton":
        '''(experimental) Grants permission to update a service instance.

        Access Level: Write

        Possible conditions:

        - .ifServiceTemplate()

        https://docs.aws.amazon.com/proton/latest/APIReference/API_UpdateServiceInstance.html

        :stability: experimental
        '''
        return typing.cast("Proton", jsii.invoke(self, "toUpdateServiceInstance", []))

    @jsii.member(jsii_name="toUpdateServicePipeline")
    def to_update_service_pipeline(self) -> "Proton":
        '''(experimental) Grants permission to update a service pipeline.

        Access Level: Write

        Possible conditions:

        - .ifServiceTemplate()

        https://docs.aws.amazon.com/proton/latest/APIReference/API_UpdateServicePipeline.html

        :stability: experimental
        '''
        return typing.cast("Proton", jsii.invoke(self, "toUpdateServicePipeline", []))

    @jsii.member(jsii_name="toUpdateServiceTemplate")
    def to_update_service_template(self) -> "Proton":
        '''(experimental) Grants permission to update a service template.

        Access Level: Write

        https://docs.aws.amazon.com/proton/latest/APIReference/API_UpdateServiceTemplate.html

        :stability: experimental
        '''
        return typing.cast("Proton", jsii.invoke(self, "toUpdateServiceTemplate", []))

    @jsii.member(jsii_name="toUpdateServiceTemplateMajorVersion")
    def to_update_service_template_major_version(self) -> "Proton":
        '''(experimental) Grants permission to update a service template major version. DEPRECATED - use UpdateServiceTemplateVersion instead.

        Access Level: Write

        https://docs.aws.amazon.com/proton/latest/APIReference/API_UpdateServiceTemplateMajorVersion.html

        :stability: experimental
        '''
        return typing.cast("Proton", jsii.invoke(self, "toUpdateServiceTemplateMajorVersion", []))

    @jsii.member(jsii_name="toUpdateServiceTemplateMinorVersion")
    def to_update_service_template_minor_version(self) -> "Proton":
        '''(experimental) Grants permission to create a service template minor version. DEPRECATED - use UpdateServiceTemplateVersion instead.

        Access Level: Write

        https://docs.aws.amazon.com/proton/latest/APIReference/API_UpdateServiceTemplateMinorVersion.html

        :stability: experimental
        '''
        return typing.cast("Proton", jsii.invoke(self, "toUpdateServiceTemplateMinorVersion", []))

    @jsii.member(jsii_name="toUpdateServiceTemplateVersion")
    def to_update_service_template_version(self) -> "Proton":
        '''(experimental) Grants permission to update a service template version.

        Access Level: Write

        https://docs.aws.amazon.com/proton/latest/APIReference/API_UpdateServiceTemplateVersion.html

        :stability: experimental
        '''
        return typing.cast("Proton", jsii.invoke(self, "toUpdateServiceTemplateVersion", []))

    @jsii.member(jsii_name="toUpdateTemplateSyncConfig")
    def to_update_template_sync_config(self) -> "Proton":
        '''(experimental) Grants permission to update a TemplateSyncConfig.

        Access Level: Write

        https://docs.aws.amazon.com/proton/latest/APIReference/API_UpdateTemplateSyncConfig.html

        :stability: experimental
        '''
        return typing.cast("Proton", jsii.invoke(self, "toUpdateTemplateSyncConfig", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__cee18e641232e7242cd266c124c69a563052934095d9d502db588c2b0e028536)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__47a6aaa6185f89c9e9cb0bb6459b12bafa5974a90396d074394c3d40581a094f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class PurchaseOrders(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.PurchaseOrders",
):
    '''(experimental) Statement provider for service `purchase-orders <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awspurchaseordersconsole.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `purchase-orders <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awspurchaseordersconsole.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="toModifyPurchaseOrders")
    def to_modify_purchase_orders(self) -> "PurchaseOrders":
        '''(experimental) Modify purchase orders and details.

        Access Level: Write

        https://docs.aws.amazon.com/awsaccountbilling/latest/aboutv2/billing-permissions-ref.html#user-permissions

        :stability: experimental
        '''
        return typing.cast("PurchaseOrders", jsii.invoke(self, "toModifyPurchaseOrders", []))

    @jsii.member(jsii_name="toViewPurchaseOrders")
    def to_view_purchase_orders(self) -> "PurchaseOrders":
        '''(experimental) View purchase orders and details.

        Access Level: Read

        https://docs.aws.amazon.com/awsaccountbilling/latest/aboutv2/billing-permissions-ref.html#user-permissions

        :stability: experimental
        '''
        return typing.cast("PurchaseOrders", jsii.invoke(self, "toViewPurchaseOrders", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3e3d436024cfbd35405a5a8df265a65629876a0414e29d6d27540b97fcf3cd74)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5b41b89765dd8d0efa87eb8aaa217d06dc70601dadd5e37000420d9dbfd00acb)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Qldb(PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Qldb"):
    '''(experimental) Statement provider for service `qldb <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonqldb.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `qldb <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonqldb.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="ifPurge")
    def if_purge(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Qldb":
        '''(experimental) Filters access by the value of purge that is specified in a PartiQL DROP statement.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_condition-keys.html#condition-keys-purge

        Applies to actions:

        - .toPartiQLDropIndex()
        - .toPartiQLDropTable()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__25fc78ee73c9b42f748c66e1e161a9637861df2dc4aa4c3ab949f0d42e33b240)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Qldb", jsii.invoke(self, "ifPurge", [value, operator]))

    @jsii.member(jsii_name="onCatalog")
    def on_catalog(
        self,
        ledger_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Qldb":
        '''(experimental) Adds a resource of type catalog to the statement.

        https://docs.aws.amazon.com/qldb/latest/developerguide/working.catalog.html

        :param ledger_name: - Identifier for the ledgerName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__131223977953c8d9e91e0ef0a4d361c675ed0322fb616c8df32835ac536595de)
            check_type(argname="argument ledger_name", value=ledger_name, expected_type=type_hints["ledger_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Qldb", jsii.invoke(self, "onCatalog", [ledger_name, account, region, partition]))

    @jsii.member(jsii_name="onLedger")
    def on_ledger(
        self,
        ledger_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Qldb":
        '''(experimental) Adds a resource of type ledger to the statement.

        https://docs.aws.amazon.com/qldb/latest/developerguide/ledger-structure.html

        :param ledger_name: - Identifier for the ledgerName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7f63c4c848438da1f9887d2d1805f43bd2b43c74b433b269e4c5492f159b125b)
            check_type(argname="argument ledger_name", value=ledger_name, expected_type=type_hints["ledger_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Qldb", jsii.invoke(self, "onLedger", [ledger_name, account, region, partition]))

    @jsii.member(jsii_name="onStream")
    def on_stream(
        self,
        ledger_name: builtins.str,
        stream_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Qldb":
        '''(experimental) Adds a resource of type stream to the statement.

        https://docs.aws.amazon.com/qldb/latest/developerguide/streams.html

        :param ledger_name: - Identifier for the ledgerName.
        :param stream_id: - Identifier for the streamId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a8acc269f9427058d34add18281ce78396044b76b37a40877580898a1b448468)
            check_type(argname="argument ledger_name", value=ledger_name, expected_type=type_hints["ledger_name"])
            check_type(argname="argument stream_id", value=stream_id, expected_type=type_hints["stream_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Qldb", jsii.invoke(self, "onStream", [ledger_name, stream_id, account, region, partition]))

    @jsii.member(jsii_name="onTable")
    def on_table(
        self,
        ledger_name: builtins.str,
        table_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Qldb":
        '''(experimental) Adds a resource of type table to the statement.

        https://docs.aws.amazon.com/qldb/latest/developerguide/working.manage-tables.html

        :param ledger_name: - Identifier for the ledgerName.
        :param table_id: - Identifier for the tableId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5259b62eba77b89955d9ce76169264bc8b8c1e4e6c21850e6e09d9d2ce18d476)
            check_type(argname="argument ledger_name", value=ledger_name, expected_type=type_hints["ledger_name"])
            check_type(argname="argument table_id", value=table_id, expected_type=type_hints["table_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Qldb", jsii.invoke(self, "onTable", [ledger_name, table_id, account, region, partition]))

    @jsii.member(jsii_name="toCancelJournalKinesisStream")
    def to_cancel_journal_kinesis_stream(self) -> "Qldb":
        '''(experimental) Grants permission to cancel a journal kinesis stream.

        Access Level: Write

        https://docs.aws.amazon.com/qldb/latest/developerguide/API_CancelJournalKinesisStream.html

        :stability: experimental
        '''
        return typing.cast("Qldb", jsii.invoke(self, "toCancelJournalKinesisStream", []))

    @jsii.member(jsii_name="toCreateLedger")
    def to_create_ledger(self) -> "Qldb":
        '''(experimental) Grants permission to create a ledger.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/qldb/latest/developerguide/API_CreateLedger.html

        :stability: experimental
        '''
        return typing.cast("Qldb", jsii.invoke(self, "toCreateLedger", []))

    @jsii.member(jsii_name="toDeleteLedger")
    def to_delete_ledger(self) -> "Qldb":
        '''(experimental) Grants permission to delete a ledger.

        Access Level: Write

        https://docs.aws.amazon.com/qldb/latest/developerguide/API_DeleteLedger.html

        :stability: experimental
        '''
        return typing.cast("Qldb", jsii.invoke(self, "toDeleteLedger", []))

    @jsii.member(jsii_name="toDescribeJournalKinesisStream")
    def to_describe_journal_kinesis_stream(self) -> "Qldb":
        '''(experimental) Grants permission to describe information about a journal kinesis stream.

        Access Level: Read

        https://docs.aws.amazon.com/qldb/latest/developerguide/API_DescribeJournalKinesisStream.html

        :stability: experimental
        '''
        return typing.cast("Qldb", jsii.invoke(self, "toDescribeJournalKinesisStream", []))

    @jsii.member(jsii_name="toDescribeJournalS3Export")
    def to_describe_journal_s3_export(self) -> "Qldb":
        '''(experimental) Grants permission to describe information about a journal export job.

        Access Level: Read

        https://docs.aws.amazon.com/qldb/latest/developerguide/API_DescribeJournalS3Export.html

        :stability: experimental
        '''
        return typing.cast("Qldb", jsii.invoke(self, "toDescribeJournalS3Export", []))

    @jsii.member(jsii_name="toDescribeLedger")
    def to_describe_ledger(self) -> "Qldb":
        '''(experimental) Grants permission to describe a ledger.

        Access Level: Read

        https://docs.aws.amazon.com/qldb/latest/developerguide/API_DescribeLedger.html

        :stability: experimental
        '''
        return typing.cast("Qldb", jsii.invoke(self, "toDescribeLedger", []))

    @jsii.member(jsii_name="toExecuteStatement")
    def to_execute_statement(self) -> "Qldb":
        '''(experimental) Grants permission to send commands to a ledger via the console.

        Access Level: Write

        https://docs.aws.amazon.com/qldb/latest/developerguide/console_QLDB.html

        :stability: experimental
        '''
        return typing.cast("Qldb", jsii.invoke(self, "toExecuteStatement", []))

    @jsii.member(jsii_name="toExportJournalToS3")
    def to_export_journal_to_s3(self) -> "Qldb":
        '''(experimental) Grants permission to export journal contents to an Amazon S3 bucket.

        Access Level: Write

        https://docs.aws.amazon.com/qldb/latest/developerguide/API_ExportJournalToS3.html

        :stability: experimental
        '''
        return typing.cast("Qldb", jsii.invoke(self, "toExportJournalToS3", []))

    @jsii.member(jsii_name="toGetBlock")
    def to_get_block(self) -> "Qldb":
        '''(experimental) Grants permission to retrieve a block from a ledger for a given BlockAddress.

        Access Level: Read

        https://docs.aws.amazon.com/qldb/latest/developerguide/API_GetBlock.html

        :stability: experimental
        '''
        return typing.cast("Qldb", jsii.invoke(self, "toGetBlock", []))

    @jsii.member(jsii_name="toGetDigest")
    def to_get_digest(self) -> "Qldb":
        '''(experimental) Grants permission to retrieve a digest from a ledger for a given BlockAddress.

        Access Level: Read

        https://docs.aws.amazon.com/qldb/latest/developerguide/API_GetDigest.html

        :stability: experimental
        '''
        return typing.cast("Qldb", jsii.invoke(self, "toGetDigest", []))

    @jsii.member(jsii_name="toGetRevision")
    def to_get_revision(self) -> "Qldb":
        '''(experimental) Grants permission to retrieve a revision for a given document ID and a given BlockAddress.

        Access Level: Read

        https://docs.aws.amazon.com/qldb/latest/developerguide/API_GetRevision.html

        :stability: experimental
        '''
        return typing.cast("Qldb", jsii.invoke(self, "toGetRevision", []))

    @jsii.member(jsii_name="toInsertSampleData")
    def to_insert_sample_data(self) -> "Qldb":
        '''(experimental) Grants permission to insert sample application data via the console.

        Access Level: Write

        https://docs.aws.amazon.com/qldb/latest/developerguide/console_QLDB.html

        :stability: experimental
        '''
        return typing.cast("Qldb", jsii.invoke(self, "toInsertSampleData", []))

    @jsii.member(jsii_name="toListJournalKinesisStreamsForLedger")
    def to_list_journal_kinesis_streams_for_ledger(self) -> "Qldb":
        '''(experimental) Grants permission to list journal kinesis streams for a specified ledger.

        Access Level: List

        https://docs.aws.amazon.com/qldb/latest/developerguide/API_ListJournalKinesisStreamsForLedger.html

        :stability: experimental
        '''
        return typing.cast("Qldb", jsii.invoke(self, "toListJournalKinesisStreamsForLedger", []))

    @jsii.member(jsii_name="toListJournalS3Exports")
    def to_list_journal_s3_exports(self) -> "Qldb":
        '''(experimental) Grants permission to list journal export jobs for all ledgers.

        Access Level: List

        https://docs.aws.amazon.com/qldb/latest/developerguide/API_ListJournalS3Exports.html

        :stability: experimental
        '''
        return typing.cast("Qldb", jsii.invoke(self, "toListJournalS3Exports", []))

    @jsii.member(jsii_name="toListJournalS3ExportsForLedger")
    def to_list_journal_s3_exports_for_ledger(self) -> "Qldb":
        '''(experimental) Grants permission to list journal export jobs for a specified ledger.

        Access Level: List

        https://docs.aws.amazon.com/qldb/latest/developerguide/API_ListJournalS3ExportsForLedger.html

        :stability: experimental
        '''
        return typing.cast("Qldb", jsii.invoke(self, "toListJournalS3ExportsForLedger", []))

    @jsii.member(jsii_name="toListLedgers")
    def to_list_ledgers(self) -> "Qldb":
        '''(experimental) Grants permission to list existing ledgers.

        Access Level: List

        https://docs.aws.amazon.com/qldb/latest/developerguide/API_ListLedgers.html

        :stability: experimental
        '''
        return typing.cast("Qldb", jsii.invoke(self, "toListLedgers", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Qldb":
        '''(experimental) Grants permission to list tags for a resource.

        Access Level: Read

        https://docs.aws.amazon.com/qldb/latest/developerguide/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("Qldb", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toPartiQLCreateIndex")
    def to_parti_ql_create_index(self) -> "Qldb":
        '''(experimental) Grants permission to create an index on a table.

        Access Level: Write

        https://docs.aws.amazon.com/qldb/latest/developerguide/ql-reference.create-index.html

        :stability: experimental
        '''
        return typing.cast("Qldb", jsii.invoke(self, "toPartiQLCreateIndex", []))

    @jsii.member(jsii_name="toPartiQLCreateTable")
    def to_parti_ql_create_table(self) -> "Qldb":
        '''(experimental) Grants permission to create a table.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/qldb/latest/developerguide/ql-reference.create-table.html

        :stability: experimental
        '''
        return typing.cast("Qldb", jsii.invoke(self, "toPartiQLCreateTable", []))

    @jsii.member(jsii_name="toPartiQLDelete")
    def to_parti_ql_delete(self) -> "Qldb":
        '''(experimental) Grants permission to delete documents from a table.

        Access Level: Write

        https://docs.aws.amazon.com/qldb/latest/developerguide/ql-reference.delete.html

        :stability: experimental
        '''
        return typing.cast("Qldb", jsii.invoke(self, "toPartiQLDelete", []))

    @jsii.member(jsii_name="toPartiQLDropIndex")
    def to_parti_ql_drop_index(self) -> "Qldb":
        '''(experimental) Grants permission to drop an index from a table.

        Access Level: Write

        Possible conditions:

        - .ifPurge()

        https://docs.aws.amazon.com/qldb/latest/developerguide/ql-reference.drop-index.html

        :stability: experimental
        '''
        return typing.cast("Qldb", jsii.invoke(self, "toPartiQLDropIndex", []))

    @jsii.member(jsii_name="toPartiQLDropTable")
    def to_parti_ql_drop_table(self) -> "Qldb":
        '''(experimental) Grants permission to drop a table.

        Access Level: Write

        Possible conditions:

        - .ifPurge()

        https://docs.aws.amazon.com/qldb/latest/developerguide/ql-reference.drop-table.html

        :stability: experimental
        '''
        return typing.cast("Qldb", jsii.invoke(self, "toPartiQLDropTable", []))

    @jsii.member(jsii_name="toPartiQLHistoryFunction")
    def to_parti_ql_history_function(self) -> "Qldb":
        '''(experimental) Grants permission to use the history function on a table.

        Access Level: Read

        https://docs.aws.amazon.com/qldb/latest/developerguide/working.history.html

        :stability: experimental
        '''
        return typing.cast("Qldb", jsii.invoke(self, "toPartiQLHistoryFunction", []))

    @jsii.member(jsii_name="toPartiQLInsert")
    def to_parti_ql_insert(self) -> "Qldb":
        '''(experimental) Grants permission to insert documents into a table.

        Access Level: Write

        https://docs.aws.amazon.com/qldb/latest/developerguide/ql-reference.insert.html

        :stability: experimental
        '''
        return typing.cast("Qldb", jsii.invoke(self, "toPartiQLInsert", []))

    @jsii.member(jsii_name="toPartiQLRedact")
    def to_parti_ql_redact(self) -> "Qldb":
        '''(experimental) Grants permission to redact historic revisions.

        Access Level: Write

        https://docs.aws.amazon.com/qldb/latest/developerguide/ql-stored-procedures.redact_revision.html

        :stability: experimental
        '''
        return typing.cast("Qldb", jsii.invoke(self, "toPartiQLRedact", []))

    @jsii.member(jsii_name="toPartiQLSelect")
    def to_parti_ql_select(self) -> "Qldb":
        '''(experimental) Grants permission to select documents from a table.

        Access Level: Read

        https://docs.aws.amazon.com/qldb/latest/developerguide/ql-reference.select.html

        :stability: experimental
        '''
        return typing.cast("Qldb", jsii.invoke(self, "toPartiQLSelect", []))

    @jsii.member(jsii_name="toPartiQLUndropTable")
    def to_parti_ql_undrop_table(self) -> "Qldb":
        '''(experimental) Grants permission to undrop a table.

        Access Level: Write

        https://docs.aws.amazon.com/qldb/latest/developerguide/ql-reference.undrop-table.html

        :stability: experimental
        '''
        return typing.cast("Qldb", jsii.invoke(self, "toPartiQLUndropTable", []))

    @jsii.member(jsii_name="toPartiQLUpdate")
    def to_parti_ql_update(self) -> "Qldb":
        '''(experimental) Grants permission to update existing documents in a table.

        Access Level: Write

        https://docs.aws.amazon.com/qldb/latest/developerguide/ql-reference.update.html

        :stability: experimental
        '''
        return typing.cast("Qldb", jsii.invoke(self, "toPartiQLUpdate", []))

    @jsii.member(jsii_name="toSendCommand")
    def to_send_command(self) -> "Qldb":
        '''(experimental) Grants permission to send commands to a ledger.

        Access Level: Write

        https://docs.aws.amazon.com/qldb/latest/developerguide/API_QLDB-Session_SendCommand.html

        :stability: experimental
        '''
        return typing.cast("Qldb", jsii.invoke(self, "toSendCommand", []))

    @jsii.member(jsii_name="toShowCatalog")
    def to_show_catalog(self) -> "Qldb":
        '''(experimental) Grants permission to view a ledger's catalog via the console.

        Access Level: Write

        https://docs.aws.amazon.com/qldb/latest/developerguide/console_QLDB.html

        :stability: experimental
        '''
        return typing.cast("Qldb", jsii.invoke(self, "toShowCatalog", []))

    @jsii.member(jsii_name="toStreamJournalToKinesis")
    def to_stream_journal_to_kinesis(self) -> "Qldb":
        '''(experimental) Grants permission to stream journal contents to a Kinesis Data Stream.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/qldb/latest/developerguide/API_StreamJournalToKinesis.html

        :stability: experimental
        '''
        return typing.cast("Qldb", jsii.invoke(self, "toStreamJournalToKinesis", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Qldb":
        '''(experimental) Grants permission to add one or more tags to a resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/qldb/latest/developerguide/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("Qldb", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Qldb":
        '''(experimental) Grants permission to remove one or more tags from a resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/qldb/latest/developerguide/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("Qldb", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateLedger")
    def to_update_ledger(self) -> "Qldb":
        '''(experimental) Grants permission to update properties on a ledger.

        Access Level: Write

        https://docs.aws.amazon.com/qldb/latest/developerguide/API_UpdateLedger.html

        :stability: experimental
        '''
        return typing.cast("Qldb", jsii.invoke(self, "toUpdateLedger", []))

    @jsii.member(jsii_name="toUpdateLedgerPermissionsMode")
    def to_update_ledger_permissions_mode(self) -> "Qldb":
        '''(experimental) Grants permission to update the permissions mode on a ledger.

        Access Level: Write

        https://docs.aws.amazon.com/qldb/latest/developerguide/API_UpdateLedgerPermissionsMode.html

        :stability: experimental
        '''
        return typing.cast("Qldb", jsii.invoke(self, "toUpdateLedgerPermissionsMode", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1ccef00513824a3c4df9fee296ec0531a8913d4672e252f393b64f84ecccad05)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__69240f7fd8d6b079163a836df6b28f9efd9ddec0305e06ac9a20171e28f33627)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Quicksight(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Quicksight",
):
    '''(experimental) Statement provider for service `quicksight <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonquicksight.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `quicksight <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonquicksight.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="ifAllowedEmbeddingDomains")
    def if_allowed_embedding_domains(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Quicksight":
        '''(experimental) Filters access by the allowed embedding domains.

        https://docs.aws.amazon.com/quicksight/latest/user/embedded-dashboards-for-authenticated-users-step-1.html

        Applies to actions:

        - .toGenerateEmbedUrlForAnonymousUser()
        - .toGenerateEmbedUrlForRegisteredUser()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5e0c710756e3bf2b1ca44eb6d7d80ab03299bba6f18270f82772f384da601f80)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Quicksight", jsii.invoke(self, "ifAllowedEmbeddingDomains", [value, operator]))

    @jsii.member(jsii_name="ifDirectoryType")
    def if_directory_type(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Quicksight":
        '''(experimental) Filters access by the user management options.

        https://docs.aws.amazon.com/quicksight/latest/user/security-scp.html

        Applies to actions:

        - .toSubscribe()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__db2661f7c772db4be984fe4284e72b8b89556cc45e0c1083fdc07daeca27d853)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Quicksight", jsii.invoke(self, "ifDirectoryType", [value, operator]))

    @jsii.member(jsii_name="ifEdition")
    def if_edition(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Quicksight":
        '''(experimental) Filters access by the edition of QuickSight.

        https://docs.aws.amazon.com/quicksight/latest/user/security-scp.html

        Applies to actions:

        - .toSubscribe()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0f4a621f11bb21179e60b6b64885b190ac70d799bc8185d8d6cf87e0fcf3ffcd)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Quicksight", jsii.invoke(self, "ifEdition", [value, operator]))

    @jsii.member(jsii_name="ifIamArn")
    def if_iam_arn(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Quicksight":
        '''(experimental) Filters access by IAM user or role ARN.

        https://docs.aws.amazon.com/quicksight/latest/user/iam-actions.html

        Applies to actions:

        - .toRegisterUser()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__44159aa408ec26a402a18c7c525859af9dbc6aa81c94547c093f92000ea9de96)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Quicksight", jsii.invoke(self, "ifIamArn", [value, operator]))

    @jsii.member(jsii_name="ifSessionName")
    def if_session_name(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Quicksight":
        '''(experimental) Filters access by session name.

        https://docs.aws.amazon.com/quicksight/latest/user/iam-actions.html

        Applies to actions:

        - .toRegisterUser()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__14795a604d3b0ccb927167a36b61a3c81156be1ee754bd5be23e3694dbd0a8c9)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Quicksight", jsii.invoke(self, "ifSessionName", [value, operator]))

    @jsii.member(jsii_name="ifUserName")
    def if_user_name(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Quicksight":
        '''(experimental) Filters access by user name.

        https://docs.aws.amazon.com/quicksight/latest/user/iam-actions.html

        Applies to actions:

        - .toCreateGroupMembership()
        - .toDeleteGroupMembership()
        - .toDescribeGroupMembership()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e9709dcc769a166fd093a1b255c8963a5fc195c702cc40ec3ba9ad88c1d21864)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Quicksight", jsii.invoke(self, "ifUserName", [value, operator]))

    @jsii.member(jsii_name="onAccount")
    def on_account(
        self,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Quicksight":
        '''(experimental) Adds a resource of type account to the statement.

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_AccountInfo.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bb41b4f8581e81474d7e2daadfac4f50b65fad3dd12f80b41c8d25a54d0d3b7e)
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Quicksight", jsii.invoke(self, "onAccount", [resource_id, account, region, partition]))

    @jsii.member(jsii_name="onAnalysis")
    def on_analysis(
        self,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Quicksight":
        '''(experimental) Adds a resource of type analysis to the statement.

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_Analysis.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__957d75e003b4b5bf3829c2d0c82275863b15387ac179ac2df753414e26430f0d)
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Quicksight", jsii.invoke(self, "onAnalysis", [resource_id, account, region, partition]))

    @jsii.member(jsii_name="onAssignment")
    def on_assignment(
        self,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Quicksight":
        '''(experimental) Adds a resource of type assignment to the statement.

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_IAMPolicyAssignment.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1350e0ebc15b8fc9495bee2deef13f5fd8b2e7344833b17161cbdaa5d85939ba)
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Quicksight", jsii.invoke(self, "onAssignment", [resource_id, account, partition]))

    @jsii.member(jsii_name="onCustomization")
    def on_customization(
        self,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Quicksight":
        '''(experimental) Adds a resource of type customization to the statement.

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_AccountCustomization.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__33c08c2da8209e9d8a9504cd2ea593bf28c3c5aa15bea88b79758ead38680184)
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Quicksight", jsii.invoke(self, "onCustomization", [resource_id, account, region, partition]))

    @jsii.member(jsii_name="onDashboard")
    def on_dashboard(
        self,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Quicksight":
        '''(experimental) Adds a resource of type dashboard to the statement.

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_Dashboard.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__84ec0a9917d324ea3cd842f28fd5dd04a75a189fd0d56909f5ba169194c0626d)
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Quicksight", jsii.invoke(self, "onDashboard", [resource_id, account, region, partition]))

    @jsii.member(jsii_name="onDataset")
    def on_dataset(
        self,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Quicksight":
        '''(experimental) Adds a resource of type dataset to the statement.

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_DataSet.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8db0720b3b947dcd3e602e18d0def15b54422b06586ba77ca9046724f29f93fb)
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Quicksight", jsii.invoke(self, "onDataset", [resource_id, account, region, partition]))

    @jsii.member(jsii_name="onDatasource")
    def on_datasource(
        self,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Quicksight":
        '''(experimental) Adds a resource of type datasource to the statement.

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_DataSource.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__43e087be1e1589de610a19aa12ef6378ce302d49d22caa94b6feb33294a4a826)
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Quicksight", jsii.invoke(self, "onDatasource", [resource_id, account, region, partition]))

    @jsii.member(jsii_name="onEmailCustomizationTemplate")
    def on_email_customization_template(
        self,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Quicksight":
        '''(experimental) Adds a resource of type emailCustomizationTemplate to the statement.

        https://docs.aws.amazon.com/quicksight/latest/user/customizing-quicksight-email-templates.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9ed14425ec6b1ee8dc4b901398ba6663ffc67b46d3ca8e6ecf8b70e344b28c29)
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Quicksight", jsii.invoke(self, "onEmailCustomizationTemplate", [resource_id, account, region, partition]))

    @jsii.member(jsii_name="onFolder")
    def on_folder(
        self,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Quicksight":
        '''(experimental) Adds a resource of type folder to the statement.

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_Folder.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__306701a65ed65af18d94fbf36932eaa53fe003890d20a5027842a45617f51f08)
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Quicksight", jsii.invoke(self, "onFolder", [resource_id, account, region, partition]))

    @jsii.member(jsii_name="onGroup")
    def on_group(
        self,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Quicksight":
        '''(experimental) Adds a resource of type group to the statement.

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_Group.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3d1c0a94e524114e63a705f01751d70c7f60c6f7b621d1557c84e2572af05282)
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Quicksight", jsii.invoke(self, "onGroup", [resource_id, account, region, partition]))

    @jsii.member(jsii_name="onIngestion")
    def on_ingestion(
        self,
        dataset_id: builtins.str,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Quicksight":
        '''(experimental) Adds a resource of type ingestion to the statement.

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_Ingestion.html

        :param dataset_id: - Identifier for the datasetId.
        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1fff74d1d768b23282f9c12b3fac57d207c1d10b5afd42b8a19a950da3719b93)
            check_type(argname="argument dataset_id", value=dataset_id, expected_type=type_hints["dataset_id"])
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Quicksight", jsii.invoke(self, "onIngestion", [dataset_id, resource_id, account, region, partition]))

    @jsii.member(jsii_name="onNamespace")
    def on_namespace(
        self,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Quicksight":
        '''(experimental) Adds a resource of type namespace to the statement.

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_NamespaceInfoV2.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__904a18163bac938bf761856c867da18d24e4122954a4f9a3c90cc0dd307d3b55)
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Quicksight", jsii.invoke(self, "onNamespace", [resource_id, account, region, partition]))

    @jsii.member(jsii_name="onTemplate")
    def on_template(
        self,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Quicksight":
        '''(experimental) Adds a resource of type template to the statement.

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_Template.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0088b86f4f1e5e3d72affd4e3d67f9eeb53768221c2cff1995e2cb0f2f4be06c)
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Quicksight", jsii.invoke(self, "onTemplate", [resource_id, account, region, partition]))

    @jsii.member(jsii_name="onTheme")
    def on_theme(
        self,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Quicksight":
        '''(experimental) Adds a resource of type theme to the statement.

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_Theme.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2fe9c5527c78ca4ce91627feee176bb0c7201290dfc851a6e669ab913db9595e)
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Quicksight", jsii.invoke(self, "onTheme", [resource_id, account, region, partition]))

    @jsii.member(jsii_name="onTopic")
    def on_topic(
        self,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Quicksight":
        '''(experimental) Adds a resource of type topic to the statement.

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_Topic.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e8f56174fa358b7046ea8c6fcfdc0732aff78792e2764d8ffd9e886713aef7ee)
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Quicksight", jsii.invoke(self, "onTopic", [resource_id, account, region, partition]))

    @jsii.member(jsii_name="onUser")
    def on_user(
        self,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Quicksight":
        '''(experimental) Adds a resource of type user to the statement.

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_User.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__463cb80b4449529b6638609f1e062d3eafb546a22c023ad53816e88ea5cf4b93)
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Quicksight", jsii.invoke(self, "onUser", [resource_id, account, region, partition]))

    @jsii.member(jsii_name="toAccountConfigurations")
    def to_account_configurations(self) -> "Quicksight":
        '''(experimental) Grants permission to enable setting default access to AWS resources.

        Access Level: Write

        https://docs.aws.amazon.com/quicksight/latest/user/accessing-data-sources.html

        :stability: experimental
        '''
        return typing.cast("Quicksight", jsii.invoke(self, "toAccountConfigurations", []))

    @jsii.member(jsii_name="toCancelIngestion")
    def to_cancel_ingestion(self) -> "Quicksight":
        '''(experimental) Grants permission to cancel a SPICE ingestions on a dataset.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_CancelIngestion.html

        :stability: experimental
        '''
        return typing.cast("Quicksight", jsii.invoke(self, "toCancelIngestion", []))

    @jsii.member(jsii_name="toCreateAccountCustomization")
    def to_create_account_customization(self) -> "Quicksight":
        '''(experimental) Grants permission to create an account customization for QuickSight account or namespace.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_CreateAccountCustomization.html

        :stability: experimental
        '''
        return typing.cast("Quicksight", jsii.invoke(self, "toCreateAccountCustomization", []))

    @jsii.member(jsii_name="toCreateAccountSubscription")
    def to_create_account_subscription(self) -> "Quicksight":
        '''(experimental) Grants permission to subscribe to QuickSight.

        Access Level: Write

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_CreateAccountSubscription.html

        :stability: experimental
        '''
        return typing.cast("Quicksight", jsii.invoke(self, "toCreateAccountSubscription", []))

    @jsii.member(jsii_name="toCreateAdmin")
    def to_create_admin(self) -> "Quicksight":
        '''(experimental) Grants permission to provision Amazon QuickSight administrators, authors, and readers.

        Access Level: Write

        https://docs.aws.amazon.com/quicksight/latest/user/iam-actions.html

        :stability: experimental
        '''
        return typing.cast("Quicksight", jsii.invoke(self, "toCreateAdmin", []))

    @jsii.member(jsii_name="toCreateAnalysis")
    def to_create_analysis(self) -> "Quicksight":
        '''(experimental) Grants permission to create an analysis from a template.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_CreateAnalysis.html

        :stability: experimental
        '''
        return typing.cast("Quicksight", jsii.invoke(self, "toCreateAnalysis", []))

    @jsii.member(jsii_name="toCreateCustomPermissions")
    def to_create_custom_permissions(self) -> "Quicksight":
        '''(experimental) Grants permission to create a custom permissions resource for restricting user access.

        Access Level: Permissions management

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/quicksight/latest/user/iam-actions.html

        :stability: experimental
        '''
        return typing.cast("Quicksight", jsii.invoke(self, "toCreateCustomPermissions", []))

    @jsii.member(jsii_name="toCreateDashboard")
    def to_create_dashboard(self) -> "Quicksight":
        '''(experimental) Grants permission to create a QuickSight Dashboard.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_CreateDashboard.html

        :stability: experimental
        '''
        return typing.cast("Quicksight", jsii.invoke(self, "toCreateDashboard", []))

    @jsii.member(jsii_name="toCreateDataSet")
    def to_create_data_set(self) -> "Quicksight":
        '''(experimental) Grants permission to create a dataset.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - quicksight:PassDataSource

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_CreateDataSet.html

        :stability: experimental
        '''
        return typing.cast("Quicksight", jsii.invoke(self, "toCreateDataSet", []))

    @jsii.member(jsii_name="toCreateDataSource")
    def to_create_data_source(self) -> "Quicksight":
        '''(experimental) Grants permission to create a data source.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_CreateDataSource.html

        :stability: experimental
        '''
        return typing.cast("Quicksight", jsii.invoke(self, "toCreateDataSource", []))

    @jsii.member(jsii_name="toCreateEmailCustomizationTemplate")
    def to_create_email_customization_template(self) -> "Quicksight":
        '''(experimental) Grants permission to create a QuickSight email customization template.

        Access Level: Write

        https://docs.aws.amazon.com/quicksight/latest/user/customizing-quicksight-email-templates.html

        :stability: experimental
        '''
        return typing.cast("Quicksight", jsii.invoke(self, "toCreateEmailCustomizationTemplate", []))

    @jsii.member(jsii_name="toCreateFolder")
    def to_create_folder(self) -> "Quicksight":
        '''(experimental) Grants permission to create a QuickSight folder.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_CreateFolder.html

        :stability: experimental
        '''
        return typing.cast("Quicksight", jsii.invoke(self, "toCreateFolder", []))

    @jsii.member(jsii_name="toCreateFolderMembership")
    def to_create_folder_membership(self) -> "Quicksight":
        '''(experimental) Grants permission to add a QuickSight Dashboard, Analysis or Dataset to a QuickSight Folder.

        Access Level: Write

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_CreateFolderMembership.html

        :stability: experimental
        '''
        return typing.cast("Quicksight", jsii.invoke(self, "toCreateFolderMembership", []))

    @jsii.member(jsii_name="toCreateGroup")
    def to_create_group(self) -> "Quicksight":
        '''(experimental) Grants permission to create a QuickSight group.

        Access Level: Write

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_CreateGroup.html

        :stability: experimental
        '''
        return typing.cast("Quicksight", jsii.invoke(self, "toCreateGroup", []))

    @jsii.member(jsii_name="toCreateGroupMembership")
    def to_create_group_membership(self) -> "Quicksight":
        '''(experimental) Grants permission to add a QuickSight user to a QuickSight group.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_CreateGroupMembership.html

        :stability: experimental
        '''
        return typing.cast("Quicksight", jsii.invoke(self, "toCreateGroupMembership", []))

    @jsii.member(jsii_name="toCreateIAMPolicyAssignment")
    def to_create_iam_policy_assignment(self) -> "Quicksight":
        '''(experimental) Grants permission to create an assignment with one specified IAM Policy ARN that will be assigned to specified groups or users of QuickSight.

        Access Level: Write

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_CreateIAMPolicyAssignment.html

        :stability: experimental
        '''
        return typing.cast("Quicksight", jsii.invoke(self, "toCreateIAMPolicyAssignment", []))

    @jsii.member(jsii_name="toCreateIngestion")
    def to_create_ingestion(self) -> "Quicksight":
        '''(experimental) Grants permission to start a SPICE ingestion on a dataset.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_CreateIngestion.html

        :stability: experimental
        '''
        return typing.cast("Quicksight", jsii.invoke(self, "toCreateIngestion", []))

    @jsii.member(jsii_name="toCreateNamespace")
    def to_create_namespace(self) -> "Quicksight":
        '''(experimental) Grants permission to create an QuickSight namespace.

        Access Level: Write

        Dependent actions:

        - ds:CreateIdentityPoolDirectory

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_CreateNamespace.html

        :stability: experimental
        '''
        return typing.cast("Quicksight", jsii.invoke(self, "toCreateNamespace", []))

    @jsii.member(jsii_name="toCreateReader")
    def to_create_reader(self) -> "Quicksight":
        '''(experimental) Grants permission to provision Amazon QuickSight readers.

        Access Level: Write

        https://docs.aws.amazon.com/quicksight/latest/user/iam-actions.html

        :stability: experimental
        '''
        return typing.cast("Quicksight", jsii.invoke(self, "toCreateReader", []))

    @jsii.member(jsii_name="toCreateTemplate")
    def to_create_template(self) -> "Quicksight":
        '''(experimental) Grants permission to create a template.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_CreateTemplate.html

        :stability: experimental
        '''
        return typing.cast("Quicksight", jsii.invoke(self, "toCreateTemplate", []))

    @jsii.member(jsii_name="toCreateTemplateAlias")
    def to_create_template_alias(self) -> "Quicksight":
        '''(experimental) Grants permission to create a template alias.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_CreateTemplateAlias.html

        :stability: experimental
        '''
        return typing.cast("Quicksight", jsii.invoke(self, "toCreateTemplateAlias", []))

    @jsii.member(jsii_name="toCreateTheme")
    def to_create_theme(self) -> "Quicksight":
        '''(experimental) Grants permission to create a theme.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_CreateTheme.html

        :stability: experimental
        '''
        return typing.cast("Quicksight", jsii.invoke(self, "toCreateTheme", []))

    @jsii.member(jsii_name="toCreateThemeAlias")
    def to_create_theme_alias(self) -> "Quicksight":
        '''(experimental) Grants permission to create an alias for a theme version.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_CreateThemeAlias.html

        :stability: experimental
        '''
        return typing.cast("Quicksight", jsii.invoke(self, "toCreateThemeAlias", []))

    @jsii.member(jsii_name="toCreateUser")
    def to_create_user(self) -> "Quicksight":
        '''(experimental) Grants permission to provision Amazon QuickSight authors and readers.

        Access Level: Write

        https://docs.aws.amazon.com/quicksight/latest/user/iam-actions.html

        :stability: experimental
        '''
        return typing.cast("Quicksight", jsii.invoke(self, "toCreateUser", []))

    @jsii.member(jsii_name="toCreateVPCConnection")
    def to_create_vpc_connection(self) -> "Quicksight":
        '''(experimental) Grants permission to create a VPC connection.

        Access Level: Write

        https://docs.aws.amazon.com/quicksight/latest/user/vpc-creating-a-connection-in-quicksight.html

        :stability: experimental
        '''
        return typing.cast("Quicksight", jsii.invoke(self, "toCreateVPCConnection", []))

    @jsii.member(jsii_name="toDeleteAccountCustomization")
    def to_delete_account_customization(self) -> "Quicksight":
        '''(experimental) Grants permission to delete an account customization for QuickSight account or namespace.

        Access Level: Write

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_DeleteAccountCustomization.html

        :stability: experimental
        '''
        return typing.cast("Quicksight", jsii.invoke(self, "toDeleteAccountCustomization", []))

    @jsii.member(jsii_name="toDeleteAccountSubscription")
    def to_delete_account_subscription(self) -> "Quicksight":
        '''(experimental) Grants permission to delete a QuickSight account.

        Access Level: Write

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_DeleteAccountSubscription.html

        :stability: experimental
        '''
        return typing.cast("Quicksight", jsii.invoke(self, "toDeleteAccountSubscription", []))

    @jsii.member(jsii_name="toDeleteAnalysis")
    def to_delete_analysis(self) -> "Quicksight":
        '''(experimental) Grants permission to delete an analysis.

        Access Level: Write

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_DeleteAnalysis.html

        :stability: experimental
        '''
        return typing.cast("Quicksight", jsii.invoke(self, "toDeleteAnalysis", []))

    @jsii.member(jsii_name="toDeleteCustomPermissions")
    def to_delete_custom_permissions(self) -> "Quicksight":
        '''(experimental) Grants permission to delete a custom permissions resource.

        Access Level: Permissions management

        https://docs.aws.amazon.com/quicksight/latest/user/iam-actions.html

        :stability: experimental
        '''
        return typing.cast("Quicksight", jsii.invoke(self, "toDeleteCustomPermissions", []))

    @jsii.member(jsii_name="toDeleteDashboard")
    def to_delete_dashboard(self) -> "Quicksight":
        '''(experimental) Grants permission to delete a QuickSight Dashboard.

        Access Level: Write

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_DeleteDashboard.html

        :stability: experimental
        '''
        return typing.cast("Quicksight", jsii.invoke(self, "toDeleteDashboard", []))

    @jsii.member(jsii_name="toDeleteDataSet")
    def to_delete_data_set(self) -> "Quicksight":
        '''(experimental) Grants permission to delete a dataset.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_DeleteDataSet.html

        :stability: experimental
        '''
        return typing.cast("Quicksight", jsii.invoke(self, "toDeleteDataSet", []))

    @jsii.member(jsii_name="toDeleteDataSource")
    def to_delete_data_source(self) -> "Quicksight":
        '''(experimental) Grants permission to delete a data source.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_DeleteDataSource.html

        :stability: experimental
        '''
        return typing.cast("Quicksight", jsii.invoke(self, "toDeleteDataSource", []))

    @jsii.member(jsii_name="toDeleteEmailCustomizationTemplate")
    def to_delete_email_customization_template(self) -> "Quicksight":
        '''(experimental) Grants permission to delete a QuickSight email customization template.

        Access Level: Write

        https://docs.aws.amazon.com/quicksight/latest/user/customizing-quicksight-email-templates.html

        :stability: experimental
        '''
        return typing.cast("Quicksight", jsii.invoke(self, "toDeleteEmailCustomizationTemplate", []))

    @jsii.member(jsii_name="toDeleteFolder")
    def to_delete_folder(self) -> "Quicksight":
        '''(experimental) Grants permission to delete a QuickSight Folder.

        Access Level: Write

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_DeleteFolder.html

        :stability: experimental
        '''
        return typing.cast("Quicksight", jsii.invoke(self, "toDeleteFolder", []))

    @jsii.member(jsii_name="toDeleteFolderMembership")
    def to_delete_folder_membership(self) -> "Quicksight":
        '''(experimental) Grants permission to remove a QuickSight Dashboard, Analysis or Dataset from a QuickSight Folder.

        Access Level: Write

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_DeleteFolderMembership.html

        :stability: experimental
        '''
        return typing.cast("Quicksight", jsii.invoke(self, "toDeleteFolderMembership", []))

    @jsii.member(jsii_name="toDeleteGroup")
    def to_delete_group(self) -> "Quicksight":
        '''(experimental) Grants permission to remove a user group from QuickSight.

        Access Level: Write

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_DeleteGroup.html

        :stability: experimental
        '''
        return typing.cast("Quicksight", jsii.invoke(self, "toDeleteGroup", []))

    @jsii.member(jsii_name="toDeleteGroupMembership")
    def to_delete_group_membership(self) -> "Quicksight":
        '''(experimental) Grants permission to remove a user from a group so that he/she is no longer a member of the group.

        Access Level: Write

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_DeleteGroupMembership.html

        :stability: experimental
        '''
        return typing.cast("Quicksight", jsii.invoke(self, "toDeleteGroupMembership", []))

    @jsii.member(jsii_name="toDeleteIAMPolicyAssignment")
    def to_delete_iam_policy_assignment(self) -> "Quicksight":
        '''(experimental) Grants permission to update an existing assignment.

        Access Level: Write

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_DeleteIAMPolicyAssignment.html

        :stability: experimental
        '''
        return typing.cast("Quicksight", jsii.invoke(self, "toDeleteIAMPolicyAssignment", []))

    @jsii.member(jsii_name="toDeleteNamespace")
    def to_delete_namespace(self) -> "Quicksight":
        '''(experimental) Grants permission to delete a QuickSight namespace.

        Access Level: Write

        Dependent actions:

        - ds:DeleteDirectory

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_DeleteNamespace.html

        :stability: experimental
        '''
        return typing.cast("Quicksight", jsii.invoke(self, "toDeleteNamespace", []))

    @jsii.member(jsii_name="toDeleteTemplate")
    def to_delete_template(self) -> "Quicksight":
        '''(experimental) Grants permission to delete a template.

        Access Level: Write

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_DeleteTemplate.html

        :stability: experimental
        '''
        return typing.cast("Quicksight", jsii.invoke(self, "toDeleteTemplate", []))

    @jsii.member(jsii_name="toDeleteTemplateAlias")
    def to_delete_template_alias(self) -> "Quicksight":
        '''(experimental) Grants permission to delete a template alias.

        Access Level: Write

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_DeleteTemplateAlias.html

        :stability: experimental
        '''
        return typing.cast("Quicksight", jsii.invoke(self, "toDeleteTemplateAlias", []))

    @jsii.member(jsii_name="toDeleteTheme")
    def to_delete_theme(self) -> "Quicksight":
        '''(experimental) Grants permission to delete a theme.

        Access Level: Write

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_DeleteTheme.html

        :stability: experimental
        '''
        return typing.cast("Quicksight", jsii.invoke(self, "toDeleteTheme", []))

    @jsii.member(jsii_name="toDeleteThemeAlias")
    def to_delete_theme_alias(self) -> "Quicksight":
        '''(experimental) Grants permission to delete the alias of a theme.

        Access Level: Write

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_DeleteThemeAlias.html

        :stability: experimental
        '''
        return typing.cast("Quicksight", jsii.invoke(self, "toDeleteThemeAlias", []))

    @jsii.member(jsii_name="toDeleteUser")
    def to_delete_user(self) -> "Quicksight":
        '''(experimental) Grants permission to delete a QuickSight user, given the user name.

        Access Level: Write

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_DeleteUser.html

        :stability: experimental
        '''
        return typing.cast("Quicksight", jsii.invoke(self, "toDeleteUser", []))

    @jsii.member(jsii_name="toDeleteUserByPrincipalId")
    def to_delete_user_by_principal_id(self) -> "Quicksight":
        '''(experimental) Grants permission to deletes a user identified by its principal ID.

        Access Level: Write

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_DeleteUserByPrincipalId.html

        :stability: experimental
        '''
        return typing.cast("Quicksight", jsii.invoke(self, "toDeleteUserByPrincipalId", []))

    @jsii.member(jsii_name="toDeleteVPCConnection")
    def to_delete_vpc_connection(self) -> "Quicksight":
        '''(experimental) Grants permission to delete a VPC connection.

        Access Level: Write

        https://docs.aws.amazon.com/quicksight/latest/user/vpc-creating-a-connection-in-quicksight.html

        :stability: experimental
        '''
        return typing.cast("Quicksight", jsii.invoke(self, "toDeleteVPCConnection", []))

    @jsii.member(jsii_name="toDescribeAccountCustomization")
    def to_describe_account_customization(self) -> "Quicksight":
        '''(experimental) Grants permission to describe an account customization for QuickSight account or namespace.

        Access Level: Read

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_DescribeAccountCustomization.html

        :stability: experimental
        '''
        return typing.cast("Quicksight", jsii.invoke(self, "toDescribeAccountCustomization", []))

    @jsii.member(jsii_name="toDescribeAccountSettings")
    def to_describe_account_settings(self) -> "Quicksight":
        '''(experimental) Grants permission to describe the administrative account settings for QuickSight account.

        Access Level: Read

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_DescribeAccountSettings.html

        :stability: experimental
        '''
        return typing.cast("Quicksight", jsii.invoke(self, "toDescribeAccountSettings", []))

    @jsii.member(jsii_name="toDescribeAccountSubscription")
    def to_describe_account_subscription(self) -> "Quicksight":
        '''(experimental) Grants permission to describe a QuickSight account.

        Access Level: Read

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_DescribeAccountSubscription.html

        :stability: experimental
        '''
        return typing.cast("Quicksight", jsii.invoke(self, "toDescribeAccountSubscription", []))

    @jsii.member(jsii_name="toDescribeAnalysis")
    def to_describe_analysis(self) -> "Quicksight":
        '''(experimental) Grants permission to describe an analysis.

        Access Level: Read

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_DescribeAnalysis.html

        :stability: experimental
        '''
        return typing.cast("Quicksight", jsii.invoke(self, "toDescribeAnalysis", []))

    @jsii.member(jsii_name="toDescribeAnalysisPermissions")
    def to_describe_analysis_permissions(self) -> "Quicksight":
        '''(experimental) Grants permission to describe permissions for an analysis.

        Access Level: Read

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_DescribeAnalysisPermissions.html

        :stability: experimental
        '''
        return typing.cast("Quicksight", jsii.invoke(self, "toDescribeAnalysisPermissions", []))

    @jsii.member(jsii_name="toDescribeCustomPermissions")
    def to_describe_custom_permissions(self) -> "Quicksight":
        '''(experimental) Grants permission to describe a custom permissions resource in a QuickSight account.

        Access Level: Write

        https://docs.aws.amazon.com/quicksight/latest/user/iam-actions.html

        :stability: experimental
        '''
        return typing.cast("Quicksight", jsii.invoke(self, "toDescribeCustomPermissions", []))

    @jsii.member(jsii_name="toDescribeDashboard")
    def to_describe_dashboard(self) -> "Quicksight":
        '''(experimental) Grants permission to describe a QuickSight Dashboard.

        Access Level: Read

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_DescribeDashboard.html

        :stability: experimental
        '''
        return typing.cast("Quicksight", jsii.invoke(self, "toDescribeDashboard", []))

    @jsii.member(jsii_name="toDescribeDashboardPermissions")
    def to_describe_dashboard_permissions(self) -> "Quicksight":
        '''(experimental) Grants permission to describe permissions for a QuickSight Dashboard.

        Access Level: Read

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_DescribeDashboardPermissions.html

        :stability: experimental
        '''
        return typing.cast("Quicksight", jsii.invoke(self, "toDescribeDashboardPermissions", []))

    @jsii.member(jsii_name="toDescribeDataSet")
    def to_describe_data_set(self) -> "Quicksight":
        '''(experimental) Grants permission to describe a dataset.

        Access Level: Read

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_DescribeDataSet.html

        :stability: experimental
        '''
        return typing.cast("Quicksight", jsii.invoke(self, "toDescribeDataSet", []))

    @jsii.member(jsii_name="toDescribeDataSetPermissions")
    def to_describe_data_set_permissions(self) -> "Quicksight":
        '''(experimental) Grants permission to describe the resource policy of a dataset.

        Access Level: Permissions management

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_DescribeDataSetPermissions.html

        :stability: experimental
        '''
        return typing.cast("Quicksight", jsii.invoke(self, "toDescribeDataSetPermissions", []))

    @jsii.member(jsii_name="toDescribeDataSource")
    def to_describe_data_source(self) -> "Quicksight":
        '''(experimental) Grants permission to describe a data source.

        Access Level: Read

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_DescribeDataSource.html

        :stability: experimental
        '''
        return typing.cast("Quicksight", jsii.invoke(self, "toDescribeDataSource", []))

    @jsii.member(jsii_name="toDescribeDataSourcePermissions")
    def to_describe_data_source_permissions(self) -> "Quicksight":
        '''(experimental) Grants permission to describe the resource policy of a data source.

        Access Level: Permissions management

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_DescribeDataSourcePermissions.html

        :stability: experimental
        '''
        return typing.cast("Quicksight", jsii.invoke(self, "toDescribeDataSourcePermissions", []))

    @jsii.member(jsii_name="toDescribeEmailCustomizationTemplate")
    def to_describe_email_customization_template(self) -> "Quicksight":
        '''(experimental) Grants permission to describe a QuickSight email customization template.

        Access Level: Read

        https://docs.aws.amazon.com/quicksight/latest/user/customizing-quicksight-email-templates.html

        :stability: experimental
        '''
        return typing.cast("Quicksight", jsii.invoke(self, "toDescribeEmailCustomizationTemplate", []))

    @jsii.member(jsii_name="toDescribeFolder")
    def to_describe_folder(self) -> "Quicksight":
        '''(experimental) Grants permission to describe a QuickSight Folder.

        Access Level: Read

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_DescribeFolder.html

        :stability: experimental
        '''
        return typing.cast("Quicksight", jsii.invoke(self, "toDescribeFolder", []))

    @jsii.member(jsii_name="toDescribeFolderPermissions")
    def to_describe_folder_permissions(self) -> "Quicksight":
        '''(experimental) Grants permission to describe permissions for a QuickSight Folder.

        Access Level: Read

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_DescribeFolderPermissions.html

        :stability: experimental
        '''
        return typing.cast("Quicksight", jsii.invoke(self, "toDescribeFolderPermissions", []))

    @jsii.member(jsii_name="toDescribeFolderResolvedPermissions")
    def to_describe_folder_resolved_permissions(self) -> "Quicksight":
        '''(experimental) Grants permission to describe resolved permissions for a QuickSight Folder.

        Access Level: Read

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_DescribeFolderResolvedPermissions.html

        :stability: experimental
        '''
        return typing.cast("Quicksight", jsii.invoke(self, "toDescribeFolderResolvedPermissions", []))

    @jsii.member(jsii_name="toDescribeGroup")
    def to_describe_group(self) -> "Quicksight":
        '''(experimental) Grants permission to describe a QuickSight group.

        Access Level: Read

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_DescribeGroup.html

        :stability: experimental
        '''
        return typing.cast("Quicksight", jsii.invoke(self, "toDescribeGroup", []))

    @jsii.member(jsii_name="toDescribeGroupMembership")
    def to_describe_group_membership(self) -> "Quicksight":
        '''(experimental) Grants permission to describe a QuickSight group member.

        Access Level: Read

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_DescribeGroupMembership.html

        :stability: experimental
        '''
        return typing.cast("Quicksight", jsii.invoke(self, "toDescribeGroupMembership", []))

    @jsii.member(jsii_name="toDescribeIAMPolicyAssignment")
    def to_describe_iam_policy_assignment(self) -> "Quicksight":
        '''(experimental) Grants permission to describe an existing assignment.

        Access Level: Read

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_DescribeIAMPolicyAssignment.html

        :stability: experimental
        '''
        return typing.cast("Quicksight", jsii.invoke(self, "toDescribeIAMPolicyAssignment", []))

    @jsii.member(jsii_name="toDescribeIngestion")
    def to_describe_ingestion(self) -> "Quicksight":
        '''(experimental) Grants permission to describe a SPICE ingestion on a dataset.

        Access Level: Read

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_DescribeIngestion.html

        :stability: experimental
        '''
        return typing.cast("Quicksight", jsii.invoke(self, "toDescribeIngestion", []))

    @jsii.member(jsii_name="toDescribeIpRestriction")
    def to_describe_ip_restriction(self) -> "Quicksight":
        '''(experimental) Grants permission to describe the IP restrictions for QuickSight account.

        Access Level: Read

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_DescribeIpRestriction.html

        :stability: experimental
        '''
        return typing.cast("Quicksight", jsii.invoke(self, "toDescribeIpRestriction", []))

    @jsii.member(jsii_name="toDescribeNamespace")
    def to_describe_namespace(self) -> "Quicksight":
        '''(experimental) Grants permission to describe a QuickSight namespace.

        Access Level: Read

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_DescribeNamespace.html

        :stability: experimental
        '''
        return typing.cast("Quicksight", jsii.invoke(self, "toDescribeNamespace", []))

    @jsii.member(jsii_name="toDescribeTemplate")
    def to_describe_template(self) -> "Quicksight":
        '''(experimental) Grants permission to describe a template.

        Access Level: Read

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_DescribeTemplate.html

        :stability: experimental
        '''
        return typing.cast("Quicksight", jsii.invoke(self, "toDescribeTemplate", []))

    @jsii.member(jsii_name="toDescribeTemplateAlias")
    def to_describe_template_alias(self) -> "Quicksight":
        '''(experimental) Grants permission to describe a template alias.

        Access Level: Read

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_DescribeTemplateAlias.html

        :stability: experimental
        '''
        return typing.cast("Quicksight", jsii.invoke(self, "toDescribeTemplateAlias", []))

    @jsii.member(jsii_name="toDescribeTemplatePermissions")
    def to_describe_template_permissions(self) -> "Quicksight":
        '''(experimental) Grants permission to describe permissions for a template.

        Access Level: Read

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_DescribeTemplatePermissions.html

        :stability: experimental
        '''
        return typing.cast("Quicksight", jsii.invoke(self, "toDescribeTemplatePermissions", []))

    @jsii.member(jsii_name="toDescribeTheme")
    def to_describe_theme(self) -> "Quicksight":
        '''(experimental) Grants permission to describe a theme.

        Access Level: Read

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_DescribeTheme.html

        :stability: experimental
        '''
        return typing.cast("Quicksight", jsii.invoke(self, "toDescribeTheme", []))

    @jsii.member(jsii_name="toDescribeThemeAlias")
    def to_describe_theme_alias(self) -> "Quicksight":
        '''(experimental) Grants permission to describe a theme alias.

        Access Level: Read

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_DescribeThemeAlias.html

        :stability: experimental
        '''
        return typing.cast("Quicksight", jsii.invoke(self, "toDescribeThemeAlias", []))

    @jsii.member(jsii_name="toDescribeThemePermissions")
    def to_describe_theme_permissions(self) -> "Quicksight":
        '''(experimental) Grants permission to describe permissions for a theme.

        Access Level: Read

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_DescribeThemePermissions.html

        :stability: experimental
        '''
        return typing.cast("Quicksight", jsii.invoke(self, "toDescribeThemePermissions", []))

    @jsii.member(jsii_name="toDescribeUser")
    def to_describe_user(self) -> "Quicksight":
        '''(experimental) Grants permission to describe a QuickSight user given the user name.

        Access Level: Read

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_DescribeUser.html

        :stability: experimental
        '''
        return typing.cast("Quicksight", jsii.invoke(self, "toDescribeUser", []))

    @jsii.member(jsii_name="toGenerateEmbedUrlForAnonymousUser")
    def to_generate_embed_url_for_anonymous_user(self) -> "Quicksight":
        '''(experimental) Grants permission to generate a URL used to embed a QuickSight Dashboard or Q Topic for a user not registered with QuickSight.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()
        - .ifAllowedEmbeddingDomains()

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_GenerateEmbedUrlForAnonymousUser.html

        :stability: experimental
        '''
        return typing.cast("Quicksight", jsii.invoke(self, "toGenerateEmbedUrlForAnonymousUser", []))

    @jsii.member(jsii_name="toGenerateEmbedUrlForRegisteredUser")
    def to_generate_embed_url_for_registered_user(self) -> "Quicksight":
        '''(experimental) Grants permission to generate a URL used to embed a QuickSight Dashboard for a user registered with QuickSight.

        Access Level: Write

        Possible conditions:

        - .ifAllowedEmbeddingDomains()

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_GenerateEmbedUrlForRegisteredUser.html

        :stability: experimental
        '''
        return typing.cast("Quicksight", jsii.invoke(self, "toGenerateEmbedUrlForRegisteredUser", []))

    @jsii.member(jsii_name="toGetAnonymousUserEmbedUrl")
    def to_get_anonymous_user_embed_url(self) -> "Quicksight":
        '''(experimental) Grants permission to get a URL used to embed a QuickSight Dashboard for a user not registered with QuickSight.

        Access Level: Read

        https://docs.aws.amazon.com/quicksight/latest/user/iam-actions.html

        :stability: experimental
        '''
        return typing.cast("Quicksight", jsii.invoke(self, "toGetAnonymousUserEmbedUrl", []))

    @jsii.member(jsii_name="toGetAuthCode")
    def to_get_auth_code(self) -> "Quicksight":
        '''(experimental) Grants permission to get an auth code representing a QuickSight user.

        Access Level: Read

        https://docs.aws.amazon.com/quicksight/latest/user/iam-actions.html

        :stability: experimental
        '''
        return typing.cast("Quicksight", jsii.invoke(self, "toGetAuthCode", []))

    @jsii.member(jsii_name="toGetDashboardEmbedUrl")
    def to_get_dashboard_embed_url(self) -> "Quicksight":
        '''(experimental) Grants permission to get a URL used to embed a QuickSight Dashboard.

        Access Level: Read

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_GetDashboardEmbedUrl.html

        :stability: experimental
        '''
        return typing.cast("Quicksight", jsii.invoke(self, "toGetDashboardEmbedUrl", []))

    @jsii.member(jsii_name="toGetGroupMapping")
    def to_get_group_mapping(self) -> "Quicksight":
        '''(experimental) Grants permission to use Amazon QuickSight, in Enterprise edition, to identify and display the Microsoft Active Directory (Microsoft Active Directory) directory groups that are mapped to roles in Amazon QuickSight.

        Access Level: Read

        https://docs.aws.amazon.com/quicksight/latest/user/iam-actions.html

        :stability: experimental
        '''
        return typing.cast("Quicksight", jsii.invoke(self, "toGetGroupMapping", []))

    @jsii.member(jsii_name="toGetSessionEmbedUrl")
    def to_get_session_embed_url(self) -> "Quicksight":
        '''(experimental) Grants permission to get a URL to embed QuickSight console experience.

        Access Level: Read

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_GetSessionEmbedUrl.html

        :stability: experimental
        '''
        return typing.cast("Quicksight", jsii.invoke(self, "toGetSessionEmbedUrl", []))

    @jsii.member(jsii_name="toListAnalyses")
    def to_list_analyses(self) -> "Quicksight":
        '''(experimental) Grants permission to list all analyses in an account.

        Access Level: List

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_ListAnalyses.html

        :stability: experimental
        '''
        return typing.cast("Quicksight", jsii.invoke(self, "toListAnalyses", []))

    @jsii.member(jsii_name="toListCustomPermissions")
    def to_list_custom_permissions(self) -> "Quicksight":
        '''(experimental) Grants permission to list custom permissions resources in QuickSight account.

        Access Level: Write

        https://docs.aws.amazon.com/quicksight/latest/user/iam-actions.html

        :stability: experimental
        '''
        return typing.cast("Quicksight", jsii.invoke(self, "toListCustomPermissions", []))

    @jsii.member(jsii_name="toListDashboards")
    def to_list_dashboards(self) -> "Quicksight":
        '''(experimental) Grants permission to list all Dashboards in a QuickSight Account.

        Access Level: List

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_ListDashboards.html

        :stability: experimental
        '''
        return typing.cast("Quicksight", jsii.invoke(self, "toListDashboards", []))

    @jsii.member(jsii_name="toListDashboardVersions")
    def to_list_dashboard_versions(self) -> "Quicksight":
        '''(experimental) Grants permission to list all versions of a QuickSight Dashboard.

        Access Level: List

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_ListDashboardVersions.html

        :stability: experimental
        '''
        return typing.cast("Quicksight", jsii.invoke(self, "toListDashboardVersions", []))

    @jsii.member(jsii_name="toListDataSets")
    def to_list_data_sets(self) -> "Quicksight":
        '''(experimental) Grants permission to list all datasets.

        Access Level: List

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_ListDataSets.html

        :stability: experimental
        '''
        return typing.cast("Quicksight", jsii.invoke(self, "toListDataSets", []))

    @jsii.member(jsii_name="toListDataSources")
    def to_list_data_sources(self) -> "Quicksight":
        '''(experimental) Grants permission to list all data sources.

        Access Level: List

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_ListDataSources.html

        :stability: experimental
        '''
        return typing.cast("Quicksight", jsii.invoke(self, "toListDataSources", []))

    @jsii.member(jsii_name="toListFolderMembers")
    def to_list_folder_members(self) -> "Quicksight":
        '''(experimental) Grants permission to list all members in a folder.

        Access Level: Read

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_ListFolderMembers.html

        :stability: experimental
        '''
        return typing.cast("Quicksight", jsii.invoke(self, "toListFolderMembers", []))

    @jsii.member(jsii_name="toListFolders")
    def to_list_folders(self) -> "Quicksight":
        '''(experimental) Grants permission to list all Folders in a QuickSight Account.

        Access Level: List

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_ListFolders.html

        :stability: experimental
        '''
        return typing.cast("Quicksight", jsii.invoke(self, "toListFolders", []))

    @jsii.member(jsii_name="toListGroupMemberships")
    def to_list_group_memberships(self) -> "Quicksight":
        '''(experimental) Grants permission to list member users in a group.

        Access Level: List

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_ListGroupMemberships.html

        :stability: experimental
        '''
        return typing.cast("Quicksight", jsii.invoke(self, "toListGroupMemberships", []))

    @jsii.member(jsii_name="toListGroups")
    def to_list_groups(self) -> "Quicksight":
        '''(experimental) Grants permission to list all user groups in QuickSight.

        Access Level: List

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_ListGroups.html

        :stability: experimental
        '''
        return typing.cast("Quicksight", jsii.invoke(self, "toListGroups", []))

    @jsii.member(jsii_name="toListIAMPolicyAssignments")
    def to_list_iam_policy_assignments(self) -> "Quicksight":
        '''(experimental) Grants permission to list all assignments in the current Amazon QuickSight account.

        Access Level: List

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_ListIAMPolicyAssignments.html

        :stability: experimental
        '''
        return typing.cast("Quicksight", jsii.invoke(self, "toListIAMPolicyAssignments", []))

    @jsii.member(jsii_name="toListIAMPolicyAssignmentsForUser")
    def to_list_iam_policy_assignments_for_user(self) -> "Quicksight":
        '''(experimental) Grants permission to list all assignments assigned to a user and the groups it belongs.

        Access Level: List

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_ListIAMPolicyAssignmentsForUser.html

        :stability: experimental
        '''
        return typing.cast("Quicksight", jsii.invoke(self, "toListIAMPolicyAssignmentsForUser", []))

    @jsii.member(jsii_name="toListIngestions")
    def to_list_ingestions(self) -> "Quicksight":
        '''(experimental) Grants permission to list all SPICE ingestions on a dataset.

        Access Level: List

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_ListIngestions.html

        :stability: experimental
        '''
        return typing.cast("Quicksight", jsii.invoke(self, "toListIngestions", []))

    @jsii.member(jsii_name="toListNamespaces")
    def to_list_namespaces(self) -> "Quicksight":
        '''(experimental) Grants permission to lists all namespaces in a QuickSight account.

        Access Level: List

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_ListNamespaces.html

        :stability: experimental
        '''
        return typing.cast("Quicksight", jsii.invoke(self, "toListNamespaces", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Quicksight":
        '''(experimental) Grants permission to list tags of a QuickSight resource.

        Access Level: Read

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("Quicksight", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toListTemplateAliases")
    def to_list_template_aliases(self) -> "Quicksight":
        '''(experimental) Grants permission to list all aliases for a template.

        Access Level: List

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_ListTemplateAliases.html

        :stability: experimental
        '''
        return typing.cast("Quicksight", jsii.invoke(self, "toListTemplateAliases", []))

    @jsii.member(jsii_name="toListTemplates")
    def to_list_templates(self) -> "Quicksight":
        '''(experimental) Grants permission to list all templates in a QuickSight account.

        Access Level: List

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_ListTemplates.html

        :stability: experimental
        '''
        return typing.cast("Quicksight", jsii.invoke(self, "toListTemplates", []))

    @jsii.member(jsii_name="toListTemplateVersions")
    def to_list_template_versions(self) -> "Quicksight":
        '''(experimental) Grants permission to list all versions of a template.

        Access Level: List

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_ListTemplateVersions.html

        :stability: experimental
        '''
        return typing.cast("Quicksight", jsii.invoke(self, "toListTemplateVersions", []))

    @jsii.member(jsii_name="toListThemeAliases")
    def to_list_theme_aliases(self) -> "Quicksight":
        '''(experimental) Grants permission to list all aliases of a theme.

        Access Level: List

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_ListThemeAliases.html

        :stability: experimental
        '''
        return typing.cast("Quicksight", jsii.invoke(self, "toListThemeAliases", []))

    @jsii.member(jsii_name="toListThemes")
    def to_list_themes(self) -> "Quicksight":
        '''(experimental) Grants permission to list all themes in an account.

        Access Level: List

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_ListThemes.html

        :stability: experimental
        '''
        return typing.cast("Quicksight", jsii.invoke(self, "toListThemes", []))

    @jsii.member(jsii_name="toListThemeVersions")
    def to_list_theme_versions(self) -> "Quicksight":
        '''(experimental) Grants permission to list all versions of a theme.

        Access Level: List

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_ListThemeVersions.html

        :stability: experimental
        '''
        return typing.cast("Quicksight", jsii.invoke(self, "toListThemeVersions", []))

    @jsii.member(jsii_name="toListUserGroups")
    def to_list_user_groups(self) -> "Quicksight":
        '''(experimental) Grants permission to list groups that a given user is a member of.

        Access Level: List

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_ListUserGroups.html

        :stability: experimental
        '''
        return typing.cast("Quicksight", jsii.invoke(self, "toListUserGroups", []))

    @jsii.member(jsii_name="toListUsers")
    def to_list_users(self) -> "Quicksight":
        '''(experimental) Grants permission to list all of the QuickSight users belonging to this account.

        Access Level: List

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_ListUsers.html

        :stability: experimental
        '''
        return typing.cast("Quicksight", jsii.invoke(self, "toListUsers", []))

    @jsii.member(jsii_name="toPassDataSet")
    def to_pass_data_set(self) -> "Quicksight":
        '''(experimental) Grants permission to use a dataset for a template.

        Access Level: Read

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/quicksight/latest/APIReference/qs-api-overview.html

        :stability: experimental
        '''
        return typing.cast("Quicksight", jsii.invoke(self, "toPassDataSet", []))

    @jsii.member(jsii_name="toPassDataSource")
    def to_pass_data_source(self) -> "Quicksight":
        '''(experimental) Grants permission to use a data source for a data set.

        Access Level: Read

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/quicksight/latest/APIReference/qs-api-overview.html

        :stability: experimental
        '''
        return typing.cast("Quicksight", jsii.invoke(self, "toPassDataSource", []))

    @jsii.member(jsii_name="toRegisterUser")
    def to_register_user(self) -> "Quicksight":
        '''(experimental) Grants permission to create a QuickSight user, whose identity is associated with the IAM identity/role specified in the request.

        Access Level: Write

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_RegisterUser.html

        :stability: experimental
        '''
        return typing.cast("Quicksight", jsii.invoke(self, "toRegisterUser", []))

    @jsii.member(jsii_name="toRestoreAnalysis")
    def to_restore_analysis(self) -> "Quicksight":
        '''(experimental) Grants permission to restore a deleted analysis.

        Access Level: Write

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_RestoreAnalysis.html

        :stability: experimental
        '''
        return typing.cast("Quicksight", jsii.invoke(self, "toRestoreAnalysis", []))

    @jsii.member(jsii_name="toScopeDownPolicy")
    def to_scope_down_policy(self) -> "Quicksight":
        '''(experimental) Grants permission to manage scoping policies for permissions to AWS resources.

        Access Level: Write

        https://docs.aws.amazon.com/quicksight/latest/user/accessing-data-sources.html

        :stability: experimental
        '''
        return typing.cast("Quicksight", jsii.invoke(self, "toScopeDownPolicy", []))

    @jsii.member(jsii_name="toSearchAnalyses")
    def to_search_analyses(self) -> "Quicksight":
        '''(experimental) Grants permission to search for a sub-set of analyses.

        Access Level: List

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_SearchAnalyses.html

        :stability: experimental
        '''
        return typing.cast("Quicksight", jsii.invoke(self, "toSearchAnalyses", []))

    @jsii.member(jsii_name="toSearchDashboards")
    def to_search_dashboards(self) -> "Quicksight":
        '''(experimental) Grants permission to search for a sub-set of QuickSight Dashboards.

        Access Level: List

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_SearchDashboards.html

        :stability: experimental
        '''
        return typing.cast("Quicksight", jsii.invoke(self, "toSearchDashboards", []))

    @jsii.member(jsii_name="toSearchDataSets")
    def to_search_data_sets(self) -> "Quicksight":
        '''(experimental) Grants permission to search for a sub-set of QuickSight DatSets.

        Access Level: List

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_SearchDataSets.html

        :stability: experimental
        '''
        return typing.cast("Quicksight", jsii.invoke(self, "toSearchDataSets", []))

    @jsii.member(jsii_name="toSearchDataSources")
    def to_search_data_sources(self) -> "Quicksight":
        '''(experimental) Grants permission to search for a sub-set of QuickSight Data Sources.

        Access Level: List

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_SearchDataSources.html

        :stability: experimental
        '''
        return typing.cast("Quicksight", jsii.invoke(self, "toSearchDataSources", []))

    @jsii.member(jsii_name="toSearchDirectoryGroups")
    def to_search_directory_groups(self) -> "Quicksight":
        '''(experimental) Grants permission to use Amazon QuickSight, in Enterprise edition, to display your Microsoft Active Directory directory groups so that you can choose which ones to map to roles in Amazon QuickSight.

        Access Level: List

        https://docs.aws.amazon.com/quicksight/latest/user/iam-actions.html

        :stability: experimental
        '''
        return typing.cast("Quicksight", jsii.invoke(self, "toSearchDirectoryGroups", []))

    @jsii.member(jsii_name="toSearchFolders")
    def to_search_folders(self) -> "Quicksight":
        '''(experimental) Grants permission to search for a sub-set of QuickSight Folders.

        Access Level: Read

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_SearchFolders.html

        :stability: experimental
        '''
        return typing.cast("Quicksight", jsii.invoke(self, "toSearchFolders", []))

    @jsii.member(jsii_name="toSearchGroups")
    def to_search_groups(self) -> "Quicksight":
        '''(experimental) Grants permission to search for a sub-set of QuickSight groups.

        Access Level: List

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_SearchGroups.html

        :stability: experimental
        '''
        return typing.cast("Quicksight", jsii.invoke(self, "toSearchGroups", []))

    @jsii.member(jsii_name="toSetGroupMapping")
    def to_set_group_mapping(self) -> "Quicksight":
        '''(experimental) Grants permission to use Amazon QuickSight, in Enterprise edition, to display your Microsoft Active Directory directory groups so that you can choose which ones to map to roles in Amazon QuickSight.

        Access Level: Write

        https://docs.aws.amazon.com/quicksight/latest/user/iam-actions.html

        :stability: experimental
        '''
        return typing.cast("Quicksight", jsii.invoke(self, "toSetGroupMapping", []))

    @jsii.member(jsii_name="toSubscribe")
    def to_subscribe(self) -> "Quicksight":
        '''(experimental) Grants permission to subscribe to Amazon QuickSight, and also to allow the user to upgrade the subscription to Enterprise edition.

        Access Level: Write

        Possible conditions:

        - .ifEdition()
        - .ifDirectoryType()

        https://docs.aws.amazon.com/quicksight/latest/user/iam-actions.html

        :stability: experimental
        '''
        return typing.cast("Quicksight", jsii.invoke(self, "toSubscribe", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Quicksight":
        '''(experimental) Grants permission to add tags to a QuickSight resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("Quicksight", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUnsubscribe")
    def to_unsubscribe(self) -> "Quicksight":
        '''(experimental) Grants permission to unsubscribe from Amazon QuickSight, which permanently deletes all users and their resources from Amazon QuickSight.

        Access Level: Write

        https://docs.aws.amazon.com/quicksight/latest/user/iam-actions.html

        :stability: experimental
        '''
        return typing.cast("Quicksight", jsii.invoke(self, "toUnsubscribe", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Quicksight":
        '''(experimental) Grants permission to remove tags from a QuickSight resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("Quicksight", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateAccountCustomization")
    def to_update_account_customization(self) -> "Quicksight":
        '''(experimental) Grants permission to update an account customization for QuickSight account or namespace.

        Access Level: Write

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_UpdateAccountCustomization.html

        :stability: experimental
        '''
        return typing.cast("Quicksight", jsii.invoke(self, "toUpdateAccountCustomization", []))

    @jsii.member(jsii_name="toUpdateAccountSettings")
    def to_update_account_settings(self) -> "Quicksight":
        '''(experimental) Grants permission to update the administrative account settings for QuickSight account.

        Access Level: Write

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_UpdateAccountSettings.html

        :stability: experimental
        '''
        return typing.cast("Quicksight", jsii.invoke(self, "toUpdateAccountSettings", []))

    @jsii.member(jsii_name="toUpdateAnalysis")
    def to_update_analysis(self) -> "Quicksight":
        '''(experimental) Grants permission to update an analysis.

        Access Level: Write

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_UpdateAnalysis.html

        :stability: experimental
        '''
        return typing.cast("Quicksight", jsii.invoke(self, "toUpdateAnalysis", []))

    @jsii.member(jsii_name="toUpdateAnalysisPermissions")
    def to_update_analysis_permissions(self) -> "Quicksight":
        '''(experimental) Grants permission to update permissions for an analysis.

        Access Level: Permissions management

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_UpdateAnalysisPermissions.html

        :stability: experimental
        '''
        return typing.cast("Quicksight", jsii.invoke(self, "toUpdateAnalysisPermissions", []))

    @jsii.member(jsii_name="toUpdateCustomPermissions")
    def to_update_custom_permissions(self) -> "Quicksight":
        '''(experimental) Grants permission to update a custom permissions resource.

        Access Level: Permissions management

        https://docs.aws.amazon.com/quicksight/latest/user/iam-actions.html

        :stability: experimental
        '''
        return typing.cast("Quicksight", jsii.invoke(self, "toUpdateCustomPermissions", []))

    @jsii.member(jsii_name="toUpdateDashboard")
    def to_update_dashboard(self) -> "Quicksight":
        '''(experimental) Grants permission to update a QuickSight Dashboard.

        Access Level: Write

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_UpdateDashboard.html

        :stability: experimental
        '''
        return typing.cast("Quicksight", jsii.invoke(self, "toUpdateDashboard", []))

    @jsii.member(jsii_name="toUpdateDashboardPermissions")
    def to_update_dashboard_permissions(self) -> "Quicksight":
        '''(experimental) Grants permission to update permissions for a QuickSight Dashboard.

        Access Level: Permissions management

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_UpdateDashboardPermissions.html

        :stability: experimental
        '''
        return typing.cast("Quicksight", jsii.invoke(self, "toUpdateDashboardPermissions", []))

    @jsii.member(jsii_name="toUpdateDashboardPublishedVersion")
    def to_update_dashboard_published_version(self) -> "Quicksight":
        '''(experimental) Grants permission to update a QuickSight Dashboard’s Published Version.

        Access Level: Write

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_UpdateDashboardPublishedVersion.html

        :stability: experimental
        '''
        return typing.cast("Quicksight", jsii.invoke(self, "toUpdateDashboardPublishedVersion", []))

    @jsii.member(jsii_name="toUpdateDataSet")
    def to_update_data_set(self) -> "Quicksight":
        '''(experimental) Grants permission to update a dataset.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - quicksight:PassDataSource

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_UpdateDataSet.html

        :stability: experimental
        '''
        return typing.cast("Quicksight", jsii.invoke(self, "toUpdateDataSet", []))

    @jsii.member(jsii_name="toUpdateDataSetPermissions")
    def to_update_data_set_permissions(self) -> "Quicksight":
        '''(experimental) Grants permission to update the resource policy of a dataset.

        Access Level: Permissions management

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_UpdateDataSetPermissions.html

        :stability: experimental
        '''
        return typing.cast("Quicksight", jsii.invoke(self, "toUpdateDataSetPermissions", []))

    @jsii.member(jsii_name="toUpdateDataSource")
    def to_update_data_source(self) -> "Quicksight":
        '''(experimental) Grants permission to update a data source.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_UpdateDataSource.html

        :stability: experimental
        '''
        return typing.cast("Quicksight", jsii.invoke(self, "toUpdateDataSource", []))

    @jsii.member(jsii_name="toUpdateDataSourcePermissions")
    def to_update_data_source_permissions(self) -> "Quicksight":
        '''(experimental) Grants permission to update the resource policy of a data source.

        Access Level: Permissions management

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_UpdateDataSourcePermissions.html

        :stability: experimental
        '''
        return typing.cast("Quicksight", jsii.invoke(self, "toUpdateDataSourcePermissions", []))

    @jsii.member(jsii_name="toUpdateEmailCustomizationTemplate")
    def to_update_email_customization_template(self) -> "Quicksight":
        '''(experimental) Grants permission to update a QuickSight email customization template.

        Access Level: Write

        https://docs.aws.amazon.com/quicksight/latest/user/customizing-quicksight-email-templates.html

        :stability: experimental
        '''
        return typing.cast("Quicksight", jsii.invoke(self, "toUpdateEmailCustomizationTemplate", []))

    @jsii.member(jsii_name="toUpdateFolder")
    def to_update_folder(self) -> "Quicksight":
        '''(experimental) Grants permission to update a QuickSight Folder.

        Access Level: Write

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_UpdateFolder.html

        :stability: experimental
        '''
        return typing.cast("Quicksight", jsii.invoke(self, "toUpdateFolder", []))

    @jsii.member(jsii_name="toUpdateFolderPermissions")
    def to_update_folder_permissions(self) -> "Quicksight":
        '''(experimental) Grants permission to update permissions for a QuickSight Folder.

        Access Level: Permissions management

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_UpdateFolderPermissions.html

        :stability: experimental
        '''
        return typing.cast("Quicksight", jsii.invoke(self, "toUpdateFolderPermissions", []))

    @jsii.member(jsii_name="toUpdateGroup")
    def to_update_group(self) -> "Quicksight":
        '''(experimental) Grants permission to change group description.

        Access Level: Write

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_UpdateGroup.html

        :stability: experimental
        '''
        return typing.cast("Quicksight", jsii.invoke(self, "toUpdateGroup", []))

    @jsii.member(jsii_name="toUpdateIAMPolicyAssignment")
    def to_update_iam_policy_assignment(self) -> "Quicksight":
        '''(experimental) Grants permission to update an existing assignment.

        Access Level: Write

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_UpdateIAMPolicyAssignment.html

        :stability: experimental
        '''
        return typing.cast("Quicksight", jsii.invoke(self, "toUpdateIAMPolicyAssignment", []))

    @jsii.member(jsii_name="toUpdateIpRestriction")
    def to_update_ip_restriction(self) -> "Quicksight":
        '''(experimental) Grants permission to update the IP restrictions for QuickSight account.

        Access Level: Write

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_UpdateIpRestriction.html

        :stability: experimental
        '''
        return typing.cast("Quicksight", jsii.invoke(self, "toUpdateIpRestriction", []))

    @jsii.member(jsii_name="toUpdatePublicSharingSettings")
    def to_update_public_sharing_settings(self) -> "Quicksight":
        '''(experimental) Grants permission to enable or disable public sharing on an account.

        Access Level: Write

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_UpdatePublicSharingSettings.html

        :stability: experimental
        '''
        return typing.cast("Quicksight", jsii.invoke(self, "toUpdatePublicSharingSettings", []))

    @jsii.member(jsii_name="toUpdateResourcePermissions")
    def to_update_resource_permissions(self) -> "Quicksight":
        '''(experimental) Grants permission to update resource-level permissions in QuickSight.

        Access Level: Write

        https://docs.aws.amazon.com/quicksight/latest/user/security_iam_service-with-iam.html

        :stability: experimental
        '''
        return typing.cast("Quicksight", jsii.invoke(self, "toUpdateResourcePermissions", []))

    @jsii.member(jsii_name="toUpdateTemplate")
    def to_update_template(self) -> "Quicksight":
        '''(experimental) Grants permission to update a template.

        Access Level: Write

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_UpdateTemplate.html

        :stability: experimental
        '''
        return typing.cast("Quicksight", jsii.invoke(self, "toUpdateTemplate", []))

    @jsii.member(jsii_name="toUpdateTemplateAlias")
    def to_update_template_alias(self) -> "Quicksight":
        '''(experimental) Grants permission to update a template alias.

        Access Level: Write

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_UpdateTemplateAlias.html

        :stability: experimental
        '''
        return typing.cast("Quicksight", jsii.invoke(self, "toUpdateTemplateAlias", []))

    @jsii.member(jsii_name="toUpdateTemplatePermissions")
    def to_update_template_permissions(self) -> "Quicksight":
        '''(experimental) Grants permission to update permissions for a template.

        Access Level: Permissions management

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_UpdateTemplatePermissions.html

        :stability: experimental
        '''
        return typing.cast("Quicksight", jsii.invoke(self, "toUpdateTemplatePermissions", []))

    @jsii.member(jsii_name="toUpdateTheme")
    def to_update_theme(self) -> "Quicksight":
        '''(experimental) Grants permission to update a theme.

        Access Level: Write

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_UpdateTheme.html

        :stability: experimental
        '''
        return typing.cast("Quicksight", jsii.invoke(self, "toUpdateTheme", []))

    @jsii.member(jsii_name="toUpdateThemeAlias")
    def to_update_theme_alias(self) -> "Quicksight":
        '''(experimental) Grants permission to update the alias of a theme.

        Access Level: Write

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_UpdateThemeAlias.html

        :stability: experimental
        '''
        return typing.cast("Quicksight", jsii.invoke(self, "toUpdateThemeAlias", []))

    @jsii.member(jsii_name="toUpdateThemePermissions")
    def to_update_theme_permissions(self) -> "Quicksight":
        '''(experimental) Grants permission to update permissions for a theme.

        Access Level: Permissions management

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_UpdateThemePermissions.html

        :stability: experimental
        '''
        return typing.cast("Quicksight", jsii.invoke(self, "toUpdateThemePermissions", []))

    @jsii.member(jsii_name="toUpdateUser")
    def to_update_user(self) -> "Quicksight":
        '''(experimental) Grants permission to update an Amazon QuickSight user.

        Access Level: Write

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_UpdateUser.html

        :stability: experimental
        '''
        return typing.cast("Quicksight", jsii.invoke(self, "toUpdateUser", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7c6b53eae3e980b95782f51583e413a110978b74d56aaf9955cb3df60c3edfca)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__29ae795573d8061836506865c7777c84ab73159ae5bf3a261ff3c962f251a119)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Ram(PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Ram"):
    '''(experimental) Statement provider for service `ram <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsresourceaccessmanager.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `ram <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsresourceaccessmanager.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="ifAllowsExternalPrincipals")
    def if_allows_external_principals(
        self,
        value: typing.Optional[builtins.bool] = None,
    ) -> "Ram":
        '''(experimental) Filters access based on resource shares that allow or deny sharing with external principals.

        For example, specify true if the action can only be performed on resource shares that allow sharing with external principals. External principals are AWS accounts that are outside of its AWS organization

        https://docs.aws.amazon.com/ram/latest/userguide/iam-policies.html#iam-policies-condition

        Applies to actions:

        - .toAssociateResourceShare()
        - .toDeleteResourceShare()
        - .toDisassociateResourceShare()
        - .toListResourceSharePermissions()
        - .toUpdateResourceShare()

        Applies to resource types:

        - resource-share

        :param value: ``true`` or ``false``. **Default:** ``true``

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2235097db0b8de509a76389fee5cccd2d209350d2ac98a87cad6b0454d77acc1)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast("Ram", jsii.invoke(self, "ifAllowsExternalPrincipals", [value]))

    @jsii.member(jsii_name="ifPermissionArn")
    def if_permission_arn(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Ram":
        '''(experimental) Filters access based on the specified Permission ARN.

        https://docs.aws.amazon.com/ram/latest/userguide/iam-policies.html#iam-policies-condition

        Applies to actions:

        - .toGetPermission()

        Applies to resource types:

        - permission

        :param value: The value(s) to check.
        :param operator: Works with `arn operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_ARN>`_. **Default:** ``ArnLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ea06878a24bf9053a0c82945a480387de98267b00bb5fb8fb908884e3cffecb3)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Ram", jsii.invoke(self, "ifPermissionArn", [value, operator]))

    @jsii.member(jsii_name="ifPermissionResourceType")
    def if_permission_resource_type(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Ram":
        '''(experimental) Filters access based on permissions of specified resource type.

        https://docs.aws.amazon.com/ram/latest/userguide/iam-policies.html#iam-policies-condition

        Applies to resource types:

        - permission

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6c3fea5cab82466098458b3ef9bc60397edb4874ba9e61f12b8478ec154b25a6)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Ram", jsii.invoke(self, "ifPermissionResourceType", [value, operator]))

    @jsii.member(jsii_name="ifPrincipal")
    def if_principal(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Ram":
        '''(experimental) Filters access based on the format of the specified principal.

        https://docs.aws.amazon.com/ram/latest/userguide/iam-policies.html#iam-policies-condition

        Applies to actions:

        - .toAssociateResourceShare()
        - .toCreateResourceShare()
        - .toDisassociateResourceShare()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6a05a661b149132501e2399d31db71b9bc0968063300855e6c7f9bb6ff621766)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Ram", jsii.invoke(self, "ifPrincipal", [value, operator]))

    @jsii.member(jsii_name="ifRequestedAllowsExternalPrincipals")
    def if_requested_allows_external_principals(
        self,
        value: typing.Optional[builtins.bool] = None,
    ) -> "Ram":
        '''(experimental) Filters access based on the specified value for 'allowExternalPrincipals'.

        External principals are AWS accounts that are outside of its AWS Organization

        https://docs.aws.amazon.com/ram/latest/userguide/iam-policies.html#iam-policies-condition

        Applies to actions:

        - .toCreateResourceShare()
        - .toUpdateResourceShare()

        :param value: ``true`` or ``false``. **Default:** ``true``

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c2a717933926c33ba0a1c2bb90dcde7259449533a4a40b0a31d2408d32db6122)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast("Ram", jsii.invoke(self, "ifRequestedAllowsExternalPrincipals", [value]))

    @jsii.member(jsii_name="ifRequestedResourceType")
    def if_requested_resource_type(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Ram":
        '''(experimental) Filters access based on the specified resource type.

        https://docs.aws.amazon.com/ram/latest/userguide/iam-policies.html#iam-policies-condition

        Applies to actions:

        - .toAssociateResourceShare()
        - .toCreateResourceShare()
        - .toDisassociateResourceShare()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3f5ef853a00b84e8a1d7efb184efb32ec712a6bacf5b4313842abd95c9a6f980)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Ram", jsii.invoke(self, "ifRequestedResourceType", [value, operator]))

    @jsii.member(jsii_name="ifResourceArn")
    def if_resource_arn(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Ram":
        '''(experimental) Filters access based on a resource with the specified ARN.

        https://docs.aws.amazon.com/ram/latest/userguide/iam-policies.html#iam-policies-condition

        Applies to actions:

        - .toAssociateResourceShare()
        - .toCreateResourceShare()
        - .toDisassociateResourceShare()

        :param value: The value(s) to check.
        :param operator: Works with `arn operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_ARN>`_. **Default:** ``ArnLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0e5426f7987fbc1a5fc5fc196b1ed6651c93ff5e72abc8148162652b52a1b349)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Ram", jsii.invoke(self, "ifResourceArn", [value, operator]))

    @jsii.member(jsii_name="ifResourceShareName")
    def if_resource_share_name(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Ram":
        '''(experimental) Filters access based on a resource share with the specified name.

        https://docs.aws.amazon.com/ram/latest/userguide/iam-policies.html#iam-policies-condition

        Applies to actions:

        - .toAssociateResourceShare()
        - .toDeleteResourceShare()
        - .toDisassociateResourceShare()
        - .toListResourceSharePermissions()
        - .toUpdateResourceShare()

        Applies to resource types:

        - resource-share

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__08ccf3fc32e275bc7ff3d79939850909de2c0dfb4108dee5f6cb2692fa60e948)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Ram", jsii.invoke(self, "ifResourceShareName", [value, operator]))

    @jsii.member(jsii_name="ifShareOwnerAccountId")
    def if_share_owner_account_id(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Ram":
        '''(experimental) Filters access based on resource shares owned by a specific account.

        For example, you can use this condition key to specify which resource share invitations can be accepted or rejected based on the resource share owner's account ID

        https://docs.aws.amazon.com/ram/latest/userguide/iam-policies.html#iam-policies-condition

        Applies to actions:

        - .toAcceptResourceShareInvitation()
        - .toRejectResourceShareInvitation()

        Applies to resource types:

        - resource-share-invitation

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b507beec83babaed0298d691e322d03df4d80ac27c19a1d9122aaeb9d48b7b4f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Ram", jsii.invoke(self, "ifShareOwnerAccountId", [value, operator]))

    @jsii.member(jsii_name="onPermission")
    def on_permission(
        self,
        resource_path: builtins.str,
        account: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Ram":
        '''(experimental) Adds a resource of type permission to the statement.

        https://docs.aws.amazon.com/ram/latest/APIReference/API_ResourceSharePermissionDetail.html

        :param resource_path: - Identifier for the resourcePath.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifPermissionArn() - .ifPermissionResourceType()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b750445fd2d890d8843c02442e2b69d24f9278df5635f50cdf7312a651d76948)
            check_type(argname="argument resource_path", value=resource_path, expected_type=type_hints["resource_path"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Ram", jsii.invoke(self, "onPermission", [resource_path, account, partition]))

    @jsii.member(jsii_name="onResourceShare")
    def on_resource_share(
        self,
        resource_path: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Ram":
        '''(experimental) Adds a resource of type resource-share to the statement.

        https://docs.aws.amazon.com/ram/latest/APIReference/API_ResourceShare.html

        :param resource_path: - Identifier for the resourcePath.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag() - .ifAllowsExternalPrincipals() - .ifResourceShareName()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__28815fc5b6aab3f2f30193b6663fce1d62e2290c2eb8cbadac2d423cad3d1d12)
            check_type(argname="argument resource_path", value=resource_path, expected_type=type_hints["resource_path"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Ram", jsii.invoke(self, "onResourceShare", [resource_path, account, region, partition]))

    @jsii.member(jsii_name="onResourceShareInvitation")
    def on_resource_share_invitation(
        self,
        resource_path: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Ram":
        '''(experimental) Adds a resource of type resource-share-invitation to the statement.

        https://docs.aws.amazon.com/ram/latest/APIReference/API_ResourceShareInvitation.html

        :param resource_path: - Identifier for the resourcePath.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifShareOwnerAccountId()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__dfbd4feaefffb4c3e50215633880d25e59fa8eee3c3d97da425a49dd573ea707)
            check_type(argname="argument resource_path", value=resource_path, expected_type=type_hints["resource_path"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Ram", jsii.invoke(self, "onResourceShareInvitation", [resource_path, account, region, partition]))

    @jsii.member(jsii_name="toAcceptResourceShareInvitation")
    def to_accept_resource_share_invitation(self) -> "Ram":
        '''(experimental) Grants permission to accept the specified resource share invitation.

        Access Level: Write

        Possible conditions:

        - .ifShareOwnerAccountId()

        https://docs.aws.amazon.com/ram/latest/APIReference/API_AcceptResourceShareInvitation.html

        :stability: experimental
        '''
        return typing.cast("Ram", jsii.invoke(self, "toAcceptResourceShareInvitation", []))

    @jsii.member(jsii_name="toAssociateResourceShare")
    def to_associate_resource_share(self) -> "Ram":
        '''(experimental) Grants permission to associate resource(s) and/or principal(s) to a resource share.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()
        - .ifResourceShareName()
        - .ifAllowsExternalPrincipals()
        - .ifPrincipal()
        - .ifRequestedResourceType()
        - .ifResourceArn()

        https://docs.aws.amazon.com/ram/latest/APIReference/API_AssociateResourceShare.html

        :stability: experimental
        '''
        return typing.cast("Ram", jsii.invoke(self, "toAssociateResourceShare", []))

    @jsii.member(jsii_name="toAssociateResourceSharePermission")
    def to_associate_resource_share_permission(self) -> "Ram":
        '''(experimental) Grants permission to associate a Permission with a Resource Share.

        Access Level: Write

        https://docs.aws.amazon.com/ram/latest/APIReference/API_AssociateResourceSharePermission.html

        :stability: experimental
        '''
        return typing.cast("Ram", jsii.invoke(self, "toAssociateResourceSharePermission", []))

    @jsii.member(jsii_name="toCreateResourceShare")
    def to_create_resource_share(self) -> "Ram":
        '''(experimental) Grants permission to create a resource share with provided resource(s) and/or principal(s).

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifRequestedResourceType()
        - .ifResourceArn()
        - .ifRequestedAllowsExternalPrincipals()
        - .ifPrincipal()

        Dependent actions:

        - ec2:CreateTags

        https://docs.aws.amazon.com/ram/latest/APIReference/API_CreateResourceShare.html

        :stability: experimental
        '''
        return typing.cast("Ram", jsii.invoke(self, "toCreateResourceShare", []))

    @jsii.member(jsii_name="toDeleteResourceShare")
    def to_delete_resource_share(self) -> "Ram":
        '''(experimental) Grants permission to delete resource share.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()
        - .ifResourceShareName()
        - .ifAllowsExternalPrincipals()

        https://docs.aws.amazon.com/ram/latest/APIReference/API_DeleteResourceShare.html

        :stability: experimental
        '''
        return typing.cast("Ram", jsii.invoke(self, "toDeleteResourceShare", []))

    @jsii.member(jsii_name="toDisassociateResourceShare")
    def to_disassociate_resource_share(self) -> "Ram":
        '''(experimental) Grants permission to disassociate resource(s) and/or principal(s) from a resource share.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()
        - .ifResourceShareName()
        - .ifAllowsExternalPrincipals()
        - .ifPrincipal()
        - .ifRequestedResourceType()
        - .ifResourceArn()

        https://docs.aws.amazon.com/ram/latest/APIReference/API_DisassociateResourceShare.html

        :stability: experimental
        '''
        return typing.cast("Ram", jsii.invoke(self, "toDisassociateResourceShare", []))

    @jsii.member(jsii_name="toDisassociateResourceSharePermission")
    def to_disassociate_resource_share_permission(self) -> "Ram":
        '''(experimental) Grants permission to disassociate a Permission from a Resource Share.

        Access Level: Write

        https://docs.aws.amazon.com/ram/latest/APIReference/API_DisassociateResourceSharePermission.html

        :stability: experimental
        '''
        return typing.cast("Ram", jsii.invoke(self, "toDisassociateResourceSharePermission", []))

    @jsii.member(jsii_name="toEnableSharingWithAwsOrganization")
    def to_enable_sharing_with_aws_organization(self) -> "Ram":
        '''(experimental) Grants permission to access customer's organization and create a SLR in the customer's account.

        Access Level: Permissions management

        Dependent actions:

        - iam:CreateServiceLinkedRole
        - organizations:DescribeOrganization
        - organizations:EnableAWSServiceAccess

        https://docs.aws.amazon.com/ram/latest/APIReference/API_EnableSharingWithAwsOrganization.html

        :stability: experimental
        '''
        return typing.cast("Ram", jsii.invoke(self, "toEnableSharingWithAwsOrganization", []))

    @jsii.member(jsii_name="toGetPermission")
    def to_get_permission(self) -> "Ram":
        '''(experimental) Grants permission to get the contents of an AWS RAM permission.

        Access Level: Read

        Possible conditions:

        - .ifPermissionArn()

        https://docs.aws.amazon.com/ram/latest/APIReference/API_GetPermission.html

        :stability: experimental
        '''
        return typing.cast("Ram", jsii.invoke(self, "toGetPermission", []))

    @jsii.member(jsii_name="toGetResourcePolicies")
    def to_get_resource_policies(self) -> "Ram":
        '''(experimental) Grants permission to get the policies for the specified resources that you own and have shared.

        Access Level: Read

        https://docs.aws.amazon.com/ram/latest/APIReference/API_GetResourcePolicies.html

        :stability: experimental
        '''
        return typing.cast("Ram", jsii.invoke(self, "toGetResourcePolicies", []))

    @jsii.member(jsii_name="toGetResourceShareAssociations")
    def to_get_resource_share_associations(self) -> "Ram":
        '''(experimental) Grants permission to get a set of resource share associations from a provided list or with a specified status of the specified type.

        Access Level: Read

        https://docs.aws.amazon.com/ram/latest/APIReference/API_GetResourceShareAssociations.html

        :stability: experimental
        '''
        return typing.cast("Ram", jsii.invoke(self, "toGetResourceShareAssociations", []))

    @jsii.member(jsii_name="toGetResourceShareInvitations")
    def to_get_resource_share_invitations(self) -> "Ram":
        '''(experimental) Grants permission to get resource share invitations by the specified invitation arn or those for the resource share.

        Access Level: Read

        https://docs.aws.amazon.com/ram/latest/APIReference/API_GetResourceShareInvitations.html

        :stability: experimental
        '''
        return typing.cast("Ram", jsii.invoke(self, "toGetResourceShareInvitations", []))

    @jsii.member(jsii_name="toGetResourceShares")
    def to_get_resource_shares(self) -> "Ram":
        '''(experimental) Grants permission to get a set of resource shares from a provided list or with a specified status.

        Access Level: Read

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/ram/latest/APIReference/API_GetResourceShares.html

        :stability: experimental
        '''
        return typing.cast("Ram", jsii.invoke(self, "toGetResourceShares", []))

    @jsii.member(jsii_name="toListPendingInvitationResources")
    def to_list_pending_invitation_resources(self) -> "Ram":
        '''(experimental) Grants permission to list the resources in a resource share that is shared with you but that the invitation is still pending for.

        Access Level: Read

        https://docs.aws.amazon.com/ram/latest/APIReference/API_ListPendingInvitationResources.html

        :stability: experimental
        '''
        return typing.cast("Ram", jsii.invoke(self, "toListPendingInvitationResources", []))

    @jsii.member(jsii_name="toListPermissions")
    def to_list_permissions(self) -> "Ram":
        '''(experimental) Grants permission to list the AWS RAM permissions.

        Access Level: List

        https://docs.aws.amazon.com/ram/latest/APIReference/API_ListPermissions.html

        :stability: experimental
        '''
        return typing.cast("Ram", jsii.invoke(self, "toListPermissions", []))

    @jsii.member(jsii_name="toListPermissionVersions")
    def to_list_permission_versions(self) -> "Ram":
        '''(experimental) Grants permission to list the versions of an AWS RAM permission.

        Access Level: List

        https://docs.aws.amazon.com/ram/latest/APIReference/API_ListPermissionVersions.html

        :stability: experimental
        '''
        return typing.cast("Ram", jsii.invoke(self, "toListPermissionVersions", []))

    @jsii.member(jsii_name="toListPrincipals")
    def to_list_principals(self) -> "Ram":
        '''(experimental) Grants permission to list the principals that you have shared resources with or that have shared resources with you.

        Access Level: List

        https://docs.aws.amazon.com/ram/latest/APIReference/API_ListPrincipals.html

        :stability: experimental
        '''
        return typing.cast("Ram", jsii.invoke(self, "toListPrincipals", []))

    @jsii.member(jsii_name="toListResources")
    def to_list_resources(self) -> "Ram":
        '''(experimental) Grants permission to list the resources that you added to resource shares or the resources that are shared with you.

        Access Level: List

        https://docs.aws.amazon.com/ram/latest/APIReference/API_ListResources.html

        :stability: experimental
        '''
        return typing.cast("Ram", jsii.invoke(self, "toListResources", []))

    @jsii.member(jsii_name="toListResourceSharePermissions")
    def to_list_resource_share_permissions(self) -> "Ram":
        '''(experimental) Grants permission to list the Permissions associated with a Resource Share.

        Access Level: List

        Possible conditions:

        - .ifAwsResourceTag()
        - .ifResourceShareName()
        - .ifAllowsExternalPrincipals()

        https://docs.aws.amazon.com/ram/latest/APIReference/API_ListResourceSharePermissions.html

        :stability: experimental
        '''
        return typing.cast("Ram", jsii.invoke(self, "toListResourceSharePermissions", []))

    @jsii.member(jsii_name="toListResourceTypes")
    def to_list_resource_types(self) -> "Ram":
        '''(experimental) Grants permission to list the shareable resource types supported by AWS RAM.

        Access Level: List

        https://docs.aws.amazon.com/ram/latest/APIReference/API_ListResourceTypes.html

        :stability: experimental
        '''
        return typing.cast("Ram", jsii.invoke(self, "toListResourceTypes", []))

    @jsii.member(jsii_name="toPromoteResourceShareCreatedFromPolicy")
    def to_promote_resource_share_created_from_policy(self) -> "Ram":
        '''(experimental) Grants permission to promote the specified resource share.

        Access Level: Write

        https://docs.aws.amazon.com/ram/latest/APIReference/API_PromoteResourceShareCreatedFromPolicy.html

        :stability: experimental
        '''
        return typing.cast("Ram", jsii.invoke(self, "toPromoteResourceShareCreatedFromPolicy", []))

    @jsii.member(jsii_name="toRejectResourceShareInvitation")
    def to_reject_resource_share_invitation(self) -> "Ram":
        '''(experimental) Grants permission to reject the specified resource share invitation.

        Access Level: Write

        Possible conditions:

        - .ifShareOwnerAccountId()

        https://docs.aws.amazon.com/ram/latest/APIReference/API_RejectResourceShareInvitation.html

        :stability: experimental
        '''
        return typing.cast("Ram", jsii.invoke(self, "toRejectResourceShareInvitation", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Ram":
        '''(experimental) Grants permission to tag the specified resource share.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/ram/latest/APIReference/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("Ram", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Ram":
        '''(experimental) Grants permission to untag the specified resource share.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/ram/latest/APIReference/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("Ram", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateResourceShare")
    def to_update_resource_share(self) -> "Ram":
        '''(experimental) Grants permission to update attributes of the resource share.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()
        - .ifResourceShareName()
        - .ifAllowsExternalPrincipals()
        - .ifRequestedAllowsExternalPrincipals()

        https://docs.aws.amazon.com/ram/latest/APIReference/API_UpdateResourceShare.html

        :stability: experimental
        '''
        return typing.cast("Ram", jsii.invoke(self, "toUpdateResourceShare", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__dd344d8ec5d188cbb36ce51cddcdcf36677c8cc3b3170ad595e80c9e58940247)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9abd48b42c44ddf1bcb569b04c64c103260012d41f02dcec00c2f1b1769987bf)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Rbin(PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Rbin"):
    '''(experimental) Statement provider for service `rbin <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsrecyclebin.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `rbin <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsrecyclebin.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="ifAttributeResourceType")
    def if_attribute_resource_type(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Rbin":
        '''(experimental) Filters access by the resource type of the existing rule.

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/recycle-bin-perms.html#rbin-condition-keys

        Applies to actions:

        - .toDeleteRule()
        - .toGetRule()
        - .toListTagsForResource()
        - .toLockRule()
        - .toTagResource()
        - .toUnlockRule()
        - .toUntagResource()
        - .toUpdateRule()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__69ce5c5a3135a847b9dba239ca50da4afd4c05900f81ceed15cff1c072cc9f85)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Rbin", jsii.invoke(self, "ifAttributeResourceType", [value, operator]))

    @jsii.member(jsii_name="ifRequestResourceType")
    def if_request_resource_type(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Rbin":
        '''(experimental) Filters access by the resource type in a request.

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/recycle-bin-perms.html#rbin-condition-keys

        Applies to actions:

        - .toCreateRule()
        - .toListRules()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__61c6c30244287bbf027f37c0af88b7a82e9f4b56d9069208b30dcd1553a117db)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Rbin", jsii.invoke(self, "ifRequestResourceType", [value, operator]))

    @jsii.member(jsii_name="onRule")
    def on_rule(
        self,
        resource_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Rbin":
        '''(experimental) Adds a resource of type rule to the statement.

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/snapshot-recycle-bin.html#recycle-bin-concepts

        :param resource_name: - Identifier for the resourceName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__30f27a713e27953f8518c81b09396e2482a3921067e82ade307880599ffb8761)
            check_type(argname="argument resource_name", value=resource_name, expected_type=type_hints["resource_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Rbin", jsii.invoke(self, "onRule", [resource_name, account, region, partition]))

    @jsii.member(jsii_name="toCreateRule")
    def to_create_rule(self) -> "Rbin":
        '''(experimental) Grants permission to create a Recycle Bin retention rule.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifRequestResourceType()

        https://docs.aws.amazon.com/recyclebin/latest/APIReference/API_CreateRule.html

        :stability: experimental
        '''
        return typing.cast("Rbin", jsii.invoke(self, "toCreateRule", []))

    @jsii.member(jsii_name="toDeleteRule")
    def to_delete_rule(self) -> "Rbin":
        '''(experimental) Grants permission to delete a Recycle Bin retention rule.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()
        - .ifAttributeResourceType()

        https://docs.aws.amazon.com/recyclebin/latest/APIReference/API_DeleteRule.html

        :stability: experimental
        '''
        return typing.cast("Rbin", jsii.invoke(self, "toDeleteRule", []))

    @jsii.member(jsii_name="toGetRule")
    def to_get_rule(self) -> "Rbin":
        '''(experimental) Grants permission to get detailed information about a Recycle Bin retention rule.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()
        - .ifAttributeResourceType()

        https://docs.aws.amazon.com/recyclebin/latest/APIReference/API_GetRule.html

        :stability: experimental
        '''
        return typing.cast("Rbin", jsii.invoke(self, "toGetRule", []))

    @jsii.member(jsii_name="toListRules")
    def to_list_rules(self) -> "Rbin":
        '''(experimental) Grants permission to list the Recycle Bin retention rules in the Region.

        Access Level: Read

        Possible conditions:

        - .ifRequestResourceType()

        https://docs.aws.amazon.com/recyclebin/latest/APIReference/API_ListRules.html

        :stability: experimental
        '''
        return typing.cast("Rbin", jsii.invoke(self, "toListRules", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Rbin":
        '''(experimental) Grants permission to list the tags associated with a resource.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()
        - .ifAttributeResourceType()

        https://docs.aws.amazon.com/recyclebin/latest/APIReference/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("Rbin", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toLockRule")
    def to_lock_rule(self) -> "Rbin":
        '''(experimental) Grants permission to lock an existing Recycle Bin retention rule.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()
        - .ifAttributeResourceType()

        https://docs.aws.amazon.com/recyclebin/latest/APIReference/API_LockRule.html

        :stability: experimental
        '''
        return typing.cast("Rbin", jsii.invoke(self, "toLockRule", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Rbin":
        '''(experimental) Grants permission to add or update tags of a resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsResourceTag()
        - .ifAwsTagKeys()
        - .ifAttributeResourceType()

        https://docs.aws.amazon.com/recyclebin/latest/APIReference/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("Rbin", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUnlockRule")
    def to_unlock_rule(self) -> "Rbin":
        '''(experimental) Grants permission to unlock an existing Recycle Bin retention rule.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()
        - .ifAttributeResourceType()

        https://docs.aws.amazon.com/recyclebin/latest/APIReference/API_UnlockRule.html

        :stability: experimental
        '''
        return typing.cast("Rbin", jsii.invoke(self, "toUnlockRule", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Rbin":
        '''(experimental) Grants permission to remove tags associated with a resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsResourceTag()
        - .ifAwsTagKeys()
        - .ifAttributeResourceType()

        https://docs.aws.amazon.com/recyclebin/latest/APIReference/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("Rbin", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateRule")
    def to_update_rule(self) -> "Rbin":
        '''(experimental) Grants permission to update an existing Recycle Bin retention rule.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()
        - .ifAttributeResourceType()

        https://docs.aws.amazon.com/recyclebin/latest/APIReference/API_UpdateRule.html

        :stability: experimental
        '''
        return typing.cast("Rbin", jsii.invoke(self, "toUpdateRule", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bc1fc9bb2930a30bf8a8a50117479b43e3821f08e4a7a98a84b5ade81372163f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__cead1dc1359ec6a8366db8df6ce43b1a23e1b7dcceafa2de1570f50c4cfcfc7d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Rds(PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Rds"):
    '''(experimental) Statement provider for service `rds <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonrds.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `rds <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonrds.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="ifBackupTarget")
    def if_backup_target(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Rds":
        '''(experimental) Filters access by the type of backup target. One of: REGION, OUTPOSTS.

        https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/security_iam_service-with-iam.html#UsingWithRDS.IAM.Conditions

        Applies to actions:

        - .toCreateDBInstance()
        - .toCreateDBSnapshot()
        - .toRestoreDBInstanceFromDBSnapshot()
        - .toRestoreDBInstanceToPointInTime()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c0b50b72c1d9e4e5c71ef35145d24c127985b7a00281b1af97fb79a10cbe8fc9)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Rds", jsii.invoke(self, "ifBackupTarget", [value, operator]))

    @jsii.member(jsii_name="ifClusterPgTag")
    def if_cluster_pg_tag(
        self,
        tag_key: builtins.str,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Rds":
        '''(experimental) Filters access by the tag attached to a DB cluster parameter group.

        https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/security_iam_service-with-iam.html#UsingWithRDS.IAM.Conditions

        Applies to actions:

        - .toCreateBlueGreenDeployment()

        Applies to resource types:

        - cluster-pg

        :param tag_key: The tag key to check.
        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__34d37ece1f2b0f4ac7e049332eb2506a53d642699f2eb2bac91093360ce1c22b)
            check_type(argname="argument tag_key", value=tag_key, expected_type=type_hints["tag_key"])
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Rds", jsii.invoke(self, "ifClusterPgTag", [tag_key, value, operator]))

    @jsii.member(jsii_name="ifClusterSnapshotTag")
    def if_cluster_snapshot_tag(
        self,
        tag_key: builtins.str,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Rds":
        '''(experimental) Filters access by the tag attached to a DB cluster snapshot.

        https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/security_iam_service-with-iam.html#UsingWithRDS.IAM.Conditions

        Applies to resource types:

        - cluster-snapshot

        :param tag_key: The tag key to check.
        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d9255ba1cc21498aed371cde6de81bd1e5f13f566eab0499a9e512d6dab7541f)
            check_type(argname="argument tag_key", value=tag_key, expected_type=type_hints["tag_key"])
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Rds", jsii.invoke(self, "ifClusterSnapshotTag", [tag_key, value, operator]))

    @jsii.member(jsii_name="ifClusterTag")
    def if_cluster_tag(
        self,
        tag_key: builtins.str,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Rds":
        '''(experimental) Filters access by the tag attached to a DB cluster.

        https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/security_iam_service-with-iam.html#UsingWithRDS.IAM.Conditions

        Applies to actions:

        - .toCreateBlueGreenDeployment()

        Applies to resource types:

        - cluster

        :param tag_key: The tag key to check.
        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fc09882fdfd30f9785938a4ccbd078db4bc6d48610c5e6588e05f875e15b6075)
            check_type(argname="argument tag_key", value=tag_key, expected_type=type_hints["tag_key"])
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Rds", jsii.invoke(self, "ifClusterTag", [tag_key, value, operator]))

    @jsii.member(jsii_name="ifCopyOptionGroup")
    def if_copy_option_group(
        self,
        value: typing.Optional[builtins.bool] = None,
    ) -> "Rds":
        '''(experimental) Filters access by the value that specifies whether the CopyDBSnapshot action requires copying the DB option group.

        https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/security_iam_service-with-iam.html#UsingWithRDS.IAM.Conditions

        Applies to actions:

        - .toCopyDBSnapshot()

        :param value: ``true`` or ``false``. **Default:** ``true``

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__cc39c9249f6ce1ba49bfe2b6e258f2fe72383b7866fc0287ec5a74e63189098d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast("Rds", jsii.invoke(self, "ifCopyOptionGroup", [value]))

    @jsii.member(jsii_name="ifDatabaseClass")
    def if_database_class(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Rds":
        '''(experimental) Filters access by the type of DB instance class.

        https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/security_iam_service-with-iam.html#UsingWithRDS.IAM.Conditions

        Applies to actions:

        - .toCreateBlueGreenDeployment()
        - .toCreateDBCluster()
        - .toModifyDBCluster()
        - .toRestoreDBClusterFromSnapshot()
        - .toRestoreDBClusterToPointInTime()

        Applies to resource types:

        - db

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7af7de060fd56a6d7f529190380a150ca173a38942b85dd71ac9e47c4b921e91)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Rds", jsii.invoke(self, "ifDatabaseClass", [value, operator]))

    @jsii.member(jsii_name="ifDatabaseEngine")
    def if_database_engine(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Rds":
        '''(experimental) Filters access by the database engine. For possible values refer to the engine parameter in CreateDBInstance API.

        https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/security_iam_service-with-iam.html#UsingWithRDS.IAM.Conditions

        Applies to actions:

        - .toCreateBlueGreenDeployment()
        - .toCreateDBCluster()
        - .toRestoreDBClusterFromS3()

        Applies to resource types:

        - db

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5ef1efc5211d55ac4ea39e1c436bce80b61f644d3882cbed29d836da9f4cf31b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Rds", jsii.invoke(self, "ifDatabaseEngine", [value, operator]))

    @jsii.member(jsii_name="ifDatabaseName")
    def if_database_name(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Rds":
        '''(experimental) Filters access by the user-defined name of the database on the DB instance.

        https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/security_iam_service-with-iam.html#UsingWithRDS.IAM.Conditions

        Applies to actions:

        - .toCreateBlueGreenDeployment()
        - .toCreateDBCluster()
        - .toRestoreDBClusterFromS3()

        Applies to resource types:

        - db

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0c069beef1c2a1138f1f452545c247e3ae23a2a9839226850f41968e35188b6f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Rds", jsii.invoke(self, "ifDatabaseName", [value, operator]))

    @jsii.member(jsii_name="ifDbTag")
    def if_db_tag(
        self,
        tag_key: builtins.str,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Rds":
        '''(experimental) Filters access by the tag attached to a DB instance.

        https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/security_iam_service-with-iam.html#UsingWithRDS.IAM.Conditions

        Applies to actions:

        - .toCreateBlueGreenDeployment()

        Applies to resource types:

        - db

        :param tag_key: The tag key to check.
        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d269806a49d38fd536660597afbe6afd855e028109395979fa592dba10c9e4f8)
            check_type(argname="argument tag_key", value=tag_key, expected_type=type_hints["tag_key"])
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Rds", jsii.invoke(self, "ifDbTag", [tag_key, value, operator]))

    @jsii.member(jsii_name="ifEndpointType")
    def if_endpoint_type(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Rds":
        '''(experimental) Filters access by the type of the endpoint. One of: READER, WRITER, CUSTOM.

        https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/security_iam_service-with-iam.html#UsingWithRDS.IAM.Conditions

        Applies to actions:

        - .toCreateDBClusterEndpoint()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__604392b59c0fe00b129013b85b2aae371f5eba9df4f122ab6d74ade09683330d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Rds", jsii.invoke(self, "ifEndpointType", [value, operator]))

    @jsii.member(jsii_name="ifEsTag")
    def if_es_tag(
        self,
        tag_key: builtins.str,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Rds":
        '''(experimental) Filters access by the tag attached to an event subscription.

        https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/security_iam_service-with-iam.html#UsingWithRDS.IAM.Conditions

        Applies to resource types:

        - es

        :param tag_key: The tag key to check.
        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b191d148e2333642d134ce4445f0113701ff6031d1e647aec56d19afa8c80ff6)
            check_type(argname="argument tag_key", value=tag_key, expected_type=type_hints["tag_key"])
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Rds", jsii.invoke(self, "ifEsTag", [tag_key, value, operator]))

    @jsii.member(jsii_name="ifMultiAz")
    def if_multi_az(self, value: typing.Optional[builtins.bool] = None) -> "Rds":
        '''(experimental) Filters access by the value that specifies whether the DB instance runs in multiple Availability Zones.

        To indicate that the DB instance is using Multi-AZ, specify true

        https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/security_iam_service-with-iam.html#UsingWithRDS.IAM.Conditions

        Applies to actions:

        - .toCreateBlueGreenDeployment()

        Applies to resource types:

        - db

        :param value: ``true`` or ``false``. **Default:** ``true``

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c2a2e0850d7c9106659ac2dd9cb9657eac6aa216e90ef475bb4c34dbc6a35942)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast("Rds", jsii.invoke(self, "ifMultiAz", [value]))

    @jsii.member(jsii_name="ifOgTag")
    def if_og_tag(
        self,
        tag_key: builtins.str,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Rds":
        '''(experimental) Filters access by the tag attached to a DB option group.

        https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/security_iam_service-with-iam.html#UsingWithRDS.IAM.Conditions

        Applies to resource types:

        - og

        :param tag_key: The tag key to check.
        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__64e682e005b538a2d09a32d1d154336093f87e4fdb8859871848cc074bb5f746)
            check_type(argname="argument tag_key", value=tag_key, expected_type=type_hints["tag_key"])
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Rds", jsii.invoke(self, "ifOgTag", [tag_key, value, operator]))

    @jsii.member(jsii_name="ifPgTag")
    def if_pg_tag(
        self,
        tag_key: builtins.str,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Rds":
        '''(experimental) Filters access by the tag attached to a DB parameter group.

        https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/security_iam_service-with-iam.html#UsingWithRDS.IAM.Conditions

        Applies to actions:

        - .toCreateBlueGreenDeployment()

        Applies to resource types:

        - pg

        :param tag_key: The tag key to check.
        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ba436c05ff735a353f8bc0b928ce8bcc0c24ae30aa277d09ff35de3dd0fac7f5)
            check_type(argname="argument tag_key", value=tag_key, expected_type=type_hints["tag_key"])
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Rds", jsii.invoke(self, "ifPgTag", [tag_key, value, operator]))

    @jsii.member(jsii_name="ifPiops")
    def if_piops(
        self,
        value: typing.Union[jsii.Number, typing.Sequence[jsii.Number]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Rds":
        '''(experimental) Filters access by the value that contains the number of Provisioned IOPS (PIOPS) that the instance supports.

        To indicate a DB instance that does not have PIOPS enabled, specify 0

        https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/security_iam_service-with-iam.html#UsingWithRDS.IAM.Conditions

        Applies to actions:

        - .toCreateBlueGreenDeployment()
        - .toCreateDBCluster()
        - .toModifyDBCluster()
        - .toRestoreDBClusterFromSnapshot()
        - .toRestoreDBClusterToPointInTime()

        Applies to resource types:

        - db

        :param value: The value(s) to check.
        :param operator: Works with `numeric operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_Numeric>`_. **Default:** ``NumericEquals``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c06d26d78e96da093c39360f6e094958f025d74770216e06af19583adbf773eb)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Rds", jsii.invoke(self, "ifPiops", [value, operator]))

    @jsii.member(jsii_name="ifReqTag")
    def if_req_tag(
        self,
        tag_key: builtins.str,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Rds":
        '''(experimental) Filters access by the set of tag keys and values that can be used to tag a resource.

        https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/security_iam_service-with-iam.html#UsingWithRDS.IAM.Conditions

        Applies to actions:

        - .toAddTagsToResource()
        - .toCreateBlueGreenDeployment()
        - .toCreateDBCluster()
        - .toCreateDBClusterParameterGroup()
        - .toCreateDBClusterSnapshot()
        - .toCreateDBInstance()
        - .toCreateDBInstanceReadReplica()
        - .toCreateDBParameterGroup()
        - .toCreateDBSecurityGroup()
        - .toCreateDBSnapshot()
        - .toCreateDBSubnetGroup()
        - .toCreateEventSubscription()
        - .toCreateOptionGroup()
        - .toDeleteBlueGreenDeployment()
        - .toRemoveTagsFromResource()
        - .toRestoreDBClusterFromS3()
        - .toRestoreDBClusterFromSnapshot()
        - .toRestoreDBClusterToPointInTime()
        - .toRestoreDBInstanceFromDBSnapshot()
        - .toRestoreDBInstanceFromS3()
        - .toRestoreDBInstanceToPointInTime()
        - .toSwitchoverBlueGreenDeployment()

        :param tag_key: The tag key to check.
        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5cc0630b61826fdf5e064bbc02a57d096875ebbf8fd1191f95b57c010f3aacea)
            check_type(argname="argument tag_key", value=tag_key, expected_type=type_hints["tag_key"])
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Rds", jsii.invoke(self, "ifReqTag", [tag_key, value, operator]))

    @jsii.member(jsii_name="ifRiTag")
    def if_ri_tag(
        self,
        tag_key: builtins.str,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Rds":
        '''(experimental) Filters access by the tag attached to a reserved DB instance.

        https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/security_iam_service-with-iam.html#UsingWithRDS.IAM.Conditions

        Applies to resource types:

        - ri

        :param tag_key: The tag key to check.
        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__57b72fd033672f6aaba0a77b05166340e45a80d6ee8b01b45a024908181ce049)
            check_type(argname="argument tag_key", value=tag_key, expected_type=type_hints["tag_key"])
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Rds", jsii.invoke(self, "ifRiTag", [tag_key, value, operator]))

    @jsii.member(jsii_name="ifSecgrpTag")
    def if_secgrp_tag(
        self,
        tag_key: builtins.str,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Rds":
        '''(experimental) Filters access by the tag attached to a DB security group.

        https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/security_iam_service-with-iam.html#UsingWithRDS.IAM.Conditions

        Applies to resource types:

        - secgrp

        :param tag_key: The tag key to check.
        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9c43c6dfb8bb5d1f50a4352c5c7c78c443cc4e673654a339b6f3a68f7f48903e)
            check_type(argname="argument tag_key", value=tag_key, expected_type=type_hints["tag_key"])
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Rds", jsii.invoke(self, "ifSecgrpTag", [tag_key, value, operator]))

    @jsii.member(jsii_name="ifSnapshotTag")
    def if_snapshot_tag(
        self,
        tag_key: builtins.str,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Rds":
        '''(experimental) Filters access by the tag attached to a DB snapshot.

        https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/security_iam_service-with-iam.html#UsingWithRDS.IAM.Conditions

        Applies to resource types:

        - snapshot

        :param tag_key: The tag key to check.
        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1fbc0d4606f29b96e451d8819f5ced25b4e57f7cf35cfc64b47541c11518159a)
            check_type(argname="argument tag_key", value=tag_key, expected_type=type_hints["tag_key"])
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Rds", jsii.invoke(self, "ifSnapshotTag", [tag_key, value, operator]))

    @jsii.member(jsii_name="ifStorageEncrypted")
    def if_storage_encrypted(
        self,
        value: typing.Optional[builtins.bool] = None,
    ) -> "Rds":
        '''(experimental) Filters access by the value that specifies whether the DB instance storage should be encrypted.

        To enforce storage encryption, specify true

        https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/security_iam_service-with-iam.html#UsingWithRDS.IAM.Conditions

        Applies to actions:

        - .toCreateBlueGreenDeployment()
        - .toCreateDBCluster()
        - .toRestoreDBClusterFromS3()

        Applies to resource types:

        - db

        :param value: ``true`` or ``false``. **Default:** ``true``

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8d64202ebdb619a9d171ba83fd1e504c537a154b479f02045622f2403721938c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast("Rds", jsii.invoke(self, "ifStorageEncrypted", [value]))

    @jsii.member(jsii_name="ifStorageSize")
    def if_storage_size(
        self,
        value: typing.Union[jsii.Number, typing.Sequence[jsii.Number]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Rds":
        '''(experimental) Filters access by the storage volume size (in GB).

        https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/security_iam_service-with-iam.html#UsingWithRDS.IAM.Conditions

        Applies to actions:

        - .toCreateBlueGreenDeployment()
        - .toCreateDBCluster()
        - .toModifyDBCluster()
        - .toRestoreDBClusterFromSnapshot()
        - .toRestoreDBClusterToPointInTime()

        Applies to resource types:

        - db

        :param value: The value(s) to check.
        :param operator: Works with `numeric operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_Numeric>`_. **Default:** ``NumericEquals``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9901df7bbf23a27a15df6e411bb81b7aa2e718d49b931ef79f2dbe7328f3a554)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Rds", jsii.invoke(self, "ifStorageSize", [value, operator]))

    @jsii.member(jsii_name="ifSubgrpTag")
    def if_subgrp_tag(
        self,
        tag_key: builtins.str,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Rds":
        '''(experimental) Filters access by the tag attached to a DB subnet group.

        https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/security_iam_service-with-iam.html#UsingWithRDS.IAM.Conditions

        Applies to resource types:

        - subgrp

        :param tag_key: The tag key to check.
        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ac1b019df3ffcdd7d7c7d9f37b3faf54375dd88b86e0c3403c3e6e628485dcc1)
            check_type(argname="argument tag_key", value=tag_key, expected_type=type_hints["tag_key"])
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Rds", jsii.invoke(self, "ifSubgrpTag", [tag_key, value, operator]))

    @jsii.member(jsii_name="ifVpc")
    def if_vpc(self, value: typing.Optional[builtins.bool] = None) -> "Rds":
        '''(experimental) Filters access by the value that specifies whether the DB instance runs in an Amazon Virtual Private Cloud (Amazon VPC).

        To indicate that the DB instance runs in an Amazon VPC, specify true

        https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/security_iam_service-with-iam.html#UsingWithRDS.IAM.Conditions

        Applies to actions:

        - .toCreateBlueGreenDeployment()

        Applies to resource types:

        - db

        :param value: ``true`` or ``false``. **Default:** ``true``

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__debc0b3aa64b7b962f2989f9f7c58606e8f72c4a5722069eb381aebe10b7c467)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast("Rds", jsii.invoke(self, "ifVpc", [value]))

    @jsii.member(jsii_name="onCev")
    def on_cev(
        self,
        engine: builtins.str,
        engine_version: builtins.str,
        custom_db_engine_version_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Rds":
        '''(experimental) Adds a resource of type cev to the statement.

        https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/custom-cev.html

        :param engine: - Identifier for the engine.
        :param engine_version: - Identifier for the engineVersion.
        :param custom_db_engine_version_id: - Identifier for the customDbEngineVersionId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9fc267c6d78a122ed15919bce7f1a5c8c0344f71c24836cca398486a89d02169)
            check_type(argname="argument engine", value=engine, expected_type=type_hints["engine"])
            check_type(argname="argument engine_version", value=engine_version, expected_type=type_hints["engine_version"])
            check_type(argname="argument custom_db_engine_version_id", value=custom_db_engine_version_id, expected_type=type_hints["custom_db_engine_version_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Rds", jsii.invoke(self, "onCev", [engine, engine_version, custom_db_engine_version_id, account, region, partition]))

    @jsii.member(jsii_name="onCluster")
    def on_cluster(
        self,
        db_cluster_instance_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Rds":
        '''(experimental) Adds a resource of type cluster to the statement.

        https://docs.aws.amazon.com/AmazonRDS/latest/AuroraUserGuide/CHAP_Aurora.html

        :param db_cluster_instance_name: - Identifier for the dbClusterInstanceName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag() - .ifClusterTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__944a6b99d179514045fad46759703a8d820f102f3577c62ac0fe758436b4b287)
            check_type(argname="argument db_cluster_instance_name", value=db_cluster_instance_name, expected_type=type_hints["db_cluster_instance_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Rds", jsii.invoke(self, "onCluster", [db_cluster_instance_name, account, region, partition]))

    @jsii.member(jsii_name="onClusterEndpoint")
    def on_cluster_endpoint(
        self,
        db_cluster_endpoint: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Rds":
        '''(experimental) Adds a resource of type cluster-endpoint to the statement.

        https://docs.aws.amazon.com/AmazonRDS/latest/AuroraUserGuide/Aurora.Overview.Endpoints.html

        :param db_cluster_endpoint: - Identifier for the dbClusterEndpoint.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e43064940b3da8a4ffea65adf2c8462909a33e7ce2c41954b71d35582b81c82a)
            check_type(argname="argument db_cluster_endpoint", value=db_cluster_endpoint, expected_type=type_hints["db_cluster_endpoint"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Rds", jsii.invoke(self, "onClusterEndpoint", [db_cluster_endpoint, account, region, partition]))

    @jsii.member(jsii_name="onClusterPg")
    def on_cluster_pg(
        self,
        cluster_parameter_group_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Rds":
        '''(experimental) Adds a resource of type cluster-pg to the statement.

        https://docs.aws.amazon.com/AmazonRDS/latest/AuroraUserGuide/USER_WorkingWithParamGroups.html

        :param cluster_parameter_group_name: - Identifier for the clusterParameterGroupName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag() - .ifClusterPgTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c4d6ff2653c5596c61c2495505d446fcb77b84204be8fc8de80890599926b3ac)
            check_type(argname="argument cluster_parameter_group_name", value=cluster_parameter_group_name, expected_type=type_hints["cluster_parameter_group_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Rds", jsii.invoke(self, "onClusterPg", [cluster_parameter_group_name, account, region, partition]))

    @jsii.member(jsii_name="onClusterSnapshot")
    def on_cluster_snapshot(
        self,
        cluster_snapshot_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Rds":
        '''(experimental) Adds a resource of type cluster-snapshot to the statement.

        https://docs.aws.amazon.com/AmazonRDS/latest/AuroraUserGuide/Aurora.Managing.Backups.html

        :param cluster_snapshot_name: - Identifier for the clusterSnapshotName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag() - .ifClusterSnapshotTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__afe9603a235c9154ab146abaada6f7057a88ef4f46bb174dd81bf15e532762e7)
            check_type(argname="argument cluster_snapshot_name", value=cluster_snapshot_name, expected_type=type_hints["cluster_snapshot_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Rds", jsii.invoke(self, "onClusterSnapshot", [cluster_snapshot_name, account, region, partition]))

    @jsii.member(jsii_name="onDb")
    def on_db(
        self,
        db_instance_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Rds":
        '''(experimental) Adds a resource of type db to the statement.

        https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/Overview.DBInstance.html

        :param db_instance_name: - Identifier for the dbInstanceName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag() - .ifDatabaseClass() - .ifDatabaseEngine() - .ifDatabaseName() - .ifMultiAz() - .ifPiops() - .ifStorageEncrypted() - .ifStorageSize() - .ifVpc() - .ifDbTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__45859d47716715a15f970e88b36e35f0992d087c41bdddcdcab136ec35ca1789)
            check_type(argname="argument db_instance_name", value=db_instance_name, expected_type=type_hints["db_instance_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Rds", jsii.invoke(self, "onDb", [db_instance_name, account, region, partition]))

    @jsii.member(jsii_name="onDeployment")
    def on_deployment(
        self,
        blue_green_deployment_identifier: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Rds":
        '''(experimental) Adds a resource of type deployment to the statement.

        https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/blue-green-deployments.html

        :param blue_green_deployment_identifier: - Identifier for the blueGreenDeploymentIdentifier.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b0dda477f85080d12861f660ad999af5fd818e9c0e4f3f1710b548423161271c)
            check_type(argname="argument blue_green_deployment_identifier", value=blue_green_deployment_identifier, expected_type=type_hints["blue_green_deployment_identifier"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Rds", jsii.invoke(self, "onDeployment", [blue_green_deployment_identifier, account, region, partition]))

    @jsii.member(jsii_name="onEs")
    def on_es(
        self,
        subscription_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Rds":
        '''(experimental) Adds a resource of type es to the statement.

        https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/USER_Events.html

        :param subscription_name: - Identifier for the subscriptionName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag() - .ifEsTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7adc22584ea62303c693ca661f37a654689a818d603261488c2b740227e93456)
            check_type(argname="argument subscription_name", value=subscription_name, expected_type=type_hints["subscription_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Rds", jsii.invoke(self, "onEs", [subscription_name, account, region, partition]))

    @jsii.member(jsii_name="onGlobalCluster")
    def on_global_cluster(
        self,
        global_cluster: builtins.str,
        account: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Rds":
        '''(experimental) Adds a resource of type global-cluster to the statement.

        https://docs.aws.amazon.com/AmazonRDS/latest/AuroraUserGuide/aurora-global-database.html

        :param global_cluster: - Identifier for the globalCluster.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b7afacc989ab6ecd9eef72828755a71a190de07a518fed34135ed4fa35a5f7a0)
            check_type(argname="argument global_cluster", value=global_cluster, expected_type=type_hints["global_cluster"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Rds", jsii.invoke(self, "onGlobalCluster", [global_cluster, account, partition]))

    @jsii.member(jsii_name="onOg")
    def on_og(
        self,
        option_group_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Rds":
        '''(experimental) Adds a resource of type og to the statement.

        https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/USER_WorkingWithOptionGroups.html

        :param option_group_name: - Identifier for the optionGroupName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag() - .ifOgTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e3e645a2e2981b9724a1e21112e33dfc5d90d25d87d1d0cd16b4f5443c310b07)
            check_type(argname="argument option_group_name", value=option_group_name, expected_type=type_hints["option_group_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Rds", jsii.invoke(self, "onOg", [option_group_name, account, region, partition]))

    @jsii.member(jsii_name="onPg")
    def on_pg(
        self,
        parameter_group_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Rds":
        '''(experimental) Adds a resource of type pg to the statement.

        https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/USER_WorkingWithParamGroups.html

        :param parameter_group_name: - Identifier for the parameterGroupName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag() - .ifPgTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__07e4ad63f2cd24812d1b4657541f0d78aa8921e5fec85971c5873701d40889db)
            check_type(argname="argument parameter_group_name", value=parameter_group_name, expected_type=type_hints["parameter_group_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Rds", jsii.invoke(self, "onPg", [parameter_group_name, account, region, partition]))

    @jsii.member(jsii_name="onProxy")
    def on_proxy(
        self,
        db_proxy_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Rds":
        '''(experimental) Adds a resource of type proxy to the statement.

        https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/rds-proxy.html

        :param db_proxy_id: - Identifier for the dbProxyId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ca3fa0b80c5d33fc67f3c46944a111b65605bb0f187ab5dd29a2eb2a77eb5d97)
            check_type(argname="argument db_proxy_id", value=db_proxy_id, expected_type=type_hints["db_proxy_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Rds", jsii.invoke(self, "onProxy", [db_proxy_id, account, region, partition]))

    @jsii.member(jsii_name="onProxyEndpoint")
    def on_proxy_endpoint(
        self,
        db_proxy_endpoint_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Rds":
        '''(experimental) Adds a resource of type proxy-endpoint to the statement.

        https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/rds-proxy.html

        :param db_proxy_endpoint_id: - Identifier for the dbProxyEndpointId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1c1f65db78636309776e8ca086804675e55b2f585cad49a8e48b31d9396a2949)
            check_type(argname="argument db_proxy_endpoint_id", value=db_proxy_endpoint_id, expected_type=type_hints["db_proxy_endpoint_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Rds", jsii.invoke(self, "onProxyEndpoint", [db_proxy_endpoint_id, account, region, partition]))

    @jsii.member(jsii_name="onRi")
    def on_ri(
        self,
        reserved_db_instance_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Rds":
        '''(experimental) Adds a resource of type ri to the statement.

        https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/USER_WorkingWithReservedDBInstances.html

        :param reserved_db_instance_name: - Identifier for the reservedDbInstanceName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag() - .ifRiTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__24532d4209f76c86a28d3e4ef027dd6fa60f5a6a16eebd84191e6b746e5104bd)
            check_type(argname="argument reserved_db_instance_name", value=reserved_db_instance_name, expected_type=type_hints["reserved_db_instance_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Rds", jsii.invoke(self, "onRi", [reserved_db_instance_name, account, region, partition]))

    @jsii.member(jsii_name="onSecgrp")
    def on_secgrp(
        self,
        security_group_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Rds":
        '''(experimental) Adds a resource of type secgrp to the statement.

        https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/Overview.RDSSecurityGroups.html

        :param security_group_name: - Identifier for the securityGroupName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag() - .ifSecgrpTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__619642916d135fda15fa1f05a511ff579e26e63665f66ba5d2edc1220accfeee)
            check_type(argname="argument security_group_name", value=security_group_name, expected_type=type_hints["security_group_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Rds", jsii.invoke(self, "onSecgrp", [security_group_name, account, region, partition]))

    @jsii.member(jsii_name="onSnapshot")
    def on_snapshot(
        self,
        snapshot_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Rds":
        '''(experimental) Adds a resource of type snapshot to the statement.

        https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/USER_WorkingWithAutomatedBackups.html

        :param snapshot_name: - Identifier for the snapshotName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag() - .ifSnapshotTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__578aac8fc1d33ef9d3ab9a50053f913cbd0bd5944e14bf481a4d69f6e6ba8c61)
            check_type(argname="argument snapshot_name", value=snapshot_name, expected_type=type_hints["snapshot_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Rds", jsii.invoke(self, "onSnapshot", [snapshot_name, account, region, partition]))

    @jsii.member(jsii_name="onSubgrp")
    def on_subgrp(
        self,
        subnet_group_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Rds":
        '''(experimental) Adds a resource of type subgrp to the statement.

        https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/USER_VPC.Scenarios.html#USER_VPC.Scenario1

        :param subnet_group_name: - Identifier for the subnetGroupName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag() - .ifSubgrpTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__24f8117a1e8630e3f0a89eb775d3f05378543d573ba39b2add42cf95778d25b1)
            check_type(argname="argument subnet_group_name", value=subnet_group_name, expected_type=type_hints["subnet_group_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Rds", jsii.invoke(self, "onSubgrp", [subnet_group_name, account, region, partition]))

    @jsii.member(jsii_name="onTarget")
    def on_target(
        self,
        target_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Rds":
        '''(experimental) Adds a resource of type target to the statement.

        https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/rds-proxy.html

        :param target_id: - Identifier for the targetId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9af5c45f17edf1e6762e9c021bbf116d5c1f9cd0d903e60c339d96abb3decb01)
            check_type(argname="argument target_id", value=target_id, expected_type=type_hints["target_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Rds", jsii.invoke(self, "onTarget", [target_id, account, region, partition]))

    @jsii.member(jsii_name="onTargetGroup")
    def on_target_group(
        self,
        target_group_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Rds":
        '''(experimental) Adds a resource of type target-group to the statement.

        https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/rds-proxy.html

        :param target_group_id: - Identifier for the targetGroupId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2eed1e77192e80c3f804f6141259b68754e8db103e1387632806561f83e2a063)
            check_type(argname="argument target_group_id", value=target_group_id, expected_type=type_hints["target_group_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Rds", jsii.invoke(self, "onTargetGroup", [target_group_id, account, region, partition]))

    @jsii.member(jsii_name="toAddRoleToDBCluster")
    def to_add_role_to_db_cluster(self) -> "Rds":
        '''(experimental) Grants permission to associate an Identity and Access Management (IAM) role from an Aurora DB cluster.

        Access Level: Write

        Dependent actions:

        - iam:PassRole

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_AddRoleToDBCluster.html

        :stability: experimental
        '''
        return typing.cast("Rds", jsii.invoke(self, "toAddRoleToDBCluster", []))

    @jsii.member(jsii_name="toAddRoleToDBInstance")
    def to_add_role_to_db_instance(self) -> "Rds":
        '''(experimental) Grants permission to associate an AWS Identity and Access Management (IAM) role with a DB instance.

        Access Level: Write

        Dependent actions:

        - iam:PassRole

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_AddRoleToDBInstance.html

        :stability: experimental
        '''
        return typing.cast("Rds", jsii.invoke(self, "toAddRoleToDBInstance", []))

    @jsii.member(jsii_name="toAddSourceIdentifierToSubscription")
    def to_add_source_identifier_to_subscription(self) -> "Rds":
        '''(experimental) Grants permission to add a source identifier to an existing RDS event notification subscription.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_AddSourceIdentifierToSubscription.html

        :stability: experimental
        '''
        return typing.cast("Rds", jsii.invoke(self, "toAddSourceIdentifierToSubscription", []))

    @jsii.member(jsii_name="toAddTagsToResource")
    def to_add_tags_to_resource(self) -> "Rds":
        '''(experimental) Grants permission to add metadata tags to an Amazon RDS resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifReqTag()

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_AddTagsToResource.html

        :stability: experimental
        '''
        return typing.cast("Rds", jsii.invoke(self, "toAddTagsToResource", []))

    @jsii.member(jsii_name="toApplyPendingMaintenanceAction")
    def to_apply_pending_maintenance_action(self) -> "Rds":
        '''(experimental) Grants permission to apply a pending maintenance action to a resource.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_ApplyPendingMaintenanceAction.html

        :stability: experimental
        '''
        return typing.cast("Rds", jsii.invoke(self, "toApplyPendingMaintenanceAction", []))

    @jsii.member(jsii_name="toAuthorizeDBSecurityGroupIngress")
    def to_authorize_db_security_group_ingress(self) -> "Rds":
        '''(experimental) Grants permission to enable ingress to a DBSecurityGroup using one of two forms of authorization.

        Access Level: Permissions management

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_AuthorizeDBSecurityGroupIngress.html

        :stability: experimental
        '''
        return typing.cast("Rds", jsii.invoke(self, "toAuthorizeDBSecurityGroupIngress", []))

    @jsii.member(jsii_name="toBacktrackDBCluster")
    def to_backtrack_db_cluster(self) -> "Rds":
        '''(experimental) Grants permission to backtrack a DB cluster to a specific time, without creating a new DB cluster.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_BacktrackDBCluster.html

        :stability: experimental
        '''
        return typing.cast("Rds", jsii.invoke(self, "toBacktrackDBCluster", []))

    @jsii.member(jsii_name="toCancelExportTask")
    def to_cancel_export_task(self) -> "Rds":
        '''(experimental) Grants permission to cancel an export task in progress.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_CancelExportTask.html

        :stability: experimental
        '''
        return typing.cast("Rds", jsii.invoke(self, "toCancelExportTask", []))

    @jsii.member(jsii_name="toCopyDBClusterParameterGroup")
    def to_copy_db_cluster_parameter_group(self) -> "Rds":
        '''(experimental) Grants permission to copy the specified DB cluster parameter group.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - rds:AddTagsToResource

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_CopyDBClusterParameterGroup.html

        :stability: experimental
        '''
        return typing.cast("Rds", jsii.invoke(self, "toCopyDBClusterParameterGroup", []))

    @jsii.member(jsii_name="toCopyDBClusterSnapshot")
    def to_copy_db_cluster_snapshot(self) -> "Rds":
        '''(experimental) Grants permission to create a snapshot of a DB cluster.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - rds:AddTagsToResource

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_CopyDBClusterSnapshot.html

        :stability: experimental
        '''
        return typing.cast("Rds", jsii.invoke(self, "toCopyDBClusterSnapshot", []))

    @jsii.member(jsii_name="toCopyDBParameterGroup")
    def to_copy_db_parameter_group(self) -> "Rds":
        '''(experimental) Grants permission to copy the specified DB parameter group.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - rds:AddTagsToResource

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_CopyDBParameterGroup.html

        :stability: experimental
        '''
        return typing.cast("Rds", jsii.invoke(self, "toCopyDBParameterGroup", []))

    @jsii.member(jsii_name="toCopyDBSnapshot")
    def to_copy_db_snapshot(self) -> "Rds":
        '''(experimental) Grants permission to copy the specified DB snapshot.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifCopyOptionGroup()

        Dependent actions:

        - rds:AddTagsToResource

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_CopyDBSnapshot.html

        :stability: experimental
        '''
        return typing.cast("Rds", jsii.invoke(self, "toCopyDBSnapshot", []))

    @jsii.member(jsii_name="toCopyOptionGroup")
    def to_copy_option_group(self) -> "Rds":
        '''(experimental) Grants permission to copy the specified option group.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - rds:AddTagsToResource

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_CopyOptionGroup.html

        :stability: experimental
        '''
        return typing.cast("Rds", jsii.invoke(self, "toCopyOptionGroup", []))

    @jsii.member(jsii_name="toCreateBlueGreenDeployment")
    def to_create_blue_green_deployment(self) -> "Rds":
        '''(experimental) Grants permission to create a blue-green deployment for a given source cluster or instance.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsResourceTag()
        - .ifAwsTagKeys()
        - .ifClusterTag()
        - .ifClusterPgTag()
        - .ifDbTag()
        - .ifPgTag()
        - .ifReqTag()
        - .ifDatabaseEngine()
        - .ifDatabaseName()
        - .ifStorageEncrypted()
        - .ifDatabaseClass()
        - .ifStorageSize()
        - .ifMultiAz()
        - .ifPiops()
        - .ifVpc()

        Dependent actions:

        - rds:AddTagsToResource
        - rds:CreateDBCluster
        - rds:CreateDBClusterEndpoint
        - rds:CreateDBInstance
        - rds:CreateDBInstanceReadReplica

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_CreateBlueGreenDeployment.html

        :stability: experimental
        '''
        return typing.cast("Rds", jsii.invoke(self, "toCreateBlueGreenDeployment", []))

    @jsii.member(jsii_name="toCreateCustomDBEngineVersion")
    def to_create_custom_db_engine_version(self) -> "Rds":
        '''(experimental) Grants permission to create a custom engine version.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - iam:CreateServiceLinkedRole
        - mediaimport:CreateDatabaseBinarySnapshot
        - rds:AddTagsToResource

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_CreateCustomDBEngineVersion.html

        :stability: experimental
        '''
        return typing.cast("Rds", jsii.invoke(self, "toCreateCustomDBEngineVersion", []))

    @jsii.member(jsii_name="toCreateDBCluster")
    def to_create_db_cluster(self) -> "Rds":
        '''(experimental) Grants permission to create a new Amazon Aurora DB cluster.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifReqTag()
        - .ifDatabaseEngine()
        - .ifDatabaseName()
        - .ifStorageEncrypted()
        - .ifDatabaseClass()
        - .ifStorageSize()
        - .ifPiops()

        Dependent actions:

        - iam:PassRole
        - rds:AddTagsToResource
        - rds:CreateDBInstance

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_CreateDBCluster.html

        :stability: experimental
        '''
        return typing.cast("Rds", jsii.invoke(self, "toCreateDBCluster", []))

    @jsii.member(jsii_name="toCreateDBClusterEndpoint")
    def to_create_db_cluster_endpoint(self) -> "Rds":
        '''(experimental) Grants permission to create a new custom endpoint and associates it with an Amazon Aurora DB cluster.

        Access Level: Write

        Possible conditions:

        - .ifEndpointType()
        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - rds:AddTagsToResource

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_CreateDBClusterEndpoint.html

        :stability: experimental
        '''
        return typing.cast("Rds", jsii.invoke(self, "toCreateDBClusterEndpoint", []))

    @jsii.member(jsii_name="toCreateDBClusterParameterGroup")
    def to_create_db_cluster_parameter_group(self) -> "Rds":
        '''(experimental) Grants permission to create a new DB cluster parameter group.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifReqTag()

        Dependent actions:

        - rds:AddTagsToResource

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_CreateDBClusterParameterGroup.html

        :stability: experimental
        '''
        return typing.cast("Rds", jsii.invoke(self, "toCreateDBClusterParameterGroup", []))

    @jsii.member(jsii_name="toCreateDBClusterSnapshot")
    def to_create_db_cluster_snapshot(self) -> "Rds":
        '''(experimental) Grants permission to create a snapshot of a DB cluster.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifReqTag()

        Dependent actions:

        - rds:AddTagsToResource

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_CreateDBClusterSnapshot.html

        :stability: experimental
        '''
        return typing.cast("Rds", jsii.invoke(self, "toCreateDBClusterSnapshot", []))

    @jsii.member(jsii_name="toCreateDBInstance")
    def to_create_db_instance(self) -> "Rds":
        '''(experimental) Grants permission to create a new DB instance.

        Access Level: Write

        Possible conditions:

        - .ifBackupTarget()
        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifReqTag()

        Dependent actions:

        - iam:PassRole
        - rds:AddTagsToResource

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_CreateDBInstance.html

        :stability: experimental
        '''
        return typing.cast("Rds", jsii.invoke(self, "toCreateDBInstance", []))

    @jsii.member(jsii_name="toCreateDBInstanceReadReplica")
    def to_create_db_instance_read_replica(self) -> "Rds":
        '''(experimental) Grants permission to create a DB instance that acts as a Read Replica of a source DB instance.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifReqTag()

        Dependent actions:

        - iam:PassRole
        - rds:AddTagsToResource

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_CreateDBInstanceReadReplica.html

        :stability: experimental
        '''
        return typing.cast("Rds", jsii.invoke(self, "toCreateDBInstanceReadReplica", []))

    @jsii.member(jsii_name="toCreateDBParameterGroup")
    def to_create_db_parameter_group(self) -> "Rds":
        '''(experimental) Grants permission to create a new DB parameter group.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifReqTag()

        Dependent actions:

        - rds:AddTagsToResource

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_CreateDBParameterGroup.html

        :stability: experimental
        '''
        return typing.cast("Rds", jsii.invoke(self, "toCreateDBParameterGroup", []))

    @jsii.member(jsii_name="toCreateDBProxy")
    def to_create_db_proxy(self) -> "Rds":
        '''(experimental) Grants permission to create a database proxy.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - iam:PassRole

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_CreateDBProxy.html

        :stability: experimental
        '''
        return typing.cast("Rds", jsii.invoke(self, "toCreateDBProxy", []))

    @jsii.member(jsii_name="toCreateDBProxyEndpoint")
    def to_create_db_proxy_endpoint(self) -> "Rds":
        '''(experimental) Grants permission to create a database proxy endpoint.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_CreateDBProxyEndpoint.html

        :stability: experimental
        '''
        return typing.cast("Rds", jsii.invoke(self, "toCreateDBProxyEndpoint", []))

    @jsii.member(jsii_name="toCreateDBSecurityGroup")
    def to_create_db_security_group(self) -> "Rds":
        '''(experimental) Grants permission to create a new DB security group. DB security groups control access to a DB instance.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifReqTag()

        Dependent actions:

        - rds:AddTagsToResource

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_CreateDBSecurityGroup.html

        :stability: experimental
        '''
        return typing.cast("Rds", jsii.invoke(self, "toCreateDBSecurityGroup", []))

    @jsii.member(jsii_name="toCreateDBSnapshot")
    def to_create_db_snapshot(self) -> "Rds":
        '''(experimental) Grants permission to create a DBSnapshot.

        Access Level: Write

        Possible conditions:

        - .ifBackupTarget()
        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifReqTag()

        Dependent actions:

        - rds:AddTagsToResource

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_CreateDBSnapshot.html

        :stability: experimental
        '''
        return typing.cast("Rds", jsii.invoke(self, "toCreateDBSnapshot", []))

    @jsii.member(jsii_name="toCreateDBSubnetGroup")
    def to_create_db_subnet_group(self) -> "Rds":
        '''(experimental) Grants permission to create a new DB subnet group.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifReqTag()

        Dependent actions:

        - rds:AddTagsToResource

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_CreateDBSubnetGroup.html

        :stability: experimental
        '''
        return typing.cast("Rds", jsii.invoke(self, "toCreateDBSubnetGroup", []))

    @jsii.member(jsii_name="toCreateEventSubscription")
    def to_create_event_subscription(self) -> "Rds":
        '''(experimental) Grants permission to create an RDS event notification subscription.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifReqTag()

        Dependent actions:

        - rds:AddTagsToResource

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_CreateEventSubscription.html

        :stability: experimental
        '''
        return typing.cast("Rds", jsii.invoke(self, "toCreateEventSubscription", []))

    @jsii.member(jsii_name="toCreateGlobalCluster")
    def to_create_global_cluster(self) -> "Rds":
        '''(experimental) Grants permission to create an Aurora global database spread across multiple regions.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_CreateGlobalCluster.html

        :stability: experimental
        '''
        return typing.cast("Rds", jsii.invoke(self, "toCreateGlobalCluster", []))

    @jsii.member(jsii_name="toCreateOptionGroup")
    def to_create_option_group(self) -> "Rds":
        '''(experimental) Grants permission to create a new option group.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifReqTag()

        Dependent actions:

        - rds:AddTagsToResource

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_CreateOptionGroup.html

        :stability: experimental
        '''
        return typing.cast("Rds", jsii.invoke(self, "toCreateOptionGroup", []))

    @jsii.member(jsii_name="toCrossRegionCommunication")
    def to_cross_region_communication(self) -> "Rds":
        '''(experimental) Grants permission to access a resource in the remote Region when executing cross-Region operations, such as cross-Region snapshot copy or cross-Region read replica creation.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonRDS/latest/security_iam_service-with-iam.html#UsingWithRDS.IAM.Conditions

        :stability: experimental
        '''
        return typing.cast("Rds", jsii.invoke(self, "toCrossRegionCommunication", []))

    @jsii.member(jsii_name="toDeleteBlueGreenDeployment")
    def to_delete_blue_green_deployment(self) -> "Rds":
        '''(experimental) Grants permission to delete blue green deployments.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsResourceTag()
        - .ifAwsTagKeys()
        - .ifReqTag()

        Dependent actions:

        - rds:DeleteDBCluster
        - rds:DeleteDBClusterEndpoint
        - rds:DeleteDBInstance

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_DeleteBlueGreenDeployment.html

        :stability: experimental
        '''
        return typing.cast("Rds", jsii.invoke(self, "toDeleteBlueGreenDeployment", []))

    @jsii.member(jsii_name="toDeleteCustomDBEngineVersion")
    def to_delete_custom_db_engine_version(self) -> "Rds":
        '''(experimental) Grants permission to delete an existing custom engine version.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_DeleteCustomDBEngineVersion.html

        :stability: experimental
        '''
        return typing.cast("Rds", jsii.invoke(self, "toDeleteCustomDBEngineVersion", []))

    @jsii.member(jsii_name="toDeleteDBCluster")
    def to_delete_db_cluster(self) -> "Rds":
        '''(experimental) Grants permission to delete a previously provisioned DB cluster.

        Access Level: Write

        Dependent actions:

        - rds:DeleteDBInstance

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_DeleteDBCluster.html

        :stability: experimental
        '''
        return typing.cast("Rds", jsii.invoke(self, "toDeleteDBCluster", []))

    @jsii.member(jsii_name="toDeleteDBClusterEndpoint")
    def to_delete_db_cluster_endpoint(self) -> "Rds":
        '''(experimental) Grants permission to delete a custom endpoint and removes it from an Amazon Aurora DB cluster.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_DeleteDBClusterEndpoint.html

        :stability: experimental
        '''
        return typing.cast("Rds", jsii.invoke(self, "toDeleteDBClusterEndpoint", []))

    @jsii.member(jsii_name="toDeleteDBClusterParameterGroup")
    def to_delete_db_cluster_parameter_group(self) -> "Rds":
        '''(experimental) Grants permission to delete a specified DB cluster parameter group.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_DeleteDBClusterParameterGroup.html

        :stability: experimental
        '''
        return typing.cast("Rds", jsii.invoke(self, "toDeleteDBClusterParameterGroup", []))

    @jsii.member(jsii_name="toDeleteDBClusterSnapshot")
    def to_delete_db_cluster_snapshot(self) -> "Rds":
        '''(experimental) Grants permission to delete a DB cluster snapshot.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_DeleteDBClusterSnapshot.html

        :stability: experimental
        '''
        return typing.cast("Rds", jsii.invoke(self, "toDeleteDBClusterSnapshot", []))

    @jsii.member(jsii_name="toDeleteDBInstance")
    def to_delete_db_instance(self) -> "Rds":
        '''(experimental) Grants permission to delete a previously provisioned DB instance.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_DeleteDBInstance.html

        :stability: experimental
        '''
        return typing.cast("Rds", jsii.invoke(self, "toDeleteDBInstance", []))

    @jsii.member(jsii_name="toDeleteDBInstanceAutomatedBackup")
    def to_delete_db_instance_automated_backup(self) -> "Rds":
        '''(experimental) Grants permission to deletes automated backups based on the source instance's DbiResourceId value or the restorable instance's resource ID.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_DeleteDBInstanceAutomatedBackup.html

        :stability: experimental
        '''
        return typing.cast("Rds", jsii.invoke(self, "toDeleteDBInstanceAutomatedBackup", []))

    @jsii.member(jsii_name="toDeleteDBParameterGroup")
    def to_delete_db_parameter_group(self) -> "Rds":
        '''(experimental) Grants permission to delete a specified DBParameterGroup.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_DeleteDBParameterGroup.html

        :stability: experimental
        '''
        return typing.cast("Rds", jsii.invoke(self, "toDeleteDBParameterGroup", []))

    @jsii.member(jsii_name="toDeleteDBProxy")
    def to_delete_db_proxy(self) -> "Rds":
        '''(experimental) Grants permission to delete a database proxy.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_DeleteDBProxy.html

        :stability: experimental
        '''
        return typing.cast("Rds", jsii.invoke(self, "toDeleteDBProxy", []))

    @jsii.member(jsii_name="toDeleteDBProxyEndpoint")
    def to_delete_db_proxy_endpoint(self) -> "Rds":
        '''(experimental) Grants permission to delete a database proxy endpoint.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_DeleteDBProxyEndpoint.html

        :stability: experimental
        '''
        return typing.cast("Rds", jsii.invoke(self, "toDeleteDBProxyEndpoint", []))

    @jsii.member(jsii_name="toDeleteDBSecurityGroup")
    def to_delete_db_security_group(self) -> "Rds":
        '''(experimental) Grants permission to delete a DB security group.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_DeleteDBSecurityGroup.html

        :stability: experimental
        '''
        return typing.cast("Rds", jsii.invoke(self, "toDeleteDBSecurityGroup", []))

    @jsii.member(jsii_name="toDeleteDBSnapshot")
    def to_delete_db_snapshot(self) -> "Rds":
        '''(experimental) Grants permission to delete a DBSnapshot.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_DeleteDBSnapshot.html

        :stability: experimental
        '''
        return typing.cast("Rds", jsii.invoke(self, "toDeleteDBSnapshot", []))

    @jsii.member(jsii_name="toDeleteDBSubnetGroup")
    def to_delete_db_subnet_group(self) -> "Rds":
        '''(experimental) Grants permission to delete a DB subnet group.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_DeleteDBSubnetGroup.html

        :stability: experimental
        '''
        return typing.cast("Rds", jsii.invoke(self, "toDeleteDBSubnetGroup", []))

    @jsii.member(jsii_name="toDeleteEventSubscription")
    def to_delete_event_subscription(self) -> "Rds":
        '''(experimental) Grants permission to delete an RDS event notification subscription.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_DeleteEventSubscription.html

        :stability: experimental
        '''
        return typing.cast("Rds", jsii.invoke(self, "toDeleteEventSubscription", []))

    @jsii.member(jsii_name="toDeleteGlobalCluster")
    def to_delete_global_cluster(self) -> "Rds":
        '''(experimental) Grants permission to delete a global database cluster.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_DeleteGlobalCluster.html

        :stability: experimental
        '''
        return typing.cast("Rds", jsii.invoke(self, "toDeleteGlobalCluster", []))

    @jsii.member(jsii_name="toDeleteOptionGroup")
    def to_delete_option_group(self) -> "Rds":
        '''(experimental) Grants permission to delete an existing option group.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_DeleteOptionGroup.html

        :stability: experimental
        '''
        return typing.cast("Rds", jsii.invoke(self, "toDeleteOptionGroup", []))

    @jsii.member(jsii_name="toDeregisterDBProxyTargets")
    def to_deregister_db_proxy_targets(self) -> "Rds":
        '''(experimental) Grants permission to remove targets from a database proxy target group.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_DeregisterDBProxyTargets.html

        :stability: experimental
        '''
        return typing.cast("Rds", jsii.invoke(self, "toDeregisterDBProxyTargets", []))

    @jsii.member(jsii_name="toDescribeAccountAttributes")
    def to_describe_account_attributes(self) -> "Rds":
        '''(experimental) Grants permission to list all of the attributes for a customer account.

        Access Level: List

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_DescribeAccountAttributes.html

        :stability: experimental
        '''
        return typing.cast("Rds", jsii.invoke(self, "toDescribeAccountAttributes", []))

    @jsii.member(jsii_name="toDescribeBlueGreenDeployments")
    def to_describe_blue_green_deployments(self) -> "Rds":
        '''(experimental) Grants permission to describe blue green deployments.

        Access Level: List

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_DescribeBlueGreenDeployments.html

        :stability: experimental
        '''
        return typing.cast("Rds", jsii.invoke(self, "toDescribeBlueGreenDeployments", []))

    @jsii.member(jsii_name="toDescribeCertificates")
    def to_describe_certificates(self) -> "Rds":
        '''(experimental) Grants permission to list the set of CA certificates provided by Amazon RDS for this AWS account.

        Access Level: List

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_DescribeCertificates.html

        :stability: experimental
        '''
        return typing.cast("Rds", jsii.invoke(self, "toDescribeCertificates", []))

    @jsii.member(jsii_name="toDescribeDBClusterBacktracks")
    def to_describe_db_cluster_backtracks(self) -> "Rds":
        '''(experimental) Grants permission to return information about backtracks for a DB cluster.

        Access Level: List

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_DescribeDBClusterBacktracks.html

        :stability: experimental
        '''
        return typing.cast("Rds", jsii.invoke(self, "toDescribeDBClusterBacktracks", []))

    @jsii.member(jsii_name="toDescribeDBClusterEndpoints")
    def to_describe_db_cluster_endpoints(self) -> "Rds":
        '''(experimental) Grants permission to return information about endpoints for an Amazon Aurora DB cluster.

        Access Level: List

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_DescribeDBClusterEndpoints.html

        :stability: experimental
        '''
        return typing.cast("Rds", jsii.invoke(self, "toDescribeDBClusterEndpoints", []))

    @jsii.member(jsii_name="toDescribeDBClusterParameterGroups")
    def to_describe_db_cluster_parameter_groups(self) -> "Rds":
        '''(experimental) Grants permission to return a list of DBClusterParameterGroup descriptions.

        Access Level: List

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_DescribeDBClusterParameterGroups.html

        :stability: experimental
        '''
        return typing.cast("Rds", jsii.invoke(self, "toDescribeDBClusterParameterGroups", []))

    @jsii.member(jsii_name="toDescribeDBClusterParameters")
    def to_describe_db_cluster_parameters(self) -> "Rds":
        '''(experimental) Grants permission to return the detailed parameter list for a particular DB cluster parameter group.

        Access Level: List

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_DescribeDBClusterParameters.html

        :stability: experimental
        '''
        return typing.cast("Rds", jsii.invoke(self, "toDescribeDBClusterParameters", []))

    @jsii.member(jsii_name="toDescribeDBClusters")
    def to_describe_db_clusters(self) -> "Rds":
        '''(experimental) Grants permission to return information about provisioned Aurora DB clusters.

        Access Level: List

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_DescribeDBClusters.html

        :stability: experimental
        '''
        return typing.cast("Rds", jsii.invoke(self, "toDescribeDBClusters", []))

    @jsii.member(jsii_name="toDescribeDBClusterSnapshotAttributes")
    def to_describe_db_cluster_snapshot_attributes(self) -> "Rds":
        '''(experimental) Grants permission to return a list of DB cluster snapshot attribute names and values for a manual DB cluster snapshot.

        Access Level: List

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_DescribeDBClusterSnapshotAttributes.html

        :stability: experimental
        '''
        return typing.cast("Rds", jsii.invoke(self, "toDescribeDBClusterSnapshotAttributes", []))

    @jsii.member(jsii_name="toDescribeDBClusterSnapshots")
    def to_describe_db_cluster_snapshots(self) -> "Rds":
        '''(experimental) Grants permission to return information about DB cluster snapshots.

        Access Level: List

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_DescribeDBClusterSnapshots.html

        :stability: experimental
        '''
        return typing.cast("Rds", jsii.invoke(self, "toDescribeDBClusterSnapshots", []))

    @jsii.member(jsii_name="toDescribeDBEngineVersions")
    def to_describe_db_engine_versions(self) -> "Rds":
        '''(experimental) Grants permission to return a list of the available DB engines.

        Access Level: List

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_DescribeDBEngineVersions.html

        :stability: experimental
        '''
        return typing.cast("Rds", jsii.invoke(self, "toDescribeDBEngineVersions", []))

    @jsii.member(jsii_name="toDescribeDBInstanceAutomatedBackups")
    def to_describe_db_instance_automated_backups(self) -> "Rds":
        '''(experimental) Grants permission to return a list of automated backups for both current and deleted instances.

        Access Level: List

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_DescribeDBInstanceAutomatedBackups.html

        :stability: experimental
        '''
        return typing.cast("Rds", jsii.invoke(self, "toDescribeDBInstanceAutomatedBackups", []))

    @jsii.member(jsii_name="toDescribeDBInstances")
    def to_describe_db_instances(self) -> "Rds":
        '''(experimental) Grants permission to return information about provisioned RDS instances.

        Access Level: List

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_DescribeDBInstances.html

        :stability: experimental
        '''
        return typing.cast("Rds", jsii.invoke(self, "toDescribeDBInstances", []))

    @jsii.member(jsii_name="toDescribeDBLogFiles")
    def to_describe_db_log_files(self) -> "Rds":
        '''(experimental) Grants permission to return a list of DB log files for the DB instance.

        Access Level: List

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_DescribeDBLogFiles.html

        :stability: experimental
        '''
        return typing.cast("Rds", jsii.invoke(self, "toDescribeDBLogFiles", []))

    @jsii.member(jsii_name="toDescribeDBParameterGroups")
    def to_describe_db_parameter_groups(self) -> "Rds":
        '''(experimental) Grants permission to return a list of DBParameterGroup descriptions.

        Access Level: List

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_DescribeDBParameterGroups.html

        :stability: experimental
        '''
        return typing.cast("Rds", jsii.invoke(self, "toDescribeDBParameterGroups", []))

    @jsii.member(jsii_name="toDescribeDBParameters")
    def to_describe_db_parameters(self) -> "Rds":
        '''(experimental) Grants permission to return the detailed parameter list for a particular DB parameter group.

        Access Level: List

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_DescribeDBParameters.html

        :stability: experimental
        '''
        return typing.cast("Rds", jsii.invoke(self, "toDescribeDBParameters", []))

    @jsii.member(jsii_name="toDescribeDBProxies")
    def to_describe_db_proxies(self) -> "Rds":
        '''(experimental) Grants permission to view proxies.

        Access Level: List

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_DescribeDBProxies.html

        :stability: experimental
        '''
        return typing.cast("Rds", jsii.invoke(self, "toDescribeDBProxies", []))

    @jsii.member(jsii_name="toDescribeDBProxyEndpoints")
    def to_describe_db_proxy_endpoints(self) -> "Rds":
        '''(experimental) Grants permission to view proxy endpoints.

        Access Level: List

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_DescribeDBProxyEndpoints.html

        :stability: experimental
        '''
        return typing.cast("Rds", jsii.invoke(self, "toDescribeDBProxyEndpoints", []))

    @jsii.member(jsii_name="toDescribeDBProxyTargetGroups")
    def to_describe_db_proxy_target_groups(self) -> "Rds":
        '''(experimental) Grants permission to view database proxy target group details.

        Access Level: List

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_DescribeDBProxyTargetGroups.html

        :stability: experimental
        '''
        return typing.cast("Rds", jsii.invoke(self, "toDescribeDBProxyTargetGroups", []))

    @jsii.member(jsii_name="toDescribeDBProxyTargets")
    def to_describe_db_proxy_targets(self) -> "Rds":
        '''(experimental) Grants permission to view database proxy target details.

        Access Level: List

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_DescribeDBProxyTargets.html

        :stability: experimental
        '''
        return typing.cast("Rds", jsii.invoke(self, "toDescribeDBProxyTargets", []))

    @jsii.member(jsii_name="toDescribeDBSecurityGroups")
    def to_describe_db_security_groups(self) -> "Rds":
        '''(experimental) Grants permission to return a list of DBSecurityGroup descriptions.

        Access Level: List

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_DescribeDBSecurityGroups.html

        :stability: experimental
        '''
        return typing.cast("Rds", jsii.invoke(self, "toDescribeDBSecurityGroups", []))

    @jsii.member(jsii_name="toDescribeDBSnapshotAttributes")
    def to_describe_db_snapshot_attributes(self) -> "Rds":
        '''(experimental) Grants permission to return a list of DB snapshot attribute names and values for a manual DB snapshot.

        Access Level: List

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_DescribeDBSnapshotAttributes.html

        :stability: experimental
        '''
        return typing.cast("Rds", jsii.invoke(self, "toDescribeDBSnapshotAttributes", []))

    @jsii.member(jsii_name="toDescribeDBSnapshots")
    def to_describe_db_snapshots(self) -> "Rds":
        '''(experimental) Grants permission to return information about DB snapshots.

        Access Level: List

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_DescribeDBSnapshots.html

        :stability: experimental
        '''
        return typing.cast("Rds", jsii.invoke(self, "toDescribeDBSnapshots", []))

    @jsii.member(jsii_name="toDescribeDBSubnetGroups")
    def to_describe_db_subnet_groups(self) -> "Rds":
        '''(experimental) Grants permission to return a list of DBSubnetGroup descriptions.

        Access Level: List

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_DescribeDBSubnetGroups.html

        :stability: experimental
        '''
        return typing.cast("Rds", jsii.invoke(self, "toDescribeDBSubnetGroups", []))

    @jsii.member(jsii_name="toDescribeEngineDefaultClusterParameters")
    def to_describe_engine_default_cluster_parameters(self) -> "Rds":
        '''(experimental) Grants permission to return the default engine and system parameter information for the cluster database engine.

        Access Level: List

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_DescribeEngineDefaultClusterParameters.html

        :stability: experimental
        '''
        return typing.cast("Rds", jsii.invoke(self, "toDescribeEngineDefaultClusterParameters", []))

    @jsii.member(jsii_name="toDescribeEngineDefaultParameters")
    def to_describe_engine_default_parameters(self) -> "Rds":
        '''(experimental) Grants permission to return the default engine and system parameter information for the specified database engine.

        Access Level: List

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_DescribeEngineDefaultParameters.html

        :stability: experimental
        '''
        return typing.cast("Rds", jsii.invoke(self, "toDescribeEngineDefaultParameters", []))

    @jsii.member(jsii_name="toDescribeEventCategories")
    def to_describe_event_categories(self) -> "Rds":
        '''(experimental) Grants permission to display a list of categories for all event source types, or, if specified, for a specified source type.

        Access Level: List

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_DescribeEventCategories.html

        :stability: experimental
        '''
        return typing.cast("Rds", jsii.invoke(self, "toDescribeEventCategories", []))

    @jsii.member(jsii_name="toDescribeEvents")
    def to_describe_events(self) -> "Rds":
        '''(experimental) Grants permission to return events related to DB instances, DB security groups, DB snapshots, and DB parameter groups for the past 14 days.

        Access Level: List

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_DescribeEvents.html

        :stability: experimental
        '''
        return typing.cast("Rds", jsii.invoke(self, "toDescribeEvents", []))

    @jsii.member(jsii_name="toDescribeEventSubscriptions")
    def to_describe_event_subscriptions(self) -> "Rds":
        '''(experimental) Grants permission to list all the subscription descriptions for a customer account.

        Access Level: List

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_DescribeEventSubscriptions.html

        :stability: experimental
        '''
        return typing.cast("Rds", jsii.invoke(self, "toDescribeEventSubscriptions", []))

    @jsii.member(jsii_name="toDescribeExportTasks")
    def to_describe_export_tasks(self) -> "Rds":
        '''(experimental) Grants permission to return information about the export tasks.

        Access Level: List

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_DescribeExportTasks.html

        :stability: experimental
        '''
        return typing.cast("Rds", jsii.invoke(self, "toDescribeExportTasks", []))

    @jsii.member(jsii_name="toDescribeGlobalClusters")
    def to_describe_global_clusters(self) -> "Rds":
        '''(experimental) Grants permission to return information about Aurora global database clusters.

        Access Level: List

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_DescribeGlobalClusters.html

        :stability: experimental
        '''
        return typing.cast("Rds", jsii.invoke(self, "toDescribeGlobalClusters", []))

    @jsii.member(jsii_name="toDescribeOptionGroupOptions")
    def to_describe_option_group_options(self) -> "Rds":
        '''(experimental) Grants permission to describe all available options.

        Access Level: List

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_DescribeOptionGroupOptions.html

        :stability: experimental
        '''
        return typing.cast("Rds", jsii.invoke(self, "toDescribeOptionGroupOptions", []))

    @jsii.member(jsii_name="toDescribeOptionGroups")
    def to_describe_option_groups(self) -> "Rds":
        '''(experimental) Grants permission to describe the available option groups.

        Access Level: List

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_DescribeOptionGroups.html

        :stability: experimental
        '''
        return typing.cast("Rds", jsii.invoke(self, "toDescribeOptionGroups", []))

    @jsii.member(jsii_name="toDescribeOrderableDBInstanceOptions")
    def to_describe_orderable_db_instance_options(self) -> "Rds":
        '''(experimental) Grants permission to return a list of orderable DB instance options for the specified engine.

        Access Level: List

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_DescribeOrderableDBInstanceOptions.html

        :stability: experimental
        '''
        return typing.cast("Rds", jsii.invoke(self, "toDescribeOrderableDBInstanceOptions", []))

    @jsii.member(jsii_name="toDescribePendingMaintenanceActions")
    def to_describe_pending_maintenance_actions(self) -> "Rds":
        '''(experimental) Grants permission to return a list of resources (for example, DB instances) that have at least one pending maintenance action.

        Access Level: List

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_DescribePendingMaintenanceActions.html

        :stability: experimental
        '''
        return typing.cast("Rds", jsii.invoke(self, "toDescribePendingMaintenanceActions", []))

    @jsii.member(jsii_name="toDescribeRecommendationGroups")
    def to_describe_recommendation_groups(self) -> "Rds":
        '''(experimental) Grants permission to return information about recommendation groups.

        Access Level: Read

        https://docs.aws.amazon.com/AmazonRDS/latest/USER_Recommendations.html

        :stability: experimental
        '''
        return typing.cast("Rds", jsii.invoke(self, "toDescribeRecommendationGroups", []))

    @jsii.member(jsii_name="toDescribeRecommendations")
    def to_describe_recommendations(self) -> "Rds":
        '''(experimental) Grants permission to return information about recommendations.

        Access Level: Read

        https://docs.aws.amazon.com/AmazonRDS/latest/USER_Recommendations.html

        :stability: experimental
        '''
        return typing.cast("Rds", jsii.invoke(self, "toDescribeRecommendations", []))

    @jsii.member(jsii_name="toDescribeReservedDBInstances")
    def to_describe_reserved_db_instances(self) -> "Rds":
        '''(experimental) Grants permission to return information about reserved DB instances for this account, or about a specified reserved DB instance.

        Access Level: List

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_DescribeReservedDBInstances.html

        :stability: experimental
        '''
        return typing.cast("Rds", jsii.invoke(self, "toDescribeReservedDBInstances", []))

    @jsii.member(jsii_name="toDescribeReservedDBInstancesOfferings")
    def to_describe_reserved_db_instances_offerings(self) -> "Rds":
        '''(experimental) Grants permission to list available reserved DB instance offerings.

        Access Level: List

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_DescribeReservedDBInstancesOfferings.html

        :stability: experimental
        '''
        return typing.cast("Rds", jsii.invoke(self, "toDescribeReservedDBInstancesOfferings", []))

    @jsii.member(jsii_name="toDescribeSourceRegions")
    def to_describe_source_regions(self) -> "Rds":
        '''(experimental) Grants permission to return a list of the source AWS Regions where the current AWS Region can create a Read Replica or copy a DB snapshot from.

        Access Level: List

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_DescribeSourceRegions.html

        :stability: experimental
        '''
        return typing.cast("Rds", jsii.invoke(self, "toDescribeSourceRegions", []))

    @jsii.member(jsii_name="toDescribeValidDBInstanceModifications")
    def to_describe_valid_db_instance_modifications(self) -> "Rds":
        '''(experimental) Grants permission to list available modifications you can make to your DB instance.

        Access Level: List

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_DescribeValidDBInstanceModifications.html

        :stability: experimental
        '''
        return typing.cast("Rds", jsii.invoke(self, "toDescribeValidDBInstanceModifications", []))

    @jsii.member(jsii_name="toDownloadCompleteDBLogFile")
    def to_download_complete_db_log_file(self) -> "Rds":
        '''(experimental) Grants permission to download specified log file.

        Access Level: Read

        https://docs.aws.amazon.com/AmazonRDS/latest/USER_LogAccess.html

        :stability: experimental
        '''
        return typing.cast("Rds", jsii.invoke(self, "toDownloadCompleteDBLogFile", []))

    @jsii.member(jsii_name="toDownloadDBLogFilePortion")
    def to_download_db_log_file_portion(self) -> "Rds":
        '''(experimental) Grants permission to download all or a portion of the specified log file, up to 1 MB in size.

        Access Level: Read

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_DownloadDBLogFilePortion.html

        :stability: experimental
        '''
        return typing.cast("Rds", jsii.invoke(self, "toDownloadDBLogFilePortion", []))

    @jsii.member(jsii_name="toFailoverDBCluster")
    def to_failover_db_cluster(self) -> "Rds":
        '''(experimental) Grants permission to force a failover for a DB cluster.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_FailoverDBCluster.html

        :stability: experimental
        '''
        return typing.cast("Rds", jsii.invoke(self, "toFailoverDBCluster", []))

    @jsii.member(jsii_name="toFailoverGlobalCluster")
    def to_failover_global_cluster(self) -> "Rds":
        '''(experimental) Grants permission to failover a global cluster.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_FailoverGlobalCluster.html

        :stability: experimental
        '''
        return typing.cast("Rds", jsii.invoke(self, "toFailoverGlobalCluster", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Rds":
        '''(experimental) Grants permission to list all tags on an Amazon RDS resource.

        Access Level: Read

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("Rds", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toModifyActivityStream")
    def to_modify_activity_stream(self) -> "Rds":
        '''(experimental) Grants permission to modify a database activity stream.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_ModifyActivityStream.html

        :stability: experimental
        '''
        return typing.cast("Rds", jsii.invoke(self, "toModifyActivityStream", []))

    @jsii.member(jsii_name="toModifyCertificates")
    def to_modify_certificates(self) -> "Rds":
        '''(experimental) Grants permission to modify the system-default Secure Sockets Layer/Transport Layer Security (SSL/TLS) certificate for Amazon RDS for new DB instances.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_ModifyCertificates.html

        :stability: experimental
        '''
        return typing.cast("Rds", jsii.invoke(self, "toModifyCertificates", []))

    @jsii.member(jsii_name="toModifyCurrentDBClusterCapacity")
    def to_modify_current_db_cluster_capacity(self) -> "Rds":
        '''(experimental) Grants permission to modify current cluster capacity for an Amazon Aurora Severless DB cluster.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_ModifyCurrentDBClusterCapacity.html

        :stability: experimental
        '''
        return typing.cast("Rds", jsii.invoke(self, "toModifyCurrentDBClusterCapacity", []))

    @jsii.member(jsii_name="toModifyCustomDBEngineVersion")
    def to_modify_custom_db_engine_version(self) -> "Rds":
        '''(experimental) Grants permission to modify an existing custom engine version.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_ModifyCustomDBEngineVersion.html

        :stability: experimental
        '''
        return typing.cast("Rds", jsii.invoke(self, "toModifyCustomDBEngineVersion", []))

    @jsii.member(jsii_name="toModifyDBCluster")
    def to_modify_db_cluster(self) -> "Rds":
        '''(experimental) Grants permission to modify a setting for an Amazon Aurora DB cluster.

        Access Level: Write

        Possible conditions:

        - .ifDatabaseClass()
        - .ifStorageSize()
        - .ifPiops()

        Dependent actions:

        - iam:PassRole
        - rds:ModifyDBInstance

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_ModifyDBCluster.html

        :stability: experimental
        '''
        return typing.cast("Rds", jsii.invoke(self, "toModifyDBCluster", []))

    @jsii.member(jsii_name="toModifyDBClusterEndpoint")
    def to_modify_db_cluster_endpoint(self) -> "Rds":
        '''(experimental) Grants permission to modify the properties of an endpoint in an Amazon Aurora DB cluster.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_ModifyDBClusterEndpoint.html

        :stability: experimental
        '''
        return typing.cast("Rds", jsii.invoke(self, "toModifyDBClusterEndpoint", []))

    @jsii.member(jsii_name="toModifyDBClusterParameterGroup")
    def to_modify_db_cluster_parameter_group(self) -> "Rds":
        '''(experimental) Grants permission to modify the parameters of a DB cluster parameter group.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_ModifyDBClusterParameterGroup.html

        :stability: experimental
        '''
        return typing.cast("Rds", jsii.invoke(self, "toModifyDBClusterParameterGroup", []))

    @jsii.member(jsii_name="toModifyDBClusterSnapshotAttribute")
    def to_modify_db_cluster_snapshot_attribute(self) -> "Rds":
        '''(experimental) Grants permission to add an attribute and values to, or removes an attribute and values from, a manual DB cluster snapshot.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_ModifyDBClusterSnapshotAttribute.html

        :stability: experimental
        '''
        return typing.cast("Rds", jsii.invoke(self, "toModifyDBClusterSnapshotAttribute", []))

    @jsii.member(jsii_name="toModifyDBInstance")
    def to_modify_db_instance(self) -> "Rds":
        '''(experimental) Grants permission to modify settings for a DB instance.

        Access Level: Write

        Dependent actions:

        - iam:PassRole

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_ModifyDBInstance.html

        :stability: experimental
        '''
        return typing.cast("Rds", jsii.invoke(self, "toModifyDBInstance", []))

    @jsii.member(jsii_name="toModifyDBParameterGroup")
    def to_modify_db_parameter_group(self) -> "Rds":
        '''(experimental) Grants permission to modify the parameters of a DB parameter group.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_ModifyDBParameterGroup.html

        :stability: experimental
        '''
        return typing.cast("Rds", jsii.invoke(self, "toModifyDBParameterGroup", []))

    @jsii.member(jsii_name="toModifyDBProxy")
    def to_modify_db_proxy(self) -> "Rds":
        '''(experimental) Grants permission to modify database proxy.

        Access Level: Write

        Dependent actions:

        - iam:PassRole

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_ModifyDBProxy.html

        :stability: experimental
        '''
        return typing.cast("Rds", jsii.invoke(self, "toModifyDBProxy", []))

    @jsii.member(jsii_name="toModifyDBProxyEndpoint")
    def to_modify_db_proxy_endpoint(self) -> "Rds":
        '''(experimental) Grants permission to modify database proxy endpoint.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_ModifyDBProxyEndpoint.html

        :stability: experimental
        '''
        return typing.cast("Rds", jsii.invoke(self, "toModifyDBProxyEndpoint", []))

    @jsii.member(jsii_name="toModifyDBProxyTargetGroup")
    def to_modify_db_proxy_target_group(self) -> "Rds":
        '''(experimental) Grants permission to modify target group for a database proxy.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_ModifyDBProxyTargetGroup.html

        :stability: experimental
        '''
        return typing.cast("Rds", jsii.invoke(self, "toModifyDBProxyTargetGroup", []))

    @jsii.member(jsii_name="toModifyDBSnapshot")
    def to_modify_db_snapshot(self) -> "Rds":
        '''(experimental) Grants permission to update a manual DB snapshot, which can be encrypted or not encrypted, with a new engine version.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_ModifyDBSnapshot.html

        :stability: experimental
        '''
        return typing.cast("Rds", jsii.invoke(self, "toModifyDBSnapshot", []))

    @jsii.member(jsii_name="toModifyDBSnapshotAttribute")
    def to_modify_db_snapshot_attribute(self) -> "Rds":
        '''(experimental) Grants permission to add an attribute and values to, or removes an attribute and values from, a manual DB snapshot.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_ModifyDBSnapshotAttribute.html

        :stability: experimental
        '''
        return typing.cast("Rds", jsii.invoke(self, "toModifyDBSnapshotAttribute", []))

    @jsii.member(jsii_name="toModifyDBSubnetGroup")
    def to_modify_db_subnet_group(self) -> "Rds":
        '''(experimental) Grants permission to modify an existing DB subnet group.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_ModifyDBSubnetGroup.html

        :stability: experimental
        '''
        return typing.cast("Rds", jsii.invoke(self, "toModifyDBSubnetGroup", []))

    @jsii.member(jsii_name="toModifyEventSubscription")
    def to_modify_event_subscription(self) -> "Rds":
        '''(experimental) Grants permission to modify an existing RDS event notification subscription.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_ModifyEventSubscription.html

        :stability: experimental
        '''
        return typing.cast("Rds", jsii.invoke(self, "toModifyEventSubscription", []))

    @jsii.member(jsii_name="toModifyGlobalCluster")
    def to_modify_global_cluster(self) -> "Rds":
        '''(experimental) Grants permission to modify a setting for an Amazon Aurora global cluster.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_ModifyGlobalCluster.html

        :stability: experimental
        '''
        return typing.cast("Rds", jsii.invoke(self, "toModifyGlobalCluster", []))

    @jsii.member(jsii_name="toModifyOptionGroup")
    def to_modify_option_group(self) -> "Rds":
        '''(experimental) Grants permission to modify an existing option group.

        Access Level: Write

        Dependent actions:

        - iam:PassRole

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_ModifyOptionGroup.html

        :stability: experimental
        '''
        return typing.cast("Rds", jsii.invoke(self, "toModifyOptionGroup", []))

    @jsii.member(jsii_name="toModifyRecommendation")
    def to_modify_recommendation(self) -> "Rds":
        '''(experimental) Grants permission to modify recommendation.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonRDS/latest/USER_Recommendations.html

        :stability: experimental
        '''
        return typing.cast("Rds", jsii.invoke(self, "toModifyRecommendation", []))

    @jsii.member(jsii_name="toPromoteReadReplica")
    def to_promote_read_replica(self) -> "Rds":
        '''(experimental) Grants permission to promote a Read Replica DB instance to a standalone DB instance.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_PromoteReadReplica.html

        :stability: experimental
        '''
        return typing.cast("Rds", jsii.invoke(self, "toPromoteReadReplica", []))

    @jsii.member(jsii_name="toPromoteReadReplicaDBCluster")
    def to_promote_read_replica_db_cluster(self) -> "Rds":
        '''(experimental) Grants permission to promote a Read Replica DB cluster to a standalone DB cluster.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_PromoteReadReplicaDBCluster.html

        :stability: experimental
        '''
        return typing.cast("Rds", jsii.invoke(self, "toPromoteReadReplicaDBCluster", []))

    @jsii.member(jsii_name="toPurchaseReservedDBInstancesOffering")
    def to_purchase_reserved_db_instances_offering(self) -> "Rds":
        '''(experimental) Grants permission to purchase a reserved DB instance offering.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_PurchaseReservedDBInstancesOffering.html

        :stability: experimental
        '''
        return typing.cast("Rds", jsii.invoke(self, "toPurchaseReservedDBInstancesOffering", []))

    @jsii.member(jsii_name="toRebootDBCluster")
    def to_reboot_db_cluster(self) -> "Rds":
        '''(experimental) Grants permission to reboot a previously provisioned DB cluster.

        Access Level: Write

        Dependent actions:

        - rds:RebootDBInstance

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_RebootDBCluster.html

        :stability: experimental
        '''
        return typing.cast("Rds", jsii.invoke(self, "toRebootDBCluster", []))

    @jsii.member(jsii_name="toRebootDBInstance")
    def to_reboot_db_instance(self) -> "Rds":
        '''(experimental) Grants permission to restart the database engine service.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_RebootDBInstance.html

        :stability: experimental
        '''
        return typing.cast("Rds", jsii.invoke(self, "toRebootDBInstance", []))

    @jsii.member(jsii_name="toRegisterDBProxyTargets")
    def to_register_db_proxy_targets(self) -> "Rds":
        '''(experimental) Grants permission to add targets to a database proxy target group.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_RegisterDBProxyTargets.html

        :stability: experimental
        '''
        return typing.cast("Rds", jsii.invoke(self, "toRegisterDBProxyTargets", []))

    @jsii.member(jsii_name="toRemoveFromGlobalCluster")
    def to_remove_from_global_cluster(self) -> "Rds":
        '''(experimental) Grants permission to detach an Aurora secondary cluster from an Aurora global database cluster.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_RemoveFromGlobalCluster.html

        :stability: experimental
        '''
        return typing.cast("Rds", jsii.invoke(self, "toRemoveFromGlobalCluster", []))

    @jsii.member(jsii_name="toRemoveRoleFromDBCluster")
    def to_remove_role_from_db_cluster(self) -> "Rds":
        '''(experimental) Grants permission to disassociate an AWS Identity and Access Management (IAM) role from an Amazon Aurora DB cluster.

        Access Level: Write

        Dependent actions:

        - iam:PassRole

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_RemoveRoleFromDBCluster.html

        :stability: experimental
        '''
        return typing.cast("Rds", jsii.invoke(self, "toRemoveRoleFromDBCluster", []))

    @jsii.member(jsii_name="toRemoveRoleFromDBInstance")
    def to_remove_role_from_db_instance(self) -> "Rds":
        '''(experimental) Grants permission to disassociate an AWS Identity and Access Management (IAM) role from a DB instance.

        Access Level: Write

        Dependent actions:

        - iam:PassRole

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_RemoveRoleFromDBInstance.html

        :stability: experimental
        '''
        return typing.cast("Rds", jsii.invoke(self, "toRemoveRoleFromDBInstance", []))

    @jsii.member(jsii_name="toRemoveSourceIdentifierFromSubscription")
    def to_remove_source_identifier_from_subscription(self) -> "Rds":
        '''(experimental) Grants permission to remove a source identifier from an existing RDS event notification subscription.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_RemoveSourceIdentifierFromSubscription.html

        :stability: experimental
        '''
        return typing.cast("Rds", jsii.invoke(self, "toRemoveSourceIdentifierFromSubscription", []))

    @jsii.member(jsii_name="toRemoveTagsFromResource")
    def to_remove_tags_from_resource(self) -> "Rds":
        '''(experimental) Grants permission to remove metadata tags from an Amazon RDS resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifReqTag()

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_RemoveTagsFromResource.html

        :stability: experimental
        '''
        return typing.cast("Rds", jsii.invoke(self, "toRemoveTagsFromResource", []))

    @jsii.member(jsii_name="toResetDBClusterParameterGroup")
    def to_reset_db_cluster_parameter_group(self) -> "Rds":
        '''(experimental) Grants permission to modify the parameters of a DB cluster parameter group to the default value.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_ResetDBClusterParameterGroup.html

        :stability: experimental
        '''
        return typing.cast("Rds", jsii.invoke(self, "toResetDBClusterParameterGroup", []))

    @jsii.member(jsii_name="toResetDBParameterGroup")
    def to_reset_db_parameter_group(self) -> "Rds":
        '''(experimental) Grants permission to modify the parameters of a DB parameter group to the engine/system default value.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_ResetDBParameterGroup.html

        :stability: experimental
        '''
        return typing.cast("Rds", jsii.invoke(self, "toResetDBParameterGroup", []))

    @jsii.member(jsii_name="toRestoreDBClusterFromS3")
    def to_restore_db_cluster_from_s3(self) -> "Rds":
        '''(experimental) Grants permission to create an Amazon Aurora DB cluster from data stored in an Amazon S3 bucket.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifReqTag()
        - .ifDatabaseEngine()
        - .ifDatabaseName()
        - .ifStorageEncrypted()

        Dependent actions:

        - iam:PassRole
        - rds:AddTagsToResource

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_RestoreDBClusterFromS3.html

        :stability: experimental
        '''
        return typing.cast("Rds", jsii.invoke(self, "toRestoreDBClusterFromS3", []))

    @jsii.member(jsii_name="toRestoreDBClusterFromSnapshot")
    def to_restore_db_cluster_from_snapshot(self) -> "Rds":
        '''(experimental) Grants permission to create a new DB cluster from a DB cluster snapshot.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifReqTag()
        - .ifDatabaseClass()
        - .ifStorageSize()
        - .ifPiops()

        Dependent actions:

        - iam:PassRole
        - rds:AddTagsToResource
        - rds:CreateDBInstance

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_RestoreDBClusterFromSnapshot.html

        :stability: experimental
        '''
        return typing.cast("Rds", jsii.invoke(self, "toRestoreDBClusterFromSnapshot", []))

    @jsii.member(jsii_name="toRestoreDBClusterToPointInTime")
    def to_restore_db_cluster_to_point_in_time(self) -> "Rds":
        '''(experimental) Grants permission to restore a DB cluster to an arbitrary point in time.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifReqTag()
        - .ifDatabaseClass()
        - .ifStorageSize()
        - .ifPiops()

        Dependent actions:

        - iam:PassRole
        - rds:AddTagsToResource
        - rds:CreateDBInstance

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_RestoreDBClusterToPointInTime.html

        :stability: experimental
        '''
        return typing.cast("Rds", jsii.invoke(self, "toRestoreDBClusterToPointInTime", []))

    @jsii.member(jsii_name="toRestoreDBInstanceFromDBSnapshot")
    def to_restore_db_instance_from_db_snapshot(self) -> "Rds":
        '''(experimental) Grants permission to create a new DB instance from a DB snapshot.

        Access Level: Write

        Possible conditions:

        - .ifBackupTarget()
        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifReqTag()

        Dependent actions:

        - iam:PassRole
        - rds:AddTagsToResource

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_RestoreDBInstanceFromDBSnapshot.html

        :stability: experimental
        '''
        return typing.cast("Rds", jsii.invoke(self, "toRestoreDBInstanceFromDBSnapshot", []))

    @jsii.member(jsii_name="toRestoreDBInstanceFromS3")
    def to_restore_db_instance_from_s3(self) -> "Rds":
        '''(experimental) Grants permission to create a new DB instance from an Amazon S3 bucket.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifReqTag()

        Dependent actions:

        - iam:PassRole
        - rds:AddTagsToResource

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_RestoreDBInstanceFromS3.html

        :stability: experimental
        '''
        return typing.cast("Rds", jsii.invoke(self, "toRestoreDBInstanceFromS3", []))

    @jsii.member(jsii_name="toRestoreDBInstanceToPointInTime")
    def to_restore_db_instance_to_point_in_time(self) -> "Rds":
        '''(experimental) Grants permission to restore a DB instance to an arbitrary point in time.

        Access Level: Write

        Possible conditions:

        - .ifBackupTarget()
        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifReqTag()

        Dependent actions:

        - iam:PassRole
        - rds:AddTagsToResource

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_RestoreDBInstanceToPointInTime.html

        :stability: experimental
        '''
        return typing.cast("Rds", jsii.invoke(self, "toRestoreDBInstanceToPointInTime", []))

    @jsii.member(jsii_name="toRevokeDBSecurityGroupIngress")
    def to_revoke_db_security_group_ingress(self) -> "Rds":
        '''(experimental) Grants permission to revoke ingress from a DBSecurityGroup for previously authorized IP ranges or EC2 or VPC Security Groups.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_RevokeDBSecurityGroupIngress.html

        :stability: experimental
        '''
        return typing.cast("Rds", jsii.invoke(self, "toRevokeDBSecurityGroupIngress", []))

    @jsii.member(jsii_name="toStartActivityStream")
    def to_start_activity_stream(self) -> "Rds":
        '''(experimental) Grants permission to start Activity Stream.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_StartActivityStream.html

        :stability: experimental
        '''
        return typing.cast("Rds", jsii.invoke(self, "toStartActivityStream", []))

    @jsii.member(jsii_name="toStartDBCluster")
    def to_start_db_cluster(self) -> "Rds":
        '''(experimental) Grants permission to start the DB cluster.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_StartDBCluster.html

        :stability: experimental
        '''
        return typing.cast("Rds", jsii.invoke(self, "toStartDBCluster", []))

    @jsii.member(jsii_name="toStartDBInstance")
    def to_start_db_instance(self) -> "Rds":
        '''(experimental) Grants permission to start the DB instance.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_StartDBInstance.html

        :stability: experimental
        '''
        return typing.cast("Rds", jsii.invoke(self, "toStartDBInstance", []))

    @jsii.member(jsii_name="toStartDBInstanceAutomatedBackupsReplication")
    def to_start_db_instance_automated_backups_replication(self) -> "Rds":
        '''(experimental) Grants permission to start replication of automated backups to a different AWS Region.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_StartDBInstanceAutomatedBackupsReplication.html

        :stability: experimental
        '''
        return typing.cast("Rds", jsii.invoke(self, "toStartDBInstanceAutomatedBackupsReplication", []))

    @jsii.member(jsii_name="toStartExportTask")
    def to_start_export_task(self) -> "Rds":
        '''(experimental) Grants permission to start a new Export task for a DB snapshot.

        Access Level: Write

        Dependent actions:

        - iam:PassRole

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_StartExportTask.html

        :stability: experimental
        '''
        return typing.cast("Rds", jsii.invoke(self, "toStartExportTask", []))

    @jsii.member(jsii_name="toStopActivityStream")
    def to_stop_activity_stream(self) -> "Rds":
        '''(experimental) Grants permission to stop Activity Stream.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_StopActivityStream.html

        :stability: experimental
        '''
        return typing.cast("Rds", jsii.invoke(self, "toStopActivityStream", []))

    @jsii.member(jsii_name="toStopDBCluster")
    def to_stop_db_cluster(self) -> "Rds":
        '''(experimental) Grants permission to stop the DB cluster.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_StopDBCluster.html

        :stability: experimental
        '''
        return typing.cast("Rds", jsii.invoke(self, "toStopDBCluster", []))

    @jsii.member(jsii_name="toStopDBInstance")
    def to_stop_db_instance(self) -> "Rds":
        '''(experimental) Grants permission to stop the DB instance.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_StopDBInstance.html

        :stability: experimental
        '''
        return typing.cast("Rds", jsii.invoke(self, "toStopDBInstance", []))

    @jsii.member(jsii_name="toStopDBInstanceAutomatedBackupsReplication")
    def to_stop_db_instance_automated_backups_replication(self) -> "Rds":
        '''(experimental) Grants permission to stop automated backup replication for a DB instance.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_StopDBInstanceAutomatedBackupsReplication.html

        :stability: experimental
        '''
        return typing.cast("Rds", jsii.invoke(self, "toStopDBInstanceAutomatedBackupsReplication", []))

    @jsii.member(jsii_name="toSwitchoverBlueGreenDeployment")
    def to_switchover_blue_green_deployment(self) -> "Rds":
        '''(experimental) Grants permission to switch a blue-green deployment from source instance or cluster to target.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsResourceTag()
        - .ifAwsTagKeys()
        - .ifReqTag()

        Dependent actions:

        - rds:ModifyDBCluster
        - rds:ModifyDBInstance
        - rds:PromoteReadReplica
        - rds:PromoteReadReplicaDBCluster

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_SwitchoverBlueGreenDeployment.html

        :stability: experimental
        '''
        return typing.cast("Rds", jsii.invoke(self, "toSwitchoverBlueGreenDeployment", []))

    @jsii.member(jsii_name="toSwitchoverReadReplica")
    def to_switchover_read_replica(self) -> "Rds":
        '''(experimental) Grants permission to switch over a read replica, making it the new primary database.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_SwitchoverReadReplica.html

        :stability: experimental
        '''
        return typing.cast("Rds", jsii.invoke(self, "toSwitchoverReadReplica", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__630578f0f6bb1016c481a41130264ae16aa9fdae569db1e736ad582fe7079050)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__668f84ce2ffda25343ef83454063ca754b6761b34cee2eb966241db6a4bcb3ad)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class RdsData(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.RdsData",
):
    '''(experimental) Statement provider for service `rds-data <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonrdsdataapi.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `rds-data <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonrdsdataapi.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onCluster")
    def on_cluster(
        self,
        db_cluster_instance_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "RdsData":
        '''(experimental) Adds a resource of type cluster to the statement.

        https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/Aurora.Managing.html

        :param db_cluster_instance_name: - Identifier for the dbClusterInstanceName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag() - .ifAwsTagKeys()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__09a5ce552e9c695f972c5fb23a736931b8e91614cbf7e9db665970ff3893b882)
            check_type(argname="argument db_cluster_instance_name", value=db_cluster_instance_name, expected_type=type_hints["db_cluster_instance_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("RdsData", jsii.invoke(self, "onCluster", [db_cluster_instance_name, account, region, partition]))

    @jsii.member(jsii_name="toBatchExecuteStatement")
    def to_batch_execute_statement(self) -> "RdsData":
        '''(experimental) Grants permission to run a batch SQL statement over an array of data.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/rdsdataservice/latest/APIReference/API_BatchExecuteStatement.html

        :stability: experimental
        '''
        return typing.cast("RdsData", jsii.invoke(self, "toBatchExecuteStatement", []))

    @jsii.member(jsii_name="toBeginTransaction")
    def to_begin_transaction(self) -> "RdsData":
        '''(experimental) Grants permission to start a SQL transaction.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/rdsdataservice/latest/APIReference/API_BeginTransaction.html

        :stability: experimental
        '''
        return typing.cast("RdsData", jsii.invoke(self, "toBeginTransaction", []))

    @jsii.member(jsii_name="toCommitTransaction")
    def to_commit_transaction(self) -> "RdsData":
        '''(experimental) Grants permission to end a SQL transaction started with the BeginTransaction operation and commits the changes.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - rds-data:BeginTransaction

        https://docs.aws.amazon.com/rdsdataservice/latest/APIReference/API_CommitTransaction.html

        :stability: experimental
        '''
        return typing.cast("RdsData", jsii.invoke(self, "toCommitTransaction", []))

    @jsii.member(jsii_name="toExecuteSql")
    def to_execute_sql(self) -> "RdsData":
        '''(experimental) Grants permission to run one or more SQL statements. This operation is deprecated. Use the BatchExecuteStatement or ExecuteStatement operation.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/rdsdataservice/latest/APIReference/API_ExecuteSql.html

        :stability: experimental
        '''
        return typing.cast("RdsData", jsii.invoke(self, "toExecuteSql", []))

    @jsii.member(jsii_name="toExecuteStatement")
    def to_execute_statement(self) -> "RdsData":
        '''(experimental) Grants permission to run a SQL statement against a database.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/rdsdataservice/latest/APIReference/API_ExecuteStatement.html

        :stability: experimental
        '''
        return typing.cast("RdsData", jsii.invoke(self, "toExecuteStatement", []))

    @jsii.member(jsii_name="toRollbackTransaction")
    def to_rollback_transaction(self) -> "RdsData":
        '''(experimental) Grants permission to perform a rollback of a transaction. Rolling back a transaction cancels its changes.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - rds-data:BeginTransaction

        https://docs.aws.amazon.com/rdsdataservice/latest/APIReference/API_RollbackTransaction.html

        :stability: experimental
        '''
        return typing.cast("RdsData", jsii.invoke(self, "toRollbackTransaction", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__648be6c21385f2a48fb24913b13bcc7828d03ff40a464a07aa51175db3881ca1)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__17882f42f2108cad985e7fbdfb5f20da7f7af81870f73f05491fa76ee8a9ead5)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class RdsDb(PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.RdsDb"):
    '''(experimental) Statement provider for service `rds-db <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonrdsiamauthentication.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `rds-db <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonrdsiamauthentication.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onDbUser")
    def on_db_user(
        self,
        dbi_resource_id: builtins.str,
        db_user_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "RdsDb":
        '''(experimental) Adds a resource of type db-user to the statement.

        https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/UsingWithRDS.IAMDBAuth.DBAccounts.html

        :param dbi_resource_id: - Identifier for the dbiResourceId.
        :param db_user_name: - Identifier for the dbUserName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d6034507aca07f9084ae13802530395eff0e73ec0ea99acc8127ab207e1c4714)
            check_type(argname="argument dbi_resource_id", value=dbi_resource_id, expected_type=type_hints["dbi_resource_id"])
            check_type(argname="argument db_user_name", value=db_user_name, expected_type=type_hints["db_user_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("RdsDb", jsii.invoke(self, "onDbUser", [dbi_resource_id, db_user_name, account, region, partition]))

    @jsii.member(jsii_name="toConnect")
    def to_connect(self) -> "RdsDb":
        '''(experimental) Allows IAM role or user to connect to RDS database.

        Access Level: Permissions management

        https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/UsingWithRDS.IAMDBAuth.IAMPolicy.html

        :stability: experimental
        '''
        return typing.cast("RdsDb", jsii.invoke(self, "toConnect", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b611253fcc150803064b88ff04239c0fe3a7a227c63970580e1cfcdaf5c982f1)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bd665cd142ebdf49b5627f109dcc34d783b11d22845b7ef1863a5566a06ac914)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Redshift(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Redshift",
):
    '''(experimental) Statement provider for service `redshift <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonredshift.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `redshift <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonredshift.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="ifConsumerArn")
    def if_consumer_arn(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Redshift":
        '''(experimental) Filters access by the datashare consumer arn.

        https://docs.aws.amazon.com/redshift/latest/mgmt/redshift-iam-access-control-overview.html#redshift-policy-resources.conditions

        Applies to actions:

        - .toAssociateDataShareConsumer()
        - .toDisassociateDataShareConsumer()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d227fb8b8acc6e58c170c4a730daf83b45177bb27d4f211587c578b7d6da0215)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Redshift", jsii.invoke(self, "ifConsumerArn", [value, operator]))

    @jsii.member(jsii_name="ifConsumerIdentifier")
    def if_consumer_identifier(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Redshift":
        '''(experimental) Filters access by the datashare consumer.

        https://docs.aws.amazon.com/redshift/latest/mgmt/redshift-iam-access-control-overview.html#redshift-policy-resources.conditions

        Applies to actions:

        - .toAuthorizeDataShare()
        - .toDeauthorizeDataShare()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3ed690be7a02aa7464be32b7c0ad704fba78477e7f53fba53cb6c8f047dfa6f1)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Redshift", jsii.invoke(self, "ifConsumerIdentifier", [value, operator]))

    @jsii.member(jsii_name="ifDbName")
    def if_db_name(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Redshift":
        '''(experimental) Filters access by the database name.

        https://docs.aws.amazon.com/redshift/latest/mgmt/redshift-iam-access-control-overview.html#redshift-policy-resources.conditions

        Applies to actions:

        - .toGetClusterCredentials()
        - .toGetClusterCredentialsWithIAM()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3ad838f848ca9184a9ae53f3e9c5ef213068fcd84c333a75ec4c70625cb6ab95)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Redshift", jsii.invoke(self, "ifDbName", [value, operator]))

    @jsii.member(jsii_name="ifDbUser")
    def if_db_user(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Redshift":
        '''(experimental) Filters access by the database user name.

        https://docs.aws.amazon.com/redshift/latest/mgmt/redshift-iam-access-control-overview.html#redshift-policy-resources.conditions

        Applies to actions:

        - .toCreateClusterUser()
        - .toGetClusterCredentials()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9a1a0ed532c12d54870adc50bf91082c6084713b8d785c1b9214b66d9303932a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Redshift", jsii.invoke(self, "ifDbUser", [value, operator]))

    @jsii.member(jsii_name="ifDurationSeconds")
    def if_duration_seconds(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Redshift":
        '''(experimental) Filters access by the number of seconds until a temporary credential set expires.

        https://docs.aws.amazon.com/redshift/latest/mgmt/redshift-iam-access-control-overview.html#redshift-policy-resources.conditions

        Applies to actions:

        - .toGetClusterCredentials()
        - .toGetClusterCredentialsWithIAM()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2f2681ad39edacdaf1fb98cfb36f0ff7aebd740992de162acf5de0c2ee8ce17f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Redshift", jsii.invoke(self, "ifDurationSeconds", [value, operator]))

    @jsii.member(jsii_name="onCluster")
    def on_cluster(
        self,
        cluster_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Redshift":
        '''(experimental) Adds a resource of type cluster to the statement.

        https://docs.aws.amazon.com/redshift/latest/mgmt/working-with-clusters.html

        :param cluster_name: - Identifier for the clusterName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__223fa46b1223d700239fbed8b2142119c84106b88db05a3dff938aad34dd6df3)
            check_type(argname="argument cluster_name", value=cluster_name, expected_type=type_hints["cluster_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Redshift", jsii.invoke(self, "onCluster", [cluster_name, account, region, partition]))

    @jsii.member(jsii_name="onDatashare")
    def on_datashare(
        self,
        producer_cluster_namespace: builtins.str,
        data_share_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Redshift":
        '''(experimental) Adds a resource of type datashare to the statement.

        https://docs.aws.amazon.com/redshift/latest/dg/datashare-overview.html

        :param producer_cluster_namespace: - Identifier for the producerClusterNamespace.
        :param data_share_name: - Identifier for the dataShareName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1a3e2be2b8142f8032eb9eadb9df46a559736d32cc7e80f001efe63bb1a7ae69)
            check_type(argname="argument producer_cluster_namespace", value=producer_cluster_namespace, expected_type=type_hints["producer_cluster_namespace"])
            check_type(argname="argument data_share_name", value=data_share_name, expected_type=type_hints["data_share_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Redshift", jsii.invoke(self, "onDatashare", [producer_cluster_namespace, data_share_name, account, region, partition]))

    @jsii.member(jsii_name="onDbgroup")
    def on_dbgroup(
        self,
        cluster_name: builtins.str,
        db_group: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Redshift":
        '''(experimental) Adds a resource of type dbgroup to the statement.

        https://docs.aws.amazon.com/redshift/latest/dg/r_CREATE_GROUP.html

        :param cluster_name: - Identifier for the clusterName.
        :param db_group: - Identifier for the dbGroup.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__465ab44400c65dc223c349361ad99c659a3a6907b51c0366139c1394dede7128)
            check_type(argname="argument cluster_name", value=cluster_name, expected_type=type_hints["cluster_name"])
            check_type(argname="argument db_group", value=db_group, expected_type=type_hints["db_group"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Redshift", jsii.invoke(self, "onDbgroup", [cluster_name, db_group, account, region, partition]))

    @jsii.member(jsii_name="onDbname")
    def on_dbname(
        self,
        cluster_name: builtins.str,
        db_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Redshift":
        '''(experimental) Adds a resource of type dbname to the statement.

        https://docs.aws.amazon.com/redshift/latest/dg/t_creating_database.html

        :param cluster_name: - Identifier for the clusterName.
        :param db_name: - Identifier for the dbName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b312774e1a7091380cd891927593603dc5594408171a108ac28092e4ea47fbcc)
            check_type(argname="argument cluster_name", value=cluster_name, expected_type=type_hints["cluster_name"])
            check_type(argname="argument db_name", value=db_name, expected_type=type_hints["db_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Redshift", jsii.invoke(self, "onDbname", [cluster_name, db_name, account, region, partition]))

    @jsii.member(jsii_name="onDbuser")
    def on_dbuser(
        self,
        cluster_name: builtins.str,
        db_user: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Redshift":
        '''(experimental) Adds a resource of type dbuser to the statement.

        https://docs.aws.amazon.com/redshift/latest/dg/r_Users.html

        :param cluster_name: - Identifier for the clusterName.
        :param db_user: - Identifier for the dbUser.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d6620cd5d4726779ba54b980cae22c649f910b27c1a4837665f298f90a20d26a)
            check_type(argname="argument cluster_name", value=cluster_name, expected_type=type_hints["cluster_name"])
            check_type(argname="argument db_user", value=db_user, expected_type=type_hints["db_user"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Redshift", jsii.invoke(self, "onDbuser", [cluster_name, db_user, account, region, partition]))

    @jsii.member(jsii_name="onEventsubscription")
    def on_eventsubscription(
        self,
        event_subscription_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Redshift":
        '''(experimental) Adds a resource of type eventsubscription to the statement.

        https://docs.aws.amazon.com/redshift/latest/mgmt/working-with-events.html

        :param event_subscription_name: - Identifier for the eventSubscriptionName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__80766c5cfa0f1a62e1cc1713d13f9cfdb8be09907dd25003375dcd051584e17d)
            check_type(argname="argument event_subscription_name", value=event_subscription_name, expected_type=type_hints["event_subscription_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Redshift", jsii.invoke(self, "onEventsubscription", [event_subscription_name, account, region, partition]))

    @jsii.member(jsii_name="onHsmclientcertificate")
    def on_hsmclientcertificate(
        self,
        h_sm_client_certificate_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Redshift":
        '''(experimental) Adds a resource of type hsmclientcertificate to the statement.

        https://docs.aws.amazon.com/redshift/latest/mgmt/working-with-db-encryption.html#working-with-HSM

        :param h_sm_client_certificate_id: - Identifier for the hSMClientCertificateId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c23595481dda13fa4cfbd40d551a24e7697158c02ae04b5deef17d1aee50419b)
            check_type(argname="argument h_sm_client_certificate_id", value=h_sm_client_certificate_id, expected_type=type_hints["h_sm_client_certificate_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Redshift", jsii.invoke(self, "onHsmclientcertificate", [h_sm_client_certificate_id, account, region, partition]))

    @jsii.member(jsii_name="onHsmconfiguration")
    def on_hsmconfiguration(
        self,
        h_sm_configuration_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Redshift":
        '''(experimental) Adds a resource of type hsmconfiguration to the statement.

        https://docs.aws.amazon.com/redshift/latest/mgmt/working-with-db-encryption.html#working-with-HSM

        :param h_sm_configuration_id: - Identifier for the hSMConfigurationId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0edffb50023b9ee9f77560babf7d0dae7120b3f6f344e24d8975ec45534c7167)
            check_type(argname="argument h_sm_configuration_id", value=h_sm_configuration_id, expected_type=type_hints["h_sm_configuration_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Redshift", jsii.invoke(self, "onHsmconfiguration", [h_sm_configuration_id, account, region, partition]))

    @jsii.member(jsii_name="onNamespace")
    def on_namespace(
        self,
        producer_cluster_namespace: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Redshift":
        '''(experimental) Adds a resource of type namespace to the statement.

        https://docs.aws.amazon.com/redshift/latest/dg/concepts.html

        :param producer_cluster_namespace: - Identifier for the producerClusterNamespace.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7a9335f02c066e99218b06ffdfe78c4ad84102cfdacb8970d73e11a5e667e165)
            check_type(argname="argument producer_cluster_namespace", value=producer_cluster_namespace, expected_type=type_hints["producer_cluster_namespace"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Redshift", jsii.invoke(self, "onNamespace", [producer_cluster_namespace, account, region, partition]))

    @jsii.member(jsii_name="onParametergroup")
    def on_parametergroup(
        self,
        parameter_group_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Redshift":
        '''(experimental) Adds a resource of type parametergroup to the statement.

        https://docs.aws.amazon.com/redshift/latest/mgmt/working-with-parameter-groups.html

        :param parameter_group_name: - Identifier for the parameterGroupName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b72d8a714f1dd5e3a653fc24ee0fd2a1f2882e083a89fc2280b2c25bdd8f71a5)
            check_type(argname="argument parameter_group_name", value=parameter_group_name, expected_type=type_hints["parameter_group_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Redshift", jsii.invoke(self, "onParametergroup", [parameter_group_name, account, region, partition]))

    @jsii.member(jsii_name="onSecuritygroup")
    def on_securitygroup(
        self,
        security_group_name: builtins.str,
        owner: builtins.str,
        ec2_security_group_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Redshift":
        '''(experimental) Adds a resource of type securitygroup to the statement.

        https://docs.aws.amazon.com/redshift/latest/mgmt/working-with-security-groups.html

        :param security_group_name: - Identifier for the securityGroupName.
        :param owner: - Identifier for the owner.
        :param ec2_security_group_id: - Identifier for the ec2SecurityGroupId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bfd969edcb4d19e3c25b1a77f664558bc15879c37845d53b226791119934bc3a)
            check_type(argname="argument security_group_name", value=security_group_name, expected_type=type_hints["security_group_name"])
            check_type(argname="argument owner", value=owner, expected_type=type_hints["owner"])
            check_type(argname="argument ec2_security_group_id", value=ec2_security_group_id, expected_type=type_hints["ec2_security_group_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Redshift", jsii.invoke(self, "onSecuritygroup", [security_group_name, owner, ec2_security_group_id, account, region, partition]))

    @jsii.member(jsii_name="onSecuritygroupingressCidr")
    def on_securitygroupingress_cidr(
        self,
        security_group_name: builtins.str,
        ip_range: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Redshift":
        '''(experimental) Adds a resource of type securitygroupingress-cidr to the statement.

        https://docs.aws.amazon.com/redshift/latest/mgmt/working-with-security-groups.html

        :param security_group_name: - Identifier for the securityGroupName.
        :param ip_range: - Identifier for the ipRange.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__394a4c7f6af9f13d5172d96aeebad1f543a5c07b1c8ae4b3403f8a504161cffe)
            check_type(argname="argument security_group_name", value=security_group_name, expected_type=type_hints["security_group_name"])
            check_type(argname="argument ip_range", value=ip_range, expected_type=type_hints["ip_range"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Redshift", jsii.invoke(self, "onSecuritygroupingressCidr", [security_group_name, ip_range, account, region, partition]))

    @jsii.member(jsii_name="onSecuritygroupingressEc2securitygroup")
    def on_securitygroupingress_ec2securitygroup(
        self,
        security_group_name: builtins.str,
        owner: builtins.str,
        ece2_securitygroup_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Redshift":
        '''(experimental) Adds a resource of type securitygroupingress-ec2securitygroup to the statement.

        https://docs.aws.amazon.com/redshift/latest/mgmt/working-with-security-groups.html

        :param security_group_name: - Identifier for the securityGroupName.
        :param owner: - Identifier for the owner.
        :param ece2_securitygroup_id: - Identifier for the ece2SecuritygroupId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f6d2fe84f89a65ddc027ad50637cb2816ebae84c1b10a9a569179348fb90b447)
            check_type(argname="argument security_group_name", value=security_group_name, expected_type=type_hints["security_group_name"])
            check_type(argname="argument owner", value=owner, expected_type=type_hints["owner"])
            check_type(argname="argument ece2_securitygroup_id", value=ece2_securitygroup_id, expected_type=type_hints["ece2_securitygroup_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Redshift", jsii.invoke(self, "onSecuritygroupingressEc2securitygroup", [security_group_name, owner, ece2_securitygroup_id, account, region, partition]))

    @jsii.member(jsii_name="onSnapshot")
    def on_snapshot(
        self,
        cluster_name: builtins.str,
        snapshot_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Redshift":
        '''(experimental) Adds a resource of type snapshot to the statement.

        https://docs.aws.amazon.com/redshift/latest/mgmt/working-with-snapshots.html

        :param cluster_name: - Identifier for the clusterName.
        :param snapshot_name: - Identifier for the snapshotName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__eee273e6de69f74d1e1a5a2129988153943b6d8e06f65bc43463e56f0bdb3ec7)
            check_type(argname="argument cluster_name", value=cluster_name, expected_type=type_hints["cluster_name"])
            check_type(argname="argument snapshot_name", value=snapshot_name, expected_type=type_hints["snapshot_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Redshift", jsii.invoke(self, "onSnapshot", [cluster_name, snapshot_name, account, region, partition]))

    @jsii.member(jsii_name="onSnapshotcopygrant")
    def on_snapshotcopygrant(
        self,
        snapshot_copy_grant_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Redshift":
        '''(experimental) Adds a resource of type snapshotcopygrant to the statement.

        https://docs.aws.amazon.com/redshift/latest/mgmt/working-with-db-encryption.html#configure-snapshot-copy-grant

        :param snapshot_copy_grant_name: - Identifier for the snapshotCopyGrantName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ea9f346c7ea2efdbabf17387903e38b2b966836a762f83d89d02e7efd053605b)
            check_type(argname="argument snapshot_copy_grant_name", value=snapshot_copy_grant_name, expected_type=type_hints["snapshot_copy_grant_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Redshift", jsii.invoke(self, "onSnapshotcopygrant", [snapshot_copy_grant_name, account, region, partition]))

    @jsii.member(jsii_name="onSnapshotschedule")
    def on_snapshotschedule(
        self,
        parameter_group_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Redshift":
        '''(experimental) Adds a resource of type snapshotschedule to the statement.

        https://docs.aws.amazon.com/redshift/latest/mgmt/working-with-snapshots.html

        :param parameter_group_name: - Identifier for the parameterGroupName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__551e07c48ccd9beb84351fbb671b5c85215e80ae262b0f62d3ac1812029829cb)
            check_type(argname="argument parameter_group_name", value=parameter_group_name, expected_type=type_hints["parameter_group_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Redshift", jsii.invoke(self, "onSnapshotschedule", [parameter_group_name, account, region, partition]))

    @jsii.member(jsii_name="onSubnetgroup")
    def on_subnetgroup(
        self,
        subnet_group_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Redshift":
        '''(experimental) Adds a resource of type subnetgroup to the statement.

        https://docs.aws.amazon.com/redshift/latest/mgmt/working-with-cluster-subnet-groups.html

        :param subnet_group_name: - Identifier for the subnetGroupName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0060693348413f0186d827f778ce0408443316475ed32ba5f57ee0e92682e45b)
            check_type(argname="argument subnet_group_name", value=subnet_group_name, expected_type=type_hints["subnet_group_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Redshift", jsii.invoke(self, "onSubnetgroup", [subnet_group_name, account, region, partition]))

    @jsii.member(jsii_name="onUsagelimit")
    def on_usagelimit(
        self,
        usage_limit_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Redshift":
        '''(experimental) Adds a resource of type usagelimit to the statement.

        https://docs.aws.amazon.com/redshift/latest/mgmt/managing-cluster-usage-limits.html

        :param usage_limit_id: - Identifier for the usageLimitId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3477896d8d15e08e0d916c70b462f4393aa3ea7eb37e9818bf5c5f536306b6e3)
            check_type(argname="argument usage_limit_id", value=usage_limit_id, expected_type=type_hints["usage_limit_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Redshift", jsii.invoke(self, "onUsagelimit", [usage_limit_id, account, region, partition]))

    @jsii.member(jsii_name="toAcceptReservedNodeExchange")
    def to_accept_reserved_node_exchange(self) -> "Redshift":
        '''(experimental) Grants permission to exchange a DC1 reserved node for a DC2 reserved node with no changes to the configuration.

        Access Level: Write

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_AcceptReservedNodeExchange.html

        :stability: experimental
        '''
        return typing.cast("Redshift", jsii.invoke(self, "toAcceptReservedNodeExchange", []))

    @jsii.member(jsii_name="toAddPartner")
    def to_add_partner(self) -> "Redshift":
        '''(experimental) Grants permission to add a partner integration to a cluster.

        Access Level: Write

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_AddPartner.html

        :stability: experimental
        '''
        return typing.cast("Redshift", jsii.invoke(self, "toAddPartner", []))

    @jsii.member(jsii_name="toAssociateDataShareConsumer")
    def to_associate_data_share_consumer(self) -> "Redshift":
        '''(experimental) Grants permission to associate a consumer to a datashare.

        Access Level: Write

        Possible conditions:

        - .ifConsumerArn()

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_AssociateDataShareConsumer.html

        :stability: experimental
        '''
        return typing.cast("Redshift", jsii.invoke(self, "toAssociateDataShareConsumer", []))

    @jsii.member(jsii_name="toAuthorizeClusterSecurityGroupIngress")
    def to_authorize_cluster_security_group_ingress(self) -> "Redshift":
        '''(experimental) Grants permission to add an inbound (ingress) rule to an Amazon Redshift security group.

        Access Level: Write

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_AuthorizeClusterSecurityGroupIngress.html

        :stability: experimental
        '''
        return typing.cast("Redshift", jsii.invoke(self, "toAuthorizeClusterSecurityGroupIngress", []))

    @jsii.member(jsii_name="toAuthorizeDataShare")
    def to_authorize_data_share(self) -> "Redshift":
        '''(experimental) Grants permission to authorize the specified datashare consumer to consume a datashare.

        Access Level: Permissions management

        Possible conditions:

        - .ifConsumerIdentifier()

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_AuthorizeDataShare.html

        :stability: experimental
        '''
        return typing.cast("Redshift", jsii.invoke(self, "toAuthorizeDataShare", []))

    @jsii.member(jsii_name="toAuthorizeEndpointAccess")
    def to_authorize_endpoint_access(self) -> "Redshift":
        '''(experimental) Grants permission to authorize endpoint related activities for redshift-managed vpc endpoint.

        Access Level: Permissions management

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_AuthorizeEndpointAccess.html

        :stability: experimental
        '''
        return typing.cast("Redshift", jsii.invoke(self, "toAuthorizeEndpointAccess", []))

    @jsii.member(jsii_name="toAuthorizeSnapshotAccess")
    def to_authorize_snapshot_access(self) -> "Redshift":
        '''(experimental) Grants permission to the specified AWS account to restore a snapshot.

        Access Level: Permissions management

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_AuthorizeSnapshotAccess.html

        :stability: experimental
        '''
        return typing.cast("Redshift", jsii.invoke(self, "toAuthorizeSnapshotAccess", []))

    @jsii.member(jsii_name="toBatchDeleteClusterSnapshots")
    def to_batch_delete_cluster_snapshots(self) -> "Redshift":
        '''(experimental) Grants permission to delete snapshots in a batch of size upto 100.

        Access Level: Write

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_BatchDeleteClusterSnapshots.html

        :stability: experimental
        '''
        return typing.cast("Redshift", jsii.invoke(self, "toBatchDeleteClusterSnapshots", []))

    @jsii.member(jsii_name="toBatchModifyClusterSnapshots")
    def to_batch_modify_cluster_snapshots(self) -> "Redshift":
        '''(experimental) Grants permission to modify settings for a list of snapshots.

        Access Level: Write

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_BatchModifyClusterSnapshots.html

        :stability: experimental
        '''
        return typing.cast("Redshift", jsii.invoke(self, "toBatchModifyClusterSnapshots", []))

    @jsii.member(jsii_name="toCancelQuery")
    def to_cancel_query(self) -> "Redshift":
        '''(experimental) Grants permission to cancel a query through the Amazon Redshift console.

        Access Level: Write

        https://docs.aws.amazon.com/redshift/latest/mgmt/redshift-policy-resources.resource-permissions.html

        :stability: experimental
        '''
        return typing.cast("Redshift", jsii.invoke(self, "toCancelQuery", []))

    @jsii.member(jsii_name="toCancelQuerySession")
    def to_cancel_query_session(self) -> "Redshift":
        '''(experimental) Grants permission to see queries in the Amazon Redshift console.

        Access Level: Write

        https://docs.aws.amazon.com/redshift/latest/mgmt/redshift-policy-resources.resource-permissions.html

        :stability: experimental
        '''
        return typing.cast("Redshift", jsii.invoke(self, "toCancelQuerySession", []))

    @jsii.member(jsii_name="toCancelResize")
    def to_cancel_resize(self) -> "Redshift":
        '''(experimental) Grants permission to cancel a resize operation.

        Access Level: Write

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_CancelResize.html

        :stability: experimental
        '''
        return typing.cast("Redshift", jsii.invoke(self, "toCancelResize", []))

    @jsii.member(jsii_name="toCopyClusterSnapshot")
    def to_copy_cluster_snapshot(self) -> "Redshift":
        '''(experimental) Grants permission to copy a cluster snapshot.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_CopyClusterSnapshot.html

        :stability: experimental
        '''
        return typing.cast("Redshift", jsii.invoke(self, "toCopyClusterSnapshot", []))

    @jsii.member(jsii_name="toCreateAuthenticationProfile")
    def to_create_authentication_profile(self) -> "Redshift":
        '''(experimental) Grants permission to create an Amazon Redshift authentication profile.

        Access Level: Write

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_CreateAuthenticationProfile.html

        :stability: experimental
        '''
        return typing.cast("Redshift", jsii.invoke(self, "toCreateAuthenticationProfile", []))

    @jsii.member(jsii_name="toCreateCluster")
    def to_create_cluster(self) -> "Redshift":
        '''(experimental) Grants permission to create a cluster.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_CreateCluster.html

        :stability: experimental
        '''
        return typing.cast("Redshift", jsii.invoke(self, "toCreateCluster", []))

    @jsii.member(jsii_name="toCreateClusterParameterGroup")
    def to_create_cluster_parameter_group(self) -> "Redshift":
        '''(experimental) Grants permission to create an Amazon Redshift parameter group.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_CreateClusterParameterGroup.html

        :stability: experimental
        '''
        return typing.cast("Redshift", jsii.invoke(self, "toCreateClusterParameterGroup", []))

    @jsii.member(jsii_name="toCreateClusterSecurityGroup")
    def to_create_cluster_security_group(self) -> "Redshift":
        '''(experimental) Grants permission to create an Amazon Redshift security group.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_CreateClusterSecurityGroup.html

        :stability: experimental
        '''
        return typing.cast("Redshift", jsii.invoke(self, "toCreateClusterSecurityGroup", []))

    @jsii.member(jsii_name="toCreateClusterSnapshot")
    def to_create_cluster_snapshot(self) -> "Redshift":
        '''(experimental) Grants permission to create a manual snapshot of the specified cluster.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_CreateClusterSnapshot.html

        :stability: experimental
        '''
        return typing.cast("Redshift", jsii.invoke(self, "toCreateClusterSnapshot", []))

    @jsii.member(jsii_name="toCreateClusterSubnetGroup")
    def to_create_cluster_subnet_group(self) -> "Redshift":
        '''(experimental) Grants permission to create an Amazon Redshift subnet group.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_CreateClusterSubnetGroup.html

        :stability: experimental
        '''
        return typing.cast("Redshift", jsii.invoke(self, "toCreateClusterSubnetGroup", []))

    @jsii.member(jsii_name="toCreateClusterUser")
    def to_create_cluster_user(self) -> "Redshift":
        '''(experimental) Grants permission to automatically create the specified Amazon Redshift user if it does not exist.

        Access Level: Permissions management

        Possible conditions:

        - .ifDbUser()

        https://docs.aws.amazon.com/redshift/latest/mgmt/generating-iam-credentials-role-permissions.html

        :stability: experimental
        '''
        return typing.cast("Redshift", jsii.invoke(self, "toCreateClusterUser", []))

    @jsii.member(jsii_name="toCreateEndpointAccess")
    def to_create_endpoint_access(self) -> "Redshift":
        '''(experimental) Grants permission to create a redshift-managed vpc endpoint.

        Access Level: Write

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_CreateEndpointAccess.html

        :stability: experimental
        '''
        return typing.cast("Redshift", jsii.invoke(self, "toCreateEndpointAccess", []))

    @jsii.member(jsii_name="toCreateEventSubscription")
    def to_create_event_subscription(self) -> "Redshift":
        '''(experimental) Grants permission to create an Amazon Redshift event notification subscription.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_CreateEventSubscription.html

        :stability: experimental
        '''
        return typing.cast("Redshift", jsii.invoke(self, "toCreateEventSubscription", []))

    @jsii.member(jsii_name="toCreateHsmClientCertificate")
    def to_create_hsm_client_certificate(self) -> "Redshift":
        '''(experimental) Grants permission to create an HSM client certificate that a cluster uses to connect to an HSM.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_CreateHsmClientCertificate.html

        :stability: experimental
        '''
        return typing.cast("Redshift", jsii.invoke(self, "toCreateHsmClientCertificate", []))

    @jsii.member(jsii_name="toCreateHsmConfiguration")
    def to_create_hsm_configuration(self) -> "Redshift":
        '''(experimental) Grants permission to create an HSM configuration that contains information required by a cluster to store and use database encryption keys in a hardware security module (HSM).

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_CreateHsmConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Redshift", jsii.invoke(self, "toCreateHsmConfiguration", []))

    @jsii.member(jsii_name="toCreateSavedQuery")
    def to_create_saved_query(self) -> "Redshift":
        '''(experimental) Grants permission to create saved SQL queries through the Amazon Redshift console.

        Access Level: Write

        https://docs.aws.amazon.com/redshift/latest/mgmt/redshift-policy-resources.resource-permissions.html

        :stability: experimental
        '''
        return typing.cast("Redshift", jsii.invoke(self, "toCreateSavedQuery", []))

    @jsii.member(jsii_name="toCreateScheduledAction")
    def to_create_scheduled_action(self) -> "Redshift":
        '''(experimental) Grants permission to create an Amazon Redshift scheduled action.

        Access Level: Write

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_CreateScheduledAction.html

        :stability: experimental
        '''
        return typing.cast("Redshift", jsii.invoke(self, "toCreateScheduledAction", []))

    @jsii.member(jsii_name="toCreateSnapshotCopyGrant")
    def to_create_snapshot_copy_grant(self) -> "Redshift":
        '''(experimental) Grants permission to create a snapshot copy grant and encrypt copied snapshots in a destination AWS Region.

        Access Level: Permissions management

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_CreateSnapshotCopyGrant.html

        :stability: experimental
        '''
        return typing.cast("Redshift", jsii.invoke(self, "toCreateSnapshotCopyGrant", []))

    @jsii.member(jsii_name="toCreateSnapshotSchedule")
    def to_create_snapshot_schedule(self) -> "Redshift":
        '''(experimental) Grants permission to create a snapshot schedule.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_CreateSnapshotSchedule.html

        :stability: experimental
        '''
        return typing.cast("Redshift", jsii.invoke(self, "toCreateSnapshotSchedule", []))

    @jsii.member(jsii_name="toCreateTags")
    def to_create_tags(self) -> "Redshift":
        '''(experimental) Grants permission to add one or more tags to a specified resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_CreateTags.html

        :stability: experimental
        '''
        return typing.cast("Redshift", jsii.invoke(self, "toCreateTags", []))

    @jsii.member(jsii_name="toCreateUsageLimit")
    def to_create_usage_limit(self) -> "Redshift":
        '''(experimental) Grants permission to create a usage limit.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_CreateUsageLimit.html

        :stability: experimental
        '''
        return typing.cast("Redshift", jsii.invoke(self, "toCreateUsageLimit", []))

    @jsii.member(jsii_name="toDeauthorizeDataShare")
    def to_deauthorize_data_share(self) -> "Redshift":
        '''(experimental) Grants permission to remove permission from the specified datashare consumer to consume a datashare.

        Access Level: Permissions management

        Possible conditions:

        - .ifConsumerIdentifier()

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_DeauthorizeDataShare.html

        :stability: experimental
        '''
        return typing.cast("Redshift", jsii.invoke(self, "toDeauthorizeDataShare", []))

    @jsii.member(jsii_name="toDeleteAuthenticationProfile")
    def to_delete_authentication_profile(self) -> "Redshift":
        '''(experimental) Grants permission to delete an Amazon Redshift authentication profile.

        Access Level: Write

        :stability: experimental
        '''
        return typing.cast("Redshift", jsii.invoke(self, "toDeleteAuthenticationProfile", []))

    @jsii.member(jsii_name="toDeleteCluster")
    def to_delete_cluster(self) -> "Redshift":
        '''(experimental) Grants permission to delete a previously provisioned cluster.

        Access Level: Write

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_DeleteCluster.html

        :stability: experimental
        '''
        return typing.cast("Redshift", jsii.invoke(self, "toDeleteCluster", []))

    @jsii.member(jsii_name="toDeleteClusterParameterGroup")
    def to_delete_cluster_parameter_group(self) -> "Redshift":
        '''(experimental) Grants permission to delete an Amazon Redshift parameter group.

        Access Level: Write

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_DeleteClusterParameterGroup.html

        :stability: experimental
        '''
        return typing.cast("Redshift", jsii.invoke(self, "toDeleteClusterParameterGroup", []))

    @jsii.member(jsii_name="toDeleteClusterSecurityGroup")
    def to_delete_cluster_security_group(self) -> "Redshift":
        '''(experimental) Grants permission to delete an Amazon Redshift security group.

        Access Level: Write

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_DeleteClusterSecurityGroup.html

        :stability: experimental
        '''
        return typing.cast("Redshift", jsii.invoke(self, "toDeleteClusterSecurityGroup", []))

    @jsii.member(jsii_name="toDeleteClusterSnapshot")
    def to_delete_cluster_snapshot(self) -> "Redshift":
        '''(experimental) Grants permission to delete a manual snapshot.

        Access Level: Write

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_DeleteClusterSnapshot.html

        :stability: experimental
        '''
        return typing.cast("Redshift", jsii.invoke(self, "toDeleteClusterSnapshot", []))

    @jsii.member(jsii_name="toDeleteClusterSubnetGroup")
    def to_delete_cluster_subnet_group(self) -> "Redshift":
        '''(experimental) Grants permission to delete a cluster subnet group.

        Access Level: Write

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_DeleteClusterSubnetGroup.html

        :stability: experimental
        '''
        return typing.cast("Redshift", jsii.invoke(self, "toDeleteClusterSubnetGroup", []))

    @jsii.member(jsii_name="toDeleteEndpointAccess")
    def to_delete_endpoint_access(self) -> "Redshift":
        '''(experimental) Grants permission to delete a redshift-managed vpc endpoint.

        Access Level: Write

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_DeleteEndpointAccess.html

        :stability: experimental
        '''
        return typing.cast("Redshift", jsii.invoke(self, "toDeleteEndpointAccess", []))

    @jsii.member(jsii_name="toDeleteEventSubscription")
    def to_delete_event_subscription(self) -> "Redshift":
        '''(experimental) Grants permission to delete an Amazon Redshift event notification subscription.

        Access Level: Write

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_DeleteEventSubscription.html

        :stability: experimental
        '''
        return typing.cast("Redshift", jsii.invoke(self, "toDeleteEventSubscription", []))

    @jsii.member(jsii_name="toDeleteHsmClientCertificate")
    def to_delete_hsm_client_certificate(self) -> "Redshift":
        '''(experimental) Grants permission to delete an HSM client certificate.

        Access Level: Write

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_DeleteHsmClientCertificate.html

        :stability: experimental
        '''
        return typing.cast("Redshift", jsii.invoke(self, "toDeleteHsmClientCertificate", []))

    @jsii.member(jsii_name="toDeleteHsmConfiguration")
    def to_delete_hsm_configuration(self) -> "Redshift":
        '''(experimental) Grants permission to delete an Amazon Redshift HSM configuration.

        Access Level: Write

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_DeleteHsmConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Redshift", jsii.invoke(self, "toDeleteHsmConfiguration", []))

    @jsii.member(jsii_name="toDeletePartner")
    def to_delete_partner(self) -> "Redshift":
        '''(experimental) Grants permission to delete a partner integration from a cluster.

        Access Level: Write

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_DeletePartner.html

        :stability: experimental
        '''
        return typing.cast("Redshift", jsii.invoke(self, "toDeletePartner", []))

    @jsii.member(jsii_name="toDeleteSavedQueries")
    def to_delete_saved_queries(self) -> "Redshift":
        '''(experimental) Grants permission to delete saved SQL queries through the Amazon Redshift console.

        Access Level: Write

        https://docs.aws.amazon.com/redshift/latest/mgmt/redshift-policy-resources.resource-permissions.html

        :stability: experimental
        '''
        return typing.cast("Redshift", jsii.invoke(self, "toDeleteSavedQueries", []))

    @jsii.member(jsii_name="toDeleteScheduledAction")
    def to_delete_scheduled_action(self) -> "Redshift":
        '''(experimental) Grants permission to delete an Amazon Redshift scheduled action.

        Access Level: Write

        :stability: experimental
        '''
        return typing.cast("Redshift", jsii.invoke(self, "toDeleteScheduledAction", []))

    @jsii.member(jsii_name="toDeleteSnapshotCopyGrant")
    def to_delete_snapshot_copy_grant(self) -> "Redshift":
        '''(experimental) Grants permission to delete a snapshot copy grant.

        Access Level: Write

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_DeleteSnapshotCopyGrant.html

        :stability: experimental
        '''
        return typing.cast("Redshift", jsii.invoke(self, "toDeleteSnapshotCopyGrant", []))

    @jsii.member(jsii_name="toDeleteSnapshotSchedule")
    def to_delete_snapshot_schedule(self) -> "Redshift":
        '''(experimental) Grants permission to delete a snapshot schedule.

        Access Level: Write

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_DeleteSnapshotSchedule.html

        :stability: experimental
        '''
        return typing.cast("Redshift", jsii.invoke(self, "toDeleteSnapshotSchedule", []))

    @jsii.member(jsii_name="toDeleteTags")
    def to_delete_tags(self) -> "Redshift":
        '''(experimental) Grants permission to delete a tag or tags from a resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_DeleteTags.html

        :stability: experimental
        '''
        return typing.cast("Redshift", jsii.invoke(self, "toDeleteTags", []))

    @jsii.member(jsii_name="toDeleteUsageLimit")
    def to_delete_usage_limit(self) -> "Redshift":
        '''(experimental) Grants permission to delete a usage limit.

        Access Level: Write

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_DeleteUsageLimit.html

        :stability: experimental
        '''
        return typing.cast("Redshift", jsii.invoke(self, "toDeleteUsageLimit", []))

    @jsii.member(jsii_name="toDescribeAccountAttributes")
    def to_describe_account_attributes(self) -> "Redshift":
        '''(experimental) Grants permission to describe attributes attached to the specified AWS account.

        Access Level: Read

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_DescribeAccountAttributes.html

        :stability: experimental
        '''
        return typing.cast("Redshift", jsii.invoke(self, "toDescribeAccountAttributes", []))

    @jsii.member(jsii_name="toDescribeAuthenticationProfiles")
    def to_describe_authentication_profiles(self) -> "Redshift":
        '''(experimental) Grants permission to describe created Amazon Redshift authentication profiles.

        Access Level: Read

        :stability: experimental
        '''
        return typing.cast("Redshift", jsii.invoke(self, "toDescribeAuthenticationProfiles", []))

    @jsii.member(jsii_name="toDescribeClusterDbRevisions")
    def to_describe_cluster_db_revisions(self) -> "Redshift":
        '''(experimental) Grants permission to describe database revisions for a cluster.

        Access Level: List

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_DescribeClusterDbRevisions.html

        :stability: experimental
        '''
        return typing.cast("Redshift", jsii.invoke(self, "toDescribeClusterDbRevisions", []))

    @jsii.member(jsii_name="toDescribeClusterParameterGroups")
    def to_describe_cluster_parameter_groups(self) -> "Redshift":
        '''(experimental) Grants permission to describe Amazon Redshift parameter groups, including parameter groups you created and the default parameter group.

        Access Level: Read

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_DescribeClusterParameterGroups.html

        :stability: experimental
        '''
        return typing.cast("Redshift", jsii.invoke(self, "toDescribeClusterParameterGroups", []))

    @jsii.member(jsii_name="toDescribeClusterParameters")
    def to_describe_cluster_parameters(self) -> "Redshift":
        '''(experimental) Grants permission to describe parameters contained within an Amazon Redshift parameter group.

        Access Level: Read

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_DescribeClusterParameters.html

        :stability: experimental
        '''
        return typing.cast("Redshift", jsii.invoke(self, "toDescribeClusterParameters", []))

    @jsii.member(jsii_name="toDescribeClusters")
    def to_describe_clusters(self) -> "Redshift":
        '''(experimental) Grants permission to describe properties of provisioned clusters.

        Access Level: List

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_DescribeClusters.html

        :stability: experimental
        '''
        return typing.cast("Redshift", jsii.invoke(self, "toDescribeClusters", []))

    @jsii.member(jsii_name="toDescribeClusterSecurityGroups")
    def to_describe_cluster_security_groups(self) -> "Redshift":
        '''(experimental) Grants permission to describe Amazon Redshift security groups.

        Access Level: Read

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_DescribeClusterSecurityGroups.html

        :stability: experimental
        '''
        return typing.cast("Redshift", jsii.invoke(self, "toDescribeClusterSecurityGroups", []))

    @jsii.member(jsii_name="toDescribeClusterSnapshots")
    def to_describe_cluster_snapshots(self) -> "Redshift":
        '''(experimental) Grants permission to describe one or more snapshot objects, which contain metadata about your cluster snapshots.

        Access Level: Read

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_DescribeClusterSnapshots.html

        :stability: experimental
        '''
        return typing.cast("Redshift", jsii.invoke(self, "toDescribeClusterSnapshots", []))

    @jsii.member(jsii_name="toDescribeClusterSubnetGroups")
    def to_describe_cluster_subnet_groups(self) -> "Redshift":
        '''(experimental) Grants permission to describe one or more cluster subnet group objects, which contain metadata about your cluster subnet groups.

        Access Level: Read

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_DescribeClusterSubnetGroups.html

        :stability: experimental
        '''
        return typing.cast("Redshift", jsii.invoke(self, "toDescribeClusterSubnetGroups", []))

    @jsii.member(jsii_name="toDescribeClusterTracks")
    def to_describe_cluster_tracks(self) -> "Redshift":
        '''(experimental) Grants permission to describe available maintenance tracks.

        Access Level: List

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_DescribeClusterTracks.html

        :stability: experimental
        '''
        return typing.cast("Redshift", jsii.invoke(self, "toDescribeClusterTracks", []))

    @jsii.member(jsii_name="toDescribeClusterVersions")
    def to_describe_cluster_versions(self) -> "Redshift":
        '''(experimental) Grants permission to describe available Amazon Redshift cluster versions.

        Access Level: Read

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_DescribeClusterVersions.html

        :stability: experimental
        '''
        return typing.cast("Redshift", jsii.invoke(self, "toDescribeClusterVersions", []))

    @jsii.member(jsii_name="toDescribeDataShares")
    def to_describe_data_shares(self) -> "Redshift":
        '''(experimental) Grants permission to describe datashares created and consumed by your clusters.

        Access Level: Read

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_DescribeDataShares.html

        :stability: experimental
        '''
        return typing.cast("Redshift", jsii.invoke(self, "toDescribeDataShares", []))

    @jsii.member(jsii_name="toDescribeDataSharesForConsumer")
    def to_describe_data_shares_for_consumer(self) -> "Redshift":
        '''(experimental) Grants permission to describe only datashares consumed by your clusters.

        Access Level: Read

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_DescribeDataSharesForConsumer.html

        :stability: experimental
        '''
        return typing.cast("Redshift", jsii.invoke(self, "toDescribeDataSharesForConsumer", []))

    @jsii.member(jsii_name="toDescribeDataSharesForProducer")
    def to_describe_data_shares_for_producer(self) -> "Redshift":
        '''(experimental) Grants permission to describe only datashares created by your clusters.

        Access Level: Read

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_DescribeDataSharesForProducer.html

        :stability: experimental
        '''
        return typing.cast("Redshift", jsii.invoke(self, "toDescribeDataSharesForProducer", []))

    @jsii.member(jsii_name="toDescribeDefaultClusterParameters")
    def to_describe_default_cluster_parameters(self) -> "Redshift":
        '''(experimental) Grants permission to describe parameter settings for a parameter group family.

        Access Level: Read

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_DescribeDefaultClusterParameters.html

        :stability: experimental
        '''
        return typing.cast("Redshift", jsii.invoke(self, "toDescribeDefaultClusterParameters", []))

    @jsii.member(jsii_name="toDescribeEndpointAccess")
    def to_describe_endpoint_access(self) -> "Redshift":
        '''(experimental) Grants permission to describe redshift-managed vpc endpoints.

        Access Level: Read

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_DescribeEndpointAccess.html

        :stability: experimental
        '''
        return typing.cast("Redshift", jsii.invoke(self, "toDescribeEndpointAccess", []))

    @jsii.member(jsii_name="toDescribeEndpointAuthorization")
    def to_describe_endpoint_authorization(self) -> "Redshift":
        '''(experimental) Grants permission to authorize describe activity for redshift-managed vpc endpoint.

        Access Level: Permissions management

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_DescribeEndpointAuthorization.html

        :stability: experimental
        '''
        return typing.cast("Redshift", jsii.invoke(self, "toDescribeEndpointAuthorization", []))

    @jsii.member(jsii_name="toDescribeEventCategories")
    def to_describe_event_categories(self) -> "Redshift":
        '''(experimental) Grants permission to describe event categories for all event source types, or for a specified source type.

        Access Level: Read

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_DescribeEventCategories.html

        :stability: experimental
        '''
        return typing.cast("Redshift", jsii.invoke(self, "toDescribeEventCategories", []))

    @jsii.member(jsii_name="toDescribeEvents")
    def to_describe_events(self) -> "Redshift":
        '''(experimental) Grants permission to describe events related to clusters, security groups, snapshots, and parameter groups for the past 14 days.

        Access Level: List

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_DescribeEvents.html

        :stability: experimental
        '''
        return typing.cast("Redshift", jsii.invoke(self, "toDescribeEvents", []))

    @jsii.member(jsii_name="toDescribeEventSubscriptions")
    def to_describe_event_subscriptions(self) -> "Redshift":
        '''(experimental) Grants permission to describe Amazon Redshift event notification subscriptions for the specified AWS account.

        Access Level: Read

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_DescribeEventSubscriptions.html

        :stability: experimental
        '''
        return typing.cast("Redshift", jsii.invoke(self, "toDescribeEventSubscriptions", []))

    @jsii.member(jsii_name="toDescribeHsmClientCertificates")
    def to_describe_hsm_client_certificates(self) -> "Redshift":
        '''(experimental) Grants permission to describe HSM client certificates.

        Access Level: Read

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_DescribeHsmClientCertificates.html

        :stability: experimental
        '''
        return typing.cast("Redshift", jsii.invoke(self, "toDescribeHsmClientCertificates", []))

    @jsii.member(jsii_name="toDescribeHsmConfigurations")
    def to_describe_hsm_configurations(self) -> "Redshift":
        '''(experimental) Grants permission to describe Amazon Redshift HSM configurations.

        Access Level: Read

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_DescribeHsmConfigurations.html

        :stability: experimental
        '''
        return typing.cast("Redshift", jsii.invoke(self, "toDescribeHsmConfigurations", []))

    @jsii.member(jsii_name="toDescribeLoggingStatus")
    def to_describe_logging_status(self) -> "Redshift":
        '''(experimental) Grants permission to describe whether information, such as queries and connection attempts, is being logged for a cluster.

        Access Level: Read

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_DescribeLoggingStatus.html

        :stability: experimental
        '''
        return typing.cast("Redshift", jsii.invoke(self, "toDescribeLoggingStatus", []))

    @jsii.member(jsii_name="toDescribeNodeConfigurationOptions")
    def to_describe_node_configuration_options(self) -> "Redshift":
        '''(experimental) Grants permission to describe properties of possible node configurations such as node type, number of nodes, and disk usage for the specified action type.

        Access Level: List

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_DescribeNodeConfigurationOptions.html

        :stability: experimental
        '''
        return typing.cast("Redshift", jsii.invoke(self, "toDescribeNodeConfigurationOptions", []))

    @jsii.member(jsii_name="toDescribeOrderableClusterOptions")
    def to_describe_orderable_cluster_options(self) -> "Redshift":
        '''(experimental) Grants permission to describe orderable cluster options.

        Access Level: Read

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_DescribeOrderableClusterOptions.html

        :stability: experimental
        '''
        return typing.cast("Redshift", jsii.invoke(self, "toDescribeOrderableClusterOptions", []))

    @jsii.member(jsii_name="toDescribePartners")
    def to_describe_partners(self) -> "Redshift":
        '''(experimental) Grants permission to retrieve information about the partner integrations defined for a cluster.

        Access Level: Read

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_DescribePartners.html

        :stability: experimental
        '''
        return typing.cast("Redshift", jsii.invoke(self, "toDescribePartners", []))

    @jsii.member(jsii_name="toDescribeQuery")
    def to_describe_query(self) -> "Redshift":
        '''(experimental) Grants permission to describe a query through the Amazon Redshift console.

        Access Level: Read

        https://docs.aws.amazon.com/redshift/latest/mgmt/redshift-policy-resources.resource-permissions.html

        :stability: experimental
        '''
        return typing.cast("Redshift", jsii.invoke(self, "toDescribeQuery", []))

    @jsii.member(jsii_name="toDescribeReservedNodeExchangeStatus")
    def to_describe_reserved_node_exchange_status(self) -> "Redshift":
        '''(experimental) Grants permission to describe exchange status details and associated metadata for a reserved-node exchange.

        Statuses include such values as in progress and requested

        Access Level: Read

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_DescribeReservedNodeExchangeStatus.html

        :stability: experimental
        '''
        return typing.cast("Redshift", jsii.invoke(self, "toDescribeReservedNodeExchangeStatus", []))

    @jsii.member(jsii_name="toDescribeReservedNodeOfferings")
    def to_describe_reserved_node_offerings(self) -> "Redshift":
        '''(experimental) Grants permission to describe available reserved node offerings by Amazon Redshift.

        Access Level: Read

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_DescribeReservedNodeOfferings.html

        :stability: experimental
        '''
        return typing.cast("Redshift", jsii.invoke(self, "toDescribeReservedNodeOfferings", []))

    @jsii.member(jsii_name="toDescribeReservedNodes")
    def to_describe_reserved_nodes(self) -> "Redshift":
        '''(experimental) Grants permission to describe the reserved nodes.

        Access Level: Read

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_DescribeReservedNodes.html

        :stability: experimental
        '''
        return typing.cast("Redshift", jsii.invoke(self, "toDescribeReservedNodes", []))

    @jsii.member(jsii_name="toDescribeResize")
    def to_describe_resize(self) -> "Redshift":
        '''(experimental) Grants permission to describe the last resize operation for a cluster.

        Access Level: Read

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_DescribeResize.html

        :stability: experimental
        '''
        return typing.cast("Redshift", jsii.invoke(self, "toDescribeResize", []))

    @jsii.member(jsii_name="toDescribeSavedQueries")
    def to_describe_saved_queries(self) -> "Redshift":
        '''(experimental) Grants permission to describe saved queries through the Amazon Redshift console.

        Access Level: Read

        https://docs.aws.amazon.com/redshift/latest/mgmt/redshift-policy-resources.resource-permissions.html

        :stability: experimental
        '''
        return typing.cast("Redshift", jsii.invoke(self, "toDescribeSavedQueries", []))

    @jsii.member(jsii_name="toDescribeScheduledActions")
    def to_describe_scheduled_actions(self) -> "Redshift":
        '''(experimental) Grants permission to describe created Amazon Redshift scheduled actions.

        Access Level: Read

        :stability: experimental
        '''
        return typing.cast("Redshift", jsii.invoke(self, "toDescribeScheduledActions", []))

    @jsii.member(jsii_name="toDescribeSnapshotCopyGrants")
    def to_describe_snapshot_copy_grants(self) -> "Redshift":
        '''(experimental) Grants permission to describe snapshot copy grants owned by the specified AWS account in the destination AWS Region.

        Access Level: Read

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_DescribeSnapshotCopyGrants.html

        :stability: experimental
        '''
        return typing.cast("Redshift", jsii.invoke(self, "toDescribeSnapshotCopyGrants", []))

    @jsii.member(jsii_name="toDescribeSnapshotSchedules")
    def to_describe_snapshot_schedules(self) -> "Redshift":
        '''(experimental) Grants permission to describe snapshot schedules.

        Access Level: Read

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_DescribeSnapshotSchedules.html

        :stability: experimental
        '''
        return typing.cast("Redshift", jsii.invoke(self, "toDescribeSnapshotSchedules", []))

    @jsii.member(jsii_name="toDescribeStorage")
    def to_describe_storage(self) -> "Redshift":
        '''(experimental) Grants permission to describe account level backups storage size and provisional storage.

        Access Level: Read

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_DescribeStorage.html

        :stability: experimental
        '''
        return typing.cast("Redshift", jsii.invoke(self, "toDescribeStorage", []))

    @jsii.member(jsii_name="toDescribeTable")
    def to_describe_table(self) -> "Redshift":
        '''(experimental) Grants permission to describe a table through the Amazon Redshift console.

        Access Level: Read

        https://docs.aws.amazon.com/redshift/latest/mgmt/redshift-policy-resources.resource-permissions.html

        :stability: experimental
        '''
        return typing.cast("Redshift", jsii.invoke(self, "toDescribeTable", []))

    @jsii.member(jsii_name="toDescribeTableRestoreStatus")
    def to_describe_table_restore_status(self) -> "Redshift":
        '''(experimental) Grants permission to describe status of one or more table restore requests made using the RestoreTableFromClusterSnapshot API action.

        Access Level: Read

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_DescribeTableRestoreStatus.html

        :stability: experimental
        '''
        return typing.cast("Redshift", jsii.invoke(self, "toDescribeTableRestoreStatus", []))

    @jsii.member(jsii_name="toDescribeTags")
    def to_describe_tags(self) -> "Redshift":
        '''(experimental) Grants permission to describe tags.

        Access Level: Read

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_DescribeTags.html

        :stability: experimental
        '''
        return typing.cast("Redshift", jsii.invoke(self, "toDescribeTags", []))

    @jsii.member(jsii_name="toDescribeUsageLimits")
    def to_describe_usage_limits(self) -> "Redshift":
        '''(experimental) Grants permission to describe usage limits.

        Access Level: Read

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_DescribeUsageLimits.html

        :stability: experimental
        '''
        return typing.cast("Redshift", jsii.invoke(self, "toDescribeUsageLimits", []))

    @jsii.member(jsii_name="toDisableLogging")
    def to_disable_logging(self) -> "Redshift":
        '''(experimental) Grants permission to disable logging information, such as queries and connection attempts, for a cluster.

        Access Level: Write

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_DisableLogging.html

        :stability: experimental
        '''
        return typing.cast("Redshift", jsii.invoke(self, "toDisableLogging", []))

    @jsii.member(jsii_name="toDisableSnapshotCopy")
    def to_disable_snapshot_copy(self) -> "Redshift":
        '''(experimental) Grants permission to disable the automatic copy of snapshots for a cluster.

        Access Level: Write

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_DisableSnapshotCopy.html

        :stability: experimental
        '''
        return typing.cast("Redshift", jsii.invoke(self, "toDisableSnapshotCopy", []))

    @jsii.member(jsii_name="toDisassociateDataShareConsumer")
    def to_disassociate_data_share_consumer(self) -> "Redshift":
        '''(experimental) Grants permission to disassociate a consumer from a datashare.

        Access Level: Write

        Possible conditions:

        - .ifConsumerArn()

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_DisassociateDataShareConsumer.html

        :stability: experimental
        '''
        return typing.cast("Redshift", jsii.invoke(self, "toDisassociateDataShareConsumer", []))

    @jsii.member(jsii_name="toEnableLogging")
    def to_enable_logging(self) -> "Redshift":
        '''(experimental) Grants permission to enable logging information, such as queries and connection attempts, for a cluster.

        Access Level: Write

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_EnableLogging.html

        :stability: experimental
        '''
        return typing.cast("Redshift", jsii.invoke(self, "toEnableLogging", []))

    @jsii.member(jsii_name="toEnableSnapshotCopy")
    def to_enable_snapshot_copy(self) -> "Redshift":
        '''(experimental) Grants permission to enable the automatic copy of snapshots for a cluster.

        Access Level: Write

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_EnableSnapshotCopy.html

        :stability: experimental
        '''
        return typing.cast("Redshift", jsii.invoke(self, "toEnableSnapshotCopy", []))

    @jsii.member(jsii_name="toExecuteQuery")
    def to_execute_query(self) -> "Redshift":
        '''(experimental) Grants permission to execute a query through the Amazon Redshift console.

        Access Level: Write

        https://docs.aws.amazon.com/redshift/latest/mgmt/redshift-policy-resources.resource-permissions.html

        :stability: experimental
        '''
        return typing.cast("Redshift", jsii.invoke(self, "toExecuteQuery", []))

    @jsii.member(jsii_name="toFetchResults")
    def to_fetch_results(self) -> "Redshift":
        '''(experimental) Grants permission to fetch query results through the Amazon Redshift console.

        Access Level: Read

        https://docs.aws.amazon.com/redshift/latest/mgmt/redshift-policy-resources.resource-permissions.html

        :stability: experimental
        '''
        return typing.cast("Redshift", jsii.invoke(self, "toFetchResults", []))

    @jsii.member(jsii_name="toGetClusterCredentials")
    def to_get_cluster_credentials(self) -> "Redshift":
        '''(experimental) Grants permission to get temporary credentials to access an Amazon Redshift database by the specified AWS account.

        Access Level: Write

        Possible conditions:

        - .ifDbName()
        - .ifDbUser()
        - .ifDurationSeconds()

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_GetClusterCredentials.html

        :stability: experimental
        '''
        return typing.cast("Redshift", jsii.invoke(self, "toGetClusterCredentials", []))

    @jsii.member(jsii_name="toGetClusterCredentialsWithIAM")
    def to_get_cluster_credentials_with_iam(self) -> "Redshift":
        '''(experimental) Grants permission to get enhanced temporary credentials to access an Amazon Redshift database by the specified AWS account.

        Access Level: Write

        Possible conditions:

        - .ifDbName()
        - .ifDurationSeconds()

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_GetClusterCredentialsWithIAM.html

        :stability: experimental
        '''
        return typing.cast("Redshift", jsii.invoke(self, "toGetClusterCredentialsWithIAM", []))

    @jsii.member(jsii_name="toGetReservedNodeExchangeConfigurationOptions")
    def to_get_reserved_node_exchange_configuration_options(self) -> "Redshift":
        '''(experimental) Grants permission to get the configuration options for the reserved-node exchange.

        Access Level: Read

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_GetReservedNodeExchangeConfigurationOptions.html

        :stability: experimental
        '''
        return typing.cast("Redshift", jsii.invoke(self, "toGetReservedNodeExchangeConfigurationOptions", []))

    @jsii.member(jsii_name="toGetReservedNodeExchangeOfferings")
    def to_get_reserved_node_exchange_offerings(self) -> "Redshift":
        '''(experimental) Grants permission to get an array of DC2 ReservedNodeOfferings that matches the payment type, term, and usage price of the given DC1 reserved node.

        Access Level: Read

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_GetReservedNodeExchangeOfferings.html

        :stability: experimental
        '''
        return typing.cast("Redshift", jsii.invoke(self, "toGetReservedNodeExchangeOfferings", []))

    @jsii.member(jsii_name="toJoinGroup")
    def to_join_group(self) -> "Redshift":
        '''(experimental) Grants permission to join the specified Amazon Redshift group.

        Access Level: Permissions management

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_GetClusterCredentials.html

        :stability: experimental
        '''
        return typing.cast("Redshift", jsii.invoke(self, "toJoinGroup", []))

    @jsii.member(jsii_name="toListDatabases")
    def to_list_databases(self) -> "Redshift":
        '''(experimental) Grants permission to list databases through the Amazon Redshift console.

        Access Level: List

        https://docs.aws.amazon.com/redshift/latest/mgmt/redshift-policy-resources.resource-permissions.html

        :stability: experimental
        '''
        return typing.cast("Redshift", jsii.invoke(self, "toListDatabases", []))

    @jsii.member(jsii_name="toListSavedQueries")
    def to_list_saved_queries(self) -> "Redshift":
        '''(experimental) Grants permission to list saved queries through the Amazon Redshift console.

        Access Level: List

        https://docs.aws.amazon.com/redshift/latest/mgmt/redshift-policy-resources.resource-permissions.html

        :stability: experimental
        '''
        return typing.cast("Redshift", jsii.invoke(self, "toListSavedQueries", []))

    @jsii.member(jsii_name="toListSchemas")
    def to_list_schemas(self) -> "Redshift":
        '''(experimental) Grants permission to list schemas through the Amazon Redshift console.

        Access Level: List

        https://docs.aws.amazon.com/redshift/latest/mgmt/redshift-policy-resources.resource-permissions.html

        :stability: experimental
        '''
        return typing.cast("Redshift", jsii.invoke(self, "toListSchemas", []))

    @jsii.member(jsii_name="toListTables")
    def to_list_tables(self) -> "Redshift":
        '''(experimental) Grants permission to list tables through the Amazon Redshift console.

        Access Level: List

        https://docs.aws.amazon.com/redshift/latest/mgmt/redshift-policy-resources.resource-permissions.html

        :stability: experimental
        '''
        return typing.cast("Redshift", jsii.invoke(self, "toListTables", []))

    @jsii.member(jsii_name="toModifyAquaConfiguration")
    def to_modify_aqua_configuration(self) -> "Redshift":
        '''(experimental) Grants permission to modify the AQUA configuration of a cluster.

        Access Level: Write

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_ModifyAquaConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Redshift", jsii.invoke(self, "toModifyAquaConfiguration", []))

    @jsii.member(jsii_name="toModifyAuthenticationProfile")
    def to_modify_authentication_profile(self) -> "Redshift":
        '''(experimental) Grants permission to modify an existing Amazon Redshift authentication profile.

        Access Level: Write

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_ModifyAuthenticationProfile.html

        :stability: experimental
        '''
        return typing.cast("Redshift", jsii.invoke(self, "toModifyAuthenticationProfile", []))

    @jsii.member(jsii_name="toModifyCluster")
    def to_modify_cluster(self) -> "Redshift":
        '''(experimental) Grants permission to modify the settings of a cluster.

        Access Level: Write

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_ModifyCluster.html

        :stability: experimental
        '''
        return typing.cast("Redshift", jsii.invoke(self, "toModifyCluster", []))

    @jsii.member(jsii_name="toModifyClusterDbRevision")
    def to_modify_cluster_db_revision(self) -> "Redshift":
        '''(experimental) Grants permission to modify the database revision of a cluster.

        Access Level: Write

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_ModifyClusterDbRevision.html

        :stability: experimental
        '''
        return typing.cast("Redshift", jsii.invoke(self, "toModifyClusterDbRevision", []))

    @jsii.member(jsii_name="toModifyClusterIamRoles")
    def to_modify_cluster_iam_roles(self) -> "Redshift":
        '''(experimental) Grants permission to modify the list of AWS Identity and Access Management (IAM) roles that can be used by a cluster to access other AWS services.

        Access Level: Permissions management

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_ModifyClusterIamRoles.html

        :stability: experimental
        '''
        return typing.cast("Redshift", jsii.invoke(self, "toModifyClusterIamRoles", []))

    @jsii.member(jsii_name="toModifyClusterMaintenance")
    def to_modify_cluster_maintenance(self) -> "Redshift":
        '''(experimental) Grants permission to modify the maintenance settings of a cluster.

        Access Level: Write

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_ModifyClusterMaintenance.html

        :stability: experimental
        '''
        return typing.cast("Redshift", jsii.invoke(self, "toModifyClusterMaintenance", []))

    @jsii.member(jsii_name="toModifyClusterParameterGroup")
    def to_modify_cluster_parameter_group(self) -> "Redshift":
        '''(experimental) Grants permission to modify the parameters of a parameter group.

        Access Level: Write

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_ModifyClusterParameterGroup.html

        :stability: experimental
        '''
        return typing.cast("Redshift", jsii.invoke(self, "toModifyClusterParameterGroup", []))

    @jsii.member(jsii_name="toModifyClusterSnapshot")
    def to_modify_cluster_snapshot(self) -> "Redshift":
        '''(experimental) Grants permission to modify the settings of a snapshot.

        Access Level: Write

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_ModifyClusterSnapshot.html

        :stability: experimental
        '''
        return typing.cast("Redshift", jsii.invoke(self, "toModifyClusterSnapshot", []))

    @jsii.member(jsii_name="toModifyClusterSnapshotSchedule")
    def to_modify_cluster_snapshot_schedule(self) -> "Redshift":
        '''(experimental) Grants permission to modify a snapshot schedule for a cluster.

        Access Level: Write

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_ModifyClusterSnapshotSchedule.html

        :stability: experimental
        '''
        return typing.cast("Redshift", jsii.invoke(self, "toModifyClusterSnapshotSchedule", []))

    @jsii.member(jsii_name="toModifyClusterSubnetGroup")
    def to_modify_cluster_subnet_group(self) -> "Redshift":
        '''(experimental) Grants permission to modify a cluster subnet group to include the specified list of VPC subnets.

        Access Level: Write

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_ModifyClusterSubnetGroup.html

        :stability: experimental
        '''
        return typing.cast("Redshift", jsii.invoke(self, "toModifyClusterSubnetGroup", []))

    @jsii.member(jsii_name="toModifyEndpointAccess")
    def to_modify_endpoint_access(self) -> "Redshift":
        '''(experimental) Grants permission to modify a redshift-managed vpc endpoint.

        Access Level: Write

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_ModifyEndpointAccess.html

        :stability: experimental
        '''
        return typing.cast("Redshift", jsii.invoke(self, "toModifyEndpointAccess", []))

    @jsii.member(jsii_name="toModifyEventSubscription")
    def to_modify_event_subscription(self) -> "Redshift":
        '''(experimental) Grants permission to modify an existing Amazon Redshift event notification subscription.

        Access Level: Write

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_ModifyEventSubscription.html

        :stability: experimental
        '''
        return typing.cast("Redshift", jsii.invoke(self, "toModifyEventSubscription", []))

    @jsii.member(jsii_name="toModifySavedQuery")
    def to_modify_saved_query(self) -> "Redshift":
        '''(experimental) Grants permission to modify an existing saved query through the Amazon Redshift console.

        Access Level: Write

        https://docs.aws.amazon.com/redshift/latest/mgmt/redshift-policy-resources.resource-permissions.html

        :stability: experimental
        '''
        return typing.cast("Redshift", jsii.invoke(self, "toModifySavedQuery", []))

    @jsii.member(jsii_name="toModifyScheduledAction")
    def to_modify_scheduled_action(self) -> "Redshift":
        '''(experimental) Grants permission to modify an existing Amazon Redshift scheduled action.

        Access Level: Write

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_ModifyScheduledAction.html

        :stability: experimental
        '''
        return typing.cast("Redshift", jsii.invoke(self, "toModifyScheduledAction", []))

    @jsii.member(jsii_name="toModifySnapshotCopyRetentionPeriod")
    def to_modify_snapshot_copy_retention_period(self) -> "Redshift":
        '''(experimental) Grants permission to modify the number of days to retain snapshots in the destination AWS Region after they are copied from the source AWS Region.

        Access Level: Write

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_ModifySnapshotCopyRetentionPeriod.html

        :stability: experimental
        '''
        return typing.cast("Redshift", jsii.invoke(self, "toModifySnapshotCopyRetentionPeriod", []))

    @jsii.member(jsii_name="toModifySnapshotSchedule")
    def to_modify_snapshot_schedule(self) -> "Redshift":
        '''(experimental) Grants permission to modify a snapshot schedule.

        Access Level: Write

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_ModifySnapshotSchedule.html

        :stability: experimental
        '''
        return typing.cast("Redshift", jsii.invoke(self, "toModifySnapshotSchedule", []))

    @jsii.member(jsii_name="toModifyUsageLimit")
    def to_modify_usage_limit(self) -> "Redshift":
        '''(experimental) Grants permission to modify a usage limit.

        Access Level: Write

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_ModifyUsageLimit.html

        :stability: experimental
        '''
        return typing.cast("Redshift", jsii.invoke(self, "toModifyUsageLimit", []))

    @jsii.member(jsii_name="toPauseCluster")
    def to_pause_cluster(self) -> "Redshift":
        '''(experimental) Grants permission to pause a cluster.

        Access Level: Write

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_PauseCluster.html

        :stability: experimental
        '''
        return typing.cast("Redshift", jsii.invoke(self, "toPauseCluster", []))

    @jsii.member(jsii_name="toPurchaseReservedNodeOffering")
    def to_purchase_reserved_node_offering(self) -> "Redshift":
        '''(experimental) Grants permission to purchase a reserved node.

        Access Level: Write

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_PurchaseReservedNodeOffering.html

        :stability: experimental
        '''
        return typing.cast("Redshift", jsii.invoke(self, "toPurchaseReservedNodeOffering", []))

    @jsii.member(jsii_name="toRebootCluster")
    def to_reboot_cluster(self) -> "Redshift":
        '''(experimental) Grants permission to reboot a cluster.

        Access Level: Write

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_RebootCluster.html

        :stability: experimental
        '''
        return typing.cast("Redshift", jsii.invoke(self, "toRebootCluster", []))

    @jsii.member(jsii_name="toRejectDataShare")
    def to_reject_data_share(self) -> "Redshift":
        '''(experimental) Grants permission to decline a datashare shared from another account.

        Access Level: Permissions management

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_RejectDataShare.html

        :stability: experimental
        '''
        return typing.cast("Redshift", jsii.invoke(self, "toRejectDataShare", []))

    @jsii.member(jsii_name="toResetClusterParameterGroup")
    def to_reset_cluster_parameter_group(self) -> "Redshift":
        '''(experimental) Grants permission to set one or more parameters of a parameter group to their default values and set the source values of the parameters to "engine-default".

        Access Level: Write

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_ResetClusterParameterGroup.html

        :stability: experimental
        '''
        return typing.cast("Redshift", jsii.invoke(self, "toResetClusterParameterGroup", []))

    @jsii.member(jsii_name="toResizeCluster")
    def to_resize_cluster(self) -> "Redshift":
        '''(experimental) Grants permission to change the size of a cluster.

        Access Level: Write

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_ResizeCluster.html

        :stability: experimental
        '''
        return typing.cast("Redshift", jsii.invoke(self, "toResizeCluster", []))

    @jsii.member(jsii_name="toRestoreFromClusterSnapshot")
    def to_restore_from_cluster_snapshot(self) -> "Redshift":
        '''(experimental) Grants permission to create a cluster from a snapshot.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_RestoreFromClusterSnapshot.html

        :stability: experimental
        '''
        return typing.cast("Redshift", jsii.invoke(self, "toRestoreFromClusterSnapshot", []))

    @jsii.member(jsii_name="toRestoreTableFromClusterSnapshot")
    def to_restore_table_from_cluster_snapshot(self) -> "Redshift":
        '''(experimental) Grants permission to create a table from a table in an Amazon Redshift cluster snapshot.

        Access Level: Write

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_RestoreTableFromClusterSnapshot.html

        :stability: experimental
        '''
        return typing.cast("Redshift", jsii.invoke(self, "toRestoreTableFromClusterSnapshot", []))

    @jsii.member(jsii_name="toResumeCluster")
    def to_resume_cluster(self) -> "Redshift":
        '''(experimental) Grants permission to resume a cluster.

        Access Level: Write

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_ResumeCluster.html

        :stability: experimental
        '''
        return typing.cast("Redshift", jsii.invoke(self, "toResumeCluster", []))

    @jsii.member(jsii_name="toRevokeClusterSecurityGroupIngress")
    def to_revoke_cluster_security_group_ingress(self) -> "Redshift":
        '''(experimental) Grants permission to revoke an ingress rule in an Amazon Redshift security group for a previously authorized IP range or Amazon EC2 security group.

        Access Level: Write

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_RevokeClusterSecurityGroupIngress.html

        :stability: experimental
        '''
        return typing.cast("Redshift", jsii.invoke(self, "toRevokeClusterSecurityGroupIngress", []))

    @jsii.member(jsii_name="toRevokeEndpointAccess")
    def to_revoke_endpoint_access(self) -> "Redshift":
        '''(experimental) Grants permission to revoke access for endpoint related activities for redshift-managed vpc endpoint.

        Access Level: Permissions management

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_RevokeEndpointAccess.html

        :stability: experimental
        '''
        return typing.cast("Redshift", jsii.invoke(self, "toRevokeEndpointAccess", []))

    @jsii.member(jsii_name="toRevokeSnapshotAccess")
    def to_revoke_snapshot_access(self) -> "Redshift":
        '''(experimental) Grants permission to revoke access from the specified AWS account to restore a snapshot.

        Access Level: Permissions management

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_RevokeSnapshotAccess.html

        :stability: experimental
        '''
        return typing.cast("Redshift", jsii.invoke(self, "toRevokeSnapshotAccess", []))

    @jsii.member(jsii_name="toRotateEncryptionKey")
    def to_rotate_encryption_key(self) -> "Redshift":
        '''(experimental) Grants permission to rotate an encryption key for a cluster.

        Access Level: Write

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_RotateEncryptionKey.html

        :stability: experimental
        '''
        return typing.cast("Redshift", jsii.invoke(self, "toRotateEncryptionKey", []))

    @jsii.member(jsii_name="toUpdatePartnerStatus")
    def to_update_partner_status(self) -> "Redshift":
        '''(experimental) Grants permission to update the status of a partner integration.

        Access Level: Write

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_UpdatePartnerStatus.html

        :stability: experimental
        '''
        return typing.cast("Redshift", jsii.invoke(self, "toUpdatePartnerStatus", []))

    @jsii.member(jsii_name="toViewQueriesFromConsole")
    def to_view_queries_from_console(self) -> "Redshift":
        '''(experimental) Grants permission to view query results through the Amazon Redshift console.

        Access Level: List

        https://docs.aws.amazon.com/redshift/latest/mgmt/redshift-policy-resources.resource-permissions.html

        :stability: experimental
        '''
        return typing.cast("Redshift", jsii.invoke(self, "toViewQueriesFromConsole", []))

    @jsii.member(jsii_name="toViewQueriesInConsole")
    def to_view_queries_in_console(self) -> "Redshift":
        '''(experimental) Grants permission to terminate running queries and loads through the Amazon Redshift console.

        Access Level: List

        https://docs.aws.amazon.com/redshift/latest/mgmt/redshift-policy-resources.resource-permissions.html

        :stability: experimental
        '''
        return typing.cast("Redshift", jsii.invoke(self, "toViewQueriesInConsole", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__27a3783acef7fc0edd4d41af61709ce4884c380d97d49404bb1b4668a801434a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__26f8fe0f17b8f2aab016793718e12bd0665be7bb46c1a02bed72c1dd32a1aa66)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class RedshiftData(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.RedshiftData",
):
    '''(experimental) Statement provider for service `redshift-data <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonredshiftdataapi.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `redshift-data <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonredshiftdataapi.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="ifStatementOwnerIamUserid")
    def if_statement_owner_iam_userid(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "RedshiftData":
        '''(experimental) Filters access by statement owner iam userid.

        https://docs.aws.amazon.com/redshift/latest/mgmt/redshift-iam-access-control-overview.html#redshift-policy-resources.conditions

        Applies to actions:

        - .toCancelStatement()
        - .toDescribeStatement()
        - .toGetStatementResult()
        - .toListStatements()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f0bdc2ec501837e62f0a169f110ddff63a15c3e522f83607c22c4b242b28794c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("RedshiftData", jsii.invoke(self, "ifStatementOwnerIamUserid", [value, operator]))

    @jsii.member(jsii_name="onCluster")
    def on_cluster(
        self,
        cluster_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "RedshiftData":
        '''(experimental) Adds a resource of type cluster to the statement.

        https://docs.aws.amazon.com/redshift/latest/mgmt/working-with-clusters.html

        :param cluster_name: - Identifier for the clusterName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9760aa5e7590453f83ffd7c92c202a39f1fa565a94a3d056250d66820c163716)
            check_type(argname="argument cluster_name", value=cluster_name, expected_type=type_hints["cluster_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("RedshiftData", jsii.invoke(self, "onCluster", [cluster_name, account, region, partition]))

    @jsii.member(jsii_name="onWorkgroup")
    def on_workgroup(
        self,
        workgroup_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "RedshiftData":
        '''(experimental) Adds a resource of type workgroup to the statement.

        https://docs.aws.amazon.com/redshift/latest/mgmt/working-with-serverless.html

        :param workgroup_id: - Identifier for the workgroupId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b25d020bc47e677a27c12f7e89bc0671c2757532036da378d09f856aeba6cbdd)
            check_type(argname="argument workgroup_id", value=workgroup_id, expected_type=type_hints["workgroup_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("RedshiftData", jsii.invoke(self, "onWorkgroup", [workgroup_id, account, region, partition]))

    @jsii.member(jsii_name="toBatchExecuteStatement")
    def to_batch_execute_statement(self) -> "RedshiftData":
        '''(experimental) Grants permission to execute multiple queries under a single connection.

        Access Level: Write

        https://docs.aws.amazon.com/redshift-data/latest/APIReference/API_BatchExecuteStatement.html

        :stability: experimental
        '''
        return typing.cast("RedshiftData", jsii.invoke(self, "toBatchExecuteStatement", []))

    @jsii.member(jsii_name="toCancelStatement")
    def to_cancel_statement(self) -> "RedshiftData":
        '''(experimental) Grants permission to cancel a running query.

        Access Level: Write

        Possible conditions:

        - .ifStatementOwnerIamUserid()

        https://docs.aws.amazon.com/redshift-data/latest/APIReference/API_CancelStatement.html

        :stability: experimental
        '''
        return typing.cast("RedshiftData", jsii.invoke(self, "toCancelStatement", []))

    @jsii.member(jsii_name="toDescribeStatement")
    def to_describe_statement(self) -> "RedshiftData":
        '''(experimental) Grants permission to retrieve detailed information about a statement execution.

        Access Level: Read

        Possible conditions:

        - .ifStatementOwnerIamUserid()

        https://docs.aws.amazon.com/redshift-data/latest/APIReference/API_DescribeStatement.html

        :stability: experimental
        '''
        return typing.cast("RedshiftData", jsii.invoke(self, "toDescribeStatement", []))

    @jsii.member(jsii_name="toDescribeTable")
    def to_describe_table(self) -> "RedshiftData":
        '''(experimental) Grants permission to retrieve metadata about a particular table.

        Access Level: Read

        https://docs.aws.amazon.com/redshift-data/latest/APIReference/API_DescribeTable.html

        :stability: experimental
        '''
        return typing.cast("RedshiftData", jsii.invoke(self, "toDescribeTable", []))

    @jsii.member(jsii_name="toExecuteStatement")
    def to_execute_statement(self) -> "RedshiftData":
        '''(experimental) Grants permission to execute a query.

        Access Level: Write

        https://docs.aws.amazon.com/redshift-data/latest/APIReference/API_ExecuteStatement.html

        :stability: experimental
        '''
        return typing.cast("RedshiftData", jsii.invoke(self, "toExecuteStatement", []))

    @jsii.member(jsii_name="toGetStatementResult")
    def to_get_statement_result(self) -> "RedshiftData":
        '''(experimental) Grants permission to fetch the result of a query.

        Access Level: Read

        Possible conditions:

        - .ifStatementOwnerIamUserid()

        https://docs.aws.amazon.com/redshift-data/latest/APIReference/API_GetStatementResult.html

        :stability: experimental
        '''
        return typing.cast("RedshiftData", jsii.invoke(self, "toGetStatementResult", []))

    @jsii.member(jsii_name="toListDatabases")
    def to_list_databases(self) -> "RedshiftData":
        '''(experimental) Grants permission to list databases for a given cluster.

        Access Level: Read

        https://docs.aws.amazon.com/redshift-data/latest/APIReference/API_ListDatabases.html

        :stability: experimental
        '''
        return typing.cast("RedshiftData", jsii.invoke(self, "toListDatabases", []))

    @jsii.member(jsii_name="toListSchemas")
    def to_list_schemas(self) -> "RedshiftData":
        '''(experimental) Grants permission to list schemas for a given cluster.

        Access Level: Read

        https://docs.aws.amazon.com/redshift-data/latest/APIReference/API_ListSchemas.html

        :stability: experimental
        '''
        return typing.cast("RedshiftData", jsii.invoke(self, "toListSchemas", []))

    @jsii.member(jsii_name="toListStatements")
    def to_list_statements(self) -> "RedshiftData":
        '''(experimental) Grants permission to list queries for a given principal.

        Access Level: List

        Possible conditions:

        - .ifStatementOwnerIamUserid()

        https://docs.aws.amazon.com/redshift-data/latest/APIReference/API_ListStatements.html

        :stability: experimental
        '''
        return typing.cast("RedshiftData", jsii.invoke(self, "toListStatements", []))

    @jsii.member(jsii_name="toListTables")
    def to_list_tables(self) -> "RedshiftData":
        '''(experimental) Grants permission to list tables for a given cluster.

        Access Level: List

        https://docs.aws.amazon.com/redshift-data/latest/APIReference/API_ListTables.html

        :stability: experimental
        '''
        return typing.cast("RedshiftData", jsii.invoke(self, "toListTables", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c9bcaf7e78efb7a26d198755edd4bd8d4988fdc51d3d58951d0d42d10014f48b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__961d688957f974f942ebc0acfe0de7f5f6d3db09d2f7e1a0e6355756f57f7aa3)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class RedshiftServerless(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.RedshiftServerless",
):
    '''(experimental) Statement provider for service `redshift-serverless <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonredshiftserverless.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `redshift-serverless <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonredshiftserverless.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="ifEndpointAccessId")
    def if_endpoint_access_id(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "RedshiftServerless":
        '''(experimental) Filters access by the endpoint access identifier.

        https://docs.aws.amazon.com/redshift/latest/mgmt/redshift-policy-resources.resource-permissions.html

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5f70805c90b3ed2f5766473e78d4b136dc10dd32e96597ecad45c09d52de069c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("RedshiftServerless", jsii.invoke(self, "ifEndpointAccessId", [value, operator]))

    @jsii.member(jsii_name="ifNamespaceId")
    def if_namespace_id(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "RedshiftServerless":
        '''(experimental) Filters access by the namespace identifier.

        https://docs.aws.amazon.com/redshift/latest/mgmt/redshift-policy-resources.resource-permissions.html

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2c64fd462106c9cf44ec86636da6b98ad072ca935b1dde8abc4587a7e2d8a2ff)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("RedshiftServerless", jsii.invoke(self, "ifNamespaceId", [value, operator]))

    @jsii.member(jsii_name="ifRecoveryPointId")
    def if_recovery_point_id(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "RedshiftServerless":
        '''(experimental) Filters access by the recovery point identifier.

        https://docs.aws.amazon.com/redshift/latest/mgmt/redshift-policy-resources.resource-permissions.html

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2b46922be7ca33b011c823b4a336893d8d9641458850fbeae3746d0d3bf4a8dd)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("RedshiftServerless", jsii.invoke(self, "ifRecoveryPointId", [value, operator]))

    @jsii.member(jsii_name="ifSnapshotId")
    def if_snapshot_id(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "RedshiftServerless":
        '''(experimental) Filters access by the snapshot identifier.

        https://docs.aws.amazon.com/redshift/latest/mgmt/redshift-policy-resources.resource-permissions.html

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f76aee1acad2752c1a61c35c7bfcaf21fc5ab044ecbdbcedcaae95855627d6fe)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("RedshiftServerless", jsii.invoke(self, "ifSnapshotId", [value, operator]))

    @jsii.member(jsii_name="ifWorkgroupId")
    def if_workgroup_id(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "RedshiftServerless":
        '''(experimental) Filters access by the workgroup identifier.

        https://docs.aws.amazon.com/redshift/latest/mgmt/redshift-policy-resources.resource-permissions.html

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__08036020ddd194d8f3941761586cc22fc4f511d39899b44c895e3fd6aad4f91e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("RedshiftServerless", jsii.invoke(self, "ifWorkgroupId", [value, operator]))

    @jsii.member(jsii_name="onEndpointAccess")
    def on_endpoint_access(
        self,
        endpoint_access_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "RedshiftServerless":
        '''(experimental) Adds a resource of type endpointAccess to the statement.

        https://docs.aws.amazon.com/redshift/latest/mgmt/serverless-connecting.html

        :param endpoint_access_id: - Identifier for the endpointAccessId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__facc4b3fab0879e9a5a8ef9f3fe7182992abf386d1df8501ea23acae7f46dba6)
            check_type(argname="argument endpoint_access_id", value=endpoint_access_id, expected_type=type_hints["endpoint_access_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("RedshiftServerless", jsii.invoke(self, "onEndpointAccess", [endpoint_access_id, account, region, partition]))

    @jsii.member(jsii_name="onNamespace")
    def on_namespace(
        self,
        namespace_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "RedshiftServerless":
        '''(experimental) Adds a resource of type namespace to the statement.

        https://docs.aws.amazon.com/redshift/latest/mgmt/serverless-workgroup-namespace.html

        :param namespace_id: - Identifier for the namespaceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__27832be3785047cecded20ffc374a27ba2885e762112e5812f757257b9b237e7)
            check_type(argname="argument namespace_id", value=namespace_id, expected_type=type_hints["namespace_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("RedshiftServerless", jsii.invoke(self, "onNamespace", [namespace_id, account, region, partition]))

    @jsii.member(jsii_name="onRecoveryPoint")
    def on_recovery_point(
        self,
        recovery_point_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "RedshiftServerless":
        '''(experimental) Adds a resource of type recoveryPoint to the statement.

        https://docs.aws.amazon.com/redshift/latest/mgmt/serverless-snapshots-recovery.html

        :param recovery_point_id: - Identifier for the recoveryPointId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c2494e33673557550abe8b81af9fcad0911e3a9e170731ddc324d42a83f7de50)
            check_type(argname="argument recovery_point_id", value=recovery_point_id, expected_type=type_hints["recovery_point_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("RedshiftServerless", jsii.invoke(self, "onRecoveryPoint", [recovery_point_id, account, region, partition]))

    @jsii.member(jsii_name="onSnapshot")
    def on_snapshot(
        self,
        snapshot_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "RedshiftServerless":
        '''(experimental) Adds a resource of type snapshot to the statement.

        https://docs.aws.amazon.com/redshift/latest/mgmt/serverless-snapshots-recovery.html

        :param snapshot_id: - Identifier for the snapshotId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__512d1b4bbece9e20bce96451aba9dc48d4222a533272edb225721e18b77057f9)
            check_type(argname="argument snapshot_id", value=snapshot_id, expected_type=type_hints["snapshot_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("RedshiftServerless", jsii.invoke(self, "onSnapshot", [snapshot_id, account, region, partition]))

    @jsii.member(jsii_name="onWorkgroup")
    def on_workgroup(
        self,
        workgroup_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "RedshiftServerless":
        '''(experimental) Adds a resource of type workgroup to the statement.

        https://docs.aws.amazon.com/redshift/latest/mgmt/serverless-workgroup-namespace.html

        :param workgroup_id: - Identifier for the workgroupId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__71c17ebfd86c4b4bcf164d4e41e028cd62010dee072b860bff61ae6d180e1127)
            check_type(argname="argument workgroup_id", value=workgroup_id, expected_type=type_hints["workgroup_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("RedshiftServerless", jsii.invoke(self, "onWorkgroup", [workgroup_id, account, region, partition]))

    @jsii.member(jsii_name="toConvertRecoveryPointToSnapshot")
    def to_convert_recovery_point_to_snapshot(self) -> "RedshiftServerless":
        '''(experimental) Grants permission to convert a recovery point to a snapshot.

        Access Level: Write

        https://docs.aws.amazon.com/redshift-serverless/latest/APIReference/API_ConvertRecoveryPointToSnapshot.html

        :stability: experimental
        '''
        return typing.cast("RedshiftServerless", jsii.invoke(self, "toConvertRecoveryPointToSnapshot", []))

    @jsii.member(jsii_name="toCreateEndpointAccess")
    def to_create_endpoint_access(self) -> "RedshiftServerless":
        '''(experimental) Grants permission to create an Amazon Redshift Serverless managed VPC endpoint.

        Access Level: Write

        https://docs.aws.amazon.com/redshift-serverless/latest/APIReference/API_CreateEndpointAccess.html

        :stability: experimental
        '''
        return typing.cast("RedshiftServerless", jsii.invoke(self, "toCreateEndpointAccess", []))

    @jsii.member(jsii_name="toCreateNamespace")
    def to_create_namespace(self) -> "RedshiftServerless":
        '''(experimental) Grants permission to create an Amazon Redshift Serverless namespace.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/redshift-serverless/latest/APIReference/API_CreateNamespace.html

        :stability: experimental
        '''
        return typing.cast("RedshiftServerless", jsii.invoke(self, "toCreateNamespace", []))

    @jsii.member(jsii_name="toCreateSnapshot")
    def to_create_snapshot(self) -> "RedshiftServerless":
        '''(experimental) Grants permission to create a snapshot of all databases in a namespace.

        Access Level: Write

        https://docs.aws.amazon.com/redshift-serverless/latest/APIReference/API_CreateSnapshot.html

        :stability: experimental
        '''
        return typing.cast("RedshiftServerless", jsii.invoke(self, "toCreateSnapshot", []))

    @jsii.member(jsii_name="toCreateUsageLimit")
    def to_create_usage_limit(self) -> "RedshiftServerless":
        '''(experimental) Grants permission to create a usage limit for a specified Amazon Redshift Serverless usage type.

        Access Level: Write

        https://docs.aws.amazon.com/redshift-serverless/latest/APIReference/API_CreateUsageLimit.html

        :stability: experimental
        '''
        return typing.cast("RedshiftServerless", jsii.invoke(self, "toCreateUsageLimit", []))

    @jsii.member(jsii_name="toCreateWorkgroup")
    def to_create_workgroup(self) -> "RedshiftServerless":
        '''(experimental) Grants permission to create a workgroup in Amazon Redshift Serverless.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/redshift-serverless/latest/APIReference/API_CreateWorkgroup.html

        :stability: experimental
        '''
        return typing.cast("RedshiftServerless", jsii.invoke(self, "toCreateWorkgroup", []))

    @jsii.member(jsii_name="toDeleteEndpointAccess")
    def to_delete_endpoint_access(self) -> "RedshiftServerless":
        '''(experimental) Grants permission to delete an Amazon Redshift Serverless managed VPC endpoint.

        Access Level: Write

        https://docs.aws.amazon.com/redshift-serverless/latest/APIReference/API_DeleteEndpointAccess.html

        :stability: experimental
        '''
        return typing.cast("RedshiftServerless", jsii.invoke(self, "toDeleteEndpointAccess", []))

    @jsii.member(jsii_name="toDeleteNamespace")
    def to_delete_namespace(self) -> "RedshiftServerless":
        '''(experimental) Grants permission to delete a namespace from Amazon Redshift Serverless.

        Access Level: Write

        https://docs.aws.amazon.com/redshift-serverless/latest/APIReference/API_DeleteNamespace.html

        :stability: experimental
        '''
        return typing.cast("RedshiftServerless", jsii.invoke(self, "toDeleteNamespace", []))

    @jsii.member(jsii_name="toDeleteResourcePolicy")
    def to_delete_resource_policy(self) -> "RedshiftServerless":
        '''(experimental) Grants permission to delete the specified resource policy.

        Access Level: Write

        https://docs.aws.amazon.com/redshift-serverless/latest/APIReference/API_DeleteResourcePolicy.html

        :stability: experimental
        '''
        return typing.cast("RedshiftServerless", jsii.invoke(self, "toDeleteResourcePolicy", []))

    @jsii.member(jsii_name="toDeleteSnapshot")
    def to_delete_snapshot(self) -> "RedshiftServerless":
        '''(experimental) Grants permission to delete a snapshot from Amazon Redshift Serverless.

        Access Level: Write

        https://docs.aws.amazon.com/redshift-serverless/latest/APIReference/API_DeleteSnapshot.html

        :stability: experimental
        '''
        return typing.cast("RedshiftServerless", jsii.invoke(self, "toDeleteSnapshot", []))

    @jsii.member(jsii_name="toDeleteUsageLimit")
    def to_delete_usage_limit(self) -> "RedshiftServerless":
        '''(experimental) Grants permission to delete a usage limit from Amazon Redshift Serverless.

        Access Level: Write

        https://docs.aws.amazon.com/redshift-serverless/latest/APIReference/API_DeleteUsageLimit.html

        :stability: experimental
        '''
        return typing.cast("RedshiftServerless", jsii.invoke(self, "toDeleteUsageLimit", []))

    @jsii.member(jsii_name="toDeleteWorkgroup")
    def to_delete_workgroup(self) -> "RedshiftServerless":
        '''(experimental) Grants permission to delete a workgroup.

        Access Level: Write

        https://docs.aws.amazon.com/redshift-serverless/latest/APIReference/API_DeleteWorkgroup.html

        :stability: experimental
        '''
        return typing.cast("RedshiftServerless", jsii.invoke(self, "toDeleteWorkgroup", []))

    @jsii.member(jsii_name="toGetCredentials")
    def to_get_credentials(self) -> "RedshiftServerless":
        '''(experimental) Grants permission to get a database user name and temporary password with temporary authorization to log on to Amazon Redshift Serverless.

        Access Level: Write

        https://docs.aws.amazon.com/redshift-serverless/latest/APIReference/API_GetCredentials.html

        :stability: experimental
        '''
        return typing.cast("RedshiftServerless", jsii.invoke(self, "toGetCredentials", []))

    @jsii.member(jsii_name="toGetEndpointAccess")
    def to_get_endpoint_access(self) -> "RedshiftServerless":
        '''(experimental) Grants permission to create an Amazon Redshift Serverless managed VPC endpoint.

        Access Level: Read

        https://docs.aws.amazon.com/redshift-serverless/latest/APIReference/API_GetEndpointAccess.html

        :stability: experimental
        '''
        return typing.cast("RedshiftServerless", jsii.invoke(self, "toGetEndpointAccess", []))

    @jsii.member(jsii_name="toGetNamespace")
    def to_get_namespace(self) -> "RedshiftServerless":
        '''(experimental) Grants permission to get information about a namespace in Amazon Redshift Serverless.

        Access Level: Read

        https://docs.aws.amazon.com/redshift-serverless/latest/APIReference/API_GetNamespace.html

        :stability: experimental
        '''
        return typing.cast("RedshiftServerless", jsii.invoke(self, "toGetNamespace", []))

    @jsii.member(jsii_name="toGetRecoveryPoint")
    def to_get_recovery_point(self) -> "RedshiftServerless":
        '''(experimental) Grants permission to get information about a recovery point.

        Access Level: Read

        https://docs.aws.amazon.com/redshift-serverless/latest/APIReference/API_GetRecoveryPoint.html

        :stability: experimental
        '''
        return typing.cast("RedshiftServerless", jsii.invoke(self, "toGetRecoveryPoint", []))

    @jsii.member(jsii_name="toGetResourcePolicy")
    def to_get_resource_policy(self) -> "RedshiftServerless":
        '''(experimental) Grants permission to get a resource policy.

        Access Level: Read

        https://docs.aws.amazon.com/redshift-serverless/latest/APIReference/API_GetResourcePolicy.html

        :stability: experimental
        '''
        return typing.cast("RedshiftServerless", jsii.invoke(self, "toGetResourcePolicy", []))

    @jsii.member(jsii_name="toGetSnapshot")
    def to_get_snapshot(self) -> "RedshiftServerless":
        '''(experimental) Grants permission to get information about a specific snapshot.

        Access Level: Read

        https://docs.aws.amazon.com/redshift-serverless/latest/APIReference/API_GetSnapshot.html

        :stability: experimental
        '''
        return typing.cast("RedshiftServerless", jsii.invoke(self, "toGetSnapshot", []))

    @jsii.member(jsii_name="toGetUsageLimit")
    def to_get_usage_limit(self) -> "RedshiftServerless":
        '''(experimental) Grants permission to get information about a usage limit in Amazon Redshift Serverless.

        Access Level: Read

        https://docs.aws.amazon.com/redshift-serverless/latest/APIReference/API_GetUsageLimit.html

        :stability: experimental
        '''
        return typing.cast("RedshiftServerless", jsii.invoke(self, "toGetUsageLimit", []))

    @jsii.member(jsii_name="toGetWorkgroup")
    def to_get_workgroup(self) -> "RedshiftServerless":
        '''(experimental) Grants permission to get information about a specific workgroup.

        Access Level: Read

        https://docs.aws.amazon.com/redshift-serverless/latest/APIReference/API_GetWorkgroup.html

        :stability: experimental
        '''
        return typing.cast("RedshiftServerless", jsii.invoke(self, "toGetWorkgroup", []))

    @jsii.member(jsii_name="toListEndpointAccess")
    def to_list_endpoint_access(self) -> "RedshiftServerless":
        '''(experimental) Grants permission to list EndpointAccess objects and relevant information.

        Access Level: List

        https://docs.aws.amazon.com/redshift-serverless/latest/APIReference/API_ListEndpointAccess.html

        :stability: experimental
        '''
        return typing.cast("RedshiftServerless", jsii.invoke(self, "toListEndpointAccess", []))

    @jsii.member(jsii_name="toListNamespaces")
    def to_list_namespaces(self) -> "RedshiftServerless":
        '''(experimental) Grants permission to list namespaces in Amazon Redshift Serverless.

        Access Level: List

        https://docs.aws.amazon.com/redshift-serverless/latest/APIReference/API_ListNamespaces.html

        :stability: experimental
        '''
        return typing.cast("RedshiftServerless", jsii.invoke(self, "toListNamespaces", []))

    @jsii.member(jsii_name="toListRecoveryPoints")
    def to_list_recovery_points(self) -> "RedshiftServerless":
        '''(experimental) Grants permission to list an array of recovery points.

        Access Level: List

        https://docs.aws.amazon.com/redshift-serverless/latest/APIReference/API_ListRecoveryPoints.html

        :stability: experimental
        '''
        return typing.cast("RedshiftServerless", jsii.invoke(self, "toListRecoveryPoints", []))

    @jsii.member(jsii_name="toListSnapshots")
    def to_list_snapshots(self) -> "RedshiftServerless":
        '''(experimental) Grants permission to list snapshots.

        Access Level: List

        https://docs.aws.amazon.com/redshift-serverless/latest/APIReference/API_ListSnapshots.html

        :stability: experimental
        '''
        return typing.cast("RedshiftServerless", jsii.invoke(self, "toListSnapshots", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "RedshiftServerless":
        '''(experimental) Grants permission to list the tags assigned to a resource.

        Access Level: List

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/redshift-serverless/latest/APIReference/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("RedshiftServerless", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toListUsageLimits")
    def to_list_usage_limits(self) -> "RedshiftServerless":
        '''(experimental) Grants permission to list all usage limits within Amazon Redshift Serverless.

        Access Level: List

        https://docs.aws.amazon.com/redshift-serverless/latest/APIReference/API_ListUsageLimits.html

        :stability: experimental
        '''
        return typing.cast("RedshiftServerless", jsii.invoke(self, "toListUsageLimits", []))

    @jsii.member(jsii_name="toListWorkgroups")
    def to_list_workgroups(self) -> "RedshiftServerless":
        '''(experimental) Grants permission to list workgroups in Amazon Redshift Serverless.

        Access Level: List

        https://docs.aws.amazon.com/redshift-serverless/latest/APIReference/API_ListWorkgroups.html

        :stability: experimental
        '''
        return typing.cast("RedshiftServerless", jsii.invoke(self, "toListWorkgroups", []))

    @jsii.member(jsii_name="toPutResourcePolicy")
    def to_put_resource_policy(self) -> "RedshiftServerless":
        '''(experimental) Grants permission to create or update a resource policy.

        Access Level: Write

        https://docs.aws.amazon.com/redshift-serverless/latest/APIReference/API_PutResourcePolicy.html

        :stability: experimental
        '''
        return typing.cast("RedshiftServerless", jsii.invoke(self, "toPutResourcePolicy", []))

    @jsii.member(jsii_name="toRestoreFromRecoveryPoint")
    def to_restore_from_recovery_point(self) -> "RedshiftServerless":
        '''(experimental) Grants permission to restore the data from a recovery point.

        Access Level: Write

        https://docs.aws.amazon.com/redshift-serverless/latest/APIReference/API_RestoreFromRecoveryPoint.html

        :stability: experimental
        '''
        return typing.cast("RedshiftServerless", jsii.invoke(self, "toRestoreFromRecoveryPoint", []))

    @jsii.member(jsii_name="toRestoreFromSnapshot")
    def to_restore_from_snapshot(self) -> "RedshiftServerless":
        '''(experimental) Grants permission to restore a namespace from a snapshot.

        Access Level: Write

        https://docs.aws.amazon.com/redshift-serverless/latest/APIReference/API_RestoreFromSnapshot.html

        :stability: experimental
        '''
        return typing.cast("RedshiftServerless", jsii.invoke(self, "toRestoreFromSnapshot", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "RedshiftServerless":
        '''(experimental) Grants permission to assign one or more tags to a resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()
        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/redshift-serverless/latest/APIReference/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("RedshiftServerless", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "RedshiftServerless":
        '''(experimental) Grants permission to remove a tag or set of tags from a resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/redshift-serverless/latest/APIReference/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("RedshiftServerless", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateEndpointAccess")
    def to_update_endpoint_access(self) -> "RedshiftServerless":
        '''(experimental) Grants permission to update an Amazon Redshift Serverless managed VPC endpoint.

        Access Level: Write

        https://docs.aws.amazon.com/redshift-serverless/latest/APIReference/API_UpdateEndpointAccess.html

        :stability: experimental
        '''
        return typing.cast("RedshiftServerless", jsii.invoke(self, "toUpdateEndpointAccess", []))

    @jsii.member(jsii_name="toUpdateNamespace")
    def to_update_namespace(self) -> "RedshiftServerless":
        '''(experimental) Grants permission to update a namespace with the specified configuration settings.

        Access Level: Write

        https://docs.aws.amazon.com/redshift-serverless/latest/APIReference/API_UpdateNamespace.html

        :stability: experimental
        '''
        return typing.cast("RedshiftServerless", jsii.invoke(self, "toUpdateNamespace", []))

    @jsii.member(jsii_name="toUpdateSnapshot")
    def to_update_snapshot(self) -> "RedshiftServerless":
        '''(experimental) Grants permission to update a snapshot.

        Access Level: Write

        https://docs.aws.amazon.com/redshift-serverless/latest/APIReference/API_UpdateSnapshot.html

        :stability: experimental
        '''
        return typing.cast("RedshiftServerless", jsii.invoke(self, "toUpdateSnapshot", []))

    @jsii.member(jsii_name="toUpdateUsageLimit")
    def to_update_usage_limit(self) -> "RedshiftServerless":
        '''(experimental) Grants permission to update a usage limit in Amazon Redshift Serverless.

        Access Level: Write

        https://docs.aws.amazon.com/redshift-serverless/latest/APIReference/API_UpdateUsageLimit.html

        :stability: experimental
        '''
        return typing.cast("RedshiftServerless", jsii.invoke(self, "toUpdateUsageLimit", []))

    @jsii.member(jsii_name="toUpdateWorkgroup")
    def to_update_workgroup(self) -> "RedshiftServerless":
        '''(experimental) Grants permission to update an Amazon Redshift Serverless workgroup with the specified configuration settings.

        Access Level: Write

        https://docs.aws.amazon.com/redshift-serverless/latest/APIReference/API_UpdateWorkgroup.html

        :stability: experimental
        '''
        return typing.cast("RedshiftServerless", jsii.invoke(self, "toUpdateWorkgroup", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__712e031176b21b2ad13d58e1cc12f7ffd97e71f30c8abc1fede153c27f52129b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3daca9081e22196517fb6bb34b60c97dca09a53e19cbc0fa3e15570c07554e54)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class RefactorSpaces(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.RefactorSpaces",
):
    '''(experimental) Statement provider for service `refactor-spaces <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsmigrationhubrefactorspaces.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `refactor-spaces <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsmigrationhubrefactorspaces.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="ifApplicationCreatedByAccount")
    def if_application_created_by_account(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "RefactorSpaces":
        '''(experimental) Filters access by restricting the action to only those accounts that created the application within an environment.

        https://docs.aws.amazon.com/migrationhub-refactor-spaces/latest/userguide/security_iam_service-with-iam.html#security_iam_service-with-iam-id-based-policies-conditionkeys

        Applies to actions:

        - .toCreateApplication()
        - .toCreateRoute()
        - .toCreateService()
        - .toDeleteApplication()
        - .toDeleteRoute()
        - .toDeleteService()
        - .toGetApplication()
        - .toGetRoute()
        - .toGetService()
        - .toTagResource()
        - .toUntagResource()
        - .toUpdateRoute()

        Applies to resource types:

        - application
        - service
        - route

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__74695e9de25a599223d50004511871229f14123c08c8bf82a0bee7ab0f9b2f27)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("RefactorSpaces", jsii.invoke(self, "ifApplicationCreatedByAccount", [value, operator]))

    @jsii.member(jsii_name="ifCreatedByAccountIds")
    def if_created_by_account_ids(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "RefactorSpaces":
        '''(experimental) Filters access by the accounts that created the resource.

        https://docs.aws.amazon.com/migrationhub-refactor-spaces/latest/userguide/security_iam_service-with-iam.html#security_iam_service-with-iam-id-based-policies-conditionkeys

        Applies to actions:

        - .toCreateApplication()
        - .toCreateRoute()
        - .toCreateService()
        - .toDeleteApplication()
        - .toDeleteRoute()
        - .toDeleteService()
        - .toGetApplication()
        - .toGetRoute()
        - .toGetService()
        - .toTagResource()
        - .toUntagResource()
        - .toUpdateRoute()

        Applies to resource types:

        - application
        - service
        - route

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6ac3b9e32c15f4303d052f7497e622936924d253cd71f01f876d62af616372dd)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("RefactorSpaces", jsii.invoke(self, "ifCreatedByAccountIds", [value, operator]))

    @jsii.member(jsii_name="ifRouteCreatedByAccount")
    def if_route_created_by_account(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "RefactorSpaces":
        '''(experimental) Filters access by restricting the action to only those accounts that created the route within an application.

        https://docs.aws.amazon.com/migrationhub-refactor-spaces/latest/userguide/security_iam_service-with-iam.html#security_iam_service-with-iam-id-based-policies-conditionkeys

        Applies to actions:

        - .toCreateRoute()
        - .toDeleteRoute()
        - .toGetRoute()
        - .toTagResource()
        - .toUntagResource()
        - .toUpdateRoute()

        Applies to resource types:

        - route

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b37f93e0fc7499b832ac828193261c4e4ffa7851f903f510761df8f02e6bf4be)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("RefactorSpaces", jsii.invoke(self, "ifRouteCreatedByAccount", [value, operator]))

    @jsii.member(jsii_name="ifServiceCreatedByAccount")
    def if_service_created_by_account(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "RefactorSpaces":
        '''(experimental) Filters access by restricting the action to only those accounts that created the service within an application.

        https://docs.aws.amazon.com/migrationhub-refactor-spaces/latest/userguide/security_iam_service-with-iam.html#security_iam_service-with-iam-id-based-policies-conditionkeys

        Applies to actions:

        - .toCreateRoute()
        - .toCreateService()
        - .toDeleteRoute()
        - .toDeleteService()
        - .toGetRoute()
        - .toGetService()
        - .toTagResource()
        - .toUntagResource()
        - .toUpdateRoute()

        Applies to resource types:

        - service
        - route

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3549224f7022f0024c90df002675c7f2218584e04d8b0cc386d1dd938f004d48)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("RefactorSpaces", jsii.invoke(self, "ifServiceCreatedByAccount", [value, operator]))

    @jsii.member(jsii_name="ifSourcePath")
    def if_source_path(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "RefactorSpaces":
        '''(experimental) Filters access by the path of the route.

        https://docs.aws.amazon.com/migrationhub-refactor-spaces/latest/userguide/security_iam_service-with-iam.html#security_iam_service-with-iam-id-based-policies-conditionkeys

        Applies to actions:

        - .toCreateRoute()
        - .toDeleteRoute()
        - .toGetRoute()
        - .toTagResource()
        - .toUntagResource()
        - .toUpdateRoute()

        Applies to resource types:

        - route

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ff8baf630ff7fecd2a755577fe8d8ac7c6aed07baba8c1e997cb31edf596b635)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("RefactorSpaces", jsii.invoke(self, "ifSourcePath", [value, operator]))

    @jsii.member(jsii_name="onApplication")
    def on_application(
        self,
        environment_id: builtins.str,
        application_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "RefactorSpaces":
        '''(experimental) Adds a resource of type application to the statement.

        https://docs.aws.amazon.com/migrationhub-refactor-spaces/latest/userguide/security_iam_service-with-iam.html#security_iam_service-with-iam-id-based-policies-resources

        :param environment_id: - Identifier for the environmentId.
        :param application_id: - Identifier for the applicationId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag() - .ifApplicationCreatedByAccount() - .ifCreatedByAccountIds()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7a3e678bafb3c9cd784042a8d0626a9d85a0553da5c97c40b09227404aac6d2b)
            check_type(argname="argument environment_id", value=environment_id, expected_type=type_hints["environment_id"])
            check_type(argname="argument application_id", value=application_id, expected_type=type_hints["application_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("RefactorSpaces", jsii.invoke(self, "onApplication", [environment_id, application_id, account, region, partition]))

    @jsii.member(jsii_name="onEnvironment")
    def on_environment(
        self,
        environment_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "RefactorSpaces":
        '''(experimental) Adds a resource of type environment to the statement.

        https://docs.aws.amazon.com/migrationhub-refactor-spaces/latest/userguide/security_iam_service-with-iam.html#security_iam_service-with-iam-id-based-policies-resources

        :param environment_id: - Identifier for the environmentId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3de92234f0725efdd42fd5d3a55a5e53c1b02159bc8ca5f14d812f929e761c4c)
            check_type(argname="argument environment_id", value=environment_id, expected_type=type_hints["environment_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("RefactorSpaces", jsii.invoke(self, "onEnvironment", [environment_id, account, region, partition]))

    @jsii.member(jsii_name="onRoute")
    def on_route(
        self,
        environment_id: builtins.str,
        application_id: builtins.str,
        route_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "RefactorSpaces":
        '''(experimental) Adds a resource of type route to the statement.

        https://docs.aws.amazon.com/migrationhub-refactor-spaces/latest/userguide/security_iam_service-with-iam.html#security_iam_service-with-iam-id-based-policies-resources

        :param environment_id: - Identifier for the environmentId.
        :param application_id: - Identifier for the applicationId.
        :param route_id: - Identifier for the routeId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag() - .ifApplicationCreatedByAccount() - .ifCreatedByAccountIds() - .ifRouteCreatedByAccount() - .ifServiceCreatedByAccount() - .ifSourcePath()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__26f21f32707684567451b14871bbcbb234bf16fbd09d04d076f0f20a41ccd4ac)
            check_type(argname="argument environment_id", value=environment_id, expected_type=type_hints["environment_id"])
            check_type(argname="argument application_id", value=application_id, expected_type=type_hints["application_id"])
            check_type(argname="argument route_id", value=route_id, expected_type=type_hints["route_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("RefactorSpaces", jsii.invoke(self, "onRoute", [environment_id, application_id, route_id, account, region, partition]))

    @jsii.member(jsii_name="onService")
    def on_service(
        self,
        environment_id: builtins.str,
        application_id: builtins.str,
        service_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "RefactorSpaces":
        '''(experimental) Adds a resource of type service to the statement.

        https://docs.aws.amazon.com/migrationhub-refactor-spaces/latest/userguide/security_iam_service-with-iam.html#security_iam_service-with-iam-id-based-policies-resources

        :param environment_id: - Identifier for the environmentId.
        :param application_id: - Identifier for the applicationId.
        :param service_id: - Identifier for the serviceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag() - .ifApplicationCreatedByAccount() - .ifCreatedByAccountIds() - .ifServiceCreatedByAccount()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c585d0bb4a7b6c4999d6ee0133954e96a491c562aae85b01b8b923bd029a8d6d)
            check_type(argname="argument environment_id", value=environment_id, expected_type=type_hints["environment_id"])
            check_type(argname="argument application_id", value=application_id, expected_type=type_hints["application_id"])
            check_type(argname="argument service_id", value=service_id, expected_type=type_hints["service_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("RefactorSpaces", jsii.invoke(self, "onService", [environment_id, application_id, service_id, account, region, partition]))

    @jsii.member(jsii_name="toCreateApplication")
    def to_create_application(self) -> "RefactorSpaces":
        '''(experimental) Grants permission to create an application within an environment.

        Access Level: Write

        Possible conditions:

        - .ifApplicationCreatedByAccount()
        - .ifCreatedByAccountIds()
        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/migrationhub-refactor-spaces/latest/APIReference/API_CreateApplication.html

        :stability: experimental
        '''
        return typing.cast("RefactorSpaces", jsii.invoke(self, "toCreateApplication", []))

    @jsii.member(jsii_name="toCreateEnvironment")
    def to_create_environment(self) -> "RefactorSpaces":
        '''(experimental) Grants permission to create an environment.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/migrationhub-refactor-spaces/latest/APIReference/API_CreateEnvironment.html

        :stability: experimental
        '''
        return typing.cast("RefactorSpaces", jsii.invoke(self, "toCreateEnvironment", []))

    @jsii.member(jsii_name="toCreateRoute")
    def to_create_route(self) -> "RefactorSpaces":
        '''(experimental) Grants permission to create a route within an application.

        Access Level: Write

        Possible conditions:

        - .ifApplicationCreatedByAccount()
        - .ifServiceCreatedByAccount()
        - .ifRouteCreatedByAccount()
        - .ifCreatedByAccountIds()
        - .ifSourcePath()
        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/migrationhub-refactor-spaces/latest/APIReference/API_CreateRoute.html

        :stability: experimental
        '''
        return typing.cast("RefactorSpaces", jsii.invoke(self, "toCreateRoute", []))

    @jsii.member(jsii_name="toCreateService")
    def to_create_service(self) -> "RefactorSpaces":
        '''(experimental) Grants permission to create a service within an application.

        Access Level: Write

        Possible conditions:

        - .ifApplicationCreatedByAccount()
        - .ifServiceCreatedByAccount()
        - .ifCreatedByAccountIds()
        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/migrationhub-refactor-spaces/latest/APIReference/API_CreateService.html

        :stability: experimental
        '''
        return typing.cast("RefactorSpaces", jsii.invoke(self, "toCreateService", []))

    @jsii.member(jsii_name="toDeleteApplication")
    def to_delete_application(self) -> "RefactorSpaces":
        '''(experimental) Grants permission to delete an application from an environment.

        Access Level: Write

        Possible conditions:

        - .ifApplicationCreatedByAccount()
        - .ifCreatedByAccountIds()
        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/migrationhub-refactor-spaces/latest/APIReference/API_DeleteApplication.html

        :stability: experimental
        '''
        return typing.cast("RefactorSpaces", jsii.invoke(self, "toDeleteApplication", []))

    @jsii.member(jsii_name="toDeleteEnvironment")
    def to_delete_environment(self) -> "RefactorSpaces":
        '''(experimental) Grants permission to delete an environment.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/migrationhub-refactor-spaces/latest/APIReference/API_DeleteEnvironment.html

        :stability: experimental
        '''
        return typing.cast("RefactorSpaces", jsii.invoke(self, "toDeleteEnvironment", []))

    @jsii.member(jsii_name="toDeleteResourcePolicy")
    def to_delete_resource_policy(self) -> "RefactorSpaces":
        '''(experimental) Grants permission to delete a resource policy.

        Access Level: Write

        https://docs.aws.amazon.com/migrationhub-refactor-spaces/latest/APIReference/API_DeleteResourcePolicy.html

        :stability: experimental
        '''
        return typing.cast("RefactorSpaces", jsii.invoke(self, "toDeleteResourcePolicy", []))

    @jsii.member(jsii_name="toDeleteRoute")
    def to_delete_route(self) -> "RefactorSpaces":
        '''(experimental) Grants permission to delete a route from an application.

        Access Level: Write

        Possible conditions:

        - .ifApplicationCreatedByAccount()
        - .ifServiceCreatedByAccount()
        - .ifRouteCreatedByAccount()
        - .ifCreatedByAccountIds()
        - .ifSourcePath()
        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/migrationhub-refactor-spaces/latest/APIReference/API_DeleteRoute.html

        :stability: experimental
        '''
        return typing.cast("RefactorSpaces", jsii.invoke(self, "toDeleteRoute", []))

    @jsii.member(jsii_name="toDeleteService")
    def to_delete_service(self) -> "RefactorSpaces":
        '''(experimental) Grants permission to delete a service from an application.

        Access Level: Write

        Possible conditions:

        - .ifApplicationCreatedByAccount()
        - .ifServiceCreatedByAccount()
        - .ifCreatedByAccountIds()
        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/migrationhub-refactor-spaces/latest/APIReference/API_DeleteService.html

        :stability: experimental
        '''
        return typing.cast("RefactorSpaces", jsii.invoke(self, "toDeleteService", []))

    @jsii.member(jsii_name="toGetApplication")
    def to_get_application(self) -> "RefactorSpaces":
        '''(experimental) Grants permission to get more information about an application.

        Access Level: Read

        Possible conditions:

        - .ifApplicationCreatedByAccount()
        - .ifCreatedByAccountIds()
        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/migrationhub-refactor-spaces/latest/APIReference/API_GetApplication.html

        :stability: experimental
        '''
        return typing.cast("RefactorSpaces", jsii.invoke(self, "toGetApplication", []))

    @jsii.member(jsii_name="toGetEnvironment")
    def to_get_environment(self) -> "RefactorSpaces":
        '''(experimental) Grants permission to get more information for an environment.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/migrationhub-refactor-spaces/latest/APIReference/API_GetEnvironment.html

        :stability: experimental
        '''
        return typing.cast("RefactorSpaces", jsii.invoke(self, "toGetEnvironment", []))

    @jsii.member(jsii_name="toGetResourcePolicy")
    def to_get_resource_policy(self) -> "RefactorSpaces":
        '''(experimental) Grants permission to get the details about a resource policy.

        Access Level: Read

        https://docs.aws.amazon.com/migrationhub-refactor-spaces/latest/APIReference/API_GetResourcePolicy.html

        :stability: experimental
        '''
        return typing.cast("RefactorSpaces", jsii.invoke(self, "toGetResourcePolicy", []))

    @jsii.member(jsii_name="toGetRoute")
    def to_get_route(self) -> "RefactorSpaces":
        '''(experimental) Grants permission to get more information about a route.

        Access Level: Read

        Possible conditions:

        - .ifApplicationCreatedByAccount()
        - .ifServiceCreatedByAccount()
        - .ifRouteCreatedByAccount()
        - .ifCreatedByAccountIds()
        - .ifSourcePath()
        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/migrationhub-refactor-spaces/latest/APIReference/API_GetRoute.html

        :stability: experimental
        '''
        return typing.cast("RefactorSpaces", jsii.invoke(self, "toGetRoute", []))

    @jsii.member(jsii_name="toGetService")
    def to_get_service(self) -> "RefactorSpaces":
        '''(experimental) Grants permission to get more information about a service.

        Access Level: Read

        Possible conditions:

        - .ifApplicationCreatedByAccount()
        - .ifServiceCreatedByAccount()
        - .ifCreatedByAccountIds()
        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/migrationhub-refactor-spaces/latest/APIReference/API_GetService.html

        :stability: experimental
        '''
        return typing.cast("RefactorSpaces", jsii.invoke(self, "toGetService", []))

    @jsii.member(jsii_name="toListApplications")
    def to_list_applications(self) -> "RefactorSpaces":
        '''(experimental) Grants permission to list all the applications in an environment.

        Access Level: Read

        https://docs.aws.amazon.com/migrationhub-refactor-spaces/latest/APIReference/API_ListApplications.html

        :stability: experimental
        '''
        return typing.cast("RefactorSpaces", jsii.invoke(self, "toListApplications", []))

    @jsii.member(jsii_name="toListEnvironments")
    def to_list_environments(self) -> "RefactorSpaces":
        '''(experimental) Grants permission to list all environments.

        Access Level: Read

        https://docs.aws.amazon.com/migrationhub-refactor-spaces/latest/APIReference/API_ListEnvironments.html

        :stability: experimental
        '''
        return typing.cast("RefactorSpaces", jsii.invoke(self, "toListEnvironments", []))

    @jsii.member(jsii_name="toListEnvironmentVpcs")
    def to_list_environment_vpcs(self) -> "RefactorSpaces":
        '''(experimental) Grants permission to list all the VPCs for the environment.

        Access Level: Read

        https://docs.aws.amazon.com/migrationhub-refactor-spaces/latest/APIReference/API_ListEnvironmentVpcs.html

        :stability: experimental
        '''
        return typing.cast("RefactorSpaces", jsii.invoke(self, "toListEnvironmentVpcs", []))

    @jsii.member(jsii_name="toListRoutes")
    def to_list_routes(self) -> "RefactorSpaces":
        '''(experimental) Grants permission to list all the routes in an application.

        Access Level: Read

        https://docs.aws.amazon.com/migrationhub-refactor-spaces/latest/APIReference/API_ListRoutes.html

        :stability: experimental
        '''
        return typing.cast("RefactorSpaces", jsii.invoke(self, "toListRoutes", []))

    @jsii.member(jsii_name="toListServices")
    def to_list_services(self) -> "RefactorSpaces":
        '''(experimental) Grants permission to list all the services in an environment.

        Access Level: Read

        https://docs.aws.amazon.com/migrationhub-refactor-spaces/latest/APIReference/API_ListServices.html

        :stability: experimental
        '''
        return typing.cast("RefactorSpaces", jsii.invoke(self, "toListServices", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "RefactorSpaces":
        '''(experimental) Grants permission to list all the tags for a given resource.

        Access Level: Read

        https://docs.aws.amazon.com/migrationhub-refactor-spaces/latest/APIReference/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("RefactorSpaces", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toPutResourcePolicy")
    def to_put_resource_policy(self) -> "RefactorSpaces":
        '''(experimental) Grants permission to add a resource policy.

        Access Level: Write

        https://docs.aws.amazon.com/migrationhub-refactor-spaces/latest/APIReference/API_PutResourcePolicy.html

        :stability: experimental
        '''
        return typing.cast("RefactorSpaces", jsii.invoke(self, "toPutResourcePolicy", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "RefactorSpaces":
        '''(experimental) Grants permission to tag a resource.

        Access Level: Tagging

        Possible conditions:

        - .ifApplicationCreatedByAccount()
        - .ifServiceCreatedByAccount()
        - .ifRouteCreatedByAccount()
        - .ifCreatedByAccountIds()
        - .ifSourcePath()
        - .ifAwsTagKeys()
        - .ifAwsRequestTag()
        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/migrationhub-refactor-spaces/latest/APIReference/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("RefactorSpaces", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "RefactorSpaces":
        '''(experimental) Grants permission to remove a tag from a resource.

        Access Level: Tagging

        Possible conditions:

        - .ifApplicationCreatedByAccount()
        - .ifServiceCreatedByAccount()
        - .ifRouteCreatedByAccount()
        - .ifCreatedByAccountIds()
        - .ifSourcePath()
        - .ifAwsTagKeys()
        - .ifAwsRequestTag()
        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/migrationhub-refactor-spaces/latest/APIReference/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("RefactorSpaces", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateRoute")
    def to_update_route(self) -> "RefactorSpaces":
        '''(experimental) Grants permission to update a route from an application.

        Access Level: Write

        Possible conditions:

        - .ifApplicationCreatedByAccount()
        - .ifServiceCreatedByAccount()
        - .ifRouteCreatedByAccount()
        - .ifCreatedByAccountIds()
        - .ifSourcePath()
        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/migrationhub-refactor-spaces/latest/APIReference/API_UpdateRoute.html

        :stability: experimental
        '''
        return typing.cast("RefactorSpaces", jsii.invoke(self, "toUpdateRoute", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__36d39356952edeed025fca47732a7c1f5422f197cd53d19226336a5fa13f158d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__832fa86560a5353e715104e64a422a616e4a7bdf55b6fa2d7fd5d9d29639a90b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Rekognition(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Rekognition",
):
    '''(experimental) Statement provider for service `rekognition <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonrekognition.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `rekognition <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonrekognition.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onCollection")
    def on_collection(
        self,
        collection_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Rekognition":
        '''(experimental) Adds a resource of type collection to the statement.

        https://docs.aws.amazon.com/rekognition/latest/dg/collections.html

        :param collection_id: - Identifier for the collectionId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ef769c33497a939f85ed8a7dc1cfd6438a208c29dc37ddb2d3f8065d2aefa152)
            check_type(argname="argument collection_id", value=collection_id, expected_type=type_hints["collection_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Rekognition", jsii.invoke(self, "onCollection", [collection_id, account, region, partition]))

    @jsii.member(jsii_name="onDataset")
    def on_dataset(
        self,
        project_name: builtins.str,
        dataset_type: builtins.str,
        creation_timestamp: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Rekognition":
        '''(experimental) Adds a resource of type dataset to the statement.

        https://docs.aws.amazon.com/rekognition/latest/customlabels-dg/creating-datasets.html

        :param project_name: - Identifier for the projectName.
        :param dataset_type: - Identifier for the datasetType.
        :param creation_timestamp: - Identifier for the creationTimestamp.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a4894838fa19e276fe2ccd9ec114333a631d62a526eb682de56147fab5b722c0)
            check_type(argname="argument project_name", value=project_name, expected_type=type_hints["project_name"])
            check_type(argname="argument dataset_type", value=dataset_type, expected_type=type_hints["dataset_type"])
            check_type(argname="argument creation_timestamp", value=creation_timestamp, expected_type=type_hints["creation_timestamp"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Rekognition", jsii.invoke(self, "onDataset", [project_name, dataset_type, creation_timestamp, account, region, partition]))

    @jsii.member(jsii_name="onProject")
    def on_project(
        self,
        project_name: builtins.str,
        creation_timestamp: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Rekognition":
        '''(experimental) Adds a resource of type project to the statement.

        https://docs.aws.amazon.com/rekognition/latest/customlabels-dg/mp-create-project.html

        :param project_name: - Identifier for the projectName.
        :param creation_timestamp: - Identifier for the creationTimestamp.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7b4e65681ce26c427368cf1925efccf503abd623e67803683304726200cc489a)
            check_type(argname="argument project_name", value=project_name, expected_type=type_hints["project_name"])
            check_type(argname="argument creation_timestamp", value=creation_timestamp, expected_type=type_hints["creation_timestamp"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Rekognition", jsii.invoke(self, "onProject", [project_name, creation_timestamp, account, region, partition]))

    @jsii.member(jsii_name="onProjectversion")
    def on_projectversion(
        self,
        project_name: builtins.str,
        version_name: builtins.str,
        creation_timestamp: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Rekognition":
        '''(experimental) Adds a resource of type projectversion to the statement.

        https://docs.aws.amazon.com/rekognition/latest/customlabels-dg/training-model.html

        :param project_name: - Identifier for the projectName.
        :param version_name: - Identifier for the versionName.
        :param creation_timestamp: - Identifier for the creationTimestamp.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__95283f7d4e4ca230169e60a2dc3b6c4598437f4455ae7f4978d8deab46598311)
            check_type(argname="argument project_name", value=project_name, expected_type=type_hints["project_name"])
            check_type(argname="argument version_name", value=version_name, expected_type=type_hints["version_name"])
            check_type(argname="argument creation_timestamp", value=creation_timestamp, expected_type=type_hints["creation_timestamp"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Rekognition", jsii.invoke(self, "onProjectversion", [project_name, version_name, creation_timestamp, account, region, partition]))

    @jsii.member(jsii_name="onStreamprocessor")
    def on_streamprocessor(
        self,
        streamprocessor_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Rekognition":
        '''(experimental) Adds a resource of type streamprocessor to the statement.

        https://docs.aws.amazon.com/rekognition/latest/dg/streaming-video.html

        :param streamprocessor_id: - Identifier for the streamprocessorId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ab3c82b5425bedc1f9bc98e845d21b6d403dec270f51f56701c0d90335f1c7c7)
            check_type(argname="argument streamprocessor_id", value=streamprocessor_id, expected_type=type_hints["streamprocessor_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Rekognition", jsii.invoke(self, "onStreamprocessor", [streamprocessor_id, account, region, partition]))

    @jsii.member(jsii_name="toCompareFaces")
    def to_compare_faces(self) -> "Rekognition":
        '''(experimental) Grants permission to compare faces in the source input image with each face detected in the target input image.

        Access Level: Read

        https://docs.aws.amazon.com/rekognition/latest/APIReference/API_CompareFaces.html

        :stability: experimental
        '''
        return typing.cast("Rekognition", jsii.invoke(self, "toCompareFaces", []))

    @jsii.member(jsii_name="toCopyProjectVersion")
    def to_copy_project_version(self) -> "Rekognition":
        '''(experimental) Grants permission to copy an existing model version to a new model version.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/rekognition/latest/APIReference/API_CopyProjectVersion.html

        :stability: experimental
        '''
        return typing.cast("Rekognition", jsii.invoke(self, "toCopyProjectVersion", []))

    @jsii.member(jsii_name="toCreateCollection")
    def to_create_collection(self) -> "Rekognition":
        '''(experimental) Grants permission to create a collection in an AWS Region.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/rekognition/latest/APIReference/API_CreateCollection.html

        :stability: experimental
        '''
        return typing.cast("Rekognition", jsii.invoke(self, "toCreateCollection", []))

    @jsii.member(jsii_name="toCreateDataset")
    def to_create_dataset(self) -> "Rekognition":
        '''(experimental) Grants permission to create a new Amazon Rekognition Custom Labels dataset.

        Access Level: Write

        https://docs.aws.amazon.com/rekognition/latest/APIReference/API_CreateDataset.html

        :stability: experimental
        '''
        return typing.cast("Rekognition", jsii.invoke(self, "toCreateDataset", []))

    @jsii.member(jsii_name="toCreateProject")
    def to_create_project(self) -> "Rekognition":
        '''(experimental) Grants permission to create an Amazon Rekognition Custom Labels project.

        Access Level: Write

        https://docs.aws.amazon.com/rekognition/latest/APIReference/API_CreateProject.html

        :stability: experimental
        '''
        return typing.cast("Rekognition", jsii.invoke(self, "toCreateProject", []))

    @jsii.member(jsii_name="toCreateProjectVersion")
    def to_create_project_version(self) -> "Rekognition":
        '''(experimental) Grants permission to begin training a new version of a model.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/rekognition/latest/APIReference/API_CreateProjectVersion.html

        :stability: experimental
        '''
        return typing.cast("Rekognition", jsii.invoke(self, "toCreateProjectVersion", []))

    @jsii.member(jsii_name="toCreateStreamProcessor")
    def to_create_stream_processor(self) -> "Rekognition":
        '''(experimental) Grants permission to create an Amazon Rekognition stream processor.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/rekognition/latest/APIReference/API_CreateStreamProcessor.html

        :stability: experimental
        '''
        return typing.cast("Rekognition", jsii.invoke(self, "toCreateStreamProcessor", []))

    @jsii.member(jsii_name="toDeleteCollection")
    def to_delete_collection(self) -> "Rekognition":
        '''(experimental) Grants permission to delete the specified collection.

        Access Level: Write

        https://docs.aws.amazon.com/rekognition/latest/APIReference/API_DeleteCollection.html

        :stability: experimental
        '''
        return typing.cast("Rekognition", jsii.invoke(self, "toDeleteCollection", []))

    @jsii.member(jsii_name="toDeleteDataset")
    def to_delete_dataset(self) -> "Rekognition":
        '''(experimental) Grants permission to delete an existing Amazon Rekognition Custom Labels dataset.

        Access Level: Write

        https://docs.aws.amazon.com/rekognition/latest/APIReference/API_DeleteDataset.html

        :stability: experimental
        '''
        return typing.cast("Rekognition", jsii.invoke(self, "toDeleteDataset", []))

    @jsii.member(jsii_name="toDeleteFaces")
    def to_delete_faces(self) -> "Rekognition":
        '''(experimental) Grants permission to delete faces from a collection.

        Access Level: Write

        https://docs.aws.amazon.com/rekognition/latest/APIReference/API_DeleteFaces.html

        :stability: experimental
        '''
        return typing.cast("Rekognition", jsii.invoke(self, "toDeleteFaces", []))

    @jsii.member(jsii_name="toDeleteProject")
    def to_delete_project(self) -> "Rekognition":
        '''(experimental) Grants permission to delete a project.

        Access Level: Write

        https://docs.aws.amazon.com/rekognition/latest/APIReference/API_DeleteProject.html

        :stability: experimental
        '''
        return typing.cast("Rekognition", jsii.invoke(self, "toDeleteProject", []))

    @jsii.member(jsii_name="toDeleteProjectPolicy")
    def to_delete_project_policy(self) -> "Rekognition":
        '''(experimental) Grants permission to delete a resource policy attached to a project.

        Access Level: Write

        https://docs.aws.amazon.com/rekognition/latest/APIReference/API_DeleteProjectPolicy.html

        :stability: experimental
        '''
        return typing.cast("Rekognition", jsii.invoke(self, "toDeleteProjectPolicy", []))

    @jsii.member(jsii_name="toDeleteProjectVersion")
    def to_delete_project_version(self) -> "Rekognition":
        '''(experimental) Grants permission to delete a model.

        Access Level: Write

        https://docs.aws.amazon.com/rekognition/latest/APIReference/API_DeleteProjectVersion.html

        :stability: experimental
        '''
        return typing.cast("Rekognition", jsii.invoke(self, "toDeleteProjectVersion", []))

    @jsii.member(jsii_name="toDeleteStreamProcessor")
    def to_delete_stream_processor(self) -> "Rekognition":
        '''(experimental) Grants permission to delete the specified stream processor.

        Access Level: Write

        https://docs.aws.amazon.com/rekognition/latest/APIReference/API_DeleteStreamProcessor.html

        :stability: experimental
        '''
        return typing.cast("Rekognition", jsii.invoke(self, "toDeleteStreamProcessor", []))

    @jsii.member(jsii_name="toDescribeCollection")
    def to_describe_collection(self) -> "Rekognition":
        '''(experimental) Grants permission to read details about a collection.

        Access Level: Read

        https://docs.aws.amazon.com/rekognition/latest/APIReference/API_DescribeCollection.html

        :stability: experimental
        '''
        return typing.cast("Rekognition", jsii.invoke(self, "toDescribeCollection", []))

    @jsii.member(jsii_name="toDescribeDataset")
    def to_describe_dataset(self) -> "Rekognition":
        '''(experimental) Grants permission to describe an Amazon Rekognition Custom Labels dataset.

        Access Level: Read

        https://docs.aws.amazon.com/rekognition/latest/APIReference/API_DescribeDataset.html

        :stability: experimental
        '''
        return typing.cast("Rekognition", jsii.invoke(self, "toDescribeDataset", []))

    @jsii.member(jsii_name="toDescribeProjects")
    def to_describe_projects(self) -> "Rekognition":
        '''(experimental) Grants permission to list Amazon Rekognition Custom Labels projects.

        Access Level: Read

        https://docs.aws.amazon.com/rekognition/latest/APIReference/API_DescribeProjects.html

        :stability: experimental
        '''
        return typing.cast("Rekognition", jsii.invoke(self, "toDescribeProjects", []))

    @jsii.member(jsii_name="toDescribeProjectVersions")
    def to_describe_project_versions(self) -> "Rekognition":
        '''(experimental) Grants permission to list the versions of a model in an Amazon Rekognition Custom Labels project.

        Access Level: Read

        https://docs.aws.amazon.com/rekognition/latest/APIReference/API_DescribeProjectVersions.html

        :stability: experimental
        '''
        return typing.cast("Rekognition", jsii.invoke(self, "toDescribeProjectVersions", []))

    @jsii.member(jsii_name="toDescribeStreamProcessor")
    def to_describe_stream_processor(self) -> "Rekognition":
        '''(experimental) Grants permission to get information about the specified stream processor.

        Access Level: Read

        https://docs.aws.amazon.com/rekognition/latest/APIReference/API_DescribeStreamProcessor.html

        :stability: experimental
        '''
        return typing.cast("Rekognition", jsii.invoke(self, "toDescribeStreamProcessor", []))

    @jsii.member(jsii_name="toDetectCustomLabels")
    def to_detect_custom_labels(self) -> "Rekognition":
        '''(experimental) Grants permission to detect custom labels in a supplied image.

        Access Level: Read

        https://docs.aws.amazon.com/rekognition/latest/APIReference/API_DetectCustomLabels.html

        :stability: experimental
        '''
        return typing.cast("Rekognition", jsii.invoke(self, "toDetectCustomLabels", []))

    @jsii.member(jsii_name="toDetectFaces")
    def to_detect_faces(self) -> "Rekognition":
        '''(experimental) Grants permission to detect human faces within an image provided as input.

        Access Level: Read

        https://docs.aws.amazon.com/rekognition/latest/APIReference/API_DetectFaces.html

        :stability: experimental
        '''
        return typing.cast("Rekognition", jsii.invoke(self, "toDetectFaces", []))

    @jsii.member(jsii_name="toDetectLabels")
    def to_detect_labels(self) -> "Rekognition":
        '''(experimental) Grants permission to detect instances of real-world labels within an image provided as input.

        Access Level: Read

        https://docs.aws.amazon.com/rekognition/latest/APIReference/API_DetectLabels.html

        :stability: experimental
        '''
        return typing.cast("Rekognition", jsii.invoke(self, "toDetectLabels", []))

    @jsii.member(jsii_name="toDetectModerationLabels")
    def to_detect_moderation_labels(self) -> "Rekognition":
        '''(experimental) Grants permission to detect moderation labels within the input image.

        Access Level: Read

        https://docs.aws.amazon.com/rekognition/latest/APIReference/API_DetectModerationLabels.html

        :stability: experimental
        '''
        return typing.cast("Rekognition", jsii.invoke(self, "toDetectModerationLabels", []))

    @jsii.member(jsii_name="toDetectProtectiveEquipment")
    def to_detect_protective_equipment(self) -> "Rekognition":
        '''(experimental) Grants permission to detect Personal Protective Equipment in the input image.

        Access Level: Read

        https://docs.aws.amazon.com/rekognition/latest/APIReference/API_DetectProtectiveEquipment.html

        :stability: experimental
        '''
        return typing.cast("Rekognition", jsii.invoke(self, "toDetectProtectiveEquipment", []))

    @jsii.member(jsii_name="toDetectText")
    def to_detect_text(self) -> "Rekognition":
        '''(experimental) Grants permission to detect text in the input image and convert it into machine-readable text.

        Access Level: Read

        https://docs.aws.amazon.com/rekognition/latest/APIReference/API_DetectText.html

        :stability: experimental
        '''
        return typing.cast("Rekognition", jsii.invoke(self, "toDetectText", []))

    @jsii.member(jsii_name="toDistributeDatasetEntries")
    def to_distribute_dataset_entries(self) -> "Rekognition":
        '''(experimental) Grants permission to distribute the entries in a training dataset across the training dataset and the test dataset for a project.

        Access Level: Write

        https://docs.aws.amazon.com/rekognition/latest/APIReference/API_DistributeDatasetEntries.html

        :stability: experimental
        '''
        return typing.cast("Rekognition", jsii.invoke(self, "toDistributeDatasetEntries", []))

    @jsii.member(jsii_name="toGetCelebrityInfo")
    def to_get_celebrity_info(self) -> "Rekognition":
        '''(experimental) Grants permission to read the name, and additional information, of a celebrity.

        Access Level: Read

        https://docs.aws.amazon.com/rekognition/latest/APIReference/API_GetCelebrityInfo.html

        :stability: experimental
        '''
        return typing.cast("Rekognition", jsii.invoke(self, "toGetCelebrityInfo", []))

    @jsii.member(jsii_name="toGetCelebrityRecognition")
    def to_get_celebrity_recognition(self) -> "Rekognition":
        '''(experimental) Grants permission to read the celebrity recognition results found in a stored video by an asynchronous celebrity recognition job.

        Access Level: Read

        https://docs.aws.amazon.com/rekognition/latest/APIReference/API_GetCelebrityRecognition.html

        :stability: experimental
        '''
        return typing.cast("Rekognition", jsii.invoke(self, "toGetCelebrityRecognition", []))

    @jsii.member(jsii_name="toGetContentModeration")
    def to_get_content_moderation(self) -> "Rekognition":
        '''(experimental) Grants permission to read the content moderation analysis results found in a stored video by an asynchronous content moderation job.

        Access Level: Read

        https://docs.aws.amazon.com/rekognition/latest/APIReference/API_GetContentModeration.html

        :stability: experimental
        '''
        return typing.cast("Rekognition", jsii.invoke(self, "toGetContentModeration", []))

    @jsii.member(jsii_name="toGetFaceDetection")
    def to_get_face_detection(self) -> "Rekognition":
        '''(experimental) Grants permission to read the faces detection results found in a stored video by an asynchronous face detection job.

        Access Level: Read

        https://docs.aws.amazon.com/rekognition/latest/APIReference/API_GetFaceDetection.html

        :stability: experimental
        '''
        return typing.cast("Rekognition", jsii.invoke(self, "toGetFaceDetection", []))

    @jsii.member(jsii_name="toGetFaceSearch")
    def to_get_face_search(self) -> "Rekognition":
        '''(experimental) Grants permission to read the matching collection faces found in a stored video by an asynchronous face search job.

        Access Level: Read

        https://docs.aws.amazon.com/rekognition/latest/APIReference/API_GetFaceSearch.html

        :stability: experimental
        '''
        return typing.cast("Rekognition", jsii.invoke(self, "toGetFaceSearch", []))

    @jsii.member(jsii_name="toGetLabelDetection")
    def to_get_label_detection(self) -> "Rekognition":
        '''(experimental) Grants permission to read the label detected resuls found in a stored video by an asynchronous label detection job.

        Access Level: Read

        https://docs.aws.amazon.com/rekognition/latest/APIReference/API_GetLabelDetection.html

        :stability: experimental
        '''
        return typing.cast("Rekognition", jsii.invoke(self, "toGetLabelDetection", []))

    @jsii.member(jsii_name="toGetPersonTracking")
    def to_get_person_tracking(self) -> "Rekognition":
        '''(experimental) Grants permission to read the list of persons detected in a stored video by an asynchronous person tracking job.

        Access Level: Read

        https://docs.aws.amazon.com/rekognition/latest/APIReference/API_GetPersonTracking.html

        :stability: experimental
        '''
        return typing.cast("Rekognition", jsii.invoke(self, "toGetPersonTracking", []))

    @jsii.member(jsii_name="toGetSegmentDetection")
    def to_get_segment_detection(self) -> "Rekognition":
        '''(experimental) Grants permission to get the vdeo segments found in a stored video by an asynchronous segment detection job.

        Access Level: Read

        https://docs.aws.amazon.com/rekognition/latest/APIReference/API_GetSegmentDetection.html

        :stability: experimental
        '''
        return typing.cast("Rekognition", jsii.invoke(self, "toGetSegmentDetection", []))

    @jsii.member(jsii_name="toGetTextDetection")
    def to_get_text_detection(self) -> "Rekognition":
        '''(experimental) Grants permission to get the text found in a stored video by an asynchronous text detection job.

        Access Level: Read

        https://docs.aws.amazon.com/rekognition/latest/APIReference/API_GetTextDetection.html

        :stability: experimental
        '''
        return typing.cast("Rekognition", jsii.invoke(self, "toGetTextDetection", []))

    @jsii.member(jsii_name="toIndexFaces")
    def to_index_faces(self) -> "Rekognition":
        '''(experimental) Grants permission to update an existing collection with faces detected in the input image.

        Access Level: Write

        https://docs.aws.amazon.com/rekognition/latest/APIReference/API_IndexFaces.html

        :stability: experimental
        '''
        return typing.cast("Rekognition", jsii.invoke(self, "toIndexFaces", []))

    @jsii.member(jsii_name="toListCollections")
    def to_list_collections(self) -> "Rekognition":
        '''(experimental) Grants permission to read the collection Id's in your account.

        Access Level: Read

        https://docs.aws.amazon.com/rekognition/latest/APIReference/API_ListCollections.html

        :stability: experimental
        '''
        return typing.cast("Rekognition", jsii.invoke(self, "toListCollections", []))

    @jsii.member(jsii_name="toListDatasetEntries")
    def to_list_dataset_entries(self) -> "Rekognition":
        '''(experimental) Grants permission to list the dataset entries in an existing Amazon Rekognition Custom Labels dataset.

        Access Level: Read

        https://docs.aws.amazon.com/rekognition/latest/APIReference/API_ListDatasetEntries.html

        :stability: experimental
        '''
        return typing.cast("Rekognition", jsii.invoke(self, "toListDatasetEntries", []))

    @jsii.member(jsii_name="toListDatasetLabels")
    def to_list_dataset_labels(self) -> "Rekognition":
        '''(experimental) Grants permission to list the labels in a dataset.

        Access Level: Read

        https://docs.aws.amazon.com/rekognition/latest/APIReference/API_ListDatasetLabels.html

        :stability: experimental
        '''
        return typing.cast("Rekognition", jsii.invoke(self, "toListDatasetLabels", []))

    @jsii.member(jsii_name="toListFaces")
    def to_list_faces(self) -> "Rekognition":
        '''(experimental) Grants permission to read metadata for faces in the specificed collection.

        Access Level: Read

        https://docs.aws.amazon.com/rekognition/latest/APIReference/API_ListFaces.html

        :stability: experimental
        '''
        return typing.cast("Rekognition", jsii.invoke(self, "toListFaces", []))

    @jsii.member(jsii_name="toListProjectPolicies")
    def to_list_project_policies(self) -> "Rekognition":
        '''(experimental) Grants permission to list the resource policies attached to a project.

        Access Level: Read

        https://docs.aws.amazon.com/rekognition/latest/APIReference/API_ListProjectPolicies.html

        :stability: experimental
        '''
        return typing.cast("Rekognition", jsii.invoke(self, "toListProjectPolicies", []))

    @jsii.member(jsii_name="toListStreamProcessors")
    def to_list_stream_processors(self) -> "Rekognition":
        '''(experimental) Grants permission to get a list of your stream processors.

        Access Level: List

        https://docs.aws.amazon.com/rekognition/latest/APIReference/API_ListStreamProcessors.html

        :stability: experimental
        '''
        return typing.cast("Rekognition", jsii.invoke(self, "toListStreamProcessors", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Rekognition":
        '''(experimental) Grants permission to return a list of tags associated with a resource.

        Access Level: Read

        https://docs.aws.amazon.com/rekognition/latest/APIReference/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("Rekognition", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toPutProjectPolicy")
    def to_put_project_policy(self) -> "Rekognition":
        '''(experimental) Grants permission to attach a resource policy to a project.

        Access Level: Write

        https://docs.aws.amazon.com/rekognition/latest/APIReference/API_PutProjectPolicy.html

        :stability: experimental
        '''
        return typing.cast("Rekognition", jsii.invoke(self, "toPutProjectPolicy", []))

    @jsii.member(jsii_name="toRecognizeCelebrities")
    def to_recognize_celebrities(self) -> "Rekognition":
        '''(experimental) Grants permission to detect celebrities in the input image.

        Access Level: Read

        https://docs.aws.amazon.com/rekognition/latest/APIReference/API_RecognizeCelebrities.html

        :stability: experimental
        '''
        return typing.cast("Rekognition", jsii.invoke(self, "toRecognizeCelebrities", []))

    @jsii.member(jsii_name="toSearchFaces")
    def to_search_faces(self) -> "Rekognition":
        '''(experimental) Grants permission to search the specificed collection for the supplied face ID.

        Access Level: Read

        https://docs.aws.amazon.com/rekognition/latest/APIReference/API_SearchFaces.html

        :stability: experimental
        '''
        return typing.cast("Rekognition", jsii.invoke(self, "toSearchFaces", []))

    @jsii.member(jsii_name="toSearchFacesByImage")
    def to_search_faces_by_image(self) -> "Rekognition":
        '''(experimental) Grants permission to search the specificed collection for the largest face in the input image.

        Access Level: Read

        https://docs.aws.amazon.com/rekognition/latest/APIReference/API_SearchFacesByImage.html

        :stability: experimental
        '''
        return typing.cast("Rekognition", jsii.invoke(self, "toSearchFacesByImage", []))

    @jsii.member(jsii_name="toStartCelebrityRecognition")
    def to_start_celebrity_recognition(self) -> "Rekognition":
        '''(experimental) Grants permission to start the asynchronous recognition of celebrities in a stored video.

        Access Level: Write

        https://docs.aws.amazon.com/rekognition/latest/APIReference/API_StartCelebrityRecognition.html

        :stability: experimental
        '''
        return typing.cast("Rekognition", jsii.invoke(self, "toStartCelebrityRecognition", []))

    @jsii.member(jsii_name="toStartContentModeration")
    def to_start_content_moderation(self) -> "Rekognition":
        '''(experimental) Grants permission to start asynchronous detection of explicit or suggestive adult content in a stored video.

        Access Level: Write

        https://docs.aws.amazon.com/rekognition/latest/APIReference/API_StartContentModeration.html

        :stability: experimental
        '''
        return typing.cast("Rekognition", jsii.invoke(self, "toStartContentModeration", []))

    @jsii.member(jsii_name="toStartFaceDetection")
    def to_start_face_detection(self) -> "Rekognition":
        '''(experimental) Grants permission to start asynchronous detection of faces in a stored video.

        Access Level: Write

        https://docs.aws.amazon.com/rekognition/latest/APIReference/API_StartFaceDetection.html

        :stability: experimental
        '''
        return typing.cast("Rekognition", jsii.invoke(self, "toStartFaceDetection", []))

    @jsii.member(jsii_name="toStartFaceSearch")
    def to_start_face_search(self) -> "Rekognition":
        '''(experimental) Grants permission to start an asynchronous search for faces in a collection that match the faces of persons detected in a stored video.

        Access Level: Write

        https://docs.aws.amazon.com/rekognition/latest/APIReference/API_StartFaceSearch.html

        :stability: experimental
        '''
        return typing.cast("Rekognition", jsii.invoke(self, "toStartFaceSearch", []))

    @jsii.member(jsii_name="toStartLabelDetection")
    def to_start_label_detection(self) -> "Rekognition":
        '''(experimental) Grants permission to start asynchronous detection of labels in a stored video.

        Access Level: Write

        https://docs.aws.amazon.com/rekognition/latest/APIReference/API_StartLabelDetection.html

        :stability: experimental
        '''
        return typing.cast("Rekognition", jsii.invoke(self, "toStartLabelDetection", []))

    @jsii.member(jsii_name="toStartPersonTracking")
    def to_start_person_tracking(self) -> "Rekognition":
        '''(experimental) Grants permission to start the asynchronous tracking of persons in a stored video.

        Access Level: Write

        https://docs.aws.amazon.com/rekognition/latest/APIReference/API_StartPersonTracking.html

        :stability: experimental
        '''
        return typing.cast("Rekognition", jsii.invoke(self, "toStartPersonTracking", []))

    @jsii.member(jsii_name="toStartProjectVersion")
    def to_start_project_version(self) -> "Rekognition":
        '''(experimental) Grants permission to start running a model version.

        Access Level: Write

        https://docs.aws.amazon.com/rekognition/latest/APIReference/API_StartProjectVersion.html

        :stability: experimental
        '''
        return typing.cast("Rekognition", jsii.invoke(self, "toStartProjectVersion", []))

    @jsii.member(jsii_name="toStartSegmentDetection")
    def to_start_segment_detection(self) -> "Rekognition":
        '''(experimental) Grants permission to start the asynchronous detection of segments in a stored video.

        Access Level: Write

        https://docs.aws.amazon.com/rekognition/latest/APIReference/API_StartSegmentDetection.html

        :stability: experimental
        '''
        return typing.cast("Rekognition", jsii.invoke(self, "toStartSegmentDetection", []))

    @jsii.member(jsii_name="toStartStreamProcessor")
    def to_start_stream_processor(self) -> "Rekognition":
        '''(experimental) Grants permission to start running a stream processor.

        Access Level: Write

        https://docs.aws.amazon.com/rekognition/latest/APIReference/API_StartStreamProcessor.html

        :stability: experimental
        '''
        return typing.cast("Rekognition", jsii.invoke(self, "toStartStreamProcessor", []))

    @jsii.member(jsii_name="toStartTextDetection")
    def to_start_text_detection(self) -> "Rekognition":
        '''(experimental) Grants permission to start the asynchronous detection of text in a stored video.

        Access Level: Write

        https://docs.aws.amazon.com/rekognition/latest/APIReference/API_StartTextDetection.html

        :stability: experimental
        '''
        return typing.cast("Rekognition", jsii.invoke(self, "toStartTextDetection", []))

    @jsii.member(jsii_name="toStopProjectVersion")
    def to_stop_project_version(self) -> "Rekognition":
        '''(experimental) Grants permission to stop a running model version.

        Access Level: Write

        https://docs.aws.amazon.com/rekognition/latest/APIReference/API_StopProjectVersion.html

        :stability: experimental
        '''
        return typing.cast("Rekognition", jsii.invoke(self, "toStopProjectVersion", []))

    @jsii.member(jsii_name="toStopStreamProcessor")
    def to_stop_stream_processor(self) -> "Rekognition":
        '''(experimental) Grants permission to stop a running stream processor.

        Access Level: Write

        https://docs.aws.amazon.com/rekognition/latest/APIReference/API_StopStreamProcessor.html

        :stability: experimental
        '''
        return typing.cast("Rekognition", jsii.invoke(self, "toStopStreamProcessor", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Rekognition":
        '''(experimental) Grants permission to add one or more tags to a resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/rekognition/latest/APIReference/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("Rekognition", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Rekognition":
        '''(experimental) Grants permission to remove one or more tags from a resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/rekognition/latest/APIReference/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("Rekognition", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateDatasetEntries")
    def to_update_dataset_entries(self) -> "Rekognition":
        '''(experimental) Grants permission to add or update one or more JSON Lines (entries) in a dataset.

        Access Level: Write

        https://docs.aws.amazon.com/rekognition/latest/APIReference/API_UpdateDatasetEntries.html

        :stability: experimental
        '''
        return typing.cast("Rekognition", jsii.invoke(self, "toUpdateDatasetEntries", []))

    @jsii.member(jsii_name="toUpdateStreamProcessor")
    def to_update_stream_processor(self) -> "Rekognition":
        '''(experimental) Grants permission to modify properties for a stream processor.

        Access Level: Write

        https://docs.aws.amazon.com/rekognition/latest/APIReference/API_UpdateStreamProcessor.html

        :stability: experimental
        '''
        return typing.cast("Rekognition", jsii.invoke(self, "toUpdateStreamProcessor", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5fc0f3ad25de8e78fc435d352366875c95e11b0197d96bb23f52d8deff98b95d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__24ed3ca8616ab85fa4c8076868b27211696f377cbce1c1154617789049c2ceb3)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Resiliencehub(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Resiliencehub",
):
    '''(experimental) Statement provider for service `resiliencehub <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsresiliencehubservice.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `resiliencehub <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsresiliencehubservice.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onAppAssessment")
    def on_app_assessment(
        self,
        app_assessment_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Resiliencehub":
        '''(experimental) Adds a resource of type app-assessment to the statement.

        https://docs.aws.amazon.com/resilience-hub/latest/APIReference/API_AppAssessment.html

        :param app_assessment_id: - Identifier for the appAssessmentId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4af5f1c4978d29fb42e30a628a42f96a3adf73e9d1a576cc3542e1ee43d26db1)
            check_type(argname="argument app_assessment_id", value=app_assessment_id, expected_type=type_hints["app_assessment_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Resiliencehub", jsii.invoke(self, "onAppAssessment", [app_assessment_id, account, region, partition]))

    @jsii.member(jsii_name="onApplication")
    def on_application(
        self,
        app_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Resiliencehub":
        '''(experimental) Adds a resource of type application to the statement.

        https://docs.aws.amazon.com/resilience-hub/latest/APIReference/API_App.html

        :param app_id: - Identifier for the appId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2507c0f8259f9e637ab7b91ddecba0dc270a7cc01ded05cac3749d0bc57ea98f)
            check_type(argname="argument app_id", value=app_id, expected_type=type_hints["app_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Resiliencehub", jsii.invoke(self, "onApplication", [app_id, account, region, partition]))

    @jsii.member(jsii_name="onRecommendationTemplate")
    def on_recommendation_template(
        self,
        recommendation_template_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Resiliencehub":
        '''(experimental) Adds a resource of type recommendation-template to the statement.

        https://docs.aws.amazon.com/resilience-hub/latest/APIReference/API_RecommendationTemplate.html

        :param recommendation_template_id: - Identifier for the recommendationTemplateId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ebed51e06a3f306609dea6ebc5b3b292eef87eecc1d78f8815b1da349ab0dbb0)
            check_type(argname="argument recommendation_template_id", value=recommendation_template_id, expected_type=type_hints["recommendation_template_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Resiliencehub", jsii.invoke(self, "onRecommendationTemplate", [recommendation_template_id, account, region, partition]))

    @jsii.member(jsii_name="onResiliencyPolicy")
    def on_resiliency_policy(
        self,
        resiliency_policy_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Resiliencehub":
        '''(experimental) Adds a resource of type resiliency-policy to the statement.

        https://docs.aws.amazon.com/resilience-hub/latest/APIReference/API_ResiliencyPolicy.html

        :param resiliency_policy_id: - Identifier for the resiliencyPolicyId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f3987905f09b92c5b8082a52e25d37871b18df9a6ef0042d5595c62166d2f0ec)
            check_type(argname="argument resiliency_policy_id", value=resiliency_policy_id, expected_type=type_hints["resiliency_policy_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Resiliencehub", jsii.invoke(self, "onResiliencyPolicy", [resiliency_policy_id, account, region, partition]))

    @jsii.member(jsii_name="toAddDraftAppVersionResourceMappings")
    def to_add_draft_app_version_resource_mappings(self) -> "Resiliencehub":
        '''(experimental) Grants permission to add draft application version resource mappings.

        Access Level: Write

        Dependent actions:

        - cloudformation:DescribeStacks
        - cloudformation:ListStackResources
        - resource-groups:GetGroup
        - resource-groups:ListGroupResources
        - servicecatalog:GetApplication
        - servicecatalog:ListAssociatedResources

        https://docs.aws.amazon.com/resilience-hub/latest/APIReference/API_AddDraftAppVersionResourceMappings.html

        :stability: experimental
        '''
        return typing.cast("Resiliencehub", jsii.invoke(self, "toAddDraftAppVersionResourceMappings", []))

    @jsii.member(jsii_name="toCreateApp")
    def to_create_app(self) -> "Resiliencehub":
        '''(experimental) Grants permission to create application.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/resilience-hub/latest/APIReference/API_CreateApp.html

        :stability: experimental
        '''
        return typing.cast("Resiliencehub", jsii.invoke(self, "toCreateApp", []))

    @jsii.member(jsii_name="toCreateRecommendationTemplate")
    def to_create_recommendation_template(self) -> "Resiliencehub":
        '''(experimental) Grants permission to create recommendation template.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - s3:CreateBucket
        - s3:ListBucket
        - s3:PutObject

        https://docs.aws.amazon.com/resilience-hub/latest/APIReference/API_CreateRecommendationTemplate.html

        :stability: experimental
        '''
        return typing.cast("Resiliencehub", jsii.invoke(self, "toCreateRecommendationTemplate", []))

    @jsii.member(jsii_name="toCreateResiliencyPolicy")
    def to_create_resiliency_policy(self) -> "Resiliencehub":
        '''(experimental) Grants permission to create resiliency policy.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/resilience-hub/latest/APIReference/API_CreateResiliencyPolicy.html

        :stability: experimental
        '''
        return typing.cast("Resiliencehub", jsii.invoke(self, "toCreateResiliencyPolicy", []))

    @jsii.member(jsii_name="toDeleteApp")
    def to_delete_app(self) -> "Resiliencehub":
        '''(experimental) Grants permission to batch delete application.

        Access Level: Write

        https://docs.aws.amazon.com/resilience-hub/latest/APIReference/API_DeleteApp.html

        :stability: experimental
        '''
        return typing.cast("Resiliencehub", jsii.invoke(self, "toDeleteApp", []))

    @jsii.member(jsii_name="toDeleteAppAssessment")
    def to_delete_app_assessment(self) -> "Resiliencehub":
        '''(experimental) Grants permission to batch delete application assessment.

        Access Level: Write

        https://docs.aws.amazon.com/resilience-hub/latest/APIReference/API_DeleteAppAssessment.html

        :stability: experimental
        '''
        return typing.cast("Resiliencehub", jsii.invoke(self, "toDeleteAppAssessment", []))

    @jsii.member(jsii_name="toDeleteRecommendationTemplate")
    def to_delete_recommendation_template(self) -> "Resiliencehub":
        '''(experimental) Grants permission to batch delete recommendation template.

        Access Level: Write

        https://docs.aws.amazon.com/resilience-hub/latest/APIReference/API_DeleteRecommendationTemplate.html

        :stability: experimental
        '''
        return typing.cast("Resiliencehub", jsii.invoke(self, "toDeleteRecommendationTemplate", []))

    @jsii.member(jsii_name="toDeleteResiliencyPolicy")
    def to_delete_resiliency_policy(self) -> "Resiliencehub":
        '''(experimental) Grants permission to batch delete resiliency policy.

        Access Level: Write

        https://docs.aws.amazon.com/resilience-hub/latest/APIReference/API_DeleteResiliencyPolicy.html

        :stability: experimental
        '''
        return typing.cast("Resiliencehub", jsii.invoke(self, "toDeleteResiliencyPolicy", []))

    @jsii.member(jsii_name="toDescribeApp")
    def to_describe_app(self) -> "Resiliencehub":
        '''(experimental) Grants permission to describe application.

        Access Level: Read

        https://docs.aws.amazon.com/resilience-hub/latest/APIReference/API_DescribeApp.html

        :stability: experimental
        '''
        return typing.cast("Resiliencehub", jsii.invoke(self, "toDescribeApp", []))

    @jsii.member(jsii_name="toDescribeAppAssessment")
    def to_describe_app_assessment(self) -> "Resiliencehub":
        '''(experimental) Grants permission to describe application assessment.

        Access Level: Read

        https://docs.aws.amazon.com/resilience-hub/latest/APIReference/API_DescribeAppAssessment.html

        :stability: experimental
        '''
        return typing.cast("Resiliencehub", jsii.invoke(self, "toDescribeAppAssessment", []))

    @jsii.member(jsii_name="toDescribeAppVersionResourcesResolutionStatus")
    def to_describe_app_version_resources_resolution_status(self) -> "Resiliencehub":
        '''(experimental) Grants permission to describe application resolution.

        Access Level: Read

        https://docs.aws.amazon.com/resilience-hub/latest/APIReference/API_DescribeAppVersionResourcesResolutionStatus.html

        :stability: experimental
        '''
        return typing.cast("Resiliencehub", jsii.invoke(self, "toDescribeAppVersionResourcesResolutionStatus", []))

    @jsii.member(jsii_name="toDescribeAppVersionTemplate")
    def to_describe_app_version_template(self) -> "Resiliencehub":
        '''(experimental) Grants permission to describe application version template.

        Access Level: Read

        https://docs.aws.amazon.com/resilience-hub/latest/APIReference/API_DescribeAppVersionTemplate.html

        :stability: experimental
        '''
        return typing.cast("Resiliencehub", jsii.invoke(self, "toDescribeAppVersionTemplate", []))

    @jsii.member(jsii_name="toDescribeDraftAppVersionResourcesImportStatus")
    def to_describe_draft_app_version_resources_import_status(self) -> "Resiliencehub":
        '''(experimental) Grants permission to describe draft application version resources import status.

        Access Level: Read

        https://docs.aws.amazon.com/resilience-hub/latest/APIReference/API_DescribeDraftAppVersionResourcesImportStatus.html

        :stability: experimental
        '''
        return typing.cast("Resiliencehub", jsii.invoke(self, "toDescribeDraftAppVersionResourcesImportStatus", []))

    @jsii.member(jsii_name="toDescribeResiliencyPolicy")
    def to_describe_resiliency_policy(self) -> "Resiliencehub":
        '''(experimental) Grants permission to describe resiliency policy.

        Access Level: Read

        https://docs.aws.amazon.com/resilience-hub/latest/APIReference/API_DescribeResiliencyPolicy.html

        :stability: experimental
        '''
        return typing.cast("Resiliencehub", jsii.invoke(self, "toDescribeResiliencyPolicy", []))

    @jsii.member(jsii_name="toImportResourcesToDraftAppVersion")
    def to_import_resources_to_draft_app_version(self) -> "Resiliencehub":
        '''(experimental) Grants permission to import resources to draft application version.

        Access Level: Write

        Dependent actions:

        - cloudformation:DescribeStacks
        - cloudformation:ListStackResources
        - resource-groups:GetGroup
        - resource-groups:ListGroupResources
        - servicecatalog:GetApplication
        - servicecatalog:ListAssociatedResources

        https://docs.aws.amazon.com/resilience-hub/latest/APIReference/API_ImportResourcesToDraftAppVersion.html

        :stability: experimental
        '''
        return typing.cast("Resiliencehub", jsii.invoke(self, "toImportResourcesToDraftAppVersion", []))

    @jsii.member(jsii_name="toListAlarmRecommendations")
    def to_list_alarm_recommendations(self) -> "Resiliencehub":
        '''(experimental) Grants permission to list alarm recommendation.

        Access Level: List

        https://docs.aws.amazon.com/resilience-hub/latest/APIReference/API_ListAlarmRecommendations.html

        :stability: experimental
        '''
        return typing.cast("Resiliencehub", jsii.invoke(self, "toListAlarmRecommendations", []))

    @jsii.member(jsii_name="toListAppAssessments")
    def to_list_app_assessments(self) -> "Resiliencehub":
        '''(experimental) Grants permission to list application assessment.

        Access Level: List

        https://docs.aws.amazon.com/resilience-hub/latest/APIReference/API_ListAppAssessments.html

        :stability: experimental
        '''
        return typing.cast("Resiliencehub", jsii.invoke(self, "toListAppAssessments", []))

    @jsii.member(jsii_name="toListAppComponentCompliances")
    def to_list_app_component_compliances(self) -> "Resiliencehub":
        '''(experimental) Grants permission to list app component compliances.

        Access Level: List

        https://docs.aws.amazon.com/resilience-hub/latest/APIReference/API_ListAppComponentCompliances.html

        :stability: experimental
        '''
        return typing.cast("Resiliencehub", jsii.invoke(self, "toListAppComponentCompliances", []))

    @jsii.member(jsii_name="toListAppComponentRecommendations")
    def to_list_app_component_recommendations(self) -> "Resiliencehub":
        '''(experimental) Grants permission to list app component recommendations.

        Access Level: List

        https://docs.aws.amazon.com/resilience-hub/latest/APIReference/API_ListAppComponentRecommendations.html

        :stability: experimental
        '''
        return typing.cast("Resiliencehub", jsii.invoke(self, "toListAppComponentRecommendations", []))

    @jsii.member(jsii_name="toListApps")
    def to_list_apps(self) -> "Resiliencehub":
        '''(experimental) Grants permission to list applications.

        Access Level: List

        https://docs.aws.amazon.com/resilience-hub/latest/APIReference/API_ListApps.html

        :stability: experimental
        '''
        return typing.cast("Resiliencehub", jsii.invoke(self, "toListApps", []))

    @jsii.member(jsii_name="toListAppVersionResourceMappings")
    def to_list_app_version_resource_mappings(self) -> "Resiliencehub":
        '''(experimental) Grants permission to application version resource mappings.

        Access Level: List

        https://docs.aws.amazon.com/resilience-hub/latest/APIReference/API_ListAppVersionResourceMappings.html

        :stability: experimental
        '''
        return typing.cast("Resiliencehub", jsii.invoke(self, "toListAppVersionResourceMappings", []))

    @jsii.member(jsii_name="toListAppVersionResources")
    def to_list_app_version_resources(self) -> "Resiliencehub":
        '''(experimental) Grants permission to list application resources.

        Access Level: List

        https://docs.aws.amazon.com/resilience-hub/latest/APIReference/API_ListAppVersionResources.html

        :stability: experimental
        '''
        return typing.cast("Resiliencehub", jsii.invoke(self, "toListAppVersionResources", []))

    @jsii.member(jsii_name="toListAppVersions")
    def to_list_app_versions(self) -> "Resiliencehub":
        '''(experimental) Grants permission to list application version.

        Access Level: List

        https://docs.aws.amazon.com/resilience-hub/latest/APIReference/API_ListAppVersions.html

        :stability: experimental
        '''
        return typing.cast("Resiliencehub", jsii.invoke(self, "toListAppVersions", []))

    @jsii.member(jsii_name="toListRecommendationTemplates")
    def to_list_recommendation_templates(self) -> "Resiliencehub":
        '''(experimental) Grants permission to list recommendation templates.

        Access Level: List

        https://docs.aws.amazon.com/resilience-hub/latest/APIReference/API_ListRecommendationTemplates.html

        :stability: experimental
        '''
        return typing.cast("Resiliencehub", jsii.invoke(self, "toListRecommendationTemplates", []))

    @jsii.member(jsii_name="toListResiliencyPolicies")
    def to_list_resiliency_policies(self) -> "Resiliencehub":
        '''(experimental) Grants permission to list resiliency policies.

        Access Level: List

        https://docs.aws.amazon.com/resilience-hub/latest/APIReference/API_ListResiliencyPolicies.html

        :stability: experimental
        '''
        return typing.cast("Resiliencehub", jsii.invoke(self, "toListResiliencyPolicies", []))

    @jsii.member(jsii_name="toListSopRecommendations")
    def to_list_sop_recommendations(self) -> "Resiliencehub":
        '''(experimental) Grants permission to list SOP recommendations.

        Access Level: List

        https://docs.aws.amazon.com/resilience-hub/latest/APIReference/API_ListSopRecommendations.html

        :stability: experimental
        '''
        return typing.cast("Resiliencehub", jsii.invoke(self, "toListSopRecommendations", []))

    @jsii.member(jsii_name="toListSuggestedResiliencyPolicies")
    def to_list_suggested_resiliency_policies(self) -> "Resiliencehub":
        '''(experimental) Grants permission to list suggested resiliency policies.

        Access Level: List

        https://docs.aws.amazon.com/resilience-hub/latest/APIReference/API_ListSuggestedResiliencyPolicies.html

        :stability: experimental
        '''
        return typing.cast("Resiliencehub", jsii.invoke(self, "toListSuggestedResiliencyPolicies", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Resiliencehub":
        '''(experimental) Grants permission to list tags for a resource.

        Access Level: Read

        https://docs.aws.amazon.com/resilience-hub/latest/APIReference/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("Resiliencehub", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toListTestRecommendations")
    def to_list_test_recommendations(self) -> "Resiliencehub":
        '''(experimental) Grants permission to list test recommendations.

        Access Level: List

        https://docs.aws.amazon.com/resilience-hub/latest/APIReference/API_ListTestRecommendations.html

        :stability: experimental
        '''
        return typing.cast("Resiliencehub", jsii.invoke(self, "toListTestRecommendations", []))

    @jsii.member(jsii_name="toListUnsupportedAppVersionResources")
    def to_list_unsupported_app_version_resources(self) -> "Resiliencehub":
        '''(experimental) Grants permission to list unsupported application version resources.

        Access Level: List

        https://docs.aws.amazon.com/resilience-hub/latest/APIReference/API_ListUnsupportedAppVersionResources.html

        :stability: experimental
        '''
        return typing.cast("Resiliencehub", jsii.invoke(self, "toListUnsupportedAppVersionResources", []))

    @jsii.member(jsii_name="toPublishAppVersion")
    def to_publish_app_version(self) -> "Resiliencehub":
        '''(experimental) Grants permission to publish application version.

        Access Level: Write

        https://docs.aws.amazon.com/resilience-hub/latest/APIReference/API_PublishAppVersion.html

        :stability: experimental
        '''
        return typing.cast("Resiliencehub", jsii.invoke(self, "toPublishAppVersion", []))

    @jsii.member(jsii_name="toPutDraftAppVersionTemplate")
    def to_put_draft_app_version_template(self) -> "Resiliencehub":
        '''(experimental) Grants permission to put draft application version template.

        Access Level: Write

        https://docs.aws.amazon.com/resilience-hub/latest/APIReference/API_PutDraftAppVersionTemplate.html

        :stability: experimental
        '''
        return typing.cast("Resiliencehub", jsii.invoke(self, "toPutDraftAppVersionTemplate", []))

    @jsii.member(jsii_name="toRemoveDraftAppVersionResourceMappings")
    def to_remove_draft_app_version_resource_mappings(self) -> "Resiliencehub":
        '''(experimental) Grants permission to remove draft application version mappings.

        Access Level: Write

        https://docs.aws.amazon.com/resilience-hub/latest/APIReference/API_RemoveDraftAppVersionResourceMappings.html

        :stability: experimental
        '''
        return typing.cast("Resiliencehub", jsii.invoke(self, "toRemoveDraftAppVersionResourceMappings", []))

    @jsii.member(jsii_name="toResolveAppVersionResources")
    def to_resolve_app_version_resources(self) -> "Resiliencehub":
        '''(experimental) Grants permission to resolve application version resources.

        Access Level: Write

        Dependent actions:

        - cloudformation:DescribeStacks
        - cloudformation:ListStackResources
        - resource-groups:GetGroup
        - resource-groups:ListGroupResources
        - servicecatalog:GetApplication
        - servicecatalog:ListAssociatedResources

        https://docs.aws.amazon.com/resilience-hub/latest/APIReference/API_ResolveAppVersionResources.html

        :stability: experimental
        '''
        return typing.cast("Resiliencehub", jsii.invoke(self, "toResolveAppVersionResources", []))

    @jsii.member(jsii_name="toStartAppAssessment")
    def to_start_app_assessment(self) -> "Resiliencehub":
        '''(experimental) Grants permission to create application assessment.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - cloudformation:DescribeStacks
        - cloudformation:ListStackResources
        - cloudwatch:DescribeAlarms
        - cloudwatch:GetMetricData
        - cloudwatch:GetMetricStatistics
        - cloudwatch:PutMetricData
        - ec2:DescribeRegions
        - fis:GetExperimentTemplate
        - fis:ListExperimentTemplates
        - fis:ListExperiments
        - resource-groups:GetGroup
        - resource-groups:ListGroupResources
        - servicecatalog:GetApplication
        - servicecatalog:ListAssociatedResources
        - ssm:GetParametersByPath

        https://docs.aws.amazon.com/resilience-hub/latest/APIReference/API_StartAppAssessment.html

        :stability: experimental
        '''
        return typing.cast("Resiliencehub", jsii.invoke(self, "toStartAppAssessment", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Resiliencehub":
        '''(experimental) Grants permission to assign a resource tag.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/resilience-hub/latest/APIReference/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("Resiliencehub", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Resiliencehub":
        '''(experimental) Grants permission to untag a resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/resilience-hub/latest/APIReference/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("Resiliencehub", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateApp")
    def to_update_app(self) -> "Resiliencehub":
        '''(experimental) Grants permission to update application.

        Access Level: Write

        https://docs.aws.amazon.com/resilience-hub/latest/APIReference/API_UpdateApp.html

        :stability: experimental
        '''
        return typing.cast("Resiliencehub", jsii.invoke(self, "toUpdateApp", []))

    @jsii.member(jsii_name="toUpdateResiliencyPolicy")
    def to_update_resiliency_policy(self) -> "Resiliencehub":
        '''(experimental) Grants permission to update resiliency policy.

        Access Level: Write

        https://docs.aws.amazon.com/resilience-hub/latest/APIReference/API_UpdateResiliencyPolicy.html

        :stability: experimental
        '''
        return typing.cast("Resiliencehub", jsii.invoke(self, "toUpdateResiliencyPolicy", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c8e2d530e9fa96ac267eed4008de04d0fca70b0975dccf545d23b65ea21561b5)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5c3b282518a68378d69fdec19657225216cecfd9628d8fa926bddc00c216af58)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class ResourceExplorer(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.ResourceExplorer",
):
    '''(experimental) Statement provider for service `resource-explorer <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awstageditor.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `resource-explorer <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awstageditor.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="toListResources")
    def to_list_resources(self) -> "ResourceExplorer":
        '''(experimental) Grants permission to retrieve the identifiers of the resources in the AWS account.

        Access Level: List

        https://docs.aws.amazon.com/ARG/latest/userguide/gettingstarted-prereqs.html#rg-permissions-te

        :stability: experimental
        '''
        return typing.cast("ResourceExplorer", jsii.invoke(self, "toListResources", []))

    @jsii.member(jsii_name="toListResourceTypes")
    def to_list_resource_types(self) -> "ResourceExplorer":
        '''(experimental) Grants permission to retrieve the resource types currently supported by Tag Editor.

        Access Level: List

        https://docs.aws.amazon.com/ARG/latest/userguide/gettingstarted-prereqs.html#rg-permissions-te

        :stability: experimental
        '''
        return typing.cast("ResourceExplorer", jsii.invoke(self, "toListResourceTypes", []))

    @jsii.member(jsii_name="toListTags")
    def to_list_tags(self) -> "ResourceExplorer":
        '''(experimental) Grants permission to retrieve the tags attached to the specified resource identifiers.

        Access Level: Read

        Dependent actions:

        - tag:GetResources

        https://docs.aws.amazon.com/ARG/latest/userguide/gettingstarted-prereqs.html#rg-permissions-te

        :stability: experimental
        '''
        return typing.cast("ResourceExplorer", jsii.invoke(self, "toListTags", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e47fbb229c299184c96be535f84b79afcf2f5ad9ba1dedfbb506113b40f5180a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__10bb712cca8229fd5858e076dd5e65285772ce589ac25cc5b9a3188ddcd28925)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class ResourceExplorer2(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.ResourceExplorer2",
):
    '''(experimental) Statement provider for service `resource-explorer-2 <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsresourceexplorer.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `resource-explorer-2 <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsresourceexplorer.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onIndex")
    def on_index(
        self,
        index_uuid: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "ResourceExplorer2":
        '''(experimental) Adds a resource of type index to the statement.

        https://docs.aws.amazon.com/resource-explorer/latest/apireference/API_Index.html

        :param index_uuid: - Identifier for the indexUuid.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4213a8426de1b41302bd960b8da70f1e740119e5faf2252fa5094b735c56c976)
            check_type(argname="argument index_uuid", value=index_uuid, expected_type=type_hints["index_uuid"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("ResourceExplorer2", jsii.invoke(self, "onIndex", [index_uuid, account, region, partition]))

    @jsii.member(jsii_name="onView")
    def on_view(
        self,
        view_name: builtins.str,
        view_uuid: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "ResourceExplorer2":
        '''(experimental) Adds a resource of type view to the statement.

        https://docs.aws.amazon.com/resource-explorer/latest/apireference/API_View.html

        :param view_name: - Identifier for the viewName.
        :param view_uuid: - Identifier for the viewUuid.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__879db4830398e7a5514de0651c1549ff470f7039b978624bcbf8eba1818648ba)
            check_type(argname="argument view_name", value=view_name, expected_type=type_hints["view_name"])
            check_type(argname="argument view_uuid", value=view_uuid, expected_type=type_hints["view_uuid"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("ResourceExplorer2", jsii.invoke(self, "onView", [view_name, view_uuid, account, region, partition]))

    @jsii.member(jsii_name="toAssociateDefaultView")
    def to_associate_default_view(self) -> "ResourceExplorer2":
        '''(experimental) Grants permission to set the specified view as the default for this AWS Region in this AWS account.

        Access Level: Write

        https://docs.aws.amazon.com/resource-explorer/latest/apireference/API_AssociateDefaultView.html

        :stability: experimental
        '''
        return typing.cast("ResourceExplorer2", jsii.invoke(self, "toAssociateDefaultView", []))

    @jsii.member(jsii_name="toBatchGetView")
    def to_batch_get_view(self) -> "ResourceExplorer2":
        '''(experimental) Grants permission to retrieve details about views that you specify by a list of ARNs.

        Access Level: Read

        Dependent actions:

        - resource-explorer-2:GetView

        https://docs.aws.amazon.com/resource-explorer/latest/apireference/API_BatchGetView.html

        :stability: experimental
        '''
        return typing.cast("ResourceExplorer2", jsii.invoke(self, "toBatchGetView", []))

    @jsii.member(jsii_name="toCreateIndex")
    def to_create_index(self) -> "ResourceExplorer2":
        '''(experimental) Grants permission to turn on Resource Explorer in the AWS Region in which you called this operation by creating an index.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/resource-explorer/latest/apireference/API_CreateIndex.html

        :stability: experimental
        '''
        return typing.cast("ResourceExplorer2", jsii.invoke(self, "toCreateIndex", []))

    @jsii.member(jsii_name="toCreateView")
    def to_create_view(self) -> "ResourceExplorer2":
        '''(experimental) Grants permission to create a view that users can query.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/resource-explorer/latest/apireference/API_CreateView.html

        :stability: experimental
        '''
        return typing.cast("ResourceExplorer2", jsii.invoke(self, "toCreateView", []))

    @jsii.member(jsii_name="toDeleteIndex")
    def to_delete_index(self) -> "ResourceExplorer2":
        '''(experimental) Grants permission to turn off Resource Explorer in the specified AWS Region by deleting the index.

        Access Level: Write

        https://docs.aws.amazon.com/resource-explorer/latest/apireference/API_DeleteIndex.html

        :stability: experimental
        '''
        return typing.cast("ResourceExplorer2", jsii.invoke(self, "toDeleteIndex", []))

    @jsii.member(jsii_name="toDeleteView")
    def to_delete_view(self) -> "ResourceExplorer2":
        '''(experimental) Grants permission to delete a view.

        Access Level: Write

        https://docs.aws.amazon.com/resource-explorer/latest/apireference/API_DeleteView.html

        :stability: experimental
        '''
        return typing.cast("ResourceExplorer2", jsii.invoke(self, "toDeleteView", []))

    @jsii.member(jsii_name="toDisassociateDefaultView")
    def to_disassociate_default_view(self) -> "ResourceExplorer2":
        '''(experimental) Grants permission to remove the default view for the AWS Region in which you call this operation.

        Access Level: Write

        https://docs.aws.amazon.com/resource-explorer/latest/apireference/API_DisassociateDefaultView.html

        :stability: experimental
        '''
        return typing.cast("ResourceExplorer2", jsii.invoke(self, "toDisassociateDefaultView", []))

    @jsii.member(jsii_name="toGetDefaultView")
    def to_get_default_view(self) -> "ResourceExplorer2":
        '''(experimental) Grants permission to retrieve the Amazon resource name (ARN) of the view that is the default for the AWS Region in which you call this operation.

        Access Level: Read

        https://docs.aws.amazon.com/resource-explorer/latest/apireference/API_GetDefaultView.html

        :stability: experimental
        '''
        return typing.cast("ResourceExplorer2", jsii.invoke(self, "toGetDefaultView", []))

    @jsii.member(jsii_name="toGetIndex")
    def to_get_index(self) -> "ResourceExplorer2":
        '''(experimental) Grants permission to retrieve information about the index in the AWS Region in which you call this operation.

        Access Level: Read

        https://docs.aws.amazon.com/resource-explorer/latest/apireference/API_GetIndex.html

        :stability: experimental
        '''
        return typing.cast("ResourceExplorer2", jsii.invoke(self, "toGetIndex", []))

    @jsii.member(jsii_name="toGetView")
    def to_get_view(self) -> "ResourceExplorer2":
        '''(experimental) Grants permission to retrieve information about the specified view.

        Access Level: Read

        https://docs.aws.amazon.com/resource-explorer/latest/apireference/API_GetView.html

        :stability: experimental
        '''
        return typing.cast("ResourceExplorer2", jsii.invoke(self, "toGetView", []))

    @jsii.member(jsii_name="toListIndexes")
    def to_list_indexes(self) -> "ResourceExplorer2":
        '''(experimental) Grants permission to list the indexes in all AWS Regions.

        Access Level: List

        https://docs.aws.amazon.com/resource-explorer/latest/apireference/API_ListIndexes.html

        :stability: experimental
        '''
        return typing.cast("ResourceExplorer2", jsii.invoke(self, "toListIndexes", []))

    @jsii.member(jsii_name="toListSupportedResourceTypes")
    def to_list_supported_resource_types(self) -> "ResourceExplorer2":
        '''(experimental) Grants permission to retrieve a list of all resource types currently supported by Resource Explorer.

        Access Level: List

        https://docs.aws.amazon.com/resource-explorer/latest/apireference/API_ListSupportedResourceTypes.html

        :stability: experimental
        '''
        return typing.cast("ResourceExplorer2", jsii.invoke(self, "toListSupportedResourceTypes", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "ResourceExplorer2":
        '''(experimental) Grants permission to list the tags that are attached to the specified resource.

        Access Level: Read

        https://docs.aws.amazon.com/resource-explorer/latest/apireference/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("ResourceExplorer2", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toListViews")
    def to_list_views(self) -> "ResourceExplorer2":
        '''(experimental) Grants permission to list the Amazon resource names (ARNs) of all of the views available in the AWS Region in which you call this operation.

        Access Level: List

        https://docs.aws.amazon.com/resource-explorer/latest/apireference/API_ListViews.html

        :stability: experimental
        '''
        return typing.cast("ResourceExplorer2", jsii.invoke(self, "toListViews", []))

    @jsii.member(jsii_name="toSearch")
    def to_search(self) -> "ResourceExplorer2":
        '''(experimental) Grants permission to search for resources and display details about all resources that match the specified criteria.

        Access Level: Read

        https://docs.aws.amazon.com/resource-explorer/latest/apireference/API_Search.html

        :stability: experimental
        '''
        return typing.cast("ResourceExplorer2", jsii.invoke(self, "toSearch", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "ResourceExplorer2":
        '''(experimental) Grants permission to add one or more tag key and value pairs to the specified resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/resource-explorer/latest/apireference/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("ResourceExplorer2", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "ResourceExplorer2":
        '''(experimental) Grants permission to remove one or more tag key and value pairs from the specified resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/resource-explorer/latest/apireference/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("ResourceExplorer2", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateIndexType")
    def to_update_index_type(self) -> "ResourceExplorer2":
        '''(experimental) Grants permission to change the type of the index from LOCAL to AGGREGATOR or back.

        Access Level: Write

        https://docs.aws.amazon.com/resource-explorer/latest/apireference/API_UpdateIndexType.html

        :stability: experimental
        '''
        return typing.cast("ResourceExplorer2", jsii.invoke(self, "toUpdateIndexType", []))

    @jsii.member(jsii_name="toUpdateView")
    def to_update_view(self) -> "ResourceExplorer2":
        '''(experimental) Grants permission to modify some of the details of a view.

        Access Level: Write

        https://docs.aws.amazon.com/resource-explorer/latest/apireference/API_UpdateView.html

        :stability: experimental
        '''
        return typing.cast("ResourceExplorer2", jsii.invoke(self, "toUpdateView", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ade4f809cb3eef1bcda39b45592cb78eaf43276b78a7b3f709437544198d8b41)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a1232ea42aa80ef5501688834b78f4b09688d2e822ba45d5f96336804bae3937)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class ResourceGroups(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.ResourceGroups",
):
    '''(experimental) Statement provider for service `resource-groups <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsresourcegroups.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `resource-groups <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsresourcegroups.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onGroup")
    def on_group(
        self,
        group_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "ResourceGroups":
        '''(experimental) Adds a resource of type group to the statement.

        https://docs.aws.amazon.com/ARG/latest/userguide/resource-groups.html

        :param group_name: - Identifier for the groupName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__aa59430d7bb61b88283331af3708fdbe9ac5e71e93c94114b5ad34370d643a77)
            check_type(argname="argument group_name", value=group_name, expected_type=type_hints["group_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("ResourceGroups", jsii.invoke(self, "onGroup", [group_name, account, region, partition]))

    @jsii.member(jsii_name="toCreateGroup")
    def to_create_group(self) -> "ResourceGroups":
        '''(experimental) Grants permission to create a resource group with a specified name, description, and resource query.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/ARG/latest/APIReference/API_CreateGroup.html

        :stability: experimental
        '''
        return typing.cast("ResourceGroups", jsii.invoke(self, "toCreateGroup", []))

    @jsii.member(jsii_name="toDeleteGroup")
    def to_delete_group(self) -> "ResourceGroups":
        '''(experimental) Grants permission to delete a specified resource group.

        Access Level: Write

        https://docs.aws.amazon.com/ARG/latest/APIReference/API_DeleteGroup.html

        :stability: experimental
        '''
        return typing.cast("ResourceGroups", jsii.invoke(self, "toDeleteGroup", []))

    @jsii.member(jsii_name="toGetGroup")
    def to_get_group(self) -> "ResourceGroups":
        '''(experimental) Grants permission to get information of a specified resource group.

        Access Level: Read

        https://docs.aws.amazon.com/ARG/latest/APIReference/API_GetGroup.html

        :stability: experimental
        '''
        return typing.cast("ResourceGroups", jsii.invoke(self, "toGetGroup", []))

    @jsii.member(jsii_name="toGetGroupConfiguration")
    def to_get_group_configuration(self) -> "ResourceGroups":
        '''(experimental) Grants permission to get the service configuration associated with the specified resource group.

        Access Level: Read

        https://docs.aws.amazon.com/ARG/latest/APIReference/API_GetGroupConfiguration.html

        :stability: experimental
        '''
        return typing.cast("ResourceGroups", jsii.invoke(self, "toGetGroupConfiguration", []))

    @jsii.member(jsii_name="toGetGroupQuery")
    def to_get_group_query(self) -> "ResourceGroups":
        '''(experimental) Grants permission to get the query associated with a specified resource group.

        Access Level: Read

        https://docs.aws.amazon.com/ARG/latest/APIReference/API_GetGroupQuery.html

        :stability: experimental
        '''
        return typing.cast("ResourceGroups", jsii.invoke(self, "toGetGroupQuery", []))

    @jsii.member(jsii_name="toGetTags")
    def to_get_tags(self) -> "ResourceGroups":
        '''(experimental) Grants permission to get the tags associated with a specified resource group.

        Access Level: Read

        https://docs.aws.amazon.com/ARG/latest/APIReference/API_GetTags.html

        :stability: experimental
        '''
        return typing.cast("ResourceGroups", jsii.invoke(self, "toGetTags", []))

    @jsii.member(jsii_name="toGroupResources")
    def to_group_resources(self) -> "ResourceGroups":
        '''(experimental) Grants permission to add the specified resources to the specified group.

        Access Level: Write

        https://docs.aws.amazon.com/ARG/latest/APIReference/API_GroupResources.html

        :stability: experimental
        '''
        return typing.cast("ResourceGroups", jsii.invoke(self, "toGroupResources", []))

    @jsii.member(jsii_name="toListGroupResources")
    def to_list_group_resources(self) -> "ResourceGroups":
        '''(experimental) Grants permission to list the resources that are members of a specified resource group.

        Access Level: List

        Dependent actions:

        - cloudformation:DescribeStacks
        - cloudformation:ListStackResources
        - tag:GetResources

        https://docs.aws.amazon.com/ARG/latest/APIReference/API_ListGroupResources.html

        :stability: experimental
        '''
        return typing.cast("ResourceGroups", jsii.invoke(self, "toListGroupResources", []))

    @jsii.member(jsii_name="toListGroups")
    def to_list_groups(self) -> "ResourceGroups":
        '''(experimental) Grants permission to list all resource groups in your account.

        Access Level: List

        https://docs.aws.amazon.com/ARG/latest/APIReference/API_ListGroups.html

        :stability: experimental
        '''
        return typing.cast("ResourceGroups", jsii.invoke(self, "toListGroups", []))

    @jsii.member(jsii_name="toPutGroupConfiguration")
    def to_put_group_configuration(self) -> "ResourceGroups":
        '''(experimental) Grants permission to put the service configuration associated with the specified resource group.

        Access Level: Write

        https://docs.aws.amazon.com/ARG/latest/APIReference/API_PutGroupConfiguration.html

        :stability: experimental
        '''
        return typing.cast("ResourceGroups", jsii.invoke(self, "toPutGroupConfiguration", []))

    @jsii.member(jsii_name="toPutGroupPolicy")
    def to_put_group_policy(self) -> "ResourceGroups":
        '''(experimental) Grants permission to add a resource-based policy for the specified group.

        Access Level: Write

        https://docs.aws.amazon.com/license-manager/latest/userguide/management-role.html#service-linked-role-permissions-management-role

        :stability: experimental
        '''
        return typing.cast("ResourceGroups", jsii.invoke(self, "toPutGroupPolicy", []))

    @jsii.member(jsii_name="toSearchResources")
    def to_search_resources(self) -> "ResourceGroups":
        '''(experimental) Grants permission to search for AWS resources matching the given query.

        Access Level: List

        Dependent actions:

        - cloudformation:DescribeStacks
        - cloudformation:ListStackResources
        - tag:GetResources

        https://docs.aws.amazon.com/ARG/latest/APIReference/API_SearchResources.html

        :stability: experimental
        '''
        return typing.cast("ResourceGroups", jsii.invoke(self, "toSearchResources", []))

    @jsii.member(jsii_name="toTag")
    def to_tag(self) -> "ResourceGroups":
        '''(experimental) Grants permission to tag a specified resource group.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/ARG/latest/APIReference/API_Tag.html

        :stability: experimental
        '''
        return typing.cast("ResourceGroups", jsii.invoke(self, "toTag", []))

    @jsii.member(jsii_name="toUngroupResources")
    def to_ungroup_resources(self) -> "ResourceGroups":
        '''(experimental) Grants permission to remove the specified resources from the specified group.

        Access Level: Write

        https://docs.aws.amazon.com/ARG/latest/APIReference/API_UngroupResources.html

        :stability: experimental
        '''
        return typing.cast("ResourceGroups", jsii.invoke(self, "toUngroupResources", []))

    @jsii.member(jsii_name="toUntag")
    def to_untag(self) -> "ResourceGroups":
        '''(experimental) Grants permission to remove tags associated with a specified resource group.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/ARG/latest/APIReference/API_Untag.html

        :stability: experimental
        '''
        return typing.cast("ResourceGroups", jsii.invoke(self, "toUntag", []))

    @jsii.member(jsii_name="toUpdateGroup")
    def to_update_group(self) -> "ResourceGroups":
        '''(experimental) Grants permission to update a specified resource group.

        Access Level: Write

        https://docs.aws.amazon.com/ARG/latest/APIReference/API_UpdateGroup.html

        :stability: experimental
        '''
        return typing.cast("ResourceGroups", jsii.invoke(self, "toUpdateGroup", []))

    @jsii.member(jsii_name="toUpdateGroupQuery")
    def to_update_group_query(self) -> "ResourceGroups":
        '''(experimental) Grants permission to update the query associated with a specified resource group.

        Access Level: Write

        https://docs.aws.amazon.com/ARG/latest/APIReference/API_UpdateGroupQuery.html

        :stability: experimental
        '''
        return typing.cast("ResourceGroups", jsii.invoke(self, "toUpdateGroupQuery", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__425eba4a1ab5a25c7dad6a1878fc9f9b797fd9999fb4d3e10251effdfcebd9e1)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ef7e1077c7c84ea8572ff88cc97e49b4fb0e4d2c91b7a33c9a6e7a7e0c559642)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Rhelkb(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Rhelkb",
):
    '''(experimental) Statement provider for service `rhelkb <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonrhelknowledgebaseportal.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `rhelkb <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonrhelknowledgebaseportal.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="toGetRhelURL")
    def to_get_rhel_url(self) -> "Rhelkb":
        '''(experimental) Grants permission to access the Red Hat Knowledgebase portal.

        Access Level: Read

        https://docs.aws.amazon.com/systems-manager/latest/userguide/fleet-rhel.html

        :stability: experimental
        '''
        return typing.cast("Rhelkb", jsii.invoke(self, "toGetRhelURL", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9fc4e1b052c082e221a8d5c6cdfe1d69c2990973fb295487a2b60a5b81b31dd2)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__270790c46f352b784864b35ba6a10fe9a1b4a4a360ec66b949814d4ae3dd1546)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Robomaker(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Robomaker",
):
    '''(experimental) Statement provider for service `robomaker <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsrobomaker.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `robomaker <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsrobomaker.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onDeploymentFleet")
    def on_deployment_fleet(
        self,
        fleet_name: builtins.str,
        created_on_epoch: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Robomaker":
        '''(experimental) Adds a resource of type deploymentFleet to the statement.

        https://docs.aws.amazon.com/robomaker/latest/dg/managing-simulation-applications.html

        :param fleet_name: - Identifier for the fleetName.
        :param created_on_epoch: - Identifier for the createdOnEpoch.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__78abb5eb41a1a0b8de716c4b734e256ddf7d1dd1a7f14a7be95b7b6d4a5ed1eb)
            check_type(argname="argument fleet_name", value=fleet_name, expected_type=type_hints["fleet_name"])
            check_type(argname="argument created_on_epoch", value=created_on_epoch, expected_type=type_hints["created_on_epoch"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Robomaker", jsii.invoke(self, "onDeploymentFleet", [fleet_name, created_on_epoch, account, region, partition]))

    @jsii.member(jsii_name="onDeploymentJob")
    def on_deployment_job(
        self,
        deployment_job_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Robomaker":
        '''(experimental) Adds a resource of type deploymentJob to the statement.

        https://docs.aws.amazon.com/robomaker/latest/dg/deployment.html

        :param deployment_job_id: - Identifier for the deploymentJobId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1d3bb75e851d6ddae89ebfdede638d91514e374303a02041c95bcd87e5d61358)
            check_type(argname="argument deployment_job_id", value=deployment_job_id, expected_type=type_hints["deployment_job_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Robomaker", jsii.invoke(self, "onDeploymentJob", [deployment_job_id, account, region, partition]))

    @jsii.member(jsii_name="onRobot")
    def on_robot(
        self,
        robot_name: builtins.str,
        created_on_epoch: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Robomaker":
        '''(experimental) Adds a resource of type robot to the statement.

        https://docs.aws.amazon.com/robomaker/latest/dg/fleets.html

        :param robot_name: - Identifier for the robotName.
        :param created_on_epoch: - Identifier for the createdOnEpoch.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6c2f317fb38f4c089d9a7f860679a583bf670d701386b92ad46ca4cde8514033)
            check_type(argname="argument robot_name", value=robot_name, expected_type=type_hints["robot_name"])
            check_type(argname="argument created_on_epoch", value=created_on_epoch, expected_type=type_hints["created_on_epoch"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Robomaker", jsii.invoke(self, "onRobot", [robot_name, created_on_epoch, account, region, partition]))

    @jsii.member(jsii_name="onRobotApplication")
    def on_robot_application(
        self,
        application_name: builtins.str,
        created_on_epoch: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Robomaker":
        '''(experimental) Adds a resource of type robotApplication to the statement.

        https://docs.aws.amazon.com/robomaker/latest/dg/managing-robot-applications.html

        :param application_name: - Identifier for the applicationName.
        :param created_on_epoch: - Identifier for the createdOnEpoch.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__49c32ba9644dbe87a047afc807db52a9388b7cfc80c4410d30178ec2fe1795cb)
            check_type(argname="argument application_name", value=application_name, expected_type=type_hints["application_name"])
            check_type(argname="argument created_on_epoch", value=created_on_epoch, expected_type=type_hints["created_on_epoch"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Robomaker", jsii.invoke(self, "onRobotApplication", [application_name, created_on_epoch, account, region, partition]))

    @jsii.member(jsii_name="onSimulationApplication")
    def on_simulation_application(
        self,
        application_name: builtins.str,
        created_on_epoch: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Robomaker":
        '''(experimental) Adds a resource of type simulationApplication to the statement.

        https://docs.aws.amazon.com/robomaker/latest/dg/managing-simulation-applications.html

        :param application_name: - Identifier for the applicationName.
        :param created_on_epoch: - Identifier for the createdOnEpoch.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e04f377d30da5cbb0c4bb9db3fd0e777f29250fb3f16d6200c121810f99238e4)
            check_type(argname="argument application_name", value=application_name, expected_type=type_hints["application_name"])
            check_type(argname="argument created_on_epoch", value=created_on_epoch, expected_type=type_hints["created_on_epoch"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Robomaker", jsii.invoke(self, "onSimulationApplication", [application_name, created_on_epoch, account, region, partition]))

    @jsii.member(jsii_name="onSimulationJob")
    def on_simulation_job(
        self,
        simulation_job_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Robomaker":
        '''(experimental) Adds a resource of type simulationJob to the statement.

        https://docs.aws.amazon.com/robomaker/latest/dg/simulation.html

        :param simulation_job_id: - Identifier for the simulationJobId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2f7a30dbcde8bf58ecf0c9cc50f90878c911beb3f30bf96fc5d17a8d15b34729)
            check_type(argname="argument simulation_job_id", value=simulation_job_id, expected_type=type_hints["simulation_job_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Robomaker", jsii.invoke(self, "onSimulationJob", [simulation_job_id, account, region, partition]))

    @jsii.member(jsii_name="onSimulationJobBatch")
    def on_simulation_job_batch(
        self,
        simulation_job_batch_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Robomaker":
        '''(experimental) Adds a resource of type simulationJobBatch to the statement.

        https://docs.aws.amazon.com/robomaker/latest/dg/simulation-job-batch.html

        :param simulation_job_batch_id: - Identifier for the simulationJobBatchId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d8daf776ce5493875ecf5dbefbd7012ebb3cdfe84c324f01b109d5e218aa4158)
            check_type(argname="argument simulation_job_batch_id", value=simulation_job_batch_id, expected_type=type_hints["simulation_job_batch_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Robomaker", jsii.invoke(self, "onSimulationJobBatch", [simulation_job_batch_id, account, region, partition]))

    @jsii.member(jsii_name="onWorld")
    def on_world(
        self,
        world_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Robomaker":
        '''(experimental) Adds a resource of type world to the statement.

        https://docs.aws.amazon.com/robomaker/latest/dg/worlds-managing-generated-worlds.html

        :param world_id: - Identifier for the worldId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__89132bb9ae90bb3ae9e2993c248a8df5ba4ad2aeb16add4ad2ab99492ed91324)
            check_type(argname="argument world_id", value=world_id, expected_type=type_hints["world_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Robomaker", jsii.invoke(self, "onWorld", [world_id, account, region, partition]))

    @jsii.member(jsii_name="onWorldExportJob")
    def on_world_export_job(
        self,
        world_export_job_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Robomaker":
        '''(experimental) Adds a resource of type worldExportJob to the statement.

        https://docs.aws.amazon.com/robomaker/latest/dg/worlds-managing-export-jobs.html

        :param world_export_job_id: - Identifier for the worldExportJobId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__70333703090476bb7782b3e6e0f40d16407452217b4f60319e669b1a9abdcd1e)
            check_type(argname="argument world_export_job_id", value=world_export_job_id, expected_type=type_hints["world_export_job_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Robomaker", jsii.invoke(self, "onWorldExportJob", [world_export_job_id, account, region, partition]))

    @jsii.member(jsii_name="onWorldGenerationJob")
    def on_world_generation_job(
        self,
        world_generation_job_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Robomaker":
        '''(experimental) Adds a resource of type worldGenerationJob to the statement.

        https://docs.aws.amazon.com/robomaker/latest/dg/worlds-managing-generation-jobs.html

        :param world_generation_job_id: - Identifier for the worldGenerationJobId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__484162b90033478439224904ab221329b7be51c50423b90e114f540f6f1457d8)
            check_type(argname="argument world_generation_job_id", value=world_generation_job_id, expected_type=type_hints["world_generation_job_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Robomaker", jsii.invoke(self, "onWorldGenerationJob", [world_generation_job_id, account, region, partition]))

    @jsii.member(jsii_name="onWorldTemplate")
    def on_world_template(
        self,
        world_template_job_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Robomaker":
        '''(experimental) Adds a resource of type worldTemplate to the statement.

        https://docs.aws.amazon.com/robomaker/latest/dg/worlds-managing-simworld-templates.html

        :param world_template_job_id: - Identifier for the worldTemplateJobId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__15c1e3d36862890f400e53021cc0f87f0332d9ea00f3ea84ea4bdd8b67333e12)
            check_type(argname="argument world_template_job_id", value=world_template_job_id, expected_type=type_hints["world_template_job_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Robomaker", jsii.invoke(self, "onWorldTemplate", [world_template_job_id, account, region, partition]))

    @jsii.member(jsii_name="toBatchDeleteWorlds")
    def to_batch_delete_worlds(self) -> "Robomaker":
        '''(experimental) Delete one or more worlds in a batch operation.

        Access Level: Write

        https://docs.aws.amazon.com/robomaker/latest/dg/API_BatchDeleteWorlds.html

        :stability: experimental
        '''
        return typing.cast("Robomaker", jsii.invoke(self, "toBatchDeleteWorlds", []))

    @jsii.member(jsii_name="toBatchDescribeSimulationJob")
    def to_batch_describe_simulation_job(self) -> "Robomaker":
        '''(experimental) Describe multiple simulation jobs.

        Access Level: Read

        https://docs.aws.amazon.com/robomaker/latest/dg/API_BatchDescribeSimulationJob.html

        :stability: experimental
        '''
        return typing.cast("Robomaker", jsii.invoke(self, "toBatchDescribeSimulationJob", []))

    @jsii.member(jsii_name="toCancelDeploymentJob")
    def to_cancel_deployment_job(self) -> "Robomaker":
        '''(experimental) Cancel a deployment job.

        Access Level: Write

        https://docs.aws.amazon.com/robomaker/latest/dg/API_CancelDeploymentJob.html

        :stability: experimental
        '''
        return typing.cast("Robomaker", jsii.invoke(self, "toCancelDeploymentJob", []))

    @jsii.member(jsii_name="toCancelSimulationJob")
    def to_cancel_simulation_job(self) -> "Robomaker":
        '''(experimental) Cancel a simulation job.

        Access Level: Write

        https://docs.aws.amazon.com/robomaker/latest/dg/API_CancelSimulationJob.html

        :stability: experimental
        '''
        return typing.cast("Robomaker", jsii.invoke(self, "toCancelSimulationJob", []))

    @jsii.member(jsii_name="toCancelSimulationJobBatch")
    def to_cancel_simulation_job_batch(self) -> "Robomaker":
        '''(experimental) Cancel a simulation job batch.

        Access Level: Write

        https://docs.aws.amazon.com/robomaker/latest/dg/API_CancelSimulationJobBatch.html

        :stability: experimental
        '''
        return typing.cast("Robomaker", jsii.invoke(self, "toCancelSimulationJobBatch", []))

    @jsii.member(jsii_name="toCancelWorldExportJob")
    def to_cancel_world_export_job(self) -> "Robomaker":
        '''(experimental) Cancel a world export job.

        Access Level: Write

        https://docs.aws.amazon.com/robomaker/latest/dg/API_CancelWorldExportJob.html

        :stability: experimental
        '''
        return typing.cast("Robomaker", jsii.invoke(self, "toCancelWorldExportJob", []))

    @jsii.member(jsii_name="toCancelWorldGenerationJob")
    def to_cancel_world_generation_job(self) -> "Robomaker":
        '''(experimental) Cancel a world generation job.

        Access Level: Write

        https://docs.aws.amazon.com/robomaker/latest/dg/API_CancelWorldGenerationJob.html

        :stability: experimental
        '''
        return typing.cast("Robomaker", jsii.invoke(self, "toCancelWorldGenerationJob", []))

    @jsii.member(jsii_name="toCreateDeploymentJob")
    def to_create_deployment_job(self) -> "Robomaker":
        '''(experimental) Create a deployment job.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        Dependent actions:

        - iam:CreateServiceLinkedRole

        https://docs.aws.amazon.com/robomaker/latest/dg/API_CreateDeploymentJob.html

        :stability: experimental
        '''
        return typing.cast("Robomaker", jsii.invoke(self, "toCreateDeploymentJob", []))

    @jsii.member(jsii_name="toCreateFleet")
    def to_create_fleet(self) -> "Robomaker":
        '''(experimental) Create a deployment fleet that represents a logical group of robots running the same robot application.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/robomaker/latest/dg/API_CreateFleet.html

        :stability: experimental
        '''
        return typing.cast("Robomaker", jsii.invoke(self, "toCreateFleet", []))

    @jsii.member(jsii_name="toCreateRobot")
    def to_create_robot(self) -> "Robomaker":
        '''(experimental) Create a robot that can be registered to a fleet.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        Dependent actions:

        - iam:CreateServiceLinkedRole

        https://docs.aws.amazon.com/robomaker/latest/dg/API_CreateRobot.html

        :stability: experimental
        '''
        return typing.cast("Robomaker", jsii.invoke(self, "toCreateRobot", []))

    @jsii.member(jsii_name="toCreateRobotApplication")
    def to_create_robot_application(self) -> "Robomaker":
        '''(experimental) Create a robot application.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/robomaker/latest/dg/API_CreateRobotApplication.html

        :stability: experimental
        '''
        return typing.cast("Robomaker", jsii.invoke(self, "toCreateRobotApplication", []))

    @jsii.member(jsii_name="toCreateRobotApplicationVersion")
    def to_create_robot_application_version(self) -> "Robomaker":
        '''(experimental) Create a snapshot of a robot application.

        Access Level: Write

        Dependent actions:

        - s3:GetObject

        https://docs.aws.amazon.com/robomaker/latest/dg/API_CreateRobotApplicationVersion.html

        :stability: experimental
        '''
        return typing.cast("Robomaker", jsii.invoke(self, "toCreateRobotApplicationVersion", []))

    @jsii.member(jsii_name="toCreateSimulationApplication")
    def to_create_simulation_application(self) -> "Robomaker":
        '''(experimental) Create a simulation application.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/robomaker/latest/dg/API_CreateSimulationApplication.html

        :stability: experimental
        '''
        return typing.cast("Robomaker", jsii.invoke(self, "toCreateSimulationApplication", []))

    @jsii.member(jsii_name="toCreateSimulationApplicationVersion")
    def to_create_simulation_application_version(self) -> "Robomaker":
        '''(experimental) Create a snapshot of a simulation application.

        Access Level: Write

        Dependent actions:

        - s3:GetObject

        https://docs.aws.amazon.com/robomaker/latest/dg/API_CreateSimulationApplicationVersion.html

        :stability: experimental
        '''
        return typing.cast("Robomaker", jsii.invoke(self, "toCreateSimulationApplicationVersion", []))

    @jsii.member(jsii_name="toCreateSimulationJob")
    def to_create_simulation_job(self) -> "Robomaker":
        '''(experimental) Create a simulation job.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        Dependent actions:

        - iam:CreateServiceLinkedRole

        https://docs.aws.amazon.com/robomaker/latest/dg/API_CreateSimulationJob.html

        :stability: experimental
        '''
        return typing.cast("Robomaker", jsii.invoke(self, "toCreateSimulationJob", []))

    @jsii.member(jsii_name="toCreateWorldExportJob")
    def to_create_world_export_job(self) -> "Robomaker":
        '''(experimental) Create a world export job.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/robomaker/latest/dg/API_CreateWorldExportJob.html

        :stability: experimental
        '''
        return typing.cast("Robomaker", jsii.invoke(self, "toCreateWorldExportJob", []))

    @jsii.member(jsii_name="toCreateWorldGenerationJob")
    def to_create_world_generation_job(self) -> "Robomaker":
        '''(experimental) Create a world generation job.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/robomaker/latest/dg/API_CreateWorldGenerationJob.html

        :stability: experimental
        '''
        return typing.cast("Robomaker", jsii.invoke(self, "toCreateWorldGenerationJob", []))

    @jsii.member(jsii_name="toCreateWorldTemplate")
    def to_create_world_template(self) -> "Robomaker":
        '''(experimental) Create a world template.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/robomaker/latest/dg/API_CreateWorldTemplate.html

        :stability: experimental
        '''
        return typing.cast("Robomaker", jsii.invoke(self, "toCreateWorldTemplate", []))

    @jsii.member(jsii_name="toDeleteFleet")
    def to_delete_fleet(self) -> "Robomaker":
        '''(experimental) Delete a deployment fleet.

        Access Level: Write

        https://docs.aws.amazon.com/robomaker/latest/dg/API_DeleteFleet.html

        :stability: experimental
        '''
        return typing.cast("Robomaker", jsii.invoke(self, "toDeleteFleet", []))

    @jsii.member(jsii_name="toDeleteRobot")
    def to_delete_robot(self) -> "Robomaker":
        '''(experimental) Delete a robot.

        Access Level: Write

        https://docs.aws.amazon.com/robomaker/latest/dg/API_DeleteRobot.html

        :stability: experimental
        '''
        return typing.cast("Robomaker", jsii.invoke(self, "toDeleteRobot", []))

    @jsii.member(jsii_name="toDeleteRobotApplication")
    def to_delete_robot_application(self) -> "Robomaker":
        '''(experimental) Delete a robot application.

        Access Level: Write

        https://docs.aws.amazon.com/robomaker/latest/dg/API_DeleteRobotApplication.html

        :stability: experimental
        '''
        return typing.cast("Robomaker", jsii.invoke(self, "toDeleteRobotApplication", []))

    @jsii.member(jsii_name="toDeleteSimulationApplication")
    def to_delete_simulation_application(self) -> "Robomaker":
        '''(experimental) Delete a simulation application.

        Access Level: Write

        https://docs.aws.amazon.com/robomaker/latest/dg/API_DeleteSimulationApplication.html

        :stability: experimental
        '''
        return typing.cast("Robomaker", jsii.invoke(self, "toDeleteSimulationApplication", []))

    @jsii.member(jsii_name="toDeleteWorldTemplate")
    def to_delete_world_template(self) -> "Robomaker":
        '''(experimental) Delete a world template.

        Access Level: Write

        https://docs.aws.amazon.com/robomaker/latest/dg/API_DeleteWorldTemplate.html

        :stability: experimental
        '''
        return typing.cast("Robomaker", jsii.invoke(self, "toDeleteWorldTemplate", []))

    @jsii.member(jsii_name="toDeregisterRobot")
    def to_deregister_robot(self) -> "Robomaker":
        '''(experimental) Deregister a robot from a fleet.

        Access Level: Write

        https://docs.aws.amazon.com/robomaker/latest/dg/API_DeregisterRobot.html

        :stability: experimental
        '''
        return typing.cast("Robomaker", jsii.invoke(self, "toDeregisterRobot", []))

    @jsii.member(jsii_name="toDescribeDeploymentJob")
    def to_describe_deployment_job(self) -> "Robomaker":
        '''(experimental) Describe a deployment job.

        Access Level: Read

        https://docs.aws.amazon.com/robomaker/latest/dg/API_DescribeDeploymentJob.html

        :stability: experimental
        '''
        return typing.cast("Robomaker", jsii.invoke(self, "toDescribeDeploymentJob", []))

    @jsii.member(jsii_name="toDescribeFleet")
    def to_describe_fleet(self) -> "Robomaker":
        '''(experimental) Describe a deployment fleet.

        Access Level: Read

        https://docs.aws.amazon.com/robomaker/latest/dg/API_DescribeFleet.html

        :stability: experimental
        '''
        return typing.cast("Robomaker", jsii.invoke(self, "toDescribeFleet", []))

    @jsii.member(jsii_name="toDescribeRobot")
    def to_describe_robot(self) -> "Robomaker":
        '''(experimental) Describe a robot.

        Access Level: Read

        https://docs.aws.amazon.com/robomaker/latest/dg/API_DescribeRobot.html

        :stability: experimental
        '''
        return typing.cast("Robomaker", jsii.invoke(self, "toDescribeRobot", []))

    @jsii.member(jsii_name="toDescribeRobotApplication")
    def to_describe_robot_application(self) -> "Robomaker":
        '''(experimental) Describe a robot application.

        Access Level: Read

        https://docs.aws.amazon.com/robomaker/latest/dg/API_DescribeRobotApplication.html

        :stability: experimental
        '''
        return typing.cast("Robomaker", jsii.invoke(self, "toDescribeRobotApplication", []))

    @jsii.member(jsii_name="toDescribeSimulationApplication")
    def to_describe_simulation_application(self) -> "Robomaker":
        '''(experimental) Describe a simulation application.

        Access Level: Read

        https://docs.aws.amazon.com/robomaker/latest/dg/API_DescribeSimulationApplication.html

        :stability: experimental
        '''
        return typing.cast("Robomaker", jsii.invoke(self, "toDescribeSimulationApplication", []))

    @jsii.member(jsii_name="toDescribeSimulationJob")
    def to_describe_simulation_job(self) -> "Robomaker":
        '''(experimental) Describe a simulation job.

        Access Level: Read

        https://docs.aws.amazon.com/robomaker/latest/dg/API_DescribeSimulationJob.html

        :stability: experimental
        '''
        return typing.cast("Robomaker", jsii.invoke(self, "toDescribeSimulationJob", []))

    @jsii.member(jsii_name="toDescribeSimulationJobBatch")
    def to_describe_simulation_job_batch(self) -> "Robomaker":
        '''(experimental) Describe a simulation job batch.

        Access Level: Read

        https://docs.aws.amazon.com/robomaker/latest/dg/API_DescribeSimulationJobBatch.html

        :stability: experimental
        '''
        return typing.cast("Robomaker", jsii.invoke(self, "toDescribeSimulationJobBatch", []))

    @jsii.member(jsii_name="toDescribeWorld")
    def to_describe_world(self) -> "Robomaker":
        '''(experimental) Describe a world.

        Access Level: Read

        https://docs.aws.amazon.com/robomaker/latest/dg/API_DescribeWorld.html

        :stability: experimental
        '''
        return typing.cast("Robomaker", jsii.invoke(self, "toDescribeWorld", []))

    @jsii.member(jsii_name="toDescribeWorldExportJob")
    def to_describe_world_export_job(self) -> "Robomaker":
        '''(experimental) Describe a world export job.

        Access Level: Read

        https://docs.aws.amazon.com/robomaker/latest/dg/API_DescribeWorldExportJob.html

        :stability: experimental
        '''
        return typing.cast("Robomaker", jsii.invoke(self, "toDescribeWorldExportJob", []))

    @jsii.member(jsii_name="toDescribeWorldGenerationJob")
    def to_describe_world_generation_job(self) -> "Robomaker":
        '''(experimental) Describe a world generation job.

        Access Level: Read

        https://docs.aws.amazon.com/robomaker/latest/dg/API_DescribeWorldGenerationJob.html

        :stability: experimental
        '''
        return typing.cast("Robomaker", jsii.invoke(self, "toDescribeWorldGenerationJob", []))

    @jsii.member(jsii_name="toDescribeWorldTemplate")
    def to_describe_world_template(self) -> "Robomaker":
        '''(experimental) Describe a world template.

        Access Level: Read

        https://docs.aws.amazon.com/robomaker/latest/dg/API_DescribeWorldTemplate.html

        :stability: experimental
        '''
        return typing.cast("Robomaker", jsii.invoke(self, "toDescribeWorldTemplate", []))

    @jsii.member(jsii_name="toGetWorldTemplateBody")
    def to_get_world_template_body(self) -> "Robomaker":
        '''(experimental) Get the body of a world template.

        Access Level: Read

        https://docs.aws.amazon.com/robomaker/latest/dg/API_GetWorldTemplateBody.html

        :stability: experimental
        '''
        return typing.cast("Robomaker", jsii.invoke(self, "toGetWorldTemplateBody", []))

    @jsii.member(jsii_name="toListDeploymentJobs")
    def to_list_deployment_jobs(self) -> "Robomaker":
        '''(experimental) List deployment jobs.

        Access Level: List

        https://docs.aws.amazon.com/robomaker/latest/dg/API_ListDeploymentJobs.html

        :stability: experimental
        '''
        return typing.cast("Robomaker", jsii.invoke(self, "toListDeploymentJobs", []))

    @jsii.member(jsii_name="toListFleets")
    def to_list_fleets(self) -> "Robomaker":
        '''(experimental) List fleets.

        Access Level: List

        https://docs.aws.amazon.com/robomaker/latest/dg/API_ListFleets.html

        :stability: experimental
        '''
        return typing.cast("Robomaker", jsii.invoke(self, "toListFleets", []))

    @jsii.member(jsii_name="toListRobotApplications")
    def to_list_robot_applications(self) -> "Robomaker":
        '''(experimental) List robot applications.

        Access Level: List

        https://docs.aws.amazon.com/robomaker/latest/dg/API_ListRobotApplications.html

        :stability: experimental
        '''
        return typing.cast("Robomaker", jsii.invoke(self, "toListRobotApplications", []))

    @jsii.member(jsii_name="toListRobots")
    def to_list_robots(self) -> "Robomaker":
        '''(experimental) List robots.

        Access Level: List

        https://docs.aws.amazon.com/robomaker/latest/dg/API_ListRobots.html

        :stability: experimental
        '''
        return typing.cast("Robomaker", jsii.invoke(self, "toListRobots", []))

    @jsii.member(jsii_name="toListSimulationApplications")
    def to_list_simulation_applications(self) -> "Robomaker":
        '''(experimental) List simulation applications.

        Access Level: List

        https://docs.aws.amazon.com/robomaker/latest/dg/API_ListSimulationApplications.html

        :stability: experimental
        '''
        return typing.cast("Robomaker", jsii.invoke(self, "toListSimulationApplications", []))

    @jsii.member(jsii_name="toListSimulationJobBatches")
    def to_list_simulation_job_batches(self) -> "Robomaker":
        '''(experimental) List simulation job batches.

        Access Level: List

        https://docs.aws.amazon.com/robomaker/latest/dg/API_ListSimulationJobBatches.html

        :stability: experimental
        '''
        return typing.cast("Robomaker", jsii.invoke(self, "toListSimulationJobBatches", []))

    @jsii.member(jsii_name="toListSimulationJobs")
    def to_list_simulation_jobs(self) -> "Robomaker":
        '''(experimental) List simulation jobs.

        Access Level: List

        https://docs.aws.amazon.com/robomaker/latest/dg/API_ListSimulationJobs.html

        :stability: experimental
        '''
        return typing.cast("Robomaker", jsii.invoke(self, "toListSimulationJobs", []))

    @jsii.member(jsii_name="toListSupportedAvailabilityZones")
    def to_list_supported_availability_zones(self) -> "Robomaker":
        '''(experimental) Lists supported availability zones.

        Access Level: List

        :stability: experimental
        '''
        return typing.cast("Robomaker", jsii.invoke(self, "toListSupportedAvailabilityZones", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Robomaker":
        '''(experimental) List tags for a RoboMaker resource.

        Access Level: List

        https://docs.aws.amazon.com/robomaker/latest/dg/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("Robomaker", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toListWorldExportJobs")
    def to_list_world_export_jobs(self) -> "Robomaker":
        '''(experimental) List world export jobs.

        Access Level: List

        https://docs.aws.amazon.com/robomaker/latest/dg/API_ListWorldExportJobs.html

        :stability: experimental
        '''
        return typing.cast("Robomaker", jsii.invoke(self, "toListWorldExportJobs", []))

    @jsii.member(jsii_name="toListWorldGenerationJobs")
    def to_list_world_generation_jobs(self) -> "Robomaker":
        '''(experimental) List world generation jobs.

        Access Level: List

        https://docs.aws.amazon.com/robomaker/latest/dg/API_ListWorldGenerationJobs.html

        :stability: experimental
        '''
        return typing.cast("Robomaker", jsii.invoke(self, "toListWorldGenerationJobs", []))

    @jsii.member(jsii_name="toListWorlds")
    def to_list_worlds(self) -> "Robomaker":
        '''(experimental) List worlds.

        Access Level: List

        https://docs.aws.amazon.com/robomaker/latest/dg/API_ListWorlds.html

        :stability: experimental
        '''
        return typing.cast("Robomaker", jsii.invoke(self, "toListWorlds", []))

    @jsii.member(jsii_name="toListWorldTemplates")
    def to_list_world_templates(self) -> "Robomaker":
        '''(experimental) List world templates.

        Access Level: List

        https://docs.aws.amazon.com/robomaker/latest/dg/API_ListWorldTemplates.html

        :stability: experimental
        '''
        return typing.cast("Robomaker", jsii.invoke(self, "toListWorldTemplates", []))

    @jsii.member(jsii_name="toRegisterRobot")
    def to_register_robot(self) -> "Robomaker":
        '''(experimental) Register a robot to a fleet.

        Access Level: Write

        https://docs.aws.amazon.com/robomaker/latest/dg/API_RegisterRobot.html

        :stability: experimental
        '''
        return typing.cast("Robomaker", jsii.invoke(self, "toRegisterRobot", []))

    @jsii.member(jsii_name="toRestartSimulationJob")
    def to_restart_simulation_job(self) -> "Robomaker":
        '''(experimental) Restart a running simulation job.

        Access Level: Write

        https://docs.aws.amazon.com/robomaker/latest/dg/API_RestartSimulationJob.html

        :stability: experimental
        '''
        return typing.cast("Robomaker", jsii.invoke(self, "toRestartSimulationJob", []))

    @jsii.member(jsii_name="toStartSimulationJobBatch")
    def to_start_simulation_job_batch(self) -> "Robomaker":
        '''(experimental) Create a simulation job batch.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        Dependent actions:

        - iam:CreateServiceLinkedRole

        https://docs.aws.amazon.com/robomaker/latest/dg/API_StartSimulationJobBatch.html

        :stability: experimental
        '''
        return typing.cast("Robomaker", jsii.invoke(self, "toStartSimulationJobBatch", []))

    @jsii.member(jsii_name="toSyncDeploymentJob")
    def to_sync_deployment_job(self) -> "Robomaker":
        '''(experimental) Ensures the most recently deployed robot application is deployed to all robots in the fleet.

        Access Level: Write

        Dependent actions:

        - iam:CreateServiceLinkedRole

        https://docs.aws.amazon.com/robomaker/latest/dg/API_SyncDeploymentJob.html

        :stability: experimental
        '''
        return typing.cast("Robomaker", jsii.invoke(self, "toSyncDeploymentJob", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Robomaker":
        '''(experimental) Add tags to a RoboMaker resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/robomaker/latest/dg/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("Robomaker", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Robomaker":
        '''(experimental) Remove tags from a RoboMaker resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/robomaker/latest/dg/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("Robomaker", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateRobotApplication")
    def to_update_robot_application(self) -> "Robomaker":
        '''(experimental) Update a robot application.

        Access Level: Write

        https://docs.aws.amazon.com/robomaker/latest/dg/API_UpdateRobotApplication.html

        :stability: experimental
        '''
        return typing.cast("Robomaker", jsii.invoke(self, "toUpdateRobotApplication", []))

    @jsii.member(jsii_name="toUpdateRobotDeployment")
    def to_update_robot_deployment(self) -> "Robomaker":
        '''(experimental) Report the deployment status for an individual robot.

        Access Level: Write

        :stability: experimental
        '''
        return typing.cast("Robomaker", jsii.invoke(self, "toUpdateRobotDeployment", []))

    @jsii.member(jsii_name="toUpdateSimulationApplication")
    def to_update_simulation_application(self) -> "Robomaker":
        '''(experimental) Update a simulation application.

        Access Level: Write

        https://docs.aws.amazon.com/robomaker/latest/dg/API_UpdateSimulationApplication.html

        :stability: experimental
        '''
        return typing.cast("Robomaker", jsii.invoke(self, "toUpdateSimulationApplication", []))

    @jsii.member(jsii_name="toUpdateWorldTemplate")
    def to_update_world_template(self) -> "Robomaker":
        '''(experimental) Update a world template.

        Access Level: Write

        https://docs.aws.amazon.com/robomaker/latest/dg/API_UpdateWorldTemplate.html

        :stability: experimental
        '''
        return typing.cast("Robomaker", jsii.invoke(self, "toUpdateWorldTemplate", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4d164ef4da774e68a7dfd3b9be6a45773f498e73c5aedcbe286d037ad57d584f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__480be3032854a8be7f8df07494bebf11fb2179cb18ef55904723deb07ebe466d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Rolesanywhere(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Rolesanywhere",
):
    '''(experimental) Statement provider for service `rolesanywhere <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsidentityandaccessmanagementrolesanywhere.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `rolesanywhere <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsidentityandaccessmanagementrolesanywhere.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onCrl")
    def on_crl(
        self,
        crl_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Rolesanywhere":
        '''(experimental) Adds a resource of type crl to the statement.

        https://docs.aws.amazon.com/rolesanywhere/latest/userguide/introduction.html#first-time-user

        :param crl_id: - Identifier for the crlId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fd275ff83c3f72a094457418d37ded5de6982a8d6955844b5e9b26493f5de5e5)
            check_type(argname="argument crl_id", value=crl_id, expected_type=type_hints["crl_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Rolesanywhere", jsii.invoke(self, "onCrl", [crl_id, account, region, partition]))

    @jsii.member(jsii_name="onProfile")
    def on_profile(
        self,
        profile_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Rolesanywhere":
        '''(experimental) Adds a resource of type profile to the statement.

        https://docs.aws.amazon.com/rolesanywhere/latest/userguide/introduction.html#first-time-user

        :param profile_id: - Identifier for the profileId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__dbc3d5cff8ab209703aa2f0beb8f32013a83c0ef10dd876229369c172e19ac2c)
            check_type(argname="argument profile_id", value=profile_id, expected_type=type_hints["profile_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Rolesanywhere", jsii.invoke(self, "onProfile", [profile_id, account, region, partition]))

    @jsii.member(jsii_name="onSubject")
    def on_subject(
        self,
        subject_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Rolesanywhere":
        '''(experimental) Adds a resource of type subject to the statement.

        https://docs.aws.amazon.com/rolesanywhere/latest/userguide/introduction.html#first-time-user

        :param subject_id: - Identifier for the subjectId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8d9010a61bf26573df767b9038644f2642078b10ffbf0537200d77dfcc0834d0)
            check_type(argname="argument subject_id", value=subject_id, expected_type=type_hints["subject_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Rolesanywhere", jsii.invoke(self, "onSubject", [subject_id, account, region, partition]))

    @jsii.member(jsii_name="onTrustAnchor")
    def on_trust_anchor(
        self,
        trust_anchor_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Rolesanywhere":
        '''(experimental) Adds a resource of type trust-anchor to the statement.

        https://docs.aws.amazon.com/rolesanywhere/latest/userguide/introduction.html#first-time-user

        :param trust_anchor_id: - Identifier for the trustAnchorId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4afec003b3da3110b8d8efac47e6b16d1f924aefc7926e54b29e2a41c24a1cea)
            check_type(argname="argument trust_anchor_id", value=trust_anchor_id, expected_type=type_hints["trust_anchor_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Rolesanywhere", jsii.invoke(self, "onTrustAnchor", [trust_anchor_id, account, region, partition]))

    @jsii.member(jsii_name="toCreateProfile")
    def to_create_profile(self) -> "Rolesanywhere":
        '''(experimental) Grants permission to create a profile.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - iam:PassRole

        https://docs.aws.amazon.com/rolesanywhere/latest/APIReference/API_CreateProfile.html

        :stability: experimental
        '''
        return typing.cast("Rolesanywhere", jsii.invoke(self, "toCreateProfile", []))

    @jsii.member(jsii_name="toCreateTrustAnchor")
    def to_create_trust_anchor(self) -> "Rolesanywhere":
        '''(experimental) Grants permission to create a trust anchor.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/rolesanywhere/latest/APIReference/API_CreateTrustAnchor.html

        :stability: experimental
        '''
        return typing.cast("Rolesanywhere", jsii.invoke(self, "toCreateTrustAnchor", []))

    @jsii.member(jsii_name="toDeleteCrl")
    def to_delete_crl(self) -> "Rolesanywhere":
        '''(experimental) Grants permission to delete a certificate revocation list (crl).

        Access Level: Write

        https://docs.aws.amazon.com/rolesanywhere/latest/APIReference/API_DeleteCrl.html

        :stability: experimental
        '''
        return typing.cast("Rolesanywhere", jsii.invoke(self, "toDeleteCrl", []))

    @jsii.member(jsii_name="toDeleteProfile")
    def to_delete_profile(self) -> "Rolesanywhere":
        '''(experimental) Grants permission to delete a profile.

        Access Level: Write

        https://docs.aws.amazon.com/rolesanywhere/latest/APIReference/API_DeleteProfile.html

        :stability: experimental
        '''
        return typing.cast("Rolesanywhere", jsii.invoke(self, "toDeleteProfile", []))

    @jsii.member(jsii_name="toDeleteTrustAnchor")
    def to_delete_trust_anchor(self) -> "Rolesanywhere":
        '''(experimental) Grants permission to delete a trust anchor.

        Access Level: Write

        https://docs.aws.amazon.com/rolesanywhere/latest/APIReference/API_DeleteTrustAnchor.html

        :stability: experimental
        '''
        return typing.cast("Rolesanywhere", jsii.invoke(self, "toDeleteTrustAnchor", []))

    @jsii.member(jsii_name="toDisableCrl")
    def to_disable_crl(self) -> "Rolesanywhere":
        '''(experimental) Grants permission to disable a certificate revocation list (crl).

        Access Level: Write

        https://docs.aws.amazon.com/rolesanywhere/latest/APIReference/API_DisableCrl.html

        :stability: experimental
        '''
        return typing.cast("Rolesanywhere", jsii.invoke(self, "toDisableCrl", []))

    @jsii.member(jsii_name="toDisableProfile")
    def to_disable_profile(self) -> "Rolesanywhere":
        '''(experimental) Grants permission to disable a profile.

        Access Level: Write

        https://docs.aws.amazon.com/rolesanywhere/latest/APIReference/API_DisableProfile.html

        :stability: experimental
        '''
        return typing.cast("Rolesanywhere", jsii.invoke(self, "toDisableProfile", []))

    @jsii.member(jsii_name="toDisableTrustAnchor")
    def to_disable_trust_anchor(self) -> "Rolesanywhere":
        '''(experimental) Grants permission to disable a trust anchor.

        Access Level: Write

        https://docs.aws.amazon.com/rolesanywhere/latest/APIReference/API_DisableTrustAnchor.html

        :stability: experimental
        '''
        return typing.cast("Rolesanywhere", jsii.invoke(self, "toDisableTrustAnchor", []))

    @jsii.member(jsii_name="toEnableCrl")
    def to_enable_crl(self) -> "Rolesanywhere":
        '''(experimental) Grants permission to enable a certificate revocation list (crl).

        Access Level: Write

        https://docs.aws.amazon.com/rolesanywhere/latest/APIReference/API_EnableCrl.html

        :stability: experimental
        '''
        return typing.cast("Rolesanywhere", jsii.invoke(self, "toEnableCrl", []))

    @jsii.member(jsii_name="toEnableProfile")
    def to_enable_profile(self) -> "Rolesanywhere":
        '''(experimental) Grants permission to enable a profile.

        Access Level: Write

        Dependent actions:

        - iam:PassRole

        https://docs.aws.amazon.com/rolesanywhere/latest/APIReference/API_EnableProfile.html

        :stability: experimental
        '''
        return typing.cast("Rolesanywhere", jsii.invoke(self, "toEnableProfile", []))

    @jsii.member(jsii_name="toEnableTrustAnchor")
    def to_enable_trust_anchor(self) -> "Rolesanywhere":
        '''(experimental) Grants permission to enable a trust anchor.

        Access Level: Write

        https://docs.aws.amazon.com/rolesanywhere/latest/APIReference/API_EnableTrustAnchor.html

        :stability: experimental
        '''
        return typing.cast("Rolesanywhere", jsii.invoke(self, "toEnableTrustAnchor", []))

    @jsii.member(jsii_name="toGetCrl")
    def to_get_crl(self) -> "Rolesanywhere":
        '''(experimental) Grants permission to get a certificate revocation list (crl).

        Access Level: Read

        https://docs.aws.amazon.com/rolesanywhere/latest/APIReference/API_GetCrl.html

        :stability: experimental
        '''
        return typing.cast("Rolesanywhere", jsii.invoke(self, "toGetCrl", []))

    @jsii.member(jsii_name="toGetProfile")
    def to_get_profile(self) -> "Rolesanywhere":
        '''(experimental) Grants permission to get a profile.

        Access Level: Read

        https://docs.aws.amazon.com/rolesanywhere/latest/APIReference/API_GetProfile.html

        :stability: experimental
        '''
        return typing.cast("Rolesanywhere", jsii.invoke(self, "toGetProfile", []))

    @jsii.member(jsii_name="toGetSubject")
    def to_get_subject(self) -> "Rolesanywhere":
        '''(experimental) Grants permission to get a subject.

        Access Level: Read

        https://docs.aws.amazon.com/rolesanywhere/latest/APIReference/API_GetSubject.html

        :stability: experimental
        '''
        return typing.cast("Rolesanywhere", jsii.invoke(self, "toGetSubject", []))

    @jsii.member(jsii_name="toGetTrustAnchor")
    def to_get_trust_anchor(self) -> "Rolesanywhere":
        '''(experimental) Grants permission to get a trust anchor.

        Access Level: Read

        https://docs.aws.amazon.com/rolesanywhere/latest/APIReference/API_GetTrustAnchor.html

        :stability: experimental
        '''
        return typing.cast("Rolesanywhere", jsii.invoke(self, "toGetTrustAnchor", []))

    @jsii.member(jsii_name="toImportCrl")
    def to_import_crl(self) -> "Rolesanywhere":
        '''(experimental) Grants permission to import a certificate revocation list (crl).

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/rolesanywhere/latest/APIReference/API_ImportCrl.html

        :stability: experimental
        '''
        return typing.cast("Rolesanywhere", jsii.invoke(self, "toImportCrl", []))

    @jsii.member(jsii_name="toListCrls")
    def to_list_crls(self) -> "Rolesanywhere":
        '''(experimental) Grants permission to list certificate revocation lists (crls).

        Access Level: List

        https://docs.aws.amazon.com/rolesanywhere/latest/APIReference/API_ListCrls.html

        :stability: experimental
        '''
        return typing.cast("Rolesanywhere", jsii.invoke(self, "toListCrls", []))

    @jsii.member(jsii_name="toListProfiles")
    def to_list_profiles(self) -> "Rolesanywhere":
        '''(experimental) Grants permission to list profiles.

        Access Level: List

        https://docs.aws.amazon.com/rolesanywhere/latest/APIReference/API_ListProfiles.html

        :stability: experimental
        '''
        return typing.cast("Rolesanywhere", jsii.invoke(self, "toListProfiles", []))

    @jsii.member(jsii_name="toListSubjects")
    def to_list_subjects(self) -> "Rolesanywhere":
        '''(experimental) Grants permission to list subjects.

        Access Level: List

        https://docs.aws.amazon.com/rolesanywhere/latest/APIReference/API_ListSubjects.html

        :stability: experimental
        '''
        return typing.cast("Rolesanywhere", jsii.invoke(self, "toListSubjects", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Rolesanywhere":
        '''(experimental) Grants permission to list tags for a resource.

        Access Level: List

        https://docs.aws.amazon.com/rolesanywhere/latest/APIReference/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("Rolesanywhere", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toListTrustAnchors")
    def to_list_trust_anchors(self) -> "Rolesanywhere":
        '''(experimental) Grants permission to list trust anchors.

        Access Level: List

        https://docs.aws.amazon.com/rolesanywhere/latest/APIReference/API_ListTrustAnchors.html

        :stability: experimental
        '''
        return typing.cast("Rolesanywhere", jsii.invoke(self, "toListTrustAnchors", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Rolesanywhere":
        '''(experimental) Grants permission to tag a resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/rolesanywhere/latest/APIReference/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("Rolesanywhere", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Rolesanywhere":
        '''(experimental) Grants permission to untag a resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/rolesanywhere/latest/APIReference/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("Rolesanywhere", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateCrl")
    def to_update_crl(self) -> "Rolesanywhere":
        '''(experimental) Grants permission to update a certificate revocation list (crl).

        Access Level: Write

        https://docs.aws.amazon.com/rolesanywhere/latest/APIReference/API_UpdateCrl.html

        :stability: experimental
        '''
        return typing.cast("Rolesanywhere", jsii.invoke(self, "toUpdateCrl", []))

    @jsii.member(jsii_name="toUpdateProfile")
    def to_update_profile(self) -> "Rolesanywhere":
        '''(experimental) Grants permission to update a profile.

        Access Level: Write

        Dependent actions:

        - iam:PassRole

        https://docs.aws.amazon.com/rolesanywhere/latest/APIReference/API_UpdateProfile.html

        :stability: experimental
        '''
        return typing.cast("Rolesanywhere", jsii.invoke(self, "toUpdateProfile", []))

    @jsii.member(jsii_name="toUpdateTrustAnchor")
    def to_update_trust_anchor(self) -> "Rolesanywhere":
        '''(experimental) Grants permission to update a trust anchor.

        Access Level: Write

        https://docs.aws.amazon.com/rolesanywhere/latest/APIReference/API_UpdateTrustAnchor.html

        :stability: experimental
        '''
        return typing.cast("Rolesanywhere", jsii.invoke(self, "toUpdateTrustAnchor", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7df879e792cb3f935ea491d4d99ad37f64dd989533a3a7113af4f3c6c7f3e0d1)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__83c28f57ac9cb7aad301b2c754841a6a765aace6cb34bb2980dbecd15108da2c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Route53(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Route53",
):
    '''(experimental) Statement provider for service `route53 <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonroute53.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `route53 <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonroute53.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="ifChangeResourceRecordSetsActions")
    def if_change_resource_record_sets_actions(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Route53":
        '''(experimental) Filters access by the change actions, CREATE, UPSERT, or DELETE, in a ChangeResourceRecordSets request.

        https://docs.aws.amazon.com/Route53/latest/DeveloperGuide/specifying-rrset-conditions.html#route53_rrset_ConditionKeys

        Applies to actions:

        - .toChangeResourceRecordSets()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3c6c06f44d412f758508fe7b57ccac1666dd04d847184a07f39fefa2f2a43491)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Route53", jsii.invoke(self, "ifChangeResourceRecordSetsActions", [value, operator]))

    @jsii.member(jsii_name="ifChangeResourceRecordSetsNormalizedRecordNames")
    def if_change_resource_record_sets_normalized_record_names(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Route53":
        '''(experimental) Filters access by the normalized DNS record names in a ChangeResourceRecordSets request.

        https://docs.aws.amazon.com/Route53/latest/DeveloperGuide/specifying-rrset-conditions.html#route53_rrset_ConditionKeys

        Applies to actions:

        - .toChangeResourceRecordSets()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1101beae23a2c5c4ff1a16a0acc6e006d4b765be6d43f213c0358445824fc66d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Route53", jsii.invoke(self, "ifChangeResourceRecordSetsNormalizedRecordNames", [value, operator]))

    @jsii.member(jsii_name="ifChangeResourceRecordSetsRecordTypes")
    def if_change_resource_record_sets_record_types(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Route53":
        '''(experimental) Filters access by the DNS record types in a ChangeResourceRecordSets request.

        https://docs.aws.amazon.com/Route53/latest/DeveloperGuide/specifying-rrset-conditions.html#route53_rrset_ConditionKeys

        Applies to actions:

        - .toChangeResourceRecordSets()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2515e99005bafabc35e9b3052e363ff3f64750701d4902660e145bbc328afe21)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Route53", jsii.invoke(self, "ifChangeResourceRecordSetsRecordTypes", [value, operator]))

    @jsii.member(jsii_name="onChange")
    def on_change(
        self,
        id: builtins.str,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Route53":
        '''(experimental) Adds a resource of type change to the statement.

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_Change.html

        :param id: - Identifier for the id.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bdb18224b02f0e8c4c1ebb99814ce1ea11d3a391ee83114cfa5145ea5f965143)
            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Route53", jsii.invoke(self, "onChange", [id, partition]))

    @jsii.member(jsii_name="onCidrcollection")
    def on_cidrcollection(
        self,
        id: builtins.str,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Route53":
        '''(experimental) Adds a resource of type cidrcollection to the statement.

        :param id: - Identifier for the id.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__887d27ad7b837249c4c1bce13c1c46dd899476331ff895db959d4756ad79a191)
            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Route53", jsii.invoke(self, "onCidrcollection", [id, partition]))

    @jsii.member(jsii_name="onDelegationset")
    def on_delegationset(
        self,
        id: builtins.str,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Route53":
        '''(experimental) Adds a resource of type delegationset to the statement.

        https://docs.aws.amazon.com/Route53/latest/DeveloperGuide/route-53-concepts.html#route-53-concepts-reusable-delegation-set

        :param id: - Identifier for the id.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2d64514aaa0693ab2dd843176b53b5b878de7c0cc038b39f70d78c601a8eb168)
            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Route53", jsii.invoke(self, "onDelegationset", [id, partition]))

    @jsii.member(jsii_name="onHealthcheck")
    def on_healthcheck(
        self,
        id: builtins.str,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Route53":
        '''(experimental) Adds a resource of type healthcheck to the statement.

        https://docs.aws.amazon.com/Route53/latest/DeveloperGuide/route-53-concepts.html#route-53-concepts-health-check

        :param id: - Identifier for the id.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__dcd437068428482df5cd142903902d51fb9952dde257b1d4b43031e142fcb1e4)
            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Route53", jsii.invoke(self, "onHealthcheck", [id, partition]))

    @jsii.member(jsii_name="onHostedzone")
    def on_hostedzone(
        self,
        id: builtins.str,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Route53":
        '''(experimental) Adds a resource of type hostedzone to the statement.

        https://docs.aws.amazon.com/Route53/latest/DeveloperGuide/route-53-concepts.html#route-53-concepts-hosted-zone

        :param id: - Identifier for the id.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__dd6107a38d2d927566d1d1e00f803206ea25fb352c24e0b8562db4f63c66ee2a)
            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Route53", jsii.invoke(self, "onHostedzone", [id, partition]))

    @jsii.member(jsii_name="onQueryloggingconfig")
    def on_queryloggingconfig(
        self,
        id: builtins.str,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Route53":
        '''(experimental) Adds a resource of type queryloggingconfig to the statement.

        https://docs.aws.amazon.com/Route53/latest/DeveloperGuide/query-logs.html

        :param id: - Identifier for the id.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c6fb3c4677e0ffe6f7f9110d770fa7598cfadef4116e6629d6962c6d32ff3b83)
            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Route53", jsii.invoke(self, "onQueryloggingconfig", [id, partition]))

    @jsii.member(jsii_name="onTrafficpolicy")
    def on_trafficpolicy(
        self,
        id: builtins.str,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Route53":
        '''(experimental) Adds a resource of type trafficpolicy to the statement.

        https://docs.aws.amazon.com/Route53/latest/DeveloperGuide/traffic-policies.html

        :param id: - Identifier for the id.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c1db32c399ddbe5f8476083a209bf6a3a760c69b9a26573be4bb0922badb5b0d)
            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Route53", jsii.invoke(self, "onTrafficpolicy", [id, partition]))

    @jsii.member(jsii_name="onTrafficpolicyinstance")
    def on_trafficpolicyinstance(
        self,
        id: builtins.str,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Route53":
        '''(experimental) Adds a resource of type trafficpolicyinstance to the statement.

        https://docs.aws.amazon.com/Route53/latest/DeveloperGuide/traffic-policy-records.html

        :param id: - Identifier for the id.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__eccc3087b649bedada26c339f113cffa849ee3b19ad6ee4b70ec9209b8e63e81)
            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Route53", jsii.invoke(self, "onTrafficpolicyinstance", [id, partition]))

    @jsii.member(jsii_name="onVpc")
    def on_vpc(
        self,
        vpc_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Route53":
        '''(experimental) Adds a resource of type vpc to the statement.

        https://docs.aws.amazon.com/vpc/latest/userguide/VPC_Subnets.html

        :param vpc_id: - Identifier for the vpcId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fba2ec8d5b8b221ca2ef50f5ec375ab0cc2a63d51fdd9a3b6da1353ca778aba2)
            check_type(argname="argument vpc_id", value=vpc_id, expected_type=type_hints["vpc_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Route53", jsii.invoke(self, "onVpc", [vpc_id, account, region, partition]))

    @jsii.member(jsii_name="toActivateKeySigningKey")
    def to_activate_key_signing_key(self) -> "Route53":
        '''(experimental) Grants permission to activate a key-signing key so that it can be used for signing by DNSSEC.

        Access Level: Write

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_ActivateKeySigningKey.html

        :stability: experimental
        '''
        return typing.cast("Route53", jsii.invoke(self, "toActivateKeySigningKey", []))

    @jsii.member(jsii_name="toAssociateVPCWithHostedZone")
    def to_associate_vpc_with_hosted_zone(self) -> "Route53":
        '''(experimental) Grants permission to associate an additional Amazon VPC with a private hosted zone.

        Access Level: Write

        Dependent actions:

        - ec2:DescribeVpcs

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_AssociateVPCWithHostedZone.html

        :stability: experimental
        '''
        return typing.cast("Route53", jsii.invoke(self, "toAssociateVPCWithHostedZone", []))

    @jsii.member(jsii_name="toChangeCidrCollection")
    def to_change_cidr_collection(self) -> "Route53":
        '''(experimental) Grants permission to create or delete CIDR blocks within a CIDR collection.

        Access Level: Write

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_ChangeCidrCollection.html

        :stability: experimental
        '''
        return typing.cast("Route53", jsii.invoke(self, "toChangeCidrCollection", []))

    @jsii.member(jsii_name="toChangeResourceRecordSets")
    def to_change_resource_record_sets(self) -> "Route53":
        '''(experimental) Grants permission to create, update, or delete a record, which contains authoritative DNS information for a specified domain or subdomain name.

        Access Level: Write

        Possible conditions:

        - .ifChangeResourceRecordSetsNormalizedRecordNames()
        - .ifChangeResourceRecordSetsRecordTypes()
        - .ifChangeResourceRecordSetsActions()

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_ChangeResourceRecordSets.html

        :stability: experimental
        '''
        return typing.cast("Route53", jsii.invoke(self, "toChangeResourceRecordSets", []))

    @jsii.member(jsii_name="toChangeTagsForResource")
    def to_change_tags_for_resource(self) -> "Route53":
        '''(experimental) Grants permission to add, edit, or delete tags for a health check or a hosted zone.

        Access Level: Tagging

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_ChangeTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("Route53", jsii.invoke(self, "toChangeTagsForResource", []))

    @jsii.member(jsii_name="toCreateCidrCollection")
    def to_create_cidr_collection(self) -> "Route53":
        '''(experimental) Grants permission to create a new CIDR collection.

        Access Level: Write

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_CreateCidrCollection.html

        :stability: experimental
        '''
        return typing.cast("Route53", jsii.invoke(self, "toCreateCidrCollection", []))

    @jsii.member(jsii_name="toCreateHealthCheck")
    def to_create_health_check(self) -> "Route53":
        '''(experimental) Grants permission to create a new health check, which monitors the health and performance of your web applications, web servers, and other resources.

        Access Level: Write

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_CreateHealthCheck.html

        :stability: experimental
        '''
        return typing.cast("Route53", jsii.invoke(self, "toCreateHealthCheck", []))

    @jsii.member(jsii_name="toCreateHostedZone")
    def to_create_hosted_zone(self) -> "Route53":
        '''(experimental) Grants permission to create a public hosted zone, which you use to specify how the Domain Name System (DNS) routes traffic on the Internet for a domain, such as example.com, and its subdomains.

        Access Level: Write

        Dependent actions:

        - ec2:DescribeVpcs

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_CreateHostedZone.html

        :stability: experimental
        '''
        return typing.cast("Route53", jsii.invoke(self, "toCreateHostedZone", []))

    @jsii.member(jsii_name="toCreateKeySigningKey")
    def to_create_key_signing_key(self) -> "Route53":
        '''(experimental) Grants permission to create a new key-signing key associated with a hosted zone.

        Access Level: Write

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_CreateKeySigningKey.html

        :stability: experimental
        '''
        return typing.cast("Route53", jsii.invoke(self, "toCreateKeySigningKey", []))

    @jsii.member(jsii_name="toCreateQueryLoggingConfig")
    def to_create_query_logging_config(self) -> "Route53":
        '''(experimental) Grants permission to create a configuration for DNS query logging.

        Access Level: Write

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_CreateQueryLoggingConfig.html

        :stability: experimental
        '''
        return typing.cast("Route53", jsii.invoke(self, "toCreateQueryLoggingConfig", []))

    @jsii.member(jsii_name="toCreateReusableDelegationSet")
    def to_create_reusable_delegation_set(self) -> "Route53":
        '''(experimental) Grants permission to create a delegation set (a group of four name servers) that can be reused by multiple hosted zones.

        Access Level: Write

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_CreateReusableDelegationSet.html

        :stability: experimental
        '''
        return typing.cast("Route53", jsii.invoke(self, "toCreateReusableDelegationSet", []))

    @jsii.member(jsii_name="toCreateTrafficPolicy")
    def to_create_traffic_policy(self) -> "Route53":
        '''(experimental) Grants permission to create a traffic policy, which you use to create multiple DNS records for one domain name (such as example.com) or one subdomain name (such as www.example.com).

        Access Level: Write

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_CreateTrafficPolicy.html

        :stability: experimental
        '''
        return typing.cast("Route53", jsii.invoke(self, "toCreateTrafficPolicy", []))

    @jsii.member(jsii_name="toCreateTrafficPolicyInstance")
    def to_create_traffic_policy_instance(self) -> "Route53":
        '''(experimental) Grants permission to create records in a specified hosted zone based on the settings in a specified traffic policy version.

        Access Level: Write

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_CreateTrafficPolicyInstance.html

        :stability: experimental
        '''
        return typing.cast("Route53", jsii.invoke(self, "toCreateTrafficPolicyInstance", []))

    @jsii.member(jsii_name="toCreateTrafficPolicyVersion")
    def to_create_traffic_policy_version(self) -> "Route53":
        '''(experimental) Grants permission to create a new version of an existing traffic policy.

        Access Level: Write

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_CreateTrafficPolicyVersion.html

        :stability: experimental
        '''
        return typing.cast("Route53", jsii.invoke(self, "toCreateTrafficPolicyVersion", []))

    @jsii.member(jsii_name="toCreateVPCAssociationAuthorization")
    def to_create_vpc_association_authorization(self) -> "Route53":
        '''(experimental) Grants permission to authorize the AWS account that created a specified VPC to submit an AssociateVPCWithHostedZone request, which associates the VPC with a specified hosted zone that was created by a different account.

        Access Level: Write

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_CreateVPCAssociationAuthorization.html

        :stability: experimental
        '''
        return typing.cast("Route53", jsii.invoke(self, "toCreateVPCAssociationAuthorization", []))

    @jsii.member(jsii_name="toDeactivateKeySigningKey")
    def to_deactivate_key_signing_key(self) -> "Route53":
        '''(experimental) Grants permission to deactivate a key-signing key so that it will not be used for signing by DNSSEC.

        Access Level: Write

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_DeactivateKeySigningKey.html

        :stability: experimental
        '''
        return typing.cast("Route53", jsii.invoke(self, "toDeactivateKeySigningKey", []))

    @jsii.member(jsii_name="toDeleteCidrCollection")
    def to_delete_cidr_collection(self) -> "Route53":
        '''(experimental) Grants permission to delete a CIDR collection.

        Access Level: Write

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_DeleteCidrCollection.html

        :stability: experimental
        '''
        return typing.cast("Route53", jsii.invoke(self, "toDeleteCidrCollection", []))

    @jsii.member(jsii_name="toDeleteHealthCheck")
    def to_delete_health_check(self) -> "Route53":
        '''(experimental) Grants permission to delete a health check.

        Access Level: Write

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_DeleteHealthCheck.html

        :stability: experimental
        '''
        return typing.cast("Route53", jsii.invoke(self, "toDeleteHealthCheck", []))

    @jsii.member(jsii_name="toDeleteHostedZone")
    def to_delete_hosted_zone(self) -> "Route53":
        '''(experimental) Grants permission to delete a hosted zone.

        Access Level: Write

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_DeleteHostedZone.html

        :stability: experimental
        '''
        return typing.cast("Route53", jsii.invoke(self, "toDeleteHostedZone", []))

    @jsii.member(jsii_name="toDeleteKeySigningKey")
    def to_delete_key_signing_key(self) -> "Route53":
        '''(experimental) Grants permission to delete a key-signing key.

        Access Level: Write

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_DeleteKeySigningKey.html

        :stability: experimental
        '''
        return typing.cast("Route53", jsii.invoke(self, "toDeleteKeySigningKey", []))

    @jsii.member(jsii_name="toDeleteQueryLoggingConfig")
    def to_delete_query_logging_config(self) -> "Route53":
        '''(experimental) Grants permission to delete a configuration for DNS query logging.

        Access Level: Write

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_DeleteQueryLoggingConfig.html

        :stability: experimental
        '''
        return typing.cast("Route53", jsii.invoke(self, "toDeleteQueryLoggingConfig", []))

    @jsii.member(jsii_name="toDeleteReusableDelegationSet")
    def to_delete_reusable_delegation_set(self) -> "Route53":
        '''(experimental) Grants permission to delete a reusable delegation set.

        Access Level: Write

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_DeleteReusableDelegationSet.html

        :stability: experimental
        '''
        return typing.cast("Route53", jsii.invoke(self, "toDeleteReusableDelegationSet", []))

    @jsii.member(jsii_name="toDeleteTrafficPolicy")
    def to_delete_traffic_policy(self) -> "Route53":
        '''(experimental) Grants permission to delete a traffic policy.

        Access Level: Write

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_DeleteTrafficPolicy.html

        :stability: experimental
        '''
        return typing.cast("Route53", jsii.invoke(self, "toDeleteTrafficPolicy", []))

    @jsii.member(jsii_name="toDeleteTrafficPolicyInstance")
    def to_delete_traffic_policy_instance(self) -> "Route53":
        '''(experimental) Grants permission to delete a traffic policy instance and all the records that Route 53 created when you created the instance.

        Access Level: Write

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_DeleteTrafficPolicyInstance.html

        :stability: experimental
        '''
        return typing.cast("Route53", jsii.invoke(self, "toDeleteTrafficPolicyInstance", []))

    @jsii.member(jsii_name="toDeleteVPCAssociationAuthorization")
    def to_delete_vpc_association_authorization(self) -> "Route53":
        '''(experimental) Grants permission to remove authorization for associating an Amazon Virtual Private Cloud with a Route 53 private hosted zone.

        Access Level: Write

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_DeleteVPCAssociationAuthorization.html

        :stability: experimental
        '''
        return typing.cast("Route53", jsii.invoke(self, "toDeleteVPCAssociationAuthorization", []))

    @jsii.member(jsii_name="toDisableHostedZoneDNSSEC")
    def to_disable_hosted_zone_dnssec(self) -> "Route53":
        '''(experimental) Grants permission to disable DNSSEC signing in a specific hosted zone.

        Access Level: Write

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_DisableHostedZoneDNSSEC.html

        :stability: experimental
        '''
        return typing.cast("Route53", jsii.invoke(self, "toDisableHostedZoneDNSSEC", []))

    @jsii.member(jsii_name="toDisassociateVPCFromHostedZone")
    def to_disassociate_vpc_from_hosted_zone(self) -> "Route53":
        '''(experimental) Grants permission to disassociate an Amazon Virtual Private Cloud from a Route 53 private hosted zone.

        Access Level: Write

        Dependent actions:

        - ec2:DescribeVpcs

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_DisassociateVPCFromHostedZone.html

        :stability: experimental
        '''
        return typing.cast("Route53", jsii.invoke(self, "toDisassociateVPCFromHostedZone", []))

    @jsii.member(jsii_name="toEnableHostedZoneDNSSEC")
    def to_enable_hosted_zone_dnssec(self) -> "Route53":
        '''(experimental) Grants permission to enable DNSSEC signing in a specific hosted zone.

        Access Level: Write

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_EnableHostedZoneDNSSEC.html

        :stability: experimental
        '''
        return typing.cast("Route53", jsii.invoke(self, "toEnableHostedZoneDNSSEC", []))

    @jsii.member(jsii_name="toGetAccountLimit")
    def to_get_account_limit(self) -> "Route53":
        '''(experimental) Grants permission to get the specified limit for the current account, for example, the maximum number of health checks that you can create using the account.

        Access Level: Read

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_GetAccountLimit.html

        :stability: experimental
        '''
        return typing.cast("Route53", jsii.invoke(self, "toGetAccountLimit", []))

    @jsii.member(jsii_name="toGetChange")
    def to_get_change(self) -> "Route53":
        '''(experimental) Grants permission to get the current status of a request to create, update, or delete one or more records.

        Access Level: List

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_GetChange.html

        :stability: experimental
        '''
        return typing.cast("Route53", jsii.invoke(self, "toGetChange", []))

    @jsii.member(jsii_name="toGetCheckerIpRanges")
    def to_get_checker_ip_ranges(self) -> "Route53":
        '''(experimental) Grants permission to get a list of the IP ranges that are used by Route 53 health checkers to check the health of your resources.

        Access Level: List

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_GetCheckerIpRanges.html

        :stability: experimental
        '''
        return typing.cast("Route53", jsii.invoke(self, "toGetCheckerIpRanges", []))

    @jsii.member(jsii_name="toGetDNSSEC")
    def to_get_dnssec(self) -> "Route53":
        '''(experimental) Grants permission to get information about DNSSEC for a specific hosted zone, including the key-signing keys in the hosted zone.

        Access Level: Read

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_GetDNSSEC.html

        :stability: experimental
        '''
        return typing.cast("Route53", jsii.invoke(self, "toGetDNSSEC", []))

    @jsii.member(jsii_name="toGetGeoLocation")
    def to_get_geo_location(self) -> "Route53":
        '''(experimental) Grants permission to get information about whether a specified geographic location is supported for Route 53 geolocation records.

        Access Level: List

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_GetGeoLocation.html

        :stability: experimental
        '''
        return typing.cast("Route53", jsii.invoke(self, "toGetGeoLocation", []))

    @jsii.member(jsii_name="toGetHealthCheck")
    def to_get_health_check(self) -> "Route53":
        '''(experimental) Grants permission to get information about a specified health check.

        Access Level: Read

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_GetHealthCheck.html

        :stability: experimental
        '''
        return typing.cast("Route53", jsii.invoke(self, "toGetHealthCheck", []))

    @jsii.member(jsii_name="toGetHealthCheckCount")
    def to_get_health_check_count(self) -> "Route53":
        '''(experimental) Grants permission to get the number of health checks that are associated with the current AWS account.

        Access Level: List

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_GetHealthCheckCount.html

        :stability: experimental
        '''
        return typing.cast("Route53", jsii.invoke(self, "toGetHealthCheckCount", []))

    @jsii.member(jsii_name="toGetHealthCheckLastFailureReason")
    def to_get_health_check_last_failure_reason(self) -> "Route53":
        '''(experimental) Grants permission to get the reason that a specified health check failed most recently.

        Access Level: List

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_GetHealthCheckLastFailureReason.html

        :stability: experimental
        '''
        return typing.cast("Route53", jsii.invoke(self, "toGetHealthCheckLastFailureReason", []))

    @jsii.member(jsii_name="toGetHealthCheckStatus")
    def to_get_health_check_status(self) -> "Route53":
        '''(experimental) Grants permission to get the status of a specified health check.

        Access Level: List

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_GetHealthCheckStatus.html

        :stability: experimental
        '''
        return typing.cast("Route53", jsii.invoke(self, "toGetHealthCheckStatus", []))

    @jsii.member(jsii_name="toGetHostedZone")
    def to_get_hosted_zone(self) -> "Route53":
        '''(experimental) Grants permission to get information about a specified hosted zone including the four name servers that Route 53 assigned to the hosted zone.

        Access Level: List

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_GetHostedZone.html

        :stability: experimental
        '''
        return typing.cast("Route53", jsii.invoke(self, "toGetHostedZone", []))

    @jsii.member(jsii_name="toGetHostedZoneCount")
    def to_get_hosted_zone_count(self) -> "Route53":
        '''(experimental) Grants permission to get the number of hosted zones that are associated with the current AWS account.

        Access Level: List

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_GetHostedZoneCount.html

        :stability: experimental
        '''
        return typing.cast("Route53", jsii.invoke(self, "toGetHostedZoneCount", []))

    @jsii.member(jsii_name="toGetHostedZoneLimit")
    def to_get_hosted_zone_limit(self) -> "Route53":
        '''(experimental) Grants permission to get the specified limit for a specified hosted zone.

        Access Level: Read

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_GetHostedZoneLimit.html

        :stability: experimental
        '''
        return typing.cast("Route53", jsii.invoke(self, "toGetHostedZoneLimit", []))

    @jsii.member(jsii_name="toGetQueryLoggingConfig")
    def to_get_query_logging_config(self) -> "Route53":
        '''(experimental) Grants permission to get information about a specified configuration for DNS query logging.

        Access Level: Read

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_GetQueryLoggingConfig.html

        :stability: experimental
        '''
        return typing.cast("Route53", jsii.invoke(self, "toGetQueryLoggingConfig", []))

    @jsii.member(jsii_name="toGetReusableDelegationSet")
    def to_get_reusable_delegation_set(self) -> "Route53":
        '''(experimental) Grants permission to get information about a specified reusable delegation set, including the four name servers that are assigned to the delegation set.

        Access Level: List

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_GetReusableDelegationSet.html

        :stability: experimental
        '''
        return typing.cast("Route53", jsii.invoke(self, "toGetReusableDelegationSet", []))

    @jsii.member(jsii_name="toGetReusableDelegationSetLimit")
    def to_get_reusable_delegation_set_limit(self) -> "Route53":
        '''(experimental) Grants permission to get the maximum number of hosted zones that you can associate with the specified reusable delegation set.

        Access Level: Read

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_GetReusableDelegationSetLimit.html

        :stability: experimental
        '''
        return typing.cast("Route53", jsii.invoke(self, "toGetReusableDelegationSetLimit", []))

    @jsii.member(jsii_name="toGetTrafficPolicy")
    def to_get_traffic_policy(self) -> "Route53":
        '''(experimental) Grants permission to get information about a specified traffic policy version.

        Access Level: Read

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_GetTrafficPolicy.html

        :stability: experimental
        '''
        return typing.cast("Route53", jsii.invoke(self, "toGetTrafficPolicy", []))

    @jsii.member(jsii_name="toGetTrafficPolicyInstance")
    def to_get_traffic_policy_instance(self) -> "Route53":
        '''(experimental) Grants permission to get information about a specified traffic policy instance.

        Access Level: Read

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_GetTrafficPolicyInstance.html

        :stability: experimental
        '''
        return typing.cast("Route53", jsii.invoke(self, "toGetTrafficPolicyInstance", []))

    @jsii.member(jsii_name="toGetTrafficPolicyInstanceCount")
    def to_get_traffic_policy_instance_count(self) -> "Route53":
        '''(experimental) Grants permission to get the number of traffic policy instances that are associated with the current AWS account.

        Access Level: Read

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_GetTrafficPolicyInstanceCount.html

        :stability: experimental
        '''
        return typing.cast("Route53", jsii.invoke(self, "toGetTrafficPolicyInstanceCount", []))

    @jsii.member(jsii_name="toListCidrBlocks")
    def to_list_cidr_blocks(self) -> "Route53":
        '''(experimental) Grants permission to get a list of the CIDR blocks within a specified CIDR collection.

        Access Level: List

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_ListCidrBlocks.html

        :stability: experimental
        '''
        return typing.cast("Route53", jsii.invoke(self, "toListCidrBlocks", []))

    @jsii.member(jsii_name="toListCidrCollections")
    def to_list_cidr_collections(self) -> "Route53":
        '''(experimental) Grants permission to get a list of the CIDR collections that are associated with the current AWS account.

        Access Level: List

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_ListCidrCollections.html

        :stability: experimental
        '''
        return typing.cast("Route53", jsii.invoke(self, "toListCidrCollections", []))

    @jsii.member(jsii_name="toListCidrLocations")
    def to_list_cidr_locations(self) -> "Route53":
        '''(experimental) Grants permission to get a list of the CIDR locations that belong to a specified CIDR collection.

        Access Level: List

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_ListCidrLocations.html

        :stability: experimental
        '''
        return typing.cast("Route53", jsii.invoke(self, "toListCidrLocations", []))

    @jsii.member(jsii_name="toListGeoLocations")
    def to_list_geo_locations(self) -> "Route53":
        '''(experimental) Grants permission to get a list of geographic locations that Route 53 supports for geolocation.

        Access Level: Read

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_ListGeoLocations.html

        :stability: experimental
        '''
        return typing.cast("Route53", jsii.invoke(self, "toListGeoLocations", []))

    @jsii.member(jsii_name="toListHealthChecks")
    def to_list_health_checks(self) -> "Route53":
        '''(experimental) Grants permission to get a list of the health checks that are associated with the current AWS account.

        Access Level: Read

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_ListHealthChecks.html

        :stability: experimental
        '''
        return typing.cast("Route53", jsii.invoke(self, "toListHealthChecks", []))

    @jsii.member(jsii_name="toListHostedZones")
    def to_list_hosted_zones(self) -> "Route53":
        '''(experimental) Grants permission to get a list of the public and private hosted zones that are associated with the current AWS account.

        Access Level: List

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_ListHostedZones.html

        :stability: experimental
        '''
        return typing.cast("Route53", jsii.invoke(self, "toListHostedZones", []))

    @jsii.member(jsii_name="toListHostedZonesByName")
    def to_list_hosted_zones_by_name(self) -> "Route53":
        '''(experimental) Grants permission to get a list of your hosted zones in lexicographic order.

        Hosted zones are sorted by name with the labels reversed, for example, com.example.www

        Access Level: List

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_ListHostedZonesByName.html

        :stability: experimental
        '''
        return typing.cast("Route53", jsii.invoke(self, "toListHostedZonesByName", []))

    @jsii.member(jsii_name="toListHostedZonesByVPC")
    def to_list_hosted_zones_by_vpc(self) -> "Route53":
        '''(experimental) Grants permission to get a list of all the private hosted zones that a specified VPC is associated with.

        Access Level: List

        Dependent actions:

        - ec2:DescribeVpcs

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_ListHostedZonesByVPC.html

        :stability: experimental
        '''
        return typing.cast("Route53", jsii.invoke(self, "toListHostedZonesByVPC", []))

    @jsii.member(jsii_name="toListQueryLoggingConfigs")
    def to_list_query_logging_configs(self) -> "Route53":
        '''(experimental) Grants permission to list the configurations for DNS query logging that are associated with the current AWS account or the configuration that is associated with a specified hosted zone.

        Access Level: List

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_ListQueryLoggingConfigs.html

        :stability: experimental
        '''
        return typing.cast("Route53", jsii.invoke(self, "toListQueryLoggingConfigs", []))

    @jsii.member(jsii_name="toListResourceRecordSets")
    def to_list_resource_record_sets(self) -> "Route53":
        '''(experimental) Grants permission to list the records in a specified hosted zone.

        Access Level: List

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_ListResourceRecordSets.html

        :stability: experimental
        '''
        return typing.cast("Route53", jsii.invoke(self, "toListResourceRecordSets", []))

    @jsii.member(jsii_name="toListReusableDelegationSets")
    def to_list_reusable_delegation_sets(self) -> "Route53":
        '''(experimental) Grants permission to list the reusable delegation sets that are associated with the current AWS account.

        Access Level: Read

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_ListReusableDelegationSets.html

        :stability: experimental
        '''
        return typing.cast("Route53", jsii.invoke(self, "toListReusableDelegationSets", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Route53":
        '''(experimental) Grants permission to list tags for one health check or hosted zone.

        Access Level: Read

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("Route53", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toListTagsForResources")
    def to_list_tags_for_resources(self) -> "Route53":
        '''(experimental) Grants permission to list tags for up to 10 health checks or hosted zones.

        Access Level: Read

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_ListTagsForResources.html

        :stability: experimental
        '''
        return typing.cast("Route53", jsii.invoke(self, "toListTagsForResources", []))

    @jsii.member(jsii_name="toListTrafficPolicies")
    def to_list_traffic_policies(self) -> "Route53":
        '''(experimental) Grants permission to get information about the latest version for every traffic policy that is associated with the current AWS account.

        Policies are listed in the order in which they were created

        Access Level: List

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_ListTrafficPolicies.html

        :stability: experimental
        '''
        return typing.cast("Route53", jsii.invoke(self, "toListTrafficPolicies", []))

    @jsii.member(jsii_name="toListTrafficPolicyInstances")
    def to_list_traffic_policy_instances(self) -> "Route53":
        '''(experimental) Grants permission to get information about the traffic policy instances that you created by using the current AWS account.

        Access Level: Read

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_ListTrafficPolicyInstances.html

        :stability: experimental
        '''
        return typing.cast("Route53", jsii.invoke(self, "toListTrafficPolicyInstances", []))

    @jsii.member(jsii_name="toListTrafficPolicyInstancesByHostedZone")
    def to_list_traffic_policy_instances_by_hosted_zone(self) -> "Route53":
        '''(experimental) Grants permission to get information about the traffic policy instances that you created in a specified hosted zone.

        Access Level: List

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_ListTrafficPolicyInstancesByHostedZone.html

        :stability: experimental
        '''
        return typing.cast("Route53", jsii.invoke(self, "toListTrafficPolicyInstancesByHostedZone", []))

    @jsii.member(jsii_name="toListTrafficPolicyInstancesByPolicy")
    def to_list_traffic_policy_instances_by_policy(self) -> "Route53":
        '''(experimental) Grants permission to get information about the traffic policy instances that you created using a specified traffic policy version.

        Access Level: List

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_ListTrafficPolicyInstancesByPolicy.html

        :stability: experimental
        '''
        return typing.cast("Route53", jsii.invoke(self, "toListTrafficPolicyInstancesByPolicy", []))

    @jsii.member(jsii_name="toListTrafficPolicyVersions")
    def to_list_traffic_policy_versions(self) -> "Route53":
        '''(experimental) Grants permission to get information about all the versions for a specified traffic policy.

        Access Level: List

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_ListTrafficPolicyVersions.html

        :stability: experimental
        '''
        return typing.cast("Route53", jsii.invoke(self, "toListTrafficPolicyVersions", []))

    @jsii.member(jsii_name="toListVPCAssociationAuthorizations")
    def to_list_vpc_association_authorizations(self) -> "Route53":
        '''(experimental) Grants permission to get a list of the VPCs that were created by other accounts and that can be associated with a specified hosted zone.

        Access Level: List

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_ListVPCAssociationAuthorizations.html

        :stability: experimental
        '''
        return typing.cast("Route53", jsii.invoke(self, "toListVPCAssociationAuthorizations", []))

    @jsii.member(jsii_name="toTestDNSAnswer")
    def to_test_dns_answer(self) -> "Route53":
        '''(experimental) Grants permission to get the value that Route 53 returns in response to a DNS query for a specified record name and type.

        Access Level: Read

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_TestDNSAnswer.html

        :stability: experimental
        '''
        return typing.cast("Route53", jsii.invoke(self, "toTestDNSAnswer", []))

    @jsii.member(jsii_name="toUpdateHealthCheck")
    def to_update_health_check(self) -> "Route53":
        '''(experimental) Grants permission to update an existing health check.

        Access Level: Write

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_UpdateHealthCheck.html

        :stability: experimental
        '''
        return typing.cast("Route53", jsii.invoke(self, "toUpdateHealthCheck", []))

    @jsii.member(jsii_name="toUpdateHostedZoneComment")
    def to_update_hosted_zone_comment(self) -> "Route53":
        '''(experimental) Grants permission to update the comment for a specified hosted zone.

        Access Level: Write

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_UpdateHostedZoneComment.html

        :stability: experimental
        '''
        return typing.cast("Route53", jsii.invoke(self, "toUpdateHostedZoneComment", []))

    @jsii.member(jsii_name="toUpdateTrafficPolicyComment")
    def to_update_traffic_policy_comment(self) -> "Route53":
        '''(experimental) Grants permission to update the comment for a specified traffic policy version.

        Access Level: Write

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_UpdateTrafficPolicyComment.html

        :stability: experimental
        '''
        return typing.cast("Route53", jsii.invoke(self, "toUpdateTrafficPolicyComment", []))

    @jsii.member(jsii_name="toUpdateTrafficPolicyInstance")
    def to_update_traffic_policy_instance(self) -> "Route53":
        '''(experimental) Grants permission to update the records in a specified hosted zone that were created based on the settings in a specified traffic policy version.

        Access Level: Write

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_UpdateTrafficPolicyInstance.html

        :stability: experimental
        '''
        return typing.cast("Route53", jsii.invoke(self, "toUpdateTrafficPolicyInstance", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5d200a66d5c3218c329658de13ed0f0d2a3fb4480d65e530683c8fcbc7a41bb2)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__565c9d4f740b94fbd07c18befff8625b2e877773c83c5d8855524efaa2313073)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Route53RecoveryCluster(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Route53RecoveryCluster",
):
    '''(experimental) Statement provider for service `route53-recovery-cluster <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonroute53recoverycluster.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `route53-recovery-cluster <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonroute53recoverycluster.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="ifAllowSafetyRulesOverrides")
    def if_allow_safety_rules_overrides(
        self,
        value: typing.Optional[builtins.bool] = None,
    ) -> "Route53RecoveryCluster":
        '''(experimental) Override safety rules to allow routing control state updates.

        https://docs.aws.amazon.com/routing-control/latest/APIReference/API_UpdateRoutingControlState.html

        Applies to actions:

        - .toUpdateRoutingControlState()
        - .toUpdateRoutingControlStates()

        :param value: ``true`` or ``false``. **Default:** ``true``

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2e0519f7e7dbd84421297c1da3d7794d5470796b59a788d62a4b1596c6c77dbc)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast("Route53RecoveryCluster", jsii.invoke(self, "ifAllowSafetyRulesOverrides", [value]))

    @jsii.member(jsii_name="onRoutingcontrol")
    def on_routingcontrol(
        self,
        control_panel_id: builtins.str,
        routing_control_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Route53RecoveryCluster":
        '''(experimental) Adds a resource of type routingcontrol to the statement.

        https://docs.aws.amazon.com/recovery-cluster/latest/api/routingcontrol.html

        :param control_panel_id: - Identifier for the controlPanelId.
        :param routing_control_id: - Identifier for the routingControlId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d252a2e09a7dafa165edfe9315f57509d8e4a2e632bd58e926337018b14899ee)
            check_type(argname="argument control_panel_id", value=control_panel_id, expected_type=type_hints["control_panel_id"])
            check_type(argname="argument routing_control_id", value=routing_control_id, expected_type=type_hints["routing_control_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Route53RecoveryCluster", jsii.invoke(self, "onRoutingcontrol", [control_panel_id, routing_control_id, account, partition]))

    @jsii.member(jsii_name="toGetRoutingControlState")
    def to_get_routing_control_state(self) -> "Route53RecoveryCluster":
        '''(experimental) Grants permission to get a routing control state.

        Access Level: Read

        https://docs.aws.amazon.com/routing-control/latest/APIReference/API_GetRoutingControlState.html

        :stability: experimental
        '''
        return typing.cast("Route53RecoveryCluster", jsii.invoke(self, "toGetRoutingControlState", []))

    @jsii.member(jsii_name="toListRoutingControls")
    def to_list_routing_controls(self) -> "Route53RecoveryCluster":
        '''(experimental) Grants permission to list routing controls.

        Access Level: Read

        https://docs.aws.amazon.com/routing-control/latest/APIReference/API_ListRoutingControls.html

        :stability: experimental
        '''
        return typing.cast("Route53RecoveryCluster", jsii.invoke(self, "toListRoutingControls", []))

    @jsii.member(jsii_name="toUpdateRoutingControlState")
    def to_update_routing_control_state(self) -> "Route53RecoveryCluster":
        '''(experimental) Grants permission to update a routing control state.

        Access Level: Write

        Possible conditions:

        - .ifAllowSafetyRulesOverrides()

        https://docs.aws.amazon.com/routing-control/latest/APIReference/API_UpdateRoutingControlState.html

        :stability: experimental
        '''
        return typing.cast("Route53RecoveryCluster", jsii.invoke(self, "toUpdateRoutingControlState", []))

    @jsii.member(jsii_name="toUpdateRoutingControlStates")
    def to_update_routing_control_states(self) -> "Route53RecoveryCluster":
        '''(experimental) Grants permission to update a batch of routing control states.

        Access Level: Write

        Possible conditions:

        - .ifAllowSafetyRulesOverrides()

        https://docs.aws.amazon.com/routing-control/latest/APIReference/API_UpdateRoutingControlStates.html

        :stability: experimental
        '''
        return typing.cast("Route53RecoveryCluster", jsii.invoke(self, "toUpdateRoutingControlStates", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__529fc8dcb43a0f21d60ec62c47f22af465776e94fc88a4545496be77f0bbf727)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__06e16804e38778fd44644453b433f9bae8bc9f3fb566072e6e0d2673709dcfc7)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Route53RecoveryControlConfig(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Route53RecoveryControlConfig",
):
    '''(experimental) Statement provider for service `route53-recovery-control-config <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonroute53recoverycontrols.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `route53-recovery-control-config <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonroute53recoverycontrols.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onCluster")
    def on_cluster(
        self,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Route53RecoveryControlConfig":
        '''(experimental) Adds a resource of type cluster to the statement.

        https://docs.aws.amazon.com/recovery-cluster/latest/api/cluster.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7a183c98d4596bc6b834842512840eb4736c366439238b489bf2bdddeb60cd03)
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Route53RecoveryControlConfig", jsii.invoke(self, "onCluster", [resource_id, account, partition]))

    @jsii.member(jsii_name="onControlpanel")
    def on_controlpanel(
        self,
        control_panel_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Route53RecoveryControlConfig":
        '''(experimental) Adds a resource of type controlpanel to the statement.

        https://docs.aws.amazon.com/recovery-cluster/latest/api/controlpanel.html

        :param control_panel_id: - Identifier for the controlPanelId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__aaf720a5d33905dbfc4f3d858cfb9b61f97657bba8d55a8e499445004d23cd54)
            check_type(argname="argument control_panel_id", value=control_panel_id, expected_type=type_hints["control_panel_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Route53RecoveryControlConfig", jsii.invoke(self, "onControlpanel", [control_panel_id, account, partition]))

    @jsii.member(jsii_name="onRoutingcontrol")
    def on_routingcontrol(
        self,
        control_panel_id: builtins.str,
        routing_control_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Route53RecoveryControlConfig":
        '''(experimental) Adds a resource of type routingcontrol to the statement.

        https://docs.aws.amazon.com/recovery-cluster/latest/api/routingcontrol.html

        :param control_panel_id: - Identifier for the controlPanelId.
        :param routing_control_id: - Identifier for the routingControlId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f49338e59cbf4d74bba3184c425a7c6be83a3f1c26c6a2e38c235e00a15e623e)
            check_type(argname="argument control_panel_id", value=control_panel_id, expected_type=type_hints["control_panel_id"])
            check_type(argname="argument routing_control_id", value=routing_control_id, expected_type=type_hints["routing_control_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Route53RecoveryControlConfig", jsii.invoke(self, "onRoutingcontrol", [control_panel_id, routing_control_id, account, partition]))

    @jsii.member(jsii_name="onSafetyrule")
    def on_safetyrule(
        self,
        control_panel_id: builtins.str,
        safety_rule_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Route53RecoveryControlConfig":
        '''(experimental) Adds a resource of type safetyrule to the statement.

        https://docs.aws.amazon.com/recovery-cluster/latest/api/safetyrule.html

        :param control_panel_id: - Identifier for the controlPanelId.
        :param safety_rule_id: - Identifier for the safetyRuleId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__24f5a890ec032ce91b17d8147649be626c3d761d1a0a6fc1ec2169c552d23576)
            check_type(argname="argument control_panel_id", value=control_panel_id, expected_type=type_hints["control_panel_id"])
            check_type(argname="argument safety_rule_id", value=safety_rule_id, expected_type=type_hints["safety_rule_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Route53RecoveryControlConfig", jsii.invoke(self, "onSafetyrule", [control_panel_id, safety_rule_id, account, partition]))

    @jsii.member(jsii_name="toCreateCluster")
    def to_create_cluster(self) -> "Route53RecoveryControlConfig":
        '''(experimental) Grants permission to create a cluster.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/recovery-cluster/latest/api/cluster.html

        :stability: experimental
        '''
        return typing.cast("Route53RecoveryControlConfig", jsii.invoke(self, "toCreateCluster", []))

    @jsii.member(jsii_name="toCreateControlPanel")
    def to_create_control_panel(self) -> "Route53RecoveryControlConfig":
        '''(experimental) Grants permission to create a control panel.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/recovery-cluster/latest/api/controlpanel.html

        :stability: experimental
        '''
        return typing.cast("Route53RecoveryControlConfig", jsii.invoke(self, "toCreateControlPanel", []))

    @jsii.member(jsii_name="toCreateRoutingControl")
    def to_create_routing_control(self) -> "Route53RecoveryControlConfig":
        '''(experimental) Grants permission to create a routing control.

        Access Level: Write

        https://docs.aws.amazon.com/recovery-cluster/latest/api/routingcontrol.html

        :stability: experimental
        '''
        return typing.cast("Route53RecoveryControlConfig", jsii.invoke(self, "toCreateRoutingControl", []))

    @jsii.member(jsii_name="toCreateSafetyRule")
    def to_create_safety_rule(self) -> "Route53RecoveryControlConfig":
        '''(experimental) Grants permission to create a safety rule.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/recovery-cluster/latest/api/safetyrule.html

        :stability: experimental
        '''
        return typing.cast("Route53RecoveryControlConfig", jsii.invoke(self, "toCreateSafetyRule", []))

    @jsii.member(jsii_name="toDeleteCluster")
    def to_delete_cluster(self) -> "Route53RecoveryControlConfig":
        '''(experimental) Grants permission to delete a cluster.

        Access Level: Write

        https://docs.aws.amazon.com/recovery-cluster/latest/api/cluster-clusterarn.html

        :stability: experimental
        '''
        return typing.cast("Route53RecoveryControlConfig", jsii.invoke(self, "toDeleteCluster", []))

    @jsii.member(jsii_name="toDeleteControlPanel")
    def to_delete_control_panel(self) -> "Route53RecoveryControlConfig":
        '''(experimental) Grants permission to delete a control panel.

        Access Level: Write

        https://docs.aws.amazon.com/recovery-cluster/latest/api/controlpanel-controlpanelarn.html

        :stability: experimental
        '''
        return typing.cast("Route53RecoveryControlConfig", jsii.invoke(self, "toDeleteControlPanel", []))

    @jsii.member(jsii_name="toDeleteRoutingControl")
    def to_delete_routing_control(self) -> "Route53RecoveryControlConfig":
        '''(experimental) Grants permission to delete a routing control.

        Access Level: Write

        https://docs.aws.amazon.com/recovery-cluster/latest/api/routingcontrol-routingcontrolarn.html

        :stability: experimental
        '''
        return typing.cast("Route53RecoveryControlConfig", jsii.invoke(self, "toDeleteRoutingControl", []))

    @jsii.member(jsii_name="toDeleteSafetyRule")
    def to_delete_safety_rule(self) -> "Route53RecoveryControlConfig":
        '''(experimental) Grants permission to delete a safety rule.

        Access Level: Write

        https://docs.aws.amazon.com/recovery-cluster/latest/api/safetyrule-safetyrulearn.html

        :stability: experimental
        '''
        return typing.cast("Route53RecoveryControlConfig", jsii.invoke(self, "toDeleteSafetyRule", []))

    @jsii.member(jsii_name="toDescribeCluster")
    def to_describe_cluster(self) -> "Route53RecoveryControlConfig":
        '''(experimental) Grants permission to describe a cluster.

        Access Level: Read

        https://docs.aws.amazon.com/recovery-cluster/latest/api/cluster-clusterarn.html

        :stability: experimental
        '''
        return typing.cast("Route53RecoveryControlConfig", jsii.invoke(self, "toDescribeCluster", []))

    @jsii.member(jsii_name="toDescribeControlPanel")
    def to_describe_control_panel(self) -> "Route53RecoveryControlConfig":
        '''(experimental) Grants permission to describe a control panel.

        Access Level: Read

        https://docs.aws.amazon.com/recovery-cluster/latest/api/controlpanel-controlpanelarn.html

        :stability: experimental
        '''
        return typing.cast("Route53RecoveryControlConfig", jsii.invoke(self, "toDescribeControlPanel", []))

    @jsii.member(jsii_name="toDescribeRoutingControl")
    def to_describe_routing_control(self) -> "Route53RecoveryControlConfig":
        '''(experimental) Grants permission to describe a routing control.

        Access Level: Read

        https://docs.aws.amazon.com/recovery-cluster/latest/api/routingcontrol-routingcontrolarn.html

        :stability: experimental
        '''
        return typing.cast("Route53RecoveryControlConfig", jsii.invoke(self, "toDescribeRoutingControl", []))

    @jsii.member(jsii_name="toDescribeRoutingControlByName")
    def to_describe_routing_control_by_name(self) -> "Route53RecoveryControlConfig":
        '''(experimental) Grants permission to describe a routing control.

        Access Level: Read

        https://docs.aws.amazon.com/recovery-cluster/latest/api/routingcontrol-routingcontrolarn.html

        :stability: experimental
        '''
        return typing.cast("Route53RecoveryControlConfig", jsii.invoke(self, "toDescribeRoutingControlByName", []))

    @jsii.member(jsii_name="toDescribeSafetyRule")
    def to_describe_safety_rule(self) -> "Route53RecoveryControlConfig":
        '''(experimental) Grants permission to describe a safety rule.

        Access Level: Read

        https://docs.aws.amazon.com/recovery-cluster/latest/api/safetyrule-safetyrulearn.html

        :stability: experimental
        '''
        return typing.cast("Route53RecoveryControlConfig", jsii.invoke(self, "toDescribeSafetyRule", []))

    @jsii.member(jsii_name="toListAssociatedRoute53HealthChecks")
    def to_list_associated_route53_health_checks(
        self,
    ) -> "Route53RecoveryControlConfig":
        '''(experimental) Grants permission to list associated Route 53 health checks.

        Access Level: List

        https://docs.aws.amazon.com/recovery-cluster/latest/api/routingcontrol-routingcontrolarn-associatedroute53healthchecks.html

        :stability: experimental
        '''
        return typing.cast("Route53RecoveryControlConfig", jsii.invoke(self, "toListAssociatedRoute53HealthChecks", []))

    @jsii.member(jsii_name="toListClusters")
    def to_list_clusters(self) -> "Route53RecoveryControlConfig":
        '''(experimental) Grants permission to list clusters.

        Access Level: Read

        https://docs.aws.amazon.com/recovery-cluster/latest/api/cluster.html

        :stability: experimental
        '''
        return typing.cast("Route53RecoveryControlConfig", jsii.invoke(self, "toListClusters", []))

    @jsii.member(jsii_name="toListControlPanels")
    def to_list_control_panels(self) -> "Route53RecoveryControlConfig":
        '''(experimental) Grants permission to list control panels.

        Access Level: Read

        https://docs.aws.amazon.com/recovery-cluster/latest/api/controlpanels.html

        :stability: experimental
        '''
        return typing.cast("Route53RecoveryControlConfig", jsii.invoke(self, "toListControlPanels", []))

    @jsii.member(jsii_name="toListRoutingControls")
    def to_list_routing_controls(self) -> "Route53RecoveryControlConfig":
        '''(experimental) Grants permission to list routing controls.

        Access Level: Read

        https://docs.aws.amazon.com/recovery-cluster/latest/api/controlpanel-controlpanelarn-routingcontrols.html

        :stability: experimental
        '''
        return typing.cast("Route53RecoveryControlConfig", jsii.invoke(self, "toListRoutingControls", []))

    @jsii.member(jsii_name="toListSafetyRules")
    def to_list_safety_rules(self) -> "Route53RecoveryControlConfig":
        '''(experimental) Grants permission to list safety rules.

        Access Level: Read

        https://docs.aws.amazon.com/recovery-cluster/latest/api/controlpanel-controlpanelarn-safetyrules.html

        :stability: experimental
        '''
        return typing.cast("Route53RecoveryControlConfig", jsii.invoke(self, "toListSafetyRules", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Route53RecoveryControlConfig":
        '''(experimental) Grants permission to list tags for a resource.

        Access Level: Read

        https://docs.aws.amazon.com/recovery-cluster/latest/api/tags-resource-arn.html

        :stability: experimental
        '''
        return typing.cast("Route53RecoveryControlConfig", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Route53RecoveryControlConfig":
        '''(experimental) Grants permission to tag a resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/recovery-cluster/latest/api/tags-resource-arn.html

        :stability: experimental
        '''
        return typing.cast("Route53RecoveryControlConfig", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Route53RecoveryControlConfig":
        '''(experimental) Grants permission to remove tags from a resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/recovery-cluster/latest/api/tags-resource-arn.html

        :stability: experimental
        '''
        return typing.cast("Route53RecoveryControlConfig", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateControlPanel")
    def to_update_control_panel(self) -> "Route53RecoveryControlConfig":
        '''(experimental) Grants permission to update a cluster.

        Access Level: Write

        https://docs.aws.amazon.com/recovery-cluster/latest/api/controlpanel.html

        :stability: experimental
        '''
        return typing.cast("Route53RecoveryControlConfig", jsii.invoke(self, "toUpdateControlPanel", []))

    @jsii.member(jsii_name="toUpdateRoutingControl")
    def to_update_routing_control(self) -> "Route53RecoveryControlConfig":
        '''(experimental) Grants permission to update a routing control.

        Access Level: Write

        https://docs.aws.amazon.com/recovery-cluster/latest/api/controlpanel-controlpanelarn-routingcontrols.html

        :stability: experimental
        '''
        return typing.cast("Route53RecoveryControlConfig", jsii.invoke(self, "toUpdateRoutingControl", []))

    @jsii.member(jsii_name="toUpdateSafetyRule")
    def to_update_safety_rule(self) -> "Route53RecoveryControlConfig":
        '''(experimental) Grants permission to update a safety rule.

        Access Level: Write

        https://docs.aws.amazon.com/recovery-cluster/latest/api/safetyrule.html

        :stability: experimental
        '''
        return typing.cast("Route53RecoveryControlConfig", jsii.invoke(self, "toUpdateSafetyRule", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1caa508660f442029f84e0dedfb663a558232622ea6897079144f8cae4b95049)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7c937712f4d5a60797925925340dfe6230a734ea29868b4ecc47587c4ff0b2c8)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Route53RecoveryReadiness(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Route53RecoveryReadiness",
):
    '''(experimental) Statement provider for service `route53-recovery-readiness <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonroute53recoveryreadiness.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `route53-recovery-readiness <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonroute53recoveryreadiness.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onCell")
    def on_cell(
        self,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Route53RecoveryReadiness":
        '''(experimental) Adds a resource of type cell to the statement.

        https://docs.aws.amazon.com/r53recovery/latest/dg/recovery-readiness.recovery-groups.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__83ebcc6262c74f89f9c6073bb7eb1a538a95f8273e95b14a5de6f9888a9a4b2b)
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Route53RecoveryReadiness", jsii.invoke(self, "onCell", [resource_id, account, partition]))

    @jsii.member(jsii_name="onReadinesscheck")
    def on_readinesscheck(
        self,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Route53RecoveryReadiness":
        '''(experimental) Adds a resource of type readinesscheck to the statement.

        https://docs.aws.amazon.com/r53recovery/latest/dg/recovery-readiness.readiness-checks.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1850c7041a58e49989ea80ead9e8968d78f42513fef32194546853ba6317b9a7)
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Route53RecoveryReadiness", jsii.invoke(self, "onReadinesscheck", [resource_id, account, partition]))

    @jsii.member(jsii_name="onRecoverygroup")
    def on_recoverygroup(
        self,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Route53RecoveryReadiness":
        '''(experimental) Adds a resource of type recoverygroup to the statement.

        https://docs.aws.amazon.com/r53recovery/latest/dg/recovery-readiness.recovery-groups.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6dd88841858aeccfbb8188488fe236ccfab5a5f9f9c4e4d5c73f9e5284deb40b)
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Route53RecoveryReadiness", jsii.invoke(self, "onRecoverygroup", [resource_id, account, partition]))

    @jsii.member(jsii_name="onResourceset")
    def on_resourceset(
        self,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Route53RecoveryReadiness":
        '''(experimental) Adds a resource of type resourceset to the statement.

        https://docs.aws.amazon.com/r53recovery/latest/dg/recovery-readiness.readiness-checks.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__93382760b057c4bbcdb06776a242e2e0ad947fe1c936e65755aec039e29ff7c1)
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Route53RecoveryReadiness", jsii.invoke(self, "onResourceset", [resource_id, account, partition]))

    @jsii.member(jsii_name="toCreateCell")
    def to_create_cell(self) -> "Route53RecoveryReadiness":
        '''(experimental) Grants permission to create a new cell.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/recovery-readiness/latest/api/cells.html

        :stability: experimental
        '''
        return typing.cast("Route53RecoveryReadiness", jsii.invoke(self, "toCreateCell", []))

    @jsii.member(jsii_name="toCreateCrossAccountAuthorization")
    def to_create_cross_account_authorization(self) -> "Route53RecoveryReadiness":
        '''(experimental) Grants permission to create a cross account authorization.

        Access Level: Write

        https://docs.aws.amazon.com/recovery-readiness/latest/api/crossaccountauthorizations.html

        :stability: experimental
        '''
        return typing.cast("Route53RecoveryReadiness", jsii.invoke(self, "toCreateCrossAccountAuthorization", []))

    @jsii.member(jsii_name="toCreateReadinessCheck")
    def to_create_readiness_check(self) -> "Route53RecoveryReadiness":
        '''(experimental) Grants permission to create a readiness check.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/recovery-readiness/latest/api/readinesschecks.html

        :stability: experimental
        '''
        return typing.cast("Route53RecoveryReadiness", jsii.invoke(self, "toCreateReadinessCheck", []))

    @jsii.member(jsii_name="toCreateRecoveryGroup")
    def to_create_recovery_group(self) -> "Route53RecoveryReadiness":
        '''(experimental) Grants permission to create a recovery group.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/recovery-readiness/latest/api/recoverygroups.html

        :stability: experimental
        '''
        return typing.cast("Route53RecoveryReadiness", jsii.invoke(self, "toCreateRecoveryGroup", []))

    @jsii.member(jsii_name="toCreateResourceSet")
    def to_create_resource_set(self) -> "Route53RecoveryReadiness":
        '''(experimental) Grants permission to create a resource set.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/recovery-readiness/latest/api/resourcesets.html

        :stability: experimental
        '''
        return typing.cast("Route53RecoveryReadiness", jsii.invoke(self, "toCreateResourceSet", []))

    @jsii.member(jsii_name="toDeleteCell")
    def to_delete_cell(self) -> "Route53RecoveryReadiness":
        '''(experimental) Grants permission to delete a cell.

        Access Level: Write

        https://docs.aws.amazon.com/recovery-readiness/latest/api/cells-cellname.html

        :stability: experimental
        '''
        return typing.cast("Route53RecoveryReadiness", jsii.invoke(self, "toDeleteCell", []))

    @jsii.member(jsii_name="toDeleteCrossAccountAuthorization")
    def to_delete_cross_account_authorization(self) -> "Route53RecoveryReadiness":
        '''(experimental) Grants permission to delete a cross account authorization.

        Access Level: Write

        https://docs.aws.amazon.com/recovery-readiness/latest/api/crossaccountauthorizations-crossaccountauthorization.html

        :stability: experimental
        '''
        return typing.cast("Route53RecoveryReadiness", jsii.invoke(self, "toDeleteCrossAccountAuthorization", []))

    @jsii.member(jsii_name="toDeleteReadinessCheck")
    def to_delete_readiness_check(self) -> "Route53RecoveryReadiness":
        '''(experimental) Grants permission to delete a readiness check.

        Access Level: Write

        https://docs.aws.amazon.com/recovery-readiness/latest/api/readinesschecks-readinesscheckname.html

        :stability: experimental
        '''
        return typing.cast("Route53RecoveryReadiness", jsii.invoke(self, "toDeleteReadinessCheck", []))

    @jsii.member(jsii_name="toDeleteRecoveryGroup")
    def to_delete_recovery_group(self) -> "Route53RecoveryReadiness":
        '''(experimental) Grants permission to delete a recovery group.

        Access Level: Write

        https://docs.aws.amazon.com/recovery-readiness/latest/api/recoverygroups-recoverygroupname.html

        :stability: experimental
        '''
        return typing.cast("Route53RecoveryReadiness", jsii.invoke(self, "toDeleteRecoveryGroup", []))

    @jsii.member(jsii_name="toDeleteResourceSet")
    def to_delete_resource_set(self) -> "Route53RecoveryReadiness":
        '''(experimental) Grants permission to delete a resource set.

        Access Level: Write

        https://docs.aws.amazon.com/recovery-readiness/latest/api/resourcesets-resourcesetname.html

        :stability: experimental
        '''
        return typing.cast("Route53RecoveryReadiness", jsii.invoke(self, "toDeleteResourceSet", []))

    @jsii.member(jsii_name="toGetArchitectureRecommendations")
    def to_get_architecture_recommendations(self) -> "Route53RecoveryReadiness":
        '''(experimental) Grants permission to get architecture recommendations for a recovery group.

        Access Level: Read

        https://docs.aws.amazon.com/recovery-readiness/latest/api/recoverygroups-recoverygroupname-architecturerecommendations.html

        :stability: experimental
        '''
        return typing.cast("Route53RecoveryReadiness", jsii.invoke(self, "toGetArchitectureRecommendations", []))

    @jsii.member(jsii_name="toGetCell")
    def to_get_cell(self) -> "Route53RecoveryReadiness":
        '''(experimental) Grants permission to get information about a cell.

        Access Level: Read

        https://docs.aws.amazon.com/recovery-readiness/latest/api/cells-cellname.html

        :stability: experimental
        '''
        return typing.cast("Route53RecoveryReadiness", jsii.invoke(self, "toGetCell", []))

    @jsii.member(jsii_name="toGetCellReadinessSummary")
    def to_get_cell_readiness_summary(self) -> "Route53RecoveryReadiness":
        '''(experimental) Grants permission to get a readiness summary for a cell.

        Access Level: Read

        https://docs.aws.amazon.com/recovery-readiness/latest/api/cellreadiness-cellname.html

        :stability: experimental
        '''
        return typing.cast("Route53RecoveryReadiness", jsii.invoke(self, "toGetCellReadinessSummary", []))

    @jsii.member(jsii_name="toGetReadinessCheck")
    def to_get_readiness_check(self) -> "Route53RecoveryReadiness":
        '''(experimental) Grants permission to get information about a readiness check.

        Access Level: Read

        https://docs.aws.amazon.com/recovery-readiness/latest/api/readinesschecks-readinesscheckname.html

        :stability: experimental
        '''
        return typing.cast("Route53RecoveryReadiness", jsii.invoke(self, "toGetReadinessCheck", []))

    @jsii.member(jsii_name="toGetReadinessCheckResourceStatus")
    def to_get_readiness_check_resource_status(self) -> "Route53RecoveryReadiness":
        '''(experimental) Grants permission to get the readiness status for an individual resource.

        Access Level: Read

        https://docs.aws.amazon.com/recovery-readiness/latest/api/readinesschecks-readinesscheckname-resource-resourceidentifier-status.html

        :stability: experimental
        '''
        return typing.cast("Route53RecoveryReadiness", jsii.invoke(self, "toGetReadinessCheckResourceStatus", []))

    @jsii.member(jsii_name="toGetReadinessCheckStatus")
    def to_get_readiness_check_status(self) -> "Route53RecoveryReadiness":
        '''(experimental) Grants permission to get the status of a readiness check (for a resource set).

        Access Level: Read

        https://docs.aws.amazon.com/recovery-readiness/latest/api/readinesschecks-readinesscheckname-status.html

        :stability: experimental
        '''
        return typing.cast("Route53RecoveryReadiness", jsii.invoke(self, "toGetReadinessCheckStatus", []))

    @jsii.member(jsii_name="toGetRecoveryGroup")
    def to_get_recovery_group(self) -> "Route53RecoveryReadiness":
        '''(experimental) Grants permission to get information about a recovery group.

        Access Level: Read

        https://docs.aws.amazon.com/recovery-readiness/latest/api/recoverygroups-recoverygroupname.html

        :stability: experimental
        '''
        return typing.cast("Route53RecoveryReadiness", jsii.invoke(self, "toGetRecoveryGroup", []))

    @jsii.member(jsii_name="toGetRecoveryGroupReadinessSummary")
    def to_get_recovery_group_readiness_summary(self) -> "Route53RecoveryReadiness":
        '''(experimental) Grants permission to get a readiness summary for a recovery group.

        Access Level: Read

        https://docs.aws.amazon.com/recovery-readiness/latest/api/recoverygroupreadiness-recoverygroupname.html

        :stability: experimental
        '''
        return typing.cast("Route53RecoveryReadiness", jsii.invoke(self, "toGetRecoveryGroupReadinessSummary", []))

    @jsii.member(jsii_name="toGetResourceSet")
    def to_get_resource_set(self) -> "Route53RecoveryReadiness":
        '''(experimental) Grants permission to get information about a resource set.

        Access Level: Read

        https://docs.aws.amazon.com/recovery-readiness/latest/api/resourcesets-resourcesetname.html

        :stability: experimental
        '''
        return typing.cast("Route53RecoveryReadiness", jsii.invoke(self, "toGetResourceSet", []))

    @jsii.member(jsii_name="toListCells")
    def to_list_cells(self) -> "Route53RecoveryReadiness":
        '''(experimental) Grants permission to list cells.

        Access Level: Read

        https://docs.aws.amazon.com/recovery-readiness/latest/api/cells.html

        :stability: experimental
        '''
        return typing.cast("Route53RecoveryReadiness", jsii.invoke(self, "toListCells", []))

    @jsii.member(jsii_name="toListCrossAccountAuthorizations")
    def to_list_cross_account_authorizations(self) -> "Route53RecoveryReadiness":
        '''(experimental) Grants permission to list cross account authorizations.

        Access Level: Read

        https://docs.aws.amazon.com/recovery-readiness/latest/api/crossaccountauthorizations.html

        :stability: experimental
        '''
        return typing.cast("Route53RecoveryReadiness", jsii.invoke(self, "toListCrossAccountAuthorizations", []))

    @jsii.member(jsii_name="toListReadinessChecks")
    def to_list_readiness_checks(self) -> "Route53RecoveryReadiness":
        '''(experimental) Grants permission to list readiness checks.

        Access Level: Read

        https://docs.aws.amazon.com/recovery-readiness/latest/api/readinesschecks.html

        :stability: experimental
        '''
        return typing.cast("Route53RecoveryReadiness", jsii.invoke(self, "toListReadinessChecks", []))

    @jsii.member(jsii_name="toListRecoveryGroups")
    def to_list_recovery_groups(self) -> "Route53RecoveryReadiness":
        '''(experimental) Grants permission to list recovery groups.

        Access Level: Read

        https://docs.aws.amazon.com/recovery-readiness/latest/api/recoverygroups.html

        :stability: experimental
        '''
        return typing.cast("Route53RecoveryReadiness", jsii.invoke(self, "toListRecoveryGroups", []))

    @jsii.member(jsii_name="toListResourceSets")
    def to_list_resource_sets(self) -> "Route53RecoveryReadiness":
        '''(experimental) Grants permission to list resource sets.

        Access Level: Read

        https://docs.aws.amazon.com/recovery-readiness/latest/api/resourcesets.html

        :stability: experimental
        '''
        return typing.cast("Route53RecoveryReadiness", jsii.invoke(self, "toListResourceSets", []))

    @jsii.member(jsii_name="toListRules")
    def to_list_rules(self) -> "Route53RecoveryReadiness":
        '''(experimental) Grants permission to list readiness rules.

        Access Level: Read

        https://docs.aws.amazon.com/recovery-readiness/latest/api/rules.html

        :stability: experimental
        '''
        return typing.cast("Route53RecoveryReadiness", jsii.invoke(self, "toListRules", []))

    @jsii.member(jsii_name="toListTagsForResources")
    def to_list_tags_for_resources(self) -> "Route53RecoveryReadiness":
        '''(experimental) Grants permission to list tags for a resource.

        Access Level: Read

        https://docs.aws.amazon.com/recovery-readiness/latest/api/tags-resource-arn.html

        :stability: experimental
        '''
        return typing.cast("Route53RecoveryReadiness", jsii.invoke(self, "toListTagsForResources", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Route53RecoveryReadiness":
        '''(experimental) Grants permission to add a tag to a resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/recovery-readiness/latest/api/tags-resource-arn.html

        :stability: experimental
        '''
        return typing.cast("Route53RecoveryReadiness", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Route53RecoveryReadiness":
        '''(experimental) Grants permission to remove a tag from a resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/recovery-readiness/latest/api/tags-resource-arn.html

        :stability: experimental
        '''
        return typing.cast("Route53RecoveryReadiness", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateCell")
    def to_update_cell(self) -> "Route53RecoveryReadiness":
        '''(experimental) Grants permission to update a cell.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/recovery-readiness/latest/api/cells-cellname.html

        :stability: experimental
        '''
        return typing.cast("Route53RecoveryReadiness", jsii.invoke(self, "toUpdateCell", []))

    @jsii.member(jsii_name="toUpdateReadinessCheck")
    def to_update_readiness_check(self) -> "Route53RecoveryReadiness":
        '''(experimental) Grants permission to update a readiness check.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/recovery-readiness/latest/api/readinesschecks-readinesscheckname.html

        :stability: experimental
        '''
        return typing.cast("Route53RecoveryReadiness", jsii.invoke(self, "toUpdateReadinessCheck", []))

    @jsii.member(jsii_name="toUpdateRecoveryGroup")
    def to_update_recovery_group(self) -> "Route53RecoveryReadiness":
        '''(experimental) Grants permission to update a recovery group.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/recovery-readiness/latest/api/recoverygroups-recoverygroupname.html

        :stability: experimental
        '''
        return typing.cast("Route53RecoveryReadiness", jsii.invoke(self, "toUpdateRecoveryGroup", []))

    @jsii.member(jsii_name="toUpdateResourceSet")
    def to_update_resource_set(self) -> "Route53RecoveryReadiness":
        '''(experimental) Grants permission to update a resource set.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/recovery-readiness/latest/api/resourcesets-resourcesetname.html

        :stability: experimental
        '''
        return typing.cast("Route53RecoveryReadiness", jsii.invoke(self, "toUpdateResourceSet", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__851264da398030aae8e5c4d97122a2e6b6786cca79ef7d0c7e65d06bcc1c4a2f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4d674a5f2847270ad8c7f17406a75c8432a58ca3ffa462b994206cd79f41cb2b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Route53domains(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Route53domains",
):
    '''(experimental) Statement provider for service `route53domains <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonroute53domains.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `route53domains <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonroute53domains.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="toAcceptDomainTransferFromAnotherAwsAccount")
    def to_accept_domain_transfer_from_another_aws_account(self) -> "Route53domains":
        '''(experimental) Grants permission to accept the transfer of a domain from another AWS account to the current AWS account.

        Access Level: Write

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_domains_AcceptDomainTransferFromAnotherAwsAccount.html

        :stability: experimental
        '''
        return typing.cast("Route53domains", jsii.invoke(self, "toAcceptDomainTransferFromAnotherAwsAccount", []))

    @jsii.member(jsii_name="toAssociateDelegationSignerToDomain")
    def to_associate_delegation_signer_to_domain(self) -> "Route53domains":
        '''(experimental) Grants permission to associate a new delegation signer to a domain.

        Access Level: Write

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_domains_AssociateDelegationSignerToDomain.html

        :stability: experimental
        '''
        return typing.cast("Route53domains", jsii.invoke(self, "toAssociateDelegationSignerToDomain", []))

    @jsii.member(jsii_name="toCancelDomainTransferToAnotherAwsAccount")
    def to_cancel_domain_transfer_to_another_aws_account(self) -> "Route53domains":
        '''(experimental) Grants permission to cancel the transfer of a domain from the current AWS account to another AWS account.

        Access Level: Write

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_domains_CancelDomainTransferToAnotherAwsAccount.html

        :stability: experimental
        '''
        return typing.cast("Route53domains", jsii.invoke(self, "toCancelDomainTransferToAnotherAwsAccount", []))

    @jsii.member(jsii_name="toCheckDomainAvailability")
    def to_check_domain_availability(self) -> "Route53domains":
        '''(experimental) Grants permission to check the availability of one domain name.

        Access Level: Read

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_domains_CheckDomainAvailability.html

        :stability: experimental
        '''
        return typing.cast("Route53domains", jsii.invoke(self, "toCheckDomainAvailability", []))

    @jsii.member(jsii_name="toCheckDomainTransferability")
    def to_check_domain_transferability(self) -> "Route53domains":
        '''(experimental) Grants permission to check whether a domain name can be transferred to Amazon Route 53.

        Access Level: Read

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_domains_CheckDomainTransferability.html

        :stability: experimental
        '''
        return typing.cast("Route53domains", jsii.invoke(self, "toCheckDomainTransferability", []))

    @jsii.member(jsii_name="toDeleteDomain")
    def to_delete_domain(self) -> "Route53domains":
        '''(experimental) Grants permission to delete domains.

        Access Level: Write

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_domains_DeleteDomain.html

        :stability: experimental
        '''
        return typing.cast("Route53domains", jsii.invoke(self, "toDeleteDomain", []))

    @jsii.member(jsii_name="toDeleteTagsForDomain")
    def to_delete_tags_for_domain(self) -> "Route53domains":
        '''(experimental) Grants permission to delete the specified tags for a domain.

        Access Level: Tagging

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_domains_DeleteTagsForDomain.html

        :stability: experimental
        '''
        return typing.cast("Route53domains", jsii.invoke(self, "toDeleteTagsForDomain", []))

    @jsii.member(jsii_name="toDisableDomainAutoRenew")
    def to_disable_domain_auto_renew(self) -> "Route53domains":
        '''(experimental) Grants permission to configure Amazon Route 53 to automatically renew the specified domain before the domain registration expires.

        Access Level: Write

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_domains_DisableDomainAutoRenew.html

        :stability: experimental
        '''
        return typing.cast("Route53domains", jsii.invoke(self, "toDisableDomainAutoRenew", []))

    @jsii.member(jsii_name="toDisableDomainTransferLock")
    def to_disable_domain_transfer_lock(self) -> "Route53domains":
        '''(experimental) Grants permission to remove the transfer lock on the domain (specifically the clientTransferProhibited status) to allow domain transfers.

        Access Level: Write

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_domains_DisableDomainTransferLock.html

        :stability: experimental
        '''
        return typing.cast("Route53domains", jsii.invoke(self, "toDisableDomainTransferLock", []))

    @jsii.member(jsii_name="toDisassociateDelegationSignerFromDomain")
    def to_disassociate_delegation_signer_from_domain(self) -> "Route53domains":
        '''(experimental) Grants permission to disassociate an existing delegation signer from a domain.

        Access Level: Write

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_domains_DisassociateDelegationSignerFromDomain.html

        :stability: experimental
        '''
        return typing.cast("Route53domains", jsii.invoke(self, "toDisassociateDelegationSignerFromDomain", []))

    @jsii.member(jsii_name="toEnableDomainAutoRenew")
    def to_enable_domain_auto_renew(self) -> "Route53domains":
        '''(experimental) Grants permission to configure Amazon Route 53 to automatically renew the specified domain before the domain registration expires.

        Access Level: Write

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_domains_DisableDomainAutoRenew.html

        :stability: experimental
        '''
        return typing.cast("Route53domains", jsii.invoke(self, "toEnableDomainAutoRenew", []))

    @jsii.member(jsii_name="toEnableDomainTransferLock")
    def to_enable_domain_transfer_lock(self) -> "Route53domains":
        '''(experimental) Grants permission to set the transfer lock on the domain (specifically the clientTransferProhibited status) to prevent domain transfers.

        Access Level: Write

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_domains_EnableDomainTransferLock.html

        :stability: experimental
        '''
        return typing.cast("Route53domains", jsii.invoke(self, "toEnableDomainTransferLock", []))

    @jsii.member(jsii_name="toGetContactReachabilityStatus")
    def to_get_contact_reachability_status(self) -> "Route53domains":
        '''(experimental) Grants permission to get information about whether the registrant contact has responded for operations that require confirmation that the email address for the registrant contact is valid, such as registering a new domain.

        Access Level: Read

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_domains_GetContactReachabilityStatus.html

        :stability: experimental
        '''
        return typing.cast("Route53domains", jsii.invoke(self, "toGetContactReachabilityStatus", []))

    @jsii.member(jsii_name="toGetDomainDetail")
    def to_get_domain_detail(self) -> "Route53domains":
        '''(experimental) Grants permission to get detailed information about a domain.

        Access Level: Read

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_domains_GetDomainDetail.html

        :stability: experimental
        '''
        return typing.cast("Route53domains", jsii.invoke(self, "toGetDomainDetail", []))

    @jsii.member(jsii_name="toGetDomainSuggestions")
    def to_get_domain_suggestions(self) -> "Route53domains":
        '''(experimental) Grants permission to get a list of suggested domain names given a string, which can either be a domain name or simply a word or phrase (without spaces).

        Access Level: Read

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_domains_GetDomainSuggestions.html

        :stability: experimental
        '''
        return typing.cast("Route53domains", jsii.invoke(self, "toGetDomainSuggestions", []))

    @jsii.member(jsii_name="toGetOperationDetail")
    def to_get_operation_detail(self) -> "Route53domains":
        '''(experimental) Grants permission to get the current status of an operation that is not completed.

        Access Level: Read

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_domains_GetOperationDetail.html

        :stability: experimental
        '''
        return typing.cast("Route53domains", jsii.invoke(self, "toGetOperationDetail", []))

    @jsii.member(jsii_name="toListDomains")
    def to_list_domains(self) -> "Route53domains":
        '''(experimental) Grants permission to list all the domain names registered with Amazon Route 53 for the current AWS account.

        Access Level: List

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_domains_ListDomains.html

        :stability: experimental
        '''
        return typing.cast("Route53domains", jsii.invoke(self, "toListDomains", []))

    @jsii.member(jsii_name="toListOperations")
    def to_list_operations(self) -> "Route53domains":
        '''(experimental) Grants permission to list the operation IDs of operations that are not yet complete.

        Access Level: List

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_domains_ListOperations.html

        :stability: experimental
        '''
        return typing.cast("Route53domains", jsii.invoke(self, "toListOperations", []))

    @jsii.member(jsii_name="toListPrices")
    def to_list_prices(self) -> "Route53domains":
        '''(experimental) Grants permission to list the prices of operations for TLDs.

        Access Level: List

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_domains_ListPrices.html

        :stability: experimental
        '''
        return typing.cast("Route53domains", jsii.invoke(self, "toListPrices", []))

    @jsii.member(jsii_name="toListTagsForDomain")
    def to_list_tags_for_domain(self) -> "Route53domains":
        '''(experimental) Grants permission to list all the tags that are associated with the specified domain.

        Access Level: Read

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_domains_ListTagsForDomain.html

        :stability: experimental
        '''
        return typing.cast("Route53domains", jsii.invoke(self, "toListTagsForDomain", []))

    @jsii.member(jsii_name="toPushDomain")
    def to_push_domain(self) -> "Route53domains":
        '''(experimental) Grants permission to change the IPS tag of .uk domain to initiate a transfer process from Route 53 to another registrar.

        Access Level: Write

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_domains_PushDomain.html

        :stability: experimental
        '''
        return typing.cast("Route53domains", jsii.invoke(self, "toPushDomain", []))

    @jsii.member(jsii_name="toRegisterDomain")
    def to_register_domain(self) -> "Route53domains":
        '''(experimental) Grants permission to register domains.

        Access Level: Write

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_domains_RegisterDomain.html

        :stability: experimental
        '''
        return typing.cast("Route53domains", jsii.invoke(self, "toRegisterDomain", []))

    @jsii.member(jsii_name="toRejectDomainTransferFromAnotherAwsAccount")
    def to_reject_domain_transfer_from_another_aws_account(self) -> "Route53domains":
        '''(experimental) Grants permission to reject the transfer of a domain from another AWS account to the current AWS account.

        Access Level: Write

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_domains_RejectDomainTransferFromAnotherAwsAccount.html

        :stability: experimental
        '''
        return typing.cast("Route53domains", jsii.invoke(self, "toRejectDomainTransferFromAnotherAwsAccount", []))

    @jsii.member(jsii_name="toRenewDomain")
    def to_renew_domain(self) -> "Route53domains":
        '''(experimental) Grants permission to renew domains for the specified number of years.

        Access Level: Write

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_domains_RenewDomain.html

        :stability: experimental
        '''
        return typing.cast("Route53domains", jsii.invoke(self, "toRenewDomain", []))

    @jsii.member(jsii_name="toResendContactReachabilityEmail")
    def to_resend_contact_reachability_email(self) -> "Route53domains":
        '''(experimental) Grants permission to resend the confirmation email to the current email address for the registrant contact for operations that require confirmation that the email address for the registrant contact is valid, such as registering a new domain.

        Access Level: Write

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_domains_ResendContactReachabilityEmail.html

        :stability: experimental
        '''
        return typing.cast("Route53domains", jsii.invoke(self, "toResendContactReachabilityEmail", []))

    @jsii.member(jsii_name="toResendOperationAuthorization")
    def to_resend_operation_authorization(self) -> "Route53domains":
        '''(experimental) Grants permission to resend the operation authorization.

        Access Level: Write

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_domains_ResendOperationAuthorization.html

        :stability: experimental
        '''
        return typing.cast("Route53domains", jsii.invoke(self, "toResendOperationAuthorization", []))

    @jsii.member(jsii_name="toRetrieveDomainAuthCode")
    def to_retrieve_domain_auth_code(self) -> "Route53domains":
        '''(experimental) Grants permission to get the AuthCode for the domain.

        Access Level: Write

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_domains_RetrieveDomainAuthCode.html

        :stability: experimental
        '''
        return typing.cast("Route53domains", jsii.invoke(self, "toRetrieveDomainAuthCode", []))

    @jsii.member(jsii_name="toTransferDomain")
    def to_transfer_domain(self) -> "Route53domains":
        '''(experimental) Grants permission to transfer a domain from another registrar to Amazon Route 53.

        Access Level: Write

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_domains_TransferDomain.html

        :stability: experimental
        '''
        return typing.cast("Route53domains", jsii.invoke(self, "toTransferDomain", []))

    @jsii.member(jsii_name="toTransferDomainToAnotherAwsAccount")
    def to_transfer_domain_to_another_aws_account(self) -> "Route53domains":
        '''(experimental) Grants permission to transfer a domain from the current AWS account to another AWS account.

        Access Level: Write

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_domains_TransferDomainToAnotherAwsAccount.html

        :stability: experimental
        '''
        return typing.cast("Route53domains", jsii.invoke(self, "toTransferDomainToAnotherAwsAccount", []))

    @jsii.member(jsii_name="toUpdateDomainContact")
    def to_update_domain_contact(self) -> "Route53domains":
        '''(experimental) Grants permission to update the contact information for domain.

        Access Level: Write

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_domains_UpdateDomainContact.html

        :stability: experimental
        '''
        return typing.cast("Route53domains", jsii.invoke(self, "toUpdateDomainContact", []))

    @jsii.member(jsii_name="toUpdateDomainContactPrivacy")
    def to_update_domain_contact_privacy(self) -> "Route53domains":
        '''(experimental) Grants permission to update the domain contact privacy setting.

        Access Level: Write

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_domains_UpdateDomainContactPrivacy.html

        :stability: experimental
        '''
        return typing.cast("Route53domains", jsii.invoke(self, "toUpdateDomainContactPrivacy", []))

    @jsii.member(jsii_name="toUpdateDomainNameservers")
    def to_update_domain_nameservers(self) -> "Route53domains":
        '''(experimental) Grants permission to replace the current set of name servers for a domain with the specified set of name servers.

        Access Level: Write

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_domains_UpdateDomainNameservers.html

        :stability: experimental
        '''
        return typing.cast("Route53domains", jsii.invoke(self, "toUpdateDomainNameservers", []))

    @jsii.member(jsii_name="toUpdateTagsForDomain")
    def to_update_tags_for_domain(self) -> "Route53domains":
        '''(experimental) Grants permission to add or update tags for a specified domain.

        Access Level: Tagging

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_domains_UpdateTagsForDomain.html

        :stability: experimental
        '''
        return typing.cast("Route53domains", jsii.invoke(self, "toUpdateTagsForDomain", []))

    @jsii.member(jsii_name="toViewBilling")
    def to_view_billing(self) -> "Route53domains":
        '''(experimental) Grants permission to get all the domain-related billing records for the current AWS account for a specified period.

        Access Level: Read

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_domains_ViewBilling.html

        :stability: experimental
        '''
        return typing.cast("Route53domains", jsii.invoke(self, "toViewBilling", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__34b7b527223f8d195bbe1ab4facd589532e0b67b94f0ce88a1079e96c37c4dde)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7f9cd78ee3b9d7d812c75644db68c31e593b1e1f93ffe6307ba9cf15a5d69dfb)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Route53resolver(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Route53resolver",
):
    '''(experimental) Statement provider for service `route53resolver <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonroute53resolver.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `route53resolver <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonroute53resolver.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onFirewallConfig")
    def on_firewall_config(
        self,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Route53resolver":
        '''(experimental) Adds a resource of type firewall-config to the statement.

        https://docs.aws.amazon.com/Route53/latest/DeveloperGuide/access-control-overview.html#access-control-resources

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__13456c4cfd31e7847c56bf6f529c6c7a696629713b105e5b160d485d88b9dd1b)
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Route53resolver", jsii.invoke(self, "onFirewallConfig", [resource_id, account, region, partition]))

    @jsii.member(jsii_name="onFirewallDomainList")
    def on_firewall_domain_list(
        self,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Route53resolver":
        '''(experimental) Adds a resource of type firewall-domain-list to the statement.

        https://docs.aws.amazon.com/Route53/latest/DeveloperGuide/access-control-overview.html#access-control-resources

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4bfd4a9d4bea29482c7da173bd53fe9fca32e7235d973d37f62840f085ecf163)
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Route53resolver", jsii.invoke(self, "onFirewallDomainList", [resource_id, account, region, partition]))

    @jsii.member(jsii_name="onFirewallRuleGroup")
    def on_firewall_rule_group(
        self,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Route53resolver":
        '''(experimental) Adds a resource of type firewall-rule-group to the statement.

        https://docs.aws.amazon.com/Route53/latest/DeveloperGuide/access-control-overview.html#access-control-resources

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b8981f61ec5a6df4897310f433edf425264b3013d71a88023da7ba281d6b9b0c)
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Route53resolver", jsii.invoke(self, "onFirewallRuleGroup", [resource_id, account, region, partition]))

    @jsii.member(jsii_name="onFirewallRuleGroupAssociation")
    def on_firewall_rule_group_association(
        self,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Route53resolver":
        '''(experimental) Adds a resource of type firewall-rule-group-association to the statement.

        https://docs.aws.amazon.com/Route53/latest/DeveloperGuide/access-control-overview.html#access-control-resources

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__040e970cd0f473815b811ea9fbd0723eac54cd55a90b11bf4c9b4cc8bf204d49)
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Route53resolver", jsii.invoke(self, "onFirewallRuleGroupAssociation", [resource_id, account, region, partition]))

    @jsii.member(jsii_name="onResolverConfig")
    def on_resolver_config(
        self,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Route53resolver":
        '''(experimental) Adds a resource of type resolver-config to the statement.

        https://docs.aws.amazon.com/Route53/latest/DeveloperGuide/access-control-overview.html#access-control-resources

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5408b696f5def45878278a2f28cbab5cd2ada4ebbc30b8e178f3d243290c2ee2)
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Route53resolver", jsii.invoke(self, "onResolverConfig", [resource_id, account, region, partition]))

    @jsii.member(jsii_name="onResolverDnssecConfig")
    def on_resolver_dnssec_config(
        self,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Route53resolver":
        '''(experimental) Adds a resource of type resolver-dnssec-config to the statement.

        https://docs.aws.amazon.com/Route53/latest/DeveloperGuide/access-control-overview.html#access-control-resources

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bc9c1a5f17972d40f38b82a8f6f38568c9aca53afa4970b10610dbb746c1a674)
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Route53resolver", jsii.invoke(self, "onResolverDnssecConfig", [resource_id, account, region, partition]))

    @jsii.member(jsii_name="onResolverEndpoint")
    def on_resolver_endpoint(
        self,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Route53resolver":
        '''(experimental) Adds a resource of type resolver-endpoint to the statement.

        https://docs.aws.amazon.com/Route53/latest/DeveloperGuide/access-control-overview.html#access-control-resources

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4967bd93a4ebdf6920cdb67e5ef192779f92e05ff23302037d6a7867ad3bf04c)
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Route53resolver", jsii.invoke(self, "onResolverEndpoint", [resource_id, account, region, partition]))

    @jsii.member(jsii_name="onResolverQueryLogConfig")
    def on_resolver_query_log_config(
        self,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Route53resolver":
        '''(experimental) Adds a resource of type resolver-query-log-config to the statement.

        https://docs.aws.amazon.com/Route53/latest/DeveloperGuide/access-control-overview.html#access-control-resources

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d63a0dc09a41177e8534bc0158f070d0e786b79f64b1d346012893219e459af8)
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Route53resolver", jsii.invoke(self, "onResolverQueryLogConfig", [resource_id, account, region, partition]))

    @jsii.member(jsii_name="onResolverRule")
    def on_resolver_rule(
        self,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Route53resolver":
        '''(experimental) Adds a resource of type resolver-rule to the statement.

        https://docs.aws.amazon.com/Route53/latest/DeveloperGuide/access-control-overview.html#access-control-resources

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c3ad3a6c9c8754824504a0ce8fd4d269ddbea963e3992ad8735cf5bdeb1dde86)
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Route53resolver", jsii.invoke(self, "onResolverRule", [resource_id, account, region, partition]))

    @jsii.member(jsii_name="toAssociateFirewallRuleGroup")
    def to_associate_firewall_rule_group(self) -> "Route53resolver":
        '''(experimental) Grants permission to associate an Amazon VPC with a specified firewall rule group.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - ec2:DescribeVpcs

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_route53resolver_AssociateFirewallRuleGroup.html

        :stability: experimental
        '''
        return typing.cast("Route53resolver", jsii.invoke(self, "toAssociateFirewallRuleGroup", []))

    @jsii.member(jsii_name="toAssociateResolverEndpointIpAddress")
    def to_associate_resolver_endpoint_ip_address(self) -> "Route53resolver":
        '''(experimental) Grants permission to associate a specified IP address with a Resolver endpoint.

        This is an IP address that DNS queries pass through on the way to your network (outbound) or your VPCs (inbound)

        Access Level: Write

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_route53resolver_AssociateResolverEndpointIpAddress.html

        :stability: experimental
        '''
        return typing.cast("Route53resolver", jsii.invoke(self, "toAssociateResolverEndpointIpAddress", []))

    @jsii.member(jsii_name="toAssociateResolverQueryLogConfig")
    def to_associate_resolver_query_log_config(self) -> "Route53resolver":
        '''(experimental) Grants permission to associate an Amazon VPC with a specified query logging configuration.

        Access Level: Write

        Dependent actions:

        - ec2:DescribeVpcs

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_route53resolver_AssociateResolverQueryLogConfig.html

        :stability: experimental
        '''
        return typing.cast("Route53resolver", jsii.invoke(self, "toAssociateResolverQueryLogConfig", []))

    @jsii.member(jsii_name="toAssociateResolverRule")
    def to_associate_resolver_rule(self) -> "Route53resolver":
        '''(experimental) Grants permission to associate a specified Resolver rule with a specified VPC.

        Access Level: Write

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_route53resolver_AssociateResolverRule.html

        :stability: experimental
        '''
        return typing.cast("Route53resolver", jsii.invoke(self, "toAssociateResolverRule", []))

    @jsii.member(jsii_name="toCreateFirewallDomainList")
    def to_create_firewall_domain_list(self) -> "Route53resolver":
        '''(experimental) Grants permission to create a Firewall domain list.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_route53resolver_CreateFirewallDomainList.html

        :stability: experimental
        '''
        return typing.cast("Route53resolver", jsii.invoke(self, "toCreateFirewallDomainList", []))

    @jsii.member(jsii_name="toCreateFirewallRule")
    def to_create_firewall_rule(self) -> "Route53resolver":
        '''(experimental) Grants permission to create a Firewall rule within a Firewall rule group.

        Access Level: Write

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_route53resolver_CreateFirewallRule.html

        :stability: experimental
        '''
        return typing.cast("Route53resolver", jsii.invoke(self, "toCreateFirewallRule", []))

    @jsii.member(jsii_name="toCreateFirewallRuleGroup")
    def to_create_firewall_rule_group(self) -> "Route53resolver":
        '''(experimental) Grants permission to create a Firewall rule group.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_route53resolver_CreateFirewallRuleGroup.html

        :stability: experimental
        '''
        return typing.cast("Route53resolver", jsii.invoke(self, "toCreateFirewallRuleGroup", []))

    @jsii.member(jsii_name="toCreateResolverEndpoint")
    def to_create_resolver_endpoint(self) -> "Route53resolver":
        '''(experimental) Grants permission to create a Resolver endpoint. There are two types of Resolver endpoints, inbound and outbound.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_route53resolver_CreateResolverEndpoint.html

        :stability: experimental
        '''
        return typing.cast("Route53resolver", jsii.invoke(self, "toCreateResolverEndpoint", []))

    @jsii.member(jsii_name="toCreateResolverQueryLogConfig")
    def to_create_resolver_query_log_config(self) -> "Route53resolver":
        '''(experimental) Grants permission to create a Resolver query logging configuration, which defines where you want Resolver to save DNS query logs that originate in your VPCs.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_route53resolver_CreateResolverQueryLogConfig.html

        :stability: experimental
        '''
        return typing.cast("Route53resolver", jsii.invoke(self, "toCreateResolverQueryLogConfig", []))

    @jsii.member(jsii_name="toCreateResolverRule")
    def to_create_resolver_rule(self) -> "Route53resolver":
        '''(experimental) Grants permission to define how to route queries originating from your VPC out of the VPC.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_route53resolver_CreateResolverRule.html

        :stability: experimental
        '''
        return typing.cast("Route53resolver", jsii.invoke(self, "toCreateResolverRule", []))

    @jsii.member(jsii_name="toDeleteFirewallDomainList")
    def to_delete_firewall_domain_list(self) -> "Route53resolver":
        '''(experimental) Grants permission to delete a Firewall domain list.

        Access Level: Write

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_route53resolver_DeleteFirewallDomainList.html

        :stability: experimental
        '''
        return typing.cast("Route53resolver", jsii.invoke(self, "toDeleteFirewallDomainList", []))

    @jsii.member(jsii_name="toDeleteFirewallRule")
    def to_delete_firewall_rule(self) -> "Route53resolver":
        '''(experimental) Grants permission to delete a Firewall rule within a Firewall rule group.

        Access Level: Write

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_route53resolver_DeleteFirewallRule.html

        :stability: experimental
        '''
        return typing.cast("Route53resolver", jsii.invoke(self, "toDeleteFirewallRule", []))

    @jsii.member(jsii_name="toDeleteFirewallRuleGroup")
    def to_delete_firewall_rule_group(self) -> "Route53resolver":
        '''(experimental) Grants permission to delete a Firewall rule group.

        Access Level: Write

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_route53resolver_DeleteFirewallRuleGroup.html

        :stability: experimental
        '''
        return typing.cast("Route53resolver", jsii.invoke(self, "toDeleteFirewallRuleGroup", []))

    @jsii.member(jsii_name="toDeleteResolverEndpoint")
    def to_delete_resolver_endpoint(self) -> "Route53resolver":
        '''(experimental) Grants permission to delete a Resolver endpoint.

        The effect of deleting a Resolver endpoint depends on whether it's an inbound or an outbound endpoint

        Access Level: Write

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_route53resolver_DeleteResolverEndpoint.html

        :stability: experimental
        '''
        return typing.cast("Route53resolver", jsii.invoke(self, "toDeleteResolverEndpoint", []))

    @jsii.member(jsii_name="toDeleteResolverQueryLogConfig")
    def to_delete_resolver_query_log_config(self) -> "Route53resolver":
        '''(experimental) Grants permission to delete a Resolver query logging configuration.

        Access Level: Write

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_route53resolver_DeleteResolverQueryLogConfig.html

        :stability: experimental
        '''
        return typing.cast("Route53resolver", jsii.invoke(self, "toDeleteResolverQueryLogConfig", []))

    @jsii.member(jsii_name="toDeleteResolverRule")
    def to_delete_resolver_rule(self) -> "Route53resolver":
        '''(experimental) Grants permission to delete a Resolver rule.

        Access Level: Write

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_route53resolver_DeleteResolverRule.html

        :stability: experimental
        '''
        return typing.cast("Route53resolver", jsii.invoke(self, "toDeleteResolverRule", []))

    @jsii.member(jsii_name="toDisassociateFirewallRuleGroup")
    def to_disassociate_firewall_rule_group(self) -> "Route53resolver":
        '''(experimental) Grants permission to remove the association between a specified Firewall rule group and a specified VPC.

        Access Level: Write

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_route53resolver_DisassociateFirewallRuleGroup.html

        :stability: experimental
        '''
        return typing.cast("Route53resolver", jsii.invoke(self, "toDisassociateFirewallRuleGroup", []))

    @jsii.member(jsii_name="toDisassociateResolverEndpointIpAddress")
    def to_disassociate_resolver_endpoint_ip_address(self) -> "Route53resolver":
        '''(experimental) Grants permission to remove a specified IP address from a Resolver endpoint.

        This is an IP address that DNS queries pass through on the way to your network (outbound) or your VPCs (inbound)

        Access Level: Write

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_route53resolver_DisassociateResolverEndpointIpAddress.html

        :stability: experimental
        '''
        return typing.cast("Route53resolver", jsii.invoke(self, "toDisassociateResolverEndpointIpAddress", []))

    @jsii.member(jsii_name="toDisassociateResolverQueryLogConfig")
    def to_disassociate_resolver_query_log_config(self) -> "Route53resolver":
        '''(experimental) Grants permission to remove the association between a specified Resolver query logging configuration and a specified VPC.

        Access Level: Write

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_route53resolver_DisassociateResolverQueryLogConfig.html

        :stability: experimental
        '''
        return typing.cast("Route53resolver", jsii.invoke(self, "toDisassociateResolverQueryLogConfig", []))

    @jsii.member(jsii_name="toDisassociateResolverRule")
    def to_disassociate_resolver_rule(self) -> "Route53resolver":
        '''(experimental) Grants permission to remove the association between a specified Resolver rule and a specified VPC.

        Access Level: Write

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_route53resolver_DisassociateResolverRule.html

        :stability: experimental
        '''
        return typing.cast("Route53resolver", jsii.invoke(self, "toDisassociateResolverRule", []))

    @jsii.member(jsii_name="toGetFirewallConfig")
    def to_get_firewall_config(self) -> "Route53resolver":
        '''(experimental) Grants permission to get information about a specified Firewall config.

        Access Level: Read

        Dependent actions:

        - ec2:DescribeVpcs

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_route53resolver_GetFirewallConfig.html

        :stability: experimental
        '''
        return typing.cast("Route53resolver", jsii.invoke(self, "toGetFirewallConfig", []))

    @jsii.member(jsii_name="toGetFirewallDomainList")
    def to_get_firewall_domain_list(self) -> "Route53resolver":
        '''(experimental) Grants permission to get information about a specified Firewall domain list.

        Access Level: Read

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_route53resolver_GetFirewallDomainList.html

        :stability: experimental
        '''
        return typing.cast("Route53resolver", jsii.invoke(self, "toGetFirewallDomainList", []))

    @jsii.member(jsii_name="toGetFirewallRuleGroup")
    def to_get_firewall_rule_group(self) -> "Route53resolver":
        '''(experimental) Grants permission to get information about a specified Firewall rule group.

        Access Level: Read

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_route53resolver_GetFirewallRuleGroup.html

        :stability: experimental
        '''
        return typing.cast("Route53resolver", jsii.invoke(self, "toGetFirewallRuleGroup", []))

    @jsii.member(jsii_name="toGetFirewallRuleGroupAssociation")
    def to_get_firewall_rule_group_association(self) -> "Route53resolver":
        '''(experimental) Grants permission to get information about an association between a specified Firewall rule group and a VPC.

        Access Level: Read

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_route53resolver_GetFirewallRuleGroupAssociation.html

        :stability: experimental
        '''
        return typing.cast("Route53resolver", jsii.invoke(self, "toGetFirewallRuleGroupAssociation", []))

    @jsii.member(jsii_name="toGetFirewallRuleGroupPolicy")
    def to_get_firewall_rule_group_policy(self) -> "Route53resolver":
        '''(experimental) Grants permission to get information about a specified Firewall rule group policy, which specifies the Firewall rule group operations and resources that you want to allow another AWS account to use.

        Access Level: Read

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_route53resolver_GetFirewallRuleGroupPolicy.html

        :stability: experimental
        '''
        return typing.cast("Route53resolver", jsii.invoke(self, "toGetFirewallRuleGroupPolicy", []))

    @jsii.member(jsii_name="toGetResolverConfig")
    def to_get_resolver_config(self) -> "Route53resolver":
        '''(experimental) Grants permission to get the Resolver Config status within the specified resource.

        Access Level: Read

        Dependent actions:

        - ec2:DescribeVpcs

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_route53resolver_GetResolverConfig.html

        :stability: experimental
        '''
        return typing.cast("Route53resolver", jsii.invoke(self, "toGetResolverConfig", []))

    @jsii.member(jsii_name="toGetResolverDnssecConfig")
    def to_get_resolver_dnssec_config(self) -> "Route53resolver":
        '''(experimental) Grants permission to get the DNSSEC validation support status for DNS queries within the specified resource.

        Access Level: Read

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_route53resolver_GetResolverDnssecConfig.html

        :stability: experimental
        '''
        return typing.cast("Route53resolver", jsii.invoke(self, "toGetResolverDnssecConfig", []))

    @jsii.member(jsii_name="toGetResolverEndpoint")
    def to_get_resolver_endpoint(self) -> "Route53resolver":
        '''(experimental) Grants permission to get information about a specified Resolver endpoint, such as whether it's an inbound or an outbound endpoint, and the IP addresses in your VPC that DNS queries are forwarded to on the way into or out of your VPC.

        Access Level: Read

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_route53resolver_GetResolverEndpoint.html

        :stability: experimental
        '''
        return typing.cast("Route53resolver", jsii.invoke(self, "toGetResolverEndpoint", []))

    @jsii.member(jsii_name="toGetResolverQueryLogConfig")
    def to_get_resolver_query_log_config(self) -> "Route53resolver":
        '''(experimental) Grants permission to get information about a specified Resolver query logging configuration, such as the number of VPCs that the configuration is logging queries for and the location that logs are sent to.

        Access Level: Read

        Dependent actions:

        - ec2:DescribeVpcs

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_route53resolver_GetResolverQueryLogConfig.html

        :stability: experimental
        '''
        return typing.cast("Route53resolver", jsii.invoke(self, "toGetResolverQueryLogConfig", []))

    @jsii.member(jsii_name="toGetResolverQueryLogConfigAssociation")
    def to_get_resolver_query_log_config_association(self) -> "Route53resolver":
        '''(experimental) Grants permission to get information about a specified association between a Resolver query logging configuration and an Amazon VPC.

        When you associate a VPC with a query logging configuration, Resolver logs DNS queries that originate in that VPC

        Access Level: Read

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_route53resolver_GetResolverQueryLogConfigAssociation.html

        :stability: experimental
        '''
        return typing.cast("Route53resolver", jsii.invoke(self, "toGetResolverQueryLogConfigAssociation", []))

    @jsii.member(jsii_name="toGetResolverQueryLogConfigPolicy")
    def to_get_resolver_query_log_config_policy(self) -> "Route53resolver":
        '''(experimental) Grants permission to get information about a specified Resolver query logging policy, which specifies the Resolver query logging operations and resources that you want to allow another AWS account to use.

        Access Level: Read

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_route53resolver_GetResolverQueryLogConfigPolicy.html

        :stability: experimental
        '''
        return typing.cast("Route53resolver", jsii.invoke(self, "toGetResolverQueryLogConfigPolicy", []))

    @jsii.member(jsii_name="toGetResolverRule")
    def to_get_resolver_rule(self) -> "Route53resolver":
        '''(experimental) Grants permission to get information about a specified Resolver rule, such as the domain name that the rule forwards DNS queries for and the IP address that queries are forwarded to.

        Access Level: Read

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_route53resolver_GetResolverRule.html

        :stability: experimental
        '''
        return typing.cast("Route53resolver", jsii.invoke(self, "toGetResolverRule", []))

    @jsii.member(jsii_name="toGetResolverRuleAssociation")
    def to_get_resolver_rule_association(self) -> "Route53resolver":
        '''(experimental) Grants permission to get information about an association between a specified Resolver rule and a VPC.

        Access Level: Read

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_route53resolver_GetResolverRuleAssociation.html

        :stability: experimental
        '''
        return typing.cast("Route53resolver", jsii.invoke(self, "toGetResolverRuleAssociation", []))

    @jsii.member(jsii_name="toGetResolverRulePolicy")
    def to_get_resolver_rule_policy(self) -> "Route53resolver":
        '''(experimental) Grants permission to get information about a Resolver rule policy, which specifies the Resolver operations and resources that you want to allow another AWS account to use.

        Access Level: Read

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_route53resolver_GetResolverRulePolicy.html

        :stability: experimental
        '''
        return typing.cast("Route53resolver", jsii.invoke(self, "toGetResolverRulePolicy", []))

    @jsii.member(jsii_name="toImportFirewallDomains")
    def to_import_firewall_domains(self) -> "Route53resolver":
        '''(experimental) Grants permission to add, remove or replace Firewall domains in a Firewall domain list.

        Access Level: Write

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_route53resolver_ImportFirewallDomains.html

        :stability: experimental
        '''
        return typing.cast("Route53resolver", jsii.invoke(self, "toImportFirewallDomains", []))

    @jsii.member(jsii_name="toListFirewallConfigs")
    def to_list_firewall_configs(self) -> "Route53resolver":
        '''(experimental) Grants permission to list all the Firewall config that current AWS account is able to check.

        Access Level: List

        Dependent actions:

        - ec2:DescribeVpcs

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_route53resolver_ListFirewallConfigs.html

        :stability: experimental
        '''
        return typing.cast("Route53resolver", jsii.invoke(self, "toListFirewallConfigs", []))

    @jsii.member(jsii_name="toListFirewallDomainLists")
    def to_list_firewall_domain_lists(self) -> "Route53resolver":
        '''(experimental) Grants permission to list all the Firewall domain list that current AWS account is able to use.

        Access Level: List

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_route53resolver_ListFirewallDomainLists.html

        :stability: experimental
        '''
        return typing.cast("Route53resolver", jsii.invoke(self, "toListFirewallDomainLists", []))

    @jsii.member(jsii_name="toListFirewallDomains")
    def to_list_firewall_domains(self) -> "Route53resolver":
        '''(experimental) Grants permission to list all the Firewall domain under a speicfied Firewall domain list.

        Access Level: List

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_route53resolver_ListFirewallDomains.html

        :stability: experimental
        '''
        return typing.cast("Route53resolver", jsii.invoke(self, "toListFirewallDomains", []))

    @jsii.member(jsii_name="toListFirewallRuleGroupAssociations")
    def to_list_firewall_rule_group_associations(self) -> "Route53resolver":
        '''(experimental) Grants permission to list information about associations between Amazon VPCs and Firewall rule group.

        Access Level: List

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_route53resolver_ListFirewallRuleGroupAssociations.html

        :stability: experimental
        '''
        return typing.cast("Route53resolver", jsii.invoke(self, "toListFirewallRuleGroupAssociations", []))

    @jsii.member(jsii_name="toListFirewallRuleGroups")
    def to_list_firewall_rule_groups(self) -> "Route53resolver":
        '''(experimental) Grants permission to list all the Firewall rule group that current AWS account is able to use.

        Access Level: List

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_route53resolver_ListFirewallRuleGroups.html

        :stability: experimental
        '''
        return typing.cast("Route53resolver", jsii.invoke(self, "toListFirewallRuleGroups", []))

    @jsii.member(jsii_name="toListFirewallRules")
    def to_list_firewall_rules(self) -> "Route53resolver":
        '''(experimental) Grants permission to list all the Firewall rule under a speicfied Firewall rule group.

        Access Level: List

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_route53resolver_ListFirewallRules.html

        :stability: experimental
        '''
        return typing.cast("Route53resolver", jsii.invoke(self, "toListFirewallRules", []))

    @jsii.member(jsii_name="toListResolverConfigs")
    def to_list_resolver_configs(self) -> "Route53resolver":
        '''(experimental) Grants permission to list Resolver Config statuses.

        Access Level: List

        Dependent actions:

        - ec2:DescribeVpcs

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_route53resolver_ListResolverConfigs.html

        :stability: experimental
        '''
        return typing.cast("Route53resolver", jsii.invoke(self, "toListResolverConfigs", []))

    @jsii.member(jsii_name="toListResolverDnssecConfigs")
    def to_list_resolver_dnssec_configs(self) -> "Route53resolver":
        '''(experimental) Grants permission to list the DNSSEC validation support status for DNS queries.

        Access Level: List

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_route53resolver_ListResolverDnssecConfigs.html

        :stability: experimental
        '''
        return typing.cast("Route53resolver", jsii.invoke(self, "toListResolverDnssecConfigs", []))

    @jsii.member(jsii_name="toListResolverEndpointIpAddresses")
    def to_list_resolver_endpoint_ip_addresses(self) -> "Route53resolver":
        '''(experimental) Grants permission to list the IP addresses that DNS queries pass through on the way to your network (outbound) or your VPCs (inbound) for a specified Resolver endpoint.

        Access Level: List

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_route53resolver_ListResolverEndpointIpAddresses.html

        :stability: experimental
        '''
        return typing.cast("Route53resolver", jsii.invoke(self, "toListResolverEndpointIpAddresses", []))

    @jsii.member(jsii_name="toListResolverEndpoints")
    def to_list_resolver_endpoints(self) -> "Route53resolver":
        '''(experimental) Grants permission to list all the Resolver endpoints that were created using the current AWS account.

        Access Level: List

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_route53resolver_ListResolverEndpoints.html

        :stability: experimental
        '''
        return typing.cast("Route53resolver", jsii.invoke(self, "toListResolverEndpoints", []))

    @jsii.member(jsii_name="toListResolverQueryLogConfigAssociations")
    def to_list_resolver_query_log_config_associations(self) -> "Route53resolver":
        '''(experimental) Grants permission to list information about associations between Amazon VPCs and query logging configurations.

        Access Level: List

        Dependent actions:

        - ec2:DescribeVpcs

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_route53resolver_ListResolverQueryLogConfigAssociations.html

        :stability: experimental
        '''
        return typing.cast("Route53resolver", jsii.invoke(self, "toListResolverQueryLogConfigAssociations", []))

    @jsii.member(jsii_name="toListResolverQueryLogConfigs")
    def to_list_resolver_query_log_configs(self) -> "Route53resolver":
        '''(experimental) Grants permission to list information about the specified query logging configurations, which define where you want Resolver to save DNS query logs and specify the VPCs that you want to log queries for.

        Access Level: List

        Dependent actions:

        - ec2:DescribeVpcs

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_route53resolver_ListResolverQueryLogConfigs.html

        :stability: experimental
        '''
        return typing.cast("Route53resolver", jsii.invoke(self, "toListResolverQueryLogConfigs", []))

    @jsii.member(jsii_name="toListResolverRuleAssociations")
    def to_list_resolver_rule_associations(self) -> "Route53resolver":
        '''(experimental) Grants permission to list the associations that were created between Resolver rules and VPCs using the current AWS account.

        Access Level: List

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_route53resolver_ListResolverRuleAssociations.html

        :stability: experimental
        '''
        return typing.cast("Route53resolver", jsii.invoke(self, "toListResolverRuleAssociations", []))

    @jsii.member(jsii_name="toListResolverRules")
    def to_list_resolver_rules(self) -> "Route53resolver":
        '''(experimental) Grants permission to list the Resolver rules that were created using the current AWS account.

        Access Level: List

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_route53resolver_ListResolverRules.html

        :stability: experimental
        '''
        return typing.cast("Route53resolver", jsii.invoke(self, "toListResolverRules", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Route53resolver":
        '''(experimental) Grants permission to list the tags that you associated with the specified resource.

        Access Level: Read

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_route53resolver_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("Route53resolver", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toPutFirewallRuleGroupPolicy")
    def to_put_firewall_rule_group_policy(self) -> "Route53resolver":
        '''(experimental) Grants permission to specify an AWS account that you want to share a Firewall rule group with, the Firewall rule group that you want to share, and the operations that you want the account to be able to perform on the configuration.

        Access Level: Permissions management

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_route53resolver_PutFirewallRuleGroupPolicy.html

        :stability: experimental
        '''
        return typing.cast("Route53resolver", jsii.invoke(self, "toPutFirewallRuleGroupPolicy", []))

    @jsii.member(jsii_name="toPutResolverQueryLogConfigPolicy")
    def to_put_resolver_query_log_config_policy(self) -> "Route53resolver":
        '''(experimental) Grants permission to specify an AWS account that you want to share a query logging configuration with, the query logging configuration that you want to share, and the operations that you want the account to be able to perform on the configuration.

        Access Level: Permissions management

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_route53resolver_PutResolverQueryLogConfigPolicy.html

        :stability: experimental
        '''
        return typing.cast("Route53resolver", jsii.invoke(self, "toPutResolverQueryLogConfigPolicy", []))

    @jsii.member(jsii_name="toPutResolverRulePolicy")
    def to_put_resolver_rule_policy(self) -> "Route53resolver":
        '''(experimental) Grants permission to specify an AWS account that you want to share rules with, the Resolver rules that you want to share, and the operations that you want the account to be able to perform on those rules.

        Access Level: Permissions management

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_route53resolver_PutResolverRulePolicy.html

        :stability: experimental
        '''
        return typing.cast("Route53resolver", jsii.invoke(self, "toPutResolverRulePolicy", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Route53resolver":
        '''(experimental) Grants permission to add one or more tags to a specified resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_route53resolver_TagResource.html

        :stability: experimental
        '''
        return typing.cast("Route53resolver", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Route53resolver":
        '''(experimental) Grants permission to remove one or more tags from a specified resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_route53resolver_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("Route53resolver", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateFirewallConfig")
    def to_update_firewall_config(self) -> "Route53resolver":
        '''(experimental) Grants permission to update selected settings for an Firewall config.

        Access Level: Write

        Dependent actions:

        - ec2:DescribeVpcs

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_route53resolver_UpdateFirewallConfig.html

        :stability: experimental
        '''
        return typing.cast("Route53resolver", jsii.invoke(self, "toUpdateFirewallConfig", []))

    @jsii.member(jsii_name="toUpdateFirewallDomains")
    def to_update_firewall_domains(self) -> "Route53resolver":
        '''(experimental) Grants permission to add, remove or replace Firewall domains in a Firewall domain list.

        Access Level: Write

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_route53resolver_UpdateFirewallDomains.html

        :stability: experimental
        '''
        return typing.cast("Route53resolver", jsii.invoke(self, "toUpdateFirewallDomains", []))

    @jsii.member(jsii_name="toUpdateFirewallRule")
    def to_update_firewall_rule(self) -> "Route53resolver":
        '''(experimental) Grants permission to update selected settings for an Firewall rule in a Firewall rule group.

        Access Level: Write

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_route53resolver_UpdateFirewallRule.html

        :stability: experimental
        '''
        return typing.cast("Route53resolver", jsii.invoke(self, "toUpdateFirewallRule", []))

    @jsii.member(jsii_name="toUpdateFirewallRuleGroupAssociation")
    def to_update_firewall_rule_group_association(self) -> "Route53resolver":
        '''(experimental) Grants permission to update selected settings for an Firewall rule group association.

        Access Level: Write

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_route53resolver_UpdateFirewallRuleGroupAssociation.html

        :stability: experimental
        '''
        return typing.cast("Route53resolver", jsii.invoke(self, "toUpdateFirewallRuleGroupAssociation", []))

    @jsii.member(jsii_name="toUpdateResolverConfig")
    def to_update_resolver_config(self) -> "Route53resolver":
        '''(experimental) Grants permission to update the Resolver Config status within the specified resource.

        Access Level: Write

        Dependent actions:

        - ec2:DescribeVpcs

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_route53resolver_UpdateResolverConfig.html

        :stability: experimental
        '''
        return typing.cast("Route53resolver", jsii.invoke(self, "toUpdateResolverConfig", []))

    @jsii.member(jsii_name="toUpdateResolverDnssecConfig")
    def to_update_resolver_dnssec_config(self) -> "Route53resolver":
        '''(experimental) Grants permission to update the DNSSEC validation support status for DNS queries within the specified resource.

        Access Level: Write

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_route53resolver_UpdateResolverDnssecConfig.html

        :stability: experimental
        '''
        return typing.cast("Route53resolver", jsii.invoke(self, "toUpdateResolverDnssecConfig", []))

    @jsii.member(jsii_name="toUpdateResolverEndpoint")
    def to_update_resolver_endpoint(self) -> "Route53resolver":
        '''(experimental) Grants permission to update selected settings for an inbound or an outbound Resolver endpoint.

        Access Level: Write

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_route53resolver_UpdateResolverEndpoint.html

        :stability: experimental
        '''
        return typing.cast("Route53resolver", jsii.invoke(self, "toUpdateResolverEndpoint", []))

    @jsii.member(jsii_name="toUpdateResolverRule")
    def to_update_resolver_rule(self) -> "Route53resolver":
        '''(experimental) Grants permission to update settings for a specified Resolver rule.

        Access Level: Write

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_route53resolver_UpdateResolverRule.html

        :stability: experimental
        '''
        return typing.cast("Route53resolver", jsii.invoke(self, "toUpdateResolverRule", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6ec65403b3b0199da57088dda2e62a2efc00029738edee74e866fa64e1efb3c8)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fede4e4d0d46d4bfc3add549098f0cee165be729ad698af32eeb0afe92221eb1)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Rum(PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Rum"):
    '''(experimental) Statement provider for service `rum <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awscloudwatchrum.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `rum <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awscloudwatchrum.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onAppMonitorResource")
    def on_app_monitor_resource(
        self,
        name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Rum":
        '''(experimental) Adds a resource of type AppMonitorResource to the statement.

        https://docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/API_AppMonitor.html

        :param name: - Identifier for the name.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__eb8ec129d76c83242d20950112c2e42fa7630cfd88b2cef2abd5fc9f1f563021)
            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Rum", jsii.invoke(self, "onAppMonitorResource", [name, account, region, partition]))

    @jsii.member(jsii_name="toBatchCreateRumMetricDefinitions")
    def to_batch_create_rum_metric_definitions(self) -> "Rum":
        '''(experimental) Grants permission to create rum metric definitions.

        Access Level: Write

        https://docs.aws.amazon.com/cloudwatchrum/latest/APIReference/API_BatchCreateRumMetricDefinitions.html

        :stability: experimental
        '''
        return typing.cast("Rum", jsii.invoke(self, "toBatchCreateRumMetricDefinitions", []))

    @jsii.member(jsii_name="toBatchDeleteRumMetricDefinitions")
    def to_batch_delete_rum_metric_definitions(self) -> "Rum":
        '''(experimental) Grants permission to remove rum metric definitions.

        Access Level: Write

        https://docs.aws.amazon.com/cloudwatchrum/latest/APIReference/API_BatchDeleteRumMetricDefinitions.html

        :stability: experimental
        '''
        return typing.cast("Rum", jsii.invoke(self, "toBatchDeleteRumMetricDefinitions", []))

    @jsii.member(jsii_name="toBatchGetRumMetricDefinitions")
    def to_batch_get_rum_metric_definitions(self) -> "Rum":
        '''(experimental) Grants permission to get rum metric definitions.

        Access Level: Read

        https://docs.aws.amazon.com/cloudwatchrum/latest/APIReference/API_BatchGetRumMetricDefinitions.html

        :stability: experimental
        '''
        return typing.cast("Rum", jsii.invoke(self, "toBatchGetRumMetricDefinitions", []))

    @jsii.member(jsii_name="toCreateAppMonitor")
    def to_create_app_monitor(self) -> "Rum":
        '''(experimental) Grants permission to create appMonitor metadata.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - iam:CreateServiceLinkedRole
        - iam:GetRole

        https://docs.aws.amazon.com/cloudwatchrum/latest/APIReference/API_CreateAppMonitor.html

        :stability: experimental
        '''
        return typing.cast("Rum", jsii.invoke(self, "toCreateAppMonitor", []))

    @jsii.member(jsii_name="toDeleteAppMonitor")
    def to_delete_app_monitor(self) -> "Rum":
        '''(experimental) Grants permission to delete appMonitor metadata.

        Access Level: Write

        https://docs.aws.amazon.com/cloudwatchrum/latest/APIReference/API_DeleteAppMonitor.html

        :stability: experimental
        '''
        return typing.cast("Rum", jsii.invoke(self, "toDeleteAppMonitor", []))

    @jsii.member(jsii_name="toDeleteRumMetricsDestination")
    def to_delete_rum_metrics_destination(self) -> "Rum":
        '''(experimental) Grants permission to delete rum metrics destinations.

        Access Level: Write

        https://docs.aws.amazon.com/cloudwatchrum/latest/APIReference/API_DeleteRumMetricsDestination.html

        :stability: experimental
        '''
        return typing.cast("Rum", jsii.invoke(self, "toDeleteRumMetricsDestination", []))

    @jsii.member(jsii_name="toGetAppMonitor")
    def to_get_app_monitor(self) -> "Rum":
        '''(experimental) Grants permission to get appMonitor metadata.

        Access Level: Read

        https://docs.aws.amazon.com/cloudwatchrum/latest/APIReference/API_GetAppMonitor.html

        :stability: experimental
        '''
        return typing.cast("Rum", jsii.invoke(self, "toGetAppMonitor", []))

    @jsii.member(jsii_name="toGetAppMonitorData")
    def to_get_app_monitor_data(self) -> "Rum":
        '''(experimental) Grants permission to get appMonitor data.

        Access Level: Read

        https://docs.aws.amazon.com/cloudwatchrum/latest/APIReference/API_GetAppMonitorData.html

        :stability: experimental
        '''
        return typing.cast("Rum", jsii.invoke(self, "toGetAppMonitorData", []))

    @jsii.member(jsii_name="toListAppMonitors")
    def to_list_app_monitors(self) -> "Rum":
        '''(experimental) Grants permission to list appMonitors metadata.

        Access Level: List

        https://docs.aws.amazon.com/cloudwatchrum/latest/APIReference/API_ListAppMonitors.html

        :stability: experimental
        '''
        return typing.cast("Rum", jsii.invoke(self, "toListAppMonitors", []))

    @jsii.member(jsii_name="toListRumMetricsDestinations")
    def to_list_rum_metrics_destinations(self) -> "Rum":
        '''(experimental) Grants permission to list rum metrics destinations.

        Access Level: Read

        https://docs.aws.amazon.com/cloudwatchrum/latest/APIReference/API_ListRumMetricsDestinations.html

        :stability: experimental
        '''
        return typing.cast("Rum", jsii.invoke(self, "toListRumMetricsDestinations", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Rum":
        '''(experimental) Grants permission to list tags for resources.

        Access Level: Read

        https://docs.aws.amazon.com/cloudwatchrum/latest/APIReference/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("Rum", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toPutRumEvents")
    def to_put_rum_events(self) -> "Rum":
        '''(experimental) Grants permission to put RUM events for appmonitor.

        Access Level: Write

        https://docs.aws.amazon.com/cloudwatchrum/latest/APIReference/API_PutRumEvents.html

        :stability: experimental
        '''
        return typing.cast("Rum", jsii.invoke(self, "toPutRumEvents", []))

    @jsii.member(jsii_name="toPutRumMetricsDestination")
    def to_put_rum_metrics_destination(self) -> "Rum":
        '''(experimental) Grants permission to put rum metrics destinations.

        Access Level: Write

        https://docs.aws.amazon.com/cloudwatchrum/latest/APIReference/API_PutRumMetricsDestination.html

        :stability: experimental
        '''
        return typing.cast("Rum", jsii.invoke(self, "toPutRumMetricsDestination", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Rum":
        '''(experimental) Grants permission to tag resources.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/cloudwatchrum/latest/APIReference/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("Rum", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Rum":
        '''(experimental) Grants permission to untag resources.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/cloudwatchrum/latest/APIReference/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("Rum", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateAppMonitor")
    def to_update_app_monitor(self) -> "Rum":
        '''(experimental) Grants permission to update appmonitor metadata.

        Access Level: Write

        Dependent actions:

        - iam:CreateServiceLinkedRole
        - iam:GetRole

        https://docs.aws.amazon.com/cloudwatchrum/latest/APIReference/API_UpdateAppMonitor.html

        :stability: experimental
        '''
        return typing.cast("Rum", jsii.invoke(self, "toUpdateAppMonitor", []))

    @jsii.member(jsii_name="toUpdateRumMetricDefinition")
    def to_update_rum_metric_definition(self) -> "Rum":
        '''(experimental) Grants permission to update rum metric definition.

        Access Level: Write

        https://docs.aws.amazon.com/cloudwatchrum/latest/APIReference/API_UpdateRumMetricDefinition.html

        :stability: experimental
        '''
        return typing.cast("Rum", jsii.invoke(self, "toUpdateRumMetricDefinition", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__336939fc6223992984d7cdd9dd05593470fce9b17ebc44f662b198ad4654b99b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__38e42be3be4fefb83b9093e5e6b37dae78e919b3bb64ad56f2e3ada3a517d113)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class S3(PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.S3"):
    '''(experimental) Statement provider for service `s3 <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazons3.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `s3 <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazons3.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="ifAccessPointNetworkOrigin")
    def if_access_point_network_origin(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "S3":
        '''(experimental) Filters access by the network origin (Internet or VPC).

        https://docs.aws.amazon.com/AmazonS3/latest/userguide/creating-access-points.html#access-points-policies

        Applies to actions:

        - .toAbortMultipartUpload()
        - .toBypassGovernanceRetention()
        - .toCreateAccessPoint()
        - .toCreateAccessPointForObjectLambda()
        - .toCreateMultiRegionAccessPoint()
        - .toDeleteAccessPoint()
        - .toDeleteAccessPointForObjectLambda()
        - .toDeleteAccessPointPolicy()
        - .toDeleteAccessPointPolicyForObjectLambda()
        - .toDeleteMultiRegionAccessPoint()
        - .toDeleteObject()
        - .toDeleteObjectTagging()
        - .toDeleteObjectVersion()
        - .toDeleteObjectVersionTagging()
        - .toGetAccessPoint()
        - .toGetAccessPointConfigurationForObjectLambda()
        - .toGetAccessPointForObjectLambda()
        - .toGetAccessPointPolicy()
        - .toGetAccessPointPolicyForObjectLambda()
        - .toGetAccessPointPolicyStatus()
        - .toGetAccessPointPolicyStatusForObjectLambda()
        - .toGetMultiRegionAccessPoint()
        - .toGetMultiRegionAccessPointPolicy()
        - .toGetMultiRegionAccessPointPolicyStatus()
        - .toGetMultiRegionAccessPointRoutes()
        - .toGetObject()
        - .toGetObjectAcl()
        - .toGetObjectAttributes()
        - .toGetObjectLegalHold()
        - .toGetObjectRetention()
        - .toGetObjectTagging()
        - .toGetObjectVersion()
        - .toGetObjectVersionAcl()
        - .toGetObjectVersionAttributes()
        - .toGetObjectVersionTagging()
        - .toListBucket()
        - .toListBucketMultipartUploads()
        - .toListBucketVersions()
        - .toListMultipartUploadParts()
        - .toPutAccessPointConfigurationForObjectLambda()
        - .toPutAccessPointPolicy()
        - .toPutAccessPointPolicyForObjectLambda()
        - .toPutMultiRegionAccessPointPolicy()
        - .toPutObject()
        - .toPutObjectAcl()
        - .toPutObjectLegalHold()
        - .toPutObjectRetention()
        - .toPutObjectTagging()
        - .toPutObjectVersionAcl()
        - .toPutObjectVersionTagging()
        - .toRestoreObject()
        - .toSubmitMultiRegionAccessPointRoutes()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a031360ab57e1a655a950ed834c827dade58f3fdcc6b23fca876373a2545686f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("S3", jsii.invoke(self, "ifAccessPointNetworkOrigin", [value, operator]))

    @jsii.member(jsii_name="ifAuthType")
    def if_auth_type(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "S3":
        '''(experimental) Filters access by authentication method.

        https://docs.aws.amazon.com/AmazonS3/latest/API/bucket-policy-s3-sigv4-conditions.html

        Applies to actions:

        - .toAbortMultipartUpload()
        - .toBypassGovernanceRetention()
        - .toCreateAccessPoint()
        - .toCreateAccessPointForObjectLambda()
        - .toCreateBucket()
        - .toCreateJob()
        - .toCreateMultiRegionAccessPoint()
        - .toDeleteAccessPoint()
        - .toDeleteAccessPointForObjectLambda()
        - .toDeleteAccessPointPolicy()
        - .toDeleteAccessPointPolicyForObjectLambda()
        - .toDeleteBucket()
        - .toDeleteBucketPolicy()
        - .toDeleteBucketWebsite()
        - .toDeleteJobTagging()
        - .toDeleteMultiRegionAccessPoint()
        - .toDeleteObject()
        - .toDeleteObjectTagging()
        - .toDeleteObjectVersion()
        - .toDeleteObjectVersionTagging()
        - .toDeleteStorageLensConfiguration()
        - .toDeleteStorageLensConfigurationTagging()
        - .toDescribeJob()
        - .toDescribeMultiRegionAccessPointOperation()
        - .toGetAccelerateConfiguration()
        - .toGetAccessPoint()
        - .toGetAccessPointConfigurationForObjectLambda()
        - .toGetAccessPointForObjectLambda()
        - .toGetAccessPointPolicy()
        - .toGetAccessPointPolicyForObjectLambda()
        - .toGetAccessPointPolicyStatus()
        - .toGetAccessPointPolicyStatusForObjectLambda()
        - .toGetAccountPublicAccessBlock()
        - .toGetAnalyticsConfiguration()
        - .toGetBucketAcl()
        - .toGetBucketCORS()
        - .toGetBucketLocation()
        - .toGetBucketLogging()
        - .toGetBucketNotification()
        - .toGetBucketObjectLockConfiguration()
        - .toGetBucketOwnershipControls()
        - .toGetBucketPolicy()
        - .toGetBucketPolicyStatus()
        - .toGetBucketPublicAccessBlock()
        - .toGetBucketRequestPayment()
        - .toGetBucketTagging()
        - .toGetBucketVersioning()
        - .toGetBucketWebsite()
        - .toGetEncryptionConfiguration()
        - .toGetIntelligentTieringConfiguration()
        - .toGetInventoryConfiguration()
        - .toGetJobTagging()
        - .toGetLifecycleConfiguration()
        - .toGetMetricsConfiguration()
        - .toGetMultiRegionAccessPoint()
        - .toGetMultiRegionAccessPointPolicy()
        - .toGetMultiRegionAccessPointPolicyStatus()
        - .toGetMultiRegionAccessPointRoutes()
        - .toGetObject()
        - .toGetObjectAcl()
        - .toGetObjectAttributes()
        - .toGetObjectLegalHold()
        - .toGetObjectRetention()
        - .toGetObjectTagging()
        - .toGetObjectTorrent()
        - .toGetObjectVersion()
        - .toGetObjectVersionAcl()
        - .toGetObjectVersionAttributes()
        - .toGetObjectVersionForReplication()
        - .toGetObjectVersionTagging()
        - .toGetObjectVersionTorrent()
        - .toGetReplicationConfiguration()
        - .toGetStorageLensConfiguration()
        - .toGetStorageLensConfigurationTagging()
        - .toGetStorageLensDashboard()
        - .toListAccessPoints()
        - .toListAccessPointsForObjectLambda()
        - .toListAllMyBuckets()
        - .toListBucket()
        - .toListBucketMultipartUploads()
        - .toListBucketVersions()
        - .toListJobs()
        - .toListMultiRegionAccessPoints()
        - .toListMultipartUploadParts()
        - .toListStorageLensConfigurations()
        - .toObjectOwnerOverrideToBucketOwner()
        - .toPutAccelerateConfiguration()
        - .toPutAccessPointConfigurationForObjectLambda()
        - .toPutAccessPointPolicy()
        - .toPutAccessPointPolicyForObjectLambda()
        - .toPutAccountPublicAccessBlock()
        - .toPutAnalyticsConfiguration()
        - .toPutBucketAcl()
        - .toPutBucketCORS()
        - .toPutBucketLogging()
        - .toPutBucketNotification()
        - .toPutBucketObjectLockConfiguration()
        - .toPutBucketOwnershipControls()
        - .toPutBucketPolicy()
        - .toPutBucketPublicAccessBlock()
        - .toPutBucketRequestPayment()
        - .toPutBucketTagging()
        - .toPutBucketVersioning()
        - .toPutBucketWebsite()
        - .toPutEncryptionConfiguration()
        - .toPutIntelligentTieringConfiguration()
        - .toPutInventoryConfiguration()
        - .toPutJobTagging()
        - .toPutLifecycleConfiguration()
        - .toPutMetricsConfiguration()
        - .toPutMultiRegionAccessPointPolicy()
        - .toPutObject()
        - .toPutObjectAcl()
        - .toPutObjectLegalHold()
        - .toPutObjectRetention()
        - .toPutObjectTagging()
        - .toPutObjectVersionAcl()
        - .toPutObjectVersionTagging()
        - .toPutReplicationConfiguration()
        - .toPutStorageLensConfiguration()
        - .toPutStorageLensConfigurationTagging()
        - .toReplicateDelete()
        - .toReplicateObject()
        - .toReplicateTags()
        - .toRestoreObject()
        - .toSubmitMultiRegionAccessPointRoutes()
        - .toUpdateJobPriority()
        - .toUpdateJobStatus()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4d0ba00c484092bff16ab56a08fc98d95cf74e62c6e1bef21cd40cb8479d6fe1)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("S3", jsii.invoke(self, "ifAuthType", [value, operator]))

    @jsii.member(jsii_name="ifDataAccessPointAccount")
    def if_data_access_point_account(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "S3":
        '''(experimental) Filters access by the AWS Account ID that owns the access point.

        https://docs.aws.amazon.com/AmazonS3/latest/userguide/creating-access-points.html#access-points-policies

        Applies to actions:

        - .toAbortMultipartUpload()
        - .toBypassGovernanceRetention()
        - .toCreateAccessPoint()
        - .toCreateAccessPointForObjectLambda()
        - .toCreateMultiRegionAccessPoint()
        - .toDeleteAccessPoint()
        - .toDeleteAccessPointForObjectLambda()
        - .toDeleteAccessPointPolicy()
        - .toDeleteAccessPointPolicyForObjectLambda()
        - .toDeleteMultiRegionAccessPoint()
        - .toDeleteObject()
        - .toDeleteObjectTagging()
        - .toDeleteObjectVersion()
        - .toDeleteObjectVersionTagging()
        - .toGetAccessPoint()
        - .toGetAccessPointConfigurationForObjectLambda()
        - .toGetAccessPointForObjectLambda()
        - .toGetAccessPointPolicy()
        - .toGetAccessPointPolicyForObjectLambda()
        - .toGetAccessPointPolicyStatus()
        - .toGetAccessPointPolicyStatusForObjectLambda()
        - .toGetMultiRegionAccessPoint()
        - .toGetMultiRegionAccessPointPolicy()
        - .toGetMultiRegionAccessPointPolicyStatus()
        - .toGetMultiRegionAccessPointRoutes()
        - .toGetObject()
        - .toGetObjectAcl()
        - .toGetObjectAttributes()
        - .toGetObjectLegalHold()
        - .toGetObjectRetention()
        - .toGetObjectTagging()
        - .toGetObjectVersion()
        - .toGetObjectVersionAcl()
        - .toGetObjectVersionAttributes()
        - .toGetObjectVersionTagging()
        - .toListBucket()
        - .toListBucketMultipartUploads()
        - .toListBucketVersions()
        - .toListMultipartUploadParts()
        - .toPutAccessPointConfigurationForObjectLambda()
        - .toPutAccessPointPolicy()
        - .toPutAccessPointPolicyForObjectLambda()
        - .toPutMultiRegionAccessPointPolicy()
        - .toPutObject()
        - .toPutObjectAcl()
        - .toPutObjectLegalHold()
        - .toPutObjectRetention()
        - .toPutObjectTagging()
        - .toPutObjectVersionAcl()
        - .toPutObjectVersionTagging()
        - .toRestoreObject()
        - .toSubmitMultiRegionAccessPointRoutes()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f86531121a99aaaa83ce23b07e579df5e383ce660045f68b3a05317db89985cf)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("S3", jsii.invoke(self, "ifDataAccessPointAccount", [value, operator]))

    @jsii.member(jsii_name="ifDataAccessPointArn")
    def if_data_access_point_arn(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "S3":
        '''(experimental) Filters access by an access point Amazon Resource Name (ARN).

        https://docs.aws.amazon.com/AmazonS3/latest/userguide/creating-access-points.html#access-points-policies

        Applies to actions:

        - .toAbortMultipartUpload()
        - .toBypassGovernanceRetention()
        - .toCreateAccessPoint()
        - .toCreateAccessPointForObjectLambda()
        - .toCreateMultiRegionAccessPoint()
        - .toDeleteAccessPoint()
        - .toDeleteAccessPointForObjectLambda()
        - .toDeleteAccessPointPolicy()
        - .toDeleteAccessPointPolicyForObjectLambda()
        - .toDeleteMultiRegionAccessPoint()
        - .toDeleteObject()
        - .toDeleteObjectTagging()
        - .toDeleteObjectVersion()
        - .toDeleteObjectVersionTagging()
        - .toGetAccessPoint()
        - .toGetAccessPointConfigurationForObjectLambda()
        - .toGetAccessPointForObjectLambda()
        - .toGetAccessPointPolicy()
        - .toGetAccessPointPolicyForObjectLambda()
        - .toGetAccessPointPolicyStatus()
        - .toGetAccessPointPolicyStatusForObjectLambda()
        - .toGetMultiRegionAccessPoint()
        - .toGetMultiRegionAccessPointPolicy()
        - .toGetMultiRegionAccessPointPolicyStatus()
        - .toGetMultiRegionAccessPointRoutes()
        - .toGetObject()
        - .toGetObjectAcl()
        - .toGetObjectAttributes()
        - .toGetObjectLegalHold()
        - .toGetObjectRetention()
        - .toGetObjectTagging()
        - .toGetObjectVersion()
        - .toGetObjectVersionAcl()
        - .toGetObjectVersionAttributes()
        - .toGetObjectVersionTagging()
        - .toListBucket()
        - .toListBucketMultipartUploads()
        - .toListBucketVersions()
        - .toListMultipartUploadParts()
        - .toPutAccessPointConfigurationForObjectLambda()
        - .toPutAccessPointPolicy()
        - .toPutAccessPointPolicyForObjectLambda()
        - .toPutMultiRegionAccessPointPolicy()
        - .toPutObject()
        - .toPutObjectAcl()
        - .toPutObjectLegalHold()
        - .toPutObjectRetention()
        - .toPutObjectTagging()
        - .toPutObjectVersionAcl()
        - .toPutObjectVersionTagging()
        - .toRestoreObject()
        - .toSubmitMultiRegionAccessPointRoutes()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8f9b56cd502a3294c0bbc1e3dee2aaa540f65f0f3512247d43e7590a6ddded9d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("S3", jsii.invoke(self, "ifDataAccessPointArn", [value, operator]))

    @jsii.member(jsii_name="ifDelimiter")
    def if_delimiter(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "S3":
        '''(experimental) Filters access by delimiter parameter.

        https://docs.aws.amazon.com/AmazonS3/latest/userguide/walkthrough1.html

        Applies to actions:

        - .toListBucket()
        - .toListBucketVersions()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ad27c5e372b0e3a7713fdf29d285eae3da395e921ddb4864db638d54a1735550)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("S3", jsii.invoke(self, "ifDelimiter", [value, operator]))

    @jsii.member(jsii_name="ifExistingJobOperation")
    def if_existing_job_operation(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "S3":
        '''(experimental) Filters access by operation to updating the job priority.

        https://docs.aws.amazon.com/AmazonS3/latest/userguide/batch-ops-job-tags-examples.html

        Applies to actions:

        - .toDeleteJobTagging()
        - .toPutJobTagging()
        - .toUpdateJobPriority()
        - .toUpdateJobStatus()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__659c06ff0153ebbf19804e7860e35e095e41eacc2cc8a28691dd785f7106dbf5)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("S3", jsii.invoke(self, "ifExistingJobOperation", [value, operator]))

    @jsii.member(jsii_name="ifExistingJobPriority")
    def if_existing_job_priority(
        self,
        value: typing.Union[jsii.Number, typing.Sequence[jsii.Number]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "S3":
        '''(experimental) Filters access by priority range to cancelling existing jobs.

        https://docs.aws.amazon.com/AmazonS3/latest/userguide/batch-ops-job-tags-examples.html

        Applies to actions:

        - .toDeleteJobTagging()
        - .toPutJobTagging()
        - .toUpdateJobPriority()
        - .toUpdateJobStatus()

        :param value: The value(s) to check.
        :param operator: Works with `numeric operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_Numeric>`_. **Default:** ``NumericEquals``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7d7932dbf0bdf54ca842c00ebc82bb76b2a3be5bc7be44643c6b43b9e660b780)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("S3", jsii.invoke(self, "ifExistingJobPriority", [value, operator]))

    @jsii.member(jsii_name="ifExistingObjectTag")
    def if_existing_object_tag(
        self,
        key: builtins.str,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "S3":
        '''(experimental) Filters access by existing object tag key and value.

        https://docs.aws.amazon.com/AmazonS3/latest/userguide/object-tagging.html#tagging-and-policies

        Applies to actions:

        - .toDeleteObjectTagging()
        - .toDeleteObjectVersionTagging()
        - .toGetObject()
        - .toGetObjectAcl()
        - .toGetObjectAttributes()
        - .toGetObjectTagging()
        - .toGetObjectVersion()
        - .toGetObjectVersionAcl()
        - .toGetObjectVersionAttributes()
        - .toGetObjectVersionTagging()
        - .toPutObjectAcl()
        - .toPutObjectTagging()
        - .toPutObjectVersionAcl()
        - .toPutObjectVersionTagging()

        :param key: The tag key to check.
        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__123783c94b4c79cc49430460ad819b913d037c5d2f4226600908190f4d7592c8)
            check_type(argname="argument key", value=key, expected_type=type_hints["key"])
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("S3", jsii.invoke(self, "ifExistingObjectTag", [key, value, operator]))

    @jsii.member(jsii_name="ifJobSuspendedCause")
    def if_job_suspended_cause(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "S3":
        '''(experimental) Filters access by a specific job suspended cause (for example, AWAITING_CONFIRMATION) to cancelling suspended jobs.

        https://docs.aws.amazon.com/AmazonS3/latest/userguide/batch-ops-job-tags-examples.html

        Applies to actions:

        - .toUpdateJobStatus()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ae9ece27d57ffbe72314b4e8439337cffc202e1124b77d4e10c8c4e6913208eb)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("S3", jsii.invoke(self, "ifJobSuspendedCause", [value, operator]))

    @jsii.member(jsii_name="ifLocationconstraint")
    def if_locationconstraint(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "S3":
        '''(experimental) Filters access by a specific Region.

        https://docs.aws.amazon.com/AmazonS3/latest/userguide/amazon-s3-policy-keys.html#condition-key-bucket-ops-1

        Applies to actions:

        - .toCreateAccessPoint()
        - .toCreateBucket()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__76635c54a493d35e44291950c8f0e8d630ebf3c58377a7322f6140f7185294e9)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("S3", jsii.invoke(self, "ifLocationconstraint", [value, operator]))

    @jsii.member(jsii_name="ifMaxKeys")
    def if_max_keys(
        self,
        value: typing.Union[jsii.Number, typing.Sequence[jsii.Number]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "S3":
        '''(experimental) Filters access by maximum number of keys returned in a ListBucket request.

        https://docs.aws.amazon.com/AmazonS3/latest/userguide/amazon-s3-policy-keys.html#example-numeric-condition-operators

        Applies to actions:

        - .toListBucket()
        - .toListBucketVersions()

        :param value: The value(s) to check.
        :param operator: Works with `numeric operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_Numeric>`_. **Default:** ``NumericEquals``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__69ed959861794d188d782f7dea3562d1772ddb0f38896ec72e72e60200ae2e30)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("S3", jsii.invoke(self, "ifMaxKeys", [value, operator]))

    @jsii.member(jsii_name="ifObjectLockLegalHold")
    def if_object_lock_legal_hold(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "S3":
        '''(experimental) Filters access by object legal hold status.

        https://docs.aws.amazon.com/AmazonS3/latest/userguide/object-lock-overview.html#object-lock-legal-holds

        Applies to actions:

        - .toBypassGovernanceRetention()
        - .toPutObject()
        - .toPutObjectLegalHold()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5a4c8304aaadeb89b314cc64a9654f01a019eea84ae751ba2a5fc2c5c932e1c5)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("S3", jsii.invoke(self, "ifObjectLockLegalHold", [value, operator]))

    @jsii.member(jsii_name="ifObjectLockMode")
    def if_object_lock_mode(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "S3":
        '''(experimental) Filters access by object retention mode (COMPLIANCE or GOVERNANCE).

        https://docs.aws.amazon.com/AmazonS3/latest/userguide/object-lock-overview.html#object-lock-retention-modes

        Applies to actions:

        - .toBypassGovernanceRetention()
        - .toPutObject()
        - .toPutObjectRetention()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e614a9278eeef28b51fce29c94eb3cdfe9b2613374897202ab49998076fbb500)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("S3", jsii.invoke(self, "ifObjectLockMode", [value, operator]))

    @jsii.member(jsii_name="ifObjectLockRemainingRetentionDays")
    def if_object_lock_remaining_retention_days(
        self,
        value: typing.Union[jsii.Number, typing.Sequence[jsii.Number]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "S3":
        '''(experimental) Filters access by remaining object retention days.

        https://docs.aws.amazon.com/AmazonS3/latest/userguide/object-lock-managing.html#object-lock-managing-retention-limits

        Applies to actions:

        - .toBypassGovernanceRetention()
        - .toPutObject()
        - .toPutObjectRetention()

        :param value: The value(s) to check.
        :param operator: Works with `numeric operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_Numeric>`_. **Default:** ``NumericEquals``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__795dedc3ed8f3816ab3f91c2e8ce18063e52632174fa3a4e8305d8ca6c00720d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("S3", jsii.invoke(self, "ifObjectLockRemainingRetentionDays", [value, operator]))

    @jsii.member(jsii_name="ifObjectLockRetainUntilDate")
    def if_object_lock_retain_until_date(
        self,
        value: typing.Union[builtins.str, datetime.datetime, typing.Sequence[typing.Union[builtins.str, datetime.datetime]]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "S3":
        '''(experimental) Filters access by object retain-until date.

        https://docs.aws.amazon.com/AmazonS3/latest/userguide/object-lock-overview.html#object-lock-retention-periods

        Applies to actions:

        - .toBypassGovernanceRetention()
        - .toPutObject()
        - .toPutObjectRetention()

        :param value: The value(s) to check.
        :param operator: Works with `date operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_Date>`_. **Default:** ``DateEquals``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3aaa12a078045c7df277cb8795cfac7d22d535c2e22925a7d6b49e156967eca8)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("S3", jsii.invoke(self, "ifObjectLockRetainUntilDate", [value, operator]))

    @jsii.member(jsii_name="ifPrefix")
    def if_prefix(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "S3":
        '''(experimental) Filters access by key name prefix.

        https://docs.aws.amazon.com/AmazonS3/latest/userguide/amazon-s3-policy-keys.html#condition-key-bucket-ops-2

        Applies to actions:

        - .toListBucket()
        - .toListBucketVersions()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5c43924b9d2f7b929deed573955814c3d7a80c8677eab131a55a7118c3a709f4)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("S3", jsii.invoke(self, "ifPrefix", [value, operator]))

    @jsii.member(jsii_name="ifRequestJobOperation")
    def if_request_job_operation(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "S3":
        '''(experimental) Filters access by operation to creating jobs.

        https://docs.aws.amazon.com/AmazonS3/latest/userguide/batch-ops-job-tags-examples.html

        Applies to actions:

        - .toCreateJob()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a8eeb8671e1b4728a6618c27949ff8243c9608452e44cdaff50c23a515e5f86e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("S3", jsii.invoke(self, "ifRequestJobOperation", [value, operator]))

    @jsii.member(jsii_name="ifRequestJobPriority")
    def if_request_job_priority(
        self,
        value: typing.Union[jsii.Number, typing.Sequence[jsii.Number]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "S3":
        '''(experimental) Filters access by priority range to creating new jobs.

        https://docs.aws.amazon.com/AmazonS3/latest/userguide/batch-ops-job-tags-examples.html

        Applies to actions:

        - .toCreateJob()
        - .toUpdateJobPriority()

        :param value: The value(s) to check.
        :param operator: Works with `numeric operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_Numeric>`_. **Default:** ``NumericEquals``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ee338eb188f3182e3b6eb5dc6322a79e1a0849198ca16ff3c965cc28f2c737bb)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("S3", jsii.invoke(self, "ifRequestJobPriority", [value, operator]))

    @jsii.member(jsii_name="ifRequestObjectTag")
    def if_request_object_tag(
        self,
        key: builtins.str,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "S3":
        '''(experimental) Filters access by the tag keys and values to be added to objects.

        https://docs.aws.amazon.com/AmazonS3/latest/userguide/object-tagging.html#tagging-and-policies

        Applies to actions:

        - .toBypassGovernanceRetention()
        - .toPutObject()
        - .toPutObjectTagging()
        - .toPutObjectVersionTagging()

        :param key: The tag key to check.
        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d47c6ba0245d7c0fa6f357249c6098e7223835965e9607d8ef23a16dacc859c8)
            check_type(argname="argument key", value=key, expected_type=type_hints["key"])
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("S3", jsii.invoke(self, "ifRequestObjectTag", [key, value, operator]))

    @jsii.member(jsii_name="ifRequestObjectTagKeys")
    def if_request_object_tag_keys(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "S3":
        '''(experimental) Filters access by the tag keys to be added to objects.

        https://docs.aws.amazon.com/AmazonS3/latest/userguide/object-tagging.html#tagging-and-policies

        Applies to actions:

        - .toBypassGovernanceRetention()
        - .toPutObject()
        - .toPutObjectTagging()
        - .toPutObjectVersionTagging()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fce925b88dc774333aef6fda80d089fef1986d1a0f6f8a995b1b36481f53e09e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("S3", jsii.invoke(self, "ifRequestObjectTagKeys", [value, operator]))

    @jsii.member(jsii_name="ifResourceAccount")
    def if_resource_account(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "S3":
        '''(experimental) Filters access by the resource owner AWS account ID.

        https://docs.aws.amazon.com/AmazonS3/latest/userguide/amazon-s3-policy-keys.html#example-object-resource-account

        Applies to actions:

        - .toAbortMultipartUpload()
        - .toBypassGovernanceRetention()
        - .toCreateAccessPoint()
        - .toCreateAccessPointForObjectLambda()
        - .toCreateBucket()
        - .toCreateJob()
        - .toCreateMultiRegionAccessPoint()
        - .toDeleteAccessPoint()
        - .toDeleteAccessPointForObjectLambda()
        - .toDeleteAccessPointPolicy()
        - .toDeleteAccessPointPolicyForObjectLambda()
        - .toDeleteBucket()
        - .toDeleteBucketPolicy()
        - .toDeleteBucketWebsite()
        - .toDeleteJobTagging()
        - .toDeleteMultiRegionAccessPoint()
        - .toDeleteObject()
        - .toDeleteObjectTagging()
        - .toDeleteObjectVersion()
        - .toDeleteObjectVersionTagging()
        - .toDeleteStorageLensConfiguration()
        - .toDeleteStorageLensConfigurationTagging()
        - .toDescribeJob()
        - .toDescribeMultiRegionAccessPointOperation()
        - .toGetAccelerateConfiguration()
        - .toGetAccessPoint()
        - .toGetAccessPointConfigurationForObjectLambda()
        - .toGetAccessPointForObjectLambda()
        - .toGetAccessPointPolicy()
        - .toGetAccessPointPolicyForObjectLambda()
        - .toGetAccessPointPolicyStatus()
        - .toGetAccessPointPolicyStatusForObjectLambda()
        - .toGetAccountPublicAccessBlock()
        - .toGetAnalyticsConfiguration()
        - .toGetBucketAcl()
        - .toGetBucketCORS()
        - .toGetBucketLocation()
        - .toGetBucketLogging()
        - .toGetBucketNotification()
        - .toGetBucketObjectLockConfiguration()
        - .toGetBucketOwnershipControls()
        - .toGetBucketPolicy()
        - .toGetBucketPolicyStatus()
        - .toGetBucketPublicAccessBlock()
        - .toGetBucketRequestPayment()
        - .toGetBucketTagging()
        - .toGetBucketVersioning()
        - .toGetBucketWebsite()
        - .toGetEncryptionConfiguration()
        - .toGetIntelligentTieringConfiguration()
        - .toGetInventoryConfiguration()
        - .toGetJobTagging()
        - .toGetLifecycleConfiguration()
        - .toGetMetricsConfiguration()
        - .toGetMultiRegionAccessPoint()
        - .toGetMultiRegionAccessPointPolicy()
        - .toGetMultiRegionAccessPointPolicyStatus()
        - .toGetMultiRegionAccessPointRoutes()
        - .toGetObject()
        - .toGetObjectAcl()
        - .toGetObjectAttributes()
        - .toGetObjectLegalHold()
        - .toGetObjectRetention()
        - .toGetObjectTagging()
        - .toGetObjectTorrent()
        - .toGetObjectVersion()
        - .toGetObjectVersionAcl()
        - .toGetObjectVersionAttributes()
        - .toGetObjectVersionForReplication()
        - .toGetObjectVersionTagging()
        - .toGetObjectVersionTorrent()
        - .toGetReplicationConfiguration()
        - .toGetStorageLensConfiguration()
        - .toGetStorageLensConfigurationTagging()
        - .toGetStorageLensDashboard()
        - .toInitiateReplication()
        - .toListAccessPoints()
        - .toListAccessPointsForObjectLambda()
        - .toListAllMyBuckets()
        - .toListBucket()
        - .toListBucketMultipartUploads()
        - .toListBucketVersions()
        - .toListJobs()
        - .toListMultiRegionAccessPoints()
        - .toListMultipartUploadParts()
        - .toListStorageLensConfigurations()
        - .toObjectOwnerOverrideToBucketOwner()
        - .toPutAccelerateConfiguration()
        - .toPutAccessPointConfigurationForObjectLambda()
        - .toPutAccessPointPolicy()
        - .toPutAccessPointPolicyForObjectLambda()
        - .toPutAccountPublicAccessBlock()
        - .toPutAnalyticsConfiguration()
        - .toPutBucketAcl()
        - .toPutBucketCORS()
        - .toPutBucketLogging()
        - .toPutBucketNotification()
        - .toPutBucketObjectLockConfiguration()
        - .toPutBucketOwnershipControls()
        - .toPutBucketPolicy()
        - .toPutBucketPublicAccessBlock()
        - .toPutBucketRequestPayment()
        - .toPutBucketTagging()
        - .toPutBucketVersioning()
        - .toPutBucketWebsite()
        - .toPutEncryptionConfiguration()
        - .toPutIntelligentTieringConfiguration()
        - .toPutInventoryConfiguration()
        - .toPutJobTagging()
        - .toPutLifecycleConfiguration()
        - .toPutMetricsConfiguration()
        - .toPutMultiRegionAccessPointPolicy()
        - .toPutObject()
        - .toPutObjectAcl()
        - .toPutObjectLegalHold()
        - .toPutObjectRetention()
        - .toPutObjectTagging()
        - .toPutObjectVersionAcl()
        - .toPutObjectVersionTagging()
        - .toPutReplicationConfiguration()
        - .toPutStorageLensConfiguration()
        - .toPutStorageLensConfigurationTagging()
        - .toReplicateDelete()
        - .toReplicateObject()
        - .toReplicateTags()
        - .toRestoreObject()
        - .toSubmitMultiRegionAccessPointRoutes()
        - .toUpdateJobPriority()
        - .toUpdateJobStatus()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__eb4b9c72daa48dc85cc2402845b2556af9268f5a90e01b0a37c13456b259f17f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("S3", jsii.invoke(self, "ifResourceAccount", [value, operator]))

    @jsii.member(jsii_name="ifSignatureAge")
    def if_signature_age(
        self,
        value: typing.Union[jsii.Number, typing.Sequence[jsii.Number]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "S3":
        '''(experimental) Filters access by the age in milliseconds of the request signature.

        https://docs.aws.amazon.com/AmazonS3/latest/API/bucket-policy-s3-sigv4-conditions.html

        Applies to actions:

        - .toAbortMultipartUpload()
        - .toBypassGovernanceRetention()
        - .toCreateAccessPoint()
        - .toCreateAccessPointForObjectLambda()
        - .toCreateBucket()
        - .toCreateJob()
        - .toCreateMultiRegionAccessPoint()
        - .toDeleteAccessPoint()
        - .toDeleteAccessPointForObjectLambda()
        - .toDeleteAccessPointPolicy()
        - .toDeleteAccessPointPolicyForObjectLambda()
        - .toDeleteBucket()
        - .toDeleteBucketPolicy()
        - .toDeleteBucketWebsite()
        - .toDeleteJobTagging()
        - .toDeleteMultiRegionAccessPoint()
        - .toDeleteObject()
        - .toDeleteObjectTagging()
        - .toDeleteObjectVersion()
        - .toDeleteObjectVersionTagging()
        - .toDeleteStorageLensConfiguration()
        - .toDeleteStorageLensConfigurationTagging()
        - .toDescribeJob()
        - .toDescribeMultiRegionAccessPointOperation()
        - .toGetAccelerateConfiguration()
        - .toGetAccessPoint()
        - .toGetAccessPointConfigurationForObjectLambda()
        - .toGetAccessPointForObjectLambda()
        - .toGetAccessPointPolicy()
        - .toGetAccessPointPolicyForObjectLambda()
        - .toGetAccessPointPolicyStatus()
        - .toGetAccessPointPolicyStatusForObjectLambda()
        - .toGetAccountPublicAccessBlock()
        - .toGetAnalyticsConfiguration()
        - .toGetBucketAcl()
        - .toGetBucketCORS()
        - .toGetBucketLocation()
        - .toGetBucketLogging()
        - .toGetBucketNotification()
        - .toGetBucketObjectLockConfiguration()
        - .toGetBucketOwnershipControls()
        - .toGetBucketPolicy()
        - .toGetBucketPolicyStatus()
        - .toGetBucketPublicAccessBlock()
        - .toGetBucketRequestPayment()
        - .toGetBucketTagging()
        - .toGetBucketVersioning()
        - .toGetBucketWebsite()
        - .toGetEncryptionConfiguration()
        - .toGetIntelligentTieringConfiguration()
        - .toGetInventoryConfiguration()
        - .toGetJobTagging()
        - .toGetLifecycleConfiguration()
        - .toGetMetricsConfiguration()
        - .toGetMultiRegionAccessPoint()
        - .toGetMultiRegionAccessPointPolicy()
        - .toGetMultiRegionAccessPointPolicyStatus()
        - .toGetMultiRegionAccessPointRoutes()
        - .toGetObject()
        - .toGetObjectAcl()
        - .toGetObjectAttributes()
        - .toGetObjectLegalHold()
        - .toGetObjectRetention()
        - .toGetObjectTagging()
        - .toGetObjectTorrent()
        - .toGetObjectVersion()
        - .toGetObjectVersionAcl()
        - .toGetObjectVersionAttributes()
        - .toGetObjectVersionForReplication()
        - .toGetObjectVersionTagging()
        - .toGetObjectVersionTorrent()
        - .toGetReplicationConfiguration()
        - .toGetStorageLensConfiguration()
        - .toGetStorageLensConfigurationTagging()
        - .toGetStorageLensDashboard()
        - .toListAccessPoints()
        - .toListAccessPointsForObjectLambda()
        - .toListAllMyBuckets()
        - .toListBucket()
        - .toListBucketMultipartUploads()
        - .toListBucketVersions()
        - .toListJobs()
        - .toListMultiRegionAccessPoints()
        - .toListMultipartUploadParts()
        - .toListStorageLensConfigurations()
        - .toObjectOwnerOverrideToBucketOwner()
        - .toPutAccelerateConfiguration()
        - .toPutAccessPointConfigurationForObjectLambda()
        - .toPutAccessPointPolicy()
        - .toPutAccessPointPolicyForObjectLambda()
        - .toPutAccountPublicAccessBlock()
        - .toPutAnalyticsConfiguration()
        - .toPutBucketAcl()
        - .toPutBucketCORS()
        - .toPutBucketLogging()
        - .toPutBucketNotification()
        - .toPutBucketObjectLockConfiguration()
        - .toPutBucketOwnershipControls()
        - .toPutBucketPolicy()
        - .toPutBucketPublicAccessBlock()
        - .toPutBucketRequestPayment()
        - .toPutBucketTagging()
        - .toPutBucketVersioning()
        - .toPutBucketWebsite()
        - .toPutEncryptionConfiguration()
        - .toPutIntelligentTieringConfiguration()
        - .toPutInventoryConfiguration()
        - .toPutJobTagging()
        - .toPutLifecycleConfiguration()
        - .toPutMetricsConfiguration()
        - .toPutMultiRegionAccessPointPolicy()
        - .toPutObject()
        - .toPutObjectAcl()
        - .toPutObjectLegalHold()
        - .toPutObjectRetention()
        - .toPutObjectTagging()
        - .toPutObjectVersionAcl()
        - .toPutObjectVersionTagging()
        - .toPutReplicationConfiguration()
        - .toPutStorageLensConfiguration()
        - .toPutStorageLensConfigurationTagging()
        - .toReplicateDelete()
        - .toReplicateObject()
        - .toReplicateTags()
        - .toRestoreObject()
        - .toSubmitMultiRegionAccessPointRoutes()
        - .toUpdateJobPriority()
        - .toUpdateJobStatus()

        :param value: The value(s) to check.
        :param operator: Works with `numeric operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_Numeric>`_. **Default:** ``NumericEquals``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ddb5f320f6889be62bed3ba8e37b04b08c92257778c5b1da265ff11fded61289)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("S3", jsii.invoke(self, "ifSignatureAge", [value, operator]))

    @jsii.member(jsii_name="ifSignatureversion")
    def if_signatureversion(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "S3":
        '''(experimental) Filters access by the version of AWS Signature used on the request.

        https://docs.aws.amazon.com/AmazonS3/latest/API/bucket-policy-s3-sigv4-conditions.html

        Applies to actions:

        - .toAbortMultipartUpload()
        - .toBypassGovernanceRetention()
        - .toCreateAccessPoint()
        - .toCreateAccessPointForObjectLambda()
        - .toCreateBucket()
        - .toCreateJob()
        - .toCreateMultiRegionAccessPoint()
        - .toDeleteAccessPoint()
        - .toDeleteAccessPointForObjectLambda()
        - .toDeleteAccessPointPolicy()
        - .toDeleteAccessPointPolicyForObjectLambda()
        - .toDeleteBucket()
        - .toDeleteBucketPolicy()
        - .toDeleteBucketWebsite()
        - .toDeleteJobTagging()
        - .toDeleteMultiRegionAccessPoint()
        - .toDeleteObject()
        - .toDeleteObjectTagging()
        - .toDeleteObjectVersion()
        - .toDeleteObjectVersionTagging()
        - .toDeleteStorageLensConfiguration()
        - .toDeleteStorageLensConfigurationTagging()
        - .toDescribeJob()
        - .toDescribeMultiRegionAccessPointOperation()
        - .toGetAccelerateConfiguration()
        - .toGetAccessPoint()
        - .toGetAccessPointConfigurationForObjectLambda()
        - .toGetAccessPointForObjectLambda()
        - .toGetAccessPointPolicy()
        - .toGetAccessPointPolicyForObjectLambda()
        - .toGetAccessPointPolicyStatus()
        - .toGetAccessPointPolicyStatusForObjectLambda()
        - .toGetAccountPublicAccessBlock()
        - .toGetAnalyticsConfiguration()
        - .toGetBucketAcl()
        - .toGetBucketCORS()
        - .toGetBucketLocation()
        - .toGetBucketLogging()
        - .toGetBucketNotification()
        - .toGetBucketObjectLockConfiguration()
        - .toGetBucketOwnershipControls()
        - .toGetBucketPolicy()
        - .toGetBucketPolicyStatus()
        - .toGetBucketPublicAccessBlock()
        - .toGetBucketRequestPayment()
        - .toGetBucketTagging()
        - .toGetBucketVersioning()
        - .toGetBucketWebsite()
        - .toGetEncryptionConfiguration()
        - .toGetIntelligentTieringConfiguration()
        - .toGetInventoryConfiguration()
        - .toGetJobTagging()
        - .toGetLifecycleConfiguration()
        - .toGetMetricsConfiguration()
        - .toGetMultiRegionAccessPoint()
        - .toGetMultiRegionAccessPointPolicy()
        - .toGetMultiRegionAccessPointPolicyStatus()
        - .toGetMultiRegionAccessPointRoutes()
        - .toGetObject()
        - .toGetObjectAcl()
        - .toGetObjectAttributes()
        - .toGetObjectLegalHold()
        - .toGetObjectRetention()
        - .toGetObjectTagging()
        - .toGetObjectTorrent()
        - .toGetObjectVersion()
        - .toGetObjectVersionAcl()
        - .toGetObjectVersionAttributes()
        - .toGetObjectVersionForReplication()
        - .toGetObjectVersionTagging()
        - .toGetObjectVersionTorrent()
        - .toGetReplicationConfiguration()
        - .toGetStorageLensConfiguration()
        - .toGetStorageLensConfigurationTagging()
        - .toGetStorageLensDashboard()
        - .toListAccessPoints()
        - .toListAccessPointsForObjectLambda()
        - .toListAllMyBuckets()
        - .toListBucket()
        - .toListBucketMultipartUploads()
        - .toListBucketVersions()
        - .toListJobs()
        - .toListMultiRegionAccessPoints()
        - .toListMultipartUploadParts()
        - .toListStorageLensConfigurations()
        - .toObjectOwnerOverrideToBucketOwner()
        - .toPutAccelerateConfiguration()
        - .toPutAccessPointConfigurationForObjectLambda()
        - .toPutAccessPointPolicy()
        - .toPutAccessPointPolicyForObjectLambda()
        - .toPutAccountPublicAccessBlock()
        - .toPutAnalyticsConfiguration()
        - .toPutBucketAcl()
        - .toPutBucketCORS()
        - .toPutBucketLogging()
        - .toPutBucketNotification()
        - .toPutBucketObjectLockConfiguration()
        - .toPutBucketOwnershipControls()
        - .toPutBucketPolicy()
        - .toPutBucketPublicAccessBlock()
        - .toPutBucketRequestPayment()
        - .toPutBucketTagging()
        - .toPutBucketVersioning()
        - .toPutBucketWebsite()
        - .toPutEncryptionConfiguration()
        - .toPutIntelligentTieringConfiguration()
        - .toPutInventoryConfiguration()
        - .toPutJobTagging()
        - .toPutLifecycleConfiguration()
        - .toPutMetricsConfiguration()
        - .toPutMultiRegionAccessPointPolicy()
        - .toPutObject()
        - .toPutObjectAcl()
        - .toPutObjectLegalHold()
        - .toPutObjectRetention()
        - .toPutObjectTagging()
        - .toPutObjectVersionAcl()
        - .toPutObjectVersionTagging()
        - .toPutReplicationConfiguration()
        - .toPutStorageLensConfiguration()
        - .toPutStorageLensConfigurationTagging()
        - .toReplicateDelete()
        - .toReplicateObject()
        - .toReplicateTags()
        - .toRestoreObject()
        - .toSubmitMultiRegionAccessPointRoutes()
        - .toUpdateJobPriority()
        - .toUpdateJobStatus()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9080e3bb07a0ed978e653601d056a466086ca766bcb24749660ba94e5aadfd8e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("S3", jsii.invoke(self, "ifSignatureversion", [value, operator]))

    @jsii.member(jsii_name="ifTlsVersion")
    def if_tls_version(
        self,
        value: typing.Union[jsii.Number, typing.Sequence[jsii.Number]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "S3":
        '''(experimental) Filters access by the TLS version used by the client.

        Applies to actions:

        - .toAbortMultipartUpload()
        - .toBypassGovernanceRetention()
        - .toCreateAccessPoint()
        - .toCreateAccessPointForObjectLambda()
        - .toCreateBucket()
        - .toCreateJob()
        - .toCreateMultiRegionAccessPoint()
        - .toDeleteAccessPoint()
        - .toDeleteAccessPointForObjectLambda()
        - .toDeleteAccessPointPolicy()
        - .toDeleteAccessPointPolicyForObjectLambda()
        - .toDeleteBucket()
        - .toDeleteBucketPolicy()
        - .toDeleteBucketWebsite()
        - .toDeleteJobTagging()
        - .toDeleteMultiRegionAccessPoint()
        - .toDeleteObject()
        - .toDeleteObjectTagging()
        - .toDeleteObjectVersion()
        - .toDeleteObjectVersionTagging()
        - .toDeleteStorageLensConfiguration()
        - .toDeleteStorageLensConfigurationTagging()
        - .toDescribeJob()
        - .toDescribeMultiRegionAccessPointOperation()
        - .toGetAccelerateConfiguration()
        - .toGetAccessPoint()
        - .toGetAccessPointConfigurationForObjectLambda()
        - .toGetAccessPointForObjectLambda()
        - .toGetAccessPointPolicy()
        - .toGetAccessPointPolicyForObjectLambda()
        - .toGetAccessPointPolicyStatus()
        - .toGetAccessPointPolicyStatusForObjectLambda()
        - .toGetAccountPublicAccessBlock()
        - .toGetAnalyticsConfiguration()
        - .toGetBucketAcl()
        - .toGetBucketCORS()
        - .toGetBucketLocation()
        - .toGetBucketLogging()
        - .toGetBucketNotification()
        - .toGetBucketObjectLockConfiguration()
        - .toGetBucketOwnershipControls()
        - .toGetBucketPolicy()
        - .toGetBucketPolicyStatus()
        - .toGetBucketPublicAccessBlock()
        - .toGetBucketRequestPayment()
        - .toGetBucketTagging()
        - .toGetBucketVersioning()
        - .toGetBucketWebsite()
        - .toGetEncryptionConfiguration()
        - .toGetIntelligentTieringConfiguration()
        - .toGetInventoryConfiguration()
        - .toGetJobTagging()
        - .toGetLifecycleConfiguration()
        - .toGetMetricsConfiguration()
        - .toGetMultiRegionAccessPoint()
        - .toGetMultiRegionAccessPointPolicy()
        - .toGetMultiRegionAccessPointPolicyStatus()
        - .toGetMultiRegionAccessPointRoutes()
        - .toGetObject()
        - .toGetObjectAcl()
        - .toGetObjectAttributes()
        - .toGetObjectLegalHold()
        - .toGetObjectRetention()
        - .toGetObjectTagging()
        - .toGetObjectTorrent()
        - .toGetObjectVersion()
        - .toGetObjectVersionAcl()
        - .toGetObjectVersionAttributes()
        - .toGetObjectVersionForReplication()
        - .toGetObjectVersionTagging()
        - .toGetObjectVersionTorrent()
        - .toGetReplicationConfiguration()
        - .toGetStorageLensConfiguration()
        - .toGetStorageLensConfigurationTagging()
        - .toGetStorageLensDashboard()
        - .toListAccessPoints()
        - .toListAccessPointsForObjectLambda()
        - .toListAllMyBuckets()
        - .toListBucket()
        - .toListBucketMultipartUploads()
        - .toListBucketVersions()
        - .toListJobs()
        - .toListMultiRegionAccessPoints()
        - .toListMultipartUploadParts()
        - .toListStorageLensConfigurations()
        - .toObjectOwnerOverrideToBucketOwner()
        - .toPutAccelerateConfiguration()
        - .toPutAccessPointConfigurationForObjectLambda()
        - .toPutAccessPointPolicy()
        - .toPutAccessPointPolicyForObjectLambda()
        - .toPutAccountPublicAccessBlock()
        - .toPutAnalyticsConfiguration()
        - .toPutBucketAcl()
        - .toPutBucketCORS()
        - .toPutBucketLogging()
        - .toPutBucketNotification()
        - .toPutBucketObjectLockConfiguration()
        - .toPutBucketOwnershipControls()
        - .toPutBucketPolicy()
        - .toPutBucketPublicAccessBlock()
        - .toPutBucketRequestPayment()
        - .toPutBucketTagging()
        - .toPutBucketVersioning()
        - .toPutBucketWebsite()
        - .toPutEncryptionConfiguration()
        - .toPutIntelligentTieringConfiguration()
        - .toPutInventoryConfiguration()
        - .toPutJobTagging()
        - .toPutLifecycleConfiguration()
        - .toPutMetricsConfiguration()
        - .toPutMultiRegionAccessPointPolicy()
        - .toPutObject()
        - .toPutObjectAcl()
        - .toPutObjectLegalHold()
        - .toPutObjectRetention()
        - .toPutObjectTagging()
        - .toPutObjectVersionAcl()
        - .toPutObjectVersionTagging()
        - .toPutReplicationConfiguration()
        - .toPutStorageLensConfiguration()
        - .toPutStorageLensConfigurationTagging()
        - .toReplicateDelete()
        - .toReplicateObject()
        - .toReplicateTags()
        - .toRestoreObject()
        - .toSubmitMultiRegionAccessPointRoutes()
        - .toUpdateJobPriority()
        - .toUpdateJobStatus()

        :param value: The value(s) to check.
        :param operator: Works with `numeric operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_Numeric>`_. **Default:** ``NumericEquals``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7d350876dc5c7c748406f5b63cdc5e0485c51e53b2f57207d7524f46d8b7f230)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("S3", jsii.invoke(self, "ifTlsVersion", [value, operator]))

    @jsii.member(jsii_name="ifVersionid")
    def if_versionid(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "S3":
        '''(experimental) Filters access by a specific object version.

        https://docs.aws.amazon.com/AmazonS3/latest/userguide/amazon-s3-policy-keys.html#getobjectversion-limit-access-to-specific-version-3

        Applies to actions:

        - .toDeleteObjectVersion()
        - .toDeleteObjectVersionTagging()
        - .toGetObjectVersion()
        - .toGetObjectVersionAcl()
        - .toGetObjectVersionAttributes()
        - .toGetObjectVersionTagging()
        - .toGetObjectVersionTorrent()
        - .toPutObjectVersionAcl()
        - .toPutObjectVersionTagging()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__512a9d405f0c5c1d797ecb77932895b09861e4958604b8651edf6e9d76013a17)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("S3", jsii.invoke(self, "ifVersionid", [value, operator]))

    @jsii.member(jsii_name="ifXAmzAcl")
    def if_x_amz_acl(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "S3":
        '''(experimental) Filters access by canned ACL in the request's x-amz-acl header.

        https://docs.aws.amazon.com/AmazonS3/latest/userguide/acl-overview.html#permissions

        Applies to actions:

        - .toBypassGovernanceRetention()
        - .toCreateAccessPoint()
        - .toCreateBucket()
        - .toPutBucketAcl()
        - .toPutObject()
        - .toPutObjectAcl()
        - .toPutObjectVersionAcl()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fa38a050de556694389aaa33c2cade0a314a3dd99145b678c60f2dbfdbbccc39)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("S3", jsii.invoke(self, "ifXAmzAcl", [value, operator]))

    @jsii.member(jsii_name="ifXAmzContentSha256")
    def if_x_amz_content_sha256(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "S3":
        '''(experimental) Filters access by unsigned content in your bucket.

        https://docs.aws.amazon.com/AmazonS3/latest/API/bucket-policy-s3-sigv4-conditions.html

        Applies to actions:

        - .toAbortMultipartUpload()
        - .toBypassGovernanceRetention()
        - .toCreateAccessPoint()
        - .toCreateAccessPointForObjectLambda()
        - .toCreateBucket()
        - .toCreateJob()
        - .toDeleteAccessPoint()
        - .toDeleteAccessPointForObjectLambda()
        - .toDeleteAccessPointPolicy()
        - .toDeleteAccessPointPolicyForObjectLambda()
        - .toDeleteBucket()
        - .toDeleteBucketPolicy()
        - .toDeleteBucketWebsite()
        - .toDeleteJobTagging()
        - .toDeleteObject()
        - .toDeleteObjectTagging()
        - .toDeleteObjectVersion()
        - .toDeleteObjectVersionTagging()
        - .toDeleteStorageLensConfiguration()
        - .toDeleteStorageLensConfigurationTagging()
        - .toDescribeJob()
        - .toGetAccelerateConfiguration()
        - .toGetAccessPoint()
        - .toGetAccessPointConfigurationForObjectLambda()
        - .toGetAccessPointForObjectLambda()
        - .toGetAccessPointPolicy()
        - .toGetAccessPointPolicyForObjectLambda()
        - .toGetAccessPointPolicyStatus()
        - .toGetAccessPointPolicyStatusForObjectLambda()
        - .toGetAccountPublicAccessBlock()
        - .toGetAnalyticsConfiguration()
        - .toGetBucketAcl()
        - .toGetBucketCORS()
        - .toGetBucketLocation()
        - .toGetBucketLogging()
        - .toGetBucketNotification()
        - .toGetBucketOwnershipControls()
        - .toGetBucketPolicy()
        - .toGetBucketPolicyStatus()
        - .toGetBucketPublicAccessBlock()
        - .toGetBucketRequestPayment()
        - .toGetBucketTagging()
        - .toGetBucketVersioning()
        - .toGetBucketWebsite()
        - .toGetEncryptionConfiguration()
        - .toGetIntelligentTieringConfiguration()
        - .toGetInventoryConfiguration()
        - .toGetJobTagging()
        - .toGetLifecycleConfiguration()
        - .toGetMetricsConfiguration()
        - .toGetObject()
        - .toGetObjectAcl()
        - .toGetObjectAttributes()
        - .toGetObjectLegalHold()
        - .toGetObjectRetention()
        - .toGetObjectTagging()
        - .toGetObjectTorrent()
        - .toGetObjectVersion()
        - .toGetObjectVersionAcl()
        - .toGetObjectVersionAttributes()
        - .toGetObjectVersionForReplication()
        - .toGetObjectVersionTagging()
        - .toGetObjectVersionTorrent()
        - .toGetReplicationConfiguration()
        - .toGetStorageLensConfiguration()
        - .toGetStorageLensConfigurationTagging()
        - .toGetStorageLensDashboard()
        - .toListAccessPoints()
        - .toListAccessPointsForObjectLambda()
        - .toListAllMyBuckets()
        - .toListBucket()
        - .toListBucketMultipartUploads()
        - .toListBucketVersions()
        - .toListJobs()
        - .toListMultipartUploadParts()
        - .toListStorageLensConfigurations()
        - .toObjectOwnerOverrideToBucketOwner()
        - .toPutAccelerateConfiguration()
        - .toPutAccessPointConfigurationForObjectLambda()
        - .toPutAccessPointPolicy()
        - .toPutAccessPointPolicyForObjectLambda()
        - .toPutAccountPublicAccessBlock()
        - .toPutAnalyticsConfiguration()
        - .toPutBucketAcl()
        - .toPutBucketCORS()
        - .toPutBucketLogging()
        - .toPutBucketNotification()
        - .toPutBucketOwnershipControls()
        - .toPutBucketPolicy()
        - .toPutBucketPublicAccessBlock()
        - .toPutBucketRequestPayment()
        - .toPutBucketTagging()
        - .toPutBucketVersioning()
        - .toPutBucketWebsite()
        - .toPutEncryptionConfiguration()
        - .toPutIntelligentTieringConfiguration()
        - .toPutInventoryConfiguration()
        - .toPutJobTagging()
        - .toPutLifecycleConfiguration()
        - .toPutMetricsConfiguration()
        - .toPutObject()
        - .toPutObjectAcl()
        - .toPutObjectLegalHold()
        - .toPutObjectRetention()
        - .toPutObjectTagging()
        - .toPutObjectVersionAcl()
        - .toPutObjectVersionTagging()
        - .toPutReplicationConfiguration()
        - .toPutStorageLensConfiguration()
        - .toPutStorageLensConfigurationTagging()
        - .toReplicateDelete()
        - .toReplicateObject()
        - .toReplicateTags()
        - .toRestoreObject()
        - .toUpdateJobPriority()
        - .toUpdateJobStatus()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__75fb62365449f33f96b6333e4ec8015dcf9e5dd2b6cfa32bdd0243a651721ff4)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("S3", jsii.invoke(self, "ifXAmzContentSha256", [value, operator]))

    @jsii.member(jsii_name="ifXAmzCopySource")
    def if_x_amz_copy_source(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "S3":
        '''(experimental) Filters access by copy source bucket, prefix, or object in the copy object requests.

        https://docs.aws.amazon.com/AmazonS3/latest/userguide/amazon-s3-policy-keys.html#putobject-limit-copy-source-3

        Applies to actions:

        - .toBypassGovernanceRetention()
        - .toPutObject()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__471b778cb8dfb1630c189ff2bfef07e9a4bafb2cd281608ca193be3760516ca1)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("S3", jsii.invoke(self, "ifXAmzCopySource", [value, operator]))

    @jsii.member(jsii_name="ifXAmzGrantFullControl")
    def if_x_amz_grant_full_control(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "S3":
        '''(experimental) Filters access by x-amz-grant-full-control (full control) header.

        https://docs.aws.amazon.com/AmazonS3/latest/userguide/acl-overview.html#permissions

        Applies to actions:

        - .toBypassGovernanceRetention()
        - .toCreateBucket()
        - .toPutBucketAcl()
        - .toPutObject()
        - .toPutObjectAcl()
        - .toPutObjectVersionAcl()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3d75bd63ac5dc5a6675b05625b96953a0b60184dc14b838b2815f28e757ebd0a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("S3", jsii.invoke(self, "ifXAmzGrantFullControl", [value, operator]))

    @jsii.member(jsii_name="ifXAmzGrantRead")
    def if_x_amz_grant_read(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "S3":
        '''(experimental) Filters access by x-amz-grant-read (read access) header.

        https://docs.aws.amazon.com/AmazonS3/latest/userguide/acl-overview.html#permissions

        Applies to actions:

        - .toBypassGovernanceRetention()
        - .toCreateBucket()
        - .toPutBucketAcl()
        - .toPutObject()
        - .toPutObjectAcl()
        - .toPutObjectVersionAcl()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d5c6ba8fb2bdf0b8c1908e1bb0564162e5a070c10880a64fa04a7f8cf75f4fdf)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("S3", jsii.invoke(self, "ifXAmzGrantRead", [value, operator]))

    @jsii.member(jsii_name="ifXAmzGrantReadAcp")
    def if_x_amz_grant_read_acp(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "S3":
        '''(experimental) Filters access by the x-amz-grant-read-acp (read permissions for the ACL) header.

        https://docs.aws.amazon.com/AmazonS3/latest/userguide/acl-overview.html#permissions

        Applies to actions:

        - .toBypassGovernanceRetention()
        - .toCreateBucket()
        - .toPutBucketAcl()
        - .toPutObject()
        - .toPutObjectAcl()
        - .toPutObjectVersionAcl()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__29b344cde8ffd903fe0d7d7706564e3fafb3fb6e0a00c9e539e9bff9fcf97328)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("S3", jsii.invoke(self, "ifXAmzGrantReadAcp", [value, operator]))

    @jsii.member(jsii_name="ifXAmzGrantWrite")
    def if_x_amz_grant_write(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "S3":
        '''(experimental) Filters access by the x-amz-grant-write (write access) header.

        https://docs.aws.amazon.com/AmazonS3/latest/userguide/acl-overview.html#permissions

        Applies to actions:

        - .toBypassGovernanceRetention()
        - .toCreateBucket()
        - .toPutBucketAcl()
        - .toPutObject()
        - .toPutObjectAcl()
        - .toPutObjectVersionAcl()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__52d47d7d051d24cc4049c8f239a9a8544b4b72318181470f1e66a96c48ab486d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("S3", jsii.invoke(self, "ifXAmzGrantWrite", [value, operator]))

    @jsii.member(jsii_name="ifXAmzGrantWriteAcp")
    def if_x_amz_grant_write_acp(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "S3":
        '''(experimental) Filters access by the x-amz-grant-write-acp (write permissions for the ACL) header.

        https://docs.aws.amazon.com/AmazonS3/latest/userguide/acl-overview.html#permissions

        Applies to actions:

        - .toBypassGovernanceRetention()
        - .toCreateBucket()
        - .toPutBucketAcl()
        - .toPutObject()
        - .toPutObjectAcl()
        - .toPutObjectVersionAcl()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4386c5706ce10bfc4c1048895825866d9d04ce9ca2316a04584a25ed4ae1a8e8)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("S3", jsii.invoke(self, "ifXAmzGrantWriteAcp", [value, operator]))

    @jsii.member(jsii_name="ifXAmzMetadataDirective")
    def if_x_amz_metadata_directive(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "S3":
        '''(experimental) Filters access by object metadata behavior (COPY or REPLACE) when objects are copied.

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_CopyObject.html

        Applies to actions:

        - .toBypassGovernanceRetention()
        - .toPutObject()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__19e7cbff2565c2f144287b6f3ecd9fea288e0914bbf72d0554dc4b2da9e7bd2a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("S3", jsii.invoke(self, "ifXAmzMetadataDirective", [value, operator]))

    @jsii.member(jsii_name="ifXAmzObjectOwnership")
    def if_x_amz_object_ownership(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "S3":
        '''(experimental) Filters access by Object Ownership.

        https://docs.aws.amazon.com/AmazonS3/latest/userguide/ensure-object-ownership.html#object-ownership-requiring-bucket-owner-enforced

        Applies to actions:

        - .toCreateBucket()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__81b38af40b4f48b24b058f45f1b925bd4d70ab7c84bebc819afd1684909d17b4)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("S3", jsii.invoke(self, "ifXAmzObjectOwnership", [value, operator]))

    @jsii.member(jsii_name="ifXAmzServerSideEncryption")
    def if_x_amz_server_side_encryption(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "S3":
        '''(experimental) Filters access by server-side encryption.

        https://docs.aws.amazon.com/AmazonS3/latest/userguide/UsingServerSideEncryption.html

        Applies to actions:

        - .toBypassGovernanceRetention()
        - .toPutObject()
        - .toReplicateObject()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7f4bafa7c18d5bc088ccfba07ad4411096c95e0eab981eeef032c57c7ff4178e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("S3", jsii.invoke(self, "ifXAmzServerSideEncryption", [value, operator]))

    @jsii.member(jsii_name="ifXAmzServerSideEncryptionAwsKmsKeyId")
    def if_x_amz_server_side_encryption_aws_kms_key_id(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "S3":
        '''(experimental) Filters access by AWS KMS customer managed CMK for server-side encryption.

        https://docs.aws.amazon.com/AmazonS3/latest/userguide/UsingKMSEncryption.html#require-sse-kms

        Applies to actions:

        - .toBypassGovernanceRetention()
        - .toPutObject()
        - .toReplicateObject()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__56ee5055f3d0cc39bc8bb6561621da287b692c0cdd80d01d70f93a824384c0af)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("S3", jsii.invoke(self, "ifXAmzServerSideEncryptionAwsKmsKeyId", [value, operator]))

    @jsii.member(jsii_name="ifXAmzServerSideEncryptionCustomerAlgorithm")
    def if_x_amz_server_side_encryption_customer_algorithm(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "S3":
        '''(experimental) Filters access by customer specified algorithm for server-side encryption.

        https://docs.aws.amazon.com/AmazonS3/latest/userguide/ServerSideEncryptionCustomerKeys.html

        Applies to actions:

        - .toBypassGovernanceRetention()
        - .toPutObject()
        - .toReplicateObject()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__da2b270fd7629da79a39cb8b1403a8c2422e913b663252202303dd0fa618453d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("S3", jsii.invoke(self, "ifXAmzServerSideEncryptionCustomerAlgorithm", [value, operator]))

    @jsii.member(jsii_name="ifXAmzStorageClass")
    def if_x_amz_storage_class(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "S3":
        '''(experimental) Filters access by storage class.

        https://docs.aws.amazon.com/AmazonS3/latest/userguide/storage-class-intro.html#sc-howtoset

        Applies to actions:

        - .toBypassGovernanceRetention()
        - .toPutObject()
        - .toPutObjectAcl()
        - .toPutObjectVersionAcl()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4bce75ee0a9a42a26e4ebebea1a3d814f826631a079e6b7d88d5aab87bc05043)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("S3", jsii.invoke(self, "ifXAmzStorageClass", [value, operator]))

    @jsii.member(jsii_name="ifXAmzWebsiteRedirectLocation")
    def if_x_amz_website_redirect_location(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "S3":
        '''(experimental) Filters access by a specific website redirect location for buckets that are configured as static websites.

        https://docs.aws.amazon.com/AmazonS3/latest/userguide/how-to-page-redirect.html#page-redirect-using-rest-api

        Applies to actions:

        - .toBypassGovernanceRetention()
        - .toPutObject()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c85aeec6a1606844ea932e06abb1a8ca4495a11c9f6dba4329fbfaa3ffb914dc)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("S3", jsii.invoke(self, "ifXAmzWebsiteRedirectLocation", [value, operator]))

    @jsii.member(jsii_name="onAccesspoint")
    def on_accesspoint(
        self,
        access_point_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "S3":
        '''(experimental) Adds a resource of type accesspoint to the statement.

        https://docs.aws.amazon.com/AmazonS3/latest/userguide/access-points.html

        :param access_point_name: - Identifier for the accessPointName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f564934fdf99d145f9a329a86c8e853af4d2d133bb1f1ab4b2f5a44cfe283a58)
            check_type(argname="argument access_point_name", value=access_point_name, expected_type=type_hints["access_point_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("S3", jsii.invoke(self, "onAccesspoint", [access_point_name, account, region, partition]))

    @jsii.member(jsii_name="onBucket")
    def on_bucket(
        self,
        bucket_name: builtins.str,
        partition: typing.Optional[builtins.str] = None,
    ) -> "S3":
        '''(experimental) Adds a resource of type bucket to the statement.

        https://docs.aws.amazon.com/AmazonS3/latest/userguide/UsingBucket.html

        :param bucket_name: - Identifier for the bucketName.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f281a89b6325c5b7b018cdb23e5c8b431e78c0a7e5ede0c1199cad614fbd83d0)
            check_type(argname="argument bucket_name", value=bucket_name, expected_type=type_hints["bucket_name"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("S3", jsii.invoke(self, "onBucket", [bucket_name, partition]))

    @jsii.member(jsii_name="onJob")
    def on_job(
        self,
        job_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "S3":
        '''(experimental) Adds a resource of type job to the statement.

        https://docs.aws.amazon.com/AmazonS3/latest/userguide/batch-ops-managing-jobs.html

        :param job_id: - Identifier for the jobId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__96d21e59ccb5e2c04fc4df87b290c82ba03f3247f388081c61c33de3c11226fe)
            check_type(argname="argument job_id", value=job_id, expected_type=type_hints["job_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("S3", jsii.invoke(self, "onJob", [job_id, account, region, partition]))

    @jsii.member(jsii_name="onMultiregionaccesspoint")
    def on_multiregionaccesspoint(
        self,
        access_point_alias: builtins.str,
        account: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "S3":
        '''(experimental) Adds a resource of type multiregionaccesspoint to the statement.

        https://docs.aws.amazon.com/AmazonS3/latest/userguide/MultiRegionAccessPointRequests.html

        :param access_point_alias: - Identifier for the accessPointAlias.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__dec02f2ad0c84e852220edeb9d3657cb13788a34002776fca150819ef606c97c)
            check_type(argname="argument access_point_alias", value=access_point_alias, expected_type=type_hints["access_point_alias"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("S3", jsii.invoke(self, "onMultiregionaccesspoint", [access_point_alias, account, partition]))

    @jsii.member(jsii_name="onMultiregionaccesspointrequestarn")
    def on_multiregionaccesspointrequestarn(
        self,
        operation: builtins.str,
        token: builtins.str,
        account: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "S3":
        '''(experimental) Adds a resource of type multiregionaccesspointrequestarn to the statement.

        https://docs.aws.amazon.com/AmazonS3/latest/userguide/MultiRegionAccessPointRequests.html

        :param operation: - Identifier for the operation.
        :param token: - Identifier for the token.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e9ff06335a3553e005a50d6e53df9cc92f36f29916d173ad6442170fe47bbafd)
            check_type(argname="argument operation", value=operation, expected_type=type_hints["operation"])
            check_type(argname="argument token", value=token, expected_type=type_hints["token"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("S3", jsii.invoke(self, "onMultiregionaccesspointrequestarn", [operation, token, account, partition]))

    @jsii.member(jsii_name="onObject")
    def on_object(
        self,
        bucket_name: builtins.str,
        object_name: builtins.str,
        partition: typing.Optional[builtins.str] = None,
    ) -> "S3":
        '''(experimental) Adds a resource of type object to the statement.

        https://docs.aws.amazon.com/AmazonS3/latest/userguide/UsingObjects.html

        :param bucket_name: - Identifier for the bucketName.
        :param object_name: - Identifier for the objectName.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__11668d1c44ca2dd438b580dffeef9ef3be5ad56a25453e2f986bf3012cf56333)
            check_type(argname="argument bucket_name", value=bucket_name, expected_type=type_hints["bucket_name"])
            check_type(argname="argument object_name", value=object_name, expected_type=type_hints["object_name"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("S3", jsii.invoke(self, "onObject", [bucket_name, object_name, partition]))

    @jsii.member(jsii_name="onObjectlambdaaccesspoint")
    def on_objectlambdaaccesspoint(
        self,
        access_point_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "S3":
        '''(experimental) Adds a resource of type objectlambdaaccesspoint to the statement.

        https://docs.aws.amazon.com/AmazonS3/latest/userguide/transforming-objects.html

        :param access_point_name: - Identifier for the accessPointName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0b6fecba176f6107827d730cbe0120917bdf80dcbcc3c24388dfbf351be8aed4)
            check_type(argname="argument access_point_name", value=access_point_name, expected_type=type_hints["access_point_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("S3", jsii.invoke(self, "onObjectlambdaaccesspoint", [access_point_name, account, region, partition]))

    @jsii.member(jsii_name="onStoragelensconfiguration")
    def on_storagelensconfiguration(
        self,
        config_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "S3":
        '''(experimental) Adds a resource of type storagelensconfiguration to the statement.

        https://docs.aws.amazon.com/AmazonS3/latest/userguide/storage_lens.html

        :param config_id: - Identifier for the configId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__eaa17ac4f73d13edb54fa4e2ac78840074c603bd1525705cc63164df86be63f6)
            check_type(argname="argument config_id", value=config_id, expected_type=type_hints["config_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("S3", jsii.invoke(self, "onStoragelensconfiguration", [config_id, account, region, partition]))

    @jsii.member(jsii_name="toAbortMultipartUpload")
    def to_abort_multipart_upload(self) -> "S3":
        '''(experimental) Grants permission to abort a multipart upload.

        Access Level: Write

        Possible conditions:

        - .ifDataAccessPointArn()
        - .ifDataAccessPointAccount()
        - .ifAccessPointNetworkOrigin()
        - .ifAuthType()
        - .ifResourceAccount()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifTlsVersion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_AbortMultipartUpload.html

        :stability: experimental
        '''
        return typing.cast("S3", jsii.invoke(self, "toAbortMultipartUpload", []))

    @jsii.member(jsii_name="toBypassGovernanceRetention")
    def to_bypass_governance_retention(self) -> "S3":
        '''(experimental) Grants permission to allow circumvention of governance-mode object retention settings.

        Access Level: Permissions management

        Possible conditions:

        - .ifDataAccessPointAccount()
        - .ifDataAccessPointArn()
        - .ifAccessPointNetworkOrigin()
        - .ifRequestObjectTag()
        - .ifRequestObjectTagKeys()
        - .ifAuthType()
        - .ifResourceAccount()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifTlsVersion()
        - .ifXAmzAcl()
        - .ifXAmzContentSha256()
        - .ifXAmzCopySource()
        - .ifXAmzGrantFullControl()
        - .ifXAmzGrantRead()
        - .ifXAmzGrantReadAcp()
        - .ifXAmzGrantWrite()
        - .ifXAmzGrantWriteAcp()
        - .ifXAmzMetadataDirective()
        - .ifXAmzServerSideEncryption()
        - .ifXAmzServerSideEncryptionAwsKmsKeyId()
        - .ifXAmzServerSideEncryptionCustomerAlgorithm()
        - .ifXAmzStorageClass()
        - .ifXAmzWebsiteRedirectLocation()
        - .ifObjectLockMode()
        - .ifObjectLockRetainUntilDate()
        - .ifObjectLockRemainingRetentionDays()
        - .ifObjectLockLegalHold()

        https://docs.aws.amazon.com/AmazonS3/latest/userguide/object-lock-managing.html#object-lock-managing-bypass

        :stability: experimental
        '''
        return typing.cast("S3", jsii.invoke(self, "toBypassGovernanceRetention", []))

    @jsii.member(jsii_name="toCreateAccessPoint")
    def to_create_access_point(self) -> "S3":
        '''(experimental) Grants permission to create a new access point.

        Access Level: Write

        Possible conditions:

        - .ifDataAccessPointAccount()
        - .ifDataAccessPointArn()
        - .ifAccessPointNetworkOrigin()
        - .ifAuthType()
        - .ifLocationconstraint()
        - .ifResourceAccount()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifTlsVersion()
        - .ifXAmzAcl()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_CreateAccessPoint.html

        :stability: experimental
        '''
        return typing.cast("S3", jsii.invoke(self, "toCreateAccessPoint", []))

    @jsii.member(jsii_name="toCreateAccessPointForObjectLambda")
    def to_create_access_point_for_object_lambda(self) -> "S3":
        '''(experimental) Grants permission to create an object lambda enabled accesspoint.

        Access Level: Write

        Possible conditions:

        - .ifDataAccessPointAccount()
        - .ifDataAccessPointArn()
        - .ifAccessPointNetworkOrigin()
        - .ifAuthType()
        - .ifResourceAccount()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifTlsVersion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_CreateAccessPointForObjectLambda.html

        :stability: experimental
        '''
        return typing.cast("S3", jsii.invoke(self, "toCreateAccessPointForObjectLambda", []))

    @jsii.member(jsii_name="toCreateBucket")
    def to_create_bucket(self) -> "S3":
        '''(experimental) Grants permission to create a new bucket.

        Access Level: Write

        Possible conditions:

        - .ifAuthType()
        - .ifLocationconstraint()
        - .ifResourceAccount()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifTlsVersion()
        - .ifXAmzAcl()
        - .ifXAmzContentSha256()
        - .ifXAmzGrantFullControl()
        - .ifXAmzGrantRead()
        - .ifXAmzGrantReadAcp()
        - .ifXAmzGrantWrite()
        - .ifXAmzGrantWriteAcp()
        - .ifXAmzObjectOwnership()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_CreateBucket.html

        :stability: experimental
        '''
        return typing.cast("S3", jsii.invoke(self, "toCreateBucket", []))

    @jsii.member(jsii_name="toCreateJob")
    def to_create_job(self) -> "S3":
        '''(experimental) Grants permission to create a new Amazon S3 Batch Operations job.

        Access Level: Write

        Possible conditions:

        - .ifAuthType()
        - .ifResourceAccount()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifTlsVersion()
        - .ifXAmzContentSha256()
        - .ifRequestJobPriority()
        - .ifRequestJobOperation()
        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        Dependent actions:

        - iam:PassRole

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_CreateJob.html

        :stability: experimental
        '''
        return typing.cast("S3", jsii.invoke(self, "toCreateJob", []))

    @jsii.member(jsii_name="toCreateMultiRegionAccessPoint")
    def to_create_multi_region_access_point(self) -> "S3":
        '''(experimental) Grants permission to create a new Multi-Region Access Point.

        Access Level: Write

        Possible conditions:

        - .ifDataAccessPointAccount()
        - .ifDataAccessPointArn()
        - .ifAccessPointNetworkOrigin()
        - .ifAuthType()
        - .ifResourceAccount()
        - .ifSignatureversion()
        - .ifSignatureAge()
        - .ifTlsVersion()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_CreateMultiRegionAccessPoint.html

        :stability: experimental
        '''
        return typing.cast("S3", jsii.invoke(self, "toCreateMultiRegionAccessPoint", []))

    @jsii.member(jsii_name="toDeleteAccessPoint")
    def to_delete_access_point(self) -> "S3":
        '''(experimental) Grants permission to delete the access point named in the URI.

        Access Level: Write

        Possible conditions:

        - .ifDataAccessPointArn()
        - .ifDataAccessPointAccount()
        - .ifAccessPointNetworkOrigin()
        - .ifAuthType()
        - .ifResourceAccount()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifTlsVersion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_DeleteAccessPoint.html

        :stability: experimental
        '''
        return typing.cast("S3", jsii.invoke(self, "toDeleteAccessPoint", []))

    @jsii.member(jsii_name="toDeleteAccessPointForObjectLambda")
    def to_delete_access_point_for_object_lambda(self) -> "S3":
        '''(experimental) Grants permission to delete the object lambda enabled access point named in the URI.

        Access Level: Write

        Possible conditions:

        - .ifDataAccessPointArn()
        - .ifDataAccessPointAccount()
        - .ifAccessPointNetworkOrigin()
        - .ifAuthType()
        - .ifResourceAccount()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifTlsVersion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_DeleteAccessPointForObjectLambda.html

        :stability: experimental
        '''
        return typing.cast("S3", jsii.invoke(self, "toDeleteAccessPointForObjectLambda", []))

    @jsii.member(jsii_name="toDeleteAccessPointPolicy")
    def to_delete_access_point_policy(self) -> "S3":
        '''(experimental) Grants permission to delete the policy on a specified access point.

        Access Level: Permissions management

        Possible conditions:

        - .ifDataAccessPointArn()
        - .ifDataAccessPointAccount()
        - .ifAccessPointNetworkOrigin()
        - .ifAuthType()
        - .ifResourceAccount()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifTlsVersion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_DeleteAccessPointPolicy.html

        :stability: experimental
        '''
        return typing.cast("S3", jsii.invoke(self, "toDeleteAccessPointPolicy", []))

    @jsii.member(jsii_name="toDeleteAccessPointPolicyForObjectLambda")
    def to_delete_access_point_policy_for_object_lambda(self) -> "S3":
        '''(experimental) Grants permission to delete the policy on a specified object lambda enabled access point.

        Access Level: Permissions management

        Possible conditions:

        - .ifDataAccessPointArn()
        - .ifDataAccessPointAccount()
        - .ifAccessPointNetworkOrigin()
        - .ifAuthType()
        - .ifResourceAccount()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifTlsVersion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_DeleteAccessPointPolicyForObjectLambda.html

        :stability: experimental
        '''
        return typing.cast("S3", jsii.invoke(self, "toDeleteAccessPointPolicyForObjectLambda", []))

    @jsii.member(jsii_name="toDeleteBucket")
    def to_delete_bucket(self) -> "S3":
        '''(experimental) Grants permission to delete the bucket named in the URI.

        Access Level: Write

        Possible conditions:

        - .ifAuthType()
        - .ifResourceAccount()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifTlsVersion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_DeleteBucket.html

        :stability: experimental
        '''
        return typing.cast("S3", jsii.invoke(self, "toDeleteBucket", []))

    @jsii.member(jsii_name="toDeleteBucketPolicy")
    def to_delete_bucket_policy(self) -> "S3":
        '''(experimental) Grants permission to delete the policy on a specified bucket.

        Access Level: Permissions management

        Possible conditions:

        - .ifAuthType()
        - .ifResourceAccount()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifTlsVersion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_DeleteBucketPolicy.html

        :stability: experimental
        '''
        return typing.cast("S3", jsii.invoke(self, "toDeleteBucketPolicy", []))

    @jsii.member(jsii_name="toDeleteBucketWebsite")
    def to_delete_bucket_website(self) -> "S3":
        '''(experimental) Grants permission to remove the website configuration for a bucket.

        Access Level: Write

        Possible conditions:

        - .ifAuthType()
        - .ifResourceAccount()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifTlsVersion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_DeleteBucketWebsite.html

        :stability: experimental
        '''
        return typing.cast("S3", jsii.invoke(self, "toDeleteBucketWebsite", []))

    @jsii.member(jsii_name="toDeleteJobTagging")
    def to_delete_job_tagging(self) -> "S3":
        '''(experimental) Grants permission to remove tags from an existing Amazon S3 Batch Operations job.

        Access Level: Tagging

        Possible conditions:

        - .ifAuthType()
        - .ifResourceAccount()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifTlsVersion()
        - .ifXAmzContentSha256()
        - .ifExistingJobPriority()
        - .ifExistingJobOperation()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_DeleteJobTagging.html

        :stability: experimental
        '''
        return typing.cast("S3", jsii.invoke(self, "toDeleteJobTagging", []))

    @jsii.member(jsii_name="toDeleteMultiRegionAccessPoint")
    def to_delete_multi_region_access_point(self) -> "S3":
        '''(experimental) Grants permission to delete the Multi-Region Access Point named in the URI.

        Access Level: Write

        Possible conditions:

        - .ifDataAccessPointAccount()
        - .ifDataAccessPointArn()
        - .ifAccessPointNetworkOrigin()
        - .ifAuthType()
        - .ifResourceAccount()
        - .ifSignatureversion()
        - .ifSignatureAge()
        - .ifTlsVersion()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_DeleteMultiRegionAccessPoint.html

        :stability: experimental
        '''
        return typing.cast("S3", jsii.invoke(self, "toDeleteMultiRegionAccessPoint", []))

    @jsii.member(jsii_name="toDeleteObject")
    def to_delete_object(self) -> "S3":
        '''(experimental) Grants permission to remove the null version of an object and insert a delete marker, which becomes the current version of the object.

        Access Level: Write

        Possible conditions:

        - .ifDataAccessPointAccount()
        - .ifDataAccessPointArn()
        - .ifAccessPointNetworkOrigin()
        - .ifAuthType()
        - .ifResourceAccount()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifTlsVersion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_DeleteObject.html

        :stability: experimental
        '''
        return typing.cast("S3", jsii.invoke(self, "toDeleteObject", []))

    @jsii.member(jsii_name="toDeleteObjectTagging")
    def to_delete_object_tagging(self) -> "S3":
        '''(experimental) Grants permission to use the tagging subresource to remove the entire tag set from the specified object.

        Access Level: Tagging

        Possible conditions:

        - .ifDataAccessPointAccount()
        - .ifDataAccessPointArn()
        - .ifAccessPointNetworkOrigin()
        - .ifExistingObjectTag()
        - .ifAuthType()
        - .ifResourceAccount()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifTlsVersion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_DeleteObjectTagging.html

        :stability: experimental
        '''
        return typing.cast("S3", jsii.invoke(self, "toDeleteObjectTagging", []))

    @jsii.member(jsii_name="toDeleteObjectVersion")
    def to_delete_object_version(self) -> "S3":
        '''(experimental) Grants permission to remove a specific version of an object.

        Access Level: Write

        Possible conditions:

        - .ifDataAccessPointAccount()
        - .ifDataAccessPointArn()
        - .ifAccessPointNetworkOrigin()
        - .ifAuthType()
        - .ifResourceAccount()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifTlsVersion()
        - .ifVersionid()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_DeleteObject.html

        :stability: experimental
        '''
        return typing.cast("S3", jsii.invoke(self, "toDeleteObjectVersion", []))

    @jsii.member(jsii_name="toDeleteObjectVersionTagging")
    def to_delete_object_version_tagging(self) -> "S3":
        '''(experimental) Grants permission to remove the entire tag set for a specific version of the object.

        Access Level: Tagging

        Possible conditions:

        - .ifDataAccessPointAccount()
        - .ifDataAccessPointArn()
        - .ifAccessPointNetworkOrigin()
        - .ifExistingObjectTag()
        - .ifAuthType()
        - .ifResourceAccount()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifTlsVersion()
        - .ifVersionid()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_DeleteObjectTagging.html

        :stability: experimental
        '''
        return typing.cast("S3", jsii.invoke(self, "toDeleteObjectVersionTagging", []))

    @jsii.member(jsii_name="toDeleteStorageLensConfiguration")
    def to_delete_storage_lens_configuration(self) -> "S3":
        '''(experimental) Grants permission to delete an existing Amazon S3 Storage Lens configuration.

        Access Level: Write

        Possible conditions:

        - .ifAuthType()
        - .ifResourceAccount()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifTlsVersion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_DeleteStorageLensConfiguration.html

        :stability: experimental
        '''
        return typing.cast("S3", jsii.invoke(self, "toDeleteStorageLensConfiguration", []))

    @jsii.member(jsii_name="toDeleteStorageLensConfigurationTagging")
    def to_delete_storage_lens_configuration_tagging(self) -> "S3":
        '''(experimental) Grants permission to remove tags from an existing Amazon S3 Storage Lens configuration.

        Access Level: Tagging

        Possible conditions:

        - .ifAuthType()
        - .ifResourceAccount()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifTlsVersion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_DeleteStorageLensConfigurationTagging.html

        :stability: experimental
        '''
        return typing.cast("S3", jsii.invoke(self, "toDeleteStorageLensConfigurationTagging", []))

    @jsii.member(jsii_name="toDescribeJob")
    def to_describe_job(self) -> "S3":
        '''(experimental) Grants permission to retrieve the configuration parameters and status for a batch operations job.

        Access Level: Read

        Possible conditions:

        - .ifAuthType()
        - .ifResourceAccount()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifTlsVersion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_DescribeJob.html

        :stability: experimental
        '''
        return typing.cast("S3", jsii.invoke(self, "toDescribeJob", []))

    @jsii.member(jsii_name="toDescribeMultiRegionAccessPointOperation")
    def to_describe_multi_region_access_point_operation(self) -> "S3":
        '''(experimental) Grants permission to retrieve the configurations for a Multi-Region Access Point.

        Access Level: Read

        Possible conditions:

        - .ifAuthType()
        - .ifResourceAccount()
        - .ifSignatureversion()
        - .ifSignatureAge()
        - .ifTlsVersion()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_DescribeMultiRegionAccessPointOperation.html

        :stability: experimental
        '''
        return typing.cast("S3", jsii.invoke(self, "toDescribeMultiRegionAccessPointOperation", []))

    @jsii.member(jsii_name="toGetAccelerateConfiguration")
    def to_get_accelerate_configuration(self) -> "S3":
        '''(experimental) Grants permission to uses the accelerate subresource to return the Transfer Acceleration state of a bucket, which is either Enabled or Suspended.

        Access Level: Read

        Possible conditions:

        - .ifAuthType()
        - .ifResourceAccount()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifTlsVersion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetBucketAccelerateConfiguration.html

        :stability: experimental
        '''
        return typing.cast("S3", jsii.invoke(self, "toGetAccelerateConfiguration", []))

    @jsii.member(jsii_name="toGetAccessPoint")
    def to_get_access_point(self) -> "S3":
        '''(experimental) Grants permission to return configuration information about the specified access point.

        Access Level: Read

        Possible conditions:

        - .ifDataAccessPointAccount()
        - .ifDataAccessPointArn()
        - .ifAccessPointNetworkOrigin()
        - .ifAuthType()
        - .ifResourceAccount()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifTlsVersion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_GetAccessPoint.html

        :stability: experimental
        '''
        return typing.cast("S3", jsii.invoke(self, "toGetAccessPoint", []))

    @jsii.member(jsii_name="toGetAccessPointConfigurationForObjectLambda")
    def to_get_access_point_configuration_for_object_lambda(self) -> "S3":
        '''(experimental) Grants permission to retrieve the configuration of the object lambda enabled access point.

        Access Level: Read

        Possible conditions:

        - .ifDataAccessPointArn()
        - .ifDataAccessPointAccount()
        - .ifAccessPointNetworkOrigin()
        - .ifAuthType()
        - .ifResourceAccount()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifTlsVersion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_GetAccessPointConfigurationForObjectLambda.html

        :stability: experimental
        '''
        return typing.cast("S3", jsii.invoke(self, "toGetAccessPointConfigurationForObjectLambda", []))

    @jsii.member(jsii_name="toGetAccessPointForObjectLambda")
    def to_get_access_point_for_object_lambda(self) -> "S3":
        '''(experimental) Grants permission to create an object lambda enabled accesspoint.

        Access Level: Read

        Possible conditions:

        - .ifDataAccessPointAccount()
        - .ifDataAccessPointArn()
        - .ifAccessPointNetworkOrigin()
        - .ifAuthType()
        - .ifResourceAccount()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifTlsVersion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_GetAccessPointForObjectLambda.html

        :stability: experimental
        '''
        return typing.cast("S3", jsii.invoke(self, "toGetAccessPointForObjectLambda", []))

    @jsii.member(jsii_name="toGetAccessPointPolicy")
    def to_get_access_point_policy(self) -> "S3":
        '''(experimental) Grants permission to returns the access point policy associated with the specified access point.

        Access Level: Read

        Possible conditions:

        - .ifDataAccessPointAccount()
        - .ifDataAccessPointArn()
        - .ifAccessPointNetworkOrigin()
        - .ifAuthType()
        - .ifResourceAccount()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifTlsVersion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_GetAccessPointPolicy.html

        :stability: experimental
        '''
        return typing.cast("S3", jsii.invoke(self, "toGetAccessPointPolicy", []))

    @jsii.member(jsii_name="toGetAccessPointPolicyForObjectLambda")
    def to_get_access_point_policy_for_object_lambda(self) -> "S3":
        '''(experimental) Grants permission to returns the access point policy associated with the specified object lambda enabled access point.

        Access Level: Read

        Possible conditions:

        - .ifDataAccessPointAccount()
        - .ifDataAccessPointArn()
        - .ifAccessPointNetworkOrigin()
        - .ifAuthType()
        - .ifResourceAccount()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifTlsVersion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_GetAccessPointPolicyForObjectLambda.html

        :stability: experimental
        '''
        return typing.cast("S3", jsii.invoke(self, "toGetAccessPointPolicyForObjectLambda", []))

    @jsii.member(jsii_name="toGetAccessPointPolicyStatus")
    def to_get_access_point_policy_status(self) -> "S3":
        '''(experimental) Grants permission to return the policy status for a specific access point policy.

        Access Level: Read

        Possible conditions:

        - .ifDataAccessPointAccount()
        - .ifDataAccessPointArn()
        - .ifAccessPointNetworkOrigin()
        - .ifAuthType()
        - .ifResourceAccount()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifTlsVersion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_GetAccessPointPolicyStatus.html

        :stability: experimental
        '''
        return typing.cast("S3", jsii.invoke(self, "toGetAccessPointPolicyStatus", []))

    @jsii.member(jsii_name="toGetAccessPointPolicyStatusForObjectLambda")
    def to_get_access_point_policy_status_for_object_lambda(self) -> "S3":
        '''(experimental) Grants permission to return the policy status for a specific object lambda access point policy.

        Access Level: Read

        Possible conditions:

        - .ifDataAccessPointAccount()
        - .ifDataAccessPointArn()
        - .ifAccessPointNetworkOrigin()
        - .ifAuthType()
        - .ifResourceAccount()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifTlsVersion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_GetAccessPointPolicyStatusForObjectLambda.html

        :stability: experimental
        '''
        return typing.cast("S3", jsii.invoke(self, "toGetAccessPointPolicyStatusForObjectLambda", []))

    @jsii.member(jsii_name="toGetAccountPublicAccessBlock")
    def to_get_account_public_access_block(self) -> "S3":
        '''(experimental) Grants permission to retrieve the PublicAccessBlock configuration for an AWS account.

        Access Level: Read

        Possible conditions:

        - .ifAuthType()
        - .ifResourceAccount()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifTlsVersion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_GetPublicAccessBlock.html

        :stability: experimental
        '''
        return typing.cast("S3", jsii.invoke(self, "toGetAccountPublicAccessBlock", []))

    @jsii.member(jsii_name="toGetAnalyticsConfiguration")
    def to_get_analytics_configuration(self) -> "S3":
        '''(experimental) Grants permission to get an analytics configuration from an Amazon S3 bucket, identified by the analytics configuration ID.

        Access Level: Read

        Possible conditions:

        - .ifAuthType()
        - .ifResourceAccount()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifTlsVersion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetBucketAnalyticsConfiguration.html

        :stability: experimental
        '''
        return typing.cast("S3", jsii.invoke(self, "toGetAnalyticsConfiguration", []))

    @jsii.member(jsii_name="toGetBucketAcl")
    def to_get_bucket_acl(self) -> "S3":
        '''(experimental) Grants permission to use the acl subresource to return the access control list (ACL) of an Amazon S3 bucket.

        Access Level: Read

        Possible conditions:

        - .ifAuthType()
        - .ifResourceAccount()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifTlsVersion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetBucketAcl.html

        :stability: experimental
        '''
        return typing.cast("S3", jsii.invoke(self, "toGetBucketAcl", []))

    @jsii.member(jsii_name="toGetBucketCORS")
    def to_get_bucket_cors(self) -> "S3":
        '''(experimental) Grants permission to return the CORS configuration information set for an Amazon S3 bucket.

        Access Level: Read

        Possible conditions:

        - .ifAuthType()
        - .ifResourceAccount()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifTlsVersion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetBucketCors.html

        :stability: experimental
        '''
        return typing.cast("S3", jsii.invoke(self, "toGetBucketCORS", []))

    @jsii.member(jsii_name="toGetBucketLocation")
    def to_get_bucket_location(self) -> "S3":
        '''(experimental) Grants permission to return the Region that an Amazon S3 bucket resides in.

        Access Level: Read

        Possible conditions:

        - .ifAuthType()
        - .ifResourceAccount()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifTlsVersion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetBucketLocation.html

        :stability: experimental
        '''
        return typing.cast("S3", jsii.invoke(self, "toGetBucketLocation", []))

    @jsii.member(jsii_name="toGetBucketLogging")
    def to_get_bucket_logging(self) -> "S3":
        '''(experimental) Grants permission to return the logging status of an Amazon S3 bucket and the permissions users have to view or modify that status.

        Access Level: Read

        Possible conditions:

        - .ifAuthType()
        - .ifResourceAccount()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifTlsVersion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetBucketLogging.html

        :stability: experimental
        '''
        return typing.cast("S3", jsii.invoke(self, "toGetBucketLogging", []))

    @jsii.member(jsii_name="toGetBucketNotification")
    def to_get_bucket_notification(self) -> "S3":
        '''(experimental) Grants permission to get the notification configuration of an Amazon S3 bucket.

        Access Level: Read

        Possible conditions:

        - .ifAuthType()
        - .ifResourceAccount()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifTlsVersion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetBucketNotification.html

        :stability: experimental
        '''
        return typing.cast("S3", jsii.invoke(self, "toGetBucketNotification", []))

    @jsii.member(jsii_name="toGetBucketObjectLockConfiguration")
    def to_get_bucket_object_lock_configuration(self) -> "S3":
        '''(experimental) Grants permission to get the Object Lock configuration of an Amazon S3 bucket.

        Access Level: Read

        Possible conditions:

        - .ifAuthType()
        - .ifResourceAccount()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifTlsVersion()
        - .ifSignatureversion()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetObjectLockConfiguration.html

        :stability: experimental
        '''
        return typing.cast("S3", jsii.invoke(self, "toGetBucketObjectLockConfiguration", []))

    @jsii.member(jsii_name="toGetBucketOwnershipControls")
    def to_get_bucket_ownership_controls(self) -> "S3":
        '''(experimental) Grants permission to retrieve ownership controls on a bucket.

        Access Level: Read

        Possible conditions:

        - .ifAuthType()
        - .ifResourceAccount()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifTlsVersion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetBucketOwnershipControls.html

        :stability: experimental
        '''
        return typing.cast("S3", jsii.invoke(self, "toGetBucketOwnershipControls", []))

    @jsii.member(jsii_name="toGetBucketPolicy")
    def to_get_bucket_policy(self) -> "S3":
        '''(experimental) Grants permission to return the policy of the specified bucket.

        Access Level: Read

        Possible conditions:

        - .ifAuthType()
        - .ifResourceAccount()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifTlsVersion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetBucketPolicy.html

        :stability: experimental
        '''
        return typing.cast("S3", jsii.invoke(self, "toGetBucketPolicy", []))

    @jsii.member(jsii_name="toGetBucketPolicyStatus")
    def to_get_bucket_policy_status(self) -> "S3":
        '''(experimental) Grants permission to retrieve the policy status for a specific Amazon S3 bucket, which indicates whether the bucket is public.

        Access Level: Read

        Possible conditions:

        - .ifAuthType()
        - .ifResourceAccount()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifTlsVersion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetBucketPolicyStatus.html

        :stability: experimental
        '''
        return typing.cast("S3", jsii.invoke(self, "toGetBucketPolicyStatus", []))

    @jsii.member(jsii_name="toGetBucketPublicAccessBlock")
    def to_get_bucket_public_access_block(self) -> "S3":
        '''(experimental) Grants permission to retrieve the PublicAccessBlock configuration for an Amazon S3 bucket.

        Access Level: Read

        Possible conditions:

        - .ifAuthType()
        - .ifResourceAccount()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifTlsVersion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetPublicAccessBlock.html

        :stability: experimental
        '''
        return typing.cast("S3", jsii.invoke(self, "toGetBucketPublicAccessBlock", []))

    @jsii.member(jsii_name="toGetBucketRequestPayment")
    def to_get_bucket_request_payment(self) -> "S3":
        '''(experimental) Grants permission to return the request payment configuration for an Amazon S3 bucket.

        Access Level: Read

        Possible conditions:

        - .ifAuthType()
        - .ifResourceAccount()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifTlsVersion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetBucketRequestPayment.html

        :stability: experimental
        '''
        return typing.cast("S3", jsii.invoke(self, "toGetBucketRequestPayment", []))

    @jsii.member(jsii_name="toGetBucketTagging")
    def to_get_bucket_tagging(self) -> "S3":
        '''(experimental) Grants permission to return the tag set associated with an Amazon S3 bucket.

        Access Level: Read

        Possible conditions:

        - .ifAuthType()
        - .ifResourceAccount()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifTlsVersion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetBucketTagging.html

        :stability: experimental
        '''
        return typing.cast("S3", jsii.invoke(self, "toGetBucketTagging", []))

    @jsii.member(jsii_name="toGetBucketVersioning")
    def to_get_bucket_versioning(self) -> "S3":
        '''(experimental) Grants permission to return the versioning state of an Amazon S3 bucket.

        Access Level: Read

        Possible conditions:

        - .ifAuthType()
        - .ifResourceAccount()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifTlsVersion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetBucketVersioning.html

        :stability: experimental
        '''
        return typing.cast("S3", jsii.invoke(self, "toGetBucketVersioning", []))

    @jsii.member(jsii_name="toGetBucketWebsite")
    def to_get_bucket_website(self) -> "S3":
        '''(experimental) Grants permission to return the website configuration for an Amazon S3 bucket.

        Access Level: Read

        Possible conditions:

        - .ifAuthType()
        - .ifResourceAccount()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifTlsVersion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetBucketWebsite.html

        :stability: experimental
        '''
        return typing.cast("S3", jsii.invoke(self, "toGetBucketWebsite", []))

    @jsii.member(jsii_name="toGetEncryptionConfiguration")
    def to_get_encryption_configuration(self) -> "S3":
        '''(experimental) Grants permission to return the default encryption configuration an Amazon S3 bucket.

        Access Level: Read

        Possible conditions:

        - .ifAuthType()
        - .ifResourceAccount()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifTlsVersion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetBucketEncryption.html

        :stability: experimental
        '''
        return typing.cast("S3", jsii.invoke(self, "toGetEncryptionConfiguration", []))

    @jsii.member(jsii_name="toGetIntelligentTieringConfiguration")
    def to_get_intelligent_tiering_configuration(self) -> "S3":
        '''(experimental) Grants permission to get an or list all Amazon S3 Intelligent Tiering configuration in a S3 Bucket.

        Access Level: Read

        Possible conditions:

        - .ifAuthType()
        - .ifResourceAccount()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifTlsVersion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetBucketIntelligentTieringConfiguration.html

        :stability: experimental
        '''
        return typing.cast("S3", jsii.invoke(self, "toGetIntelligentTieringConfiguration", []))

    @jsii.member(jsii_name="toGetInventoryConfiguration")
    def to_get_inventory_configuration(self) -> "S3":
        '''(experimental) Grants permission to return an inventory configuration from an Amazon S3 bucket, identified by the inventory configuration ID.

        Access Level: Read

        Possible conditions:

        - .ifAuthType()
        - .ifResourceAccount()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifTlsVersion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetBucketInventoryConfiguration.html

        :stability: experimental
        '''
        return typing.cast("S3", jsii.invoke(self, "toGetInventoryConfiguration", []))

    @jsii.member(jsii_name="toGetJobTagging")
    def to_get_job_tagging(self) -> "S3":
        '''(experimental) Grants permission to return the tag set of an existing Amazon S3 Batch Operations job.

        Access Level: Read

        Possible conditions:

        - .ifAuthType()
        - .ifResourceAccount()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifTlsVersion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_GetJobTagging.html

        :stability: experimental
        '''
        return typing.cast("S3", jsii.invoke(self, "toGetJobTagging", []))

    @jsii.member(jsii_name="toGetLifecycleConfiguration")
    def to_get_lifecycle_configuration(self) -> "S3":
        '''(experimental) Grants permission to return the lifecycle configuration information set on an Amazon S3 bucket.

        Access Level: Read

        Possible conditions:

        - .ifAuthType()
        - .ifResourceAccount()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifTlsVersion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetBucketLifecycleConfiguration.html

        :stability: experimental
        '''
        return typing.cast("S3", jsii.invoke(self, "toGetLifecycleConfiguration", []))

    @jsii.member(jsii_name="toGetMetricsConfiguration")
    def to_get_metrics_configuration(self) -> "S3":
        '''(experimental) Grants permission to get a metrics configuration from an Amazon S3 bucket.

        Access Level: Read

        Possible conditions:

        - .ifAuthType()
        - .ifResourceAccount()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifTlsVersion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetBucketMetricsConfiguration.html

        :stability: experimental
        '''
        return typing.cast("S3", jsii.invoke(self, "toGetMetricsConfiguration", []))

    @jsii.member(jsii_name="toGetMultiRegionAccessPoint")
    def to_get_multi_region_access_point(self) -> "S3":
        '''(experimental) Grants permission to return configuration information about the specified Multi-Region Access Point.

        Access Level: Read

        Possible conditions:

        - .ifDataAccessPointAccount()
        - .ifDataAccessPointArn()
        - .ifAccessPointNetworkOrigin()
        - .ifAuthType()
        - .ifResourceAccount()
        - .ifSignatureversion()
        - .ifSignatureAge()
        - .ifTlsVersion()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_GetMultiRegionAccessPoint.html

        :stability: experimental
        '''
        return typing.cast("S3", jsii.invoke(self, "toGetMultiRegionAccessPoint", []))

    @jsii.member(jsii_name="toGetMultiRegionAccessPointPolicy")
    def to_get_multi_region_access_point_policy(self) -> "S3":
        '''(experimental) Grants permission to returns the access point policy associated with the specified Multi-Region Access Point.

        Access Level: Read

        Possible conditions:

        - .ifDataAccessPointAccount()
        - .ifDataAccessPointArn()
        - .ifAccessPointNetworkOrigin()
        - .ifAuthType()
        - .ifResourceAccount()
        - .ifSignatureversion()
        - .ifSignatureAge()
        - .ifTlsVersion()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_GetMultiRegionAccessPointPolicy.html

        :stability: experimental
        '''
        return typing.cast("S3", jsii.invoke(self, "toGetMultiRegionAccessPointPolicy", []))

    @jsii.member(jsii_name="toGetMultiRegionAccessPointPolicyStatus")
    def to_get_multi_region_access_point_policy_status(self) -> "S3":
        '''(experimental) Grants permission to return the policy status for a specific Multi-Region Access Point policy.

        Access Level: Read

        Possible conditions:

        - .ifDataAccessPointAccount()
        - .ifDataAccessPointArn()
        - .ifAccessPointNetworkOrigin()
        - .ifAuthType()
        - .ifResourceAccount()
        - .ifSignatureversion()
        - .ifSignatureAge()
        - .ifTlsVersion()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_GetMultiRegionAccessPointPolicyStatus.html

        :stability: experimental
        '''
        return typing.cast("S3", jsii.invoke(self, "toGetMultiRegionAccessPointPolicyStatus", []))

    @jsii.member(jsii_name="toGetMultiRegionAccessPointRoutes")
    def to_get_multi_region_access_point_routes(self) -> "S3":
        '''(experimental) Grants permission to return the route configuration for a Multi-Region Access Point.

        Access Level: Read

        Possible conditions:

        - .ifDataAccessPointAccount()
        - .ifDataAccessPointArn()
        - .ifAccessPointNetworkOrigin()
        - .ifAuthType()
        - .ifResourceAccount()
        - .ifSignatureversion()
        - .ifSignatureAge()
        - .ifTlsVersion()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_GetMultiRegionAccessPointRoutes.html

        :stability: experimental
        '''
        return typing.cast("S3", jsii.invoke(self, "toGetMultiRegionAccessPointRoutes", []))

    @jsii.member(jsii_name="toGetObject")
    def to_get_object(self) -> "S3":
        '''(experimental) Grants permission to retrieve objects from Amazon S3.

        Access Level: Read

        Possible conditions:

        - .ifDataAccessPointAccount()
        - .ifDataAccessPointArn()
        - .ifAccessPointNetworkOrigin()
        - .ifExistingObjectTag()
        - .ifAuthType()
        - .ifResourceAccount()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifTlsVersion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetObject.html

        :stability: experimental
        '''
        return typing.cast("S3", jsii.invoke(self, "toGetObject", []))

    @jsii.member(jsii_name="toGetObjectAcl")
    def to_get_object_acl(self) -> "S3":
        '''(experimental) Grants permission to return the access control list (ACL) of an object.

        Access Level: Read

        Possible conditions:

        - .ifDataAccessPointAccount()
        - .ifDataAccessPointArn()
        - .ifAccessPointNetworkOrigin()
        - .ifExistingObjectTag()
        - .ifAuthType()
        - .ifResourceAccount()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifTlsVersion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetObjectAcl.html

        :stability: experimental
        '''
        return typing.cast("S3", jsii.invoke(self, "toGetObjectAcl", []))

    @jsii.member(jsii_name="toGetObjectAttributes")
    def to_get_object_attributes(self) -> "S3":
        '''(experimental) Grants permission to retrieve attributes related to a specific object.

        Access Level: Read

        Possible conditions:

        - .ifDataAccessPointAccount()
        - .ifDataAccessPointArn()
        - .ifAccessPointNetworkOrigin()
        - .ifExistingObjectTag()
        - .ifAuthType()
        - .ifResourceAccount()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifTlsVersion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetObjectAttributes.html

        :stability: experimental
        '''
        return typing.cast("S3", jsii.invoke(self, "toGetObjectAttributes", []))

    @jsii.member(jsii_name="toGetObjectLegalHold")
    def to_get_object_legal_hold(self) -> "S3":
        '''(experimental) Grants permission to get an object's current Legal Hold status.

        Access Level: Read

        Possible conditions:

        - .ifDataAccessPointAccount()
        - .ifDataAccessPointArn()
        - .ifAccessPointNetworkOrigin()
        - .ifAuthType()
        - .ifResourceAccount()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifTlsVersion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetObjectLegalHold.html

        :stability: experimental
        '''
        return typing.cast("S3", jsii.invoke(self, "toGetObjectLegalHold", []))

    @jsii.member(jsii_name="toGetObjectRetention")
    def to_get_object_retention(self) -> "S3":
        '''(experimental) Grants permission to retrieve the retention settings for an object.

        Access Level: Read

        Possible conditions:

        - .ifDataAccessPointAccount()
        - .ifDataAccessPointArn()
        - .ifAccessPointNetworkOrigin()
        - .ifAuthType()
        - .ifResourceAccount()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifTlsVersion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetObjectRetention.html

        :stability: experimental
        '''
        return typing.cast("S3", jsii.invoke(self, "toGetObjectRetention", []))

    @jsii.member(jsii_name="toGetObjectTagging")
    def to_get_object_tagging(self) -> "S3":
        '''(experimental) Grants permission to return the tag set of an object.

        Access Level: Read

        Possible conditions:

        - .ifDataAccessPointAccount()
        - .ifDataAccessPointArn()
        - .ifAccessPointNetworkOrigin()
        - .ifExistingObjectTag()
        - .ifAuthType()
        - .ifResourceAccount()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifTlsVersion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetObjectTagging.html

        :stability: experimental
        '''
        return typing.cast("S3", jsii.invoke(self, "toGetObjectTagging", []))

    @jsii.member(jsii_name="toGetObjectTorrent")
    def to_get_object_torrent(self) -> "S3":
        '''(experimental) Grants permission to return torrent files from an Amazon S3 bucket.

        Access Level: Read

        Possible conditions:

        - .ifAuthType()
        - .ifResourceAccount()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifTlsVersion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetObjectTorrent.html

        :stability: experimental
        '''
        return typing.cast("S3", jsii.invoke(self, "toGetObjectTorrent", []))

    @jsii.member(jsii_name="toGetObjectVersion")
    def to_get_object_version(self) -> "S3":
        '''(experimental) Grants permission to retrieve a specific version of an object.

        Access Level: Read

        Possible conditions:

        - .ifDataAccessPointAccount()
        - .ifDataAccessPointArn()
        - .ifAccessPointNetworkOrigin()
        - .ifExistingObjectTag()
        - .ifAuthType()
        - .ifResourceAccount()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifTlsVersion()
        - .ifVersionid()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetObject.html

        :stability: experimental
        '''
        return typing.cast("S3", jsii.invoke(self, "toGetObjectVersion", []))

    @jsii.member(jsii_name="toGetObjectVersionAcl")
    def to_get_object_version_acl(self) -> "S3":
        '''(experimental) Grants permission to return the access control list (ACL) of a specific object version.

        Access Level: Read

        Possible conditions:

        - .ifDataAccessPointAccount()
        - .ifDataAccessPointArn()
        - .ifAccessPointNetworkOrigin()
        - .ifExistingObjectTag()
        - .ifAuthType()
        - .ifResourceAccount()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifTlsVersion()
        - .ifVersionid()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetObjectAcl.html

        :stability: experimental
        '''
        return typing.cast("S3", jsii.invoke(self, "toGetObjectVersionAcl", []))

    @jsii.member(jsii_name="toGetObjectVersionAttributes")
    def to_get_object_version_attributes(self) -> "S3":
        '''(experimental) Grants permission to retrieve attributes related to a specific version of an object.

        Access Level: Read

        Possible conditions:

        - .ifDataAccessPointAccount()
        - .ifDataAccessPointArn()
        - .ifAccessPointNetworkOrigin()
        - .ifExistingObjectTag()
        - .ifAuthType()
        - .ifResourceAccount()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifTlsVersion()
        - .ifVersionid()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetObjectAttributes.html

        :stability: experimental
        '''
        return typing.cast("S3", jsii.invoke(self, "toGetObjectVersionAttributes", []))

    @jsii.member(jsii_name="toGetObjectVersionForReplication")
    def to_get_object_version_for_replication(self) -> "S3":
        '''(experimental) Grants permission to replicate both unencrypted objects and objects encrypted with SSE-S3 or SSE-KMS.

        Access Level: Read

        Possible conditions:

        - .ifAuthType()
        - .ifResourceAccount()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifTlsVersion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/userguide/replication-config-for-kms-objects.html

        :stability: experimental
        '''
        return typing.cast("S3", jsii.invoke(self, "toGetObjectVersionForReplication", []))

    @jsii.member(jsii_name="toGetObjectVersionTagging")
    def to_get_object_version_tagging(self) -> "S3":
        '''(experimental) Grants permission to return the tag set for a specific version of the object.

        Access Level: Read

        Possible conditions:

        - .ifDataAccessPointAccount()
        - .ifDataAccessPointArn()
        - .ifAccessPointNetworkOrigin()
        - .ifExistingObjectTag()
        - .ifAuthType()
        - .ifResourceAccount()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifTlsVersion()
        - .ifVersionid()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/userguide/setting-repl-config-perm-overview.html

        :stability: experimental
        '''
        return typing.cast("S3", jsii.invoke(self, "toGetObjectVersionTagging", []))

    @jsii.member(jsii_name="toGetObjectVersionTorrent")
    def to_get_object_version_torrent(self) -> "S3":
        '''(experimental) Grants permission to get Torrent files about a different version using the versionId subresource.

        Access Level: Read

        Possible conditions:

        - .ifAuthType()
        - .ifResourceAccount()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifTlsVersion()
        - .ifVersionid()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetObjectTorrent.html

        :stability: experimental
        '''
        return typing.cast("S3", jsii.invoke(self, "toGetObjectVersionTorrent", []))

    @jsii.member(jsii_name="toGetReplicationConfiguration")
    def to_get_replication_configuration(self) -> "S3":
        '''(experimental) Grants permission to get the replication configuration information set on an Amazon S3 bucket.

        Access Level: Read

        Possible conditions:

        - .ifAuthType()
        - .ifResourceAccount()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifTlsVersion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetBucketReplication.html

        :stability: experimental
        '''
        return typing.cast("S3", jsii.invoke(self, "toGetReplicationConfiguration", []))

    @jsii.member(jsii_name="toGetStorageLensConfiguration")
    def to_get_storage_lens_configuration(self) -> "S3":
        '''(experimental) Grants permission to get an Amazon S3 Storage Lens configuration.

        Access Level: Read

        Possible conditions:

        - .ifAuthType()
        - .ifResourceAccount()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifTlsVersion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_GetStorageLensConfiguration.html

        :stability: experimental
        '''
        return typing.cast("S3", jsii.invoke(self, "toGetStorageLensConfiguration", []))

    @jsii.member(jsii_name="toGetStorageLensConfigurationTagging")
    def to_get_storage_lens_configuration_tagging(self) -> "S3":
        '''(experimental) Grants permission to get the tag set of an existing Amazon S3 Storage Lens configuration.

        Access Level: Read

        Possible conditions:

        - .ifAuthType()
        - .ifResourceAccount()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifTlsVersion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_GetStorageLensConfigurationTagging.html

        :stability: experimental
        '''
        return typing.cast("S3", jsii.invoke(self, "toGetStorageLensConfigurationTagging", []))

    @jsii.member(jsii_name="toGetStorageLensDashboard")
    def to_get_storage_lens_dashboard(self) -> "S3":
        '''(experimental) Grants permission to get an Amazon S3 Storage Lens dashboard.

        Access Level: Read

        Possible conditions:

        - .ifAuthType()
        - .ifResourceAccount()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifTlsVersion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/userguide/storage_lens_dashboard.html

        :stability: experimental
        '''
        return typing.cast("S3", jsii.invoke(self, "toGetStorageLensDashboard", []))

    @jsii.member(jsii_name="toInitiateReplication")
    def to_initiate_replication(self) -> "S3":
        '''(experimental) Grants permission to initiate the replication process by setting replication status of an object to pending.

        Access Level: Write

        Possible conditions:

        - .ifResourceAccount()

        https://docs.aws.amazon.com/AmazonS3/latest/userguide/setting-repl-config-perm-overview.html

        :stability: experimental
        '''
        return typing.cast("S3", jsii.invoke(self, "toInitiateReplication", []))

    @jsii.member(jsii_name="toListAccessPoints")
    def to_list_access_points(self) -> "S3":
        '''(experimental) Grants permission to list access points.

        Access Level: List

        Possible conditions:

        - .ifAuthType()
        - .ifResourceAccount()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifTlsVersion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_ListAccessPoints.html

        :stability: experimental
        '''
        return typing.cast("S3", jsii.invoke(self, "toListAccessPoints", []))

    @jsii.member(jsii_name="toListAccessPointsForObjectLambda")
    def to_list_access_points_for_object_lambda(self) -> "S3":
        '''(experimental) Grants permission to list object lambda enabled accesspoints.

        Access Level: List

        Possible conditions:

        - .ifAuthType()
        - .ifResourceAccount()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifTlsVersion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_ListAccessPointsForObjectLambda.html

        :stability: experimental
        '''
        return typing.cast("S3", jsii.invoke(self, "toListAccessPointsForObjectLambda", []))

    @jsii.member(jsii_name="toListAllMyBuckets")
    def to_list_all_my_buckets(self) -> "S3":
        '''(experimental) Grants permission to list all buckets owned by the authenticated sender of the request.

        Access Level: List

        Possible conditions:

        - .ifAuthType()
        - .ifResourceAccount()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifTlsVersion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_ListBuckets.html

        :stability: experimental
        '''
        return typing.cast("S3", jsii.invoke(self, "toListAllMyBuckets", []))

    @jsii.member(jsii_name="toListBucket")
    def to_list_bucket(self) -> "S3":
        '''(experimental) Grants permission to list some or all of the objects in an Amazon S3 bucket (up to 1000).

        Access Level: List

        Possible conditions:

        - .ifDataAccessPointAccount()
        - .ifDataAccessPointArn()
        - .ifAccessPointNetworkOrigin()
        - .ifAuthType()
        - .ifDelimiter()
        - .ifMaxKeys()
        - .ifPrefix()
        - .ifResourceAccount()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifTlsVersion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_ListObjectsV2.html

        :stability: experimental
        '''
        return typing.cast("S3", jsii.invoke(self, "toListBucket", []))

    @jsii.member(jsii_name="toListBucketMultipartUploads")
    def to_list_bucket_multipart_uploads(self) -> "S3":
        '''(experimental) Grants permission to list in-progress multipart uploads.

        Access Level: List

        Possible conditions:

        - .ifDataAccessPointAccount()
        - .ifDataAccessPointArn()
        - .ifAccessPointNetworkOrigin()
        - .ifAuthType()
        - .ifResourceAccount()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifTlsVersion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_ListMultipartUploads.html

        :stability: experimental
        '''
        return typing.cast("S3", jsii.invoke(self, "toListBucketMultipartUploads", []))

    @jsii.member(jsii_name="toListBucketVersions")
    def to_list_bucket_versions(self) -> "S3":
        '''(experimental) Grants permission to list metadata about all the versions of objects in an Amazon S3 bucket.

        Access Level: List

        Possible conditions:

        - .ifDataAccessPointAccount()
        - .ifDataAccessPointArn()
        - .ifAccessPointNetworkOrigin()
        - .ifAuthType()
        - .ifDelimiter()
        - .ifMaxKeys()
        - .ifPrefix()
        - .ifResourceAccount()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifTlsVersion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_ListObjectVersions.html

        :stability: experimental
        '''
        return typing.cast("S3", jsii.invoke(self, "toListBucketVersions", []))

    @jsii.member(jsii_name="toListJobs")
    def to_list_jobs(self) -> "S3":
        '''(experimental) Grants permission to list current jobs and jobs that have ended recently.

        Access Level: List

        Possible conditions:

        - .ifAuthType()
        - .ifResourceAccount()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifTlsVersion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_ListJobs.html

        :stability: experimental
        '''
        return typing.cast("S3", jsii.invoke(self, "toListJobs", []))

    @jsii.member(jsii_name="toListMultipartUploadParts")
    def to_list_multipart_upload_parts(self) -> "S3":
        '''(experimental) Grants permission to list the parts that have been uploaded for a specific multipart upload.

        Access Level: List

        Possible conditions:

        - .ifDataAccessPointAccount()
        - .ifDataAccessPointArn()
        - .ifAccessPointNetworkOrigin()
        - .ifAuthType()
        - .ifResourceAccount()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifTlsVersion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_ListParts.html

        :stability: experimental
        '''
        return typing.cast("S3", jsii.invoke(self, "toListMultipartUploadParts", []))

    @jsii.member(jsii_name="toListMultiRegionAccessPoints")
    def to_list_multi_region_access_points(self) -> "S3":
        '''(experimental) Grants permission to list Multi-Region Access Points.

        Access Level: List

        Possible conditions:

        - .ifAuthType()
        - .ifResourceAccount()
        - .ifSignatureversion()
        - .ifSignatureAge()
        - .ifTlsVersion()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_ListMultiRegionAccessPoints.html

        :stability: experimental
        '''
        return typing.cast("S3", jsii.invoke(self, "toListMultiRegionAccessPoints", []))

    @jsii.member(jsii_name="toListStorageLensConfigurations")
    def to_list_storage_lens_configurations(self) -> "S3":
        '''(experimental) Grants permission to list Amazon S3 Storage Lens configurations.

        Access Level: List

        Possible conditions:

        - .ifAuthType()
        - .ifResourceAccount()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifTlsVersion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_ListStorageLensConfigurations.html

        :stability: experimental
        '''
        return typing.cast("S3", jsii.invoke(self, "toListStorageLensConfigurations", []))

    @jsii.member(jsii_name="toObjectOwnerOverrideToBucketOwner")
    def to_object_owner_override_to_bucket_owner(self) -> "S3":
        '''(experimental) Grants permission to change replica ownership.

        Access Level: Permissions management

        Possible conditions:

        - .ifAuthType()
        - .ifResourceAccount()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifTlsVersion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/userguide/replication-change-owner.html#repl-ownership-add-role-permission

        :stability: experimental
        '''
        return typing.cast("S3", jsii.invoke(self, "toObjectOwnerOverrideToBucketOwner", []))

    @jsii.member(jsii_name="toPutAccelerateConfiguration")
    def to_put_accelerate_configuration(self) -> "S3":
        '''(experimental) Grants permission to use the accelerate subresource to set the Transfer Acceleration state of an existing S3 bucket.

        Access Level: Write

        Possible conditions:

        - .ifAuthType()
        - .ifResourceAccount()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifTlsVersion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_PutBucketAccelerateConfiguration.html

        :stability: experimental
        '''
        return typing.cast("S3", jsii.invoke(self, "toPutAccelerateConfiguration", []))

    @jsii.member(jsii_name="toPutAccessPointConfigurationForObjectLambda")
    def to_put_access_point_configuration_for_object_lambda(self) -> "S3":
        '''(experimental) Grants permission to set the configuration of the object lambda enabled access point.

        Access Level: Write

        Possible conditions:

        - .ifDataAccessPointArn()
        - .ifDataAccessPointAccount()
        - .ifAccessPointNetworkOrigin()
        - .ifAuthType()
        - .ifResourceAccount()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifTlsVersion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_PutAccessPointConfigurationForObjectLambda.html

        :stability: experimental
        '''
        return typing.cast("S3", jsii.invoke(self, "toPutAccessPointConfigurationForObjectLambda", []))

    @jsii.member(jsii_name="toPutAccessPointPolicy")
    def to_put_access_point_policy(self) -> "S3":
        '''(experimental) Grants permission to associate an access policy with a specified access point.

        Access Level: Permissions management

        Possible conditions:

        - .ifDataAccessPointAccount()
        - .ifDataAccessPointArn()
        - .ifAccessPointNetworkOrigin()
        - .ifAuthType()
        - .ifResourceAccount()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifTlsVersion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_PutAccessPointPolicy.html

        :stability: experimental
        '''
        return typing.cast("S3", jsii.invoke(self, "toPutAccessPointPolicy", []))

    @jsii.member(jsii_name="toPutAccessPointPolicyForObjectLambda")
    def to_put_access_point_policy_for_object_lambda(self) -> "S3":
        '''(experimental) Grants permission to associate an access policy with a specified object lambda enabled access point.

        Access Level: Permissions management

        Possible conditions:

        - .ifDataAccessPointAccount()
        - .ifDataAccessPointArn()
        - .ifAccessPointNetworkOrigin()
        - .ifAuthType()
        - .ifResourceAccount()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifTlsVersion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_PutAccessPointPolicyForObjectLambda.html

        :stability: experimental
        '''
        return typing.cast("S3", jsii.invoke(self, "toPutAccessPointPolicyForObjectLambda", []))

    @jsii.member(jsii_name="toPutAccessPointPublicAccessBlock")
    def to_put_access_point_public_access_block(self) -> "S3":
        '''(experimental) Grants permission to associate public access block configurations with a specified access point, while creating a access point.

        Access Level: Permissions management

        https://docs.aws.amazon.com/AmazonS3/latest/userguide/access-control-block-public-access.html#access-control-block-public-access-examples-access-point

        :stability: experimental
        '''
        return typing.cast("S3", jsii.invoke(self, "toPutAccessPointPublicAccessBlock", []))

    @jsii.member(jsii_name="toPutAccountPublicAccessBlock")
    def to_put_account_public_access_block(self) -> "S3":
        '''(experimental) Grants permission to create or modify the PublicAccessBlock configuration for an AWS account.

        Access Level: Permissions management

        Possible conditions:

        - .ifAuthType()
        - .ifResourceAccount()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifTlsVersion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_PutPublicAccessBlock.html

        :stability: experimental
        '''
        return typing.cast("S3", jsii.invoke(self, "toPutAccountPublicAccessBlock", []))

    @jsii.member(jsii_name="toPutAnalyticsConfiguration")
    def to_put_analytics_configuration(self) -> "S3":
        '''(experimental) Grants permission to set an analytics configuration for the bucket, specified by the analytics configuration ID.

        Access Level: Write

        Possible conditions:

        - .ifAuthType()
        - .ifResourceAccount()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifTlsVersion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_PutBucketAnalyticsConfiguration.html

        :stability: experimental
        '''
        return typing.cast("S3", jsii.invoke(self, "toPutAnalyticsConfiguration", []))

    @jsii.member(jsii_name="toPutBucketAcl")
    def to_put_bucket_acl(self) -> "S3":
        '''(experimental) Grants permission to set the permissions on an existing bucket using access control lists (ACLs).

        Access Level: Permissions management

        Possible conditions:

        - .ifAuthType()
        - .ifResourceAccount()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifTlsVersion()
        - .ifXAmzAcl()
        - .ifXAmzContentSha256()
        - .ifXAmzGrantFullControl()
        - .ifXAmzGrantRead()
        - .ifXAmzGrantReadAcp()
        - .ifXAmzGrantWrite()
        - .ifXAmzGrantWriteAcp()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_PutBucketAcl.html

        :stability: experimental
        '''
        return typing.cast("S3", jsii.invoke(self, "toPutBucketAcl", []))

    @jsii.member(jsii_name="toPutBucketCORS")
    def to_put_bucket_cors(self) -> "S3":
        '''(experimental) Grants permission to set the CORS configuration for an Amazon S3 bucket.

        Access Level: Write

        Possible conditions:

        - .ifAuthType()
        - .ifResourceAccount()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifTlsVersion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_PutBucketCors.html

        :stability: experimental
        '''
        return typing.cast("S3", jsii.invoke(self, "toPutBucketCORS", []))

    @jsii.member(jsii_name="toPutBucketLogging")
    def to_put_bucket_logging(self) -> "S3":
        '''(experimental) Grants permission to set the logging parameters for an Amazon S3 bucket.

        Access Level: Write

        Possible conditions:

        - .ifAuthType()
        - .ifResourceAccount()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifTlsVersion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_PutBucketLogging.html

        :stability: experimental
        '''
        return typing.cast("S3", jsii.invoke(self, "toPutBucketLogging", []))

    @jsii.member(jsii_name="toPutBucketNotification")
    def to_put_bucket_notification(self) -> "S3":
        '''(experimental) Grants permission to receive notifications when certain events happen in an Amazon S3 bucket.

        Access Level: Write

        Possible conditions:

        - .ifAuthType()
        - .ifResourceAccount()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifTlsVersion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_PutBucketNotification.html

        :stability: experimental
        '''
        return typing.cast("S3", jsii.invoke(self, "toPutBucketNotification", []))

    @jsii.member(jsii_name="toPutBucketObjectLockConfiguration")
    def to_put_bucket_object_lock_configuration(self) -> "S3":
        '''(experimental) Grants permission to put Object Lock configuration on a specific bucket.

        Access Level: Write

        Possible conditions:

        - .ifAuthType()
        - .ifResourceAccount()
        - .ifSignatureAge()
        - .ifTlsVersion()
        - .ifSignatureversion()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_PutObjectLockConfiguration.html

        :stability: experimental
        '''
        return typing.cast("S3", jsii.invoke(self, "toPutBucketObjectLockConfiguration", []))

    @jsii.member(jsii_name="toPutBucketOwnershipControls")
    def to_put_bucket_ownership_controls(self) -> "S3":
        '''(experimental) Grants permission to add, replace or delete ownership controls on a bucket.

        Access Level: Write

        Possible conditions:

        - .ifAuthType()
        - .ifResourceAccount()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifTlsVersion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_PutBucketOwnershipControls.html

        :stability: experimental
        '''
        return typing.cast("S3", jsii.invoke(self, "toPutBucketOwnershipControls", []))

    @jsii.member(jsii_name="toPutBucketPolicy")
    def to_put_bucket_policy(self) -> "S3":
        '''(experimental) Grants permission to add or replace a bucket policy on a bucket.

        Access Level: Permissions management

        Possible conditions:

        - .ifAuthType()
        - .ifResourceAccount()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifTlsVersion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_PutBucketPolicy.html

        :stability: experimental
        '''
        return typing.cast("S3", jsii.invoke(self, "toPutBucketPolicy", []))

    @jsii.member(jsii_name="toPutBucketPublicAccessBlock")
    def to_put_bucket_public_access_block(self) -> "S3":
        '''(experimental) Grants permission to create or modify the PublicAccessBlock configuration for a specific Amazon S3 bucket.

        Access Level: Permissions management

        Possible conditions:

        - .ifAuthType()
        - .ifResourceAccount()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifTlsVersion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_PutPublicAccessBlock.html

        :stability: experimental
        '''
        return typing.cast("S3", jsii.invoke(self, "toPutBucketPublicAccessBlock", []))

    @jsii.member(jsii_name="toPutBucketRequestPayment")
    def to_put_bucket_request_payment(self) -> "S3":
        '''(experimental) Grants permission to set the request payment configuration of a bucket.

        Access Level: Write

        Possible conditions:

        - .ifAuthType()
        - .ifResourceAccount()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifTlsVersion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_PutBucketRequestPayment.html

        :stability: experimental
        '''
        return typing.cast("S3", jsii.invoke(self, "toPutBucketRequestPayment", []))

    @jsii.member(jsii_name="toPutBucketTagging")
    def to_put_bucket_tagging(self) -> "S3":
        '''(experimental) Grants permission to add a set of tags to an existing Amazon S3 bucket.

        Access Level: Tagging

        Possible conditions:

        - .ifAuthType()
        - .ifResourceAccount()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifTlsVersion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_PutBucketTagging.html

        :stability: experimental
        '''
        return typing.cast("S3", jsii.invoke(self, "toPutBucketTagging", []))

    @jsii.member(jsii_name="toPutBucketVersioning")
    def to_put_bucket_versioning(self) -> "S3":
        '''(experimental) Grants permission to set the versioning state of an existing Amazon S3 bucket.

        Access Level: Write

        Possible conditions:

        - .ifAuthType()
        - .ifResourceAccount()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifTlsVersion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_PutBucketVersioning.html

        :stability: experimental
        '''
        return typing.cast("S3", jsii.invoke(self, "toPutBucketVersioning", []))

    @jsii.member(jsii_name="toPutBucketWebsite")
    def to_put_bucket_website(self) -> "S3":
        '''(experimental) Grants permission to set the configuration of the website that is specified in the website subresource.

        Access Level: Write

        Possible conditions:

        - .ifAuthType()
        - .ifResourceAccount()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifTlsVersion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_PutBucketWebsite.html

        :stability: experimental
        '''
        return typing.cast("S3", jsii.invoke(self, "toPutBucketWebsite", []))

    @jsii.member(jsii_name="toPutEncryptionConfiguration")
    def to_put_encryption_configuration(self) -> "S3":
        '''(experimental) Grants permission to set the encryption configuration for an Amazon S3 bucket.

        Access Level: Write

        Possible conditions:

        - .ifAuthType()
        - .ifResourceAccount()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifTlsVersion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_PutBucketEncryption.html

        :stability: experimental
        '''
        return typing.cast("S3", jsii.invoke(self, "toPutEncryptionConfiguration", []))

    @jsii.member(jsii_name="toPutIntelligentTieringConfiguration")
    def to_put_intelligent_tiering_configuration(self) -> "S3":
        '''(experimental) Grants permission to create new or update or delete an existing Amazon S3 Intelligent Tiering configuration.

        Access Level: Write

        Possible conditions:

        - .ifAuthType()
        - .ifResourceAccount()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifTlsVersion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_PutBucketIntelligentTieringConfiguration.html

        :stability: experimental
        '''
        return typing.cast("S3", jsii.invoke(self, "toPutIntelligentTieringConfiguration", []))

    @jsii.member(jsii_name="toPutInventoryConfiguration")
    def to_put_inventory_configuration(self) -> "S3":
        '''(experimental) Grants permission to add an inventory configuration to the bucket, identified by the inventory ID.

        Access Level: Write

        Possible conditions:

        - .ifAuthType()
        - .ifResourceAccount()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifTlsVersion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_PutBucketInventoryConfiguration.html

        :stability: experimental
        '''
        return typing.cast("S3", jsii.invoke(self, "toPutInventoryConfiguration", []))

    @jsii.member(jsii_name="toPutJobTagging")
    def to_put_job_tagging(self) -> "S3":
        '''(experimental) Grants permission to replace tags on an existing Amazon S3 Batch Operations job.

        Access Level: Tagging

        Possible conditions:

        - .ifAuthType()
        - .ifResourceAccount()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifTlsVersion()
        - .ifXAmzContentSha256()
        - .ifExistingJobPriority()
        - .ifExistingJobOperation()
        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_PutJobTagging.html

        :stability: experimental
        '''
        return typing.cast("S3", jsii.invoke(self, "toPutJobTagging", []))

    @jsii.member(jsii_name="toPutLifecycleConfiguration")
    def to_put_lifecycle_configuration(self) -> "S3":
        '''(experimental) Grants permission to create a new lifecycle configuration for the bucket or replace an existing lifecycle configuration.

        Access Level: Write

        Possible conditions:

        - .ifAuthType()
        - .ifResourceAccount()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifTlsVersion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_PutBucketLifecycleConfiguration.html

        :stability: experimental
        '''
        return typing.cast("S3", jsii.invoke(self, "toPutLifecycleConfiguration", []))

    @jsii.member(jsii_name="toPutMetricsConfiguration")
    def to_put_metrics_configuration(self) -> "S3":
        '''(experimental) Grants permission to set or update a metrics configuration for the CloudWatch request metrics from an Amazon S3 bucket.

        Access Level: Write

        Possible conditions:

        - .ifAuthType()
        - .ifResourceAccount()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifTlsVersion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_PutBucketMetricsConfiguration.html

        :stability: experimental
        '''
        return typing.cast("S3", jsii.invoke(self, "toPutMetricsConfiguration", []))

    @jsii.member(jsii_name="toPutMultiRegionAccessPointPolicy")
    def to_put_multi_region_access_point_policy(self) -> "S3":
        '''(experimental) Grants permission to associate an access policy with a specified Multi-Region Access Point.

        Access Level: Permissions management

        Possible conditions:

        - .ifDataAccessPointAccount()
        - .ifDataAccessPointArn()
        - .ifAccessPointNetworkOrigin()
        - .ifAuthType()
        - .ifResourceAccount()
        - .ifSignatureversion()
        - .ifSignatureAge()
        - .ifTlsVersion()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_PutMultiRegionAccessPointPolicy.html

        :stability: experimental
        '''
        return typing.cast("S3", jsii.invoke(self, "toPutMultiRegionAccessPointPolicy", []))

    @jsii.member(jsii_name="toPutObject")
    def to_put_object(self) -> "S3":
        '''(experimental) Grants permission to add an object to a bucket.

        Access Level: Write

        Possible conditions:

        - .ifDataAccessPointAccount()
        - .ifDataAccessPointArn()
        - .ifAccessPointNetworkOrigin()
        - .ifRequestObjectTag()
        - .ifRequestObjectTagKeys()
        - .ifAuthType()
        - .ifResourceAccount()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifTlsVersion()
        - .ifXAmzAcl()
        - .ifXAmzContentSha256()
        - .ifXAmzCopySource()
        - .ifXAmzGrantFullControl()
        - .ifXAmzGrantRead()
        - .ifXAmzGrantReadAcp()
        - .ifXAmzGrantWrite()
        - .ifXAmzGrantWriteAcp()
        - .ifXAmzMetadataDirective()
        - .ifXAmzServerSideEncryption()
        - .ifXAmzServerSideEncryptionAwsKmsKeyId()
        - .ifXAmzServerSideEncryptionCustomerAlgorithm()
        - .ifXAmzStorageClass()
        - .ifXAmzWebsiteRedirectLocation()
        - .ifObjectLockMode()
        - .ifObjectLockRetainUntilDate()
        - .ifObjectLockRemainingRetentionDays()
        - .ifObjectLockLegalHold()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_PutObject.html

        :stability: experimental
        '''
        return typing.cast("S3", jsii.invoke(self, "toPutObject", []))

    @jsii.member(jsii_name="toPutObjectAcl")
    def to_put_object_acl(self) -> "S3":
        '''(experimental) Grants permission to set the access control list (ACL) permissions for new or existing objects in an S3 bucket.

        Access Level: Permissions management

        Possible conditions:

        - .ifDataAccessPointAccount()
        - .ifDataAccessPointArn()
        - .ifAccessPointNetworkOrigin()
        - .ifExistingObjectTag()
        - .ifAuthType()
        - .ifResourceAccount()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifTlsVersion()
        - .ifXAmzAcl()
        - .ifXAmzContentSha256()
        - .ifXAmzGrantFullControl()
        - .ifXAmzGrantRead()
        - .ifXAmzGrantReadAcp()
        - .ifXAmzGrantWrite()
        - .ifXAmzGrantWriteAcp()
        - .ifXAmzStorageClass()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_PutObjectAcl.html

        :stability: experimental
        '''
        return typing.cast("S3", jsii.invoke(self, "toPutObjectAcl", []))

    @jsii.member(jsii_name="toPutObjectLegalHold")
    def to_put_object_legal_hold(self) -> "S3":
        '''(experimental) Grants permission to apply a Legal Hold configuration to the specified object.

        Access Level: Write

        Possible conditions:

        - .ifDataAccessPointAccount()
        - .ifDataAccessPointArn()
        - .ifAccessPointNetworkOrigin()
        - .ifAuthType()
        - .ifResourceAccount()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifTlsVersion()
        - .ifXAmzContentSha256()
        - .ifObjectLockLegalHold()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_PutObjectLegalHold.html

        :stability: experimental
        '''
        return typing.cast("S3", jsii.invoke(self, "toPutObjectLegalHold", []))

    @jsii.member(jsii_name="toPutObjectRetention")
    def to_put_object_retention(self) -> "S3":
        '''(experimental) Grants permission to place an Object Retention configuration on an object.

        Access Level: Write

        Possible conditions:

        - .ifDataAccessPointAccount()
        - .ifDataAccessPointArn()
        - .ifAccessPointNetworkOrigin()
        - .ifAuthType()
        - .ifResourceAccount()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifTlsVersion()
        - .ifXAmzContentSha256()
        - .ifObjectLockMode()
        - .ifObjectLockRetainUntilDate()
        - .ifObjectLockRemainingRetentionDays()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_PutObjectRetention.html

        :stability: experimental
        '''
        return typing.cast("S3", jsii.invoke(self, "toPutObjectRetention", []))

    @jsii.member(jsii_name="toPutObjectTagging")
    def to_put_object_tagging(self) -> "S3":
        '''(experimental) Grants permission to set the supplied tag-set to an object that already exists in a bucket.

        Access Level: Tagging

        Possible conditions:

        - .ifDataAccessPointAccount()
        - .ifDataAccessPointArn()
        - .ifAccessPointNetworkOrigin()
        - .ifExistingObjectTag()
        - .ifRequestObjectTag()
        - .ifRequestObjectTagKeys()
        - .ifAuthType()
        - .ifResourceAccount()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifTlsVersion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_PutObjectTagging.html

        :stability: experimental
        '''
        return typing.cast("S3", jsii.invoke(self, "toPutObjectTagging", []))

    @jsii.member(jsii_name="toPutObjectVersionAcl")
    def to_put_object_version_acl(self) -> "S3":
        '''(experimental) Grants permission to use the acl subresource to set the access control list (ACL) permissions for an object that already exists in a bucket.

        Access Level: Permissions management

        Possible conditions:

        - .ifDataAccessPointAccount()
        - .ifDataAccessPointArn()
        - .ifAccessPointNetworkOrigin()
        - .ifExistingObjectTag()
        - .ifAuthType()
        - .ifResourceAccount()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifTlsVersion()
        - .ifVersionid()
        - .ifXAmzAcl()
        - .ifXAmzContentSha256()
        - .ifXAmzGrantFullControl()
        - .ifXAmzGrantRead()
        - .ifXAmzGrantReadAcp()
        - .ifXAmzGrantWrite()
        - .ifXAmzGrantWriteAcp()
        - .ifXAmzStorageClass()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_PutObjectAcl.html

        :stability: experimental
        '''
        return typing.cast("S3", jsii.invoke(self, "toPutObjectVersionAcl", []))

    @jsii.member(jsii_name="toPutObjectVersionTagging")
    def to_put_object_version_tagging(self) -> "S3":
        '''(experimental) Grants permission to set the supplied tag-set for a specific version of an object.

        Access Level: Tagging

        Possible conditions:

        - .ifDataAccessPointAccount()
        - .ifDataAccessPointArn()
        - .ifAccessPointNetworkOrigin()
        - .ifExistingObjectTag()
        - .ifRequestObjectTag()
        - .ifRequestObjectTagKeys()
        - .ifAuthType()
        - .ifResourceAccount()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifTlsVersion()
        - .ifVersionid()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_PutObjectTagging.html

        :stability: experimental
        '''
        return typing.cast("S3", jsii.invoke(self, "toPutObjectVersionTagging", []))

    @jsii.member(jsii_name="toPutReplicationConfiguration")
    def to_put_replication_configuration(self) -> "S3":
        '''(experimental) Grants permission to create a new replication configuration or replace an existing one.

        Access Level: Write

        Possible conditions:

        - .ifAuthType()
        - .ifResourceAccount()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifTlsVersion()
        - .ifXAmzContentSha256()

        Dependent actions:

        - iam:PassRole

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_PutBucketReplication.html

        :stability: experimental
        '''
        return typing.cast("S3", jsii.invoke(self, "toPutReplicationConfiguration", []))

    @jsii.member(jsii_name="toPutStorageLensConfiguration")
    def to_put_storage_lens_configuration(self) -> "S3":
        '''(experimental) Grants permission to create or update an Amazon S3 Storage Lens configuration.

        Access Level: Write

        Possible conditions:

        - .ifAuthType()
        - .ifResourceAccount()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifTlsVersion()
        - .ifXAmzContentSha256()
        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_PutStorageLensConfiguration.html

        :stability: experimental
        '''
        return typing.cast("S3", jsii.invoke(self, "toPutStorageLensConfiguration", []))

    @jsii.member(jsii_name="toPutStorageLensConfigurationTagging")
    def to_put_storage_lens_configuration_tagging(self) -> "S3":
        '''(experimental) Grants permission to put or replace tags on an existing Amazon S3 Storage Lens configuration.

        Access Level: Tagging

        Possible conditions:

        - .ifAuthType()
        - .ifResourceAccount()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifTlsVersion()
        - .ifXAmzContentSha256()
        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_PutStorageLensConfigurationTagging.html

        :stability: experimental
        '''
        return typing.cast("S3", jsii.invoke(self, "toPutStorageLensConfigurationTagging", []))

    @jsii.member(jsii_name="toReplicateDelete")
    def to_replicate_delete(self) -> "S3":
        '''(experimental) Grants permission to replicate delete markers to the destination bucket.

        Access Level: Write

        Possible conditions:

        - .ifAuthType()
        - .ifResourceAccount()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifTlsVersion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/userguide/setting-repl-config-perm-overview.html

        :stability: experimental
        '''
        return typing.cast("S3", jsii.invoke(self, "toReplicateDelete", []))

    @jsii.member(jsii_name="toReplicateObject")
    def to_replicate_object(self) -> "S3":
        '''(experimental) Grants permission to replicate objects and object tags to the destination bucket.

        Access Level: Write

        Possible conditions:

        - .ifAuthType()
        - .ifResourceAccount()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifTlsVersion()
        - .ifXAmzContentSha256()
        - .ifXAmzServerSideEncryption()
        - .ifXAmzServerSideEncryptionAwsKmsKeyId()
        - .ifXAmzServerSideEncryptionCustomerAlgorithm()

        https://docs.aws.amazon.com/AmazonS3/latest/userguide/setting-repl-config-perm-overview.html

        :stability: experimental
        '''
        return typing.cast("S3", jsii.invoke(self, "toReplicateObject", []))

    @jsii.member(jsii_name="toReplicateTags")
    def to_replicate_tags(self) -> "S3":
        '''(experimental) Grants permission to replicate object tags to the destination bucket.

        Access Level: Tagging

        Possible conditions:

        - .ifAuthType()
        - .ifResourceAccount()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifTlsVersion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/userguide/setting-repl-config-perm-overview.html

        :stability: experimental
        '''
        return typing.cast("S3", jsii.invoke(self, "toReplicateTags", []))

    @jsii.member(jsii_name="toRestoreObject")
    def to_restore_object(self) -> "S3":
        '''(experimental) Grants permission to restore an archived copy of an object back into Amazon S3.

        Access Level: Write

        Possible conditions:

        - .ifDataAccessPointAccount()
        - .ifDataAccessPointArn()
        - .ifAccessPointNetworkOrigin()
        - .ifAuthType()
        - .ifResourceAccount()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifTlsVersion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_RestoreObject.html

        :stability: experimental
        '''
        return typing.cast("S3", jsii.invoke(self, "toRestoreObject", []))

    @jsii.member(jsii_name="toSubmitMultiRegionAccessPointRoutes")
    def to_submit_multi_region_access_point_routes(self) -> "S3":
        '''(experimental) Grants permission to submit a route configuration update for a Multi-Region Access Point.

        Access Level: Write

        Possible conditions:

        - .ifDataAccessPointAccount()
        - .ifDataAccessPointArn()
        - .ifAccessPointNetworkOrigin()
        - .ifAuthType()
        - .ifResourceAccount()
        - .ifSignatureversion()
        - .ifSignatureAge()
        - .ifTlsVersion()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_SubmitMultiRegionAccessPointRoutes.html

        :stability: experimental
        '''
        return typing.cast("S3", jsii.invoke(self, "toSubmitMultiRegionAccessPointRoutes", []))

    @jsii.member(jsii_name="toUpdateJobPriority")
    def to_update_job_priority(self) -> "S3":
        '''(experimental) Grants permission to update the priority of an existing job.

        Access Level: Write

        Possible conditions:

        - .ifAuthType()
        - .ifResourceAccount()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifTlsVersion()
        - .ifXAmzContentSha256()
        - .ifRequestJobPriority()
        - .ifExistingJobPriority()
        - .ifExistingJobOperation()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_UpdateJobPriority.html

        :stability: experimental
        '''
        return typing.cast("S3", jsii.invoke(self, "toUpdateJobPriority", []))

    @jsii.member(jsii_name="toUpdateJobStatus")
    def to_update_job_status(self) -> "S3":
        '''(experimental) Grants permission to update the status for the specified job.

        Access Level: Write

        Possible conditions:

        - .ifAuthType()
        - .ifResourceAccount()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifTlsVersion()
        - .ifXAmzContentSha256()
        - .ifExistingJobPriority()
        - .ifExistingJobOperation()
        - .ifJobSuspendedCause()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_UpdateJobStatus.html

        :stability: experimental
        '''
        return typing.cast("S3", jsii.invoke(self, "toUpdateJobStatus", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__93c22689bc79bd73fe955052ba4b7519f9db4ac4437f74e343b3dcddd3b775f5)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f7675e73b6f87417455f03cb49e6f265dc29638a200f313f3f158f8d9edde866)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class S3ObjectLambda(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.S3ObjectLambda",
):
    '''(experimental) Statement provider for service `s3-object-lambda <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazons3objectlambda.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `s3-object-lambda <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazons3objectlambda.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="ifAuthType")
    def if_auth_type(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "S3ObjectLambda":
        '''(experimental) Filters access by authentication method.

        https://docs.aws.amazon.com/AmazonS3/latest/API/bucket-policy-s3-sigv4-conditions.html

        Applies to actions:

        - .toAbortMultipartUpload()
        - .toDeleteObject()
        - .toDeleteObjectTagging()
        - .toDeleteObjectVersion()
        - .toDeleteObjectVersionTagging()
        - .toGetObject()
        - .toGetObjectAcl()
        - .toGetObjectLegalHold()
        - .toGetObjectRetention()
        - .toGetObjectTagging()
        - .toGetObjectVersion()
        - .toGetObjectVersionAcl()
        - .toGetObjectVersionTagging()
        - .toListBucket()
        - .toListBucketMultipartUploads()
        - .toListBucketVersions()
        - .toListMultipartUploadParts()
        - .toPutObject()
        - .toPutObjectAcl()
        - .toPutObjectLegalHold()
        - .toPutObjectRetention()
        - .toPutObjectTagging()
        - .toPutObjectVersionAcl()
        - .toPutObjectVersionTagging()
        - .toRestoreObject()
        - .toWriteGetObjectResponse()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fc4bfc82c002341d1c6d28df2c2274f07e3fb5e2439b0f597f320ea52378dadb)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("S3ObjectLambda", jsii.invoke(self, "ifAuthType", [value, operator]))

    @jsii.member(jsii_name="ifSignatureAge")
    def if_signature_age(
        self,
        value: typing.Union[jsii.Number, typing.Sequence[jsii.Number]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "S3ObjectLambda":
        '''(experimental) Filters access by the age in milliseconds of the request signature.

        https://docs.aws.amazon.com/AmazonS3/latest/API/bucket-policy-s3-sigv4-conditions.html

        Applies to actions:

        - .toAbortMultipartUpload()
        - .toDeleteObject()
        - .toDeleteObjectTagging()
        - .toDeleteObjectVersion()
        - .toDeleteObjectVersionTagging()
        - .toGetObject()
        - .toGetObjectAcl()
        - .toGetObjectLegalHold()
        - .toGetObjectRetention()
        - .toGetObjectTagging()
        - .toGetObjectVersion()
        - .toGetObjectVersionAcl()
        - .toGetObjectVersionTagging()
        - .toListBucket()
        - .toListBucketMultipartUploads()
        - .toListBucketVersions()
        - .toListMultipartUploadParts()
        - .toPutObject()
        - .toPutObjectAcl()
        - .toPutObjectLegalHold()
        - .toPutObjectRetention()
        - .toPutObjectTagging()
        - .toPutObjectVersionAcl()
        - .toPutObjectVersionTagging()
        - .toRestoreObject()
        - .toWriteGetObjectResponse()

        :param value: The value(s) to check.
        :param operator: Works with `numeric operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_Numeric>`_. **Default:** ``NumericEquals``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__64c15ce1da97771f2346ed922e3b2aa8335e7b3af768bc9dde2686e1112a30ef)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("S3ObjectLambda", jsii.invoke(self, "ifSignatureAge", [value, operator]))

    @jsii.member(jsii_name="ifTlsVersion")
    def if_tls_version(
        self,
        value: typing.Union[jsii.Number, typing.Sequence[jsii.Number]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "S3ObjectLambda":
        '''(experimental) Filters access by the TLS version used by the client.

        https://docs.aws.amazon.com/AmazonS3/latest/API/bucket-policy-s3-sigv4-conditions.html

        Applies to actions:

        - .toAbortMultipartUpload()
        - .toDeleteObject()
        - .toDeleteObjectTagging()
        - .toDeleteObjectVersion()
        - .toDeleteObjectVersionTagging()
        - .toGetObject()
        - .toGetObjectAcl()
        - .toGetObjectLegalHold()
        - .toGetObjectRetention()
        - .toGetObjectTagging()
        - .toGetObjectVersion()
        - .toGetObjectVersionAcl()
        - .toGetObjectVersionTagging()
        - .toListBucket()
        - .toListBucketMultipartUploads()
        - .toListBucketVersions()
        - .toListMultipartUploadParts()
        - .toPutObject()
        - .toPutObjectAcl()
        - .toPutObjectLegalHold()
        - .toPutObjectRetention()
        - .toPutObjectTagging()
        - .toPutObjectVersionAcl()
        - .toPutObjectVersionTagging()
        - .toRestoreObject()
        - .toWriteGetObjectResponse()

        :param value: The value(s) to check.
        :param operator: Works with `numeric operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_Numeric>`_. **Default:** ``NumericEquals``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3429a624626fc0b23ee50578d3e344056bb351b279f3c96177e2f584f7890b42)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("S3ObjectLambda", jsii.invoke(self, "ifTlsVersion", [value, operator]))

    @jsii.member(jsii_name="ifVersionid")
    def if_versionid(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "S3ObjectLambda":
        '''(experimental) Filters access by a specific object version.

        https://docs.aws.amazon.com/AmazonS3/latest/dev/amazon-s3-policy-keys.html/#getobjectversion-limit-access-to-specific-version-3

        Applies to actions:

        - .toDeleteObjectVersion()
        - .toDeleteObjectVersionTagging()
        - .toGetObjectVersion()
        - .toGetObjectVersionAcl()
        - .toGetObjectVersionTagging()
        - .toPutObjectVersionAcl()
        - .toPutObjectVersionTagging()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0f9ef23751b9e87b204b00662c4891cc3500146b83276987f27b1872c6e63302)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("S3ObjectLambda", jsii.invoke(self, "ifVersionid", [value, operator]))

    @jsii.member(jsii_name="onObjectlambdaaccesspoint")
    def on_objectlambdaaccesspoint(
        self,
        access_point_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "S3ObjectLambda":
        '''(experimental) Adds a resource of type objectlambdaaccesspoint to the statement.

        https://docs.aws.amazon.com/AmazonS3/latest/dev/transforming-objects.html

        :param access_point_name: - Identifier for the accessPointName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__210f9edc4f4ccbd7a736c825c40c61986b15e2b69728637d1ae433d1ab6eca72)
            check_type(argname="argument access_point_name", value=access_point_name, expected_type=type_hints["access_point_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("S3ObjectLambda", jsii.invoke(self, "onObjectlambdaaccesspoint", [access_point_name, account, region, partition]))

    @jsii.member(jsii_name="toAbortMultipartUpload")
    def to_abort_multipart_upload(self) -> "S3ObjectLambda":
        '''(experimental) Grants permission to abort a multipart upload.

        Access Level: Write

        Possible conditions:

        - .ifAuthType()
        - .ifSignatureAge()
        - .ifTlsVersion()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_AbortMultipartUpload.html

        :stability: experimental
        '''
        return typing.cast("S3ObjectLambda", jsii.invoke(self, "toAbortMultipartUpload", []))

    @jsii.member(jsii_name="toDeleteObject")
    def to_delete_object(self) -> "S3ObjectLambda":
        '''(experimental) Grants permission to remove the null version of an object and insert a delete marker, which becomes the current version of the object.

        Access Level: Write

        Possible conditions:

        - .ifAuthType()
        - .ifSignatureAge()
        - .ifTlsVersion()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_DeleteObject.html

        :stability: experimental
        '''
        return typing.cast("S3ObjectLambda", jsii.invoke(self, "toDeleteObject", []))

    @jsii.member(jsii_name="toDeleteObjectTagging")
    def to_delete_object_tagging(self) -> "S3ObjectLambda":
        '''(experimental) Grants permission to use the tagging subresource to remove the entire tag set from the specified object.

        Access Level: Tagging

        Possible conditions:

        - .ifAuthType()
        - .ifSignatureAge()
        - .ifTlsVersion()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_DeleteObjectTagging.html

        :stability: experimental
        '''
        return typing.cast("S3ObjectLambda", jsii.invoke(self, "toDeleteObjectTagging", []))

    @jsii.member(jsii_name="toDeleteObjectVersion")
    def to_delete_object_version(self) -> "S3ObjectLambda":
        '''(experimental) Grants permission to remove a specific version of an object.

        Access Level: Write

        Possible conditions:

        - .ifAuthType()
        - .ifSignatureAge()
        - .ifTlsVersion()
        - .ifVersionid()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_DeleteObject.html

        :stability: experimental
        '''
        return typing.cast("S3ObjectLambda", jsii.invoke(self, "toDeleteObjectVersion", []))

    @jsii.member(jsii_name="toDeleteObjectVersionTagging")
    def to_delete_object_version_tagging(self) -> "S3ObjectLambda":
        '''(experimental) Grants permission to remove the entire tag set for a specific version of the object.

        Access Level: Tagging

        Possible conditions:

        - .ifAuthType()
        - .ifSignatureAge()
        - .ifTlsVersion()
        - .ifVersionid()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_DeleteObjectTagging.html

        :stability: experimental
        '''
        return typing.cast("S3ObjectLambda", jsii.invoke(self, "toDeleteObjectVersionTagging", []))

    @jsii.member(jsii_name="toGetObject")
    def to_get_object(self) -> "S3ObjectLambda":
        '''(experimental) Grants permission to retrieve objects from Amazon S3.

        Access Level: Read

        Possible conditions:

        - .ifAuthType()
        - .ifSignatureAge()
        - .ifTlsVersion()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetObject.html

        :stability: experimental
        '''
        return typing.cast("S3ObjectLambda", jsii.invoke(self, "toGetObject", []))

    @jsii.member(jsii_name="toGetObjectAcl")
    def to_get_object_acl(self) -> "S3ObjectLambda":
        '''(experimental) Grants permission to return the access control list (ACL) of an object.

        Access Level: Read

        Possible conditions:

        - .ifAuthType()
        - .ifSignatureAge()
        - .ifTlsVersion()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetObjectAcl.html

        :stability: experimental
        '''
        return typing.cast("S3ObjectLambda", jsii.invoke(self, "toGetObjectAcl", []))

    @jsii.member(jsii_name="toGetObjectLegalHold")
    def to_get_object_legal_hold(self) -> "S3ObjectLambda":
        '''(experimental) Grants permission to get an object's current Legal Hold status.

        Access Level: Read

        Possible conditions:

        - .ifAuthType()
        - .ifSignatureAge()
        - .ifTlsVersion()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetObjectLegalHold.html

        :stability: experimental
        '''
        return typing.cast("S3ObjectLambda", jsii.invoke(self, "toGetObjectLegalHold", []))

    @jsii.member(jsii_name="toGetObjectRetention")
    def to_get_object_retention(self) -> "S3ObjectLambda":
        '''(experimental) Grants permission to retrieve the retention settings for an object.

        Access Level: Read

        Possible conditions:

        - .ifAuthType()
        - .ifSignatureAge()
        - .ifTlsVersion()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetObjectRetention.html

        :stability: experimental
        '''
        return typing.cast("S3ObjectLambda", jsii.invoke(self, "toGetObjectRetention", []))

    @jsii.member(jsii_name="toGetObjectTagging")
    def to_get_object_tagging(self) -> "S3ObjectLambda":
        '''(experimental) Grants permission to return the tag set of an object.

        Access Level: Read

        Possible conditions:

        - .ifAuthType()
        - .ifSignatureAge()
        - .ifTlsVersion()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetObjectTagging.html

        :stability: experimental
        '''
        return typing.cast("S3ObjectLambda", jsii.invoke(self, "toGetObjectTagging", []))

    @jsii.member(jsii_name="toGetObjectVersion")
    def to_get_object_version(self) -> "S3ObjectLambda":
        '''(experimental) Grants permission to retrieve a specific version of an object.

        Access Level: Read

        Possible conditions:

        - .ifAuthType()
        - .ifSignatureAge()
        - .ifTlsVersion()
        - .ifVersionid()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetObject.html

        :stability: experimental
        '''
        return typing.cast("S3ObjectLambda", jsii.invoke(self, "toGetObjectVersion", []))

    @jsii.member(jsii_name="toGetObjectVersionAcl")
    def to_get_object_version_acl(self) -> "S3ObjectLambda":
        '''(experimental) Grants permission to return the access control list (ACL) of a specific object version.

        Access Level: Read

        Possible conditions:

        - .ifAuthType()
        - .ifSignatureAge()
        - .ifTlsVersion()
        - .ifVersionid()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetObjectAcl.html

        :stability: experimental
        '''
        return typing.cast("S3ObjectLambda", jsii.invoke(self, "toGetObjectVersionAcl", []))

    @jsii.member(jsii_name="toGetObjectVersionTagging")
    def to_get_object_version_tagging(self) -> "S3ObjectLambda":
        '''(experimental) Grants permission to return the tag set for a specific version of the object.

        Access Level: Read

        Possible conditions:

        - .ifAuthType()
        - .ifSignatureAge()
        - .ifTlsVersion()
        - .ifVersionid()

        https://docs.aws.amazon.com/AmazonS3/latest/dev/setting-repl-config-perm-overview.html

        :stability: experimental
        '''
        return typing.cast("S3ObjectLambda", jsii.invoke(self, "toGetObjectVersionTagging", []))

    @jsii.member(jsii_name="toListBucket")
    def to_list_bucket(self) -> "S3ObjectLambda":
        '''(experimental) Grants permission to list some or all of the objects in an Amazon S3 bucket (up to 1000).

        Access Level: List

        Possible conditions:

        - .ifAuthType()
        - .ifSignatureAge()
        - .ifTlsVersion()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_ListObjectsV2.html

        :stability: experimental
        '''
        return typing.cast("S3ObjectLambda", jsii.invoke(self, "toListBucket", []))

    @jsii.member(jsii_name="toListBucketMultipartUploads")
    def to_list_bucket_multipart_uploads(self) -> "S3ObjectLambda":
        '''(experimental) Grants permission to list in-progress multipart uploads.

        Access Level: List

        Possible conditions:

        - .ifAuthType()
        - .ifSignatureAge()
        - .ifTlsVersion()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_ListMultipartUploads.html

        :stability: experimental
        '''
        return typing.cast("S3ObjectLambda", jsii.invoke(self, "toListBucketMultipartUploads", []))

    @jsii.member(jsii_name="toListBucketVersions")
    def to_list_bucket_versions(self) -> "S3ObjectLambda":
        '''(experimental) Grants permission to list metadata about all the versions of objects in an Amazon S3 bucket.

        Access Level: List

        Possible conditions:

        - .ifAuthType()
        - .ifSignatureAge()
        - .ifTlsVersion()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_ListObjectVersions.html

        :stability: experimental
        '''
        return typing.cast("S3ObjectLambda", jsii.invoke(self, "toListBucketVersions", []))

    @jsii.member(jsii_name="toListMultipartUploadParts")
    def to_list_multipart_upload_parts(self) -> "S3ObjectLambda":
        '''(experimental) Grants permission to list the parts that have been uploaded for a specific multipart upload.

        Access Level: List

        Possible conditions:

        - .ifAuthType()
        - .ifSignatureAge()
        - .ifTlsVersion()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_ListParts.html

        :stability: experimental
        '''
        return typing.cast("S3ObjectLambda", jsii.invoke(self, "toListMultipartUploadParts", []))

    @jsii.member(jsii_name="toPutObject")
    def to_put_object(self) -> "S3ObjectLambda":
        '''(experimental) Grants permission to add an object to a bucket.

        Access Level: Write

        Possible conditions:

        - .ifAuthType()
        - .ifSignatureAge()
        - .ifTlsVersion()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_PutObject.html

        :stability: experimental
        '''
        return typing.cast("S3ObjectLambda", jsii.invoke(self, "toPutObject", []))

    @jsii.member(jsii_name="toPutObjectAcl")
    def to_put_object_acl(self) -> "S3ObjectLambda":
        '''(experimental) Grants permission to set the access control list (ACL) permissions for new or existing objects in an S3 bucket.

        Access Level: Permissions management

        Possible conditions:

        - .ifAuthType()
        - .ifSignatureAge()
        - .ifTlsVersion()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_PutObjectAcl.html

        :stability: experimental
        '''
        return typing.cast("S3ObjectLambda", jsii.invoke(self, "toPutObjectAcl", []))

    @jsii.member(jsii_name="toPutObjectLegalHold")
    def to_put_object_legal_hold(self) -> "S3ObjectLambda":
        '''(experimental) Grants permission to apply a Legal Hold configuration to the specified object.

        Access Level: Write

        Possible conditions:

        - .ifAuthType()
        - .ifSignatureAge()
        - .ifTlsVersion()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_PutObjectLegalHold.html

        :stability: experimental
        '''
        return typing.cast("S3ObjectLambda", jsii.invoke(self, "toPutObjectLegalHold", []))

    @jsii.member(jsii_name="toPutObjectRetention")
    def to_put_object_retention(self) -> "S3ObjectLambda":
        '''(experimental) Grants permission to place an Object Retention configuration on an object.

        Access Level: Write

        Possible conditions:

        - .ifAuthType()
        - .ifSignatureAge()
        - .ifTlsVersion()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_PutObjectRetention.html

        :stability: experimental
        '''
        return typing.cast("S3ObjectLambda", jsii.invoke(self, "toPutObjectRetention", []))

    @jsii.member(jsii_name="toPutObjectTagging")
    def to_put_object_tagging(self) -> "S3ObjectLambda":
        '''(experimental) Grants permission to set the supplied tag-set to an object that already exists in a bucket.

        Access Level: Tagging

        Possible conditions:

        - .ifAuthType()
        - .ifSignatureAge()
        - .ifTlsVersion()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_PutObjectTagging.html

        :stability: experimental
        '''
        return typing.cast("S3ObjectLambda", jsii.invoke(self, "toPutObjectTagging", []))

    @jsii.member(jsii_name="toPutObjectVersionAcl")
    def to_put_object_version_acl(self) -> "S3ObjectLambda":
        '''(experimental) Grants permission to use the acl subresource to set the access control list (ACL) permissions for an object that already exists in a bucket.

        Access Level: Permissions management

        Possible conditions:

        - .ifAuthType()
        - .ifSignatureAge()
        - .ifTlsVersion()
        - .ifVersionid()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_PutObjectAcl.html

        :stability: experimental
        '''
        return typing.cast("S3ObjectLambda", jsii.invoke(self, "toPutObjectVersionAcl", []))

    @jsii.member(jsii_name="toPutObjectVersionTagging")
    def to_put_object_version_tagging(self) -> "S3ObjectLambda":
        '''(experimental) Grants permission to set the supplied tag-set for a specific version of an object.

        Access Level: Tagging

        Possible conditions:

        - .ifAuthType()
        - .ifSignatureAge()
        - .ifTlsVersion()
        - .ifVersionid()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_PutObjectTagging.html

        :stability: experimental
        '''
        return typing.cast("S3ObjectLambda", jsii.invoke(self, "toPutObjectVersionTagging", []))

    @jsii.member(jsii_name="toRestoreObject")
    def to_restore_object(self) -> "S3ObjectLambda":
        '''(experimental) Grants permission to restore an archived copy of an object back into Amazon S3.

        Access Level: Write

        Possible conditions:

        - .ifAuthType()
        - .ifSignatureAge()
        - .ifTlsVersion()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_RestoreObject.html

        :stability: experimental
        '''
        return typing.cast("S3ObjectLambda", jsii.invoke(self, "toRestoreObject", []))

    @jsii.member(jsii_name="toWriteGetObjectResponse")
    def to_write_get_object_response(self) -> "S3ObjectLambda":
        '''(experimental) Grants permission to provide data for GetObject requests send to S3 Object Lambda.

        Access Level: Write

        Possible conditions:

        - .ifAuthType()
        - .ifSignatureAge()
        - .ifTlsVersion()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_WriteGetObjectResponse.html

        :stability: experimental
        '''
        return typing.cast("S3ObjectLambda", jsii.invoke(self, "toWriteGetObjectResponse", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9f170af3efd3de732bcfab9aa143ae085e81928189113ecf125675a55b21e7cf)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__934ae304210982986473e0b1f0fdc42e86906c0e9001b2786740481b3016ad90)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class S3Outposts(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.S3Outposts",
):
    '''(experimental) Statement provider for service `s3-outposts <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazons3onoutposts.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `s3-outposts <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazons3onoutposts.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="ifAccessPointNetworkOrigin")
    def if_access_point_network_origin(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "S3Outposts":
        '''(experimental) Filters access by the network origin (Internet or VPC).

        https://docs.aws.amazon.com/AmazonS3/latest/dev/creating-access-points.html#access-points-policies

        Applies to actions:

        - .toAbortMultipartUpload()
        - .toCreateAccessPoint()
        - .toDeleteAccessPoint()
        - .toDeleteAccessPointPolicy()
        - .toDeleteObject()
        - .toDeleteObjectTagging()
        - .toGetAccessPoint()
        - .toGetAccessPointPolicy()
        - .toGetObject()
        - .toGetObjectTagging()
        - .toListBucket()
        - .toListBucketMultipartUploads()
        - .toListMultipartUploadParts()
        - .toPutAccessPointPolicy()
        - .toPutObject()
        - .toPutObjectAcl()
        - .toPutObjectTagging()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__93686141254b0a2c349b505e200a54b5eced356bbf968886120575dd14acaa73)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("S3Outposts", jsii.invoke(self, "ifAccessPointNetworkOrigin", [value, operator]))

    @jsii.member(jsii_name="ifAuthType")
    def if_auth_type(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "S3Outposts":
        '''(experimental) Filters access by restricting incoming requests to a specific authentication method.

        https://docs.aws.amazon.com/AmazonS3/latest/API/bucket-policy-s3-sigv4-conditions.html

        Applies to actions:

        - .toAbortMultipartUpload()
        - .toCreateAccessPoint()
        - .toCreateBucket()
        - .toDeleteAccessPoint()
        - .toDeleteAccessPointPolicy()
        - .toDeleteBucket()
        - .toDeleteBucketPolicy()
        - .toDeleteObject()
        - .toDeleteObjectTagging()
        - .toGetAccessPoint()
        - .toGetAccessPointPolicy()
        - .toGetBucket()
        - .toGetBucketPolicy()
        - .toGetBucketTagging()
        - .toGetLifecycleConfiguration()
        - .toGetObject()
        - .toGetObjectTagging()
        - .toListAccessPoints()
        - .toListBucket()
        - .toListBucketMultipartUploads()
        - .toListMultipartUploadParts()
        - .toListRegionalBuckets()
        - .toPutAccessPointPolicy()
        - .toPutBucketPolicy()
        - .toPutBucketTagging()
        - .toPutLifecycleConfiguration()
        - .toPutObject()
        - .toPutObjectAcl()
        - .toPutObjectTagging()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f583acbc6918c2e6dee967cb3d1ed9ec25cc61c9efc32e4ac327d86177e1ecd0)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("S3Outposts", jsii.invoke(self, "ifAuthType", [value, operator]))

    @jsii.member(jsii_name="ifDataAccessPointAccount")
    def if_data_access_point_account(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "S3Outposts":
        '''(experimental) Filters access by the AWS Account ID that owns the access point.

        https://docs.aws.amazon.com/AmazonS3/latest/dev/creating-access-points.html#access-points-policies

        Applies to actions:

        - .toAbortMultipartUpload()
        - .toCreateAccessPoint()
        - .toDeleteAccessPoint()
        - .toDeleteAccessPointPolicy()
        - .toDeleteObject()
        - .toDeleteObjectTagging()
        - .toGetAccessPoint()
        - .toGetAccessPointPolicy()
        - .toGetObject()
        - .toGetObjectTagging()
        - .toListBucket()
        - .toListBucketMultipartUploads()
        - .toListMultipartUploadParts()
        - .toPutAccessPointPolicy()
        - .toPutObject()
        - .toPutObjectAcl()
        - .toPutObjectTagging()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__36dd511a62d924eda926815fa3594e635396ab02ecc77c8ec9377930a187909b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("S3Outposts", jsii.invoke(self, "ifDataAccessPointAccount", [value, operator]))

    @jsii.member(jsii_name="ifDataAccessPointArn")
    def if_data_access_point_arn(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "S3Outposts":
        '''(experimental) Filters access by an access point Amazon Resource Name (ARN).

        Applies to actions:

        - .toAbortMultipartUpload()
        - .toCreateAccessPoint()
        - .toDeleteAccessPoint()
        - .toDeleteAccessPointPolicy()
        - .toDeleteObject()
        - .toDeleteObjectTagging()
        - .toGetAccessPoint()
        - .toGetAccessPointPolicy()
        - .toGetObject()
        - .toGetObjectTagging()
        - .toListBucket()
        - .toListBucketMultipartUploads()
        - .toListMultipartUploadParts()
        - .toPutAccessPointPolicy()
        - .toPutObject()
        - .toPutObjectAcl()
        - .toPutObjectTagging()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__63cecf77d2041c132d0aeca564a35c0f6026f2d038fdccecc175a2b1d5e0e0e9)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("S3Outposts", jsii.invoke(self, "ifDataAccessPointArn", [value, operator]))

    @jsii.member(jsii_name="ifDelimiter")
    def if_delimiter(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "S3Outposts":
        '''(experimental) Filters access by requiring the delimiter parameter.

        https://docs.aws.amazon.com/AmazonS3/latest/dev/walkthrough1.html

        Applies to actions:

        - .toListBucket()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__69ba293463666d62d9d03ccce0bb4c4b5fb3ed9d35f9d29f354640e993b42f9b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("S3Outposts", jsii.invoke(self, "ifDelimiter", [value, operator]))

    @jsii.member(jsii_name="ifExistingObjectTag")
    def if_existing_object_tag(
        self,
        key: builtins.str,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "S3Outposts":
        '''(experimental) Filters access by requiring that an existing object tag has a specific tag key and value.

        https://docs.aws.amazon.com/AmazonS3/latest/dev/object-tagging.html#tagging-and-policies

        Applies to actions:

        - .toDeleteObjectTagging()
        - .toGetObject()
        - .toGetObjectTagging()
        - .toPutObjectAcl()
        - .toPutObjectTagging()

        :param key: The tag key to check.
        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__52f8a41a17c14dc94216332f21c95954bcc35f1b57a6c29107b8659bf5075bcf)
            check_type(argname="argument key", value=key, expected_type=type_hints["key"])
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("S3Outposts", jsii.invoke(self, "ifExistingObjectTag", [key, value, operator]))

    @jsii.member(jsii_name="ifMaxKeys")
    def if_max_keys(
        self,
        value: typing.Union[jsii.Number, typing.Sequence[jsii.Number]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "S3Outposts":
        '''(experimental) Filters access by limiting the maximum number of keys returned in a ListBucket request.

        https://docs.aws.amazon.com/AmazonS3/latest/dev/amazon-s3-policy-keys.html#example-numeric-condition-operators

        Applies to actions:

        - .toListBucket()

        :param value: The value(s) to check.
        :param operator: Works with `numeric operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_Numeric>`_. **Default:** ``NumericEquals``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__13c4de129f5daa061cd125e0e5a5a020d02b1cca1316189a24b7be442a346a1a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("S3Outposts", jsii.invoke(self, "ifMaxKeys", [value, operator]))

    @jsii.member(jsii_name="ifPrefix")
    def if_prefix(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "S3Outposts":
        '''(experimental) Filters access by key name prefix.

        https://docs.aws.amazon.com/AmazonS3/latest/dev/amazon-s3-policy-keys.html#condition-key-bucket-ops-2

        Applies to actions:

        - .toListBucket()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d6a2793b77a0e2bd96751710c7afaa913cc4bbda0156cc8a2a6470f521f49767)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("S3Outposts", jsii.invoke(self, "ifPrefix", [value, operator]))

    @jsii.member(jsii_name="ifRequestObjectTag")
    def if_request_object_tag(
        self,
        key: builtins.str,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "S3Outposts":
        '''(experimental) Filters access by restricting the tag keys and values allowed on objects.

        https://docs.aws.amazon.com/AmazonS3/latest/dev/object-tagging.html#tagging-and-policies

        Applies to actions:

        - .toPutObject()
        - .toPutObjectTagging()

        :param key: The tag key to check.
        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__464dba3ed700e89b8f59d4c9a4449be0adfee44b5ca4c46cfae3196e405af531)
            check_type(argname="argument key", value=key, expected_type=type_hints["key"])
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("S3Outposts", jsii.invoke(self, "ifRequestObjectTag", [key, value, operator]))

    @jsii.member(jsii_name="ifRequestObjectTagKeys")
    def if_request_object_tag_keys(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "S3Outposts":
        '''(experimental) Filters access by restricting the tag keys allowed on objects.

        https://docs.aws.amazon.com/AmazonS3/latest/dev/object-tagging.html#tagging-and-policies

        Applies to actions:

        - .toPutObject()
        - .toPutObjectTagging()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b52647c7c0f6268c58d4f12e818ed4e3ff4200a84d4de77436fd01735fc4ada0)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("S3Outposts", jsii.invoke(self, "ifRequestObjectTagKeys", [value, operator]))

    @jsii.member(jsii_name="ifSignatureAge")
    def if_signature_age(
        self,
        value: typing.Union[jsii.Number, typing.Sequence[jsii.Number]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "S3Outposts":
        '''(experimental) Filters access by identifying the length of time, in milliseconds, that a signature is valid in an authenticated request.

        https://docs.aws.amazon.com/AmazonS3/latest/API/bucket-policy-s3-sigv4-conditions.html

        Applies to actions:

        - .toAbortMultipartUpload()
        - .toCreateAccessPoint()
        - .toCreateBucket()
        - .toDeleteAccessPoint()
        - .toDeleteAccessPointPolicy()
        - .toDeleteBucket()
        - .toDeleteBucketPolicy()
        - .toDeleteObject()
        - .toDeleteObjectTagging()
        - .toGetAccessPoint()
        - .toGetAccessPointPolicy()
        - .toGetBucket()
        - .toGetBucketPolicy()
        - .toGetBucketTagging()
        - .toGetLifecycleConfiguration()
        - .toGetObject()
        - .toGetObjectTagging()
        - .toListAccessPoints()
        - .toListBucket()
        - .toListBucketMultipartUploads()
        - .toListMultipartUploadParts()
        - .toListRegionalBuckets()
        - .toPutAccessPointPolicy()
        - .toPutBucketPolicy()
        - .toPutBucketTagging()
        - .toPutLifecycleConfiguration()
        - .toPutObject()
        - .toPutObjectAcl()
        - .toPutObjectTagging()

        :param value: The value(s) to check.
        :param operator: Works with `numeric operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_Numeric>`_. **Default:** ``NumericEquals``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bc97fdf40af742f5cff495dd2c0a33c1a6a270261ce48cfca72ba3e813b2c4e5)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("S3Outposts", jsii.invoke(self, "ifSignatureAge", [value, operator]))

    @jsii.member(jsii_name="ifSignatureversion")
    def if_signatureversion(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "S3Outposts":
        '''(experimental) Filters access by identifying the version of AWS Signature that is supported for authenticated requests.

        https://docs.aws.amazon.com/AmazonS3/latest/API/bucket-policy-s3-sigv4-conditions.html

        Applies to actions:

        - .toAbortMultipartUpload()
        - .toCreateAccessPoint()
        - .toCreateBucket()
        - .toDeleteAccessPoint()
        - .toDeleteAccessPointPolicy()
        - .toDeleteBucket()
        - .toDeleteBucketPolicy()
        - .toDeleteObject()
        - .toDeleteObjectTagging()
        - .toGetAccessPoint()
        - .toGetAccessPointPolicy()
        - .toGetBucket()
        - .toGetBucketPolicy()
        - .toGetBucketTagging()
        - .toGetLifecycleConfiguration()
        - .toGetObject()
        - .toGetObjectTagging()
        - .toListAccessPoints()
        - .toListBucket()
        - .toListBucketMultipartUploads()
        - .toListMultipartUploadParts()
        - .toListRegionalBuckets()
        - .toPutAccessPointPolicy()
        - .toPutBucketPolicy()
        - .toPutBucketTagging()
        - .toPutLifecycleConfiguration()
        - .toPutObject()
        - .toPutObjectAcl()
        - .toPutObjectTagging()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b29dbbae12af8aa1ec98fbc5ab67d0ed7e13349c7ee580681bc780994019bbe6)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("S3Outposts", jsii.invoke(self, "ifSignatureversion", [value, operator]))

    @jsii.member(jsii_name="ifXAmzAcl")
    def if_x_amz_acl(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "S3Outposts":
        '''(experimental) Filters access by requiring the x-amz-acl header with a specific canned ACL in a request.

        https://docs.aws.amazon.com/AmazonS3/latest/dev/acl-overview.html#permissions

        Applies to actions:

        - .toPutObject()
        - .toPutObjectAcl()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ea478b88c81709213dcfd6553a402827ab03e8ffcb80fa3e07f3b14388b55568)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("S3Outposts", jsii.invoke(self, "ifXAmzAcl", [value, operator]))

    @jsii.member(jsii_name="ifXAmzContentSha256")
    def if_x_amz_content_sha256(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "S3Outposts":
        '''(experimental) Filters access by disallowing unsigned content in your bucket.

        https://docs.aws.amazon.com/AmazonS3/latest/API/bucket-policy-s3-sigv4-conditions.html

        Applies to actions:

        - .toAbortMultipartUpload()
        - .toCreateAccessPoint()
        - .toCreateBucket()
        - .toDeleteAccessPoint()
        - .toDeleteAccessPointPolicy()
        - .toDeleteBucket()
        - .toDeleteBucketPolicy()
        - .toDeleteObject()
        - .toDeleteObjectTagging()
        - .toGetAccessPoint()
        - .toGetAccessPointPolicy()
        - .toGetBucket()
        - .toGetBucketPolicy()
        - .toGetBucketTagging()
        - .toGetLifecycleConfiguration()
        - .toGetObject()
        - .toGetObjectTagging()
        - .toListAccessPoints()
        - .toListBucket()
        - .toListBucketMultipartUploads()
        - .toListMultipartUploadParts()
        - .toListRegionalBuckets()
        - .toPutAccessPointPolicy()
        - .toPutBucketPolicy()
        - .toPutBucketTagging()
        - .toPutLifecycleConfiguration()
        - .toPutObject()
        - .toPutObjectAcl()
        - .toPutObjectTagging()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2f5c6711b0b6e4b5d6a60a173a2d7d4e5dfdb609a0bbc0bd555861389bed3533)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("S3Outposts", jsii.invoke(self, "ifXAmzContentSha256", [value, operator]))

    @jsii.member(jsii_name="ifXAmzCopySource")
    def if_x_amz_copy_source(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "S3Outposts":
        '''(experimental) Filters access by restricting the copy source to a specific bucket, prefix, or object.

        https://docs.aws.amazon.com/AmazonS3/latest/dev/amazon-s3-policy-keys.html#putobject-limit-copy-source-3

        Applies to actions:

        - .toPutObject()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__01c157cfbe3faf93da3e3072ad0ab290954c746b12cbab5bd8133055e03f960e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("S3Outposts", jsii.invoke(self, "ifXAmzCopySource", [value, operator]))

    @jsii.member(jsii_name="ifXAmzMetadataDirective")
    def if_x_amz_metadata_directive(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "S3Outposts":
        '''(experimental) Filters access by enabling enforcement of object metadata behavior (COPY or REPLACE) when objects are copied.

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_CopyObject.html

        Applies to actions:

        - .toPutObject()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b408a6c1ac0296fb25adf830e45af4150dd94a9654d1b0d22055d451e4fe6cbe)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("S3Outposts", jsii.invoke(self, "ifXAmzMetadataDirective", [value, operator]))

    @jsii.member(jsii_name="ifXAmzServerSideEncryption")
    def if_x_amz_server_side_encryption(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "S3Outposts":
        '''(experimental) Filters access by requiring server-side encryption.

        https://docs.aws.amazon.com/AmazonS3/latest/dev/UsingServerSideEncryption.html

        Applies to actions:

        - .toPutObject()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d2704a0fb3fa6f84cf83863cab390f40729f15dfd0ff1d2ff3071df833aa8737)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("S3Outposts", jsii.invoke(self, "ifXAmzServerSideEncryption", [value, operator]))

    @jsii.member(jsii_name="ifXAmzStorageClass")
    def if_x_amz_storage_class(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "S3Outposts":
        '''(experimental) Filters access by storage class.

        https://docs.aws.amazon.com/AmazonS3/latest/dev/storage-class-intro.html#sc-howtoset

        Applies to actions:

        - .toPutObject()
        - .toPutObjectAcl()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2c3f34a2edcf103eb7a0ea9a13fc045c906ec838a3fbe2f1ec4f9d9009fb2baf)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("S3Outposts", jsii.invoke(self, "ifXAmzStorageClass", [value, operator]))

    @jsii.member(jsii_name="onAccesspoint")
    def on_accesspoint(
        self,
        outpost_id: builtins.str,
        access_point_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "S3Outposts":
        '''(experimental) Adds a resource of type accesspoint to the statement.

        https://docs.aws.amazon.com/AmazonS3/latest/dev/access-points.html

        :param outpost_id: - Identifier for the outpostId.
        :param access_point_name: - Identifier for the accessPointName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d068a8490b61895ffbd42b872b0aeb928a92e184ed6f5e15baf35463b56772b5)
            check_type(argname="argument outpost_id", value=outpost_id, expected_type=type_hints["outpost_id"])
            check_type(argname="argument access_point_name", value=access_point_name, expected_type=type_hints["access_point_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("S3Outposts", jsii.invoke(self, "onAccesspoint", [outpost_id, access_point_name, account, region, partition]))

    @jsii.member(jsii_name="onBucket")
    def on_bucket(
        self,
        outpost_id: builtins.str,
        bucket_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "S3Outposts":
        '''(experimental) Adds a resource of type bucket to the statement.

        https://docs.aws.amazon.com/AmazonS3/latest/dev/UsingBucket.html

        :param outpost_id: - Identifier for the outpostId.
        :param bucket_name: - Identifier for the bucketName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f5564d15edabe49604432795a6e15147e7f8076eb18c41d4341993f9ee502f17)
            check_type(argname="argument outpost_id", value=outpost_id, expected_type=type_hints["outpost_id"])
            check_type(argname="argument bucket_name", value=bucket_name, expected_type=type_hints["bucket_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("S3Outposts", jsii.invoke(self, "onBucket", [outpost_id, bucket_name, account, region, partition]))

    @jsii.member(jsii_name="onEndpoint")
    def on_endpoint(
        self,
        outpost_id: builtins.str,
        endpoint_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "S3Outposts":
        '''(experimental) Adds a resource of type endpoint to the statement.

        https://docs.aws.amazon.com/AmazonS3/latest/dev/outposts-endpoints.html

        :param outpost_id: - Identifier for the outpostId.
        :param endpoint_id: - Identifier for the endpointId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ecdb383be31b74e5522569275a6984e1d11effb21bc6a252ddd5df11922ed8ec)
            check_type(argname="argument outpost_id", value=outpost_id, expected_type=type_hints["outpost_id"])
            check_type(argname="argument endpoint_id", value=endpoint_id, expected_type=type_hints["endpoint_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("S3Outposts", jsii.invoke(self, "onEndpoint", [outpost_id, endpoint_id, account, region, partition]))

    @jsii.member(jsii_name="onObject")
    def on_object(
        self,
        outpost_id: builtins.str,
        bucket_name: builtins.str,
        object_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "S3Outposts":
        '''(experimental) Adds a resource of type object to the statement.

        https://docs.aws.amazon.com/AmazonS3/latest/dev/UsingObjects.html

        :param outpost_id: - Identifier for the outpostId.
        :param bucket_name: - Identifier for the bucketName.
        :param object_name: - Identifier for the objectName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8a116574eff0a232884dc3870d489ceea2606501d599f2b76e4c53b009acf8d8)
            check_type(argname="argument outpost_id", value=outpost_id, expected_type=type_hints["outpost_id"])
            check_type(argname="argument bucket_name", value=bucket_name, expected_type=type_hints["bucket_name"])
            check_type(argname="argument object_name", value=object_name, expected_type=type_hints["object_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("S3Outposts", jsii.invoke(self, "onObject", [outpost_id, bucket_name, object_name, account, region, partition]))

    @jsii.member(jsii_name="toAbortMultipartUpload")
    def to_abort_multipart_upload(self) -> "S3Outposts":
        '''(experimental) Grants permission to abort a multipart upload.

        Access Level: Write

        Possible conditions:

        - .ifDataAccessPointArn()
        - .ifDataAccessPointAccount()
        - .ifAccessPointNetworkOrigin()
        - .ifAuthType()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_AbortMultipartUpload.html

        :stability: experimental
        '''
        return typing.cast("S3Outposts", jsii.invoke(self, "toAbortMultipartUpload", []))

    @jsii.member(jsii_name="toCreateAccessPoint")
    def to_create_access_point(self) -> "S3Outposts":
        '''(experimental) Grants permission to create a new access point.

        Access Level: Write

        Possible conditions:

        - .ifDataAccessPointAccount()
        - .ifDataAccessPointArn()
        - .ifAccessPointNetworkOrigin()
        - .ifAuthType()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_CreateAccessPoint.html

        :stability: experimental
        '''
        return typing.cast("S3Outposts", jsii.invoke(self, "toCreateAccessPoint", []))

    @jsii.member(jsii_name="toCreateBucket")
    def to_create_bucket(self) -> "S3Outposts":
        '''(experimental) Grants permission to create a new bucket.

        Access Level: Write

        Possible conditions:

        - .ifAuthType()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_CreateBucket.html

        :stability: experimental
        '''
        return typing.cast("S3Outposts", jsii.invoke(self, "toCreateBucket", []))

    @jsii.member(jsii_name="toCreateEndpoint")
    def to_create_endpoint(self) -> "S3Outposts":
        '''(experimental) Grants permission to create a new endpoint.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_s3outposts_CreateEndpoint.html

        :stability: experimental
        '''
        return typing.cast("S3Outposts", jsii.invoke(self, "toCreateEndpoint", []))

    @jsii.member(jsii_name="toDeleteAccessPoint")
    def to_delete_access_point(self) -> "S3Outposts":
        '''(experimental) Grants permission to delete the access point named in the URI.

        Access Level: Write

        Possible conditions:

        - .ifDataAccessPointArn()
        - .ifDataAccessPointAccount()
        - .ifAccessPointNetworkOrigin()
        - .ifAuthType()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_DeleteAccessPoint.html

        :stability: experimental
        '''
        return typing.cast("S3Outposts", jsii.invoke(self, "toDeleteAccessPoint", []))

    @jsii.member(jsii_name="toDeleteAccessPointPolicy")
    def to_delete_access_point_policy(self) -> "S3Outposts":
        '''(experimental) Grants permission to delete the policy on a specified access point.

        Access Level: Permissions management

        Possible conditions:

        - .ifDataAccessPointArn()
        - .ifDataAccessPointAccount()
        - .ifAccessPointNetworkOrigin()
        - .ifAuthType()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_DeleteAccessPointPolicy.html

        :stability: experimental
        '''
        return typing.cast("S3Outposts", jsii.invoke(self, "toDeleteAccessPointPolicy", []))

    @jsii.member(jsii_name="toDeleteBucket")
    def to_delete_bucket(self) -> "S3Outposts":
        '''(experimental) Grants permission to delete the bucket named in the URI.

        Access Level: Write

        Possible conditions:

        - .ifAuthType()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_DeleteBucket.html

        :stability: experimental
        '''
        return typing.cast("S3Outposts", jsii.invoke(self, "toDeleteBucket", []))

    @jsii.member(jsii_name="toDeleteBucketPolicy")
    def to_delete_bucket_policy(self) -> "S3Outposts":
        '''(experimental) Grants permission to delete the policy on a specified bucket.

        Access Level: Permissions management

        Possible conditions:

        - .ifAuthType()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_DeleteBucketPolicy.html

        :stability: experimental
        '''
        return typing.cast("S3Outposts", jsii.invoke(self, "toDeleteBucketPolicy", []))

    @jsii.member(jsii_name="toDeleteEndpoint")
    def to_delete_endpoint(self) -> "S3Outposts":
        '''(experimental) Grants permission to delete the endpoint named in the URI.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_s3outposts_DeleteEndpoint.html

        :stability: experimental
        '''
        return typing.cast("S3Outposts", jsii.invoke(self, "toDeleteEndpoint", []))

    @jsii.member(jsii_name="toDeleteObject")
    def to_delete_object(self) -> "S3Outposts":
        '''(experimental) Grants permission to remove the null version of an object and insert a delete marker, which becomes the current version of the object.

        Access Level: Write

        Possible conditions:

        - .ifDataAccessPointAccount()
        - .ifDataAccessPointArn()
        - .ifAccessPointNetworkOrigin()
        - .ifAuthType()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_DeleteObject.html

        :stability: experimental
        '''
        return typing.cast("S3Outposts", jsii.invoke(self, "toDeleteObject", []))

    @jsii.member(jsii_name="toDeleteObjectTagging")
    def to_delete_object_tagging(self) -> "S3Outposts":
        '''(experimental) Grants permission to use the tagging subresource to remove the entire tag set from the specified object.

        Access Level: Tagging

        Possible conditions:

        - .ifDataAccessPointAccount()
        - .ifDataAccessPointArn()
        - .ifAccessPointNetworkOrigin()
        - .ifExistingObjectTag()
        - .ifAuthType()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_DeleteObjectTagging.html

        :stability: experimental
        '''
        return typing.cast("S3Outposts", jsii.invoke(self, "toDeleteObjectTagging", []))

    @jsii.member(jsii_name="toGetAccessPoint")
    def to_get_access_point(self) -> "S3Outposts":
        '''(experimental) Grants permission to return configuration information about the specified access point.

        Access Level: Read

        Possible conditions:

        - .ifDataAccessPointAccount()
        - .ifDataAccessPointArn()
        - .ifAccessPointNetworkOrigin()
        - .ifAuthType()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_GetAccessPoint.html

        :stability: experimental
        '''
        return typing.cast("S3Outposts", jsii.invoke(self, "toGetAccessPoint", []))

    @jsii.member(jsii_name="toGetAccessPointPolicy")
    def to_get_access_point_policy(self) -> "S3Outposts":
        '''(experimental) Grants permission to returns the access point policy associated with the specified access point.

        Access Level: Read

        Possible conditions:

        - .ifDataAccessPointAccount()
        - .ifDataAccessPointArn()
        - .ifAccessPointNetworkOrigin()
        - .ifAuthType()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_GetAccessPointPolicy.html

        :stability: experimental
        '''
        return typing.cast("S3Outposts", jsii.invoke(self, "toGetAccessPointPolicy", []))

    @jsii.member(jsii_name="toGetBucket")
    def to_get_bucket(self) -> "S3Outposts":
        '''(experimental) Grants permission to return the bucket configuration associated with an Amazon S3 bucket.

        Access Level: Read

        Possible conditions:

        - .ifAuthType()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_GetBucket.html

        :stability: experimental
        '''
        return typing.cast("S3Outposts", jsii.invoke(self, "toGetBucket", []))

    @jsii.member(jsii_name="toGetBucketPolicy")
    def to_get_bucket_policy(self) -> "S3Outposts":
        '''(experimental) Grants permission to return the policy of the specified bucket.

        Access Level: Read

        Possible conditions:

        - .ifAuthType()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_GetBucketPolicy.html

        :stability: experimental
        '''
        return typing.cast("S3Outposts", jsii.invoke(self, "toGetBucketPolicy", []))

    @jsii.member(jsii_name="toGetBucketTagging")
    def to_get_bucket_tagging(self) -> "S3Outposts":
        '''(experimental) Grants permission to return the tag set associated with an Amazon S3 bucket.

        Access Level: Read

        Possible conditions:

        - .ifAuthType()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_GetBucketTagging.html

        :stability: experimental
        '''
        return typing.cast("S3Outposts", jsii.invoke(self, "toGetBucketTagging", []))

    @jsii.member(jsii_name="toGetLifecycleConfiguration")
    def to_get_lifecycle_configuration(self) -> "S3Outposts":
        '''(experimental) Grants permission to return the lifecycle configuration information set on an Amazon S3 bucket.

        Access Level: Read

        Possible conditions:

        - .ifAuthType()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_GetBucketLifecycleConfiguration.html

        :stability: experimental
        '''
        return typing.cast("S3Outposts", jsii.invoke(self, "toGetLifecycleConfiguration", []))

    @jsii.member(jsii_name="toGetObject")
    def to_get_object(self) -> "S3Outposts":
        '''(experimental) Grants permission to retrieve objects from Amazon S3.

        Access Level: Read

        Possible conditions:

        - .ifDataAccessPointAccount()
        - .ifDataAccessPointArn()
        - .ifAccessPointNetworkOrigin()
        - .ifExistingObjectTag()
        - .ifAuthType()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetObject.html

        :stability: experimental
        '''
        return typing.cast("S3Outposts", jsii.invoke(self, "toGetObject", []))

    @jsii.member(jsii_name="toGetObjectTagging")
    def to_get_object_tagging(self) -> "S3Outposts":
        '''(experimental) Grants permission to return the tag set of an object.

        Access Level: Read

        Possible conditions:

        - .ifDataAccessPointAccount()
        - .ifDataAccessPointArn()
        - .ifAccessPointNetworkOrigin()
        - .ifExistingObjectTag()
        - .ifAuthType()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetObjectTagging.html

        :stability: experimental
        '''
        return typing.cast("S3Outposts", jsii.invoke(self, "toGetObjectTagging", []))

    @jsii.member(jsii_name="toListAccessPoints")
    def to_list_access_points(self) -> "S3Outposts":
        '''(experimental) Grants permission to list access points.

        Access Level: List

        Possible conditions:

        - .ifAuthType()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_ListAccessPoints.html

        :stability: experimental
        '''
        return typing.cast("S3Outposts", jsii.invoke(self, "toListAccessPoints", []))

    @jsii.member(jsii_name="toListBucket")
    def to_list_bucket(self) -> "S3Outposts":
        '''(experimental) Grants permission to list some or all of the objects in an Amazon S3 bucket (up to 1000).

        Access Level: List

        Possible conditions:

        - .ifDataAccessPointAccount()
        - .ifDataAccessPointArn()
        - .ifAccessPointNetworkOrigin()
        - .ifAuthType()
        - .ifDelimiter()
        - .ifMaxKeys()
        - .ifPrefix()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_ListObjectsV2.html

        :stability: experimental
        '''
        return typing.cast("S3Outposts", jsii.invoke(self, "toListBucket", []))

    @jsii.member(jsii_name="toListBucketMultipartUploads")
    def to_list_bucket_multipart_uploads(self) -> "S3Outposts":
        '''(experimental) Grants permission to list in-progress multipart uploads.

        Access Level: List

        Possible conditions:

        - .ifDataAccessPointAccount()
        - .ifDataAccessPointArn()
        - .ifAccessPointNetworkOrigin()
        - .ifAuthType()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_ListMultipartUploads.html

        :stability: experimental
        '''
        return typing.cast("S3Outposts", jsii.invoke(self, "toListBucketMultipartUploads", []))

    @jsii.member(jsii_name="toListEndpoints")
    def to_list_endpoints(self) -> "S3Outposts":
        '''(experimental) Grants permission to list endpoints.

        Access Level: List

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_s3outposts_ListEndpoints.html

        :stability: experimental
        '''
        return typing.cast("S3Outposts", jsii.invoke(self, "toListEndpoints", []))

    @jsii.member(jsii_name="toListMultipartUploadParts")
    def to_list_multipart_upload_parts(self) -> "S3Outposts":
        '''(experimental) Grants permission to list the parts that have been uploaded for a specific multipart upload.

        Access Level: List

        Possible conditions:

        - .ifDataAccessPointAccount()
        - .ifDataAccessPointArn()
        - .ifAccessPointNetworkOrigin()
        - .ifAuthType()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_ListParts.html

        :stability: experimental
        '''
        return typing.cast("S3Outposts", jsii.invoke(self, "toListMultipartUploadParts", []))

    @jsii.member(jsii_name="toListRegionalBuckets")
    def to_list_regional_buckets(self) -> "S3Outposts":
        '''(experimental) Grants permission to list all buckets owned by the authenticated sender of the request.

        Access Level: List

        Possible conditions:

        - .ifAuthType()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_ListRegionalBuckets.html

        :stability: experimental
        '''
        return typing.cast("S3Outposts", jsii.invoke(self, "toListRegionalBuckets", []))

    @jsii.member(jsii_name="toListSharedEndpoints")
    def to_list_shared_endpoints(self) -> "S3Outposts":
        '''(experimental) Grants permission to list shared endpoints.

        Access Level: List

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_s3outposts_ListSharedEndpoints.html

        :stability: experimental
        '''
        return typing.cast("S3Outposts", jsii.invoke(self, "toListSharedEndpoints", []))

    @jsii.member(jsii_name="toPutAccessPointPolicy")
    def to_put_access_point_policy(self) -> "S3Outposts":
        '''(experimental) Grants permission to associate an access policy with a specified access point.

        Access Level: Permissions management

        Possible conditions:

        - .ifDataAccessPointAccount()
        - .ifDataAccessPointArn()
        - .ifAccessPointNetworkOrigin()
        - .ifAuthType()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_PutAccessPointPolicy.html

        :stability: experimental
        '''
        return typing.cast("S3Outposts", jsii.invoke(self, "toPutAccessPointPolicy", []))

    @jsii.member(jsii_name="toPutBucketPolicy")
    def to_put_bucket_policy(self) -> "S3Outposts":
        '''(experimental) Grants permission to add or replace a bucket policy on a bucket.

        Access Level: Permissions management

        Possible conditions:

        - .ifAuthType()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_PutBucketPolicy.html

        :stability: experimental
        '''
        return typing.cast("S3Outposts", jsii.invoke(self, "toPutBucketPolicy", []))

    @jsii.member(jsii_name="toPutBucketTagging")
    def to_put_bucket_tagging(self) -> "S3Outposts":
        '''(experimental) Grants permission to add a set of tags to an existing Amazon S3 bucket.

        Access Level: Tagging

        Possible conditions:

        - .ifAuthType()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_PutBucketTagging.html

        :stability: experimental
        '''
        return typing.cast("S3Outposts", jsii.invoke(self, "toPutBucketTagging", []))

    @jsii.member(jsii_name="toPutLifecycleConfiguration")
    def to_put_lifecycle_configuration(self) -> "S3Outposts":
        '''(experimental) Grants permission to create a new lifecycle configuration for the bucket or replace an existing lifecycle configuration.

        Access Level: Write

        Possible conditions:

        - .ifAuthType()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_PutBucketLifecycleConfiguration.html

        :stability: experimental
        '''
        return typing.cast("S3Outposts", jsii.invoke(self, "toPutLifecycleConfiguration", []))

    @jsii.member(jsii_name="toPutObject")
    def to_put_object(self) -> "S3Outposts":
        '''(experimental) Grants permission to add an object to a bucket.

        Access Level: Write

        Possible conditions:

        - .ifDataAccessPointAccount()
        - .ifDataAccessPointArn()
        - .ifAccessPointNetworkOrigin()
        - .ifRequestObjectTag()
        - .ifRequestObjectTagKeys()
        - .ifAuthType()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifXAmzAcl()
        - .ifXAmzContentSha256()
        - .ifXAmzCopySource()
        - .ifXAmzMetadataDirective()
        - .ifXAmzServerSideEncryption()
        - .ifXAmzStorageClass()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_PutObject.html

        :stability: experimental
        '''
        return typing.cast("S3Outposts", jsii.invoke(self, "toPutObject", []))

    @jsii.member(jsii_name="toPutObjectAcl")
    def to_put_object_acl(self) -> "S3Outposts":
        '''(experimental) Grants permission to set the access control list (ACL) permissions for an object that already exists in a bucket.

        Access Level: Permissions management

        Possible conditions:

        - .ifDataAccessPointAccount()
        - .ifDataAccessPointArn()
        - .ifAccessPointNetworkOrigin()
        - .ifExistingObjectTag()
        - .ifAuthType()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifXAmzAcl()
        - .ifXAmzContentSha256()
        - .ifXAmzStorageClass()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_PutObjectAcl.html

        :stability: experimental
        '''
        return typing.cast("S3Outposts", jsii.invoke(self, "toPutObjectAcl", []))

    @jsii.member(jsii_name="toPutObjectTagging")
    def to_put_object_tagging(self) -> "S3Outposts":
        '''(experimental) Grants permission to set the supplied tag-set to an object that already exists in a bucket.

        Access Level: Tagging

        Possible conditions:

        - .ifDataAccessPointAccount()
        - .ifDataAccessPointArn()
        - .ifAccessPointNetworkOrigin()
        - .ifExistingObjectTag()
        - .ifRequestObjectTag()
        - .ifRequestObjectTagKeys()
        - .ifAuthType()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_PutObjectTagging.html

        :stability: experimental
        '''
        return typing.cast("S3Outposts", jsii.invoke(self, "toPutObjectTagging", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a9692b569d968c1d12d66cc382d52d6ee82e7e7b6dd5618f0627606ed4d2e445)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__204906efa745ebd378c59ad7adb5fd2da0771f6146bf1a347c1631488490536c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Sagemaker(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Sagemaker",
):
    '''(experimental) Statement provider for service `sagemaker <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonsagemaker.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `sagemaker <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonsagemaker.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="ifAcceleratorTypes")
    def if_accelerator_types(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Sagemaker":
        '''(experimental) Filters access by the list of all accelerator types associated with the resource in the request.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonsagemaker.html#amazonsagemaker-policy-keys

        Applies to actions:

        - .toCreateEndpointConfig()
        - .toCreateNotebookInstance()
        - .toUpdateNotebookInstance()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__38442d1a6d6c7e52c43a73917755a3341b8c4ba3c2e793f866711c792e9b9121)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Sagemaker", jsii.invoke(self, "ifAcceleratorTypes", [value, operator]))

    @jsii.member(jsii_name="ifAppNetworkAccessType")
    def if_app_network_access_type(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Sagemaker":
        '''(experimental) Filters access by the app network access type associated with the resource in the request.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonsagemaker.html#amazonsagemaker-policy-keys

        Applies to actions:

        - .toCreateDomain()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6e178a7841665c729c9af77cb86feadd7ab7790303f88c9d18998b3b660741d4)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Sagemaker", jsii.invoke(self, "ifAppNetworkAccessType", [value, operator]))

    @jsii.member(jsii_name="ifCustomerMetadataProperties")
    def if_customer_metadata_properties(
        self,
        metadata_key: builtins.str,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Sagemaker":
        '''(experimental) Filters access by a metadata key and value pair.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonsagemaker.html#amazonsagemaker-policy-keys

        Applies to actions:

        - .toCreateModelPackage()
        - .toUpdateModelPackage()

        :param metadata_key: The tag key to check.
        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e73770ff74847d6713adbf5ea8be8381a7f5a9bb9356c31919b05ba04fc0e6f3)
            check_type(argname="argument metadata_key", value=metadata_key, expected_type=type_hints["metadata_key"])
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Sagemaker", jsii.invoke(self, "ifCustomerMetadataProperties", [metadata_key, value, operator]))

    @jsii.member(jsii_name="ifCustomerMetadataPropertiesToRemove")
    def if_customer_metadata_properties_to_remove(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Sagemaker":
        '''(experimental) Filters access by the list of metadata properties associated with the model-package resource in the request.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonsagemaker.html#amazonsagemaker-policy-keys

        Applies to actions:

        - .toUpdateModelPackage()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b478cbf468f61eee782796e994d95681128551993fd2cea18cf6f6fed24f41e2)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Sagemaker", jsii.invoke(self, "ifCustomerMetadataPropertiesToRemove", [value, operator]))

    @jsii.member(jsii_name="ifDirectInternetAccess")
    def if_direct_internet_access(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Sagemaker":
        '''(experimental) Filters access by the direct internet access associated with the resource in the request.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonsagemaker.html#amazonsagemaker-policy-keys

        Applies to actions:

        - .toCreateNotebookInstance()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__22bfaee4059f5dbde5c3376b3fbb8710717aaf53a796c3a7f4df259fdcb1bbae)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Sagemaker", jsii.invoke(self, "ifDirectInternetAccess", [value, operator]))

    @jsii.member(jsii_name="ifDomainSharingOutputKmsKey")
    def if_domain_sharing_output_kms_key(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Sagemaker":
        '''(experimental) Filters access by the Domain sharing output KMS key associated with the resource in the request.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonsagemaker.html#amazonsagemaker-policy-keys

        Applies to actions:

        - .toCreateDomain()
        - .toCreateUserProfile()
        - .toUpdateDomain()
        - .toUpdateUserProfile()

        :param value: The value(s) to check.
        :param operator: Works with `arn operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_ARN>`_. **Default:** ``ArnLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1ce5dcae17ab5242c97a9f336ae001ec26b7c58b2aee590007b1f41a4fc355f0)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Sagemaker", jsii.invoke(self, "ifDomainSharingOutputKmsKey", [value, operator]))

    @jsii.member(jsii_name="ifFeatureGroupOfflineStoreKmsKey")
    def if_feature_group_offline_store_kms_key(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Sagemaker":
        '''(experimental) Filters access by the offline store kms key associated with the feature group resource in the request.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonsagemaker.html#amazonsagemaker-policy-keys

        Applies to actions:

        - .toCreateFeatureGroup()

        :param value: The value(s) to check.
        :param operator: Works with `arn operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_ARN>`_. **Default:** ``ArnLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ec93c95f5886280131ae4e083ff85011b62bf91df30d2dc00ad3f5ee47d02913)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Sagemaker", jsii.invoke(self, "ifFeatureGroupOfflineStoreKmsKey", [value, operator]))

    @jsii.member(jsii_name="ifFeatureGroupOfflineStoreS3Uri")
    def if_feature_group_offline_store_s3_uri(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Sagemaker":
        '''(experimental) Filters access by the offline store s3 uri associated with the feature group resource in the request.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonsagemaker.html#amazonsagemaker-policy-keys

        Applies to actions:

        - .toCreateFeatureGroup()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d417f0730f40888f6b6e26cbc04396b37bd8b775bc6e8804c23226320cac53e3)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Sagemaker", jsii.invoke(self, "ifFeatureGroupOfflineStoreS3Uri", [value, operator]))

    @jsii.member(jsii_name="ifFeatureGroupOnlineStoreKmsKey")
    def if_feature_group_online_store_kms_key(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Sagemaker":
        '''(experimental) Filters access by the online store kms key associated with the feature group resource in the request.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonsagemaker.html#amazonsagemaker-policy-keys

        Applies to actions:

        - .toCreateFeatureGroup()

        :param value: The value(s) to check.
        :param operator: Works with `arn operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_ARN>`_. **Default:** ``ArnLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__cc555a7806b59b6c9e5a08765f547e428df7bd04f3efd9e0b2f693d0e59039af)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Sagemaker", jsii.invoke(self, "ifFeatureGroupOnlineStoreKmsKey", [value, operator]))

    @jsii.member(jsii_name="ifFileSystemAccessMode")
    def if_file_system_access_mode(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Sagemaker":
        '''(experimental) Filters access by a file system access mode associated with the resource in the request.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonsagemaker.html#amazonsagemaker-policy-keys

        Applies to actions:

        - .toCreateHyperParameterTuningJob()
        - .toCreateTrainingJob()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__02c0541f77fcee7c8c8247104048d999016b7172d3a1d9a276d22d751847a1d9)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Sagemaker", jsii.invoke(self, "ifFileSystemAccessMode", [value, operator]))

    @jsii.member(jsii_name="ifFileSystemDirectoryPath")
    def if_file_system_directory_path(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Sagemaker":
        '''(experimental) Filters access by a file system directory path associated with the resource in the request.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonsagemaker.html#amazonsagemaker-policy-keys

        Applies to actions:

        - .toCreateHyperParameterTuningJob()
        - .toCreateTrainingJob()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__eb0f3980eca82453002f4144aef627bcea189b8fc761f3427d71ab2a8f819e3a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Sagemaker", jsii.invoke(self, "ifFileSystemDirectoryPath", [value, operator]))

    @jsii.member(jsii_name="ifFileSystemId")
    def if_file_system_id(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Sagemaker":
        '''(experimental) Filters access by a file system ID associated with the resource in the request.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonsagemaker.html#amazonsagemaker-policy-keys

        Applies to actions:

        - .toCreateHyperParameterTuningJob()
        - .toCreateTrainingJob()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__dc3f1efb6906d435916b330eb0d22ecdd6c1f2a3c8d734e02498db245d558249)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Sagemaker", jsii.invoke(self, "ifFileSystemId", [value, operator]))

    @jsii.member(jsii_name="ifFileSystemType")
    def if_file_system_type(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Sagemaker":
        '''(experimental) Filters access by a file system type associated with the resource in the request.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonsagemaker.html#amazonsagemaker-policy-keys

        Applies to actions:

        - .toCreateHyperParameterTuningJob()
        - .toCreateTrainingJob()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7959f00860b5ce96dea05c640b0173b03998d68acae69b7234df9e9eec397f5e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Sagemaker", jsii.invoke(self, "ifFileSystemType", [value, operator]))

    @jsii.member(jsii_name="ifHomeEfsFileSystemKmsKey")
    def if_home_efs_file_system_kms_key(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Sagemaker":
        '''(experimental) Filters access by a key that is present in the request the user makes to the SageMaker service.

        This key is deprecated. It has been replaced by sagemaker:VolumeKmsKey

        https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonsagemaker.html#amazonsagemaker-policy-keys

        :param value: The value(s) to check.
        :param operator: Works with `arn operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_ARN>`_. **Default:** ``ArnLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f79ec987df8d491782b6c2e1e115c76d66c13121a915d466dc38d50ecac5bfb5)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Sagemaker", jsii.invoke(self, "ifHomeEfsFileSystemKmsKey", [value, operator]))

    @jsii.member(jsii_name="ifImageArns")
    def if_image_arns(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Sagemaker":
        '''(experimental) Filters access by the list of all image arns associated with the resource in the request.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonsagemaker.html#amazonsagemaker-policy-keys

        Applies to actions:

        - .toCreateApp()
        - .toCreateDomain()
        - .toCreateSpace()
        - .toCreateUserProfile()
        - .toUpdateDomain()
        - .toUpdateSpace()
        - .toUpdateUserProfile()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4f028e966b200987aa2945baaaefbe79ced1347d21a5213790bd72ccbe2f1e43)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Sagemaker", jsii.invoke(self, "ifImageArns", [value, operator]))

    @jsii.member(jsii_name="ifImageVersionArns")
    def if_image_version_arns(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Sagemaker":
        '''(experimental) Filters access by the list of all image version arns associated with the resource in the request.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonsagemaker.html#amazonsagemaker-policy-keys

        Applies to actions:

        - .toCreateApp()
        - .toCreateDomain()
        - .toCreateSpace()
        - .toCreateUserProfile()
        - .toUpdateDomain()
        - .toUpdateSpace()
        - .toUpdateUserProfile()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fd008b1ee4800adca5601cd8486462f5d8f18bfc5b30860e10872ed1dac72423)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Sagemaker", jsii.invoke(self, "ifImageVersionArns", [value, operator]))

    @jsii.member(jsii_name="ifInstanceTypes")
    def if_instance_types(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Sagemaker":
        '''(experimental) Filters access by the list of all instance types associated with the resource in the request.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonsagemaker.html#amazonsagemaker-policy-keys

        Applies to actions:

        - .toCreateApp()
        - .toCreateDataQualityJobDefinition()
        - .toCreateDomain()
        - .toCreateEndpointConfig()
        - .toCreateHyperParameterTuningJob()
        - .toCreateModelBiasJobDefinition()
        - .toCreateModelExplainabilityJobDefinition()
        - .toCreateModelQualityJobDefinition()
        - .toCreateMonitoringSchedule()
        - .toCreateNotebookInstance()
        - .toCreateProcessingJob()
        - .toCreateSpace()
        - .toCreateTrainingJob()
        - .toCreateTransformJob()
        - .toCreateUserProfile()
        - .toUpdateDomain()
        - .toUpdateMonitoringSchedule()
        - .toUpdateNotebookInstance()
        - .toUpdateSpace()
        - .toUpdateTrainingJob()
        - .toUpdateUserProfile()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e0bf054dbacac533323522362b9799e36e96fd68d89bbe7ec2188038904a3cb6)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Sagemaker", jsii.invoke(self, "ifInstanceTypes", [value, operator]))

    @jsii.member(jsii_name="ifInterContainerTrafficEncryption")
    def if_inter_container_traffic_encryption(
        self,
        value: typing.Optional[builtins.bool] = None,
    ) -> "Sagemaker":
        '''(experimental) Filters access by the inter container traffic encryption associated with the resource in the request.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonsagemaker.html#amazonsagemaker-policy-keys

        Applies to actions:

        - .toCreateAutoMLJob()
        - .toCreateDataQualityJobDefinition()
        - .toCreateHyperParameterTuningJob()
        - .toCreateModelBiasJobDefinition()
        - .toCreateModelExplainabilityJobDefinition()
        - .toCreateModelQualityJobDefinition()
        - .toCreateMonitoringSchedule()
        - .toCreateProcessingJob()
        - .toCreateTrainingJob()
        - .toUpdateMonitoringSchedule()

        :param value: ``true`` or ``false``. **Default:** ``true``

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f5ac2ee25f1c07354ff383e68b97943bedaf29901f62a852a8c3dd44b3a8cfcd)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast("Sagemaker", jsii.invoke(self, "ifInterContainerTrafficEncryption", [value]))

    @jsii.member(jsii_name="ifKeepAlivePeriod")
    def if_keep_alive_period(
        self,
        value: typing.Union[jsii.Number, typing.Sequence[jsii.Number]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Sagemaker":
        '''(experimental) Filters access by the keep-alive period associated with the resource in the request.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonsagemaker.html#amazonsagemaker-policy-keys

        Applies to actions:

        - .toCreateTrainingJob()
        - .toUpdateTrainingJob()

        :param value: The value(s) to check.
        :param operator: Works with `numeric operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_Numeric>`_. **Default:** ``NumericEquals``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4f6991a1a3f8ed71bdf190b82a6375191c81a6a77a0524688f6b774833659a00)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Sagemaker", jsii.invoke(self, "ifKeepAlivePeriod", [value, operator]))

    @jsii.member(jsii_name="ifMaxRuntimeInSeconds")
    def if_max_runtime_in_seconds(
        self,
        value: typing.Union[jsii.Number, typing.Sequence[jsii.Number]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Sagemaker":
        '''(experimental) Filters access by the max runtime in seconds associated with the resource in the request.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonsagemaker.html#amazonsagemaker-policy-keys

        Applies to actions:

        - .toCreateDataQualityJobDefinition()
        - .toCreateHyperParameterTuningJob()
        - .toCreateModelBiasJobDefinition()
        - .toCreateModelExplainabilityJobDefinition()
        - .toCreateModelQualityJobDefinition()
        - .toCreateMonitoringSchedule()
        - .toCreateProcessingJob()
        - .toCreateTrainingJob()
        - .toUpdateMonitoringSchedule()

        :param value: The value(s) to check.
        :param operator: Works with `numeric operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_Numeric>`_. **Default:** ``NumericEquals``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9ad29451faa0f4098c25fab8e1b27133b219419b4836ad4975e8b8d3875c871d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Sagemaker", jsii.invoke(self, "ifMaxRuntimeInSeconds", [value, operator]))

    @jsii.member(jsii_name="ifMinimumInstanceMetadataServiceVersion")
    def if_minimum_instance_metadata_service_version(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Sagemaker":
        '''(experimental) Filters access by the minimum instance metadata service version used by the resource in the request.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonsagemaker.html#amazonsagemaker-policy-keys

        Applies to actions:

        - .toCreateNotebookInstance()
        - .toUpdateNotebookInstance()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e9d0b9fb8b7e64e20027503afada4bd2a66742ffa974f3e17b19634fee5768d2)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Sagemaker", jsii.invoke(self, "ifMinimumInstanceMetadataServiceVersion", [value, operator]))

    @jsii.member(jsii_name="ifModelApprovalStatus")
    def if_model_approval_status(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Sagemaker":
        '''(experimental) Filters access by the model approval status with the model-package in the request.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonsagemaker.html#amazonsagemaker-policy-keys

        Applies to actions:

        - .toCreateModelPackage()
        - .toUpdateModelPackage()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c4219ac8af4dd0aa8eed6e464578909eca54ea694632b5d5d40914fd1093fccb)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Sagemaker", jsii.invoke(self, "ifModelApprovalStatus", [value, operator]))

    @jsii.member(jsii_name="ifModelArn")
    def if_model_arn(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Sagemaker":
        '''(experimental) Filters access by the model arn associated with the resource in the request.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonsagemaker.html#amazonsagemaker-policy-keys

        Applies to actions:

        - .toCreateEndpointConfig()
        - .toCreateTransformJob()

        :param value: The value(s) to check.
        :param operator: Works with `arn operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_ARN>`_. **Default:** ``ArnLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__cbae8ce63a545d32b833adc0dd8e548a206cdf367739583149033905f0b45594)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Sagemaker", jsii.invoke(self, "ifModelArn", [value, operator]))

    @jsii.member(jsii_name="ifNetworkIsolation")
    def if_network_isolation(
        self,
        value: typing.Optional[builtins.bool] = None,
    ) -> "Sagemaker":
        '''(experimental) Filters access by the network isolation associated with the resource in the request.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonsagemaker.html#amazonsagemaker-policy-keys

        Applies to actions:

        - .toCreateDataQualityJobDefinition()
        - .toCreateHyperParameterTuningJob()
        - .toCreateModel()
        - .toCreateModelBiasJobDefinition()
        - .toCreateModelExplainabilityJobDefinition()
        - .toCreateModelQualityJobDefinition()
        - .toCreateMonitoringSchedule()
        - .toCreateProcessingJob()
        - .toCreateTrainingJob()
        - .toUpdateMonitoringSchedule()

        :param value: ``true`` or ``false``. **Default:** ``true``

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3b7706117e12b163e3ae349db620ec398de74ca2656a5482640c982bad4f142a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast("Sagemaker", jsii.invoke(self, "ifNetworkIsolation", [value]))

    @jsii.member(jsii_name="ifOutputKmsKey")
    def if_output_kms_key(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Sagemaker":
        '''(experimental) Filters access by the output kms key associated with the resource in the request.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonsagemaker.html#amazonsagemaker-policy-keys

        Applies to actions:

        - .toCreateAutoMLJob()
        - .toCreateDataQualityJobDefinition()
        - .toCreateHyperParameterTuningJob()
        - .toCreateLabelingJob()
        - .toCreateModelBiasJobDefinition()
        - .toCreateModelExplainabilityJobDefinition()
        - .toCreateModelQualityJobDefinition()
        - .toCreateMonitoringSchedule()
        - .toCreateProcessingJob()
        - .toCreateTrainingJob()
        - .toCreateTransformJob()
        - .toUpdateMonitoringSchedule()

        :param value: The value(s) to check.
        :param operator: Works with `arn operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_ARN>`_. **Default:** ``ArnLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__dc8b746cc89a7b0947acc332498e735fddf926bdb3b899a6e2e504200252990b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Sagemaker", jsii.invoke(self, "ifOutputKmsKey", [value, operator]))

    @jsii.member(jsii_name="ifResourceTag")
    def if_resource_tag(
        self,
        tag_key: builtins.str,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Sagemaker":
        '''(experimental) Filters access by a tag key and value pair.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonsagemaker.html#amazonsagemaker-policy-keys

        Applies to resource types:

        - device
        - device-fleet
        - edge-packaging-job
        - edge-deployment-plan
        - flow-definition
        - human-task-ui
        - inference-recommendations-job
        - inference-experiment
        - labeling-job
        - workteam
        - workforce
        - domain
        - user-profile
        - space
        - app
        - app-image-config
        - studio-lifecycle-config
        - notebook-instance
        - code-repository
        - image
        - algorithm
        - training-job
        - processing-job
        - hyper-parameter-tuning-job
        - project
        - model-package
        - model-package-group
        - model
        - endpoint-config
        - endpoint
        - transform-job
        - compilation-job
        - automl-job
        - monitoring-schedule
        - data-quality-job-definition
        - model-quality-job-definition
        - model-bias-job-definition
        - model-explainability-job-definition
        - experiment
        - experiment-trial
        - experiment-trial-component
        - feature-group
        - pipeline
        - artifact
        - context
        - action
        - lineage-group
        - model-card
        - model-card-export-job

        :param tag_key: The tag key to check.
        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__20d0b5123e397f952b65fe02d7ba41ea832a19bc48b3f274b8e5b4de3865db41)
            check_type(argname="argument tag_key", value=tag_key, expected_type=type_hints["tag_key"])
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Sagemaker", jsii.invoke(self, "ifResourceTag", [tag_key, value, operator]))

    @jsii.member(jsii_name="ifResourceTagExists")
    def if_resource_tag_exists(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Sagemaker":
        '''(experimental) Filters access by the preface string for a tag key and value pair attached to a resource.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonsagemaker.html#amazonsagemaker-policy-keys

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2cc9f187cd0a492901f3ab1999d0b1ced14f93b699fce07c5e26e285101ae768)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Sagemaker", jsii.invoke(self, "ifResourceTagExists", [value, operator]))

    @jsii.member(jsii_name="ifRootAccess")
    def if_root_access(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Sagemaker":
        '''(experimental) Filters access by the root access associated with the resource in the request.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonsagemaker.html#amazonsagemaker-policy-keys

        Applies to actions:

        - .toCreateNotebookInstance()
        - .toUpdateNotebookInstance()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__cbe9eb03133bf853570ac6cec05ed685bdce857b54735bba729c66dcac2872f2)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Sagemaker", jsii.invoke(self, "ifRootAccess", [value, operator]))

    @jsii.member(jsii_name="ifServerlessMaxConcurrency")
    def if_serverless_max_concurrency(
        self,
        value: typing.Union[jsii.Number, typing.Sequence[jsii.Number]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Sagemaker":
        '''(experimental) Filters access by limiting maximum concurrency used for Serverless inference in the request.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonsagemaker.html#amazonsagemaker-policy-keys

        Applies to actions:

        - .toCreateEndpointConfig()

        :param value: The value(s) to check.
        :param operator: Works with `numeric operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_Numeric>`_. **Default:** ``NumericEquals``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__985c6e8cc6e203d6ddafe187730de781acece6645a25cdf677e0f43b59892f8d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Sagemaker", jsii.invoke(self, "ifServerlessMaxConcurrency", [value, operator]))

    @jsii.member(jsii_name="ifServerlessMemorySize")
    def if_serverless_memory_size(
        self,
        value: typing.Union[jsii.Number, typing.Sequence[jsii.Number]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Sagemaker":
        '''(experimental) Filters access by limiting memory size used for Serverless inference in the request.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonsagemaker.html#amazonsagemaker-policy-keys

        Applies to actions:

        - .toCreateEndpointConfig()

        :param value: The value(s) to check.
        :param operator: Works with `numeric operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_Numeric>`_. **Default:** ``NumericEquals``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a8a9b2274f94c5f53e2d37db868f3e6386a24ad9f2704f18ecd7b7ba49ecd42e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Sagemaker", jsii.invoke(self, "ifServerlessMemorySize", [value, operator]))

    @jsii.member(jsii_name="ifTargetModel")
    def if_target_model(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Sagemaker":
        '''(experimental) Filters access by the target model associated with the Multi-Model Endpoint in the request.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonsagemaker.html#amazonsagemaker-policy-keys

        Applies to actions:

        - .toInvokeEndpoint()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bdbe0d36f01970e880fcd04940e108b2ad46140a5b8a3663564c6077adfc0fdf)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Sagemaker", jsii.invoke(self, "ifTargetModel", [value, operator]))

    @jsii.member(jsii_name="ifVolumeKmsKey")
    def if_volume_kms_key(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Sagemaker":
        '''(experimental) Filters access by the volume kms key associated with the resource in the request.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonsagemaker.html#amazonsagemaker-policy-keys

        Applies to actions:

        - .toCreateAutoMLJob()
        - .toCreateDataQualityJobDefinition()
        - .toCreateDomain()
        - .toCreateEndpointConfig()
        - .toCreateHyperParameterTuningJob()
        - .toCreateLabelingJob()
        - .toCreateModelBiasJobDefinition()
        - .toCreateModelExplainabilityJobDefinition()
        - .toCreateModelQualityJobDefinition()
        - .toCreateMonitoringSchedule()
        - .toCreateNotebookInstance()
        - .toCreateProcessingJob()
        - .toCreateTrainingJob()
        - .toCreateTransformJob()
        - .toUpdateMonitoringSchedule()

        :param value: The value(s) to check.
        :param operator: Works with `arn operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_ARN>`_. **Default:** ``ArnLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3a687d31c8a76cd879d30ba8a8e6ac2744293962d1abc3e020b21b895a8cda10)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Sagemaker", jsii.invoke(self, "ifVolumeKmsKey", [value, operator]))

    @jsii.member(jsii_name="ifVpcSecurityGroupIds")
    def if_vpc_security_group_ids(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Sagemaker":
        '''(experimental) Filters access by the list of all VPC security group ids associated with the resource in the request.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonsagemaker.html#amazonsagemaker-policy-keys

        Applies to actions:

        - .toCreateAutoMLJob()
        - .toCreateDataQualityJobDefinition()
        - .toCreateDomain()
        - .toCreateHyperParameterTuningJob()
        - .toCreateModel()
        - .toCreateModelBiasJobDefinition()
        - .toCreateModelExplainabilityJobDefinition()
        - .toCreateModelQualityJobDefinition()
        - .toCreateMonitoringSchedule()
        - .toCreateNotebookInstance()
        - .toCreateProcessingJob()
        - .toCreateTrainingJob()
        - .toCreateUserProfile()
        - .toUpdateDomain()
        - .toUpdateMonitoringSchedule()
        - .toUpdateUserProfile()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__587c0f08ce78efec0b38074ca3e5dbc932f349a2d7703e439812fe72f9dd1b39)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Sagemaker", jsii.invoke(self, "ifVpcSecurityGroupIds", [value, operator]))

    @jsii.member(jsii_name="ifVpcSubnets")
    def if_vpc_subnets(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Sagemaker":
        '''(experimental) Filters access by the list of all VPC subnets associated with the resource in the request.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonsagemaker.html#amazonsagemaker-policy-keys

        Applies to actions:

        - .toCreateAutoMLJob()
        - .toCreateDataQualityJobDefinition()
        - .toCreateDomain()
        - .toCreateHyperParameterTuningJob()
        - .toCreateModel()
        - .toCreateModelBiasJobDefinition()
        - .toCreateModelExplainabilityJobDefinition()
        - .toCreateModelQualityJobDefinition()
        - .toCreateMonitoringSchedule()
        - .toCreateNotebookInstance()
        - .toCreateProcessingJob()
        - .toCreateTrainingJob()
        - .toUpdateMonitoringSchedule()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e64a673a6e270f3cbadfbb68bbef3bf9a88bc5932a7b177ff7cf09d42c8a399c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Sagemaker", jsii.invoke(self, "ifVpcSubnets", [value, operator]))

    @jsii.member(jsii_name="ifWorkteamArn")
    def if_workteam_arn(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Sagemaker":
        '''(experimental) Filters access by the workteam arn associated to the request.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonsagemaker.html#amazonsagemaker-policy-keys

        Applies to actions:

        - .toCreateFlowDefinition()
        - .toCreateLabelingJob()

        :param value: The value(s) to check.
        :param operator: Works with `arn operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_ARN>`_. **Default:** ``ArnLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ade846b14df3be5e2ed6949d4b7e605a20105c02326e75a45b51f96e8d259497)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Sagemaker", jsii.invoke(self, "ifWorkteamArn", [value, operator]))

    @jsii.member(jsii_name="ifWorkteamType")
    def if_workteam_type(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Sagemaker":
        '''(experimental) Filters access by the workteam type associated to the request. This can be public-crowd, private-crowd or vendor-crowd.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonsagemaker.html#amazonsagemaker-policy-keys

        Applies to actions:

        - .toCreateFlowDefinition()
        - .toCreateLabelingJob()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f5caeae42c0c2ead37a124f568d89e2a25345c77de1fc471994227a97d1202df)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Sagemaker", jsii.invoke(self, "ifWorkteamType", [value, operator]))

    @jsii.member(jsii_name="onAction")
    def on_action(
        self,
        action_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Sagemaker":
        '''(experimental) Adds a resource of type action to the statement.

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_ActionSummary.html

        :param action_name: - Identifier for the actionName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag() - .ifResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a7aab60ec42df713912aee9360fba75ce11b1b0353b033b41b8c001cd9e93854)
            check_type(argname="argument action_name", value=action_name, expected_type=type_hints["action_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Sagemaker", jsii.invoke(self, "onAction", [action_name, account, region, partition]))

    @jsii.member(jsii_name="onAlgorithm")
    def on_algorithm(
        self,
        algorithm_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Sagemaker":
        '''(experimental) Adds a resource of type algorithm to the statement.

        https://docs.aws.amazon.com/sagemaker/latest/dg/algorithms-choose.html

        :param algorithm_name: - Identifier for the algorithmName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag() - .ifResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0b12275505ca308216b9b429c3399b27951d469a77128651059ee70e8738f4ed)
            check_type(argname="argument algorithm_name", value=algorithm_name, expected_type=type_hints["algorithm_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Sagemaker", jsii.invoke(self, "onAlgorithm", [algorithm_name, account, region, partition]))

    @jsii.member(jsii_name="onApp")
    def on_app(
        self,
        domain_id: builtins.str,
        user_profile_name: builtins.str,
        app_type: builtins.str,
        app_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Sagemaker":
        '''(experimental) Adds a resource of type app to the statement.

        https://docs.aws.amazon.com/sagemaker/latest/dg/studio-entity-status.html

        :param domain_id: - Identifier for the domainId.
        :param user_profile_name: - Identifier for the userProfileName.
        :param app_type: - Identifier for the appType.
        :param app_name: - Identifier for the appName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag() - .ifResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__353aa603fede9286da7509dd378389bdad9fe822310edde0d1ee80996969db9c)
            check_type(argname="argument domain_id", value=domain_id, expected_type=type_hints["domain_id"])
            check_type(argname="argument user_profile_name", value=user_profile_name, expected_type=type_hints["user_profile_name"])
            check_type(argname="argument app_type", value=app_type, expected_type=type_hints["app_type"])
            check_type(argname="argument app_name", value=app_name, expected_type=type_hints["app_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Sagemaker", jsii.invoke(self, "onApp", [domain_id, user_profile_name, app_type, app_name, account, region, partition]))

    @jsii.member(jsii_name="onAppImageConfig")
    def on_app_image_config(
        self,
        app_image_config_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Sagemaker":
        '''(experimental) Adds a resource of type app-image-config to the statement.

        https://docs.aws.amazon.com/sagemaker/latest/dg/studio-byoi-create.html

        :param app_image_config_name: - Identifier for the appImageConfigName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag() - .ifResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8884be6a26cbe784c53f398bab4c57ccb8caa557a2ea5f0711af9e261334f4af)
            check_type(argname="argument app_image_config_name", value=app_image_config_name, expected_type=type_hints["app_image_config_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Sagemaker", jsii.invoke(self, "onAppImageConfig", [app_image_config_name, account, region, partition]))

    @jsii.member(jsii_name="onArtifact")
    def on_artifact(
        self,
        hash_of_artifact_source: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Sagemaker":
        '''(experimental) Adds a resource of type artifact to the statement.

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_ArtifactSummary.html

        :param hash_of_artifact_source: - Identifier for the hashOfArtifactSource.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag() - .ifResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__19633f4b4aca83438e9c4604432e3b382e7f83eebead4ced33f9ffa0402f1507)
            check_type(argname="argument hash_of_artifact_source", value=hash_of_artifact_source, expected_type=type_hints["hash_of_artifact_source"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Sagemaker", jsii.invoke(self, "onArtifact", [hash_of_artifact_source, account, region, partition]))

    @jsii.member(jsii_name="onAutomlJob")
    def on_automl_job(
        self,
        auto_ml_job_job_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Sagemaker":
        '''(experimental) Adds a resource of type automl-job to the statement.

        https://docs.aws.amazon.com/sagemaker/latest/dg/autopilot-automate-model-development.html

        :param auto_ml_job_job_name: - Identifier for the autoMLJobJobName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag() - .ifResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__79dfc4c403279b53a29afc3b551bc318e2ff7e57c3e13035dd02bed0b7c0b9ee)
            check_type(argname="argument auto_ml_job_job_name", value=auto_ml_job_job_name, expected_type=type_hints["auto_ml_job_job_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Sagemaker", jsii.invoke(self, "onAutomlJob", [auto_ml_job_job_name, account, region, partition]))

    @jsii.member(jsii_name="onCodeRepository")
    def on_code_repository(
        self,
        code_repository_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Sagemaker":
        '''(experimental) Adds a resource of type code-repository to the statement.

        https://docs.aws.amazon.com/sagemaker/latest/dg/nbi-git-repo.html

        :param code_repository_name: - Identifier for the codeRepositoryName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag() - .ifResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2d8b0473b8e66364fb34223242d4fba3a69066bdbc2c1d04ab8dec3e968f8cfe)
            check_type(argname="argument code_repository_name", value=code_repository_name, expected_type=type_hints["code_repository_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Sagemaker", jsii.invoke(self, "onCodeRepository", [code_repository_name, account, region, partition]))

    @jsii.member(jsii_name="onCompilationJob")
    def on_compilation_job(
        self,
        compilation_job_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Sagemaker":
        '''(experimental) Adds a resource of type compilation-job to the statement.

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_CompilationJobSummary.html

        :param compilation_job_name: - Identifier for the compilationJobName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag() - .ifResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7d57f33572ad2444a5989fac2a91453d10e9b5e9a4438229372f6091b9cbe889)
            check_type(argname="argument compilation_job_name", value=compilation_job_name, expected_type=type_hints["compilation_job_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Sagemaker", jsii.invoke(self, "onCompilationJob", [compilation_job_name, account, region, partition]))

    @jsii.member(jsii_name="onContext")
    def on_context(
        self,
        context_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Sagemaker":
        '''(experimental) Adds a resource of type context to the statement.

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_ContextSummary.html

        :param context_name: - Identifier for the contextName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag() - .ifResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1455215de395f9291d77a6687a6ca049b7cb46c512cc7222eae6e1fb0eceb92e)
            check_type(argname="argument context_name", value=context_name, expected_type=type_hints["context_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Sagemaker", jsii.invoke(self, "onContext", [context_name, account, region, partition]))

    @jsii.member(jsii_name="onDataQualityJobDefinition")
    def on_data_quality_job_definition(
        self,
        data_quality_job_definition_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Sagemaker":
        '''(experimental) Adds a resource of type data-quality-job-definition to the statement.

        https://docs.aws.amazon.com/sagemaker/latest/dg/model-monitor-data-quality.html

        :param data_quality_job_definition_name: - Identifier for the dataQualityJobDefinitionName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag() - .ifResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e16868aa9fc74334f9f299ec7e8bb8d587319db4df9c654d5b1bad88c398f139)
            check_type(argname="argument data_quality_job_definition_name", value=data_quality_job_definition_name, expected_type=type_hints["data_quality_job_definition_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Sagemaker", jsii.invoke(self, "onDataQualityJobDefinition", [data_quality_job_definition_name, account, region, partition]))

    @jsii.member(jsii_name="onDevice")
    def on_device(
        self,
        device_fleet_name: builtins.str,
        device_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Sagemaker":
        '''(experimental) Adds a resource of type device to the statement.

        https://docs.aws.amazon.com/sagemaker/latest/dg/neo-edge-devices.html

        :param device_fleet_name: - Identifier for the deviceFleetName.
        :param device_name: - Identifier for the deviceName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag() - .ifResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7a24f4335929e2d939dda92e46a9a2eba9f2f6e4ea1dde9287ea5c100a23b085)
            check_type(argname="argument device_fleet_name", value=device_fleet_name, expected_type=type_hints["device_fleet_name"])
            check_type(argname="argument device_name", value=device_name, expected_type=type_hints["device_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Sagemaker", jsii.invoke(self, "onDevice", [device_fleet_name, device_name, account, region, partition]))

    @jsii.member(jsii_name="onDeviceFleet")
    def on_device_fleet(
        self,
        device_fleet_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Sagemaker":
        '''(experimental) Adds a resource of type device-fleet to the statement.

        https://docs.aws.amazon.com/sagemaker/latest/dg/edge-device-fleet.html

        :param device_fleet_name: - Identifier for the deviceFleetName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag() - .ifResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__685613e04bc7f6cf0f23bc8f9af6b3261de5e5f7a33aa6945190f5c2c8f6a68e)
            check_type(argname="argument device_fleet_name", value=device_fleet_name, expected_type=type_hints["device_fleet_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Sagemaker", jsii.invoke(self, "onDeviceFleet", [device_fleet_name, account, region, partition]))

    @jsii.member(jsii_name="onDomain")
    def on_domain(
        self,
        domain_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Sagemaker":
        '''(experimental) Adds a resource of type domain to the statement.

        https://docs.aws.amazon.com/sagemaker/latest/dg/studio-entity-status.html

        :param domain_id: - Identifier for the domainId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag() - .ifResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2f3a611c667e246d4e4fa0a1872d8c8b289cea470d6597dca3cc360d4f5ac3ee)
            check_type(argname="argument domain_id", value=domain_id, expected_type=type_hints["domain_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Sagemaker", jsii.invoke(self, "onDomain", [domain_id, account, region, partition]))

    @jsii.member(jsii_name="onEdgeDeploymentPlan")
    def on_edge_deployment_plan(
        self,
        edge_deployment_plan_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Sagemaker":
        '''(experimental) Adds a resource of type edge-deployment-plan to the statement.

        https://docs.aws.amazon.com/sagemaker/latest/dg/edge.html

        :param edge_deployment_plan_name: - Identifier for the edgeDeploymentPlanName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag() - .ifResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e7afc6630f09c5c6433ca122217763c497fbe455fe579e746401edbe3b6807b1)
            check_type(argname="argument edge_deployment_plan_name", value=edge_deployment_plan_name, expected_type=type_hints["edge_deployment_plan_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Sagemaker", jsii.invoke(self, "onEdgeDeploymentPlan", [edge_deployment_plan_name, account, region, partition]))

    @jsii.member(jsii_name="onEdgePackagingJob")
    def on_edge_packaging_job(
        self,
        edge_packaging_job_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Sagemaker":
        '''(experimental) Adds a resource of type edge-packaging-job to the statement.

        https://docs.aws.amazon.com/sagemaker/latest/dg/edge-packaging-job.html

        :param edge_packaging_job_name: - Identifier for the edgePackagingJobName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag() - .ifResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3a6163c6135d98c962fe1e1a2cc0b14ba29a537c3674d79eddb5e1f35f317e2c)
            check_type(argname="argument edge_packaging_job_name", value=edge_packaging_job_name, expected_type=type_hints["edge_packaging_job_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Sagemaker", jsii.invoke(self, "onEdgePackagingJob", [edge_packaging_job_name, account, region, partition]))

    @jsii.member(jsii_name="onEndpoint")
    def on_endpoint(
        self,
        endpoint_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Sagemaker":
        '''(experimental) Adds a resource of type endpoint to the statement.

        https://docs.aws.amazon.com/sagemaker/latest/dg/realtime-endpoints.html

        :param endpoint_name: - Identifier for the endpointName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag() - .ifResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d4ca62d4741c19e7c08d9eb5881c3d14d53d29c653a18911ad08dfde71052100)
            check_type(argname="argument endpoint_name", value=endpoint_name, expected_type=type_hints["endpoint_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Sagemaker", jsii.invoke(self, "onEndpoint", [endpoint_name, account, region, partition]))

    @jsii.member(jsii_name="onEndpointConfig")
    def on_endpoint_config(
        self,
        endpoint_config_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Sagemaker":
        '''(experimental) Adds a resource of type endpoint-config to the statement.

        https://docs.aws.amazon.com/sagemaker/latest/dg/realtime-endpoints.html

        :param endpoint_config_name: - Identifier for the endpointConfigName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag() - .ifResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__edb365410421c8946c855d864cf21ca573e6f2969afb09752f1ca0da8a69b85d)
            check_type(argname="argument endpoint_config_name", value=endpoint_config_name, expected_type=type_hints["endpoint_config_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Sagemaker", jsii.invoke(self, "onEndpointConfig", [endpoint_config_name, account, region, partition]))

    @jsii.member(jsii_name="onExperiment")
    def on_experiment(
        self,
        experiment_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Sagemaker":
        '''(experimental) Adds a resource of type experiment to the statement.

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_Experiment.html

        :param experiment_name: - Identifier for the experimentName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag() - .ifResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__839867f2c56946613c931ad194a7da1956d271b775de2d4e26b6db62a0b58621)
            check_type(argname="argument experiment_name", value=experiment_name, expected_type=type_hints["experiment_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Sagemaker", jsii.invoke(self, "onExperiment", [experiment_name, account, region, partition]))

    @jsii.member(jsii_name="onExperimentTrial")
    def on_experiment_trial(
        self,
        trial_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Sagemaker":
        '''(experimental) Adds a resource of type experiment-trial to the statement.

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_Trial.html

        :param trial_name: - Identifier for the trialName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag() - .ifResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bfe37173776404a06c92319ee8ad50d17efae667412fe85089f6ab8d6befbdd1)
            check_type(argname="argument trial_name", value=trial_name, expected_type=type_hints["trial_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Sagemaker", jsii.invoke(self, "onExperimentTrial", [trial_name, account, region, partition]))

    @jsii.member(jsii_name="onExperimentTrialComponent")
    def on_experiment_trial_component(
        self,
        trial_component_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Sagemaker":
        '''(experimental) Adds a resource of type experiment-trial-component to the statement.

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_TrialComponent.html

        :param trial_component_name: - Identifier for the trialComponentName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag() - .ifResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__014e25625cb0cbc5d32aa1a26824107fe0f8225aaff92f097b9663f41dc6650e)
            check_type(argname="argument trial_component_name", value=trial_component_name, expected_type=type_hints["trial_component_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Sagemaker", jsii.invoke(self, "onExperimentTrialComponent", [trial_component_name, account, region, partition]))

    @jsii.member(jsii_name="onFeatureGroup")
    def on_feature_group(
        self,
        feature_group_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Sagemaker":
        '''(experimental) Adds a resource of type feature-group to the statement.

        https://docs.aws.amazon.com/sagemaker/latest/dg/feature-store.html

        :param feature_group_name: - Identifier for the featureGroupName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag() - .ifResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__dac2a6fda8c7ed1b70b10c8cb6a3d1604845c221cb4be5811f42f9797b7d0645)
            check_type(argname="argument feature_group_name", value=feature_group_name, expected_type=type_hints["feature_group_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Sagemaker", jsii.invoke(self, "onFeatureGroup", [feature_group_name, account, region, partition]))

    @jsii.member(jsii_name="onFlowDefinition")
    def on_flow_definition(
        self,
        flow_definition_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Sagemaker":
        '''(experimental) Adds a resource of type flow-definition to the statement.

        https://docs.aws.amazon.com/sagemaker/latest/dg/a2i-create-flow-definition.html

        :param flow_definition_name: - Identifier for the flowDefinitionName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag() - .ifResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6fca58ab0598b78bcb8c1217912eec48644f304b7eb8c466b3f206a629bc9ffd)
            check_type(argname="argument flow_definition_name", value=flow_definition_name, expected_type=type_hints["flow_definition_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Sagemaker", jsii.invoke(self, "onFlowDefinition", [flow_definition_name, account, region, partition]))

    @jsii.member(jsii_name="onHub")
    def on_hub(
        self,
        hub_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Sagemaker":
        '''(experimental) Adds a resource of type hub to the statement.

        https://docs.aws.amazon.com/sagemaker/latest/dg/jumpstart-content-sharing.html

        :param hub_name: - Identifier for the hubName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d4049e90aaaba0ac841381867d1d5bd67df764ee340f98a9505d86dc8752a26e)
            check_type(argname="argument hub_name", value=hub_name, expected_type=type_hints["hub_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Sagemaker", jsii.invoke(self, "onHub", [hub_name, account, region, partition]))

    @jsii.member(jsii_name="onHubContent")
    def on_hub_content(
        self,
        hub_name: builtins.str,
        hub_content_type: builtins.str,
        hub_content_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Sagemaker":
        '''(experimental) Adds a resource of type hub-content to the statement.

        https://docs.aws.amazon.com/sagemaker/latest/dg/jumpstart-content-sharing.html

        :param hub_name: - Identifier for the hubName.
        :param hub_content_type: - Identifier for the hubContentType.
        :param hub_content_name: - Identifier for the hubContentName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f665e3d6ddc37c6471c58be9111eea6f3bdf8aa98aa5d96579d12c8caa8b2edd)
            check_type(argname="argument hub_name", value=hub_name, expected_type=type_hints["hub_name"])
            check_type(argname="argument hub_content_type", value=hub_content_type, expected_type=type_hints["hub_content_type"])
            check_type(argname="argument hub_content_name", value=hub_content_name, expected_type=type_hints["hub_content_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Sagemaker", jsii.invoke(self, "onHubContent", [hub_name, hub_content_type, hub_content_name, account, region, partition]))

    @jsii.member(jsii_name="onHumanLoop")
    def on_human_loop(
        self,
        human_loop_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Sagemaker":
        '''(experimental) Adds a resource of type human-loop to the statement.

        https://docs.aws.amazon.com/sagemaker/latest/dg/a2i-start-human-loop.html

        :param human_loop_name: - Identifier for the humanLoopName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__05dc84c9e5cfce7996ec1280e873a71469a2e5e2a21af8d9fbf52c85059fe1c6)
            check_type(argname="argument human_loop_name", value=human_loop_name, expected_type=type_hints["human_loop_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Sagemaker", jsii.invoke(self, "onHumanLoop", [human_loop_name, account, region, partition]))

    @jsii.member(jsii_name="onHumanTaskUi")
    def on_human_task_ui(
        self,
        human_task_ui_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Sagemaker":
        '''(experimental) Adds a resource of type human-task-ui to the statement.

        https://docs.aws.amazon.com/sagemaker/latest/dg/a2i-instructions-overview.html

        :param human_task_ui_name: - Identifier for the humanTaskUiName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag() - .ifResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b82d84fea15aa98f21b852784b21d244097f61939cb44847aae504a25f0559dc)
            check_type(argname="argument human_task_ui_name", value=human_task_ui_name, expected_type=type_hints["human_task_ui_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Sagemaker", jsii.invoke(self, "onHumanTaskUi", [human_task_ui_name, account, region, partition]))

    @jsii.member(jsii_name="onHyperParameterTuningJob")
    def on_hyper_parameter_tuning_job(
        self,
        hyper_parameter_tuning_job_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Sagemaker":
        '''(experimental) Adds a resource of type hyper-parameter-tuning-job to the statement.

        https://docs.aws.amazon.com/sagemaker/latest/dg/automatic-model-tuning-how-it-works.html

        :param hyper_parameter_tuning_job_name: - Identifier for the hyperParameterTuningJobName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag() - .ifResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f9aafc652dbbf2e80ff9e564632eb0f2fc6d6440459bfff8290c34622bfd05e7)
            check_type(argname="argument hyper_parameter_tuning_job_name", value=hyper_parameter_tuning_job_name, expected_type=type_hints["hyper_parameter_tuning_job_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Sagemaker", jsii.invoke(self, "onHyperParameterTuningJob", [hyper_parameter_tuning_job_name, account, region, partition]))

    @jsii.member(jsii_name="onImage")
    def on_image(
        self,
        image_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Sagemaker":
        '''(experimental) Adds a resource of type image to the statement.

        https://docs.aws.amazon.com/sagemaker/latest/dg/studio-byoi.html

        :param image_name: - Identifier for the imageName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag() - .ifResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7ef50af25cfd2284cb51fcf30be31368ff7a893d89d7d082934f306e51e40c48)
            check_type(argname="argument image_name", value=image_name, expected_type=type_hints["image_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Sagemaker", jsii.invoke(self, "onImage", [image_name, account, region, partition]))

    @jsii.member(jsii_name="onImageVersion")
    def on_image_version(
        self,
        image_name: builtins.str,
        version: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Sagemaker":
        '''(experimental) Adds a resource of type image-version to the statement.

        https://docs.aws.amazon.com/sagemaker/latest/dg/studio-byoi.html

        :param image_name: - Identifier for the imageName.
        :param version: - Identifier for the version.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__cc4fccc24cda556a8ddf83c8a16c65406192e5d2a08ca48c5b5d75583330f27d)
            check_type(argname="argument image_name", value=image_name, expected_type=type_hints["image_name"])
            check_type(argname="argument version", value=version, expected_type=type_hints["version"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Sagemaker", jsii.invoke(self, "onImageVersion", [image_name, version, account, region, partition]))

    @jsii.member(jsii_name="onInferenceExperiment")
    def on_inference_experiment(
        self,
        inference_experiment_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Sagemaker":
        '''(experimental) Adds a resource of type inference-experiment to the statement.

        https://docs.aws.amazon.com/sagemaker/latest/dg/inference-experiment.html

        :param inference_experiment_name: - Identifier for the inferenceExperimentName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag() - .ifResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2e4ded14314cd98f7bc0306694a72048730681ff1dc54050463dfb214d875210)
            check_type(argname="argument inference_experiment_name", value=inference_experiment_name, expected_type=type_hints["inference_experiment_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Sagemaker", jsii.invoke(self, "onInferenceExperiment", [inference_experiment_name, account, region, partition]))

    @jsii.member(jsii_name="onInferenceRecommendationsJob")
    def on_inference_recommendations_job(
        self,
        inference_recommendations_job_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Sagemaker":
        '''(experimental) Adds a resource of type inference-recommendations-job to the statement.

        https://docs.aws.amazon.com/sagemaker/latest/dg/inference-recommender-recommendation-jobs.html

        :param inference_recommendations_job_name: - Identifier for the inferenceRecommendationsJobName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag() - .ifResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__85948f497099f7ce80d20236cf19b14d05a8dd223e18666f7e1384349d8a4b6f)
            check_type(argname="argument inference_recommendations_job_name", value=inference_recommendations_job_name, expected_type=type_hints["inference_recommendations_job_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Sagemaker", jsii.invoke(self, "onInferenceRecommendationsJob", [inference_recommendations_job_name, account, region, partition]))

    @jsii.member(jsii_name="onLabelingJob")
    def on_labeling_job(
        self,
        labeling_job_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Sagemaker":
        '''(experimental) Adds a resource of type labeling-job to the statement.

        https://docs.aws.amazon.com/sagemaker/latest/dg/sms.html

        :param labeling_job_name: - Identifier for the labelingJobName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag() - .ifResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__76d14d22d27420bde257323f3e2b9904bb18dee186a3acce61fb892a9a6dd70e)
            check_type(argname="argument labeling_job_name", value=labeling_job_name, expected_type=type_hints["labeling_job_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Sagemaker", jsii.invoke(self, "onLabelingJob", [labeling_job_name, account, region, partition]))

    @jsii.member(jsii_name="onLineageGroup")
    def on_lineage_group(
        self,
        lineage_group_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Sagemaker":
        '''(experimental) Adds a resource of type lineage-group to the statement.

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_LineageGroupSummary.html

        :param lineage_group_name: - Identifier for the lineageGroupName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag() - .ifResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__cea28ff7be98a6fcebb30f7cf3107b12ea192e0160cf0f49b188cde664268478)
            check_type(argname="argument lineage_group_name", value=lineage_group_name, expected_type=type_hints["lineage_group_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Sagemaker", jsii.invoke(self, "onLineageGroup", [lineage_group_name, account, region, partition]))

    @jsii.member(jsii_name="onModel")
    def on_model(
        self,
        model_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Sagemaker":
        '''(experimental) Adds a resource of type model to the statement.

        https://docs.aws.amazon.com/sagemaker/latest/dg/realtime-endpoints.html

        :param model_name: - Identifier for the modelName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag() - .ifResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bfc49dfac080ba84a7ba0ed9d8152cf44257243226611be993d9882f39d75872)
            check_type(argname="argument model_name", value=model_name, expected_type=type_hints["model_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Sagemaker", jsii.invoke(self, "onModel", [model_name, account, region, partition]))

    @jsii.member(jsii_name="onModelBiasJobDefinition")
    def on_model_bias_job_definition(
        self,
        model_bias_job_definition_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Sagemaker":
        '''(experimental) Adds a resource of type model-bias-job-definition to the statement.

        https://docs.aws.amazon.com/sagemaker/latest/dg/clarify-detect-post-training-bias.html

        :param model_bias_job_definition_name: - Identifier for the modelBiasJobDefinitionName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag() - .ifResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__556fd84c3d3395693b741e02ad0206e08d3d88dabad2cd427c5daa4190427aa3)
            check_type(argname="argument model_bias_job_definition_name", value=model_bias_job_definition_name, expected_type=type_hints["model_bias_job_definition_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Sagemaker", jsii.invoke(self, "onModelBiasJobDefinition", [model_bias_job_definition_name, account, region, partition]))

    @jsii.member(jsii_name="onModelCard")
    def on_model_card(
        self,
        model_card_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Sagemaker":
        '''(experimental) Adds a resource of type model-card to the statement.

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_ModelCard.html

        :param model_card_name: - Identifier for the modelCardName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag() - .ifResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3a9269ff594d15c0935592199959468c997ef97f9af47e057bc0891a9500b1c1)
            check_type(argname="argument model_card_name", value=model_card_name, expected_type=type_hints["model_card_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Sagemaker", jsii.invoke(self, "onModelCard", [model_card_name, account, region, partition]))

    @jsii.member(jsii_name="onModelCardExportJob")
    def on_model_card_export_job(
        self,
        model_card_name: builtins.str,
        export_job_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Sagemaker":
        '''(experimental) Adds a resource of type model-card-export-job to the statement.

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_ModelCardExportJob.html

        :param model_card_name: - Identifier for the modelCardName.
        :param export_job_name: - Identifier for the exportJobName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag() - .ifResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__80649090a00407975f1f101c82a2850ab92511d9b3132538ce0665d9e7742a07)
            check_type(argname="argument model_card_name", value=model_card_name, expected_type=type_hints["model_card_name"])
            check_type(argname="argument export_job_name", value=export_job_name, expected_type=type_hints["export_job_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Sagemaker", jsii.invoke(self, "onModelCardExportJob", [model_card_name, export_job_name, account, region, partition]))

    @jsii.member(jsii_name="onModelExplainabilityJobDefinition")
    def on_model_explainability_job_definition(
        self,
        model_explainability_job_definition_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Sagemaker":
        '''(experimental) Adds a resource of type model-explainability-job-definition to the statement.

        https://docs.aws.amazon.com/sagemaker/latest/dg/clarify-model-explainability.html

        :param model_explainability_job_definition_name: - Identifier for the modelExplainabilityJobDefinitionName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag() - .ifResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ed3798fa62affc96fa0002a9a2275d56e4da2780f5d4f3dde4e8fb56c234d29d)
            check_type(argname="argument model_explainability_job_definition_name", value=model_explainability_job_definition_name, expected_type=type_hints["model_explainability_job_definition_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Sagemaker", jsii.invoke(self, "onModelExplainabilityJobDefinition", [model_explainability_job_definition_name, account, region, partition]))

    @jsii.member(jsii_name="onModelPackage")
    def on_model_package(
        self,
        model_package_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Sagemaker":
        '''(experimental) Adds a resource of type model-package to the statement.

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_ModelPackage.html

        :param model_package_name: - Identifier for the modelPackageName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag() - .ifResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__de2016b103077574b1cd95cb553ea47fb8b2bcc8a42298e9bd1c78c3786fcde8)
            check_type(argname="argument model_package_name", value=model_package_name, expected_type=type_hints["model_package_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Sagemaker", jsii.invoke(self, "onModelPackage", [model_package_name, account, region, partition]))

    @jsii.member(jsii_name="onModelPackageGroup")
    def on_model_package_group(
        self,
        model_package_group_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Sagemaker":
        '''(experimental) Adds a resource of type model-package-group to the statement.

        https://docs.aws.amazon.com/sagemaker/latest/dg/model-registry-model-group.html

        :param model_package_group_name: - Identifier for the modelPackageGroupName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag() - .ifResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e0a2f7f86a89fe8c60cd09d8abeaaebab0b97208a9a6278cf8c389dd9032acfa)
            check_type(argname="argument model_package_group_name", value=model_package_group_name, expected_type=type_hints["model_package_group_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Sagemaker", jsii.invoke(self, "onModelPackageGroup", [model_package_group_name, account, region, partition]))

    @jsii.member(jsii_name="onModelQualityJobDefinition")
    def on_model_quality_job_definition(
        self,
        model_quality_job_definition_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Sagemaker":
        '''(experimental) Adds a resource of type model-quality-job-definition to the statement.

        https://docs.aws.amazon.com/sagemaker/latest/dg/model-monitor-model-quality.html

        :param model_quality_job_definition_name: - Identifier for the modelQualityJobDefinitionName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag() - .ifResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b3632ca3d02f7909d3a81aa5600b49233f186e7d710e1a50117924b705a18ee1)
            check_type(argname="argument model_quality_job_definition_name", value=model_quality_job_definition_name, expected_type=type_hints["model_quality_job_definition_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Sagemaker", jsii.invoke(self, "onModelQualityJobDefinition", [model_quality_job_definition_name, account, region, partition]))

    @jsii.member(jsii_name="onMonitoringSchedule")
    def on_monitoring_schedule(
        self,
        monitoring_schedule_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Sagemaker":
        '''(experimental) Adds a resource of type monitoring-schedule to the statement.

        https://docs.aws.amazon.com/sagemaker/latest/dg/model-monitor-scheduling.html

        :param monitoring_schedule_name: - Identifier for the monitoringScheduleName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag() - .ifResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e943bed4a854253997875ad6f9dbf45abc06a1b6ce3477e3984947b71fc6f1b3)
            check_type(argname="argument monitoring_schedule_name", value=monitoring_schedule_name, expected_type=type_hints["monitoring_schedule_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Sagemaker", jsii.invoke(self, "onMonitoringSchedule", [monitoring_schedule_name, account, region, partition]))

    @jsii.member(jsii_name="onMonitoringScheduleAlert")
    def on_monitoring_schedule_alert(
        self,
        monitoring_schedule_name: builtins.str,
        monitoring_schedule_alert_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Sagemaker":
        '''(experimental) Adds a resource of type monitoring-schedule-alert to the statement.

        https://docs.aws.amazon.com/sagemaker/latest/dg/model-monitor-scheduling.html

        :param monitoring_schedule_name: - Identifier for the monitoringScheduleName.
        :param monitoring_schedule_alert_name: - Identifier for the monitoringScheduleAlertName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__aa34d57f41a927eaa92c58e19aefbf2f4ac13d9006958391b896e2bc1f31fcf9)
            check_type(argname="argument monitoring_schedule_name", value=monitoring_schedule_name, expected_type=type_hints["monitoring_schedule_name"])
            check_type(argname="argument monitoring_schedule_alert_name", value=monitoring_schedule_alert_name, expected_type=type_hints["monitoring_schedule_alert_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Sagemaker", jsii.invoke(self, "onMonitoringScheduleAlert", [monitoring_schedule_name, monitoring_schedule_alert_name, account, region, partition]))

    @jsii.member(jsii_name="onNotebookInstance")
    def on_notebook_instance(
        self,
        notebook_instance_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Sagemaker":
        '''(experimental) Adds a resource of type notebook-instance to the statement.

        https://docs.aws.amazon.com/sagemaker/latest/dg/nbi.html

        :param notebook_instance_name: - Identifier for the notebookInstanceName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag() - .ifResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ec69bda11cda913062b108d33dc55d49e1f76ae1dd487b397123a740514f615a)
            check_type(argname="argument notebook_instance_name", value=notebook_instance_name, expected_type=type_hints["notebook_instance_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Sagemaker", jsii.invoke(self, "onNotebookInstance", [notebook_instance_name, account, region, partition]))

    @jsii.member(jsii_name="onNotebookInstanceLifecycleConfig")
    def on_notebook_instance_lifecycle_config(
        self,
        notebook_instance_lifecycle_config_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Sagemaker":
        '''(experimental) Adds a resource of type notebook-instance-lifecycle-config to the statement.

        https://docs.aws.amazon.com/sagemaker/latest/dg/notebook-lifecycle-config.html

        :param notebook_instance_lifecycle_config_name: - Identifier for the notebookInstanceLifecycleConfigName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__95c194612c1327c4ecdcb4c1f164ca6d955a7ac6e71b7e8f75bdbff6ce1954dd)
            check_type(argname="argument notebook_instance_lifecycle_config_name", value=notebook_instance_lifecycle_config_name, expected_type=type_hints["notebook_instance_lifecycle_config_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Sagemaker", jsii.invoke(self, "onNotebookInstanceLifecycleConfig", [notebook_instance_lifecycle_config_name, account, region, partition]))

    @jsii.member(jsii_name="onPipeline")
    def on_pipeline(
        self,
        pipeline_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Sagemaker":
        '''(experimental) Adds a resource of type pipeline to the statement.

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_Pipeline.html

        :param pipeline_name: - Identifier for the pipelineName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag() - .ifResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b2487df702567b5f0e8aacf082827fff2e8024c65265e707f02b3f45ea98d8ee)
            check_type(argname="argument pipeline_name", value=pipeline_name, expected_type=type_hints["pipeline_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Sagemaker", jsii.invoke(self, "onPipeline", [pipeline_name, account, region, partition]))

    @jsii.member(jsii_name="onPipelineExecution")
    def on_pipeline_execution(
        self,
        pipeline_name: builtins.str,
        random_string: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Sagemaker":
        '''(experimental) Adds a resource of type pipeline-execution to the statement.

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_PipelineExecution.html

        :param pipeline_name: - Identifier for the pipelineName.
        :param random_string: - Identifier for the randomString.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c7e3169aa68238b33011a64a56deba8c9233c34a39ccc6fbe587167acaf410a5)
            check_type(argname="argument pipeline_name", value=pipeline_name, expected_type=type_hints["pipeline_name"])
            check_type(argname="argument random_string", value=random_string, expected_type=type_hints["random_string"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Sagemaker", jsii.invoke(self, "onPipelineExecution", [pipeline_name, random_string, account, region, partition]))

    @jsii.member(jsii_name="onProcessingJob")
    def on_processing_job(
        self,
        processing_job_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Sagemaker":
        '''(experimental) Adds a resource of type processing-job to the statement.

        https://docs.aws.amazon.com/sagemaker/latest/dg/processing-job.html

        :param processing_job_name: - Identifier for the processingJobName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag() - .ifResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__60ee48f3e3045cf4525620cc68ca7e4184a595efc7f17bc5309a1a45931ec12e)
            check_type(argname="argument processing_job_name", value=processing_job_name, expected_type=type_hints["processing_job_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Sagemaker", jsii.invoke(self, "onProcessingJob", [processing_job_name, account, region, partition]))

    @jsii.member(jsii_name="onProject")
    def on_project(
        self,
        project_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Sagemaker":
        '''(experimental) Adds a resource of type project to the statement.

        https://docs.aws.amazon.com/sagemaker/latest/dg/sagemaker-projects-whatis.html

        :param project_name: - Identifier for the projectName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag() - .ifResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__adbedaf36894c033414ad1b2d4c1a45ce68e75f22b2e45fc785b5b0080a13265)
            check_type(argname="argument project_name", value=project_name, expected_type=type_hints["project_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Sagemaker", jsii.invoke(self, "onProject", [project_name, account, region, partition]))

    @jsii.member(jsii_name="onSharedModel")
    def on_shared_model(
        self,
        shared_model_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Sagemaker":
        '''(experimental) Adds a resource of type shared-model to the statement.

        https://docs.aws.amazon.com/sagemaker/latest/dg/canvas-collaborate-permissions.html

        :param shared_model_id: - Identifier for the sharedModelId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f25f0fc2f890c78bbaf438ba48f178bc04b6a80360579b1f74d60161eaa356c6)
            check_type(argname="argument shared_model_id", value=shared_model_id, expected_type=type_hints["shared_model_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Sagemaker", jsii.invoke(self, "onSharedModel", [shared_model_id, account, region, partition]))

    @jsii.member(jsii_name="onSharedModelEvent")
    def on_shared_model_event(
        self,
        event_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Sagemaker":
        '''(experimental) Adds a resource of type shared-model-event to the statement.

        https://docs.aws.amazon.com/sagemaker/latest/dg/canvas-collaborate-permissions.html

        :param event_id: - Identifier for the eventId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bb608fda52499da50f6a815b51fd439ec7cb44268ca420e4fb986f23b921172a)
            check_type(argname="argument event_id", value=event_id, expected_type=type_hints["event_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Sagemaker", jsii.invoke(self, "onSharedModelEvent", [event_id, account, region, partition]))

    @jsii.member(jsii_name="onSpace")
    def on_space(
        self,
        domain_id: builtins.str,
        space_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Sagemaker":
        '''(experimental) Adds a resource of type space to the statement.

        https://docs.aws.amazon.com/sagemaker/latest/dg/studio-entity-status.html

        :param domain_id: - Identifier for the domainId.
        :param space_name: - Identifier for the spaceName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag() - .ifResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__84d2273273fac3b64a0dd9d52ebe4a8cc2b33869323e927a35489fa72c273f16)
            check_type(argname="argument domain_id", value=domain_id, expected_type=type_hints["domain_id"])
            check_type(argname="argument space_name", value=space_name, expected_type=type_hints["space_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Sagemaker", jsii.invoke(self, "onSpace", [domain_id, space_name, account, region, partition]))

    @jsii.member(jsii_name="onStudioLifecycleConfig")
    def on_studio_lifecycle_config(
        self,
        studio_lifecycle_config_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Sagemaker":
        '''(experimental) Adds a resource of type studio-lifecycle-config to the statement.

        https://docs.aws.amazon.com/sagemaker/latest/dg/studio-lcc.html

        :param studio_lifecycle_config_name: - Identifier for the studioLifecycleConfigName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag() - .ifResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__095e42117b98848739706263dbd6cb2f2fd80355d575e210f835f0498162dc62)
            check_type(argname="argument studio_lifecycle_config_name", value=studio_lifecycle_config_name, expected_type=type_hints["studio_lifecycle_config_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Sagemaker", jsii.invoke(self, "onStudioLifecycleConfig", [studio_lifecycle_config_name, account, region, partition]))

    @jsii.member(jsii_name="onTrainingJob")
    def on_training_job(
        self,
        training_job_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Sagemaker":
        '''(experimental) Adds a resource of type training-job to the statement.

        https://docs.aws.amazon.com/sagemaker/latest/dg/how-it-works-training.html

        :param training_job_name: - Identifier for the trainingJobName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag() - .ifResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e26da0fb41851559f474add901a5f91a9763033817813f080d2184cc0577dc52)
            check_type(argname="argument training_job_name", value=training_job_name, expected_type=type_hints["training_job_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Sagemaker", jsii.invoke(self, "onTrainingJob", [training_job_name, account, region, partition]))

    @jsii.member(jsii_name="onTransformJob")
    def on_transform_job(
        self,
        transform_job_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Sagemaker":
        '''(experimental) Adds a resource of type transform-job to the statement.

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_TransformJob.html.html

        :param transform_job_name: - Identifier for the transformJobName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag() - .ifResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__13022b85510d2c8884103a1f086398a6d3ab1e5564be61466475f840f1d5a592)
            check_type(argname="argument transform_job_name", value=transform_job_name, expected_type=type_hints["transform_job_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Sagemaker", jsii.invoke(self, "onTransformJob", [transform_job_name, account, region, partition]))

    @jsii.member(jsii_name="onUserProfile")
    def on_user_profile(
        self,
        domain_id: builtins.str,
        user_profile_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Sagemaker":
        '''(experimental) Adds a resource of type user-profile to the statement.

        https://docs.aws.amazon.com/sagemaker/latest/dg/studio-entity-status.html

        :param domain_id: - Identifier for the domainId.
        :param user_profile_name: - Identifier for the userProfileName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag() - .ifResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d6edd0de7b5d4d7c3f31dbba3d9f5ec660873a1b09dc2c0c478442fca135df6b)
            check_type(argname="argument domain_id", value=domain_id, expected_type=type_hints["domain_id"])
            check_type(argname="argument user_profile_name", value=user_profile_name, expected_type=type_hints["user_profile_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Sagemaker", jsii.invoke(self, "onUserProfile", [domain_id, user_profile_name, account, region, partition]))

    @jsii.member(jsii_name="onWorkforce")
    def on_workforce(
        self,
        workforce_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Sagemaker":
        '''(experimental) Adds a resource of type workforce to the statement.

        https://docs.aws.amazon.com/sagemaker/latest/dg/sms-workforce-management.html

        :param workforce_name: - Identifier for the workforceName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag() - .ifResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f492a4730007908193f98bae0fff97931a1e44ba475d7f1e8ea19e83da3ce7c0)
            check_type(argname="argument workforce_name", value=workforce_name, expected_type=type_hints["workforce_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Sagemaker", jsii.invoke(self, "onWorkforce", [workforce_name, account, region, partition]))

    @jsii.member(jsii_name="onWorkteam")
    def on_workteam(
        self,
        workteam_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Sagemaker":
        '''(experimental) Adds a resource of type workteam to the statement.

        https://docs.aws.amazon.com/sagemaker/latest/dg/sms-workforce-management.html

        :param workteam_name: - Identifier for the workteamName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag() - .ifResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fa8c5fccb9a6bc228438083cbaa8964107aba597e81a8f79c4ca00dc2689947d)
            check_type(argname="argument workteam_name", value=workteam_name, expected_type=type_hints["workteam_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Sagemaker", jsii.invoke(self, "onWorkteam", [workteam_name, account, region, partition]))

    @jsii.member(jsii_name="toAddAssociation")
    def to_add_association(self) -> "Sagemaker":
        '''(experimental) Grants permission to associate a lineage entity (artifact, context, action, experiment, experiment-trial-component) to each other.

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_AddAssociation.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toAddAssociation", []))

    @jsii.member(jsii_name="toAddTags")
    def to_add_tags(self) -> "Sagemaker":
        '''(experimental) Grants permission to add or overwrite one or more tags for the specified Amazon SageMaker resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_AddTags.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toAddTags", []))

    @jsii.member(jsii_name="toAssociateTrialComponent")
    def to_associate_trial_component(self) -> "Sagemaker":
        '''(experimental) Grants permission to associate a trial component with a trial.

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_AssociateTrialComponent.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toAssociateTrialComponent", []))

    @jsii.member(jsii_name="toBatchDescribeModelPackage")
    def to_batch_describe_model_package(self) -> "Sagemaker":
        '''(experimental) Grants permission to describe one or more ModelPackages.

        Access Level: Read

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_BatchDescribeModelPackage.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toBatchDescribeModelPackage", []))

    @jsii.member(jsii_name="toBatchGetMetrics")
    def to_batch_get_metrics(self) -> "Sagemaker":
        '''(experimental) Grants permission to retrieve metrics associated with SageMaker Resources such as Training Jobs or Trial Components.

        This API is not publicly exposed at this point, however admins can control this action

        Access Level: Read

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toBatchGetMetrics", []))

    @jsii.member(jsii_name="toBatchGetRecord")
    def to_batch_get_record(self) -> "Sagemaker":
        '''(experimental) Grants permission to get a batch of records from one or more feature groups.

        Access Level: Read

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_feature_store_BatchGetRecord.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toBatchGetRecord", []))

    @jsii.member(jsii_name="toBatchPutMetrics")
    def to_batch_put_metrics(self) -> "Sagemaker":
        '''(experimental) Grants permission to publish metrics associated with a SageMaker Resource such as a Training Job or Trial Component.

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toBatchPutMetrics", []))

    @jsii.member(jsii_name="toCreateAction")
    def to_create_action(self) -> "Sagemaker":
        '''(experimental) Grants permission to create an action.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - sagemaker:AddTags

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_CreateAction.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toCreateAction", []))

    @jsii.member(jsii_name="toCreateAlgorithm")
    def to_create_algorithm(self) -> "Sagemaker":
        '''(experimental) Grants permission to create an algorithm.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - sagemaker:AddTags

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_CreateAlgorithm.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toCreateAlgorithm", []))

    @jsii.member(jsii_name="toCreateApp")
    def to_create_app(self) -> "Sagemaker":
        '''(experimental) Grants permission to create an App for a SageMaker UserProfile or Space.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifInstanceTypes()
        - .ifImageArns()
        - .ifImageVersionArns()

        Dependent actions:

        - sagemaker:AddTags

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_CreateApp.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toCreateApp", []))

    @jsii.member(jsii_name="toCreateAppImageConfig")
    def to_create_app_image_config(self) -> "Sagemaker":
        '''(experimental) Grants permission to create an AppImageConfig.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - sagemaker:AddTags

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_CreateAppImageConfig.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toCreateAppImageConfig", []))

    @jsii.member(jsii_name="toCreateArtifact")
    def to_create_artifact(self) -> "Sagemaker":
        '''(experimental) Grants permission to create an artifact.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - sagemaker:AddTags

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_CreateArtifact.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toCreateArtifact", []))

    @jsii.member(jsii_name="toCreateAutoMLJob")
    def to_create_auto_ml_job(self) -> "Sagemaker":
        '''(experimental) Grants permission to create an AutoML job.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifInterContainerTrafficEncryption()
        - .ifOutputKmsKey()
        - .ifVolumeKmsKey()
        - .ifVpcSecurityGroupIds()
        - .ifVpcSubnets()

        Dependent actions:

        - iam:PassRole
        - sagemaker:AddTags

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_CreateAutoMLJob.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toCreateAutoMLJob", []))

    @jsii.member(jsii_name="toCreateCodeRepository")
    def to_create_code_repository(self) -> "Sagemaker":
        '''(experimental) Grants permission to create a CodeRepository.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - sagemaker:AddTags

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_CreateCodeRepository.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toCreateCodeRepository", []))

    @jsii.member(jsii_name="toCreateCompilationJob")
    def to_create_compilation_job(self) -> "Sagemaker":
        '''(experimental) Grants permission to create a compilation job.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - iam:PassRole
        - sagemaker:AddTags

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_CreateCompilationJob.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toCreateCompilationJob", []))

    @jsii.member(jsii_name="toCreateContext")
    def to_create_context(self) -> "Sagemaker":
        '''(experimental) Grants permission to create a context.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - sagemaker:AddTags

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_CreateContext.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toCreateContext", []))

    @jsii.member(jsii_name="toCreateDataQualityJobDefinition")
    def to_create_data_quality_job_definition(self) -> "Sagemaker":
        '''(experimental) Grants permission to create a data quality job definition.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifInstanceTypes()
        - .ifInterContainerTrafficEncryption()
        - .ifMaxRuntimeInSeconds()
        - .ifNetworkIsolation()
        - .ifOutputKmsKey()
        - .ifVolumeKmsKey()
        - .ifVpcSecurityGroupIds()
        - .ifVpcSubnets()

        Dependent actions:

        - iam:PassRole
        - sagemaker:AddTags

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_CreateDataQualityJobDefinition.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toCreateDataQualityJobDefinition", []))

    @jsii.member(jsii_name="toCreateDeviceFleet")
    def to_create_device_fleet(self) -> "Sagemaker":
        '''(experimental) Grants permission to create a device fleet.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - iam:PassRole
        - sagemaker:AddTags

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_CreateDeviceFleet.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toCreateDeviceFleet", []))

    @jsii.member(jsii_name="toCreateDomain")
    def to_create_domain(self) -> "Sagemaker":
        '''(experimental) Grants permission to create a Domain for SageMaker Studio.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifAppNetworkAccessType()
        - .ifInstanceTypes()
        - .ifVpcSecurityGroupIds()
        - .ifVpcSubnets()
        - .ifDomainSharingOutputKmsKey()
        - .ifVolumeKmsKey()
        - .ifImageArns()
        - .ifImageVersionArns()

        Dependent actions:

        - iam:CreateServiceLinkedRole
        - iam:PassRole
        - sagemaker:AddTags

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_CreateDomain.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toCreateDomain", []))

    @jsii.member(jsii_name="toCreateEdgeDeploymentPlan")
    def to_create_edge_deployment_plan(self) -> "Sagemaker":
        '''(experimental) Grants permission to create an edge deployment plan.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - iam:PassRole
        - sagemaker:AddTags

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_CreateEdgeDeploymentPlan.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toCreateEdgeDeploymentPlan", []))

    @jsii.member(jsii_name="toCreateEdgeDeploymentStage")
    def to_create_edge_deployment_stage(self) -> "Sagemaker":
        '''(experimental) Grants permission to create an edge deployment stage.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - iam:PassRole
        - sagemaker:AddTags

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_CreateEdgeDeploymentStage.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toCreateEdgeDeploymentStage", []))

    @jsii.member(jsii_name="toCreateEdgePackagingJob")
    def to_create_edge_packaging_job(self) -> "Sagemaker":
        '''(experimental) Grants permission to create an edge packaging job.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - iam:PassRole
        - sagemaker:AddTags

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_CreateEdgePackagingJob.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toCreateEdgePackagingJob", []))

    @jsii.member(jsii_name="toCreateEndpoint")
    def to_create_endpoint(self) -> "Sagemaker":
        '''(experimental) Grants permission to create an endpoint using the endpoint configuration specified in the request.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - sagemaker:AddTags

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_CreateEndpoint.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toCreateEndpoint", []))

    @jsii.member(jsii_name="toCreateEndpointConfig")
    def to_create_endpoint_config(self) -> "Sagemaker":
        '''(experimental) Grants permission to create an endpoint configuration that can be deployed using Amazon SageMaker hosting services.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifAcceleratorTypes()
        - .ifInstanceTypes()
        - .ifModelArn()
        - .ifVolumeKmsKey()
        - .ifServerlessMaxConcurrency()
        - .ifServerlessMemorySize()

        Dependent actions:

        - sagemaker:AddTags

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_CreateEndpointConfig.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toCreateEndpointConfig", []))

    @jsii.member(jsii_name="toCreateExperiment")
    def to_create_experiment(self) -> "Sagemaker":
        '''(experimental) Grants permission to create an experiment.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - sagemaker:AddTags

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_CreateExperiment.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toCreateExperiment", []))

    @jsii.member(jsii_name="toCreateFeatureGroup")
    def to_create_feature_group(self) -> "Sagemaker":
        '''(experimental) Grants permission to create a feature group.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifFeatureGroupOnlineStoreKmsKey()
        - .ifFeatureGroupOfflineStoreKmsKey()
        - .ifFeatureGroupOfflineStoreS3Uri()

        Dependent actions:

        - iam:PassRole
        - sagemaker:AddTags

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_CreateFeatureGroup.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toCreateFeatureGroup", []))

    @jsii.member(jsii_name="toCreateFlowDefinition")
    def to_create_flow_definition(self) -> "Sagemaker":
        '''(experimental) Grants permission to create a flow definition, which defines settings for a human workflow.

        Access Level: Write

        Possible conditions:

        - .ifWorkteamArn()
        - .ifWorkteamType()
        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - iam:PassRole
        - sagemaker:AddTags

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_CreateFlowDefinition.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toCreateFlowDefinition", []))

    @jsii.member(jsii_name="toCreateHub")
    def to_create_hub(self) -> "Sagemaker":
        '''(experimental) Grants permission to create a hub.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - sagemaker:AddTags

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_CreateHub.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toCreateHub", []))

    @jsii.member(jsii_name="toCreateHumanTaskUi")
    def to_create_human_task_ui(self) -> "Sagemaker":
        '''(experimental) Grants permission to define the settings you will use for the human review workflow user interface.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - sagemaker:AddTags

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_CreateHumanTaskUi.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toCreateHumanTaskUi", []))

    @jsii.member(jsii_name="toCreateHyperParameterTuningJob")
    def to_create_hyper_parameter_tuning_job(self) -> "Sagemaker":
        '''(experimental) Grants permission to create a hyper parameter tuning job that can be deployed using Amazon SageMaker.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifFileSystemAccessMode()
        - .ifFileSystemDirectoryPath()
        - .ifFileSystemId()
        - .ifFileSystemType()
        - .ifInstanceTypes()
        - .ifInterContainerTrafficEncryption()
        - .ifMaxRuntimeInSeconds()
        - .ifNetworkIsolation()
        - .ifOutputKmsKey()
        - .ifVolumeKmsKey()
        - .ifVpcSecurityGroupIds()
        - .ifVpcSubnets()

        Dependent actions:

        - iam:PassRole
        - sagemaker:AddTags

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_CreateHyperParameterTuningJob.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toCreateHyperParameterTuningJob", []))

    @jsii.member(jsii_name="toCreateImage")
    def to_create_image(self) -> "Sagemaker":
        '''(experimental) Grants permission to create a SageMaker Image.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - iam:PassRole
        - sagemaker:AddTags

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_CreateImage.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toCreateImage", []))

    @jsii.member(jsii_name="toCreateImageVersion")
    def to_create_image_version(self) -> "Sagemaker":
        '''(experimental) Grants permission to create a SageMaker ImageVersion.

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_CreateImageVersion.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toCreateImageVersion", []))

    @jsii.member(jsii_name="toCreateInferenceExperiment")
    def to_create_inference_experiment(self) -> "Sagemaker":
        '''(experimental) Grants permission to create an inference experiment.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - iam:PassRole
        - sagemaker:AddTags

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_CreateInferenceExperiment.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toCreateInferenceExperiment", []))

    @jsii.member(jsii_name="toCreateInferenceRecommendationsJob")
    def to_create_inference_recommendations_job(self) -> "Sagemaker":
        '''(experimental) Grants permission to create an inference recommendations job.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - iam:PassRole
        - sagemaker:AddTags

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_CreateInferenceRecommendationsJob.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toCreateInferenceRecommendationsJob", []))

    @jsii.member(jsii_name="toCreateLabelingJob")
    def to_create_labeling_job(self) -> "Sagemaker":
        '''(experimental) Grants permission to start a labeling job.

        A labeling job takes unlabeled data in and produces labeled data as output, which can be used for training SageMaker models

        Access Level: Write

        Possible conditions:

        - .ifWorkteamArn()
        - .ifWorkteamType()
        - .ifVolumeKmsKey()
        - .ifOutputKmsKey()
        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - iam:PassRole
        - sagemaker:AddTags

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_CreateLabelingJob.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toCreateLabelingJob", []))

    @jsii.member(jsii_name="toCreateLineageGroupPolicy")
    def to_create_lineage_group_policy(self) -> "Sagemaker":
        '''(experimental) Grants permission to create a lineage group policy.

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/Welcome.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toCreateLineageGroupPolicy", []))

    @jsii.member(jsii_name="toCreateModel")
    def to_create_model(self) -> "Sagemaker":
        '''(experimental) Grants permission to create a model in Amazon SageMaker.

        In the request, you specify a name for the model and describe one or more containers

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifNetworkIsolation()
        - .ifVpcSecurityGroupIds()
        - .ifVpcSubnets()

        Dependent actions:

        - iam:PassRole
        - sagemaker:AddTags

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_CreateModel.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toCreateModel", []))

    @jsii.member(jsii_name="toCreateModelBiasJobDefinition")
    def to_create_model_bias_job_definition(self) -> "Sagemaker":
        '''(experimental) Grants permission to create a model bias job definition.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifInstanceTypes()
        - .ifInterContainerTrafficEncryption()
        - .ifMaxRuntimeInSeconds()
        - .ifNetworkIsolation()
        - .ifOutputKmsKey()
        - .ifVolumeKmsKey()
        - .ifVpcSecurityGroupIds()
        - .ifVpcSubnets()

        Dependent actions:

        - iam:PassRole
        - sagemaker:AddTags

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_CreateModelBiasJobDefinition.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toCreateModelBiasJobDefinition", []))

    @jsii.member(jsii_name="toCreateModelCard")
    def to_create_model_card(self) -> "Sagemaker":
        '''(experimental) Grants permission to create a model card.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - sagemaker:AddTags

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_CreateModelCard.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toCreateModelCard", []))

    @jsii.member(jsii_name="toCreateModelCardExportJob")
    def to_create_model_card_export_job(self) -> "Sagemaker":
        '''(experimental) Grants permission to create an export job for a model card.

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_CreateModelCardExportJob.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toCreateModelCardExportJob", []))

    @jsii.member(jsii_name="toCreateModelExplainabilityJobDefinition")
    def to_create_model_explainability_job_definition(self) -> "Sagemaker":
        '''(experimental) Grants permission to create a model explainability job definition.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifInstanceTypes()
        - .ifInterContainerTrafficEncryption()
        - .ifMaxRuntimeInSeconds()
        - .ifNetworkIsolation()
        - .ifOutputKmsKey()
        - .ifVolumeKmsKey()
        - .ifVpcSecurityGroupIds()
        - .ifVpcSubnets()

        Dependent actions:

        - iam:PassRole
        - sagemaker:AddTags

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_CreateModelExplainabilityJobDefinition.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toCreateModelExplainabilityJobDefinition", []))

    @jsii.member(jsii_name="toCreateModelPackage")
    def to_create_model_package(self) -> "Sagemaker":
        '''(experimental) Grants permission to create a ModelPackage.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifModelApprovalStatus()
        - .ifCustomerMetadataProperties()

        Dependent actions:

        - sagemaker:AddTags

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_CreateModelPackage.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toCreateModelPackage", []))

    @jsii.member(jsii_name="toCreateModelPackageGroup")
    def to_create_model_package_group(self) -> "Sagemaker":
        '''(experimental) Grants permission to create a ModelPackageGroup.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - sagemaker:AddTags

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_CreateModelPackageGroup.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toCreateModelPackageGroup", []))

    @jsii.member(jsii_name="toCreateModelQualityJobDefinition")
    def to_create_model_quality_job_definition(self) -> "Sagemaker":
        '''(experimental) Grants permission to create a model quality job definition.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifInstanceTypes()
        - .ifInterContainerTrafficEncryption()
        - .ifMaxRuntimeInSeconds()
        - .ifNetworkIsolation()
        - .ifOutputKmsKey()
        - .ifVolumeKmsKey()
        - .ifVpcSecurityGroupIds()
        - .ifVpcSubnets()

        Dependent actions:

        - iam:PassRole
        - sagemaker:AddTags

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_CreateModelQualityJobDefinition.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toCreateModelQualityJobDefinition", []))

    @jsii.member(jsii_name="toCreateMonitoringSchedule")
    def to_create_monitoring_schedule(self) -> "Sagemaker":
        '''(experimental) Grants permission to create a monitoring schedule.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifInstanceTypes()
        - .ifInterContainerTrafficEncryption()
        - .ifMaxRuntimeInSeconds()
        - .ifNetworkIsolation()
        - .ifOutputKmsKey()
        - .ifVolumeKmsKey()
        - .ifVpcSecurityGroupIds()
        - .ifVpcSubnets()

        Dependent actions:

        - iam:PassRole
        - sagemaker:AddTags

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_CreateMonitoringSchedule.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toCreateMonitoringSchedule", []))

    @jsii.member(jsii_name="toCreateNotebookInstance")
    def to_create_notebook_instance(self) -> "Sagemaker":
        '''(experimental) Grants permission to create an Amazon SageMaker notebook instance.

        A notebook instance is an Amazon EC2 instance running on a Jupyter Notebook

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifAcceleratorTypes()
        - .ifDirectInternetAccess()
        - .ifInstanceTypes()
        - .ifMinimumInstanceMetadataServiceVersion()
        - .ifRootAccess()
        - .ifVolumeKmsKey()
        - .ifVpcSecurityGroupIds()
        - .ifVpcSubnets()

        Dependent actions:

        - iam:PassRole
        - sagemaker:AddTags

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_CreateNotebookInstance.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toCreateNotebookInstance", []))

    @jsii.member(jsii_name="toCreateNotebookInstanceLifecycleConfig")
    def to_create_notebook_instance_lifecycle_config(self) -> "Sagemaker":
        '''(experimental) Grants permission to create a notebook instance lifecycle configuration that can be deployed using Amazon SageMaker.

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_CreateNotebookInstanceLifecycleConfig.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toCreateNotebookInstanceLifecycleConfig", []))

    @jsii.member(jsii_name="toCreatePipeline")
    def to_create_pipeline(self) -> "Sagemaker":
        '''(experimental) Grants permission to create a pipeline.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - iam:PassRole
        - sagemaker:AddTags

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_CreatePipeline.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toCreatePipeline", []))

    @jsii.member(jsii_name="toCreatePresignedDomainUrl")
    def to_create_presigned_domain_url(self) -> "Sagemaker":
        '''(experimental) Grants permission to return a URL that you can use from your browser to connect to the Domain as a specified UserProfile when AuthMode is 'IAM'.

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_CreatePresignedDomainUrl.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toCreatePresignedDomainUrl", []))

    @jsii.member(jsii_name="toCreatePresignedNotebookInstanceUrl")
    def to_create_presigned_notebook_instance_url(self) -> "Sagemaker":
        '''(experimental) Grants permission to create a URL that you can use from your browser to connect to the Notebook Instance.

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_CreatePresignedNotebookInstanceUrl.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toCreatePresignedNotebookInstanceUrl", []))

    @jsii.member(jsii_name="toCreateProcessingJob")
    def to_create_processing_job(self) -> "Sagemaker":
        '''(experimental) Grants permission to start a processing job.

        After processing completes, Amazon SageMaker saves the resulting artifacts and other optional output to an Amazon S3 location that you specify

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifInstanceTypes()
        - .ifMaxRuntimeInSeconds()
        - .ifNetworkIsolation()
        - .ifOutputKmsKey()
        - .ifVolumeKmsKey()
        - .ifVpcSecurityGroupIds()
        - .ifVpcSubnets()
        - .ifInterContainerTrafficEncryption()

        Dependent actions:

        - iam:PassRole
        - sagemaker:AddTags

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_CreateProcessingJob.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toCreateProcessingJob", []))

    @jsii.member(jsii_name="toCreateProject")
    def to_create_project(self) -> "Sagemaker":
        '''(experimental) Grants permission to create a Project.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - sagemaker:AddTags

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_CreateProject.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toCreateProject", []))

    @jsii.member(jsii_name="toCreateSharedModel")
    def to_create_shared_model(self) -> "Sagemaker":
        '''(experimental) Grants permission to create a shared model in a SageMaker Studio application.

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/dg/canvas-collaborate-permissions.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toCreateSharedModel", []))

    @jsii.member(jsii_name="toCreateSpace")
    def to_create_space(self) -> "Sagemaker":
        '''(experimental) Grants permission to create a Space for a SageMaker Domain.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifInstanceTypes()
        - .ifImageArns()
        - .ifImageVersionArns()

        Dependent actions:

        - sagemaker:AddTags

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_CreateSpace.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toCreateSpace", []))

    @jsii.member(jsii_name="toCreateStudioLifecycleConfig")
    def to_create_studio_lifecycle_config(self) -> "Sagemaker":
        '''(experimental) Grants permission to create a Studio Lifecycle Configuration that can be deployed using Amazon SageMaker.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - sagemaker:AddTags

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_CreateStudioLifecycleConfig.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toCreateStudioLifecycleConfig", []))

    @jsii.member(jsii_name="toCreateTrainingJob")
    def to_create_training_job(self) -> "Sagemaker":
        '''(experimental) Grants permission to start a model training job.

        After training completes, Amazon SageMaker saves the resulting model artifacts and other optional output to an Amazon S3 location that you specify

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifFileSystemAccessMode()
        - .ifFileSystemDirectoryPath()
        - .ifFileSystemId()
        - .ifFileSystemType()
        - .ifInstanceTypes()
        - .ifInterContainerTrafficEncryption()
        - .ifMaxRuntimeInSeconds()
        - .ifNetworkIsolation()
        - .ifOutputKmsKey()
        - .ifVolumeKmsKey()
        - .ifVpcSecurityGroupIds()
        - .ifVpcSubnets()
        - .ifKeepAlivePeriod()

        Dependent actions:

        - iam:PassRole
        - sagemaker:AddTags

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_CreateTrainingJob.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toCreateTrainingJob", []))

    @jsii.member(jsii_name="toCreateTransformJob")
    def to_create_transform_job(self) -> "Sagemaker":
        '''(experimental) Grants permission to start a transform job.

        After the results are obtained, Amazon SageMaker saves them to an Amazon S3 location that you specify

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifInstanceTypes()
        - .ifModelArn()
        - .ifOutputKmsKey()
        - .ifVolumeKmsKey()

        Dependent actions:

        - sagemaker:AddTags

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_CreateTransformJob.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toCreateTransformJob", []))

    @jsii.member(jsii_name="toCreateTrial")
    def to_create_trial(self) -> "Sagemaker":
        '''(experimental) Grants permission to create a trial.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - sagemaker:AddTags

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_CreateTrial.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toCreateTrial", []))

    @jsii.member(jsii_name="toCreateTrialComponent")
    def to_create_trial_component(self) -> "Sagemaker":
        '''(experimental) Grants permission to create a trial component.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - sagemaker:AddTags

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_CreateTrialComponent.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toCreateTrialComponent", []))

    @jsii.member(jsii_name="toCreateUserProfile")
    def to_create_user_profile(self) -> "Sagemaker":
        '''(experimental) Grants permission to create a UserProfile for a SageMaker Domain.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifVpcSecurityGroupIds()
        - .ifInstanceTypes()
        - .ifDomainSharingOutputKmsKey()
        - .ifImageArns()
        - .ifImageVersionArns()

        Dependent actions:

        - iam:PassRole
        - sagemaker:AddTags

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_CreateUserProfile.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toCreateUserProfile", []))

    @jsii.member(jsii_name="toCreateWorkforce")
    def to_create_workforce(self) -> "Sagemaker":
        '''(experimental) Grants permission to create a workforce.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - sagemaker:AddTags

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_CreateWorkforce.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toCreateWorkforce", []))

    @jsii.member(jsii_name="toCreateWorkteam")
    def to_create_workteam(self) -> "Sagemaker":
        '''(experimental) Grants permission to create a workteam.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - sagemaker:AddTags

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_CreateWorkteam.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toCreateWorkteam", []))

    @jsii.member(jsii_name="toDeleteAction")
    def to_delete_action(self) -> "Sagemaker":
        '''(experimental) Grants permission to delete an action.

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_DeleteAction.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toDeleteAction", []))

    @jsii.member(jsii_name="toDeleteAlgorithm")
    def to_delete_algorithm(self) -> "Sagemaker":
        '''(experimental) Grants permission to delete an algorithm.

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_DeleteAlgorithm.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toDeleteAlgorithm", []))

    @jsii.member(jsii_name="toDeleteApp")
    def to_delete_app(self) -> "Sagemaker":
        '''(experimental) Grants permission to delete an App.

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_DeleteApp.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toDeleteApp", []))

    @jsii.member(jsii_name="toDeleteAppImageConfig")
    def to_delete_app_image_config(self) -> "Sagemaker":
        '''(experimental) Grants permission to delete an AppImageConfig.

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_DeleteAppImageConfig.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toDeleteAppImageConfig", []))

    @jsii.member(jsii_name="toDeleteArtifact")
    def to_delete_artifact(self) -> "Sagemaker":
        '''(experimental) Grants permission to delete an artifact.

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_DeleteArtifact.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toDeleteArtifact", []))

    @jsii.member(jsii_name="toDeleteAssociation")
    def to_delete_association(self) -> "Sagemaker":
        '''(experimental) Grants permission to delete the association from a lineage entity (artifact, context, action, experiment, experiment-trial-component) to another.

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_DeleteAssociation.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toDeleteAssociation", []))

    @jsii.member(jsii_name="toDeleteCodeRepository")
    def to_delete_code_repository(self) -> "Sagemaker":
        '''(experimental) Grants permission to delete a CodeRepository.

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_DeleteCodeRepository.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toDeleteCodeRepository", []))

    @jsii.member(jsii_name="toDeleteContext")
    def to_delete_context(self) -> "Sagemaker":
        '''(experimental) Grants permission to delete a context.

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_DeleteContext.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toDeleteContext", []))

    @jsii.member(jsii_name="toDeleteDataQualityJobDefinition")
    def to_delete_data_quality_job_definition(self) -> "Sagemaker":
        '''(experimental) Grants permission to delete the data quality job definition created using the CreateDataQualityJobDefinition API.

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_DeleteDataQualityJobDefinition.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toDeleteDataQualityJobDefinition", []))

    @jsii.member(jsii_name="toDeleteDeviceFleet")
    def to_delete_device_fleet(self) -> "Sagemaker":
        '''(experimental) Grants permission to delete a device fleet.

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_DeleteDeviceFleet.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toDeleteDeviceFleet", []))

    @jsii.member(jsii_name="toDeleteDomain")
    def to_delete_domain(self) -> "Sagemaker":
        '''(experimental) Grants permission to delete a Domain.

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_DeleteDomain.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toDeleteDomain", []))

    @jsii.member(jsii_name="toDeleteEdgeDeploymentPlan")
    def to_delete_edge_deployment_plan(self) -> "Sagemaker":
        '''(experimental) Grants permission to delete an edge deployment plan.

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_DeleteEdgeDeploymentPlan.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toDeleteEdgeDeploymentPlan", []))

    @jsii.member(jsii_name="toDeleteEdgeDeploymentStage")
    def to_delete_edge_deployment_stage(self) -> "Sagemaker":
        '''(experimental) Grants permission to delete an edge deployment stage.

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_DeleteEdgeDeploymentStage.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toDeleteEdgeDeploymentStage", []))

    @jsii.member(jsii_name="toDeleteEndpoint")
    def to_delete_endpoint(self) -> "Sagemaker":
        '''(experimental) Grants permission to delete an endpoint.

        Amazon SageMaker frees up all the resources that were deployed when the endpoint was created

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_DeleteEndpoint.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toDeleteEndpoint", []))

    @jsii.member(jsii_name="toDeleteEndpointConfig")
    def to_delete_endpoint_config(self) -> "Sagemaker":
        '''(experimental) Grants permission to delete the endpoint configuration created using the CreateEndpointConfig API.

        The DeleteEndpointConfig API deletes only the specified configuration. It does not delete any endpoints created using the configuration

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_DeleteEndpointConfig.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toDeleteEndpointConfig", []))

    @jsii.member(jsii_name="toDeleteExperiment")
    def to_delete_experiment(self) -> "Sagemaker":
        '''(experimental) Grants permission to delete an experiment.

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_DeleteExperiment.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toDeleteExperiment", []))

    @jsii.member(jsii_name="toDeleteFeatureGroup")
    def to_delete_feature_group(self) -> "Sagemaker":
        '''(experimental) Grants permission to delete a feature group.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_DeleteFeatureGroup.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toDeleteFeatureGroup", []))

    @jsii.member(jsii_name="toDeleteFlowDefinition")
    def to_delete_flow_definition(self) -> "Sagemaker":
        '''(experimental) Grants permission to delete the specified flow definition.

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_DeleteFlowDefinition.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toDeleteFlowDefinition", []))

    @jsii.member(jsii_name="toDeleteHub")
    def to_delete_hub(self) -> "Sagemaker":
        '''(experimental) Grants permission to delete hubs.

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_DeleteHub.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toDeleteHub", []))

    @jsii.member(jsii_name="toDeleteHubContent")
    def to_delete_hub_content(self) -> "Sagemaker":
        '''(experimental) Grants permission to delete hub content.

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_DeleteHubContent.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toDeleteHubContent", []))

    @jsii.member(jsii_name="toDeleteHumanLoop")
    def to_delete_human_loop(self) -> "Sagemaker":
        '''(experimental) Grants permission to delete a specified human loop.

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_DeleteHumanLoop.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toDeleteHumanLoop", []))

    @jsii.member(jsii_name="toDeleteHumanTaskUi")
    def to_delete_human_task_ui(self) -> "Sagemaker":
        '''(experimental) Grants permission to delete the specified human task user interface (worker task template).

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_DeleteHumanTaskUi.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toDeleteHumanTaskUi", []))

    @jsii.member(jsii_name="toDeleteImage")
    def to_delete_image(self) -> "Sagemaker":
        '''(experimental) Grants permission to delete a SageMaker Image.

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_DeleteImage.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toDeleteImage", []))

    @jsii.member(jsii_name="toDeleteImageVersion")
    def to_delete_image_version(self) -> "Sagemaker":
        '''(experimental) Grants permission to delete a SageMaker ImageVersion.

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_DeleteImageVersion.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toDeleteImageVersion", []))

    @jsii.member(jsii_name="toDeleteInferenceExperiment")
    def to_delete_inference_experiment(self) -> "Sagemaker":
        '''(experimental) Grants permission to delete an inference experiment.

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_DeleteInferenceExperiment.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toDeleteInferenceExperiment", []))

    @jsii.member(jsii_name="toDeleteLineageGroupPolicy")
    def to_delete_lineage_group_policy(self) -> "Sagemaker":
        '''(experimental) Grants permission to delete a lineage group policy.

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/Welcome.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toDeleteLineageGroupPolicy", []))

    @jsii.member(jsii_name="toDeleteModel")
    def to_delete_model(self) -> "Sagemaker":
        '''(experimental) Grants permission to delete a model created using the CreateModel API.

        The DeleteModel API deletes only the model entry in Amazon SageMaker that you created by calling the CreateModel API. It does not delete model artifacts, inference code, or the IAM role that you specified when creating the model

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_DeleteModel.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toDeleteModel", []))

    @jsii.member(jsii_name="toDeleteModelBiasJobDefinition")
    def to_delete_model_bias_job_definition(self) -> "Sagemaker":
        '''(experimental) Grants permission to delete the model bias job definition created using the CreateModelBiasJobDefinition API.

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_DeleteModelBiasJobDefinition.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toDeleteModelBiasJobDefinition", []))

    @jsii.member(jsii_name="toDeleteModelCard")
    def to_delete_model_card(self) -> "Sagemaker":
        '''(experimental) Grants permission to delete a model card.

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_DeleteModelCard.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toDeleteModelCard", []))

    @jsii.member(jsii_name="toDeleteModelExplainabilityJobDefinition")
    def to_delete_model_explainability_job_definition(self) -> "Sagemaker":
        '''(experimental) Grants permission to delete the model explainability job definition created using the CreateModelExplainabilityJobDefinition API.

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_DeleteModelExplainabilityJobDefinition.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toDeleteModelExplainabilityJobDefinition", []))

    @jsii.member(jsii_name="toDeleteModelPackage")
    def to_delete_model_package(self) -> "Sagemaker":
        '''(experimental) Grants permission to delete a ModelPackage.

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_DeleteModelPackage.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toDeleteModelPackage", []))

    @jsii.member(jsii_name="toDeleteModelPackageGroup")
    def to_delete_model_package_group(self) -> "Sagemaker":
        '''(experimental) Grants permission to delete a ModelPackageGroup.

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_DeleteModelPackageGroup.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toDeleteModelPackageGroup", []))

    @jsii.member(jsii_name="toDeleteModelPackageGroupPolicy")
    def to_delete_model_package_group_policy(self) -> "Sagemaker":
        '''(experimental) Grants permission to delete a ModelPackageGroup policy.

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_DeleteModelPackageGroupPolicy.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toDeleteModelPackageGroupPolicy", []))

    @jsii.member(jsii_name="toDeleteModelQualityJobDefinition")
    def to_delete_model_quality_job_definition(self) -> "Sagemaker":
        '''(experimental) Grants permission to delete the model quality job definition created using the CreateModelQualityJobDefinition API.

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_DeleteModelQualityJobDefinition.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toDeleteModelQualityJobDefinition", []))

    @jsii.member(jsii_name="toDeleteMonitoringSchedule")
    def to_delete_monitoring_schedule(self) -> "Sagemaker":
        '''(experimental) Grants permission to delete a monitoring schedule.

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_DeleteMonitoringSchedule.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toDeleteMonitoringSchedule", []))

    @jsii.member(jsii_name="toDeleteNotebookInstance")
    def to_delete_notebook_instance(self) -> "Sagemaker":
        '''(experimental) Grants permission to delete a Amazon SageMaker notebook instance.

        Before you can delete a notebook instance, you must call the StopNotebookInstance API

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_DeleteNotebookInstance.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toDeleteNotebookInstance", []))

    @jsii.member(jsii_name="toDeleteNotebookInstanceLifecycleConfig")
    def to_delete_notebook_instance_lifecycle_config(self) -> "Sagemaker":
        '''(experimental) Grants permission to delete a notebook instance lifecycle configuration.

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_DeleteNotebookInstanceLifecycleConfig.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toDeleteNotebookInstanceLifecycleConfig", []))

    @jsii.member(jsii_name="toDeletePipeline")
    def to_delete_pipeline(self) -> "Sagemaker":
        '''(experimental) Grants permission to delete a pipeline.

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_DeletePipeline.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toDeletePipeline", []))

    @jsii.member(jsii_name="toDeleteProject")
    def to_delete_project(self) -> "Sagemaker":
        '''(experimental) Grants permission to delete a project.

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_DeleteProject.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toDeleteProject", []))

    @jsii.member(jsii_name="toDeleteRecord")
    def to_delete_record(self) -> "Sagemaker":
        '''(experimental) Grants permission to delete a record from a feature group.

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_feature_store_DeleteRecord.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toDeleteRecord", []))

    @jsii.member(jsii_name="toDeleteSpace")
    def to_delete_space(self) -> "Sagemaker":
        '''(experimental) Grants permission to delete a Space.

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_DeleteSpace.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toDeleteSpace", []))

    @jsii.member(jsii_name="toDeleteStudioLifecycleConfig")
    def to_delete_studio_lifecycle_config(self) -> "Sagemaker":
        '''(experimental) Grants permission to delete a Studio Lifecycle Configuration.

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_DeleteStudioLifecycleConfig.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toDeleteStudioLifecycleConfig", []))

    @jsii.member(jsii_name="toDeleteTags")
    def to_delete_tags(self) -> "Sagemaker":
        '''(experimental) Grants permission to delete the specified set of tags from an Amazon SageMaker resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_DeleteTags.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toDeleteTags", []))

    @jsii.member(jsii_name="toDeleteTrial")
    def to_delete_trial(self) -> "Sagemaker":
        '''(experimental) Grants permission to delete a trial.

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_DeleteTrial.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toDeleteTrial", []))

    @jsii.member(jsii_name="toDeleteTrialComponent")
    def to_delete_trial_component(self) -> "Sagemaker":
        '''(experimental) Grants permission to delete a trial component.

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_DeleteTrialComponent.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toDeleteTrialComponent", []))

    @jsii.member(jsii_name="toDeleteUserProfile")
    def to_delete_user_profile(self) -> "Sagemaker":
        '''(experimental) Grants permission to delete a UserProfile.

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_DeleteUserProfile.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toDeleteUserProfile", []))

    @jsii.member(jsii_name="toDeleteWorkforce")
    def to_delete_workforce(self) -> "Sagemaker":
        '''(experimental) Grants permission to delete a workforce.

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_DeleteWorkforce.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toDeleteWorkforce", []))

    @jsii.member(jsii_name="toDeleteWorkteam")
    def to_delete_workteam(self) -> "Sagemaker":
        '''(experimental) Grants permission to delete a workteam.

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_DeleteWorkteam.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toDeleteWorkteam", []))

    @jsii.member(jsii_name="toDeregisterDevices")
    def to_deregister_devices(self) -> "Sagemaker":
        '''(experimental) Grants permission to deregister a set of devices.

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_DeregisterDevices.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toDeregisterDevices", []))

    @jsii.member(jsii_name="toDescribeAction")
    def to_describe_action(self) -> "Sagemaker":
        '''(experimental) Grants permission to get information about an action.

        Access Level: Read

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_DescribeAction.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toDescribeAction", []))

    @jsii.member(jsii_name="toDescribeAlgorithm")
    def to_describe_algorithm(self) -> "Sagemaker":
        '''(experimental) Grants permission to describe an algorithm.

        Access Level: Read

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_DescribeAlgorithm.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toDescribeAlgorithm", []))

    @jsii.member(jsii_name="toDescribeApp")
    def to_describe_app(self) -> "Sagemaker":
        '''(experimental) Grants permission to describe an App.

        Access Level: Read

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_DescribeApp.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toDescribeApp", []))

    @jsii.member(jsii_name="toDescribeAppImageConfig")
    def to_describe_app_image_config(self) -> "Sagemaker":
        '''(experimental) Grants permission to describe an AppImageConfig.

        Access Level: Read

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_DescribeAppImageConfig.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toDescribeAppImageConfig", []))

    @jsii.member(jsii_name="toDescribeArtifact")
    def to_describe_artifact(self) -> "Sagemaker":
        '''(experimental) Grants permission to get information about an artifact.

        Access Level: Read

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_DescribeArtifact.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toDescribeArtifact", []))

    @jsii.member(jsii_name="toDescribeAutoMLJob")
    def to_describe_auto_ml_job(self) -> "Sagemaker":
        '''(experimental) Grants permission to describe an AutoML job that was created via the CreateAutoMLJob API.

        Access Level: Read

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_DescribeAutoMLJob.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toDescribeAutoMLJob", []))

    @jsii.member(jsii_name="toDescribeCodeRepository")
    def to_describe_code_repository(self) -> "Sagemaker":
        '''(experimental) Grants permission to describe a CodeRepository.

        Access Level: Read

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_DescribeCodeRepository.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toDescribeCodeRepository", []))

    @jsii.member(jsii_name="toDescribeCompilationJob")
    def to_describe_compilation_job(self) -> "Sagemaker":
        '''(experimental) Grants permission to return information about a compilation job.

        Access Level: Read

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_DescribeCompilationJob.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toDescribeCompilationJob", []))

    @jsii.member(jsii_name="toDescribeContext")
    def to_describe_context(self) -> "Sagemaker":
        '''(experimental) Grants permission to get information about a context.

        Access Level: Read

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_DescribeContext.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toDescribeContext", []))

    @jsii.member(jsii_name="toDescribeDataQualityJobDefinition")
    def to_describe_data_quality_job_definition(self) -> "Sagemaker":
        '''(experimental) Grants permission to return information about a data quality job definition.

        Access Level: Read

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_DescribeDataQualityJobDefinition.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toDescribeDataQualityJobDefinition", []))

    @jsii.member(jsii_name="toDescribeDevice")
    def to_describe_device(self) -> "Sagemaker":
        '''(experimental) Grants permission to access information about a device.

        Access Level: Read

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_DescribeDevice.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toDescribeDevice", []))

    @jsii.member(jsii_name="toDescribeDeviceFleet")
    def to_describe_device_fleet(self) -> "Sagemaker":
        '''(experimental) Grants permission to access information about a device fleet.

        Access Level: Read

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_DescribeDeviceFleet.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toDescribeDeviceFleet", []))

    @jsii.member(jsii_name="toDescribeDomain")
    def to_describe_domain(self) -> "Sagemaker":
        '''(experimental) Grants permission to describe a Domain.

        Access Level: Read

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_DescribeDomain.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toDescribeDomain", []))

    @jsii.member(jsii_name="toDescribeEdgeDeploymentPlan")
    def to_describe_edge_deployment_plan(self) -> "Sagemaker":
        '''(experimental) Grants permission to access information about an edge deployment plan.

        Access Level: Read

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_DescribeEdgeDeploymentPlan.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toDescribeEdgeDeploymentPlan", []))

    @jsii.member(jsii_name="toDescribeEdgePackagingJob")
    def to_describe_edge_packaging_job(self) -> "Sagemaker":
        '''(experimental) Grants permission to access information about an edge packaging job.

        Access Level: Read

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_DescribeEdgePackagingJob.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toDescribeEdgePackagingJob", []))

    @jsii.member(jsii_name="toDescribeEndpoint")
    def to_describe_endpoint(self) -> "Sagemaker":
        '''(experimental) Grants permission to return the description of an endpoint.

        Access Level: Read

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_DescribeEndpoint.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toDescribeEndpoint", []))

    @jsii.member(jsii_name="toDescribeEndpointConfig")
    def to_describe_endpoint_config(self) -> "Sagemaker":
        '''(experimental) Grants permission to return the description of an endpoint configuration, which was created using the CreateEndpointConfig API.

        Access Level: Read

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_DescribeEndpointConfig.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toDescribeEndpointConfig", []))

    @jsii.member(jsii_name="toDescribeExperiment")
    def to_describe_experiment(self) -> "Sagemaker":
        '''(experimental) Grants permission to return information about an experiment.

        Access Level: Read

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_DescribeExperiment.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toDescribeExperiment", []))

    @jsii.member(jsii_name="toDescribeFeatureGroup")
    def to_describe_feature_group(self) -> "Sagemaker":
        '''(experimental) Grants permission to return information about a feature group.

        Access Level: Read

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_DescribeFeatureGroup.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toDescribeFeatureGroup", []))

    @jsii.member(jsii_name="toDescribeFeatureMetadata")
    def to_describe_feature_metadata(self) -> "Sagemaker":
        '''(experimental) Grants permission to return information about a feature metadata.

        Access Level: Read

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_DescribeFeatureMetadata.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toDescribeFeatureMetadata", []))

    @jsii.member(jsii_name="toDescribeFlowDefinition")
    def to_describe_flow_definition(self) -> "Sagemaker":
        '''(experimental) Grants permission to return information about the specified flow definition.

        Access Level: Read

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_DescribeFlowDefinition.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toDescribeFlowDefinition", []))

    @jsii.member(jsii_name="toDescribeHub")
    def to_describe_hub(self) -> "Sagemaker":
        '''(experimental) Grants permission to describe hubs.

        Access Level: Read

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_DescribeHub.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toDescribeHub", []))

    @jsii.member(jsii_name="toDescribeHubContent")
    def to_describe_hub_content(self) -> "Sagemaker":
        '''(experimental) Grants permission to describe hub content.

        Access Level: Read

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_DescribeHubContent.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toDescribeHubContent", []))

    @jsii.member(jsii_name="toDescribeHumanLoop")
    def to_describe_human_loop(self) -> "Sagemaker":
        '''(experimental) Grants permission to return information about the specified human loop.

        Access Level: Read

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_DescribeHumanLoop.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toDescribeHumanLoop", []))

    @jsii.member(jsii_name="toDescribeHumanTaskUi")
    def to_describe_human_task_ui(self) -> "Sagemaker":
        '''(experimental) Grants permission to return detailed information about the specified human review workflow user interface.

        Access Level: Read

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_DescribeHumanTaskUi.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toDescribeHumanTaskUi", []))

    @jsii.member(jsii_name="toDescribeHyperParameterTuningJob")
    def to_describe_hyper_parameter_tuning_job(self) -> "Sagemaker":
        '''(experimental) Grants permission to describe a hyper parameter tuning job that was created via the CreateHyperParameterTuningJob API.

        Access Level: Read

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_DescribeHyperParameterTuningJob.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toDescribeHyperParameterTuningJob", []))

    @jsii.member(jsii_name="toDescribeImage")
    def to_describe_image(self) -> "Sagemaker":
        '''(experimental) Grants permission to return information about a SageMaker Image.

        Access Level: Read

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_DescribeImage.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toDescribeImage", []))

    @jsii.member(jsii_name="toDescribeImageVersion")
    def to_describe_image_version(self) -> "Sagemaker":
        '''(experimental) Grants permission to return information about a SageMaker ImageVersion.

        Access Level: Read

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_DescribeImageVersion.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toDescribeImageVersion", []))

    @jsii.member(jsii_name="toDescribeInferenceExperiment")
    def to_describe_inference_experiment(self) -> "Sagemaker":
        '''(experimental) Grants permission to get information about an inference experiment.

        Access Level: Read

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_DescribeInferenceExperiment.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toDescribeInferenceExperiment", []))

    @jsii.member(jsii_name="toDescribeInferenceRecommendationsJob")
    def to_describe_inference_recommendations_job(self) -> "Sagemaker":
        '''(experimental) Grants permission to get information about an inference recommendations job.

        Access Level: Read

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_DescribeInferenceRecommendationsJob.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toDescribeInferenceRecommendationsJob", []))

    @jsii.member(jsii_name="toDescribeLabelingJob")
    def to_describe_labeling_job(self) -> "Sagemaker":
        '''(experimental) Grants permission to return information about a labeling job.

        Access Level: Read

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_DescribeLabelingJob.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toDescribeLabelingJob", []))

    @jsii.member(jsii_name="toDescribeLineageGroup")
    def to_describe_lineage_group(self) -> "Sagemaker":
        '''(experimental) Grants permission to describe a lineage group.

        Access Level: Read

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_DescribeLineageGroup.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toDescribeLineageGroup", []))

    @jsii.member(jsii_name="toDescribeModel")
    def to_describe_model(self) -> "Sagemaker":
        '''(experimental) Grants permission to describe a model that you created using the CreateModel API.

        Access Level: Read

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_DescribeModel.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toDescribeModel", []))

    @jsii.member(jsii_name="toDescribeModelBiasJobDefinition")
    def to_describe_model_bias_job_definition(self) -> "Sagemaker":
        '''(experimental) Grants permission to return information about a model bias job definition.

        Access Level: Read

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_DescribeModelBiasJobDefinition.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toDescribeModelBiasJobDefinition", []))

    @jsii.member(jsii_name="toDescribeModelCard")
    def to_describe_model_card(self) -> "Sagemaker":
        '''(experimental) Grants permission to get information about a model card.

        Access Level: Read

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_DescribeModelCard.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toDescribeModelCard", []))

    @jsii.member(jsii_name="toDescribeModelCardExportJob")
    def to_describe_model_card_export_job(self) -> "Sagemaker":
        '''(experimental) Grants permission to get information about a model card export job.

        Access Level: Read

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_DescribeModelCardExportJob.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toDescribeModelCardExportJob", []))

    @jsii.member(jsii_name="toDescribeModelExplainabilityJobDefinition")
    def to_describe_model_explainability_job_definition(self) -> "Sagemaker":
        '''(experimental) Grants permission to return information about a model explainability job definition.

        Access Level: Read

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_DescribeModelExplainabilityJobDefinition.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toDescribeModelExplainabilityJobDefinition", []))

    @jsii.member(jsii_name="toDescribeModelPackage")
    def to_describe_model_package(self) -> "Sagemaker":
        '''(experimental) Grants permission to describe a ModelPackage.

        Access Level: Read

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_DescribeModelPackage.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toDescribeModelPackage", []))

    @jsii.member(jsii_name="toDescribeModelPackageGroup")
    def to_describe_model_package_group(self) -> "Sagemaker":
        '''(experimental) Grants permission to describe a ModelPackageGroup.

        Access Level: Read

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_DescribeModelPackageGroup.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toDescribeModelPackageGroup", []))

    @jsii.member(jsii_name="toDescribeModelQualityJobDefinition")
    def to_describe_model_quality_job_definition(self) -> "Sagemaker":
        '''(experimental) Grants permission to return information about a model quality job definition.

        Access Level: Read

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_DescribeModelQualityJobDefinition.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toDescribeModelQualityJobDefinition", []))

    @jsii.member(jsii_name="toDescribeMonitoringSchedule")
    def to_describe_monitoring_schedule(self) -> "Sagemaker":
        '''(experimental) Grants permission to return information about a monitoring schedule.

        Access Level: Read

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_DescribeMonitoringSchedule.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toDescribeMonitoringSchedule", []))

    @jsii.member(jsii_name="toDescribeNotebookInstance")
    def to_describe_notebook_instance(self) -> "Sagemaker":
        '''(experimental) Grants permission to return information about a notebook instance.

        Access Level: Read

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_DescribeNotebookInstance.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toDescribeNotebookInstance", []))

    @jsii.member(jsii_name="toDescribeNotebookInstanceLifecycleConfig")
    def to_describe_notebook_instance_lifecycle_config(self) -> "Sagemaker":
        '''(experimental) Grants permission to describe a notebook instance lifecycle configuration that was created via the CreateNotebookInstanceLifecycleConfig API.

        Access Level: Read

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_DescribeNotebookInstanceLifecycleConfig.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toDescribeNotebookInstanceLifecycleConfig", []))

    @jsii.member(jsii_name="toDescribePipeline")
    def to_describe_pipeline(self) -> "Sagemaker":
        '''(experimental) Grants permission to get information about a pipeline.

        Access Level: Read

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_DescribePipeline.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toDescribePipeline", []))

    @jsii.member(jsii_name="toDescribePipelineDefinitionForExecution")
    def to_describe_pipeline_definition_for_execution(self) -> "Sagemaker":
        '''(experimental) Grants permission to get the pipeline definition for a pipeline execution.

        Access Level: Read

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_DescribePipelineDefinitionForExecution.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toDescribePipelineDefinitionForExecution", []))

    @jsii.member(jsii_name="toDescribePipelineExecution")
    def to_describe_pipeline_execution(self) -> "Sagemaker":
        '''(experimental) Grants permission to get information about a pipeline execution.

        Access Level: Read

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_DescribePipelineExecution.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toDescribePipelineExecution", []))

    @jsii.member(jsii_name="toDescribeProcessingJob")
    def to_describe_processing_job(self) -> "Sagemaker":
        '''(experimental) Grants permission to return information about a processing job.

        Access Level: Read

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_DescribeProcessingJob.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toDescribeProcessingJob", []))

    @jsii.member(jsii_name="toDescribeProject")
    def to_describe_project(self) -> "Sagemaker":
        '''(experimental) Grants permission to describe a project.

        Access Level: Read

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_DescribeProject.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toDescribeProject", []))

    @jsii.member(jsii_name="toDescribeSharedModel")
    def to_describe_shared_model(self) -> "Sagemaker":
        '''(experimental) Grants permission to describe a shared model in a SageMaker Studio application.

        Access Level: Read

        https://docs.aws.amazon.com/sagemaker/latest/dg/canvas-collaborate-permissions.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toDescribeSharedModel", []))

    @jsii.member(jsii_name="toDescribeSpace")
    def to_describe_space(self) -> "Sagemaker":
        '''(experimental) Grants permission to describe a Space.

        Access Level: Read

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_DescribeSpace.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toDescribeSpace", []))

    @jsii.member(jsii_name="toDescribeStudioLifecycleConfig")
    def to_describe_studio_lifecycle_config(self) -> "Sagemaker":
        '''(experimental) Grants permission to describe a Studio Lifecycle Configuration.

        Access Level: Read

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_DescribeStudioLifecycleConfig.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toDescribeStudioLifecycleConfig", []))

    @jsii.member(jsii_name="toDescribeSubscribedWorkteam")
    def to_describe_subscribed_workteam(self) -> "Sagemaker":
        '''(experimental) Grants permission to return information about a subscribed workteam.

        Access Level: Read

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_DescribeSubscribedWorkteam.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toDescribeSubscribedWorkteam", []))

    @jsii.member(jsii_name="toDescribeTrainingJob")
    def to_describe_training_job(self) -> "Sagemaker":
        '''(experimental) Grants permission to return information about a training job.

        Access Level: Read

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_DescribeTrainingJob.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toDescribeTrainingJob", []))

    @jsii.member(jsii_name="toDescribeTransformJob")
    def to_describe_transform_job(self) -> "Sagemaker":
        '''(experimental) Grants permission to return information about a transform job.

        Access Level: Read

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_DescribeTransformJob.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toDescribeTransformJob", []))

    @jsii.member(jsii_name="toDescribeTrial")
    def to_describe_trial(self) -> "Sagemaker":
        '''(experimental) Grants permission to return information about a trial.

        Access Level: Read

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_DescribeTrial.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toDescribeTrial", []))

    @jsii.member(jsii_name="toDescribeTrialComponent")
    def to_describe_trial_component(self) -> "Sagemaker":
        '''(experimental) Grants permission to return information about a trial component.

        Access Level: Read

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_DescribeTrialComponent.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toDescribeTrialComponent", []))

    @jsii.member(jsii_name="toDescribeUserProfile")
    def to_describe_user_profile(self) -> "Sagemaker":
        '''(experimental) Grants permission to describe a UserProfile.

        Access Level: Read

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_DescribeUserProfile.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toDescribeUserProfile", []))

    @jsii.member(jsii_name="toDescribeWorkforce")
    def to_describe_workforce(self) -> "Sagemaker":
        '''(experimental) Grants permission to return information about a workforce.

        Access Level: Read

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_DescribeWorkforce.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toDescribeWorkforce", []))

    @jsii.member(jsii_name="toDescribeWorkteam")
    def to_describe_workteam(self) -> "Sagemaker":
        '''(experimental) Grants permission to return information about a workteam.

        Access Level: Read

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_DescribeWorkteam.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toDescribeWorkteam", []))

    @jsii.member(jsii_name="toDisableSagemakerServicecatalogPortfolio")
    def to_disable_sagemaker_servicecatalog_portfolio(self) -> "Sagemaker":
        '''(experimental) Grants permission to disable a SageMaker Service Catalog Portfolio.

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_DisableSagemakerServicecatalogPortfolio.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toDisableSagemakerServicecatalogPortfolio", []))

    @jsii.member(jsii_name="toDisassociateTrialComponent")
    def to_disassociate_trial_component(self) -> "Sagemaker":
        '''(experimental) Grants permission to disassociate a trial component from a trial.

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_DisassociateTrialComponent.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toDisassociateTrialComponent", []))

    @jsii.member(jsii_name="toEnableSagemakerServicecatalogPortfolio")
    def to_enable_sagemaker_servicecatalog_portfolio(self) -> "Sagemaker":
        '''(experimental) Grants permission to enable a SageMaker Service Catalog Portfolio.

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_EnableSagemakerServicecatalogPortfolio.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toEnableSagemakerServicecatalogPortfolio", []))

    @jsii.member(jsii_name="toGetDeviceFleetReport")
    def to_get_device_fleet_report(self) -> "Sagemaker":
        '''(experimental) Grants permission to access a summary of the devices in a device fleet.

        Access Level: Read

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_GetDeviceFleetReport.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toGetDeviceFleetReport", []))

    @jsii.member(jsii_name="toGetDeviceRegistration")
    def to_get_device_registration(self) -> "Sagemaker":
        '''(experimental) Grants permission to get device registration.

        After you deploy a model onto edge devices this api is used to get current device registration

        Access Level: Read

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_edge_GetDeviceRegistration.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toGetDeviceRegistration", []))

    @jsii.member(jsii_name="toGetLineageGroupPolicy")
    def to_get_lineage_group_policy(self) -> "Sagemaker":
        '''(experimental) Grants permission to retreive a lineage group policy.

        Access Level: Read

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_GetLineageGroupPolicy.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toGetLineageGroupPolicy", []))

    @jsii.member(jsii_name="toGetModelPackageGroupPolicy")
    def to_get_model_package_group_policy(self) -> "Sagemaker":
        '''(experimental) Grants permission to get a ModelPackageGroup policy.

        Access Level: Read

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_GetModelPackageGroupPolicy.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toGetModelPackageGroupPolicy", []))

    @jsii.member(jsii_name="toGetRecord")
    def to_get_record(self) -> "Sagemaker":
        '''(experimental) Grants permission to get a record from a feature group.

        Access Level: Read

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_feature_store_GetRecord.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toGetRecord", []))

    @jsii.member(jsii_name="toGetSagemakerServicecatalogPortfolioStatus")
    def to_get_sagemaker_servicecatalog_portfolio_status(self) -> "Sagemaker":
        '''(experimental) Grants permission to get a SageMaker Service Catalog Portfolio.

        Access Level: Read

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_GetSagemakerServicecatalogPortfolioStatus.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toGetSagemakerServicecatalogPortfolioStatus", []))

    @jsii.member(jsii_name="toGetSearchSuggestions")
    def to_get_search_suggestions(self) -> "Sagemaker":
        '''(experimental) Grants permission to get search suggestions when provided with a keyword.

        Access Level: Read

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_GetSearchSuggestions.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toGetSearchSuggestions", []))

    @jsii.member(jsii_name="toImportHubContent")
    def to_import_hub_content(self) -> "Sagemaker":
        '''(experimental) Grants permission to import hub content.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - sagemaker:AddTags

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_ImportHubContent.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toImportHubContent", []))

    @jsii.member(jsii_name="toInvokeEndpoint")
    def to_invoke_endpoint(self) -> "Sagemaker":
        '''(experimental) Grants permission to invoke an endpoint.

        After you deploy a model into production using Amazon SageMaker hosting services, your client applications use this API to get inferences from the model hosted at the specified endpoint

        Access Level: Read

        Possible conditions:

        - .ifTargetModel()

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_runtime_InvokeEndpoint.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toInvokeEndpoint", []))

    @jsii.member(jsii_name="toInvokeEndpointAsync")
    def to_invoke_endpoint_async(self) -> "Sagemaker":
        '''(experimental) Grants permission to get inferences from the hosted model at the specified endpoint in an asynchronous manner.

        Access Level: Read

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_runtime_InvokeEndpointAsync.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toInvokeEndpointAsync", []))

    @jsii.member(jsii_name="toListActions")
    def to_list_actions(self) -> "Sagemaker":
        '''(experimental) Grants permission to list actions.

        Access Level: List

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_ListActions.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toListActions", []))

    @jsii.member(jsii_name="toListAlgorithms")
    def to_list_algorithms(self) -> "Sagemaker":
        '''(experimental) Grants permission to list Algorithms.

        Access Level: List

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_ListAlgorithms.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toListAlgorithms", []))

    @jsii.member(jsii_name="toListAppImageConfigs")
    def to_list_app_image_configs(self) -> "Sagemaker":
        '''(experimental) Grants permission to list the AppImageConfigs in your account.

        Access Level: List

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_ListAppImageConfigs.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toListAppImageConfigs", []))

    @jsii.member(jsii_name="toListApps")
    def to_list_apps(self) -> "Sagemaker":
        '''(experimental) Grants permission to list the Apps in your account.

        Access Level: List

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_ListApps.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toListApps", []))

    @jsii.member(jsii_name="toListArtifacts")
    def to_list_artifacts(self) -> "Sagemaker":
        '''(experimental) Grants permission to list artifacts.

        Access Level: List

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_ListArtifacts.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toListArtifacts", []))

    @jsii.member(jsii_name="toListAssociations")
    def to_list_associations(self) -> "Sagemaker":
        '''(experimental) Grants permission to list associations.

        Access Level: List

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_ListAssociations.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toListAssociations", []))

    @jsii.member(jsii_name="toListAutoMLJobs")
    def to_list_auto_ml_jobs(self) -> "Sagemaker":
        '''(experimental) Grants permission to list AutoML jobs.

        Access Level: List

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_ListAutoMLJobs.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toListAutoMLJobs", []))

    @jsii.member(jsii_name="toListCandidatesForAutoMLJob")
    def to_list_candidates_for_auto_ml_job(self) -> "Sagemaker":
        '''(experimental) Grants permission to lists candidates for an AutoML job.

        Access Level: List

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_ListCandidatesForAutoMLJob.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toListCandidatesForAutoMLJob", []))

    @jsii.member(jsii_name="toListCodeRepositories")
    def to_list_code_repositories(self) -> "Sagemaker":
        '''(experimental) Grants permission to list code repositories.

        Access Level: List

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_ListCodeRepositories.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toListCodeRepositories", []))

    @jsii.member(jsii_name="toListCompilationJobs")
    def to_list_compilation_jobs(self) -> "Sagemaker":
        '''(experimental) Grants permission to list compilation jobs.

        Access Level: List

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_ListCompilationJobs.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toListCompilationJobs", []))

    @jsii.member(jsii_name="toListContexts")
    def to_list_contexts(self) -> "Sagemaker":
        '''(experimental) Grants permission to list contexts.

        Access Level: List

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_ListContexts.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toListContexts", []))

    @jsii.member(jsii_name="toListDataQualityJobDefinitions")
    def to_list_data_quality_job_definitions(self) -> "Sagemaker":
        '''(experimental) Grants permission to list data quality job definitions.

        Access Level: List

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_ListDataQualityJobDefinitions.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toListDataQualityJobDefinitions", []))

    @jsii.member(jsii_name="toListDeviceFleets")
    def to_list_device_fleets(self) -> "Sagemaker":
        '''(experimental) Grants permission to list device fleets.

        Access Level: List

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_ListDeviceFleets.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toListDeviceFleets", []))

    @jsii.member(jsii_name="toListDevices")
    def to_list_devices(self) -> "Sagemaker":
        '''(experimental) Grants permission to list devices.

        Access Level: List

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_ListDevices.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toListDevices", []))

    @jsii.member(jsii_name="toListDomains")
    def to_list_domains(self) -> "Sagemaker":
        '''(experimental) Grants permission to list the Domains in your account.

        Access Level: List

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_ListDomains.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toListDomains", []))

    @jsii.member(jsii_name="toListEdgeDeploymentPlans")
    def to_list_edge_deployment_plans(self) -> "Sagemaker":
        '''(experimental) Grants permission to list edge deployment plans.

        Access Level: List

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_ListEdgeDeploymentPlans.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toListEdgeDeploymentPlans", []))

    @jsii.member(jsii_name="toListEdgePackagingJobs")
    def to_list_edge_packaging_jobs(self) -> "Sagemaker":
        '''(experimental) Grants permission to list edge packaging jobs.

        Access Level: List

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_ListEdgePackagingJobs.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toListEdgePackagingJobs", []))

    @jsii.member(jsii_name="toListEndpointConfigs")
    def to_list_endpoint_configs(self) -> "Sagemaker":
        '''(experimental) Grants permission to list endpoint configurations.

        Access Level: List

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_ListEndpointConfigs.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toListEndpointConfigs", []))

    @jsii.member(jsii_name="toListEndpoints")
    def to_list_endpoints(self) -> "Sagemaker":
        '''(experimental) Grants permission to list endpoints.

        Access Level: List

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_ListEndpoints.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toListEndpoints", []))

    @jsii.member(jsii_name="toListExperiments")
    def to_list_experiments(self) -> "Sagemaker":
        '''(experimental) Grants permission to list experiments.

        Access Level: List

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_ListExperiments.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toListExperiments", []))

    @jsii.member(jsii_name="toListFeatureGroups")
    def to_list_feature_groups(self) -> "Sagemaker":
        '''(experimental) Grants permission to list feature groups.

        Access Level: List

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_ListFeatureGroups.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toListFeatureGroups", []))

    @jsii.member(jsii_name="toListFlowDefinitions")
    def to_list_flow_definitions(self) -> "Sagemaker":
        '''(experimental) Grants permission to return summary information about flow definitions, given the specified parameters.

        Access Level: List

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_ListFlowDefinitions.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toListFlowDefinitions", []))

    @jsii.member(jsii_name="toListHubContents")
    def to_list_hub_contents(self) -> "Sagemaker":
        '''(experimental) Grants permission to list newest versions of hub content.

        Access Level: List

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_ListHubContents.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toListHubContents", []))

    @jsii.member(jsii_name="toListHubContentVersions")
    def to_list_hub_content_versions(self) -> "Sagemaker":
        '''(experimental) Grants permission to list all versions of hub content.

        Access Level: List

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_ListHubContentVersions.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toListHubContentVersions", []))

    @jsii.member(jsii_name="toListHubs")
    def to_list_hubs(self) -> "Sagemaker":
        '''(experimental) Grants permission to list hubs.

        Access Level: List

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_ListHubs.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toListHubs", []))

    @jsii.member(jsii_name="toListHumanLoops")
    def to_list_human_loops(self) -> "Sagemaker":
        '''(experimental) Grants permission to return summary information about human loops, given the specified parameters.

        Access Level: List

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_ListHumanLoops.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toListHumanLoops", []))

    @jsii.member(jsii_name="toListHumanTaskUis")
    def to_list_human_task_uis(self) -> "Sagemaker":
        '''(experimental) Grants permission to return summary information about human review workflow user interfaces, given the specified parameters.

        Access Level: List

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_ListHumanTaskUis.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toListHumanTaskUis", []))

    @jsii.member(jsii_name="toListHyperParameterTuningJobs")
    def to_list_hyper_parameter_tuning_jobs(self) -> "Sagemaker":
        '''(experimental) Grants permission to list hyper parameter tuning jobs.

        Access Level: List

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_ListHyperParameterTuningJobs.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toListHyperParameterTuningJobs", []))

    @jsii.member(jsii_name="toListImages")
    def to_list_images(self) -> "Sagemaker":
        '''(experimental) Grants permission to list SageMaker Images in your account.

        Access Level: List

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_ListImages.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toListImages", []))

    @jsii.member(jsii_name="toListImageVersions")
    def to_list_image_versions(self) -> "Sagemaker":
        '''(experimental) Grants permission to list ImageVersions that belong to a SageMaker Image.

        Access Level: List

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_ListImageVersions.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toListImageVersions", []))

    @jsii.member(jsii_name="toListInferenceExperiments")
    def to_list_inference_experiments(self) -> "Sagemaker":
        '''(experimental) Grants permission to list inference experiments.

        Access Level: List

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_ListInferenceExperiments.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toListInferenceExperiments", []))

    @jsii.member(jsii_name="toListInferenceRecommendationsJobs")
    def to_list_inference_recommendations_jobs(self) -> "Sagemaker":
        '''(experimental) Grants permission to list inference recommendations jobs.

        Access Level: List

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_ListInferenceRecommendationsJobs.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toListInferenceRecommendationsJobs", []))

    @jsii.member(jsii_name="toListInferenceRecommendationsJobSteps")
    def to_list_inference_recommendations_job_steps(self) -> "Sagemaker":
        '''(experimental) Grants permission to list inference recommendations job steps.

        Access Level: List

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_ListInferenceRecommendationsJobSteps.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toListInferenceRecommendationsJobSteps", []))

    @jsii.member(jsii_name="toListLabelingJobs")
    def to_list_labeling_jobs(self) -> "Sagemaker":
        '''(experimental) Grants permission to list labeling jobs.

        Access Level: List

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_ListLabelingJobs.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toListLabelingJobs", []))

    @jsii.member(jsii_name="toListLabelingJobsForWorkteam")
    def to_list_labeling_jobs_for_workteam(self) -> "Sagemaker":
        '''(experimental) Grants permission to list labeling jobs for workteam.

        Access Level: List

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_ListLabelingJobs.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toListLabelingJobsForWorkteam", []))

    @jsii.member(jsii_name="toListLineageGroups")
    def to_list_lineage_groups(self) -> "Sagemaker":
        '''(experimental) Grants permission to list lineage groups.

        Access Level: List

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_ListLineageGroups.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toListLineageGroups", []))

    @jsii.member(jsii_name="toListModelBiasJobDefinitions")
    def to_list_model_bias_job_definitions(self) -> "Sagemaker":
        '''(experimental) Grants permission to list model bias job definitions.

        Access Level: List

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_ListModelBiasJobDefinitions.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toListModelBiasJobDefinitions", []))

    @jsii.member(jsii_name="toListModelCardExportJobs")
    def to_list_model_card_export_jobs(self) -> "Sagemaker":
        '''(experimental) Grants permission to list export jobs for a model card.

        Access Level: List

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_ListModelCardExportJobs.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toListModelCardExportJobs", []))

    @jsii.member(jsii_name="toListModelCards")
    def to_list_model_cards(self) -> "Sagemaker":
        '''(experimental) Grants permission to list model cards.

        Access Level: List

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_ListModelCards.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toListModelCards", []))

    @jsii.member(jsii_name="toListModelCardVersions")
    def to_list_model_card_versions(self) -> "Sagemaker":
        '''(experimental) Grants permission to list versions of a model card.

        Access Level: List

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_ListModelCardVersions.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toListModelCardVersions", []))

    @jsii.member(jsii_name="toListModelExplainabilityJobDefinitions")
    def to_list_model_explainability_job_definitions(self) -> "Sagemaker":
        '''(experimental) Grants permission to list model explainability job definitions.

        Access Level: List

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_ListModelExplainabilityJobDefinitions.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toListModelExplainabilityJobDefinitions", []))

    @jsii.member(jsii_name="toListModelMetadata")
    def to_list_model_metadata(self) -> "Sagemaker":
        '''(experimental) Grants permission to list model metadata for inference recommendations jobs.

        Access Level: List

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_ListModelMetadata.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toListModelMetadata", []))

    @jsii.member(jsii_name="toListModelPackageGroups")
    def to_list_model_package_groups(self) -> "Sagemaker":
        '''(experimental) Grants permission to list ModelPackageGroups.

        Access Level: List

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_ListModelPackageGroups.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toListModelPackageGroups", []))

    @jsii.member(jsii_name="toListModelPackages")
    def to_list_model_packages(self) -> "Sagemaker":
        '''(experimental) Grants permission to list ModelPackages.

        Access Level: List

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_ListModelPackages.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toListModelPackages", []))

    @jsii.member(jsii_name="toListModelQualityJobDefinitions")
    def to_list_model_quality_job_definitions(self) -> "Sagemaker":
        '''(experimental) Grants permission to list model quality job definitions.

        Access Level: List

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_ListModelQualityJobDefinitions.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toListModelQualityJobDefinitions", []))

    @jsii.member(jsii_name="toListModels")
    def to_list_models(self) -> "Sagemaker":
        '''(experimental) Grants permission to list the models created with the CreateModel API.

        Access Level: List

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_ListModels.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toListModels", []))

    @jsii.member(jsii_name="toListMonitoringAlertHistory")
    def to_list_monitoring_alert_history(self) -> "Sagemaker":
        '''(experimental) Grants permission to list the history of a monitoring alert.

        Access Level: List

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_ListMonitoringHistory.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toListMonitoringAlertHistory", []))

    @jsii.member(jsii_name="toListMonitoringAlerts")
    def to_list_monitoring_alerts(self) -> "Sagemaker":
        '''(experimental) Grants permission to list monitoring alerts.

        Access Level: List

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_ListMonitoringAlerts.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toListMonitoringAlerts", []))

    @jsii.member(jsii_name="toListMonitoringExecutions")
    def to_list_monitoring_executions(self) -> "Sagemaker":
        '''(experimental) Grants permission to list monitoring executions.

        Access Level: List

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_ListMonitoringExecutions.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toListMonitoringExecutions", []))

    @jsii.member(jsii_name="toListMonitoringSchedules")
    def to_list_monitoring_schedules(self) -> "Sagemaker":
        '''(experimental) Grants permission to list monitoring schedules.

        Access Level: List

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_ListMonitoringSchedules.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toListMonitoringSchedules", []))

    @jsii.member(jsii_name="toListNotebookInstanceLifecycleConfigs")
    def to_list_notebook_instance_lifecycle_configs(self) -> "Sagemaker":
        '''(experimental) Grants permission to list the notebook instance lifecycle configurations that can be deployed using Amazon SageMaker.

        Access Level: List

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_ListNotebookInstanceLifecycleConfigs.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toListNotebookInstanceLifecycleConfigs", []))

    @jsii.member(jsii_name="toListNotebookInstances")
    def to_list_notebook_instances(self) -> "Sagemaker":
        '''(experimental) Grants permission to list the Amazon SageMaker notebook instances in the requester's account in an AWS Region.

        Access Level: List

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_ListNotebookInstances.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toListNotebookInstances", []))

    @jsii.member(jsii_name="toListPipelineExecutions")
    def to_list_pipeline_executions(self) -> "Sagemaker":
        '''(experimental) Grants permission to list executions for a pipeline.

        Access Level: List

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_ListPipelineExecutions.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toListPipelineExecutions", []))

    @jsii.member(jsii_name="toListPipelineExecutionSteps")
    def to_list_pipeline_execution_steps(self) -> "Sagemaker":
        '''(experimental) Grants permission to list steps for a pipeline execution.

        Access Level: List

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_ListPipelineExecutionSteps.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toListPipelineExecutionSteps", []))

    @jsii.member(jsii_name="toListPipelineParametersForExecution")
    def to_list_pipeline_parameters_for_execution(self) -> "Sagemaker":
        '''(experimental) Grants permission to list parameters for a pipeline execution.

        Access Level: List

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_ListPipelineParametersForExecution.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toListPipelineParametersForExecution", []))

    @jsii.member(jsii_name="toListPipelines")
    def to_list_pipelines(self) -> "Sagemaker":
        '''(experimental) Grants permission to list pipelines.

        Access Level: List

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_ListPipelines.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toListPipelines", []))

    @jsii.member(jsii_name="toListProcessingJobs")
    def to_list_processing_jobs(self) -> "Sagemaker":
        '''(experimental) Grants permission to list processing jobs.

        Access Level: List

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_ListProcessingJobs.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toListProcessingJobs", []))

    @jsii.member(jsii_name="toListProjects")
    def to_list_projects(self) -> "Sagemaker":
        '''(experimental) Grants permission to list Projects.

        Access Level: List

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_ListProjects.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toListProjects", []))

    @jsii.member(jsii_name="toListSharedModelEvents")
    def to_list_shared_model_events(self) -> "Sagemaker":
        '''(experimental) Grants permission to list shared model events.

        Access Level: List

        https://docs.aws.amazon.com/sagemaker/latest/dg/canvas-collaborate-permissions.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toListSharedModelEvents", []))

    @jsii.member(jsii_name="toListSharedModels")
    def to_list_shared_models(self) -> "Sagemaker":
        '''(experimental) Grants permission to list shared models.

        Access Level: List

        https://docs.aws.amazon.com/sagemaker/latest/dg/canvas-collaborate-permissions.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toListSharedModels", []))

    @jsii.member(jsii_name="toListSharedModelVersions")
    def to_list_shared_model_versions(self) -> "Sagemaker":
        '''(experimental) Grants permission to list shared model versions.

        Access Level: List

        https://docs.aws.amazon.com/sagemaker/latest/dg/canvas-collaborate-permissions.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toListSharedModelVersions", []))

    @jsii.member(jsii_name="toListSpaces")
    def to_list_spaces(self) -> "Sagemaker":
        '''(experimental) Grants permission to list the Spaces in your account.

        Access Level: List

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_ListSpaces.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toListSpaces", []))

    @jsii.member(jsii_name="toListStageDevices")
    def to_list_stage_devices(self) -> "Sagemaker":
        '''(experimental) Grants permission to list stage devices.

        Access Level: List

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_ListStageDevices.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toListStageDevices", []))

    @jsii.member(jsii_name="toListStudioLifecycleConfigs")
    def to_list_studio_lifecycle_configs(self) -> "Sagemaker":
        '''(experimental) Grants permission to list the Studio Lifecycle Configurations that can be deployed using Amazon SageMaker.

        Access Level: List

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_ListStudioLifecycleConfigs.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toListStudioLifecycleConfigs", []))

    @jsii.member(jsii_name="toListSubscribedWorkteams")
    def to_list_subscribed_workteams(self) -> "Sagemaker":
        '''(experimental) Grants permission to list subscribed workteams.

        Access Level: List

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_ListSubscribedWorkteams.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toListSubscribedWorkteams", []))

    @jsii.member(jsii_name="toListTags")
    def to_list_tags(self) -> "Sagemaker":
        '''(experimental) Grants permission to list the tag set associated with the specified resource.

        Access Level: List

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_ListTags.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toListTags", []))

    @jsii.member(jsii_name="toListTrainingJobs")
    def to_list_training_jobs(self) -> "Sagemaker":
        '''(experimental) Grants permission to list training jobs.

        Access Level: List

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_ListTrainingJobs.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toListTrainingJobs", []))

    @jsii.member(jsii_name="toListTrainingJobsForHyperParameterTuningJob")
    def to_list_training_jobs_for_hyper_parameter_tuning_job(self) -> "Sagemaker":
        '''(experimental) Grants permission to list training jobs for a hyper parameter tuning job.

        Access Level: List

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_ListTrainingJobsForHyperParameterTuningJob.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toListTrainingJobsForHyperParameterTuningJob", []))

    @jsii.member(jsii_name="toListTransformJobs")
    def to_list_transform_jobs(self) -> "Sagemaker":
        '''(experimental) Grants permission to list transform jobs.

        Access Level: List

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_ListTransformJobs.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toListTransformJobs", []))

    @jsii.member(jsii_name="toListTrialComponents")
    def to_list_trial_components(self) -> "Sagemaker":
        '''(experimental) Grants permission to list trial components.

        Access Level: List

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_ListTrialComponents.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toListTrialComponents", []))

    @jsii.member(jsii_name="toListTrials")
    def to_list_trials(self) -> "Sagemaker":
        '''(experimental) Grants permission to list trials.

        Access Level: List

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_ListTrials.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toListTrials", []))

    @jsii.member(jsii_name="toListUserProfiles")
    def to_list_user_profiles(self) -> "Sagemaker":
        '''(experimental) Grants permission to list the UserProfiles in your account.

        Access Level: List

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_ListUserProfiles.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toListUserProfiles", []))

    @jsii.member(jsii_name="toListWorkforces")
    def to_list_workforces(self) -> "Sagemaker":
        '''(experimental) Grants permission to list workforces.

        Access Level: List

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_ListWorkforces.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toListWorkforces", []))

    @jsii.member(jsii_name="toListWorkteams")
    def to_list_workteams(self) -> "Sagemaker":
        '''(experimental) Grants permission to list workteams.

        Access Level: List

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_ListWorkteams.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toListWorkteams", []))

    @jsii.member(jsii_name="toPutLineageGroupPolicy")
    def to_put_lineage_group_policy(self) -> "Sagemaker":
        '''(experimental) Grants permission to put a lineage group policy.

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/Welcome.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toPutLineageGroupPolicy", []))

    @jsii.member(jsii_name="toPutModelPackageGroupPolicy")
    def to_put_model_package_group_policy(self) -> "Sagemaker":
        '''(experimental) Grants permission to put a ModelPackageGroup policy.

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_PutModelPackageGroupPolicy.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toPutModelPackageGroupPolicy", []))

    @jsii.member(jsii_name="toPutRecord")
    def to_put_record(self) -> "Sagemaker":
        '''(experimental) Grants permission to put a record to a feature group.

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_feature_store_PutRecord.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toPutRecord", []))

    @jsii.member(jsii_name="toQueryLineage")
    def to_query_lineage(self) -> "Sagemaker":
        '''(experimental) Grants permission to explore the lineage graph.

        Access Level: List

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_QueryLineage.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toQueryLineage", []))

    @jsii.member(jsii_name="toRegisterDevices")
    def to_register_devices(self) -> "Sagemaker":
        '''(experimental) Grants permission to register a set of devices.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_RegisterDevices.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toRegisterDevices", []))

    @jsii.member(jsii_name="toRenderUiTemplate")
    def to_render_ui_template(self) -> "Sagemaker":
        '''(experimental) Grants permission to render a UI template used for a human annotation task.

        Access Level: Read

        Dependent actions:

        - iam:PassRole

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_RenderUiTemplate.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toRenderUiTemplate", []))

    @jsii.member(jsii_name="toRetryPipelineExecution")
    def to_retry_pipeline_execution(self) -> "Sagemaker":
        '''(experimental) Grants permission to retry a pipeline execution.

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_RetryPipelineExecution.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toRetryPipelineExecution", []))

    @jsii.member(jsii_name="toSearch")
    def to_search(self) -> "Sagemaker":
        '''(experimental) Grants permission to search for SageMaker objects.

        Access Level: Read

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_Search.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toSearch", []))

    @jsii.member(jsii_name="toSendHeartbeat")
    def to_send_heartbeat(self) -> "Sagemaker":
        '''(experimental) Grants permission to publish heartbeat data from devices.

        After you deploy a model onto edge devices this api is used to report device status

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_edge_SendHeartbeat.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toSendHeartbeat", []))

    @jsii.member(jsii_name="toSendPipelineExecutionStepFailure")
    def to_send_pipeline_execution_step_failure(self) -> "Sagemaker":
        '''(experimental) Grants permission to fail a pending callback step.

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_SendPipelineExecutionStepFailure.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toSendPipelineExecutionStepFailure", []))

    @jsii.member(jsii_name="toSendPipelineExecutionStepSuccess")
    def to_send_pipeline_execution_step_success(self) -> "Sagemaker":
        '''(experimental) Grants permission to succeed a pending callback step.

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_SendPipelineExecutionStepSuccess.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toSendPipelineExecutionStepSuccess", []))

    @jsii.member(jsii_name="toSendSharedModelEvent")
    def to_send_shared_model_event(self) -> "Sagemaker":
        '''(experimental) Grants permission to send a shared model event.

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/dg/canvas-collaborate-permissions.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toSendSharedModelEvent", []))

    @jsii.member(jsii_name="toStartEdgeDeploymentStage")
    def to_start_edge_deployment_stage(self) -> "Sagemaker":
        '''(experimental) Grants permission to start an edge deployment stage.

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_StartEdgeDeploymentStage.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toStartEdgeDeploymentStage", []))

    @jsii.member(jsii_name="toStartHumanLoop")
    def to_start_human_loop(self) -> "Sagemaker":
        '''(experimental) Grants permission to start a human loop.

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_StartHumanLoop.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toStartHumanLoop", []))

    @jsii.member(jsii_name="toStartInferenceExperiment")
    def to_start_inference_experiment(self) -> "Sagemaker":
        '''(experimental) Grants permission to start an inference experiment.

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_StartInferenceExperiment.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toStartInferenceExperiment", []))

    @jsii.member(jsii_name="toStartMonitoringSchedule")
    def to_start_monitoring_schedule(self) -> "Sagemaker":
        '''(experimental) Grants permission to start a monitoring schedule.

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_StartMonitoringSchedule.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toStartMonitoringSchedule", []))

    @jsii.member(jsii_name="toStartNotebookInstance")
    def to_start_notebook_instance(self) -> "Sagemaker":
        '''(experimental) Grants permission to start a notebook instance.

        This launches an EC2 instance with the latest version of the libraries and attaches your EBS volume

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_StartNotebookInstance.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toStartNotebookInstance", []))

    @jsii.member(jsii_name="toStartPipelineExecution")
    def to_start_pipeline_execution(self) -> "Sagemaker":
        '''(experimental) Grants permission to start a pipeline execution.

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_StartPipelineExecution.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toStartPipelineExecution", []))

    @jsii.member(jsii_name="toStopAutoMLJob")
    def to_stop_auto_ml_job(self) -> "Sagemaker":
        '''(experimental) Grants permission to stop a running AutoML job.

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_StopAutoMLJob.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toStopAutoMLJob", []))

    @jsii.member(jsii_name="toStopCompilationJob")
    def to_stop_compilation_job(self) -> "Sagemaker":
        '''(experimental) Grants permission to stop a compilation job.

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_StopCompilationJob.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toStopCompilationJob", []))

    @jsii.member(jsii_name="toStopEdgeDeploymentStage")
    def to_stop_edge_deployment_stage(self) -> "Sagemaker":
        '''(experimental) Grants permission to stop an edge deployment stage.

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_StopEdgeDeploymentStage.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toStopEdgeDeploymentStage", []))

    @jsii.member(jsii_name="toStopEdgePackagingJob")
    def to_stop_edge_packaging_job(self) -> "Sagemaker":
        '''(experimental) Grants permission to stop an edge packaging job.

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_StopEdgePackagingJob.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toStopEdgePackagingJob", []))

    @jsii.member(jsii_name="toStopHumanLoop")
    def to_stop_human_loop(self) -> "Sagemaker":
        '''(experimental) Grants permission to stop a specified human loop.

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_StopHumanLoop.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toStopHumanLoop", []))

    @jsii.member(jsii_name="toStopHyperParameterTuningJob")
    def to_stop_hyper_parameter_tuning_job(self) -> "Sagemaker":
        '''(experimental) Grants permission to stop a running hyper parameter tuning job create via the CreateHyperParameterTuningJob.

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_StopHyperParameterTuningJob.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toStopHyperParameterTuningJob", []))

    @jsii.member(jsii_name="toStopInferenceExperiment")
    def to_stop_inference_experiment(self) -> "Sagemaker":
        '''(experimental) Grants permission to stop an inference experiment.

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_StopInferenceExperiment.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toStopInferenceExperiment", []))

    @jsii.member(jsii_name="toStopInferenceRecommendationsJob")
    def to_stop_inference_recommendations_job(self) -> "Sagemaker":
        '''(experimental) Grants permission to stop an inference recommendations job.

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_StopInferenceRecommendationsJob.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toStopInferenceRecommendationsJob", []))

    @jsii.member(jsii_name="toStopLabelingJob")
    def to_stop_labeling_job(self) -> "Sagemaker":
        '''(experimental) Grants permission to stop a labeling job. Any labels already generated will be exported before stopping.

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_StopLabelingJob.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toStopLabelingJob", []))

    @jsii.member(jsii_name="toStopMonitoringSchedule")
    def to_stop_monitoring_schedule(self) -> "Sagemaker":
        '''(experimental) Grants permission to stop a monitoring schedule.

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_StopMonitoringSchedule.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toStopMonitoringSchedule", []))

    @jsii.member(jsii_name="toStopNotebookInstance")
    def to_stop_notebook_instance(self) -> "Sagemaker":
        '''(experimental) Grants permission to stop a notebook instance.

        This terminates the EC2 instance. Before terminating the instance, Amazon SageMaker disconnects the EBS volume from it. Amazon SageMaker preserves the EBS volume

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_StopNotebookInstance.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toStopNotebookInstance", []))

    @jsii.member(jsii_name="toStopPipelineExecution")
    def to_stop_pipeline_execution(self) -> "Sagemaker":
        '''(experimental) Grants permission to stop a pipeline execution.

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_StopPipelineExecution.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toStopPipelineExecution", []))

    @jsii.member(jsii_name="toStopProcessingJob")
    def to_stop_processing_job(self) -> "Sagemaker":
        '''(experimental) Grants permission to stop a processing job.

        To stop a job, Amazon SageMaker sends the algorithm the SIGTERM signal, which delays job termination for 120 seconds

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_StopProcessingJob.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toStopProcessingJob", []))

    @jsii.member(jsii_name="toStopTrainingJob")
    def to_stop_training_job(self) -> "Sagemaker":
        '''(experimental) Grants permission to stop a training job.

        To stop a job, Amazon SageMaker sends the algorithm the SIGTERM signal, which delays job termination for 120 seconds

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_StopTrainingJob.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toStopTrainingJob", []))

    @jsii.member(jsii_name="toStopTransformJob")
    def to_stop_transform_job(self) -> "Sagemaker":
        '''(experimental) Grants permission to stop a transform job.

        When Amazon SageMaker receives a StopTransformJob request, the status of the job changes to Stopping. After Amazon SageMaker stops the job, the status is set to Stopped

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_StopTransformJob.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toStopTransformJob", []))

    @jsii.member(jsii_name="toUpdateAction")
    def to_update_action(self) -> "Sagemaker":
        '''(experimental) Grants permission to update an action.

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_UpdateAction.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toUpdateAction", []))

    @jsii.member(jsii_name="toUpdateAppImageConfig")
    def to_update_app_image_config(self) -> "Sagemaker":
        '''(experimental) Grants permission to update an AppImageConfig.

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_UpdateAppImageConfig.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toUpdateAppImageConfig", []))

    @jsii.member(jsii_name="toUpdateArtifact")
    def to_update_artifact(self) -> "Sagemaker":
        '''(experimental) Grants permission to update an artifact.

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_UpdateArtifact.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toUpdateArtifact", []))

    @jsii.member(jsii_name="toUpdateCodeRepository")
    def to_update_code_repository(self) -> "Sagemaker":
        '''(experimental) Grants permission to update a CodeRepository.

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_UpdateCodeRepository.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toUpdateCodeRepository", []))

    @jsii.member(jsii_name="toUpdateContext")
    def to_update_context(self) -> "Sagemaker":
        '''(experimental) Grants permission to update a context.

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_UpdateContext.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toUpdateContext", []))

    @jsii.member(jsii_name="toUpdateDeviceFleet")
    def to_update_device_fleet(self) -> "Sagemaker":
        '''(experimental) Grants permission to update a device fleet.

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_UpdateDeviceFleet.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toUpdateDeviceFleet", []))

    @jsii.member(jsii_name="toUpdateDevices")
    def to_update_devices(self) -> "Sagemaker":
        '''(experimental) Grants permission to update a set of devices.

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_UpdateDevices.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toUpdateDevices", []))

    @jsii.member(jsii_name="toUpdateDomain")
    def to_update_domain(self) -> "Sagemaker":
        '''(experimental) Grants permission to update a Domain.

        Access Level: Write

        Possible conditions:

        - .ifVpcSecurityGroupIds()
        - .ifInstanceTypes()
        - .ifDomainSharingOutputKmsKey()
        - .ifImageArns()
        - .ifImageVersionArns()

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_UpdateDomain.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toUpdateDomain", []))

    @jsii.member(jsii_name="toUpdateEndpoint")
    def to_update_endpoint(self) -> "Sagemaker":
        '''(experimental) Grants permission to update an endpoint to use the endpoint configuration specified in the request.

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_UpdateEndpoint.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toUpdateEndpoint", []))

    @jsii.member(jsii_name="toUpdateEndpointWeightsAndCapacities")
    def to_update_endpoint_weights_and_capacities(self) -> "Sagemaker":
        '''(experimental) Grants permission to update variant weight, capacity, or both of one or more variants associated with an endpoint.

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_UpdateEndpointWeightsAndCapacities.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toUpdateEndpointWeightsAndCapacities", []))

    @jsii.member(jsii_name="toUpdateExperiment")
    def to_update_experiment(self) -> "Sagemaker":
        '''(experimental) Grants permission to update an experiment.

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_UpdateExperiment.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toUpdateExperiment", []))

    @jsii.member(jsii_name="toUpdateFeatureGroup")
    def to_update_feature_group(self) -> "Sagemaker":
        '''(experimental) Grants permission to update a feature group.

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_UpdateFeatureGroup.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toUpdateFeatureGroup", []))

    @jsii.member(jsii_name="toUpdateFeatureMetadata")
    def to_update_feature_metadata(self) -> "Sagemaker":
        '''(experimental) Grants permission to update a feature metadata.

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_UpdateFeatureMetadata.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toUpdateFeatureMetadata", []))

    @jsii.member(jsii_name="toUpdateHub")
    def to_update_hub(self) -> "Sagemaker":
        '''(experimental) Grants permission to update hubs.

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_UpdateHub.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toUpdateHub", []))

    @jsii.member(jsii_name="toUpdateImage")
    def to_update_image(self) -> "Sagemaker":
        '''(experimental) Grants permission to update the properties of a SageMaker Image.

        Access Level: Write

        Dependent actions:

        - iam:PassRole

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_UpdateImage.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toUpdateImage", []))

    @jsii.member(jsii_name="toUpdateInferenceExperiment")
    def to_update_inference_experiment(self) -> "Sagemaker":
        '''(experimental) Grants permission to update an inference experiment.

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_UpdateInferenceExperiment.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toUpdateInferenceExperiment", []))

    @jsii.member(jsii_name="toUpdateModelCard")
    def to_update_model_card(self) -> "Sagemaker":
        '''(experimental) Grants permission to update a model card.

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_UpdateModelCard.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toUpdateModelCard", []))

    @jsii.member(jsii_name="toUpdateModelPackage")
    def to_update_model_package(self) -> "Sagemaker":
        '''(experimental) Grants permission to update a ModelPackage.

        Access Level: Write

        Possible conditions:

        - .ifModelApprovalStatus()
        - .ifCustomerMetadataProperties()
        - .ifCustomerMetadataPropertiesToRemove()

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_UpdateModelPackage.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toUpdateModelPackage", []))

    @jsii.member(jsii_name="toUpdateMonitoringAlert")
    def to_update_monitoring_alert(self) -> "Sagemaker":
        '''(experimental) Grants permission to update a monitoring alert.

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_UpdateMonitoringAlert.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toUpdateMonitoringAlert", []))

    @jsii.member(jsii_name="toUpdateMonitoringSchedule")
    def to_update_monitoring_schedule(self) -> "Sagemaker":
        '''(experimental) Grants permission to update a monitoring schedule.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifInstanceTypes()
        - .ifMaxRuntimeInSeconds()
        - .ifNetworkIsolation()
        - .ifOutputKmsKey()
        - .ifVolumeKmsKey()
        - .ifVpcSecurityGroupIds()
        - .ifVpcSubnets()
        - .ifInterContainerTrafficEncryption()

        Dependent actions:

        - iam:PassRole

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_UpdateMonitoringSchedule.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toUpdateMonitoringSchedule", []))

    @jsii.member(jsii_name="toUpdateNotebookInstance")
    def to_update_notebook_instance(self) -> "Sagemaker":
        '''(experimental) Grants permission to update a notebook instance.

        Notebook instance updates include upgrading or downgrading the EC2 instance used for your notebook instance to accommodate changes in your workload requirements

        Access Level: Write

        Possible conditions:

        - .ifAcceleratorTypes()
        - .ifInstanceTypes()
        - .ifMinimumInstanceMetadataServiceVersion()
        - .ifRootAccess()

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_UpdateNotebookInstance.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toUpdateNotebookInstance", []))

    @jsii.member(jsii_name="toUpdateNotebookInstanceLifecycleConfig")
    def to_update_notebook_instance_lifecycle_config(self) -> "Sagemaker":
        '''(experimental) Grants permission to updates a notebook instance lifecycle configuration created with the CreateNotebookInstanceLifecycleConfig API.

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_UpdateNotebookInstanceLifecycleConfig.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toUpdateNotebookInstanceLifecycleConfig", []))

    @jsii.member(jsii_name="toUpdatePipeline")
    def to_update_pipeline(self) -> "Sagemaker":
        '''(experimental) Grants permission to update a pipeline.

        Access Level: Write

        Dependent actions:

        - iam:PassRole

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_UpdatePipeline.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toUpdatePipeline", []))

    @jsii.member(jsii_name="toUpdatePipelineExecution")
    def to_update_pipeline_execution(self) -> "Sagemaker":
        '''(experimental) Grants permission to update a pipeline execution.

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_UpdatePipelineExecution.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toUpdatePipelineExecution", []))

    @jsii.member(jsii_name="toUpdateProject")
    def to_update_project(self) -> "Sagemaker":
        '''(experimental) Grants permission to update a Project.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_UpdateProject.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toUpdateProject", []))

    @jsii.member(jsii_name="toUpdateSharedModel")
    def to_update_shared_model(self) -> "Sagemaker":
        '''(experimental) Grants permission to update a shared model.

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/dg/canvas-collaborate-permissions.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toUpdateSharedModel", []))

    @jsii.member(jsii_name="toUpdateSpace")
    def to_update_space(self) -> "Sagemaker":
        '''(experimental) Grants permission to update a Space.

        Access Level: Write

        Possible conditions:

        - .ifInstanceTypes()
        - .ifImageArns()
        - .ifImageVersionArns()

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_UpdateSpace.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toUpdateSpace", []))

    @jsii.member(jsii_name="toUpdateTrainingJob")
    def to_update_training_job(self) -> "Sagemaker":
        '''(experimental) Grants permission to update a training job.

        Access Level: Write

        Possible conditions:

        - .ifInstanceTypes()
        - .ifKeepAlivePeriod()

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_UpdateTrainingJob.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toUpdateTrainingJob", []))

    @jsii.member(jsii_name="toUpdateTrial")
    def to_update_trial(self) -> "Sagemaker":
        '''(experimental) Grants permission to update a trial.

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_UpdateTrial.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toUpdateTrial", []))

    @jsii.member(jsii_name="toUpdateTrialComponent")
    def to_update_trial_component(self) -> "Sagemaker":
        '''(experimental) Grants permission to update a trial component.

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_UpdateTrialComponent.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toUpdateTrialComponent", []))

    @jsii.member(jsii_name="toUpdateUserProfile")
    def to_update_user_profile(self) -> "Sagemaker":
        '''(experimental) Grants permission to update a UserProfile.

        Access Level: Write

        Possible conditions:

        - .ifInstanceTypes()
        - .ifVpcSecurityGroupIds()
        - .ifInstanceTypes()
        - .ifDomainSharingOutputKmsKey()
        - .ifImageArns()
        - .ifImageVersionArns()

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_UpdateUserProfile.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toUpdateUserProfile", []))

    @jsii.member(jsii_name="toUpdateWorkforce")
    def to_update_workforce(self) -> "Sagemaker":
        '''(experimental) Grants permission to update a workforce.

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_UpdateWorkforce.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toUpdateWorkforce", []))

    @jsii.member(jsii_name="toUpdateWorkteam")
    def to_update_workteam(self) -> "Sagemaker":
        '''(experimental) Grants permission to update a workteam.

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_UpdateWorkteam.html

        :stability: experimental
        '''
        return typing.cast("Sagemaker", jsii.invoke(self, "toUpdateWorkteam", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2e9cc9da2a9f159dad2fb982fe34b44e3a44224595f78a65f910456f64d1ea10)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d97a437b504b9125885c18e92a91c15be1434082afbcf19472df51280ce2a5b8)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class SagemakerGeospatial(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.SagemakerGeospatial",
):
    '''(experimental) Statement provider for service `sagemaker-geospatial <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonsagemakergeospatialcapabilities.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `sagemaker-geospatial <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonsagemakergeospatialcapabilities.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onEarthObservationJob")
    def on_earth_observation_job(
        self,
        job_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "SagemakerGeospatial":
        '''(experimental) Adds a resource of type EarthObservationJob to the statement.

        https://docs.aws.amazon.com/sagemaker/latest/dg/geospatial-eoj.html

        :param job_id: - Identifier for the jobID.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__90c3d0b7f40cedfcfc946371be29a5acd76a8136552d1dfd22121b507d7c75bf)
            check_type(argname="argument job_id", value=job_id, expected_type=type_hints["job_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("SagemakerGeospatial", jsii.invoke(self, "onEarthObservationJob", [job_id, account, region, partition]))

    @jsii.member(jsii_name="onRasterDataCollection")
    def on_raster_data_collection(
        self,
        collection_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "SagemakerGeospatial":
        '''(experimental) Adds a resource of type RasterDataCollection to the statement.

        https://docs.aws.amazon.com/sagemaker/latest/dg/geospatial-rdc.html

        :param collection_id: - Identifier for the collectionID.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9f2d0c6720945c0fcf7ec6fa7d0eb30384b7e5f6829922c162cbcd931d806e2a)
            check_type(argname="argument collection_id", value=collection_id, expected_type=type_hints["collection_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("SagemakerGeospatial", jsii.invoke(self, "onRasterDataCollection", [collection_id, account, region, partition]))

    @jsii.member(jsii_name="onVectorEnrichmentJob")
    def on_vector_enrichment_job(
        self,
        job_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "SagemakerGeospatial":
        '''(experimental) Adds a resource of type VectorEnrichmentJob to the statement.

        https://docs.aws.amazon.com/sagemaker/latest/dg/geospatial-vej.html

        :param job_id: - Identifier for the jobID.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7d4e91a3260ea46965e622c9a89ec6aed3ff4d37babb0f5cfd73c33072346a3a)
            check_type(argname="argument job_id", value=job_id, expected_type=type_hints["job_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("SagemakerGeospatial", jsii.invoke(self, "onVectorEnrichmentJob", [job_id, account, region, partition]))

    @jsii.member(jsii_name="toDeleteEarthObservationJob")
    def to_delete_earth_observation_job(self) -> "SagemakerGeospatial":
        '''(experimental) Grants permission to the DeleteEarthObservationJob operation which deletes an existing earth observation job.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_geospatial_DeleteEarthObservationJob.html

        :stability: experimental
        '''
        return typing.cast("SagemakerGeospatial", jsii.invoke(self, "toDeleteEarthObservationJob", []))

    @jsii.member(jsii_name="toDeleteVectorEnrichmentJob")
    def to_delete_vector_enrichment_job(self) -> "SagemakerGeospatial":
        '''(experimental) Grants permission to the DeleteVectorEnrichmentJob operation which deletes an existing vector enrichment job.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_geospatial_DeleteVectorEnrichmentJob.html

        :stability: experimental
        '''
        return typing.cast("SagemakerGeospatial", jsii.invoke(self, "toDeleteVectorEnrichmentJob", []))

    @jsii.member(jsii_name="toExportEarthObservationJob")
    def to_export_earth_observation_job(self) -> "SagemakerGeospatial":
        '''(experimental) Grants permission to copy results of an earth observation job to an S3 location.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_geospatial_ExportEarthObservationJob.html

        :stability: experimental
        '''
        return typing.cast("SagemakerGeospatial", jsii.invoke(self, "toExportEarthObservationJob", []))

    @jsii.member(jsii_name="toExportVectorEnrichmentJob")
    def to_export_vector_enrichment_job(self) -> "SagemakerGeospatial":
        '''(experimental) Grants permission to copy results of an VectorEnrichmentJob to an S3 location.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_geospatial_ExportVectorEnrichmentJob.html

        :stability: experimental
        '''
        return typing.cast("SagemakerGeospatial", jsii.invoke(self, "toExportVectorEnrichmentJob", []))

    @jsii.member(jsii_name="toGetEarthObservationJob")
    def to_get_earth_observation_job(self) -> "SagemakerGeospatial":
        '''(experimental) Grants permission to return details about the earth observation job.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_geospatial_GetEarthObservationJob.html

        :stability: experimental
        '''
        return typing.cast("SagemakerGeospatial", jsii.invoke(self, "toGetEarthObservationJob", []))

    @jsii.member(jsii_name="toGetRasterDataCollection")
    def to_get_raster_data_collection(self) -> "SagemakerGeospatial":
        '''(experimental) Grants permission to return details about the raster data collection.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_geospatial_GetRasterDataCollection.html

        :stability: experimental
        '''
        return typing.cast("SagemakerGeospatial", jsii.invoke(self, "toGetRasterDataCollection", []))

    @jsii.member(jsii_name="toGetTile")
    def to_get_tile(self) -> "SagemakerGeospatial":
        '''(experimental) Grants permission to get the tile of an earth observation job.

        Access Level: Read

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_geospatial_GetTile.html

        :stability: experimental
        '''
        return typing.cast("SagemakerGeospatial", jsii.invoke(self, "toGetTile", []))

    @jsii.member(jsii_name="toGetVectorEnrichmentJob")
    def to_get_vector_enrichment_job(self) -> "SagemakerGeospatial":
        '''(experimental) Grants permission to return details about the vector enrichment job.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_geospatial_GetVectorEnrichmentJob.html

        :stability: experimental
        '''
        return typing.cast("SagemakerGeospatial", jsii.invoke(self, "toGetVectorEnrichmentJob", []))

    @jsii.member(jsii_name="toListEarthObservationJobs")
    def to_list_earth_observation_jobs(self) -> "SagemakerGeospatial":
        '''(experimental) Grants permission to return an array of earth observation jobs associated with the current account.

        Access Level: List

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_geospatial_ListEarthObservationJobs.html

        :stability: experimental
        '''
        return typing.cast("SagemakerGeospatial", jsii.invoke(self, "toListEarthObservationJobs", []))

    @jsii.member(jsii_name="toListRasterDataCollections")
    def to_list_raster_data_collections(self) -> "SagemakerGeospatial":
        '''(experimental) Grants permission to return an array of aster data collections associated with the given model name.

        Access Level: List

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_geospatial_ListRasterDataCollections.html

        :stability: experimental
        '''
        return typing.cast("SagemakerGeospatial", jsii.invoke(self, "toListRasterDataCollections", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "SagemakerGeospatial":
        '''(experimental) Grants permission to lists tag for an SageMaker Geospatial resource.

        Access Level: List

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_geospatial_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("SagemakerGeospatial", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toListVectorEnrichmentJobs")
    def to_list_vector_enrichment_jobs(self) -> "SagemakerGeospatial":
        '''(experimental) Grants permission to return an array of vector enrichment jobs associated with the current account.

        Access Level: List

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_geospatial_ListVectorEnrichmentJobs.html

        :stability: experimental
        '''
        return typing.cast("SagemakerGeospatial", jsii.invoke(self, "toListVectorEnrichmentJobs", []))

    @jsii.member(jsii_name="toSearchRasterDataCollection")
    def to_search_raster_data_collection(self) -> "SagemakerGeospatial":
        '''(experimental) Grants permission to query raster data collections.

        Access Level: Read

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_geospatial_SearchRasterDataCollection.html

        :stability: experimental
        '''
        return typing.cast("SagemakerGeospatial", jsii.invoke(self, "toSearchRasterDataCollection", []))

    @jsii.member(jsii_name="toStartEarthObservationJob")
    def to_start_earth_observation_job(self) -> "SagemakerGeospatial":
        '''(experimental) Grants permission to the StartEarthObservationJob operation which starts a new earth observation job to your account.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_geospatial_StartEarthObservationJob.html

        :stability: experimental
        '''
        return typing.cast("SagemakerGeospatial", jsii.invoke(self, "toStartEarthObservationJob", []))

    @jsii.member(jsii_name="toStartVectorEnrichmentJob")
    def to_start_vector_enrichment_job(self) -> "SagemakerGeospatial":
        '''(experimental) Grants permission to the StartVectorEnrichmentJob operation which starts a new vector enrichment job to your account.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_geospatial_StartVectorEnrichmentJob.html

        :stability: experimental
        '''
        return typing.cast("SagemakerGeospatial", jsii.invoke(self, "toStartVectorEnrichmentJob", []))

    @jsii.member(jsii_name="toStopEarthObservationJob")
    def to_stop_earth_observation_job(self) -> "SagemakerGeospatial":
        '''(experimental) Grants permission to the StopEarthObservationJob operation which stops an existing earth observation job.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_geospatial_StopEarthObservationJob.html

        :stability: experimental
        '''
        return typing.cast("SagemakerGeospatial", jsii.invoke(self, "toStopEarthObservationJob", []))

    @jsii.member(jsii_name="toStopVectorEnrichmentJob")
    def to_stop_vector_enrichment_job(self) -> "SagemakerGeospatial":
        '''(experimental) Grants permission to the StopVectorEnrichmentJob operation which stops an existing vector enrichment job.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_geospatial_StopVectorEnrichmentJob.html

        :stability: experimental
        '''
        return typing.cast("SagemakerGeospatial", jsii.invoke(self, "toStopVectorEnrichmentJob", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "SagemakerGeospatial":
        '''(experimental) Grants permission to tag an SageMaker Geospatial resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()
        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_geospatial_TagResource.html

        :stability: experimental
        '''
        return typing.cast("SagemakerGeospatial", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "SagemakerGeospatial":
        '''(experimental) Grants permission to untag an SageMaker Geospatial resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_geospatial_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("SagemakerGeospatial", jsii.invoke(self, "toUntagResource", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8e88e33748f469864d57bbbf1d773433f81fa9f5be5678b68aa4c70496d83421)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__89e8d149a11211d58597069623e6e3187bfd89347e7fe46cc61bef3c7e99c9e0)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class SagemakerGroundtruthSynthetic(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.SagemakerGroundtruthSynthetic",
):
    '''(experimental) Statement provider for service `sagemaker-groundtruth-synthetic <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonsagemakergroundtruthsynthetic.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `sagemaker-groundtruth-synthetic <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonsagemakergroundtruthsynthetic.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="toCreateProject")
    def to_create_project(self) -> "SagemakerGroundtruthSynthetic":
        '''(experimental) Grants permission to create a project.

        Access Level: Write

        :stability: experimental
        '''
        return typing.cast("SagemakerGroundtruthSynthetic", jsii.invoke(self, "toCreateProject", []))

    @jsii.member(jsii_name="toDeleteProject")
    def to_delete_project(self) -> "SagemakerGroundtruthSynthetic":
        '''(experimental) Grants permission to delete a project.

        Access Level: Write

        :stability: experimental
        '''
        return typing.cast("SagemakerGroundtruthSynthetic", jsii.invoke(self, "toDeleteProject", []))

    @jsii.member(jsii_name="toGetAccountDetails")
    def to_get_account_details(self) -> "SagemakerGroundtruthSynthetic":
        '''(experimental) Grants permission to get account details.

        Access Level: Read

        :stability: experimental
        '''
        return typing.cast("SagemakerGroundtruthSynthetic", jsii.invoke(self, "toGetAccountDetails", []))

    @jsii.member(jsii_name="toGetBatch")
    def to_get_batch(self) -> "SagemakerGroundtruthSynthetic":
        '''(experimental) Grants permission to get a batch.

        Access Level: Read

        :stability: experimental
        '''
        return typing.cast("SagemakerGroundtruthSynthetic", jsii.invoke(self, "toGetBatch", []))

    @jsii.member(jsii_name="toGetProject")
    def to_get_project(self) -> "SagemakerGroundtruthSynthetic":
        '''(experimental) Grants permission to get a project.

        Access Level: Read

        :stability: experimental
        '''
        return typing.cast("SagemakerGroundtruthSynthetic", jsii.invoke(self, "toGetProject", []))

    @jsii.member(jsii_name="toListBatchDataTransfers")
    def to_list_batch_data_transfers(self) -> "SagemakerGroundtruthSynthetic":
        '''(experimental) Grants permission to list batch data transfers.

        Access Level: List

        :stability: experimental
        '''
        return typing.cast("SagemakerGroundtruthSynthetic", jsii.invoke(self, "toListBatchDataTransfers", []))

    @jsii.member(jsii_name="toListBatchSummaries")
    def to_list_batch_summaries(self) -> "SagemakerGroundtruthSynthetic":
        '''(experimental) Grants permission to list batch summaries.

        Access Level: List

        :stability: experimental
        '''
        return typing.cast("SagemakerGroundtruthSynthetic", jsii.invoke(self, "toListBatchSummaries", []))

    @jsii.member(jsii_name="toListProjectDataTransfers")
    def to_list_project_data_transfers(self) -> "SagemakerGroundtruthSynthetic":
        '''(experimental) Grants permission to list project data transfers.

        Access Level: List

        :stability: experimental
        '''
        return typing.cast("SagemakerGroundtruthSynthetic", jsii.invoke(self, "toListProjectDataTransfers", []))

    @jsii.member(jsii_name="toListProjectSummaries")
    def to_list_project_summaries(self) -> "SagemakerGroundtruthSynthetic":
        '''(experimental) Grants permission to list project summaries.

        Access Level: List

        :stability: experimental
        '''
        return typing.cast("SagemakerGroundtruthSynthetic", jsii.invoke(self, "toListProjectSummaries", []))

    @jsii.member(jsii_name="toStartBatchDataTransfer")
    def to_start_batch_data_transfer(self) -> "SagemakerGroundtruthSynthetic":
        '''(experimental) Grants permission to start a batch data transfer.

        Access Level: Write

        :stability: experimental
        '''
        return typing.cast("SagemakerGroundtruthSynthetic", jsii.invoke(self, "toStartBatchDataTransfer", []))

    @jsii.member(jsii_name="toStartProjectDataTransfer")
    def to_start_project_data_transfer(self) -> "SagemakerGroundtruthSynthetic":
        '''(experimental) Grants permission to start a project data transfer.

        Access Level: Write

        :stability: experimental
        '''
        return typing.cast("SagemakerGroundtruthSynthetic", jsii.invoke(self, "toStartProjectDataTransfer", []))

    @jsii.member(jsii_name="toUpdateBatch")
    def to_update_batch(self) -> "SagemakerGroundtruthSynthetic":
        '''(experimental) Grants permission to update a batch.

        Access Level: Write

        :stability: experimental
        '''
        return typing.cast("SagemakerGroundtruthSynthetic", jsii.invoke(self, "toUpdateBatch", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1593ac861b22cbfa5de34152b29f0f9e706e62191aa652c0c2739526ac5ecfb8)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6d80e5d93ffb82a3ac423a35218777a91cf5364e7310083e710f13802e7427b5)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Savingsplans(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Savingsplans",
):
    '''(experimental) Statement provider for service `savingsplans <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awssavingsplans.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `savingsplans <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awssavingsplans.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onSavingsplan")
    def on_savingsplan(
        self,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Savingsplans":
        '''(experimental) Adds a resource of type savingsplan to the statement.

        https://docs.aws.amazon.com/savingsplans/latest/userguide/API_SavingsPlan.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__69083fc4469a16a09602943aacfd365eeb8cf2eaa571812f037257dfdec929b4)
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Savingsplans", jsii.invoke(self, "onSavingsplan", [resource_id, account, partition]))

    @jsii.member(jsii_name="toCreateSavingsPlan")
    def to_create_savings_plan(self) -> "Savingsplans":
        '''(experimental) Grants permission to create a savings plan.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/savingsplans/latest/APIReference/API_CreateSavingsPlan.html

        :stability: experimental
        '''
        return typing.cast("Savingsplans", jsii.invoke(self, "toCreateSavingsPlan", []))

    @jsii.member(jsii_name="toDeleteQueuedSavingsPlan")
    def to_delete_queued_savings_plan(self) -> "Savingsplans":
        '''(experimental) Grants permission to delete the queued savings plan associated with customers account.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/savingsplans/latest/APIReference/API_DeleteQueuedSavingsPlan.html

        :stability: experimental
        '''
        return typing.cast("Savingsplans", jsii.invoke(self, "toDeleteQueuedSavingsPlan", []))

    @jsii.member(jsii_name="toDescribeSavingsPlanRates")
    def to_describe_savings_plan_rates(self) -> "Savingsplans":
        '''(experimental) Grants permission to describe the rates associated with customers savings plan.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/savingsplans/latest/APIReference/API_DescribeSavingsPlanRates.html

        :stability: experimental
        '''
        return typing.cast("Savingsplans", jsii.invoke(self, "toDescribeSavingsPlanRates", []))

    @jsii.member(jsii_name="toDescribeSavingsPlans")
    def to_describe_savings_plans(self) -> "Savingsplans":
        '''(experimental) Grants permission to describe the savings plans associated with customers account.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/savingsplans/latest/APIReference/API_DescribeSavingsPlans.html

        :stability: experimental
        '''
        return typing.cast("Savingsplans", jsii.invoke(self, "toDescribeSavingsPlans", []))

    @jsii.member(jsii_name="toDescribeSavingsPlansOfferingRates")
    def to_describe_savings_plans_offering_rates(self) -> "Savingsplans":
        '''(experimental) Grants permission to describe the rates assciated with savings plans offerings.

        Access Level: Read

        https://docs.aws.amazon.com/savingsplans/latest/APIReference/API_DescribeSavingsPlansOfferingRates.html

        :stability: experimental
        '''
        return typing.cast("Savingsplans", jsii.invoke(self, "toDescribeSavingsPlansOfferingRates", []))

    @jsii.member(jsii_name="toDescribeSavingsPlansOfferings")
    def to_describe_savings_plans_offerings(self) -> "Savingsplans":
        '''(experimental) Grants permission to describe the savings plans offerings that customer is eligible to purchase.

        Access Level: Read

        https://docs.aws.amazon.com/savingsplans/latest/APIReference/API_DescribeSavingsPlansOfferings.html

        :stability: experimental
        '''
        return typing.cast("Savingsplans", jsii.invoke(self, "toDescribeSavingsPlansOfferings", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Savingsplans":
        '''(experimental) Grants permission to list tags for a savings plan.

        Access Level: List

        https://docs.aws.amazon.com/savingsplans/latest/APIReference/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("Savingsplans", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Savingsplans":
        '''(experimental) Grants permission to tag a savings plan.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/savingsplans/latest/APIReference/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("Savingsplans", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Savingsplans":
        '''(experimental) Grants permission to untag a savings plan.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/savingsplans/latest/APIReference/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("Savingsplans", jsii.invoke(self, "toUntagResource", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__aba649df8592e3f4bef0ea3f7dbee1c5213e644dff4924c853b1048f20c974a9)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__67b1e3526e8b5d84d784dbe52bbda2fc0c830c21fa1d8f94d5cd578ebcee5140)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Scheduler(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Scheduler",
):
    '''(experimental) Statement provider for service `scheduler <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazoneventbridgescheduler.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `scheduler <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazoneventbridgescheduler.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onSchedule")
    def on_schedule(
        self,
        group_name: builtins.str,
        schedule_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Scheduler":
        '''(experimental) Adds a resource of type schedule to the statement.

        https://docs.aws.amazon.com/scheduler/latest/UserGuide/managing-schedule.html

        :param group_name: - Identifier for the groupName.
        :param schedule_name: - Identifier for the scheduleName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__64907ad737043d425b8023f44b4e7a777098ca9cf0154c7d063089b59320187c)
            check_type(argname="argument group_name", value=group_name, expected_type=type_hints["group_name"])
            check_type(argname="argument schedule_name", value=schedule_name, expected_type=type_hints["schedule_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Scheduler", jsii.invoke(self, "onSchedule", [group_name, schedule_name, account, region, partition]))

    @jsii.member(jsii_name="onScheduleGroup")
    def on_schedule_group(
        self,
        group_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Scheduler":
        '''(experimental) Adds a resource of type schedule-group to the statement.

        https://docs.aws.amazon.com/scheduler/latest/UserGuide/managing-schedule-group.html

        :param group_name: - Identifier for the groupName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e81efaf946cc5df0932cac7305e44d89af63f9769690c382cf32b956c9e99baf)
            check_type(argname="argument group_name", value=group_name, expected_type=type_hints["group_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Scheduler", jsii.invoke(self, "onScheduleGroup", [group_name, account, region, partition]))

    @jsii.member(jsii_name="toCreateSchedule")
    def to_create_schedule(self) -> "Scheduler":
        '''(experimental) Grants permission to create an Amazon EventBridge Scheduler schedule.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/scheduler/latest/APIReference/API_CreateSchedule.html

        :stability: experimental
        '''
        return typing.cast("Scheduler", jsii.invoke(self, "toCreateSchedule", []))

    @jsii.member(jsii_name="toCreateScheduleGroup")
    def to_create_schedule_group(self) -> "Scheduler":
        '''(experimental) Grants permission to create an Amazon EventBridge Scheduler schedule group.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/scheduler/latest/APIReference/API_CreateScheduleGroup.html

        :stability: experimental
        '''
        return typing.cast("Scheduler", jsii.invoke(self, "toCreateScheduleGroup", []))

    @jsii.member(jsii_name="toDeleteSchedule")
    def to_delete_schedule(self) -> "Scheduler":
        '''(experimental) Grants permission to delete an Amazon EventBridge Scheduler schedule.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/scheduler/latest/APIReference/API_DeleteSchedule.html

        :stability: experimental
        '''
        return typing.cast("Scheduler", jsii.invoke(self, "toDeleteSchedule", []))

    @jsii.member(jsii_name="toDeleteScheduleGroup")
    def to_delete_schedule_group(self) -> "Scheduler":
        '''(experimental) Grants permission to delete an Amazon EventBridge Scheduler schedule group.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/scheduler/latest/APIReference/API_DeleteScheduleGroup.html

        :stability: experimental
        '''
        return typing.cast("Scheduler", jsii.invoke(self, "toDeleteScheduleGroup", []))

    @jsii.member(jsii_name="toGetSchedule")
    def to_get_schedule(self) -> "Scheduler":
        '''(experimental) Grants permission to view details about an Amazon EventBridge Scheduler schedule.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/scheduler/latest/APIReference/API_GetSchedule.html

        :stability: experimental
        '''
        return typing.cast("Scheduler", jsii.invoke(self, "toGetSchedule", []))

    @jsii.member(jsii_name="toGetScheduleGroup")
    def to_get_schedule_group(self) -> "Scheduler":
        '''(experimental) Grants permission to view details about an Amazon EventBridge Scheduler schedule group.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/scheduler/latest/APIReference/API_GetScheduleGroup.html

        :stability: experimental
        '''
        return typing.cast("Scheduler", jsii.invoke(self, "toGetScheduleGroup", []))

    @jsii.member(jsii_name="toListScheduleGroups")
    def to_list_schedule_groups(self) -> "Scheduler":
        '''(experimental) Grants permission to list the Amazon EventBridge Scheduler schedule groups in your account.

        Access Level: List

        https://docs.aws.amazon.com/scheduler/latest/APIReference/API_ListScheduleGroups.html

        :stability: experimental
        '''
        return typing.cast("Scheduler", jsii.invoke(self, "toListScheduleGroups", []))

    @jsii.member(jsii_name="toListSchedules")
    def to_list_schedules(self) -> "Scheduler":
        '''(experimental) Grants permission to list the Amazon EventBridge Scheduler schedules in your account.

        Access Level: List

        https://docs.aws.amazon.com/scheduler/latest/APIReference/API_ListSchedules.html

        :stability: experimental
        '''
        return typing.cast("Scheduler", jsii.invoke(self, "toListSchedules", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Scheduler":
        '''(experimental) Grants permission to lists tag for an Amazon EventBridge Scheduler resource.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/scheduler/latest/APIReference/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("Scheduler", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Scheduler":
        '''(experimental) Grants permission to tag an Amazon EventBridge Scheduler resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()
        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/scheduler/latest/APIReference/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("Scheduler", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Scheduler":
        '''(experimental) Grants permission to untag an Amazon EventBridge Scheduler resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/scheduler/latest/APIReference/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("Scheduler", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateSchedule")
    def to_update_schedule(self) -> "Scheduler":
        '''(experimental) Grants permission to modify an Amazon EventBridge Scheduler schedule.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/scheduler/latest/APIReference/API_UpdateSchedule.html

        :stability: experimental
        '''
        return typing.cast("Scheduler", jsii.invoke(self, "toUpdateSchedule", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__21c40e3265f8fea4ea846c87b1e6175b75495a3d2f8e526f40073ff6f66d4190)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d82a6ab5e16b218facda89b56cd693d246c97685b58afada3ceba8d0e3ec27c3)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Schemas(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Schemas",
):
    '''(experimental) Statement provider for service `schemas <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazoneventbridgeschemas.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `schemas <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazoneventbridgeschemas.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onDiscoverer")
    def on_discoverer(
        self,
        discoverer_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Schemas":
        '''(experimental) Adds a resource of type discoverer to the statement.

        https://docs.aws.amazon.com/eventbridge/latest/userguide/iam-identity-based-access-control-eventbridge.html

        :param discoverer_id: - Identifier for the discovererId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4c718f5f142a7d801122c3248d74697689f523a19231898c312f8d49a8473756)
            check_type(argname="argument discoverer_id", value=discoverer_id, expected_type=type_hints["discoverer_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Schemas", jsii.invoke(self, "onDiscoverer", [discoverer_id, account, region, partition]))

    @jsii.member(jsii_name="onRegistry")
    def on_registry(
        self,
        registry_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Schemas":
        '''(experimental) Adds a resource of type registry to the statement.

        https://docs.aws.amazon.com/eventbridge/latest/userguide/iam-identity-based-access-control-eventbridge.html

        :param registry_name: - Identifier for the registryName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2da95b0a92e58d70c7cf60ad603767002a9a371cb6db38e369da65a277391354)
            check_type(argname="argument registry_name", value=registry_name, expected_type=type_hints["registry_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Schemas", jsii.invoke(self, "onRegistry", [registry_name, account, region, partition]))

    @jsii.member(jsii_name="onSchema")
    def on_schema(
        self,
        registry_name: builtins.str,
        schema_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Schemas":
        '''(experimental) Adds a resource of type schema to the statement.

        https://docs.aws.amazon.com/eventbridge/latest/userguide/iam-identity-based-access-control-eventbridge.html

        :param registry_name: - Identifier for the registryName.
        :param schema_name: - Identifier for the schemaName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fa4597e43ec19df1890a80c0beeadc707742cd9ec7eeddbf1dfd98843917d86b)
            check_type(argname="argument registry_name", value=registry_name, expected_type=type_hints["registry_name"])
            check_type(argname="argument schema_name", value=schema_name, expected_type=type_hints["schema_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Schemas", jsii.invoke(self, "onSchema", [registry_name, schema_name, account, region, partition]))

    @jsii.member(jsii_name="toCreateDiscoverer")
    def to_create_discoverer(self) -> "Schemas":
        '''(experimental) Grants permission to create an event schema discoverer.

        Once created, your events will be automatically map into corresponding schema documents

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/eventbridge/latest/schema-reference/v1-discoverers-id-discovererid.html#CreateDiscoverer

        :stability: experimental
        '''
        return typing.cast("Schemas", jsii.invoke(self, "toCreateDiscoverer", []))

    @jsii.member(jsii_name="toCreateRegistry")
    def to_create_registry(self) -> "Schemas":
        '''(experimental) Grants permission to create a new schema registry in your account.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/eventbridge/latest/schema-reference/v1-registries-name-registryname.html#CreateRegistry

        :stability: experimental
        '''
        return typing.cast("Schemas", jsii.invoke(self, "toCreateRegistry", []))

    @jsii.member(jsii_name="toCreateSchema")
    def to_create_schema(self) -> "Schemas":
        '''(experimental) Grants permission to create a new schema in your account.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/eventbridge/latest/schema-reference/v1-registries-name-registryname-schemas-name-schemaname.html#CreateSchema

        :stability: experimental
        '''
        return typing.cast("Schemas", jsii.invoke(self, "toCreateSchema", []))

    @jsii.member(jsii_name="toDeleteDiscoverer")
    def to_delete_discoverer(self) -> "Schemas":
        '''(experimental) Grants permission to delete discoverer in your account.

        Access Level: Write

        https://docs.aws.amazon.com/eventbridge/latest/schema-reference/v1-discoverers-id-discovererid.html#DeleteDiscoverer

        :stability: experimental
        '''
        return typing.cast("Schemas", jsii.invoke(self, "toDeleteDiscoverer", []))

    @jsii.member(jsii_name="toDeleteRegistry")
    def to_delete_registry(self) -> "Schemas":
        '''(experimental) Grants permission to delete an existing registry in your account.

        Access Level: Write

        https://docs.aws.amazon.com/eventbridge/latest/schema-reference/v1-registries-name-registryname.html#DeleteRegistry

        :stability: experimental
        '''
        return typing.cast("Schemas", jsii.invoke(self, "toDeleteRegistry", []))

    @jsii.member(jsii_name="toDeleteResourcePolicy")
    def to_delete_resource_policy(self) -> "Schemas":
        '''(experimental) Grants permission to delete the resource-based policy attached to a given registry.

        Access Level: Write

        https://docs.aws.amazon.com/eventbridge/latest/schema-reference/v1-policy.html#DeleteResourcePolicy

        :stability: experimental
        '''
        return typing.cast("Schemas", jsii.invoke(self, "toDeleteResourcePolicy", []))

    @jsii.member(jsii_name="toDeleteSchema")
    def to_delete_schema(self) -> "Schemas":
        '''(experimental) Grants permission to delete an existing schema in your account.

        Access Level: Write

        https://docs.aws.amazon.com/eventbridge/latest/schema-reference/v1-registries-name-registryname-schemas-name-schemaname.html#DeleteSchema

        :stability: experimental
        '''
        return typing.cast("Schemas", jsii.invoke(self, "toDeleteSchema", []))

    @jsii.member(jsii_name="toDeleteSchemaVersion")
    def to_delete_schema_version(self) -> "Schemas":
        '''(experimental) Grants permission to delete a specific version of schema in your account.

        Access Level: Write

        https://docs.aws.amazon.com/eventbridge/latest/schema-reference/v1-registries-name-registryname-schemas-name-schemaname-version-schemaversion.html#DeleteSchemaVersion

        :stability: experimental
        '''
        return typing.cast("Schemas", jsii.invoke(self, "toDeleteSchemaVersion", []))

    @jsii.member(jsii_name="toDescribeCodeBinding")
    def to_describe_code_binding(self) -> "Schemas":
        '''(experimental) Grants permission to retrieve metadata for generated code for specific schema in your account.

        Access Level: Read

        https://docs.aws.amazon.com/eventbridge/latest/schema-reference/v1-registries-name-registryname-schemas-name-schemaname-language-language.html#DescribeCodeBinding

        :stability: experimental
        '''
        return typing.cast("Schemas", jsii.invoke(self, "toDescribeCodeBinding", []))

    @jsii.member(jsii_name="toDescribeDiscoverer")
    def to_describe_discoverer(self) -> "Schemas":
        '''(experimental) Grants permission to retrieve discoverer metadata in your account.

        Access Level: Read

        https://docs.aws.amazon.com/eventbridge/latest/schema-reference/v1-discoverers-id-discovererid.html#DescribeDiscoverer

        :stability: experimental
        '''
        return typing.cast("Schemas", jsii.invoke(self, "toDescribeDiscoverer", []))

    @jsii.member(jsii_name="toDescribeRegistry")
    def to_describe_registry(self) -> "Schemas":
        '''(experimental) Grants permission to describe an existing registry metadata in your account.

        Access Level: Read

        https://docs.aws.amazon.com/eventbridge/latest/schema-reference/v1-registries-name-registryname.html#DescribeRegistry

        :stability: experimental
        '''
        return typing.cast("Schemas", jsii.invoke(self, "toDescribeRegistry", []))

    @jsii.member(jsii_name="toDescribeSchema")
    def to_describe_schema(self) -> "Schemas":
        '''(experimental) Grants permission to retrieve an existing schema in your account.

        Access Level: Read

        https://docs.aws.amazon.com/eventbridge/latest/schema-reference/v1-registries-name-registryname-schemas-name-schemaname.html#DescribeSchema

        :stability: experimental
        '''
        return typing.cast("Schemas", jsii.invoke(self, "toDescribeSchema", []))

    @jsii.member(jsii_name="toExportSchema")
    def to_export_schema(self) -> "Schemas":
        '''(experimental) Grants permission to export the AWS registry or discovered schemas in OpenAPI 3 format to JSONSchema format.

        Access Level: Read

        https://docs.aws.amazon.com/eventbridge/latest/schema-reference/v1-policy.html#ExportSchema

        :stability: experimental
        '''
        return typing.cast("Schemas", jsii.invoke(self, "toExportSchema", []))

    @jsii.member(jsii_name="toGetCodeBindingSource")
    def to_get_code_binding_source(self) -> "Schemas":
        '''(experimental) Grants permission to retrieve metadata for generated code for specific schema in your account.

        Access Level: Read

        https://docs.aws.amazon.com/eventbridge/latest/schema-reference/v1-registries-name-registryname-schemas-name-schemaname-language-language-source.html#GetCodeBindingSource

        :stability: experimental
        '''
        return typing.cast("Schemas", jsii.invoke(self, "toGetCodeBindingSource", []))

    @jsii.member(jsii_name="toGetDiscoveredSchema")
    def to_get_discovered_schema(self) -> "Schemas":
        '''(experimental) Grants permission to retrieve a schema for the provided list of sample events.

        Access Level: Read

        https://docs.aws.amazon.com/eventbridge/latest/schema-reference/v1-discover.html#GetDiscoveredSchema

        :stability: experimental
        '''
        return typing.cast("Schemas", jsii.invoke(self, "toGetDiscoveredSchema", []))

    @jsii.member(jsii_name="toGetResourcePolicy")
    def to_get_resource_policy(self) -> "Schemas":
        '''(experimental) Grants permission to retrieve the resource-based policy attached to a given registry.

        Access Level: Read

        https://docs.aws.amazon.com/eventbridge/latest/schema-reference/v1-policy.html#GetResourcePolicy

        :stability: experimental
        '''
        return typing.cast("Schemas", jsii.invoke(self, "toGetResourcePolicy", []))

    @jsii.member(jsii_name="toListDiscoverers")
    def to_list_discoverers(self) -> "Schemas":
        '''(experimental) Grants permission to list all discoverers in your account.

        Access Level: List

        https://docs.aws.amazon.com/eventbridge/latest/schema-reference/v1-discoverers.html#ListDiscoverers

        :stability: experimental
        '''
        return typing.cast("Schemas", jsii.invoke(self, "toListDiscoverers", []))

    @jsii.member(jsii_name="toListRegistries")
    def to_list_registries(self) -> "Schemas":
        '''(experimental) Grants permission to list all registries in your account.

        Access Level: List

        https://docs.aws.amazon.com/eventbridge/latest/schema-reference/v1-registries.html#ListRegistries

        :stability: experimental
        '''
        return typing.cast("Schemas", jsii.invoke(self, "toListRegistries", []))

    @jsii.member(jsii_name="toListSchemas")
    def to_list_schemas(self) -> "Schemas":
        '''(experimental) Grants permission to list all schemas.

        Access Level: List

        https://docs.aws.amazon.com/eventbridge/latest/schema-reference/v1-registries-name-registryname-schemas.html#ListSchemas

        :stability: experimental
        '''
        return typing.cast("Schemas", jsii.invoke(self, "toListSchemas", []))

    @jsii.member(jsii_name="toListSchemaVersions")
    def to_list_schema_versions(self) -> "Schemas":
        '''(experimental) Grants permission to list all versions of a schema.

        Access Level: List

        https://docs.aws.amazon.com/eventbridge/latest/schema-reference/v1-registries-name-registryname-schemas-name-schemaname-versions.html#ListSchemaVersions

        :stability: experimental
        '''
        return typing.cast("Schemas", jsii.invoke(self, "toListSchemaVersions", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Schemas":
        '''(experimental) Grants permission to lists tags for a resource.

        Access Level: Read

        https://docs.aws.amazon.com/eventbridge/latest/schema-reference/tags-resource-arn.html#ListTagsForResource

        :stability: experimental
        '''
        return typing.cast("Schemas", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toPutCodeBinding")
    def to_put_code_binding(self) -> "Schemas":
        '''(experimental) Grants permission to generate code for specific schema in your account.

        Access Level: Write

        https://docs.aws.amazon.com/eventbridge/latest/schema-reference/v1-registries-name-registryname-schemas-name-schemaname-language-language.html#PutCodeBinding

        :stability: experimental
        '''
        return typing.cast("Schemas", jsii.invoke(self, "toPutCodeBinding", []))

    @jsii.member(jsii_name="toPutResourcePolicy")
    def to_put_resource_policy(self) -> "Schemas":
        '''(experimental) Grants permission to attach a resource-based policy to a given registry.

        Access Level: Write

        https://docs.aws.amazon.com/eventbridge/latest/schema-reference/v1-policy.html#PutResourcePolicy

        :stability: experimental
        '''
        return typing.cast("Schemas", jsii.invoke(self, "toPutResourcePolicy", []))

    @jsii.member(jsii_name="toSearchSchemas")
    def to_search_schemas(self) -> "Schemas":
        '''(experimental) Grants permission to search schemas based on specified keywords in your account.

        Access Level: List

        https://docs.aws.amazon.com/eventbridge/latest/schema-reference/v1-registries-name-registryname-schemas-search.html#SearchSchemas

        :stability: experimental
        '''
        return typing.cast("Schemas", jsii.invoke(self, "toSearchSchemas", []))

    @jsii.member(jsii_name="toStartDiscoverer")
    def to_start_discoverer(self) -> "Schemas":
        '''(experimental) Grants permission to start the specified discoverer.

        Once started the discoverer will automatically register schemas for published events to configured source in your account

        Access Level: Write

        https://docs.aws.amazon.com/eventbridge/latest/schema-reference/v1-discoverers-id-discovererid.html#StartDiscoverer

        :stability: experimental
        '''
        return typing.cast("Schemas", jsii.invoke(self, "toStartDiscoverer", []))

    @jsii.member(jsii_name="toStopDiscoverer")
    def to_stop_discoverer(self) -> "Schemas":
        '''(experimental) Grants permission to stop the specified discoverer.

        Once stopped the discoverer will no longer register schemas for published events to configured source in your account

        Access Level: Write

        https://docs.aws.amazon.com/eventbridge/latest/schema-reference/v1-discoverers-id-discovererid.html#StopDiscoverer

        :stability: experimental
        '''
        return typing.cast("Schemas", jsii.invoke(self, "toStopDiscoverer", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Schemas":
        '''(experimental) Grants permission to tag a resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/eventbridge/latest/schema-reference/tags-resource-arn.html#TagResource

        :stability: experimental
        '''
        return typing.cast("Schemas", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Schemas":
        '''(experimental) Grants permission to remove a tag from a resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/eventbridge/latest/schema-reference/tags-resource-arn.html#UntagResource

        :stability: experimental
        '''
        return typing.cast("Schemas", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateDiscoverer")
    def to_update_discoverer(self) -> "Schemas":
        '''(experimental) Grants permission to update an existing discoverer in your account.

        Access Level: Write

        https://docs.aws.amazon.com/eventbridge/latest/schema-reference/v1-discoverers-id-discovererid.html#UpdateDiscoverer

        :stability: experimental
        '''
        return typing.cast("Schemas", jsii.invoke(self, "toUpdateDiscoverer", []))

    @jsii.member(jsii_name="toUpdateRegistry")
    def to_update_registry(self) -> "Schemas":
        '''(experimental) Grants permission to update an existing registry metadata in your account.

        Access Level: Write

        https://docs.aws.amazon.com/eventbridge/latest/schema-reference/v1-registries-name-registryname.html#UpdateRegistry

        :stability: experimental
        '''
        return typing.cast("Schemas", jsii.invoke(self, "toUpdateRegistry", []))

    @jsii.member(jsii_name="toUpdateSchema")
    def to_update_schema(self) -> "Schemas":
        '''(experimental) Grants permission to update an existing schema in your account.

        Access Level: Write

        https://docs.aws.amazon.com/eventbridge/latest/schema-reference/v1-registries-name-registryname-schemas-name-schemaname.html#UpdateSchema

        :stability: experimental
        '''
        return typing.cast("Schemas", jsii.invoke(self, "toUpdateSchema", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__18711c6bdd99c38894e9c5d110da9562fe9a01786fe1110ba270e94b36568217)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e135b90d5871613bfb1a49953ada496a331f6def3f8ad9af21faa6f1f9aa1a9e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Sdb(PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Sdb"):
    '''(experimental) Statement provider for service `sdb <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonsimpledb.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `sdb <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonsimpledb.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onDomain")
    def on_domain(
        self,
        domain_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Sdb":
        '''(experimental) Adds a resource of type domain to the statement.

        https://docs.aws.amazon.com/AmazonSimpleDB/latest/DeveloperGuide/DataModel.html

        :param domain_name: - Identifier for the domainName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0dd550b13559912c13433babd82b82410210a4f5b89607faebb5353f5274895a)
            check_type(argname="argument domain_name", value=domain_name, expected_type=type_hints["domain_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Sdb", jsii.invoke(self, "onDomain", [domain_name, account, region, partition]))

    @jsii.member(jsii_name="toBatchDeleteAttributes")
    def to_batch_delete_attributes(self) -> "Sdb":
        '''(experimental) Performs multiple DeleteAttributes operations in a single call, which reduces round trips and latencies.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonSimpleDB/latest/DeveloperGuide/SDB_API_BatchDeleteAttributes.html

        :stability: experimental
        '''
        return typing.cast("Sdb", jsii.invoke(self, "toBatchDeleteAttributes", []))

    @jsii.member(jsii_name="toBatchPutAttributes")
    def to_batch_put_attributes(self) -> "Sdb":
        '''(experimental) With the BatchPutAttributes operation, you can perform multiple PutAttribute operations in a single call.

        With the BatchPutAttributes operation, you can perform multiple PutAttribute operations in a single call

        Access Level: Write

        https://docs.aws.amazon.com/AmazonSimpleDB/latest/DeveloperGuide/SDB_API_BatchPutAttributes.html

        :stability: experimental
        '''
        return typing.cast("Sdb", jsii.invoke(self, "toBatchPutAttributes", []))

    @jsii.member(jsii_name="toCreateDomain")
    def to_create_domain(self) -> "Sdb":
        '''(experimental) The CreateDomain operation creates a new domain.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonSimpleDB/latest/DeveloperGuide/SDB_API_CreateDomain.html

        :stability: experimental
        '''
        return typing.cast("Sdb", jsii.invoke(self, "toCreateDomain", []))

    @jsii.member(jsii_name="toDeleteAttributes")
    def to_delete_attributes(self) -> "Sdb":
        '''(experimental) Deletes one or more attributes associated with the item.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonSimpleDB/latest/DeveloperGuide/SDB_API_DeleteAttributes.html

        :stability: experimental
        '''
        return typing.cast("Sdb", jsii.invoke(self, "toDeleteAttributes", []))

    @jsii.member(jsii_name="toDeleteDomain")
    def to_delete_domain(self) -> "Sdb":
        '''(experimental) The DeleteDomain operation deletes a domain.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonSimpleDB/latest/DeveloperGuide/SDB_API_DeleteDomain.html

        :stability: experimental
        '''
        return typing.cast("Sdb", jsii.invoke(self, "toDeleteDomain", []))

    @jsii.member(jsii_name="toDomainMetadata")
    def to_domain_metadata(self) -> "Sdb":
        '''(experimental) Returns information about the domain, including when the domain was created, the number of items and attributes, and the size of attribute names and values.

        Access Level: Read

        https://docs.aws.amazon.com/AmazonSimpleDB/latest/DeveloperGuide/SDB_API_DomainMetadata.html

        :stability: experimental
        '''
        return typing.cast("Sdb", jsii.invoke(self, "toDomainMetadata", []))

    @jsii.member(jsii_name="toGetAttributes")
    def to_get_attributes(self) -> "Sdb":
        '''(experimental) Returns all of the attributes associated with the item.

        Access Level: Read

        https://docs.aws.amazon.com/AmazonSimpleDB/latest/DeveloperGuide/SDB_API_GetAttributes.html

        :stability: experimental
        '''
        return typing.cast("Sdb", jsii.invoke(self, "toGetAttributes", []))

    @jsii.member(jsii_name="toListDomains")
    def to_list_domains(self) -> "Sdb":
        '''(experimental) Description for ListDomains.

        Access Level: List

        https://docs.aws.amazon.com/AmazonSimpleDB/latest/DeveloperGuide/SDB_API_ListDomains.html

        :stability: experimental
        '''
        return typing.cast("Sdb", jsii.invoke(self, "toListDomains", []))

    @jsii.member(jsii_name="toPutAttributes")
    def to_put_attributes(self) -> "Sdb":
        '''(experimental) The PutAttributes operation creates or replaces attributes in an item.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonSimpleDB/latest/DeveloperGuide/SDB_API_PutAttributes.html

        :stability: experimental
        '''
        return typing.cast("Sdb", jsii.invoke(self, "toPutAttributes", []))

    @jsii.member(jsii_name="toSelect")
    def to_select(self) -> "Sdb":
        '''(experimental) Description for Select.

        Access Level: Read

        https://docs.aws.amazon.com/AmazonSimpleDB/latest/DeveloperGuide/SDB_API_Select.html

        :stability: experimental
        '''
        return typing.cast("Sdb", jsii.invoke(self, "toSelect", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2cf935a898270a9a7352554668a8a33b1faa62d4256020e67b9c3419be79c8d9)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8099f41c9e5ef9d00ebc028ffe2bc677a3aa26c641c531cc1f47519658e8d283)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Secretsmanager(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Secretsmanager",
):
    '''(experimental) Statement provider for service `secretsmanager <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awssecretsmanager.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `secretsmanager <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awssecretsmanager.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="ifAddReplicaRegions")
    def if_add_replica_regions(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Secretsmanager":
        '''(experimental) Filters access by the list of Regions in which to replicate the secret.

        https://docs.aws.amazon.com/secretsmanager/latest/userguide/reference_iam-permissions.html#iam-contextkeys

        Applies to actions:

        - .toCreateSecret()
        - .toReplicateSecretToRegions()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9b4ac6f97c75ddba2953248c19d9de3e1e7a5fa3728baada4c601e1b77fba326)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Secretsmanager", jsii.invoke(self, "ifAddReplicaRegions", [value, operator]))

    @jsii.member(jsii_name="ifBlockPublicPolicy")
    def if_block_public_policy(
        self,
        value: typing.Optional[builtins.bool] = None,
    ) -> "Secretsmanager":
        '''(experimental) Filters access by whether the resource policy blocks broad AWS account access.

        https://docs.aws.amazon.com/secretsmanager/latest/userguide/reference_iam-permissions.html#iam-contextkeys

        Applies to actions:

        - .toPutResourcePolicy()

        :param value: ``true`` or ``false``. **Default:** ``true``

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0914d7c607c346e92f2fd378b041fdd2d50a9e8b9dd1a1480e1eeea68e31387e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast("Secretsmanager", jsii.invoke(self, "ifBlockPublicPolicy", [value]))

    @jsii.member(jsii_name="ifDescription")
    def if_description(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Secretsmanager":
        '''(experimental) Filters access by the description text in the request.

        https://docs.aws.amazon.com/secretsmanager/latest/userguide/reference_iam-permissions.html#iam-contextkeys

        Applies to actions:

        - .toCreateSecret()
        - .toUpdateSecret()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c71c101aa8fddb1f6a622a7ba972aa9e53dbff764a597bf7b2aacb39021369ed)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Secretsmanager", jsii.invoke(self, "ifDescription", [value, operator]))

    @jsii.member(jsii_name="ifForceDeleteWithoutRecovery")
    def if_force_delete_without_recovery(
        self,
        value: typing.Optional[builtins.bool] = None,
    ) -> "Secretsmanager":
        '''(experimental) Filters access by whether the secret is to be deleted immediately without any recovery window.

        https://docs.aws.amazon.com/secretsmanager/latest/userguide/reference_iam-permissions.html#iam-contextkeys

        Applies to actions:

        - .toDeleteSecret()

        :param value: ``true`` or ``false``. **Default:** ``true``

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__94cd71da810f09b383b4674d6f4e5e4ed224756557c957712a48cfed48dae440)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast("Secretsmanager", jsii.invoke(self, "ifForceDeleteWithoutRecovery", [value]))

    @jsii.member(jsii_name="ifForceOverwriteReplicaSecret")
    def if_force_overwrite_replica_secret(
        self,
        value: typing.Optional[builtins.bool] = None,
    ) -> "Secretsmanager":
        '''(experimental) Filters access by whether to overwrite a secret with the same name in the destination Region.

        https://docs.aws.amazon.com/secretsmanager/latest/userguide/reference_iam-permissions.html#iam-contextkeys

        Applies to actions:

        - .toCreateSecret()
        - .toReplicateSecretToRegions()

        :param value: ``true`` or ``false``. **Default:** ``true``

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fa819c51cc11e6401971a2ef1eeef1c957175a5e399d7b4c82d394b05cb27967)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast("Secretsmanager", jsii.invoke(self, "ifForceOverwriteReplicaSecret", [value]))

    @jsii.member(jsii_name="ifKmsKeyId")
    def if_kms_key_id(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Secretsmanager":
        '''(experimental) Filters access by the ARN of the KMS key in the request.

        https://docs.aws.amazon.com/secretsmanager/latest/userguide/reference_iam-permissions.html#iam-contextkeys

        Applies to actions:

        - .toCreateSecret()
        - .toUpdateSecret()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b5270a52f93ded95eaa337ff52025b09799efc53f4ea96f5c383f5c87d1583c3)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Secretsmanager", jsii.invoke(self, "ifKmsKeyId", [value, operator]))

    @jsii.member(jsii_name="ifModifyRotationRules")
    def if_modify_rotation_rules(
        self,
        value: typing.Optional[builtins.bool] = None,
    ) -> "Secretsmanager":
        '''(experimental) Filters access by whether the rotation rules of the secret are to be modified.

        https://docs.aws.amazon.com/secretsmanager/latest/userguide/reference_iam-permissions.html#iam-contextkeys

        Applies to actions:

        - .toRotateSecret()

        :param value: ``true`` or ``false``. **Default:** ``true``

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__cc3e9c39a652e9d01d9f3aaeb6896d4494d7fd9df82911ae017f0ec1cda41e86)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast("Secretsmanager", jsii.invoke(self, "ifModifyRotationRules", [value]))

    @jsii.member(jsii_name="ifName")
    def if_name(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Secretsmanager":
        '''(experimental) Filters access by the friendly name of the secret in the request.

        https://docs.aws.amazon.com/secretsmanager/latest/userguide/reference_iam-permissions.html#iam-contextkeys

        Applies to actions:

        - .toCreateSecret()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8a25bcc56747feb046dadfe90f5da7cf39ab793f893b41c4af6396e33da53a8e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Secretsmanager", jsii.invoke(self, "ifName", [value, operator]))

    @jsii.member(jsii_name="ifRecoveryWindowInDays")
    def if_recovery_window_in_days(
        self,
        value: typing.Union[jsii.Number, typing.Sequence[jsii.Number]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Secretsmanager":
        '''(experimental) Filters access by the number of days that Secrets Manager waits before it can delete the secret.

        https://docs.aws.amazon.com/secretsmanager/latest/userguide/reference_iam-permissions.html#iam-contextkeys

        Applies to actions:

        - .toDeleteSecret()

        :param value: The value(s) to check.
        :param operator: Works with `numeric operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_Numeric>`_. **Default:** ``NumericEquals``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ccb65ce9400d39c537d5382a872d890e57120c13a484829825caf6b08a8bc9e4)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Secretsmanager", jsii.invoke(self, "ifRecoveryWindowInDays", [value, operator]))

    @jsii.member(jsii_name="ifResource")
    def if_resource(
        self,
        allow_rotation_lambda_arn: builtins.str,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Secretsmanager":
        '''(experimental) Filters access by the ARN of the rotation Lambda function associated with the secret.

        https://docs.aws.amazon.com/secretsmanager/latest/userguide/reference_iam-permissions.html#iam-contextkeys

        Applies to actions:

        - .toCancelRotateSecret()
        - .toDeleteResourcePolicy()
        - .toDeleteSecret()
        - .toDescribeSecret()
        - .toGetResourcePolicy()
        - .toGetSecretValue()
        - .toListSecretVersionIds()
        - .toPutResourcePolicy()
        - .toPutSecretValue()
        - .toRemoveRegionsFromReplication()
        - .toReplicateSecretToRegions()
        - .toRestoreSecret()
        - .toRotateSecret()
        - .toStopReplicationToReplica()
        - .toTagResource()
        - .toUntagResource()
        - .toUpdateSecret()
        - .toUpdateSecretVersionStage()
        - .toValidateResourcePolicy()

        Applies to resource types:

        - Secret

        :param allow_rotation_lambda_arn: The tag key to check.
        :param value: The value(s) to check.
        :param operator: Works with `arn operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_ARN>`_. **Default:** ``ArnLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d888b28cd2be9348a41260a0cf619ad47b342bd302ad97e08df83191463a5987)
            check_type(argname="argument allow_rotation_lambda_arn", value=allow_rotation_lambda_arn, expected_type=type_hints["allow_rotation_lambda_arn"])
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Secretsmanager", jsii.invoke(self, "ifResource", [allow_rotation_lambda_arn, value, operator]))

    @jsii.member(jsii_name="ifResourceTag")
    def if_resource_tag(
        self,
        tag_key: builtins.str,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Secretsmanager":
        '''(experimental) Filters access by a tag key and value pair.

        https://docs.aws.amazon.com/secretsmanager/latest/userguide/reference_iam-permissions.html#iam-contextkeys

        Applies to actions:

        - .toCancelRotateSecret()
        - .toCreateSecret()
        - .toDeleteResourcePolicy()
        - .toDeleteSecret()
        - .toDescribeSecret()
        - .toGetResourcePolicy()
        - .toGetSecretValue()
        - .toListSecretVersionIds()
        - .toPutResourcePolicy()
        - .toPutSecretValue()
        - .toRemoveRegionsFromReplication()
        - .toReplicateSecretToRegions()
        - .toRestoreSecret()
        - .toRotateSecret()
        - .toStopReplicationToReplica()
        - .toTagResource()
        - .toUntagResource()
        - .toUpdateSecret()
        - .toUpdateSecretVersionStage()
        - .toValidateResourcePolicy()

        Applies to resource types:

        - Secret

        :param tag_key: The tag key to check.
        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__37062ddf3e738e0c075d9465b9a99e7bf6bd5829ac1666c894ba4333d406602e)
            check_type(argname="argument tag_key", value=tag_key, expected_type=type_hints["tag_key"])
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Secretsmanager", jsii.invoke(self, "ifResourceTag", [tag_key, value, operator]))

    @jsii.member(jsii_name="ifRotateImmediately")
    def if_rotate_immediately(
        self,
        value: typing.Optional[builtins.bool] = None,
    ) -> "Secretsmanager":
        '''(experimental) Filters access by whether the secret is to be rotated immediately.

        https://docs.aws.amazon.com/secretsmanager/latest/userguide/reference_iam-permissions.html#iam-contextkeys

        Applies to actions:

        - .toRotateSecret()

        :param value: ``true`` or ``false``. **Default:** ``true``

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__48819556e2df068c0b4b1244c62a1abb47e2b764529ab1f43cfe83da2d131264)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast("Secretsmanager", jsii.invoke(self, "ifRotateImmediately", [value]))

    @jsii.member(jsii_name="ifRotationLambdaARN")
    def if_rotation_lambda_arn(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Secretsmanager":
        '''(experimental) Filters access by the ARN of the rotation Lambda function in the request.

        https://docs.aws.amazon.com/secretsmanager/latest/userguide/reference_iam-permissions.html#iam-contextkeys

        Applies to actions:

        - .toRotateSecret()

        :param value: The value(s) to check.
        :param operator: Works with `arn operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_ARN>`_. **Default:** ``ArnLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a72f77f5c4e698215b854b1037d6fc5eb409bed04fc556a28332b491eb70a4f3)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Secretsmanager", jsii.invoke(self, "ifRotationLambdaARN", [value, operator]))

    @jsii.member(jsii_name="ifSecretId")
    def if_secret_id(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Secretsmanager":
        '''(experimental) Filters access by the SecretID value in the request.

        https://docs.aws.amazon.com/secretsmanager/latest/userguide/reference_iam-permissions.html#iam-contextkeys

        Applies to actions:

        - .toCancelRotateSecret()
        - .toDeleteResourcePolicy()
        - .toDeleteSecret()
        - .toDescribeSecret()
        - .toGetResourcePolicy()
        - .toGetSecretValue()
        - .toListSecretVersionIds()
        - .toPutResourcePolicy()
        - .toPutSecretValue()
        - .toRemoveRegionsFromReplication()
        - .toReplicateSecretToRegions()
        - .toRestoreSecret()
        - .toRotateSecret()
        - .toStopReplicationToReplica()
        - .toTagResource()
        - .toUntagResource()
        - .toUpdateSecret()
        - .toUpdateSecretVersionStage()
        - .toValidateResourcePolicy()

        :param value: The value(s) to check.
        :param operator: Works with `arn operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_ARN>`_. **Default:** ``ArnLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a3b2c6e2253681a63f93e3538503c8786688d35f19fbdfb828a0427ba01bd5f4)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Secretsmanager", jsii.invoke(self, "ifSecretId", [value, operator]))

    @jsii.member(jsii_name="ifSecretPrimaryRegion")
    def if_secret_primary_region(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Secretsmanager":
        '''(experimental) Filters access by primary region in which the secret is created.

        https://docs.aws.amazon.com/secretsmanager/latest/userguide/reference_iam-permissions.html#iam-contextkeys

        Applies to actions:

        - .toCancelRotateSecret()
        - .toDeleteResourcePolicy()
        - .toDeleteSecret()
        - .toDescribeSecret()
        - .toGetResourcePolicy()
        - .toGetSecretValue()
        - .toListSecretVersionIds()
        - .toPutResourcePolicy()
        - .toPutSecretValue()
        - .toRemoveRegionsFromReplication()
        - .toReplicateSecretToRegions()
        - .toRestoreSecret()
        - .toRotateSecret()
        - .toStopReplicationToReplica()
        - .toTagResource()
        - .toUntagResource()
        - .toUpdateSecret()
        - .toUpdateSecretVersionStage()
        - .toValidateResourcePolicy()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f02f08c895bbc512d4a48015a06e8270d5e2ca749c46edd1057c7bb3ebfd3269)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Secretsmanager", jsii.invoke(self, "ifSecretPrimaryRegion", [value, operator]))

    @jsii.member(jsii_name="ifVersionId")
    def if_version_id(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Secretsmanager":
        '''(experimental) Filters access by the unique identifier of the version of the secret in the request.

        https://docs.aws.amazon.com/secretsmanager/latest/userguide/reference_iam-permissions.html#iam-contextkeys

        Applies to actions:

        - .toGetSecretValue()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__844789d0d3d95d6b0954c2bc4c76198cd70532a70525a7a0ff54faf456bb4fb4)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Secretsmanager", jsii.invoke(self, "ifVersionId", [value, operator]))

    @jsii.member(jsii_name="ifVersionStage")
    def if_version_stage(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Secretsmanager":
        '''(experimental) Filters access by the list of version stages in the request.

        https://docs.aws.amazon.com/secretsmanager/latest/userguide/reference_iam-permissions.html#iam-contextkeys

        Applies to actions:

        - .toGetSecretValue()
        - .toUpdateSecretVersionStage()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6ea64f516c930cd9b197edf5159f8c9ccb13691fc544d5527d3fc870afc14bbe)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Secretsmanager", jsii.invoke(self, "ifVersionStage", [value, operator]))

    @jsii.member(jsii_name="onSecret")
    def on_secret(
        self,
        secret_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Secretsmanager":
        '''(experimental) Adds a resource of type Secret to the statement.

        https://docs.aws.amazon.com/secretsmanager/latest/userguide/reference_iam-permissions.html#iam-resources

        :param secret_id: - Identifier for the secretId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsRequestTag() - .ifAwsResourceTag() - .ifAwsTagKeys() - .ifResourceTag() - .ifResource()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__20c4ecc2e2a7979c9c4281000f8094d33861a5be5574e912bab16cfdbf62e319)
            check_type(argname="argument secret_id", value=secret_id, expected_type=type_hints["secret_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Secretsmanager", jsii.invoke(self, "onSecret", [secret_id, account, region, partition]))

    @jsii.member(jsii_name="toCancelRotateSecret")
    def to_cancel_rotate_secret(self) -> "Secretsmanager":
        '''(experimental) Grants permission to cancel an in-progress secret rotation.

        Access Level: Write

        Possible conditions:

        - .ifSecretId()
        - .ifResource()
        - .ifResourceTag()
        - .ifAwsResourceTag()
        - .ifSecretPrimaryRegion()

        https://docs.aws.amazon.com/secretsmanager/latest/apireference/API_CancelRotateSecret.html

        :stability: experimental
        '''
        return typing.cast("Secretsmanager", jsii.invoke(self, "toCancelRotateSecret", []))

    @jsii.member(jsii_name="toCreateSecret")
    def to_create_secret(self) -> "Secretsmanager":
        '''(experimental) Grants permission to create a secret that stores encrypted data that can be queried and rotated.

        Access Level: Write

        Possible conditions:

        - .ifName()
        - .ifDescription()
        - .ifKmsKeyId()
        - .ifAwsRequestTag()
        - .ifAwsResourceTag()
        - .ifAwsTagKeys()
        - .ifResourceTag()
        - .ifAddReplicaRegions()
        - .ifForceOverwriteReplicaSecret()

        https://docs.aws.amazon.com/secretsmanager/latest/apireference/API_CreateSecret.html

        :stability: experimental
        '''
        return typing.cast("Secretsmanager", jsii.invoke(self, "toCreateSecret", []))

    @jsii.member(jsii_name="toDeleteResourcePolicy")
    def to_delete_resource_policy(self) -> "Secretsmanager":
        '''(experimental) Grants permission to delete the resource policy attached to a secret.

        Access Level: Permissions management

        Possible conditions:

        - .ifSecretId()
        - .ifResource()
        - .ifResourceTag()
        - .ifAwsResourceTag()
        - .ifSecretPrimaryRegion()

        https://docs.aws.amazon.com/secretsmanager/latest/apireference/API_DeleteResourcePolicy.html

        :stability: experimental
        '''
        return typing.cast("Secretsmanager", jsii.invoke(self, "toDeleteResourcePolicy", []))

    @jsii.member(jsii_name="toDeleteSecret")
    def to_delete_secret(self) -> "Secretsmanager":
        '''(experimental) Grants permission to delete a secret.

        Access Level: Write

        Possible conditions:

        - .ifSecretId()
        - .ifResource()
        - .ifRecoveryWindowInDays()
        - .ifForceDeleteWithoutRecovery()
        - .ifResourceTag()
        - .ifAwsResourceTag()
        - .ifSecretPrimaryRegion()

        https://docs.aws.amazon.com/secretsmanager/latest/apireference/API_DeleteSecret.html

        :stability: experimental
        '''
        return typing.cast("Secretsmanager", jsii.invoke(self, "toDeleteSecret", []))

    @jsii.member(jsii_name="toDescribeSecret")
    def to_describe_secret(self) -> "Secretsmanager":
        '''(experimental) Grants permission to retrieve the metadata about a secret, but not the encrypted data.

        Access Level: Read

        Possible conditions:

        - .ifSecretId()
        - .ifResource()
        - .ifResourceTag()
        - .ifAwsResourceTag()
        - .ifSecretPrimaryRegion()

        https://docs.aws.amazon.com/secretsmanager/latest/apireference/API_DescribeSecret.html

        :stability: experimental
        '''
        return typing.cast("Secretsmanager", jsii.invoke(self, "toDescribeSecret", []))

    @jsii.member(jsii_name="toGetRandomPassword")
    def to_get_random_password(self) -> "Secretsmanager":
        '''(experimental) Grants permission to generate a random string for use in password creation.

        Access Level: Read

        https://docs.aws.amazon.com/secretsmanager/latest/apireference/API_GetRandomPassword.html

        :stability: experimental
        '''
        return typing.cast("Secretsmanager", jsii.invoke(self, "toGetRandomPassword", []))

    @jsii.member(jsii_name="toGetResourcePolicy")
    def to_get_resource_policy(self) -> "Secretsmanager":
        '''(experimental) Grants permission to get the resource policy attached to a secret.

        Access Level: Read

        Possible conditions:

        - .ifSecretId()
        - .ifResource()
        - .ifResourceTag()
        - .ifAwsResourceTag()
        - .ifSecretPrimaryRegion()

        https://docs.aws.amazon.com/secretsmanager/latest/apireference/API_GetResourcePolicy.html

        :stability: experimental
        '''
        return typing.cast("Secretsmanager", jsii.invoke(self, "toGetResourcePolicy", []))

    @jsii.member(jsii_name="toGetSecretValue")
    def to_get_secret_value(self) -> "Secretsmanager":
        '''(experimental) Grants permission to retrieve and decrypt the encrypted data.

        Access Level: Read

        Possible conditions:

        - .ifSecretId()
        - .ifVersionId()
        - .ifVersionStage()
        - .ifResource()
        - .ifResourceTag()
        - .ifAwsResourceTag()
        - .ifSecretPrimaryRegion()

        https://docs.aws.amazon.com/secretsmanager/latest/apireference/API_GetSecretValue.html

        :stability: experimental
        '''
        return typing.cast("Secretsmanager", jsii.invoke(self, "toGetSecretValue", []))

    @jsii.member(jsii_name="toListSecrets")
    def to_list_secrets(self) -> "Secretsmanager":
        '''(experimental) Grants permission to list the available secrets.

        Access Level: List

        https://docs.aws.amazon.com/secretsmanager/latest/apireference/API_ListSecrets.html

        :stability: experimental
        '''
        return typing.cast("Secretsmanager", jsii.invoke(self, "toListSecrets", []))

    @jsii.member(jsii_name="toListSecretVersionIds")
    def to_list_secret_version_ids(self) -> "Secretsmanager":
        '''(experimental) Grants permission to list the available versions of a secret.

        Access Level: Read

        Possible conditions:

        - .ifSecretId()
        - .ifResource()
        - .ifResourceTag()
        - .ifAwsResourceTag()
        - .ifSecretPrimaryRegion()

        https://docs.aws.amazon.com/secretsmanager/latest/apireference/API_ListSecretVersionIds.html

        :stability: experimental
        '''
        return typing.cast("Secretsmanager", jsii.invoke(self, "toListSecretVersionIds", []))

    @jsii.member(jsii_name="toPutResourcePolicy")
    def to_put_resource_policy(self) -> "Secretsmanager":
        '''(experimental) Grants permission to attach a resource policy to a secret.

        Access Level: Permissions management

        Possible conditions:

        - .ifSecretId()
        - .ifResource()
        - .ifResourceTag()
        - .ifAwsResourceTag()
        - .ifBlockPublicPolicy()
        - .ifSecretPrimaryRegion()

        https://docs.aws.amazon.com/secretsmanager/latest/apireference/API_PutResourcePolicy.html

        :stability: experimental
        '''
        return typing.cast("Secretsmanager", jsii.invoke(self, "toPutResourcePolicy", []))

    @jsii.member(jsii_name="toPutSecretValue")
    def to_put_secret_value(self) -> "Secretsmanager":
        '''(experimental) Grants permission to create a new version of the secret with new encrypted data.

        Access Level: Write

        Possible conditions:

        - .ifSecretId()
        - .ifResource()
        - .ifResourceTag()
        - .ifAwsResourceTag()
        - .ifSecretPrimaryRegion()

        https://docs.aws.amazon.com/secretsmanager/latest/apireference/API_PutSecretValue.html

        :stability: experimental
        '''
        return typing.cast("Secretsmanager", jsii.invoke(self, "toPutSecretValue", []))

    @jsii.member(jsii_name="toRemoveRegionsFromReplication")
    def to_remove_regions_from_replication(self) -> "Secretsmanager":
        '''(experimental) Grants permission to remove regions from replication.

        Access Level: Write

        Possible conditions:

        - .ifSecretId()
        - .ifResource()
        - .ifResourceTag()
        - .ifAwsResourceTag()
        - .ifSecretPrimaryRegion()

        https://docs.aws.amazon.com/secretsmanager/latest/apireference/API_RemoveRegionsFromReplication.html

        :stability: experimental
        '''
        return typing.cast("Secretsmanager", jsii.invoke(self, "toRemoveRegionsFromReplication", []))

    @jsii.member(jsii_name="toReplicateSecretToRegions")
    def to_replicate_secret_to_regions(self) -> "Secretsmanager":
        '''(experimental) Grants permission to convert an existing secret to a multi-Region secret and begin replicating the secret to a list of new regions.

        Access Level: Write

        Possible conditions:

        - .ifSecretId()
        - .ifResource()
        - .ifResourceTag()
        - .ifAwsResourceTag()
        - .ifSecretPrimaryRegion()
        - .ifAddReplicaRegions()
        - .ifForceOverwriteReplicaSecret()

        https://docs.aws.amazon.com/secretsmanager/latest/apireference/API_ReplicateSecretToRegions.html

        :stability: experimental
        '''
        return typing.cast("Secretsmanager", jsii.invoke(self, "toReplicateSecretToRegions", []))

    @jsii.member(jsii_name="toRestoreSecret")
    def to_restore_secret(self) -> "Secretsmanager":
        '''(experimental) Grants permission to cancel deletion of a secret.

        Access Level: Write

        Possible conditions:

        - .ifSecretId()
        - .ifResource()
        - .ifResourceTag()
        - .ifAwsResourceTag()
        - .ifSecretPrimaryRegion()

        https://docs.aws.amazon.com/secretsmanager/latest/apireference/API_RestoreSecret.html

        :stability: experimental
        '''
        return typing.cast("Secretsmanager", jsii.invoke(self, "toRestoreSecret", []))

    @jsii.member(jsii_name="toRotateSecret")
    def to_rotate_secret(self) -> "Secretsmanager":
        '''(experimental) Grants permission to start rotation of a secret.

        Access Level: Write

        Possible conditions:

        - .ifSecretId()
        - .ifRotationLambdaARN()
        - .ifResource()
        - .ifResourceTag()
        - .ifAwsResourceTag()
        - .ifSecretPrimaryRegion()
        - .ifModifyRotationRules()
        - .ifRotateImmediately()

        https://docs.aws.amazon.com/secretsmanager/latest/apireference/API_RotateSecret.html

        :stability: experimental
        '''
        return typing.cast("Secretsmanager", jsii.invoke(self, "toRotateSecret", []))

    @jsii.member(jsii_name="toStopReplicationToReplica")
    def to_stop_replication_to_replica(self) -> "Secretsmanager":
        '''(experimental) Grants permission to remove the secret from replication and promote the secret to a regional secret in the replica Region.

        Access Level: Write

        Possible conditions:

        - .ifSecretId()
        - .ifResource()
        - .ifResourceTag()
        - .ifAwsResourceTag()
        - .ifSecretPrimaryRegion()

        https://docs.aws.amazon.com/secretsmanager/latest/apireference/API_StopReplicationToReplica.html

        :stability: experimental
        '''
        return typing.cast("Secretsmanager", jsii.invoke(self, "toStopReplicationToReplica", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Secretsmanager":
        '''(experimental) Grants permission to add tags to a secret.

        Access Level: Tagging

        Possible conditions:

        - .ifSecretId()
        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifResource()
        - .ifResourceTag()
        - .ifAwsResourceTag()
        - .ifSecretPrimaryRegion()

        https://docs.aws.amazon.com/secretsmanager/latest/apireference/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("Secretsmanager", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Secretsmanager":
        '''(experimental) Grants permission to remove tags from a secret.

        Access Level: Tagging

        Possible conditions:

        - .ifSecretId()
        - .ifAwsTagKeys()
        - .ifResource()
        - .ifResourceTag()
        - .ifAwsResourceTag()
        - .ifSecretPrimaryRegion()

        https://docs.aws.amazon.com/secretsmanager/latest/apireference/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("Secretsmanager", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateSecret")
    def to_update_secret(self) -> "Secretsmanager":
        '''(experimental) Grants permission to update a secret with new metadata or with a new version of the encrypted data.

        Access Level: Write

        Possible conditions:

        - .ifSecretId()
        - .ifDescription()
        - .ifKmsKeyId()
        - .ifResource()
        - .ifResourceTag()
        - .ifAwsResourceTag()
        - .ifSecretPrimaryRegion()

        https://docs.aws.amazon.com/secretsmanager/latest/apireference/API_UpdateSecret.html

        :stability: experimental
        '''
        return typing.cast("Secretsmanager", jsii.invoke(self, "toUpdateSecret", []))

    @jsii.member(jsii_name="toUpdateSecretVersionStage")
    def to_update_secret_version_stage(self) -> "Secretsmanager":
        '''(experimental) Grants permission to move a stage from one secret to another.

        Access Level: Write

        Possible conditions:

        - .ifSecretId()
        - .ifVersionStage()
        - .ifResource()
        - .ifResourceTag()
        - .ifAwsResourceTag()
        - .ifSecretPrimaryRegion()

        https://docs.aws.amazon.com/secretsmanager/latest/apireference/API_UpdateSecretVersionStage.html

        :stability: experimental
        '''
        return typing.cast("Secretsmanager", jsii.invoke(self, "toUpdateSecretVersionStage", []))

    @jsii.member(jsii_name="toValidateResourcePolicy")
    def to_validate_resource_policy(self) -> "Secretsmanager":
        '''(experimental) Grants permission to validate a resource policy before attaching policy.

        Access Level: Permissions management

        Possible conditions:

        - .ifSecretId()
        - .ifResource()
        - .ifResourceTag()
        - .ifAwsResourceTag()
        - .ifSecretPrimaryRegion()

        https://docs.aws.amazon.com/secretsmanager/latest/apireference/API_ValidateResourcePolicy.html

        :stability: experimental
        '''
        return typing.cast("Secretsmanager", jsii.invoke(self, "toValidateResourcePolicy", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bd53234c88169a2295c6c50172b864db8821a5eb8a4b02854c6a4cad3afd1de4)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__251461be4888ef9fafd03a48e982ff44f76466881e7ad5347972f0c17707fb0e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Securityhub(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Securityhub",
):
    '''(experimental) Statement provider for service `securityhub <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awssecurityhub.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `securityhub <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awssecurityhub.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="ifASFFSyntaxPath")
    def if_asff_syntax_path(
        self,
        a_sff_syntax_path: builtins.str,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Securityhub":
        '''(experimental) Filters access by the specified fields and values in the request.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_condition-keys.html#condition-keys-asffsyntaxpath

        Applies to actions:

        - .toBatchUpdateFindings()

        :param a_sff_syntax_path: The tag key to check.
        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9581d42c5ddb777a806fa306a3e4bb507d95bdf1918bbe9e3c91f2fff0cb4be7)
            check_type(argname="argument a_sff_syntax_path", value=a_sff_syntax_path, expected_type=type_hints["a_sff_syntax_path"])
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Securityhub", jsii.invoke(self, "ifASFFSyntaxPath", [a_sff_syntax_path, value, operator]))

    @jsii.member(jsii_name="ifTargetAccount")
    def if_target_account(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Securityhub":
        '''(experimental) Filters access by the AwsAccountId field that is specified in the request.

        https://docs.aws.amazon.com/securityhub/latest/userguide/securityhub-access.html#conditions

        Applies to actions:

        - .toBatchImportFindings()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9c7beb28ad0df83c7115ca6c81189a740b3221ec810013b844d0db75dd5588c5)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Securityhub", jsii.invoke(self, "ifTargetAccount", [value, operator]))

    @jsii.member(jsii_name="onFindingAggregator")
    def on_finding_aggregator(
        self,
        finding_aggregator_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Securityhub":
        '''(experimental) Adds a resource of type finding-aggregator to the statement.

        https://docs.aws.amazon.com/securityhub/latest/userguide/securityhub-access.html#resources

        :param finding_aggregator_id: - Identifier for the findingAggregatorId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3d8b1fdd6a0a79ffeca538fd7186bce6e6a256b2aaca0cb5cbdbe507668157c7)
            check_type(argname="argument finding_aggregator_id", value=finding_aggregator_id, expected_type=type_hints["finding_aggregator_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Securityhub", jsii.invoke(self, "onFindingAggregator", [finding_aggregator_id, account, region, partition]))

    @jsii.member(jsii_name="onHub")
    def on_hub(
        self,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Securityhub":
        '''(experimental) Adds a resource of type hub to the statement.

        https://docs.aws.amazon.com/securityhub/latest/userguide/securityhub-access.html#resources

        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__be5a4028eabf59e2c9c2904c26500c06823776900c49ecfbdf180b54505b922f)
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Securityhub", jsii.invoke(self, "onHub", [account, region, partition]))

    @jsii.member(jsii_name="onProduct")
    def on_product(
        self,
        company: builtins.str,
        product_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Securityhub":
        '''(experimental) Adds a resource of type product to the statement.

        https://docs.aws.amazon.com/securityhub/latest/userguide/securityhub-access.html#resources

        :param company: - Identifier for the company.
        :param product_id: - Identifier for the productId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4471b496be7b78baf316559dd037a638837e05d544d0e5ae076fee918160fa63)
            check_type(argname="argument company", value=company, expected_type=type_hints["company"])
            check_type(argname="argument product_id", value=product_id, expected_type=type_hints["product_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Securityhub", jsii.invoke(self, "onProduct", [company, product_id, account, region, partition]))

    @jsii.member(jsii_name="toAcceptAdministratorInvitation")
    def to_accept_administrator_invitation(self) -> "Securityhub":
        '''(experimental) Grants permission to accept Security Hub invitations to become a member account.

        Access Level: Write

        https://docs.aws.amazon.com/securityhub/1.0/APIReference/API_AcceptAdministratorInvitation.html

        :stability: experimental
        '''
        return typing.cast("Securityhub", jsii.invoke(self, "toAcceptAdministratorInvitation", []))

    @jsii.member(jsii_name="toAcceptInvitation")
    def to_accept_invitation(self) -> "Securityhub":
        '''(experimental) Grants permission to accept Security Hub invitations to become a member account.

        Access Level: Write

        https://docs.aws.amazon.com/securityhub/1.0/APIReference/API_AcceptInvitation.html

        :stability: experimental
        '''
        return typing.cast("Securityhub", jsii.invoke(self, "toAcceptInvitation", []))

    @jsii.member(jsii_name="toBatchDisableStandards")
    def to_batch_disable_standards(self) -> "Securityhub":
        '''(experimental) Grants permission to disable standards in Security Hub.

        Access Level: Write

        https://docs.aws.amazon.com/securityhub/1.0/APIReference/API_BatchDisableStandards.html

        :stability: experimental
        '''
        return typing.cast("Securityhub", jsii.invoke(self, "toBatchDisableStandards", []))

    @jsii.member(jsii_name="toBatchEnableStandards")
    def to_batch_enable_standards(self) -> "Securityhub":
        '''(experimental) Grants permission to enable standards in Security Hub.

        Access Level: Write

        https://docs.aws.amazon.com/securityhub/1.0/APIReference/API_BatchEnableStandards.html

        :stability: experimental
        '''
        return typing.cast("Securityhub", jsii.invoke(self, "toBatchEnableStandards", []))

    @jsii.member(jsii_name="toBatchGetStandardsControlAssociations")
    def to_batch_get_standards_control_associations(self) -> "Securityhub":
        '''(experimental) Grants permission to get the association between a list of security controls and standards in batches.

        Access Level: Read

        https://docs.aws.amazon.com/securityhub/latest/userguide/securityhub-standards.html

        :stability: experimental
        '''
        return typing.cast("Securityhub", jsii.invoke(self, "toBatchGetStandardsControlAssociations", []))

    @jsii.member(jsii_name="toBatchImportFindings")
    def to_batch_import_findings(self) -> "Securityhub":
        '''(experimental) Grants permission to import findings into Security Hub from an integrated product.

        Access Level: Write

        Possible conditions:

        - .ifTargetAccount()

        https://docs.aws.amazon.com/securityhub/1.0/APIReference/API_BatchImportFindings.html

        :stability: experimental
        '''
        return typing.cast("Securityhub", jsii.invoke(self, "toBatchImportFindings", []))

    @jsii.member(jsii_name="toBatchUpdateFindings")
    def to_batch_update_findings(self) -> "Securityhub":
        '''(experimental) Grants permission to update customer-controlled fields for a selected set of Security Hub findings.

        Access Level: Write

        Possible conditions:

        - .ifASFFSyntaxPath()

        https://docs.aws.amazon.com/securityhub/1.0/APIReference/API_BatchUpdateFindings.html

        :stability: experimental
        '''
        return typing.cast("Securityhub", jsii.invoke(self, "toBatchUpdateFindings", []))

    @jsii.member(jsii_name="toBatchUpdateStandardsControlAssociations")
    def to_batch_update_standards_control_associations(self) -> "Securityhub":
        '''(experimental) Grants permission to update the association between a list of security controls and standards in batches.

        Access Level: Write

        https://docs.aws.amazon.com/securityhub/latest/userguide/securityhub-standards.html

        :stability: experimental
        '''
        return typing.cast("Securityhub", jsii.invoke(self, "toBatchUpdateStandardsControlAssociations", []))

    @jsii.member(jsii_name="toCreateActionTarget")
    def to_create_action_target(self) -> "Securityhub":
        '''(experimental) Grants permission to create custom actions in Security Hub.

        Access Level: Write

        https://docs.aws.amazon.com/securityhub/1.0/APIReference/API_CreateActionTarget.html

        :stability: experimental
        '''
        return typing.cast("Securityhub", jsii.invoke(self, "toCreateActionTarget", []))

    @jsii.member(jsii_name="toCreateFindingAggregator")
    def to_create_finding_aggregator(self) -> "Securityhub":
        '''(experimental) Grants permission to create a finding aggregator, which contains the cross-Region finding aggregation configuration.

        Access Level: Write

        https://docs.aws.amazon.com/securityhub/1.0/APIReference/API_UpdateFindingAggregator.html

        :stability: experimental
        '''
        return typing.cast("Securityhub", jsii.invoke(self, "toCreateFindingAggregator", []))

    @jsii.member(jsii_name="toCreateInsight")
    def to_create_insight(self) -> "Securityhub":
        '''(experimental) Grants permission to create insights in Security Hub. Insights are collections of related findings.

        Access Level: Write

        https://docs.aws.amazon.com/securityhub/1.0/APIReference/API_CreateInsight.html

        :stability: experimental
        '''
        return typing.cast("Securityhub", jsii.invoke(self, "toCreateInsight", []))

    @jsii.member(jsii_name="toCreateMembers")
    def to_create_members(self) -> "Securityhub":
        '''(experimental) Grants permission to create member accounts in Security Hub.

        Access Level: Write

        https://docs.aws.amazon.com/securityhub/1.0/APIReference/API_CreateMembers.html

        :stability: experimental
        '''
        return typing.cast("Securityhub", jsii.invoke(self, "toCreateMembers", []))

    @jsii.member(jsii_name="toDeclineInvitations")
    def to_decline_invitations(self) -> "Securityhub":
        '''(experimental) Grants permission to decline Security Hub invitations to become a member account.

        Access Level: Write

        https://docs.aws.amazon.com/securityhub/1.0/APIReference/API_DeclineInvitations.html

        :stability: experimental
        '''
        return typing.cast("Securityhub", jsii.invoke(self, "toDeclineInvitations", []))

    @jsii.member(jsii_name="toDeleteActionTarget")
    def to_delete_action_target(self) -> "Securityhub":
        '''(experimental) Grants permission to delete custom actions in Security Hub.

        Access Level: Write

        https://docs.aws.amazon.com/securityhub/1.0/APIReference/API_DeleteActionTarget.html

        :stability: experimental
        '''
        return typing.cast("Securityhub", jsii.invoke(self, "toDeleteActionTarget", []))

    @jsii.member(jsii_name="toDeleteFindingAggregator")
    def to_delete_finding_aggregator(self) -> "Securityhub":
        '''(experimental) Grants permission to delete a finding aggregator, which disables finding aggregation across Regions.

        Access Level: Write

        https://docs.aws.amazon.com/securityhub/1.0/APIReference/API_DeleteFindingAggregator.html

        :stability: experimental
        '''
        return typing.cast("Securityhub", jsii.invoke(self, "toDeleteFindingAggregator", []))

    @jsii.member(jsii_name="toDeleteInsight")
    def to_delete_insight(self) -> "Securityhub":
        '''(experimental) Grants permission to delete insights from Security Hub.

        Access Level: Write

        https://docs.aws.amazon.com/securityhub/1.0/APIReference/API_DeleteInsight.html

        :stability: experimental
        '''
        return typing.cast("Securityhub", jsii.invoke(self, "toDeleteInsight", []))

    @jsii.member(jsii_name="toDeleteInvitations")
    def to_delete_invitations(self) -> "Securityhub":
        '''(experimental) Grants permission to delete Security Hub invitations to become a member account.

        Access Level: Write

        https://docs.aws.amazon.com/securityhub/1.0/APIReference/API_DeleteInvitations.html

        :stability: experimental
        '''
        return typing.cast("Securityhub", jsii.invoke(self, "toDeleteInvitations", []))

    @jsii.member(jsii_name="toDeleteMembers")
    def to_delete_members(self) -> "Securityhub":
        '''(experimental) Grants permission to delete Security Hub member accounts.

        Access Level: Write

        https://docs.aws.amazon.com/securityhub/1.0/APIReference/API_DeleteMembers.html

        :stability: experimental
        '''
        return typing.cast("Securityhub", jsii.invoke(self, "toDeleteMembers", []))

    @jsii.member(jsii_name="toDescribeActionTargets")
    def to_describe_action_targets(self) -> "Securityhub":
        '''(experimental) Grants permission to retrieve a list of custom actions using the API.

        Access Level: Read

        https://docs.aws.amazon.com/securityhub/1.0/APIReference/API_DescribeActionTargets.html

        :stability: experimental
        '''
        return typing.cast("Securityhub", jsii.invoke(self, "toDescribeActionTargets", []))

    @jsii.member(jsii_name="toDescribeHub")
    def to_describe_hub(self) -> "Securityhub":
        '''(experimental) Grants permission to retrieve information about the hub resource in your account.

        Access Level: Read

        https://docs.aws.amazon.com/securityhub/1.0/APIReference/API_DescribeHub.html

        :stability: experimental
        '''
        return typing.cast("Securityhub", jsii.invoke(self, "toDescribeHub", []))

    @jsii.member(jsii_name="toDescribeOrganizationConfiguration")
    def to_describe_organization_configuration(self) -> "Securityhub":
        '''(experimental) Grants permission to describe the organization configuration for Security Hub.

        Access Level: Read

        https://docs.aws.amazon.com/securityhub/1.0/APIReference/API_DescribeOrganizationConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Securityhub", jsii.invoke(self, "toDescribeOrganizationConfiguration", []))

    @jsii.member(jsii_name="toDescribeProducts")
    def to_describe_products(self) -> "Securityhub":
        '''(experimental) Grants permission to retrieve information about the available Security Hub product integrations.

        Access Level: Read

        https://docs.aws.amazon.com/securityhub/1.0/APIReference/API_DescribeProducts.html

        :stability: experimental
        '''
        return typing.cast("Securityhub", jsii.invoke(self, "toDescribeProducts", []))

    @jsii.member(jsii_name="toDescribeStandards")
    def to_describe_standards(self) -> "Securityhub":
        '''(experimental) Grants permission to retrieve information about Security Hub standards.

        Access Level: Read

        https://docs.aws.amazon.com/securityhub/1.0/APIReference/API_DescribeStandards.html

        :stability: experimental
        '''
        return typing.cast("Securityhub", jsii.invoke(self, "toDescribeStandards", []))

    @jsii.member(jsii_name="toDescribeStandardsControls")
    def to_describe_standards_controls(self) -> "Securityhub":
        '''(experimental) Grants permission to retrieve information about Security Hub standards controls.

        Access Level: Read

        https://docs.aws.amazon.com/securityhub/1.0/APIReference/API_DescribeStandardsControls.html

        :stability: experimental
        '''
        return typing.cast("Securityhub", jsii.invoke(self, "toDescribeStandardsControls", []))

    @jsii.member(jsii_name="toDisableImportFindingsForProduct")
    def to_disable_import_findings_for_product(self) -> "Securityhub":
        '''(experimental) Grants permission to disable the findings importing for a Security Hub integrated product.

        Access Level: Write

        https://docs.aws.amazon.com/securityhub/1.0/APIReference/API_DisableImportFindingsForProduct.html

        :stability: experimental
        '''
        return typing.cast("Securityhub", jsii.invoke(self, "toDisableImportFindingsForProduct", []))

    @jsii.member(jsii_name="toDisableOrganizationAdminAccount")
    def to_disable_organization_admin_account(self) -> "Securityhub":
        '''(experimental) Grants permission to remove the Security Hub administrator account for your organization.

        Access Level: Write

        Dependent actions:

        - organizations:DescribeOrganization

        https://docs.aws.amazon.com/securityhub/1.0/APIReference/API_DisableOrganizationAdminAccount.html

        :stability: experimental
        '''
        return typing.cast("Securityhub", jsii.invoke(self, "toDisableOrganizationAdminAccount", []))

    @jsii.member(jsii_name="toDisableSecurityHub")
    def to_disable_security_hub(self) -> "Securityhub":
        '''(experimental) Grants permission to disable Security Hub.

        Access Level: Write

        https://docs.aws.amazon.com/securityhub/1.0/APIReference/API_DisableSecurityHub.html

        :stability: experimental
        '''
        return typing.cast("Securityhub", jsii.invoke(self, "toDisableSecurityHub", []))

    @jsii.member(jsii_name="toDisassociateFromAdministratorAccount")
    def to_disassociate_from_administrator_account(self) -> "Securityhub":
        '''(experimental) Grants permission to a Security Hub member account to disassociate from the associated administrator account.

        Access Level: Write

        https://docs.aws.amazon.com/securityhub/1.0/APIReference/API_DisassociateFromAdministratorAccount.html

        :stability: experimental
        '''
        return typing.cast("Securityhub", jsii.invoke(self, "toDisassociateFromAdministratorAccount", []))

    @jsii.member(jsii_name="toDisassociateFromMasterAccount")
    def to_disassociate_from_master_account(self) -> "Securityhub":
        '''(experimental) Grants permission to a Security Hub member account to disassociate from the associated master account.

        Access Level: Write

        https://docs.aws.amazon.com/securityhub/1.0/APIReference/API_DisassociateFromMasterAccount.html

        :stability: experimental
        '''
        return typing.cast("Securityhub", jsii.invoke(self, "toDisassociateFromMasterAccount", []))

    @jsii.member(jsii_name="toDisassociateMembers")
    def to_disassociate_members(self) -> "Securityhub":
        '''(experimental) Grants permission to disassociate Security Hub member accounts from the associated administrator account.

        Access Level: Write

        https://docs.aws.amazon.com/securityhub/1.0/APIReference/API_DisassociateMembers.html

        :stability: experimental
        '''
        return typing.cast("Securityhub", jsii.invoke(self, "toDisassociateMembers", []))

    @jsii.member(jsii_name="toEnableImportFindingsForProduct")
    def to_enable_import_findings_for_product(self) -> "Securityhub":
        '''(experimental) Grants permission to enable the findings importing for a Security Hub integrated product.

        Access Level: Write

        https://docs.aws.amazon.com/securityhub/1.0/APIReference/API_EnableImportFindingsForProduct.html

        :stability: experimental
        '''
        return typing.cast("Securityhub", jsii.invoke(self, "toEnableImportFindingsForProduct", []))

    @jsii.member(jsii_name="toEnableOrganizationAdminAccount")
    def to_enable_organization_admin_account(self) -> "Securityhub":
        '''(experimental) Grants permission to designate a Security Hub administrator account for your organization.

        Access Level: Write

        Dependent actions:

        - organizations:DescribeOrganization
        - organizations:EnableAWSServiceAccess
        - organizations:RegisterDelegatedAdministrator

        https://docs.aws.amazon.com/securityhub/1.0/APIReference/API_EnableOrganizationAdminAccount.html

        :stability: experimental
        '''
        return typing.cast("Securityhub", jsii.invoke(self, "toEnableOrganizationAdminAccount", []))

    @jsii.member(jsii_name="toEnableSecurityHub")
    def to_enable_security_hub(self) -> "Securityhub":
        '''(experimental) Grants permission to enable Security Hub.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/securityhub/1.0/APIReference/API_EnableSecurityHub.html

        :stability: experimental
        '''
        return typing.cast("Securityhub", jsii.invoke(self, "toEnableSecurityHub", []))

    @jsii.member(jsii_name="toGetAdhocInsightResults")
    def to_get_adhoc_insight_results(self) -> "Securityhub":
        '''(experimental) Grants permission to retrieve insight results by providing a set of filters instead of an insight ARN.

        Access Level: Read

        https://docs.aws.amazon.com/securityhub/1.0/APIReference/API_GetAdhocInsightResults.html

        :stability: experimental
        '''
        return typing.cast("Securityhub", jsii.invoke(self, "toGetAdhocInsightResults", []))

    @jsii.member(jsii_name="toGetAdministratorAccount")
    def to_get_administrator_account(self) -> "Securityhub":
        '''(experimental) Grants permission to retrieve details about the Security Hub administrator account.

        Access Level: Read

        https://docs.aws.amazon.com/securityhub/1.0/APIReference/API_GetAdministratorAccount.html

        :stability: experimental
        '''
        return typing.cast("Securityhub", jsii.invoke(self, "toGetAdministratorAccount", []))

    @jsii.member(jsii_name="toGetControlFindingSummary")
    def to_get_control_finding_summary(self) -> "Securityhub":
        '''(experimental) Grants permission to retrieve a security score and counts of finding and control statuses for a security standard.

        Access Level: Read

        https://docs.aws.amazon.com/securityhub/1.0/APIReference/API_GetControlFindingSummary.html

        :stability: experimental
        '''
        return typing.cast("Securityhub", jsii.invoke(self, "toGetControlFindingSummary", []))

    @jsii.member(jsii_name="toGetEnabledStandards")
    def to_get_enabled_standards(self) -> "Securityhub":
        '''(experimental) Grants permission to retrieve a list of the standards that are enabled in Security Hub.

        Access Level: List

        https://docs.aws.amazon.com/securityhub/1.0/APIReference/API_GetEnabledStandards.html

        :stability: experimental
        '''
        return typing.cast("Securityhub", jsii.invoke(self, "toGetEnabledStandards", []))

    @jsii.member(jsii_name="toGetFindingAggregator")
    def to_get_finding_aggregator(self) -> "Securityhub":
        '''(experimental) Grants permission to retrieve details for a finding aggregator, which configures finding aggregation across Regions.

        Access Level: Read

        https://docs.aws.amazon.com/securityhub/1.0/APIReference/API_GetFindingAggregator.html

        :stability: experimental
        '''
        return typing.cast("Securityhub", jsii.invoke(self, "toGetFindingAggregator", []))

    @jsii.member(jsii_name="toGetFindings")
    def to_get_findings(self) -> "Securityhub":
        '''(experimental) Grants permission to retrieve a list of findings from Security Hub.

        Access Level: Read

        https://docs.aws.amazon.com/securityhub/1.0/APIReference/API_GetFindings.html

        :stability: experimental
        '''
        return typing.cast("Securityhub", jsii.invoke(self, "toGetFindings", []))

    @jsii.member(jsii_name="toGetFreeTrialEndDate")
    def to_get_free_trial_end_date(self) -> "Securityhub":
        '''(experimental) Grants permission to retrieve the end date for an account's free trial of Security Hub.

        Access Level: Read

        https://docs.aws.amazon.com/securityhub/1.0/APIReference/API_GetFreeTrialEndDate.html

        :stability: experimental
        '''
        return typing.cast("Securityhub", jsii.invoke(self, "toGetFreeTrialEndDate", []))

    @jsii.member(jsii_name="toGetFreeTrialUsage")
    def to_get_free_trial_usage(self) -> "Securityhub":
        '''(experimental) Grants permission to retrieve information about Security Hub usage during the free trial period.

        Access Level: Read

        https://docs.aws.amazon.com/securityhub/1.0/APIReference/API_GetFreeTrialUsage.html

        :stability: experimental
        '''
        return typing.cast("Securityhub", jsii.invoke(self, "toGetFreeTrialUsage", []))

    @jsii.member(jsii_name="toGetInsightFindingTrend")
    def to_get_insight_finding_trend(self) -> "Securityhub":
        '''(experimental) Grants permission to retrieve an insight finding trend from Security Hub in order to generate a graph.

        Access Level: Read

        https://docs.aws.amazon.com/securityhub/1.0/APIReference/API_GetInsightFindingTrend.html

        :stability: experimental
        '''
        return typing.cast("Securityhub", jsii.invoke(self, "toGetInsightFindingTrend", []))

    @jsii.member(jsii_name="toGetInsightResults")
    def to_get_insight_results(self) -> "Securityhub":
        '''(experimental) Grants permission to retrieve insight results from Security Hub.

        Access Level: Read

        https://docs.aws.amazon.com/securityhub/1.0/APIReference/API_GetInsightResults.html

        :stability: experimental
        '''
        return typing.cast("Securityhub", jsii.invoke(self, "toGetInsightResults", []))

    @jsii.member(jsii_name="toGetInsights")
    def to_get_insights(self) -> "Securityhub":
        '''(experimental) Grants permission to retrieve Security Hub insights.

        Access Level: List

        https://docs.aws.amazon.com/securityhub/1.0/APIReference/API_GetInsights.html

        :stability: experimental
        '''
        return typing.cast("Securityhub", jsii.invoke(self, "toGetInsights", []))

    @jsii.member(jsii_name="toGetInvitationsCount")
    def to_get_invitations_count(self) -> "Securityhub":
        '''(experimental) Grants permission to retrieve the count of Security Hub membership invitations sent to the account.

        Access Level: Read

        https://docs.aws.amazon.com/securityhub/1.0/APIReference/API_GetInvitationsCount.html

        :stability: experimental
        '''
        return typing.cast("Securityhub", jsii.invoke(self, "toGetInvitationsCount", []))

    @jsii.member(jsii_name="toGetMasterAccount")
    def to_get_master_account(self) -> "Securityhub":
        '''(experimental) Grants permission to retrieve details about the Security Hub master account.

        Access Level: Read

        https://docs.aws.amazon.com/securityhub/1.0/APIReference/API_GetMasterAccount.html

        :stability: experimental
        '''
        return typing.cast("Securityhub", jsii.invoke(self, "toGetMasterAccount", []))

    @jsii.member(jsii_name="toGetMembers")
    def to_get_members(self) -> "Securityhub":
        '''(experimental) Grants permission to retrieve the details of Security Hub member accounts.

        Access Level: Read

        https://docs.aws.amazon.com/securityhub/1.0/APIReference/API_GetMembers.html

        :stability: experimental
        '''
        return typing.cast("Securityhub", jsii.invoke(self, "toGetMembers", []))

    @jsii.member(jsii_name="toGetUsage")
    def to_get_usage(self) -> "Securityhub":
        '''(experimental) Grants permission to retrieve information about Security Hub usage by accounts.

        Access Level: Read

        https://docs.aws.amazon.com/securityhub/1.0/APIReference/API_GetUsage.html

        :stability: experimental
        '''
        return typing.cast("Securityhub", jsii.invoke(self, "toGetUsage", []))

    @jsii.member(jsii_name="toInviteMembers")
    def to_invite_members(self) -> "Securityhub":
        '''(experimental) Grants permission to invite other AWS accounts to become Security Hub member accounts.

        Access Level: Write

        https://docs.aws.amazon.com/securityhub/1.0/APIReference/API_InviteMembers.html

        :stability: experimental
        '''
        return typing.cast("Securityhub", jsii.invoke(self, "toInviteMembers", []))

    @jsii.member(jsii_name="toListControlEvaluationSummaries")
    def to_list_control_evaluation_summaries(self) -> "Securityhub":
        '''(experimental) Grants permission to retrieve a list of controls for a standard, including the control IDs, statuses and finding counts.

        Access Level: Read

        https://docs.aws.amazon.com/securityhub/1.0/APIReference/API_ListControlEvaluationSummaries.html

        :stability: experimental
        '''
        return typing.cast("Securityhub", jsii.invoke(self, "toListControlEvaluationSummaries", []))

    @jsii.member(jsii_name="toListEnabledProductsForImport")
    def to_list_enabled_products_for_import(self) -> "Securityhub":
        '''(experimental) Grants permission to retrieve the Security Hub integrated products that are currently enabled.

        Access Level: List

        https://docs.aws.amazon.com/securityhub/1.0/APIReference/API_ListEnabledProductsForImport.html

        :stability: experimental
        '''
        return typing.cast("Securityhub", jsii.invoke(self, "toListEnabledProductsForImport", []))

    @jsii.member(jsii_name="toListFindingAggregators")
    def to_list_finding_aggregators(self) -> "Securityhub":
        '''(experimental) Grants permission to retrieve a list of finding aggregators, which contain the cross-Region finding aggregation configuration.

        Access Level: List

        https://docs.aws.amazon.com/securityhub/1.0/APIReference/API_UpdateFindingAggregator.html

        :stability: experimental
        '''
        return typing.cast("Securityhub", jsii.invoke(self, "toListFindingAggregators", []))

    @jsii.member(jsii_name="toListInvitations")
    def to_list_invitations(self) -> "Securityhub":
        '''(experimental) Grants permission to retrieve the Security Hub invitations sent to the account.

        Access Level: List

        https://docs.aws.amazon.com/securityhub/1.0/APIReference/API_ListInvitations.html

        :stability: experimental
        '''
        return typing.cast("Securityhub", jsii.invoke(self, "toListInvitations", []))

    @jsii.member(jsii_name="toListMembers")
    def to_list_members(self) -> "Securityhub":
        '''(experimental) Grants permission to retrieve details about Security Hub member accounts associated with the administrator account.

        Access Level: List

        https://docs.aws.amazon.com/securityhub/1.0/APIReference/API_ListMembers.html

        :stability: experimental
        '''
        return typing.cast("Securityhub", jsii.invoke(self, "toListMembers", []))

    @jsii.member(jsii_name="toListOrganizationAdminAccounts")
    def to_list_organization_admin_accounts(self) -> "Securityhub":
        '''(experimental) Grants permission to list the Security Hub administrator accounts for your organization.

        Access Level: List

        Dependent actions:

        - organizations:DescribeOrganization

        https://docs.aws.amazon.com/securityhub/1.0/APIReference/API_ListOrganizationAdminAccounts.html

        :stability: experimental
        '''
        return typing.cast("Securityhub", jsii.invoke(self, "toListOrganizationAdminAccounts", []))

    @jsii.member(jsii_name="toListSecurityControlDefinitions")
    def to_list_security_control_definitions(self) -> "Securityhub":
        '''(experimental) Grants permission to retrieve a list of security control definitions, which contain cross-Region control details for security controls.

        Access Level: List

        https://docs.aws.amazon.com/securityhub/latest/userguide/securityhub-standards.html

        :stability: experimental
        '''
        return typing.cast("Securityhub", jsii.invoke(self, "toListSecurityControlDefinitions", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Securityhub":
        '''(experimental) Grants permission to list of tags associated with a resource.

        Access Level: Read

        https://docs.aws.amazon.com/securityhub/1.0/APIReference/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("Securityhub", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toSendFindingEvents")
    def to_send_finding_events(self) -> "Securityhub":
        '''(experimental) Grants permission to use a custom action to send Security Hub findings to Amazon EventBridge.

        Access Level: Read

        https://docs.aws.amazon.com/securityhub/1.0/APIReference/API_SendFindingEvents.html

        :stability: experimental
        '''
        return typing.cast("Securityhub", jsii.invoke(self, "toSendFindingEvents", []))

    @jsii.member(jsii_name="toSendInsightEvents")
    def to_send_insight_events(self) -> "Securityhub":
        '''(experimental) Grants permission to use a custom action to send Security Hub insights to Amazon EventBridge.

        Access Level: Read

        https://docs.aws.amazon.com/securityhub/1.0/APIReference/API_SendInsightEvents.html

        :stability: experimental
        '''
        return typing.cast("Securityhub", jsii.invoke(self, "toSendInsightEvents", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Securityhub":
        '''(experimental) Grants permission to add tags to a Security Hub resource.

        Access Level: Tagging

        https://docs.aws.amazon.com/securityhub/1.0/APIReference/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("Securityhub", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Securityhub":
        '''(experimental) Grants permission to remove tags from a Security Hub resource.

        Access Level: Tagging

        https://docs.aws.amazon.com/securityhub/1.0/APIReference/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("Securityhub", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateActionTarget")
    def to_update_action_target(self) -> "Securityhub":
        '''(experimental) Grants permission to update custom actions in Security Hub.

        Access Level: Write

        https://docs.aws.amazon.com/securityhub/1.0/APIReference/API_UpdateActionTarget.html

        :stability: experimental
        '''
        return typing.cast("Securityhub", jsii.invoke(self, "toUpdateActionTarget", []))

    @jsii.member(jsii_name="toUpdateFindingAggregator")
    def to_update_finding_aggregator(self) -> "Securityhub":
        '''(experimental) Grants permission to update a finding aggregator, which contains the cross-Region finding aggregation configuration.

        Access Level: Write

        https://docs.aws.amazon.com/securityhub/1.0/APIReference/API_UpdateFindingAggregator.html

        :stability: experimental
        '''
        return typing.cast("Securityhub", jsii.invoke(self, "toUpdateFindingAggregator", []))

    @jsii.member(jsii_name="toUpdateFindings")
    def to_update_findings(self) -> "Securityhub":
        '''(experimental) Grants permission to update Security Hub findings.

        Access Level: Write

        https://docs.aws.amazon.com/securityhub/1.0/APIReference/API_UpdateFindings.html

        :stability: experimental
        '''
        return typing.cast("Securityhub", jsii.invoke(self, "toUpdateFindings", []))

    @jsii.member(jsii_name="toUpdateInsight")
    def to_update_insight(self) -> "Securityhub":
        '''(experimental) Grants permission to update insights in Security Hub.

        Access Level: Write

        https://docs.aws.amazon.com/securityhub/1.0/APIReference/API_UpdateInsight.html

        :stability: experimental
        '''
        return typing.cast("Securityhub", jsii.invoke(self, "toUpdateInsight", []))

    @jsii.member(jsii_name="toUpdateOrganizationConfiguration")
    def to_update_organization_configuration(self) -> "Securityhub":
        '''(experimental) Grants permission to update the organization configuration for Security Hub.

        Access Level: Write

        https://docs.aws.amazon.com/securityhub/1.0/APIReference/API_UpdateOrganizationConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Securityhub", jsii.invoke(self, "toUpdateOrganizationConfiguration", []))

    @jsii.member(jsii_name="toUpdateSecurityHubConfiguration")
    def to_update_security_hub_configuration(self) -> "Securityhub":
        '''(experimental) Grants permission to update Security Hub configuration.

        Access Level: Write

        https://docs.aws.amazon.com/securityhub/1.0/APIReference/API_UpdateSecurityHubConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Securityhub", jsii.invoke(self, "toUpdateSecurityHubConfiguration", []))

    @jsii.member(jsii_name="toUpdateStandardsControl")
    def to_update_standards_control(self) -> "Securityhub":
        '''(experimental) Grants permission to update Security Hub standards controls.

        Access Level: Write

        https://docs.aws.amazon.com/securityhub/1.0/APIReference/API_UpdateStandardsControl.html

        :stability: experimental
        '''
        return typing.cast("Securityhub", jsii.invoke(self, "toUpdateStandardsControl", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__17d76b9029b0e9d26357846b0126a7fd192e65b3a4d23aa3543bd05749af9e7c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ae238d4560f4fcebb8d75143c0003a9347443bca96b608e55bdaad0b9e1576e8)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Securitylake(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Securitylake",
):
    '''(experimental) Statement provider for service `securitylake <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonsecuritylake.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `securitylake <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonsecuritylake.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="toCreateAwsLogSource")
    def to_create_aws_log_source(self) -> "Securitylake":
        '''(experimental) Grants permission to enable any source type in any region for accounts that are either part of a trusted organization or standalone accounts.

        Access Level: Write

        Dependent actions:

        - iam:CreateServiceLinkedRole
        - kms:CreateGrant
        - kms:DescribeKey

        https://docs.aws.amazon.com/security-lake/latest/APIReference/API_CreateAwsLogSource.html

        :stability: experimental
        '''
        return typing.cast("Securitylake", jsii.invoke(self, "toCreateAwsLogSource", []))

    @jsii.member(jsii_name="toCreateCustomLogSource")
    def to_create_custom_log_source(self) -> "Securitylake":
        '''(experimental) Grants permission to add a custom source name.

        Access Level: Write

        Dependent actions:

        - glue:CreateCrawler
        - glue:CreateDatabase
        - glue:CreateTable
        - glue:StartCrawlerSchedule
        - iam:DeleteRolePolicy
        - iam:GetRole
        - iam:PassRole
        - iam:PutRolePolicy
        - kms:CreateGrant
        - kms:DescribeKey
        - kms:GenerateDataKey
        - lakeformation:GrantPermissions
        - lakeformation:RegisterResource
        - s3:ListBucket
        - s3:PutObject

        https://docs.aws.amazon.com/security-lake/latest/APIReference/API_CreateCustomLogSource.html

        :stability: experimental
        '''
        return typing.cast("Securitylake", jsii.invoke(self, "toCreateCustomLogSource", []))

    @jsii.member(jsii_name="toCreateDatalake")
    def to_create_datalake(self) -> "Securitylake":
        '''(experimental) Grants permission to create a new Security Data Lake.

        Access Level: Write

        Dependent actions:

        - events:PutRule
        - events:PutTargets
        - iam:CreateServiceLinkedRole
        - iam:DeleteRolePolicy
        - iam:GetRole
        - iam:PassRole
        - iam:PutRolePolicy
        - kms:CreateGrant
        - kms:DescribeKey
        - lakeformation:GetDataLakeSettings
        - lakeformation:PutDataLakeSettings
        - lambda:CreateEventSourceMapping
        - lambda:CreateFunction
        - organizations:DescribeOrganization
        - organizations:ListDelegatedServicesForAccount
        - s3:CreateBucket
        - s3:ListBucket
        - s3:PutBucketPolicy
        - s3:PutBucketPublicAccessBlock
        - s3:PutBucketVersioning
        - sqs:CreateQueue
        - sqs:GetQueueAttributes
        - sqs:SetQueueAttributes

        https://docs.aws.amazon.com/security-lake/latest/APIReference/API_CreateDatalake.html

        :stability: experimental
        '''
        return typing.cast("Securitylake", jsii.invoke(self, "toCreateDatalake", []))

    @jsii.member(jsii_name="toCreateDatalakeAutoEnable")
    def to_create_datalake_auto_enable(self) -> "Securitylake":
        '''(experimental) Grants permission to add to the configuration for automatically enabling Amazon Security Lake access for new organization accounts.

        Access Level: Write

        https://docs.aws.amazon.com/security-lake/latest/APIReference/API_CreateDatalakeAutoEnable.html

        :stability: experimental
        '''
        return typing.cast("Securitylake", jsii.invoke(self, "toCreateDatalakeAutoEnable", []))

    @jsii.member(jsii_name="toCreateDatalakeDelegatedAdmin")
    def to_create_datalake_delegated_admin(self) -> "Securitylake":
        '''(experimental) Grants permission to designate the Amazon Security Lake administrator account for the organization.

        Access Level: Write

        Dependent actions:

        - iam:CreateServiceLinkedRole
        - organizations:DescribeOrganization
        - organizations:EnableAWSServiceAccess
        - organizations:ListDelegatedAdministrators
        - organizations:ListDelegatedServicesForAccount
        - organizations:RegisterDelegatedAdministrator

        https://docs.aws.amazon.com/security-lake/latest/APIReference/API_CreateDatalakeDelegatedAdmin.html

        :stability: experimental
        '''
        return typing.cast("Securitylake", jsii.invoke(self, "toCreateDatalakeDelegatedAdmin", []))

    @jsii.member(jsii_name="toCreateDatalakeExceptionsSubscription")
    def to_create_datalake_exceptions_subscription(self) -> "Securitylake":
        '''(experimental) Grants permission to get instant notifications about exceptions by subscribing to the SNS topics for exception notifications.

        Access Level: Write

        https://docs.aws.amazon.com/security-lake/latest/APIReference/API_CreateDatalakeExceptionsSubscription.html

        :stability: experimental
        '''
        return typing.cast("Securitylake", jsii.invoke(self, "toCreateDatalakeExceptionsSubscription", []))

    @jsii.member(jsii_name="toCreateSubscriber")
    def to_create_subscriber(self) -> "Securitylake":
        '''(experimental) Grants permission to create a subscription permission for accounts that are already enabled.

        Access Level: Write

        Dependent actions:

        - iam:CreateRole
        - iam:DeleteRolePolicy
        - iam:GetRole
        - iam:PutRolePolicy
        - lakeformation:GrantPermissions
        - lakeformation:ListPermissions
        - lakeformation:RegisterResource
        - lakeformation:RevokePermissions
        - ram:GetResourceShareAssociations
        - ram:GetResourceShares
        - ram:UpdateResourceShare
        - s3:PutObject

        https://docs.aws.amazon.com/security-lake/latest/APIReference/API_CreateSubscriber.html

        :stability: experimental
        '''
        return typing.cast("Securitylake", jsii.invoke(self, "toCreateSubscriber", []))

    @jsii.member(jsii_name="toCreateSubscriptionNotificationConfiguration")
    def to_create_subscription_notification_configuration(self) -> "Securitylake":
        '''(experimental) Grants permission to create a webhook invocation to notify a client when there is new data in the Data Lake.

        Access Level: Write

        Dependent actions:

        - events:CreateApiDestination
        - events:CreateConnection
        - events:DescribeRule
        - events:ListApiDestinations
        - events:ListConnections
        - events:PutRule
        - events:PutTargets
        - iam:DeleteRolePolicy
        - iam:GetRole
        - iam:PassRole
        - s3:GetBucketNotification
        - s3:PutBucketNotification
        - sqs:CreateQueue
        - sqs:DeleteQueue
        - sqs:GetQueueAttributes
        - sqs:GetQueueUrl
        - sqs:SetQueueAttributes

        https://docs.aws.amazon.com/security-lake/latest/APIReference/API_CreateSubscriptionNotificationConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Securitylake", jsii.invoke(self, "toCreateSubscriptionNotificationConfiguration", []))

    @jsii.member(jsii_name="toDeleteAwsLogSource")
    def to_delete_aws_log_source(self) -> "Securitylake":
        '''(experimental) Grants permission to disable any source type in any region for accounts that are either part of a trusted organization or standalone accounts.

        Access Level: Write

        https://docs.aws.amazon.com/security-lake/latest/APIReference/API_DeleteAwsLogSource.html

        :stability: experimental
        '''
        return typing.cast("Securitylake", jsii.invoke(self, "toDeleteAwsLogSource", []))

    @jsii.member(jsii_name="toDeleteCustomLogSource")
    def to_delete_custom_log_source(self) -> "Securitylake":
        '''(experimental) Grants permission to remove a custom source name.

        Access Level: Write

        Dependent actions:

        - glue:StopCrawlerSchedule

        https://docs.aws.amazon.com/security-lake/latest/APIReference/API_DeleteCustomLogSource.html

        :stability: experimental
        '''
        return typing.cast("Securitylake", jsii.invoke(self, "toDeleteCustomLogSource", []))

    @jsii.member(jsii_name="toDeleteDatalake")
    def to_delete_datalake(self) -> "Securitylake":
        '''(experimental) Grants permission to delete all Security Data Lakes.

        Access Level: Write

        Dependent actions:

        - organizations:DescribeOrganization
        - organizations:ListDelegatedAdministrators
        - organizations:ListDelegatedServicesForAccount

        https://docs.aws.amazon.com/security-lake/latest/APIReference/API_DeleteDatalake.html

        :stability: experimental
        '''
        return typing.cast("Securitylake", jsii.invoke(self, "toDeleteDatalake", []))

    @jsii.member(jsii_name="toDeleteDatalakeAutoEnable")
    def to_delete_datalake_auto_enable(self) -> "Securitylake":
        '''(experimental) Grants permission to remove from the existing configuration the automatic enabling of Amazon Security Lake access for new organization accounts.

        Access Level: Write

        https://docs.aws.amazon.com/security-lake/latest/APIReference/API_DeleteDatalakeAutoEnable.html

        :stability: experimental
        '''
        return typing.cast("Securitylake", jsii.invoke(self, "toDeleteDatalakeAutoEnable", []))

    @jsii.member(jsii_name="toDeleteDatalakeDelegatedAdmin")
    def to_delete_datalake_delegated_admin(self) -> "Securitylake":
        '''(experimental) Grants permission to remove the Delegated Administrator account and disable Amazon Security Lake as a service for this organization.

        Access Level: Write

        Dependent actions:

        - organizations:DeregisterDelegatedAdministrator
        - organizations:DescribeOrganization
        - organizations:ListDelegatedServicesForAccount

        https://docs.aws.amazon.com/security-lake/latest/APIReference/API_DeleteDatalakeDelegatedAdmin.html

        :stability: experimental
        '''
        return typing.cast("Securitylake", jsii.invoke(self, "toDeleteDatalakeDelegatedAdmin", []))

    @jsii.member(jsii_name="toDeleteDatalakeExceptionsSubscription")
    def to_delete_datalake_exceptions_subscription(self) -> "Securitylake":
        '''(experimental) Grants permission to unsubscribe from SNS topics for exception notifications. Also, removes the SNS exception notifications topic.

        Access Level: Write

        https://docs.aws.amazon.com/security-lake/latest/APIReference/API_DeleteDatalakeExceptionsSubscription.html

        :stability: experimental
        '''
        return typing.cast("Securitylake", jsii.invoke(self, "toDeleteDatalakeExceptionsSubscription", []))

    @jsii.member(jsii_name="toDeleteSubscriber")
    def to_delete_subscriber(self) -> "Securitylake":
        '''(experimental) Grants permission to delete the specified subscription permissions for accounts that are already enabled.

        Access Level: Write

        Dependent actions:

        - events:DeleteApiDestination
        - events:DeleteConnection
        - events:DeleteRule
        - events:DescribeRule
        - events:ListApiDestinations
        - events:ListTargetsByRule
        - events:RemoveTargets
        - iam:DeleteRole
        - iam:DeleteRolePolicy
        - iam:GetRole
        - iam:ListRolePolicies
        - lakeformation:ListPermissions
        - lakeformation:RevokePermissions
        - sqs:DeleteQueue
        - sqs:GetQueueUrl

        https://docs.aws.amazon.com/security-lake/latest/APIReference/API_DeleteSubscriber.html

        :stability: experimental
        '''
        return typing.cast("Securitylake", jsii.invoke(self, "toDeleteSubscriber", []))

    @jsii.member(jsii_name="toDeleteSubscriptionNotificationConfiguration")
    def to_delete_subscription_notification_configuration(self) -> "Securitylake":
        '''(experimental) Grants permission to remove a webhook invocation to notify a client when there is new data in the Data Lake.

        Access Level: Write

        Dependent actions:

        - events:DeleteApiDestination
        - events:DeleteConnection
        - events:DeleteRule
        - events:DescribeRule
        - events:ListApiDestinations
        - events:ListTargetsByRule
        - events:RemoveTargets
        - iam:DeleteRole
        - iam:DeleteRolePolicy
        - iam:GetRole
        - iam:ListRolePolicies
        - lakeformation:RevokePermissions
        - sqs:DeleteQueue
        - sqs:GetQueueUrl

        https://docs.aws.amazon.com/security-lake/latest/APIReference/API_DeleteSubscriptionNotificationConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Securitylake", jsii.invoke(self, "toDeleteSubscriptionNotificationConfiguration", []))

    @jsii.member(jsii_name="toGetDatalake")
    def to_get_datalake(self) -> "Securitylake":
        '''(experimental) Grants permission to get information on the Security Data Lake.

        Access Level: Read

        https://docs.aws.amazon.com/security-lake/latest/APIReference/API_GetDatalake.html

        :stability: experimental
        '''
        return typing.cast("Securitylake", jsii.invoke(self, "toGetDatalake", []))

    @jsii.member(jsii_name="toGetDatalakeAutoEnable")
    def to_get_datalake_auto_enable(self) -> "Securitylake":
        '''(experimental) Grants permission to get an organization’s configuration setting for the automatic enabling of Amazon Security Lake access for new organization accounts.

        Access Level: Read

        Dependent actions:

        - organizations:DescribeOrganization

        https://docs.aws.amazon.com/security-lake/latest/APIReference/API_GetDatalakeAutoEnable.html

        :stability: experimental
        '''
        return typing.cast("Securitylake", jsii.invoke(self, "toGetDatalakeAutoEnable", []))

    @jsii.member(jsii_name="toGetDatalakeExceptionsExpiry")
    def to_get_datalake_exceptions_expiry(self) -> "Securitylake":
        '''(experimental) Grants permission to allow user to query what was set as the expiration period for the exception message.

        Access Level: Read

        https://docs.aws.amazon.com/security-lake/latest/APIReference/API_GetDatalakeExceptionsExpiry.html

        :stability: experimental
        '''
        return typing.cast("Securitylake", jsii.invoke(self, "toGetDatalakeExceptionsExpiry", []))

    @jsii.member(jsii_name="toGetDatalakeExceptionsSubscription")
    def to_get_datalake_exceptions_subscription(self) -> "Securitylake":
        '''(experimental) Grants permission to query the protocol and endpoint that were supplied when subscribing to the SNS topics for exception notifications.

        Access Level: Read

        https://docs.aws.amazon.com/security-lake/latest/APIReference/API_GetDatalakeExceptionsSubscription.html

        :stability: experimental
        '''
        return typing.cast("Securitylake", jsii.invoke(self, "toGetDatalakeExceptionsSubscription", []))

    @jsii.member(jsii_name="toGetDatalakeStatus")
    def to_get_datalake_status(self) -> "Securitylake":
        '''(experimental) Grants permission to get a static snapshot of the Security Data Lake in the current region, including enabled accounts and log sources.

        Access Level: Read

        https://docs.aws.amazon.com/security-lake/latest/APIReference/API_GetDatalakeStatus.html

        :stability: experimental
        '''
        return typing.cast("Securitylake", jsii.invoke(self, "toGetDatalakeStatus", []))

    @jsii.member(jsii_name="toGetSubscriber")
    def to_get_subscriber(self) -> "Securitylake":
        '''(experimental) Grants permission to get subscription information for a subscription permission for accounts that are already enabled.

        Access Level: Read

        https://docs.aws.amazon.com/security-lake/latest/APIReference/API_GetSubscriber.html

        :stability: experimental
        '''
        return typing.cast("Securitylake", jsii.invoke(self, "toGetSubscriber", []))

    @jsii.member(jsii_name="toGetSubscriptionNotificationConfiguration")
    def to_get_subscription_notification_configuration(self) -> "Securitylake":
        '''(experimental) Grants permission to get information for a webhook invocation to notify a client when there is new data in the Data Lake.

        Access Level: Read

        https://docs.aws.amazon.com/security-lake/latest/APIReference/API_GetSubscriptionNotificationConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Securitylake", jsii.invoke(self, "toGetSubscriptionNotificationConfiguration", []))

    @jsii.member(jsii_name="toListDatalakeExceptions")
    def to_list_datalake_exceptions(self) -> "Securitylake":
        '''(experimental) Grants permission to get the list of all non-retry-able failures.

        Access Level: List

        https://docs.aws.amazon.com/security-lake/latest/APIReference/API_ListDatalakeExceptions.html

        :stability: experimental
        '''
        return typing.cast("Securitylake", jsii.invoke(self, "toListDatalakeExceptions", []))

    @jsii.member(jsii_name="toListLogSources")
    def to_list_log_sources(self) -> "Securitylake":
        '''(experimental) Grants permission to show the estate view of enabled accounts with the enabled sources in the enabled regions.

        Access Level: List

        https://docs.aws.amazon.com/security-lake/latest/APIReference/API_ListLogSources.html

        :stability: experimental
        '''
        return typing.cast("Securitylake", jsii.invoke(self, "toListLogSources", []))

    @jsii.member(jsii_name="toListSubscribers")
    def to_list_subscribers(self) -> "Securitylake":
        '''(experimental) Grants permission to list all subscription permissions for accounts that are already enabled.

        Access Level: List

        https://docs.aws.amazon.com/security-lake/latest/APIReference/API_ListSubscribers.html

        :stability: experimental
        '''
        return typing.cast("Securitylake", jsii.invoke(self, "toListSubscribers", []))

    @jsii.member(jsii_name="toUpdateDatalake")
    def to_update_datalake(self) -> "Securitylake":
        '''(experimental) Grants permission to update a Security Data Lake.

        Access Level: Write

        Dependent actions:

        - events:PutRule
        - events:PutTargets
        - iam:CreateServiceLinkedRole
        - iam:DeleteRolePolicy
        - iam:GetRole
        - iam:PutRolePolicy
        - kms:CreateGrant
        - kms:DescribeKey
        - lakeformation:GetDataLakeSettings
        - lakeformation:PutDataLakeSettings
        - lambda:CreateEventSourceMapping
        - lambda:CreateFunction
        - organizations:DescribeOrganization
        - organizations:ListDelegatedServicesForAccount
        - s3:CreateBucket
        - s3:ListBucket
        - s3:PutBucketPolicy
        - s3:PutBucketPublicAccessBlock
        - s3:PutBucketVersioning
        - sqs:CreateQueue
        - sqs:GetQueueAttributes
        - sqs:SetQueueAttributes

        https://docs.aws.amazon.com/security-lake/latest/APIReference/API_UpdateDatalake.html

        :stability: experimental
        '''
        return typing.cast("Securitylake", jsii.invoke(self, "toUpdateDatalake", []))

    @jsii.member(jsii_name="toUpdateDatalakeExceptionsExpiry")
    def to_update_datalake_exceptions_expiry(self) -> "Securitylake":
        '''(experimental) Grants permission to control the time-to-live (TTL) for the exception message to remain in service cache.

        Access Level: Write

        https://docs.aws.amazon.com/security-lake/latest/APIReference/API_UpdateDatalakeExceptionsExpiry.html

        :stability: experimental
        '''
        return typing.cast("Securitylake", jsii.invoke(self, "toUpdateDatalakeExceptionsExpiry", []))

    @jsii.member(jsii_name="toUpdateDatalakeExceptionsSubscription")
    def to_update_datalake_exceptions_subscription(self) -> "Securitylake":
        '''(experimental) Grants permission to update subscriptions to the SNS topics for exception notifications.

        Access Level: Write

        https://docs.aws.amazon.com/security-lake/latest/APIReference/API_UpdateDatalakeExceptionsSubscription.html

        :stability: experimental
        '''
        return typing.cast("Securitylake", jsii.invoke(self, "toUpdateDatalakeExceptionsSubscription", []))

    @jsii.member(jsii_name="toUpdateSubscriber")
    def to_update_subscriber(self) -> "Securitylake":
        '''(experimental) Grants permission to update subscription information for a subscription permission for accounts that are already enabled.

        Access Level: Write

        Dependent actions:

        - events:CreateApiDestination
        - events:CreateConnection
        - events:DescribeRule
        - events:ListApiDestinations
        - events:ListConnections
        - events:PutRule
        - events:PutTargets
        - iam:DeleteRolePolicy
        - iam:GetRole
        - iam:PutRolePolicy

        https://docs.aws.amazon.com/security-lake/latest/APIReference/API_UpdateSubscriber.html

        :stability: experimental
        '''
        return typing.cast("Securitylake", jsii.invoke(self, "toUpdateSubscriber", []))

    @jsii.member(jsii_name="toUpdateSubscriptionNotificationConfiguration")
    def to_update_subscription_notification_configuration(self) -> "Securitylake":
        '''(experimental) Grants permission to update a webhook invocation to notify a client when there is new data in the Data Lake.

        Access Level: Write

        Dependent actions:

        - events:CreateApiDestination
        - events:CreateConnection
        - events:DescribeRule
        - events:ListApiDestinations
        - events:ListConnections
        - events:PutRule
        - events:PutTargets
        - iam:CreateServiceLinkedRole
        - iam:DeleteRolePolicy
        - iam:GetRole
        - iam:PassRole
        - iam:PutRolePolicy
        - s3:CreateBucket
        - s3:GetBucketNotification
        - s3:ListBucket
        - s3:PutBucketNotification
        - s3:PutBucketPolicy
        - s3:PutBucketPublicAccessBlock
        - s3:PutBucketVersioning
        - s3:PutLifecycleConfiguration
        - sqs:CreateQueue
        - sqs:DeleteQueue
        - sqs:GetQueueAttributes
        - sqs:GetQueueUrl
        - sqs:SetQueueAttributes

        https://docs.aws.amazon.com/security-lake/latest/APIReference/API_UpdateSubscriptionNotificationConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Securitylake", jsii.invoke(self, "toUpdateSubscriptionNotificationConfiguration", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2b1bb07fcae906438d3480effc1a4c094620b712ebcede5debb22d88992e55b3)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e43512d29e8b537e8ce70472b52eb3c387c2d0d0b5969a29b9e52a87d0be1835)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Serverlessrepo(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Serverlessrepo",
):
    '''(experimental) Statement provider for service `serverlessrepo <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsserverlessapplicationrepository.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `serverlessrepo <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsserverlessapplicationrepository.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="ifApplicationType")
    def if_application_type(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Serverlessrepo":
        '''(experimental) Filters access by application type.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/applications.html

        Applies to actions:

        - .toCreateCloudFormationChangeSet()
        - .toCreateCloudFormationTemplate()
        - .toGetApplication()
        - .toListApplicationDependencies()
        - .toListApplicationVersions()
        - .toSearchApplications()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5639be045bb5eea1b99a8f94aa18115e33a59db228dbe35235011b7163b8bfc9)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Serverlessrepo", jsii.invoke(self, "ifApplicationType", [value, operator]))

    @jsii.member(jsii_name="onApplications")
    def on_applications(
        self,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Serverlessrepo":
        '''(experimental) Adds a resource of type applications to the statement.

        https://docs.aws.amazon.com/serverlessrepo/latest/devguide/applications.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c794e7465c36846c57f58d96a8b6c939b67842c805d3a029ec7a464a63639bec)
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Serverlessrepo", jsii.invoke(self, "onApplications", [resource_id, account, region, partition]))

    @jsii.member(jsii_name="toCreateApplication")
    def to_create_application(self) -> "Serverlessrepo":
        '''(experimental) Grants permission to create an application, optionally including an AWS SAM file to create the first application version in the same call.

        Access Level: Write

        https://docs.aws.amazon.com/serverlessrepo/latest/devguide/applications.html

        :stability: experimental
        '''
        return typing.cast("Serverlessrepo", jsii.invoke(self, "toCreateApplication", []))

    @jsii.member(jsii_name="toCreateApplicationVersion")
    def to_create_application_version(self) -> "Serverlessrepo":
        '''(experimental) Grants permission to create an application version.

        Access Level: Write

        https://docs.aws.amazon.com/serverlessrepo/latest/devguide/applications-applicationid-versions-semanticversion.html

        :stability: experimental
        '''
        return typing.cast("Serverlessrepo", jsii.invoke(self, "toCreateApplicationVersion", []))

    @jsii.member(jsii_name="toCreateCloudFormationChangeSet")
    def to_create_cloud_formation_change_set(self) -> "Serverlessrepo":
        '''(experimental) Grants permission to create an AWS CloudFormation ChangeSet for the given application.

        Access Level: Write

        Possible conditions:

        - .ifApplicationType()

        https://docs.aws.amazon.com/serverlessrepo/latest/devguide/applications-applicationid-changesets.html

        :stability: experimental
        '''
        return typing.cast("Serverlessrepo", jsii.invoke(self, "toCreateCloudFormationChangeSet", []))

    @jsii.member(jsii_name="toCreateCloudFormationTemplate")
    def to_create_cloud_formation_template(self) -> "Serverlessrepo":
        '''(experimental) Grants permission to create an AWS CloudFormation template.

        Access Level: Write

        Possible conditions:

        - .ifApplicationType()

        https://docs.aws.amazon.com/serverlessrepo/latest/devguide/applications-applicationid-templates.html

        :stability: experimental
        '''
        return typing.cast("Serverlessrepo", jsii.invoke(self, "toCreateCloudFormationTemplate", []))

    @jsii.member(jsii_name="toDeleteApplication")
    def to_delete_application(self) -> "Serverlessrepo":
        '''(experimental) Grants permission to delete the specified application.

        Access Level: Write

        https://docs.aws.amazon.com/serverlessrepo/latest/devguide/applications-applicationid.html

        :stability: experimental
        '''
        return typing.cast("Serverlessrepo", jsii.invoke(self, "toDeleteApplication", []))

    @jsii.member(jsii_name="toGetApplication")
    def to_get_application(self) -> "Serverlessrepo":
        '''(experimental) Grants permission to get the specified application.

        Access Level: Read

        Possible conditions:

        - .ifApplicationType()

        https://docs.aws.amazon.com/serverlessrepo/latest/devguide/applications-applicationid.html

        :stability: experimental
        '''
        return typing.cast("Serverlessrepo", jsii.invoke(self, "toGetApplication", []))

    @jsii.member(jsii_name="toGetApplicationPolicy")
    def to_get_application_policy(self) -> "Serverlessrepo":
        '''(experimental) Grants permission to get the policy for the specified application.

        Access Level: Read

        https://docs.aws.amazon.com/serverlessrepo/latest/devguide/applications-applicationid-policy.html

        :stability: experimental
        '''
        return typing.cast("Serverlessrepo", jsii.invoke(self, "toGetApplicationPolicy", []))

    @jsii.member(jsii_name="toGetCloudFormationTemplate")
    def to_get_cloud_formation_template(self) -> "Serverlessrepo":
        '''(experimental) Grants permission to get the specified AWS CloudFormation template.

        Access Level: Read

        https://docs.aws.amazon.com/serverlessrepo/latest/devguide/applications-applicationid-templates-templateid.html

        :stability: experimental
        '''
        return typing.cast("Serverlessrepo", jsii.invoke(self, "toGetCloudFormationTemplate", []))

    @jsii.member(jsii_name="toListApplicationDependencies")
    def to_list_application_dependencies(self) -> "Serverlessrepo":
        '''(experimental) Grants permission to retrieve the list of applications nested in the containing application.

        Access Level: List

        Possible conditions:

        - .ifApplicationType()

        https://docs.aws.amazon.com/serverlessrepo/latest/devguide/applications-applicationid-dependencies.html

        :stability: experimental
        '''
        return typing.cast("Serverlessrepo", jsii.invoke(self, "toListApplicationDependencies", []))

    @jsii.member(jsii_name="toListApplications")
    def to_list_applications(self) -> "Serverlessrepo":
        '''(experimental) Grants permission to list applications owned by the requester.

        Access Level: List

        https://docs.aws.amazon.com/serverlessrepo/latest/devguide/applications.html

        :stability: experimental
        '''
        return typing.cast("Serverlessrepo", jsii.invoke(self, "toListApplications", []))

    @jsii.member(jsii_name="toListApplicationVersions")
    def to_list_application_versions(self) -> "Serverlessrepo":
        '''(experimental) Grants permission to list versions for the specified application owned by the requester.

        Access Level: List

        Possible conditions:

        - .ifApplicationType()

        https://docs.aws.amazon.com/serverlessrepo/latest/devguide/applications-applicationid-versions.html

        :stability: experimental
        '''
        return typing.cast("Serverlessrepo", jsii.invoke(self, "toListApplicationVersions", []))

    @jsii.member(jsii_name="toPutApplicationPolicy")
    def to_put_application_policy(self) -> "Serverlessrepo":
        '''(experimental) Grants permission to put the policy for the specified application.

        Access Level: Write

        https://docs.aws.amazon.com/serverlessrepo/latest/devguide/applications-applicationid-policy.html

        :stability: experimental
        '''
        return typing.cast("Serverlessrepo", jsii.invoke(self, "toPutApplicationPolicy", []))

    @jsii.member(jsii_name="toSearchApplications")
    def to_search_applications(self) -> "Serverlessrepo":
        '''(experimental) Grants permission to get all applications authorized for this user.

        Access Level: Read

        Possible conditions:

        - .ifApplicationType()

        https://docs.aws.amazon.com/serverlessrepo/latest/devguide/applications-applicationid.html

        :stability: experimental
        '''
        return typing.cast("Serverlessrepo", jsii.invoke(self, "toSearchApplications", []))

    @jsii.member(jsii_name="toUnshareApplication")
    def to_unshare_application(self) -> "Serverlessrepo":
        '''(experimental) Grants permission to unshare the specified application.

        Access Level: Write

        https://docs.aws.amazon.com/serverlessrepo/latest/devguide/applications-applicationid.html

        :stability: experimental
        '''
        return typing.cast("Serverlessrepo", jsii.invoke(self, "toUnshareApplication", []))

    @jsii.member(jsii_name="toUpdateApplication")
    def to_update_application(self) -> "Serverlessrepo":
        '''(experimental) Grants permission to update meta-data of the application.

        Access Level: Write

        https://docs.aws.amazon.com/serverlessrepo/latest/devguide/applications-applicationid.html

        :stability: experimental
        '''
        return typing.cast("Serverlessrepo", jsii.invoke(self, "toUpdateApplication", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4831d491d7d99bf9d21f528475ef1980bacbca21e0bed9dbe509d521022d05e4)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__88de6abcfb38ad5ebad0b0171e88a299bbcb6038e05d5798aba678e831a542f6)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Servicecatalog(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Servicecatalog",
):
    '''(experimental) Statement provider for service `servicecatalog <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsservicecatalog.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `servicecatalog <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsservicecatalog.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="ifAccountLevel")
    def if_account_level(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Servicecatalog":
        '''(experimental) Filters access by user to see and perform actions on resources created by anyone in the account.

        https://docs.aws.amazon.com/servicecatalog/latest/adminguide/permissions-examples.html

        Applies to actions:

        - .toCreateProvisionedProductPlan()
        - .toDeleteProvisionedProductPlan()
        - .toDescribeProvisionedProduct()
        - .toDescribeProvisionedProductPlan()
        - .toDescribeRecord()
        - .toDescribeServiceActionExecutionParameters()
        - .toExecuteProvisionedProductPlan()
        - .toExecuteProvisionedProductServiceAction()
        - .toListProvisionedProductPlans()
        - .toListRecordHistory()
        - .toListServiceActionsForProvisioningArtifact()
        - .toListStackInstancesForProvisionedProduct()
        - .toScanProvisionedProducts()
        - .toSearchProvisionedProducts()
        - .toTerminateProvisionedProduct()
        - .toUpdateProvisionedProduct()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__64447ba0a500d0df654609f6fd96f854e457c35e99001ba6d966fec0900f6518)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Servicecatalog", jsii.invoke(self, "ifAccountLevel", [value, operator]))

    @jsii.member(jsii_name="ifResource")
    def if_resource(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Servicecatalog":
        '''(experimental) Filters access by controlling what value can be specified as the Resource parameter in an AppRegistry associate resource API.

        https://docs.aws.amazon.com/servicecatalog/latest/adminguide/permissions-examples.html

        Applies to actions:

        - .toAssociateResource()
        - .toDisassociateResource()
        - .toGetAssociatedResource()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ad1511cb011570be27c66d4008b3a98fc5d5c8f069db0c84ae9f2d635c81b025)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Servicecatalog", jsii.invoke(self, "ifResource", [value, operator]))

    @jsii.member(jsii_name="ifResourceType")
    def if_resource_type(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Servicecatalog":
        '''(experimental) Filters access by controlling what value can be specified as the ResourceType parameter in an AppRegistry associate resource API.

        https://docs.aws.amazon.com/servicecatalog/latest/adminguide/permissions-examples.html

        Applies to actions:

        - .toAssociateResource()
        - .toDisassociateResource()
        - .toGetAssociatedResource()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2ea66071cb4e7459edf6bc4a2f5fd2b8f37334a3bd3255b56e305ad821ae357a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Servicecatalog", jsii.invoke(self, "ifResourceType", [value, operator]))

    @jsii.member(jsii_name="ifRoleLevel")
    def if_role_level(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Servicecatalog":
        '''(experimental) Filters access by user to see and perform actions on resources created either by them or by anyone federating into the same role as them.

        https://docs.aws.amazon.com/servicecatalog/latest/adminguide/permissions-examples.html

        Applies to actions:

        - .toCreateProvisionedProductPlan()
        - .toDeleteProvisionedProductPlan()
        - .toDescribeProvisionedProduct()
        - .toDescribeProvisionedProductPlan()
        - .toDescribeRecord()
        - .toDescribeServiceActionExecutionParameters()
        - .toExecuteProvisionedProductPlan()
        - .toExecuteProvisionedProductServiceAction()
        - .toListProvisionedProductPlans()
        - .toListRecordHistory()
        - .toListServiceActionsForProvisioningArtifact()
        - .toListStackInstancesForProvisionedProduct()
        - .toScanProvisionedProducts()
        - .toSearchProvisionedProducts()
        - .toTerminateProvisionedProduct()
        - .toUpdateProvisionedProduct()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9749ecce11faf85a7f017060fb1187b73cfcf148d73d3ca17ae5a54f88715e1d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Servicecatalog", jsii.invoke(self, "ifRoleLevel", [value, operator]))

    @jsii.member(jsii_name="ifUserLevel")
    def if_user_level(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Servicecatalog":
        '''(experimental) Filters access by user to see and perform actions on only resources that they created.

        https://docs.aws.amazon.com/servicecatalog/latest/adminguide/permissions-examples.html

        Applies to actions:

        - .toCreateProvisionedProductPlan()
        - .toDeleteProvisionedProductPlan()
        - .toDescribeProvisionedProduct()
        - .toDescribeProvisionedProductPlan()
        - .toDescribeRecord()
        - .toDescribeServiceActionExecutionParameters()
        - .toExecuteProvisionedProductPlan()
        - .toExecuteProvisionedProductServiceAction()
        - .toListProvisionedProductPlans()
        - .toListRecordHistory()
        - .toListServiceActionsForProvisioningArtifact()
        - .toListStackInstancesForProvisionedProduct()
        - .toScanProvisionedProducts()
        - .toSearchProvisionedProducts()
        - .toTerminateProvisionedProduct()
        - .toUpdateProvisionedProduct()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1de14c25fd96f8b204651e123efed34970ef9527747659cc764e1e04c64c085a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Servicecatalog", jsii.invoke(self, "ifUserLevel", [value, operator]))

    @jsii.member(jsii_name="onApplication")
    def on_application(
        self,
        application_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Servicecatalog":
        '''(experimental) Adds a resource of type Application to the statement.

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_app-registry_CreateApplication.html

        :param application_id: - Identifier for the applicationId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__49e4a5dff0740ed9008de08db0327806af00c3a21e8feb193beb066d46963917)
            check_type(argname="argument application_id", value=application_id, expected_type=type_hints["application_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Servicecatalog", jsii.invoke(self, "onApplication", [application_id, account, region, partition]))

    @jsii.member(jsii_name="onAttributeGroup")
    def on_attribute_group(
        self,
        attribute_group_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Servicecatalog":
        '''(experimental) Adds a resource of type AttributeGroup to the statement.

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_app-registry_CreateAttributeGroup.html

        :param attribute_group_id: - Identifier for the attributeGroupId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bef6448a08daebed0033ab86ad4072ae48296923aed9bea12a5e9b519a31f7e1)
            check_type(argname="argument attribute_group_id", value=attribute_group_id, expected_type=type_hints["attribute_group_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Servicecatalog", jsii.invoke(self, "onAttributeGroup", [attribute_group_id, account, region, partition]))

    @jsii.member(jsii_name="onPortfolio")
    def on_portfolio(
        self,
        portfolio_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Servicecatalog":
        '''(experimental) Adds a resource of type Portfolio to the statement.

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_PortfolioDetail.html

        :param portfolio_id: - Identifier for the portfolioId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fffbc868179a360fdd6c51ae788dc2d24c3e92275d3e5005fc7766d12e3b976f)
            check_type(argname="argument portfolio_id", value=portfolio_id, expected_type=type_hints["portfolio_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Servicecatalog", jsii.invoke(self, "onPortfolio", [portfolio_id, account, region, partition]))

    @jsii.member(jsii_name="onProduct")
    def on_product(
        self,
        product_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Servicecatalog":
        '''(experimental) Adds a resource of type Product to the statement.

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_ProductViewDetail.html

        :param product_id: - Identifier for the productId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__550a2c1ac44ab2fd362abf7fc9ae928380ec80c988eaaa66cb73267564554333)
            check_type(argname="argument product_id", value=product_id, expected_type=type_hints["product_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Servicecatalog", jsii.invoke(self, "onProduct", [product_id, account, region, partition]))

    @jsii.member(jsii_name="toAcceptPortfolioShare")
    def to_accept_portfolio_share(self) -> "Servicecatalog":
        '''(experimental) Grants permission to accept a portfolio that has been shared with you.

        Access Level: Write

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_AcceptPortfolioShare.html

        :stability: experimental
        '''
        return typing.cast("Servicecatalog", jsii.invoke(self, "toAcceptPortfolioShare", []))

    @jsii.member(jsii_name="toAssociateAttributeGroup")
    def to_associate_attribute_group(self) -> "Servicecatalog":
        '''(experimental) Grants permission to associate an attribute group with an application.

        Access Level: Write

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_app-registry_AssociateAttributeGroup.html

        :stability: experimental
        '''
        return typing.cast("Servicecatalog", jsii.invoke(self, "toAssociateAttributeGroup", []))

    @jsii.member(jsii_name="toAssociateBudgetWithResource")
    def to_associate_budget_with_resource(self) -> "Servicecatalog":
        '''(experimental) Grants permission to associate a budget with a resource.

        Access Level: Write

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_AssociateBudgetWithResource.html

        :stability: experimental
        '''
        return typing.cast("Servicecatalog", jsii.invoke(self, "toAssociateBudgetWithResource", []))

    @jsii.member(jsii_name="toAssociatePrincipalWithPortfolio")
    def to_associate_principal_with_portfolio(self) -> "Servicecatalog":
        '''(experimental) Grants permission to associate an IAM principal with a portfolio, giving the specified principal access to any products associated with the specified portfolio.

        Access Level: Write

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_AssociatePrincipalWithPortfolio.html

        :stability: experimental
        '''
        return typing.cast("Servicecatalog", jsii.invoke(self, "toAssociatePrincipalWithPortfolio", []))

    @jsii.member(jsii_name="toAssociateProductWithPortfolio")
    def to_associate_product_with_portfolio(self) -> "Servicecatalog":
        '''(experimental) Grants permission to associate a product with a portfolio.

        Access Level: Write

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_AssociateProductWithPortfolio.html

        :stability: experimental
        '''
        return typing.cast("Servicecatalog", jsii.invoke(self, "toAssociateProductWithPortfolio", []))

    @jsii.member(jsii_name="toAssociateResource")
    def to_associate_resource(self) -> "Servicecatalog":
        '''(experimental) Grants permission to associate a resource with an application.

        Access Level: Write

        Possible conditions:

        - .ifResourceType()
        - .ifResource()

        Dependent actions:

        - cloudformation:DescribeStacks
        - resource-groups:CreateGroup
        - resource-groups:GetGroup
        - resource-groups:Tag

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_app-registry_AssociateResource.html

        :stability: experimental
        '''
        return typing.cast("Servicecatalog", jsii.invoke(self, "toAssociateResource", []))

    @jsii.member(jsii_name="toAssociateServiceActionWithProvisioningArtifact")
    def to_associate_service_action_with_provisioning_artifact(
        self,
    ) -> "Servicecatalog":
        '''(experimental) Grants permission to associate an action with a provisioning artifact.

        Access Level: Write

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_AssociateServiceActionWithProvisioningArtifact.html

        :stability: experimental
        '''
        return typing.cast("Servicecatalog", jsii.invoke(self, "toAssociateServiceActionWithProvisioningArtifact", []))

    @jsii.member(jsii_name="toAssociateTagOptionWithResource")
    def to_associate_tag_option_with_resource(self) -> "Servicecatalog":
        '''(experimental) Grants permission to associate the specified TagOption with the specified portfolio or product.

        Access Level: Write

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_AssociateTagOptionWithResource.html

        :stability: experimental
        '''
        return typing.cast("Servicecatalog", jsii.invoke(self, "toAssociateTagOptionWithResource", []))

    @jsii.member(jsii_name="toBatchAssociateServiceActionWithProvisioningArtifact")
    def to_batch_associate_service_action_with_provisioning_artifact(
        self,
    ) -> "Servicecatalog":
        '''(experimental) Grants permission to associate multiple self-service actions with provisioning artifacts.

        Access Level: Write

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_BatchAssociateServiceActionWithProvisioningArtifact.html

        :stability: experimental
        '''
        return typing.cast("Servicecatalog", jsii.invoke(self, "toBatchAssociateServiceActionWithProvisioningArtifact", []))

    @jsii.member(jsii_name="toBatchDisassociateServiceActionFromProvisioningArtifact")
    def to_batch_disassociate_service_action_from_provisioning_artifact(
        self,
    ) -> "Servicecatalog":
        '''(experimental) Grants permission to disassociate a batch of self-service actions from the specified provisioning artifact.

        Access Level: Write

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_BatchDisassociateServiceActionFromProvisioningArtifact.html

        :stability: experimental
        '''
        return typing.cast("Servicecatalog", jsii.invoke(self, "toBatchDisassociateServiceActionFromProvisioningArtifact", []))

    @jsii.member(jsii_name="toCopyProduct")
    def to_copy_product(self) -> "Servicecatalog":
        '''(experimental) Grants permission to copy the specified source product to the specified target product or a new product.

        Access Level: Write

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_CopyProduct.html

        :stability: experimental
        '''
        return typing.cast("Servicecatalog", jsii.invoke(self, "toCopyProduct", []))

    @jsii.member(jsii_name="toCreateApplication")
    def to_create_application(self) -> "Servicecatalog":
        '''(experimental) Grants permission to create an application.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - iam:CreateServiceLinkedRole

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_app-registry_CreateApplication.html

        :stability: experimental
        '''
        return typing.cast("Servicecatalog", jsii.invoke(self, "toCreateApplication", []))

    @jsii.member(jsii_name="toCreateAttributeGroup")
    def to_create_attribute_group(self) -> "Servicecatalog":
        '''(experimental) Grants permission to create an attribute group.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_app-registry_CreateAttributeGroup.html

        :stability: experimental
        '''
        return typing.cast("Servicecatalog", jsii.invoke(self, "toCreateAttributeGroup", []))

    @jsii.member(jsii_name="toCreateConstraint")
    def to_create_constraint(self) -> "Servicecatalog":
        '''(experimental) Grants permission to create a constraint on an associated product and portfolio.

        Access Level: Write

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_CreateConstraint.html

        :stability: experimental
        '''
        return typing.cast("Servicecatalog", jsii.invoke(self, "toCreateConstraint", []))

    @jsii.member(jsii_name="toCreatePortfolio")
    def to_create_portfolio(self) -> "Servicecatalog":
        '''(experimental) Grants permission to create a portfolio.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_CreatePortfolio.html

        :stability: experimental
        '''
        return typing.cast("Servicecatalog", jsii.invoke(self, "toCreatePortfolio", []))

    @jsii.member(jsii_name="toCreatePortfolioShare")
    def to_create_portfolio_share(self) -> "Servicecatalog":
        '''(experimental) Grants permission to share a portfolio you own with another AWS account.

        Access Level: Permissions management

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_CreatePortfolioShare.html

        :stability: experimental
        '''
        return typing.cast("Servicecatalog", jsii.invoke(self, "toCreatePortfolioShare", []))

    @jsii.member(jsii_name="toCreateProduct")
    def to_create_product(self) -> "Servicecatalog":
        '''(experimental) Grants permission to create a product and that product's first provisioning artifact.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_CreateProduct.html

        :stability: experimental
        '''
        return typing.cast("Servicecatalog", jsii.invoke(self, "toCreateProduct", []))

    @jsii.member(jsii_name="toCreateProvisionedProductPlan")
    def to_create_provisioned_product_plan(self) -> "Servicecatalog":
        '''(experimental) Grants permission to add a new provisioned product plan.

        Access Level: Write

        Possible conditions:

        - .ifAccountLevel()
        - .ifRoleLevel()
        - .ifUserLevel()

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_CreateProvisionedProductPlan.html

        :stability: experimental
        '''
        return typing.cast("Servicecatalog", jsii.invoke(self, "toCreateProvisionedProductPlan", []))

    @jsii.member(jsii_name="toCreateProvisioningArtifact")
    def to_create_provisioning_artifact(self) -> "Servicecatalog":
        '''(experimental) Grants permission to add a new provisioning artifact to an existing product.

        Access Level: Write

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_CreateProvisioningArtifact.html

        :stability: experimental
        '''
        return typing.cast("Servicecatalog", jsii.invoke(self, "toCreateProvisioningArtifact", []))

    @jsii.member(jsii_name="toCreateServiceAction")
    def to_create_service_action(self) -> "Servicecatalog":
        '''(experimental) Grants permission to create a self-service action.

        Access Level: Write

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_CreateServiceAction.html

        :stability: experimental
        '''
        return typing.cast("Servicecatalog", jsii.invoke(self, "toCreateServiceAction", []))

    @jsii.member(jsii_name="toCreateTagOption")
    def to_create_tag_option(self) -> "Servicecatalog":
        '''(experimental) Grants permission to create a TagOption.

        Access Level: Write

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_CreateTagOption.html

        :stability: experimental
        '''
        return typing.cast("Servicecatalog", jsii.invoke(self, "toCreateTagOption", []))

    @jsii.member(jsii_name="toDeleteApplication")
    def to_delete_application(self) -> "Servicecatalog":
        '''(experimental) Grants permission to delete an application if all associations have been removed from the application.

        Access Level: Write

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_app-registry_DeleteApplication.html

        :stability: experimental
        '''
        return typing.cast("Servicecatalog", jsii.invoke(self, "toDeleteApplication", []))

    @jsii.member(jsii_name="toDeleteAttributeGroup")
    def to_delete_attribute_group(self) -> "Servicecatalog":
        '''(experimental) Grants permission to delete an attribute group if all associations have been removed from the attribute group.

        Access Level: Write

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_app-registry_DeleteAttributeGroup.html

        :stability: experimental
        '''
        return typing.cast("Servicecatalog", jsii.invoke(self, "toDeleteAttributeGroup", []))

    @jsii.member(jsii_name="toDeleteConstraint")
    def to_delete_constraint(self) -> "Servicecatalog":
        '''(experimental) Grants permission to remove and delete an existing constraint from an associated product and portfolio.

        Access Level: Write

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_DeleteConstraint.html

        :stability: experimental
        '''
        return typing.cast("Servicecatalog", jsii.invoke(self, "toDeleteConstraint", []))

    @jsii.member(jsii_name="toDeletePortfolio")
    def to_delete_portfolio(self) -> "Servicecatalog":
        '''(experimental) Grants permission to delete a portfolio if all associations and shares have been removed from the portfolio.

        Access Level: Write

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_DeletePortfolio.html

        :stability: experimental
        '''
        return typing.cast("Servicecatalog", jsii.invoke(self, "toDeletePortfolio", []))

    @jsii.member(jsii_name="toDeletePortfolioShare")
    def to_delete_portfolio_share(self) -> "Servicecatalog":
        '''(experimental) Grants permission to unshare a portfolio you own from an AWS account you previously shared the portfolio with.

        Access Level: Permissions management

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_DeletePortfolioShare.html

        :stability: experimental
        '''
        return typing.cast("Servicecatalog", jsii.invoke(self, "toDeletePortfolioShare", []))

    @jsii.member(jsii_name="toDeleteProduct")
    def to_delete_product(self) -> "Servicecatalog":
        '''(experimental) Grants permission to delete a product if all associations have been removed from the product.

        Access Level: Write

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_DeleteProduct.html

        :stability: experimental
        '''
        return typing.cast("Servicecatalog", jsii.invoke(self, "toDeleteProduct", []))

    @jsii.member(jsii_name="toDeleteProvisionedProductPlan")
    def to_delete_provisioned_product_plan(self) -> "Servicecatalog":
        '''(experimental) Grants permission to delete a provisioned product plan.

        Access Level: Write

        Possible conditions:

        - .ifAccountLevel()
        - .ifRoleLevel()
        - .ifUserLevel()

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_DeleteProvisionedProductPlan.html

        :stability: experimental
        '''
        return typing.cast("Servicecatalog", jsii.invoke(self, "toDeleteProvisionedProductPlan", []))

    @jsii.member(jsii_name="toDeleteProvisioningArtifact")
    def to_delete_provisioning_artifact(self) -> "Servicecatalog":
        '''(experimental) Grants permission to delete a provisioning artifact from a product.

        Access Level: Write

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_DeleteProvisioningArtifact.html

        :stability: experimental
        '''
        return typing.cast("Servicecatalog", jsii.invoke(self, "toDeleteProvisioningArtifact", []))

    @jsii.member(jsii_name="toDeleteServiceAction")
    def to_delete_service_action(self) -> "Servicecatalog":
        '''(experimental) Grants permission to delete a self-service action.

        Access Level: Write

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_DeleteServiceAction.html

        :stability: experimental
        '''
        return typing.cast("Servicecatalog", jsii.invoke(self, "toDeleteServiceAction", []))

    @jsii.member(jsii_name="toDeleteTagOption")
    def to_delete_tag_option(self) -> "Servicecatalog":
        '''(experimental) Grants permission to delete the specified TagOption.

        Access Level: Write

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_DeleteTagOption.html

        :stability: experimental
        '''
        return typing.cast("Servicecatalog", jsii.invoke(self, "toDeleteTagOption", []))

    @jsii.member(jsii_name="toDescribeConstraint")
    def to_describe_constraint(self) -> "Servicecatalog":
        '''(experimental) Grants permission to describe a constraint.

        Access Level: Read

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_DescribeConstraint.html

        :stability: experimental
        '''
        return typing.cast("Servicecatalog", jsii.invoke(self, "toDescribeConstraint", []))

    @jsii.member(jsii_name="toDescribeCopyProductStatus")
    def to_describe_copy_product_status(self) -> "Servicecatalog":
        '''(experimental) Grants permission to get the status of the specified copy product operation.

        Access Level: Read

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_DescribeCopyProductStatus.html

        :stability: experimental
        '''
        return typing.cast("Servicecatalog", jsii.invoke(self, "toDescribeCopyProductStatus", []))

    @jsii.member(jsii_name="toDescribePortfolio")
    def to_describe_portfolio(self) -> "Servicecatalog":
        '''(experimental) Grants permission to describe a portfolio.

        Access Level: Read

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_DescribePortfolio.html

        :stability: experimental
        '''
        return typing.cast("Servicecatalog", jsii.invoke(self, "toDescribePortfolio", []))

    @jsii.member(jsii_name="toDescribePortfolioShares")
    def to_describe_portfolio_shares(self) -> "Servicecatalog":
        '''(experimental) Grants permission to view a summary of each of the portfolio shares that were created for the specified portfolio.

        Access Level: List

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_DescribePortfolioShares.html

        :stability: experimental
        '''
        return typing.cast("Servicecatalog", jsii.invoke(self, "toDescribePortfolioShares", []))

    @jsii.member(jsii_name="toDescribePortfolioShareStatus")
    def to_describe_portfolio_share_status(self) -> "Servicecatalog":
        '''(experimental) Grants permission to get the status of the specified portfolio share operation.

        Access Level: Read

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_DescribePortfolioShareStatus.html

        :stability: experimental
        '''
        return typing.cast("Servicecatalog", jsii.invoke(self, "toDescribePortfolioShareStatus", []))

    @jsii.member(jsii_name="toDescribeProduct")
    def to_describe_product(self) -> "Servicecatalog":
        '''(experimental) Grants permission to describe a product as an end-user.

        Access Level: Read

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_DescribeProduct.html

        :stability: experimental
        '''
        return typing.cast("Servicecatalog", jsii.invoke(self, "toDescribeProduct", []))

    @jsii.member(jsii_name="toDescribeProductAsAdmin")
    def to_describe_product_as_admin(self) -> "Servicecatalog":
        '''(experimental) Grants permission to describe a product as an admin.

        Access Level: Read

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_DescribeProductAsAdmin.html

        :stability: experimental
        '''
        return typing.cast("Servicecatalog", jsii.invoke(self, "toDescribeProductAsAdmin", []))

    @jsii.member(jsii_name="toDescribeProductView")
    def to_describe_product_view(self) -> "Servicecatalog":
        '''(experimental) Grants permission to describe a product as an end-user.

        Access Level: Read

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_DescribeProductView.html

        :stability: experimental
        '''
        return typing.cast("Servicecatalog", jsii.invoke(self, "toDescribeProductView", []))

    @jsii.member(jsii_name="toDescribeProvisionedProduct")
    def to_describe_provisioned_product(self) -> "Servicecatalog":
        '''(experimental) Grants permission to describe a provisioned product.

        Access Level: Read

        Possible conditions:

        - .ifAccountLevel()
        - .ifRoleLevel()
        - .ifUserLevel()

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_DescribeProvisionedProduct.html

        :stability: experimental
        '''
        return typing.cast("Servicecatalog", jsii.invoke(self, "toDescribeProvisionedProduct", []))

    @jsii.member(jsii_name="toDescribeProvisionedProductPlan")
    def to_describe_provisioned_product_plan(self) -> "Servicecatalog":
        '''(experimental) Grants permission to describe a provisioned product plan.

        Access Level: Read

        Possible conditions:

        - .ifAccountLevel()
        - .ifRoleLevel()
        - .ifUserLevel()

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_DescribeProvisionedProductPlan.html

        :stability: experimental
        '''
        return typing.cast("Servicecatalog", jsii.invoke(self, "toDescribeProvisionedProductPlan", []))

    @jsii.member(jsii_name="toDescribeProvisioningArtifact")
    def to_describe_provisioning_artifact(self) -> "Servicecatalog":
        '''(experimental) Grants permission to describe a provisioning artifact.

        Access Level: Read

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_DescribeProvisioningArtifact.html

        :stability: experimental
        '''
        return typing.cast("Servicecatalog", jsii.invoke(self, "toDescribeProvisioningArtifact", []))

    @jsii.member(jsii_name="toDescribeProvisioningParameters")
    def to_describe_provisioning_parameters(self) -> "Servicecatalog":
        '''(experimental) Grants permission to describe the parameters that you need to specify to successfully provision a specified provisioning artifact.

        Access Level: Read

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_DescribeProvisioningParameters.html

        :stability: experimental
        '''
        return typing.cast("Servicecatalog", jsii.invoke(self, "toDescribeProvisioningParameters", []))

    @jsii.member(jsii_name="toDescribeRecord")
    def to_describe_record(self) -> "Servicecatalog":
        '''(experimental) Grants permission to describe a record and lists any outputs.

        Access Level: Read

        Possible conditions:

        - .ifAccountLevel()
        - .ifRoleLevel()
        - .ifUserLevel()

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_DescribeRecord.html

        :stability: experimental
        '''
        return typing.cast("Servicecatalog", jsii.invoke(self, "toDescribeRecord", []))

    @jsii.member(jsii_name="toDescribeServiceAction")
    def to_describe_service_action(self) -> "Servicecatalog":
        '''(experimental) Grants permission to describe a self-service action.

        Access Level: Read

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_DescribeServiceAction.html

        :stability: experimental
        '''
        return typing.cast("Servicecatalog", jsii.invoke(self, "toDescribeServiceAction", []))

    @jsii.member(jsii_name="toDescribeServiceActionExecutionParameters")
    def to_describe_service_action_execution_parameters(self) -> "Servicecatalog":
        '''(experimental) Grants permission to get the default parameters if you executed the specified Service Action on the specified Provisioned Product.

        Access Level: Read

        Possible conditions:

        - .ifAccountLevel()
        - .ifRoleLevel()
        - .ifUserLevel()

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_DescribeServiceActionExecutionParameters.html

        :stability: experimental
        '''
        return typing.cast("Servicecatalog", jsii.invoke(self, "toDescribeServiceActionExecutionParameters", []))

    @jsii.member(jsii_name="toDescribeTagOption")
    def to_describe_tag_option(self) -> "Servicecatalog":
        '''(experimental) Grants permission to get information about the specified TagOption.

        Access Level: Read

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_DescribeTagOption.html

        :stability: experimental
        '''
        return typing.cast("Servicecatalog", jsii.invoke(self, "toDescribeTagOption", []))

    @jsii.member(jsii_name="toDisableAWSOrganizationsAccess")
    def to_disable_aws_organizations_access(self) -> "Servicecatalog":
        '''(experimental) Grants permission to disable portfolio sharing through AWS Organizations feature.

        Access Level: Write

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_DisableAWSOrganizationsAccess.html

        :stability: experimental
        '''
        return typing.cast("Servicecatalog", jsii.invoke(self, "toDisableAWSOrganizationsAccess", []))

    @jsii.member(jsii_name="toDisassociateAttributeGroup")
    def to_disassociate_attribute_group(self) -> "Servicecatalog":
        '''(experimental) Grants permission to disassociate an attribute group from an application.

        Access Level: Write

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_app-registry_DisassociateAttributeGroup.html

        :stability: experimental
        '''
        return typing.cast("Servicecatalog", jsii.invoke(self, "toDisassociateAttributeGroup", []))

    @jsii.member(jsii_name="toDisassociateBudgetFromResource")
    def to_disassociate_budget_from_resource(self) -> "Servicecatalog":
        '''(experimental) Grants permission to disassociate a budget from a resource.

        Access Level: Write

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_DisassociateBudgetFromResource.html

        :stability: experimental
        '''
        return typing.cast("Servicecatalog", jsii.invoke(self, "toDisassociateBudgetFromResource", []))

    @jsii.member(jsii_name="toDisassociatePrincipalFromPortfolio")
    def to_disassociate_principal_from_portfolio(self) -> "Servicecatalog":
        '''(experimental) Grants permission to disassociate an IAM principal from a portfolio.

        Access Level: Write

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_DisassociatePrincipalFromPortfolio.html

        :stability: experimental
        '''
        return typing.cast("Servicecatalog", jsii.invoke(self, "toDisassociatePrincipalFromPortfolio", []))

    @jsii.member(jsii_name="toDisassociateProductFromPortfolio")
    def to_disassociate_product_from_portfolio(self) -> "Servicecatalog":
        '''(experimental) Grants permission to disassociate a product from a portfolio.

        Access Level: Write

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_DisassociateProductFromPortfolio.html

        :stability: experimental
        '''
        return typing.cast("Servicecatalog", jsii.invoke(self, "toDisassociateProductFromPortfolio", []))

    @jsii.member(jsii_name="toDisassociateResource")
    def to_disassociate_resource(self) -> "Servicecatalog":
        '''(experimental) Grants permission to disassociate a resource from an application.

        Access Level: Write

        Possible conditions:

        - .ifResourceType()
        - .ifResource()

        Dependent actions:

        - resource-groups:DeleteGroup

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_app-registry_DisassociateResource.html

        :stability: experimental
        '''
        return typing.cast("Servicecatalog", jsii.invoke(self, "toDisassociateResource", []))

    @jsii.member(jsii_name="toDisassociateServiceActionFromProvisioningArtifact")
    def to_disassociate_service_action_from_provisioning_artifact(
        self,
    ) -> "Servicecatalog":
        '''(experimental) Grants permission to disassociate the specified self-service action association from the specified provisioning artifact.

        Access Level: Write

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_DisassociateServiceActionFromProvisioningArtifact.html

        :stability: experimental
        '''
        return typing.cast("Servicecatalog", jsii.invoke(self, "toDisassociateServiceActionFromProvisioningArtifact", []))

    @jsii.member(jsii_name="toDisassociateTagOptionFromResource")
    def to_disassociate_tag_option_from_resource(self) -> "Servicecatalog":
        '''(experimental) Grants permission to disassociate the specified TagOption from the specified resource.

        Access Level: Write

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_DisassociateTagOptionFromResource.html

        :stability: experimental
        '''
        return typing.cast("Servicecatalog", jsii.invoke(self, "toDisassociateTagOptionFromResource", []))

    @jsii.member(jsii_name="toEnableAWSOrganizationsAccess")
    def to_enable_aws_organizations_access(self) -> "Servicecatalog":
        '''(experimental) Grants permission to enable portfolio sharing feature through AWS Organizations.

        Access Level: Write

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_EnableAWSOrganizationsAccess.html

        :stability: experimental
        '''
        return typing.cast("Servicecatalog", jsii.invoke(self, "toEnableAWSOrganizationsAccess", []))

    @jsii.member(jsii_name="toExecuteProvisionedProductPlan")
    def to_execute_provisioned_product_plan(self) -> "Servicecatalog":
        '''(experimental) Grants permission to execute a provisioned product plan.

        Access Level: Write

        Possible conditions:

        - .ifAccountLevel()
        - .ifRoleLevel()
        - .ifUserLevel()

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_ExecuteProvisionedProductPlan.html

        :stability: experimental
        '''
        return typing.cast("Servicecatalog", jsii.invoke(self, "toExecuteProvisionedProductPlan", []))

    @jsii.member(jsii_name="toExecuteProvisionedProductServiceAction")
    def to_execute_provisioned_product_service_action(self) -> "Servicecatalog":
        '''(experimental) Grants permission to executes a provisioned product plan.

        Access Level: Write

        Possible conditions:

        - .ifAccountLevel()
        - .ifRoleLevel()
        - .ifUserLevel()

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_ExecuteProvisionedProductServiceAction.html

        :stability: experimental
        '''
        return typing.cast("Servicecatalog", jsii.invoke(self, "toExecuteProvisionedProductServiceAction", []))

    @jsii.member(jsii_name="toGetApplication")
    def to_get_application(self) -> "Servicecatalog":
        '''(experimental) Grants permission to get an application.

        Access Level: Read

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_app-registry_GetApplication.html

        :stability: experimental
        '''
        return typing.cast("Servicecatalog", jsii.invoke(self, "toGetApplication", []))

    @jsii.member(jsii_name="toGetAssociatedResource")
    def to_get_associated_resource(self) -> "Servicecatalog":
        '''(experimental) Grants permission to get information about a resource associated to an application.

        Access Level: Read

        Possible conditions:

        - .ifResourceType()
        - .ifResource()

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_app-registry_GetAssociatedResource.html

        :stability: experimental
        '''
        return typing.cast("Servicecatalog", jsii.invoke(self, "toGetAssociatedResource", []))

    @jsii.member(jsii_name="toGetAttributeGroup")
    def to_get_attribute_group(self) -> "Servicecatalog":
        '''(experimental) Grants permission to get an attribute group.

        Access Level: Read

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_app-registry_GetAttributeGroup.html

        :stability: experimental
        '''
        return typing.cast("Servicecatalog", jsii.invoke(self, "toGetAttributeGroup", []))

    @jsii.member(jsii_name="toGetAWSOrganizationsAccessStatus")
    def to_get_aws_organizations_access_status(self) -> "Servicecatalog":
        '''(experimental) Grants permission to get the access status of AWS Organization portfolio share feature.

        Access Level: Read

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_GetAWSOrganizationsAccessStatus.html

        :stability: experimental
        '''
        return typing.cast("Servicecatalog", jsii.invoke(self, "toGetAWSOrganizationsAccessStatus", []))

    @jsii.member(jsii_name="toGetConfiguration")
    def to_get_configuration(self) -> "Servicecatalog":
        '''(experimental) Grants permission to read AppRegistry configurations.

        Access Level: Read

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_app-registry_GetConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Servicecatalog", jsii.invoke(self, "toGetConfiguration", []))

    @jsii.member(jsii_name="toGetProvisionedProductOutputs")
    def to_get_provisioned_product_outputs(self) -> "Servicecatalog":
        '''(experimental) Grants permission to get the provisioned product output with either provisioned product id or name.

        Access Level: Read

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_GetProvisionedProductOutputs.html

        :stability: experimental
        '''
        return typing.cast("Servicecatalog", jsii.invoke(self, "toGetProvisionedProductOutputs", []))

    @jsii.member(jsii_name="toImportAsProvisionedProduct")
    def to_import_as_provisioned_product(self) -> "Servicecatalog":
        '''(experimental) Grants permission to import a resource into a provisioned product.

        Access Level: Write

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_ImportAsProvisionedProduct.html

        :stability: experimental
        '''
        return typing.cast("Servicecatalog", jsii.invoke(self, "toImportAsProvisionedProduct", []))

    @jsii.member(jsii_name="toListAcceptedPortfolioShares")
    def to_list_accepted_portfolio_shares(self) -> "Servicecatalog":
        '''(experimental) Grants permission to list the portfolios that have been shared with you and you have accepted.

        Access Level: List

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_ListAcceptedPortfolioShares.html

        :stability: experimental
        '''
        return typing.cast("Servicecatalog", jsii.invoke(self, "toListAcceptedPortfolioShares", []))

    @jsii.member(jsii_name="toListApplications")
    def to_list_applications(self) -> "Servicecatalog":
        '''(experimental) Grants permission to list your applications.

        Access Level: List

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_app-registry_ListApplications.html

        :stability: experimental
        '''
        return typing.cast("Servicecatalog", jsii.invoke(self, "toListApplications", []))

    @jsii.member(jsii_name="toListAssociatedAttributeGroups")
    def to_list_associated_attribute_groups(self) -> "Servicecatalog":
        '''(experimental) Grants permission to list the attribute groups associated with an application.

        Access Level: List

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_app-registry_ListAssociatedAttributeGroups.html

        :stability: experimental
        '''
        return typing.cast("Servicecatalog", jsii.invoke(self, "toListAssociatedAttributeGroups", []))

    @jsii.member(jsii_name="toListAssociatedResources")
    def to_list_associated_resources(self) -> "Servicecatalog":
        '''(experimental) Grants permission to list the resources associated with an application.

        Access Level: List

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_app-registry_ListAssociatedResources.html

        :stability: experimental
        '''
        return typing.cast("Servicecatalog", jsii.invoke(self, "toListAssociatedResources", []))

    @jsii.member(jsii_name="toListAttributeGroups")
    def to_list_attribute_groups(self) -> "Servicecatalog":
        '''(experimental) Grants permission to list your attribute groups.

        Access Level: List

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_app-registry_ListAttributeGroups.html

        :stability: experimental
        '''
        return typing.cast("Servicecatalog", jsii.invoke(self, "toListAttributeGroups", []))

    @jsii.member(jsii_name="toListAttributeGroupsForApplication")
    def to_list_attribute_groups_for_application(self) -> "Servicecatalog":
        '''(experimental) Grants permission to list the associated attribute groups for a given application.

        Access Level: List

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_app-registry_ListAttributeGroupsForApplication.html

        :stability: experimental
        '''
        return typing.cast("Servicecatalog", jsii.invoke(self, "toListAttributeGroupsForApplication", []))

    @jsii.member(jsii_name="toListBudgetsForResource")
    def to_list_budgets_for_resource(self) -> "Servicecatalog":
        '''(experimental) Grants permission to list all the budgets associated to a resource.

        Access Level: List

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_ListBudgetsForResource.html

        :stability: experimental
        '''
        return typing.cast("Servicecatalog", jsii.invoke(self, "toListBudgetsForResource", []))

    @jsii.member(jsii_name="toListConstraintsForPortfolio")
    def to_list_constraints_for_portfolio(self) -> "Servicecatalog":
        '''(experimental) Grants permission to list constraints associated with a given portfolio.

        Access Level: List

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_ListConstraintsForPortfolio.html

        :stability: experimental
        '''
        return typing.cast("Servicecatalog", jsii.invoke(self, "toListConstraintsForPortfolio", []))

    @jsii.member(jsii_name="toListLaunchPaths")
    def to_list_launch_paths(self) -> "Servicecatalog":
        '''(experimental) Grants permission to list the different ways to launch a given product as an end-user.

        Access Level: List

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_ListLaunchPaths.html

        :stability: experimental
        '''
        return typing.cast("Servicecatalog", jsii.invoke(self, "toListLaunchPaths", []))

    @jsii.member(jsii_name="toListOrganizationPortfolioAccess")
    def to_list_organization_portfolio_access(self) -> "Servicecatalog":
        '''(experimental) Grants permission to list the organization nodes that have access to the specified portfolio.

        Access Level: List

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_ListOrganizationPortfolioAccess.html

        :stability: experimental
        '''
        return typing.cast("Servicecatalog", jsii.invoke(self, "toListOrganizationPortfolioAccess", []))

    @jsii.member(jsii_name="toListPortfolioAccess")
    def to_list_portfolio_access(self) -> "Servicecatalog":
        '''(experimental) Grants permission to list the AWS accounts you have shared a given portfolio with.

        Access Level: List

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_ListPortfolioAccess.html

        :stability: experimental
        '''
        return typing.cast("Servicecatalog", jsii.invoke(self, "toListPortfolioAccess", []))

    @jsii.member(jsii_name="toListPortfolios")
    def to_list_portfolios(self) -> "Servicecatalog":
        '''(experimental) Grants permission to list the portfolios in your account.

        Access Level: List

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_ListPortfolios.html

        :stability: experimental
        '''
        return typing.cast("Servicecatalog", jsii.invoke(self, "toListPortfolios", []))

    @jsii.member(jsii_name="toListPortfoliosForProduct")
    def to_list_portfolios_for_product(self) -> "Servicecatalog":
        '''(experimental) Grants permission to list the portfolios associated with a given product.

        Access Level: List

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_ListPortfoliosForProduct.html

        :stability: experimental
        '''
        return typing.cast("Servicecatalog", jsii.invoke(self, "toListPortfoliosForProduct", []))

    @jsii.member(jsii_name="toListPrincipalsForPortfolio")
    def to_list_principals_for_portfolio(self) -> "Servicecatalog":
        '''(experimental) Grants permission to list the IAM principals associated with a given portfolio.

        Access Level: List

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_ListPrincipalsForPortfolio.html

        :stability: experimental
        '''
        return typing.cast("Servicecatalog", jsii.invoke(self, "toListPrincipalsForPortfolio", []))

    @jsii.member(jsii_name="toListProvisionedProductPlans")
    def to_list_provisioned_product_plans(self) -> "Servicecatalog":
        '''(experimental) Grants permission to list the provisioned product plans.

        Access Level: List

        Possible conditions:

        - .ifAccountLevel()
        - .ifRoleLevel()
        - .ifUserLevel()

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_ListProvisionedProductPlans.html

        :stability: experimental
        '''
        return typing.cast("Servicecatalog", jsii.invoke(self, "toListProvisionedProductPlans", []))

    @jsii.member(jsii_name="toListProvisioningArtifacts")
    def to_list_provisioning_artifacts(self) -> "Servicecatalog":
        '''(experimental) Grants permission to list the provisioning artifacts associated with a given product.

        Access Level: List

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_ListProvisioningArtifacts.html

        :stability: experimental
        '''
        return typing.cast("Servicecatalog", jsii.invoke(self, "toListProvisioningArtifacts", []))

    @jsii.member(jsii_name="toListProvisioningArtifactsForServiceAction")
    def to_list_provisioning_artifacts_for_service_action(self) -> "Servicecatalog":
        '''(experimental) Grants permission to list all provisioning artifacts for the specified self-service action.

        Access Level: List

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_ListProvisioningArtifactsForServiceAction.html

        :stability: experimental
        '''
        return typing.cast("Servicecatalog", jsii.invoke(self, "toListProvisioningArtifactsForServiceAction", []))

    @jsii.member(jsii_name="toListRecordHistory")
    def to_list_record_history(self) -> "Servicecatalog":
        '''(experimental) Grants permission to list all the records in your account or all the records related to a given provisioned product.

        Access Level: List

        Possible conditions:

        - .ifAccountLevel()
        - .ifRoleLevel()
        - .ifUserLevel()

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_ListRecordHistory.html

        :stability: experimental
        '''
        return typing.cast("Servicecatalog", jsii.invoke(self, "toListRecordHistory", []))

    @jsii.member(jsii_name="toListResourcesForTagOption")
    def to_list_resources_for_tag_option(self) -> "Servicecatalog":
        '''(experimental) Grants permission to list the resources associated with the specified TagOption.

        Access Level: List

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_ListResourcesForTagOption.html

        :stability: experimental
        '''
        return typing.cast("Servicecatalog", jsii.invoke(self, "toListResourcesForTagOption", []))

    @jsii.member(jsii_name="toListServiceActions")
    def to_list_service_actions(self) -> "Servicecatalog":
        '''(experimental) Grants permission to list all self-service actions.

        Access Level: List

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_ListServiceActions.html

        :stability: experimental
        '''
        return typing.cast("Servicecatalog", jsii.invoke(self, "toListServiceActions", []))

    @jsii.member(jsii_name="toListServiceActionsForProvisioningArtifact")
    def to_list_service_actions_for_provisioning_artifact(self) -> "Servicecatalog":
        '''(experimental) Grants permission to list all the service actions associated with the specified provisioning artifact in your account.

        Access Level: List

        Possible conditions:

        - .ifAccountLevel()
        - .ifRoleLevel()
        - .ifUserLevel()

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_ListServiceActionsForProvisioningArtifact.html

        :stability: experimental
        '''
        return typing.cast("Servicecatalog", jsii.invoke(self, "toListServiceActionsForProvisioningArtifact", []))

    @jsii.member(jsii_name="toListStackInstancesForProvisionedProduct")
    def to_list_stack_instances_for_provisioned_product(self) -> "Servicecatalog":
        '''(experimental) Grants permission to list account, region and status of each stack instances that are associated with a CFN_STACKSET type provisioned product.

        Access Level: List

        Possible conditions:

        - .ifAccountLevel()
        - .ifRoleLevel()
        - .ifUserLevel()

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_ListStackInstancesForProvisionedProduct.html

        :stability: experimental
        '''
        return typing.cast("Servicecatalog", jsii.invoke(self, "toListStackInstancesForProvisionedProduct", []))

    @jsii.member(jsii_name="toListTagOptions")
    def to_list_tag_options(self) -> "Servicecatalog":
        '''(experimental) Grants permission to list the specified TagOptions or all TagOptions.

        Access Level: List

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_ListTagOptions.html

        :stability: experimental
        '''
        return typing.cast("Servicecatalog", jsii.invoke(self, "toListTagOptions", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Servicecatalog":
        '''(experimental) Grants permission to list the tags for a service catalog appregistry resource.

        Access Level: Read

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_app-registry_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("Servicecatalog", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toProvisionProduct")
    def to_provision_product(self) -> "Servicecatalog":
        '''(experimental) Grants permission to provision a product with a specified provisioning artifact and launch parameters.

        Access Level: Write

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_ProvisionProduct.html

        :stability: experimental
        '''
        return typing.cast("Servicecatalog", jsii.invoke(self, "toProvisionProduct", []))

    @jsii.member(jsii_name="toPutConfiguration")
    def to_put_configuration(self) -> "Servicecatalog":
        '''(experimental) Grants permission to assign AppRegistry configurations.

        Access Level: Write

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_app-registry_PutConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Servicecatalog", jsii.invoke(self, "toPutConfiguration", []))

    @jsii.member(jsii_name="toRejectPortfolioShare")
    def to_reject_portfolio_share(self) -> "Servicecatalog":
        '''(experimental) Grants permission to reject a portfolio that has been shared with you that you previously accepted.

        Access Level: Write

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_RejectPortfolioShare.html

        :stability: experimental
        '''
        return typing.cast("Servicecatalog", jsii.invoke(self, "toRejectPortfolioShare", []))

    @jsii.member(jsii_name="toScanProvisionedProducts")
    def to_scan_provisioned_products(self) -> "Servicecatalog":
        '''(experimental) Grants permission to list all the provisioned products in your account.

        Access Level: List

        Possible conditions:

        - .ifAccountLevel()
        - .ifRoleLevel()
        - .ifUserLevel()

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_ScanProvisionedProducts.html

        :stability: experimental
        '''
        return typing.cast("Servicecatalog", jsii.invoke(self, "toScanProvisionedProducts", []))

    @jsii.member(jsii_name="toSearchProducts")
    def to_search_products(self) -> "Servicecatalog":
        '''(experimental) Grants permission to list the products available to you as an end-user.

        Access Level: List

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_SearchProducts.html

        :stability: experimental
        '''
        return typing.cast("Servicecatalog", jsii.invoke(self, "toSearchProducts", []))

    @jsii.member(jsii_name="toSearchProductsAsAdmin")
    def to_search_products_as_admin(self) -> "Servicecatalog":
        '''(experimental) Grants permission to list all the products in your account or all the products associated with a given portfolio.

        Access Level: List

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_SearchProductsAsAdmin.html

        :stability: experimental
        '''
        return typing.cast("Servicecatalog", jsii.invoke(self, "toSearchProductsAsAdmin", []))

    @jsii.member(jsii_name="toSearchProvisionedProducts")
    def to_search_provisioned_products(self) -> "Servicecatalog":
        '''(experimental) Grants permission to list all the provisioned products in your account.

        Access Level: List

        Possible conditions:

        - .ifAccountLevel()
        - .ifRoleLevel()
        - .ifUserLevel()

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_SearchProvisionedProducts.html

        :stability: experimental
        '''
        return typing.cast("Servicecatalog", jsii.invoke(self, "toSearchProvisionedProducts", []))

    @jsii.member(jsii_name="toSyncResource")
    def to_sync_resource(self) -> "Servicecatalog":
        '''(experimental) Grants permission to sync a resource with its current state in AppRegistry.

        Access Level: Write

        Dependent actions:

        - cloudformation:UpdateStack

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_app-registry_SyncResource.html

        :stability: experimental
        '''
        return typing.cast("Servicecatalog", jsii.invoke(self, "toSyncResource", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Servicecatalog":
        '''(experimental) Grants permission to tag a service catalog appregistry resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_app-registry_TagResource.html

        :stability: experimental
        '''
        return typing.cast("Servicecatalog", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toTerminateProvisionedProduct")
    def to_terminate_provisioned_product(self) -> "Servicecatalog":
        '''(experimental) Grants permission to terminate an existing provisioned product.

        Access Level: Write

        Possible conditions:

        - .ifAccountLevel()
        - .ifRoleLevel()
        - .ifUserLevel()

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_TerminateProvisionedProduct.html

        :stability: experimental
        '''
        return typing.cast("Servicecatalog", jsii.invoke(self, "toTerminateProvisionedProduct", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Servicecatalog":
        '''(experimental) Grants permission to remove a tag from a service catalog appregistry resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_app-registry_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("Servicecatalog", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateApplication")
    def to_update_application(self) -> "Servicecatalog":
        '''(experimental) Grants permission to update the attributes of an existing application.

        Access Level: Write

        Dependent actions:

        - iam:CreateServiceLinkedRole

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_app-registry_UpdateApplication.html

        :stability: experimental
        '''
        return typing.cast("Servicecatalog", jsii.invoke(self, "toUpdateApplication", []))

    @jsii.member(jsii_name="toUpdateAttributeGroup")
    def to_update_attribute_group(self) -> "Servicecatalog":
        '''(experimental) Grants permission to update the attributes of an existing attribute group.

        Access Level: Write

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_app-registry_UpdateAttributeGroup.html

        :stability: experimental
        '''
        return typing.cast("Servicecatalog", jsii.invoke(self, "toUpdateAttributeGroup", []))

    @jsii.member(jsii_name="toUpdateConstraint")
    def to_update_constraint(self) -> "Servicecatalog":
        '''(experimental) Grants permission to update the metadata fields of an existing constraint.

        Access Level: Write

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_UpdateConstraint.html

        :stability: experimental
        '''
        return typing.cast("Servicecatalog", jsii.invoke(self, "toUpdateConstraint", []))

    @jsii.member(jsii_name="toUpdatePortfolio")
    def to_update_portfolio(self) -> "Servicecatalog":
        '''(experimental) Grants permission to update the metadata fields and/or tags of an existing portfolio.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_UpdatePortfolio.html

        :stability: experimental
        '''
        return typing.cast("Servicecatalog", jsii.invoke(self, "toUpdatePortfolio", []))

    @jsii.member(jsii_name="toUpdatePortfolioShare")
    def to_update_portfolio_share(self) -> "Servicecatalog":
        '''(experimental) Grants permission to enable or disable resource sharing for an existing portfolio share.

        Access Level: Permissions management

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_UpdatePortfolioShare.html

        :stability: experimental
        '''
        return typing.cast("Servicecatalog", jsii.invoke(self, "toUpdatePortfolioShare", []))

    @jsii.member(jsii_name="toUpdateProduct")
    def to_update_product(self) -> "Servicecatalog":
        '''(experimental) Grants permission to update the metadata fields and/or tags of an existing product.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_UpdateProduct.html

        :stability: experimental
        '''
        return typing.cast("Servicecatalog", jsii.invoke(self, "toUpdateProduct", []))

    @jsii.member(jsii_name="toUpdateProvisionedProduct")
    def to_update_provisioned_product(self) -> "Servicecatalog":
        '''(experimental) Grants permission to update an existing provisioned product.

        Access Level: Write

        Possible conditions:

        - .ifAccountLevel()
        - .ifRoleLevel()
        - .ifUserLevel()

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_UpdateProvisionedProduct.html

        :stability: experimental
        '''
        return typing.cast("Servicecatalog", jsii.invoke(self, "toUpdateProvisionedProduct", []))

    @jsii.member(jsii_name="toUpdateProvisionedProductProperties")
    def to_update_provisioned_product_properties(self) -> "Servicecatalog":
        '''(experimental) Grants permission to update the properties of an existing provisioned product.

        Access Level: Write

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_UpdateProvisionedProductProperties.html

        :stability: experimental
        '''
        return typing.cast("Servicecatalog", jsii.invoke(self, "toUpdateProvisionedProductProperties", []))

    @jsii.member(jsii_name="toUpdateProvisioningArtifact")
    def to_update_provisioning_artifact(self) -> "Servicecatalog":
        '''(experimental) Grants permission to update the metadata fields of an existing provisioning artifact.

        Access Level: Write

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_UpdateProvisioningArtifact.html

        :stability: experimental
        '''
        return typing.cast("Servicecatalog", jsii.invoke(self, "toUpdateProvisioningArtifact", []))

    @jsii.member(jsii_name="toUpdateServiceAction")
    def to_update_service_action(self) -> "Servicecatalog":
        '''(experimental) Grants permission to update a self-service action.

        Access Level: Write

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_UpdateServiceAction.html

        :stability: experimental
        '''
        return typing.cast("Servicecatalog", jsii.invoke(self, "toUpdateServiceAction", []))

    @jsii.member(jsii_name="toUpdateTagOption")
    def to_update_tag_option(self) -> "Servicecatalog":
        '''(experimental) Grants permission to update the specified TagOption.

        Access Level: Write

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_UpdateTagOption.html

        :stability: experimental
        '''
        return typing.cast("Servicecatalog", jsii.invoke(self, "toUpdateTagOption", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b9de06cbd0e4fc99b58fd55d12da6bcd9c6370d9b0ec93607e6feac49285481f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f7d8260b5ac347917a615787db21dab68b86b138b72879789b8ee7dbc1e08063)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Servicediscovery(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Servicediscovery",
):
    '''(experimental) Statement provider for service `servicediscovery <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awscloudmap.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `servicediscovery <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awscloudmap.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="ifNamespaceArn")
    def if_namespace_arn(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Servicediscovery":
        '''(experimental) Filters access by specifying the Amazon Resource Name (ARN) for the related namespace.

        https://docs.aws.amazon.com/cloud-map/latest/dg/access-control-overview.html#specifying-conditions

        Applies to actions:

        - .toCreateService()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__80f39cfcc77165c0522806ed5d31196e54d7badbdf9a7915848897c174606c3a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Servicediscovery", jsii.invoke(self, "ifNamespaceArn", [value, operator]))

    @jsii.member(jsii_name="ifNamespaceName")
    def if_namespace_name(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Servicediscovery":
        '''(experimental) Filters access by specifying the name of the related namespace.

        https://docs.aws.amazon.com/cloud-map/latest/dg/access-control-overview.html#specifying-conditions

        Applies to actions:

        - .toDiscoverInstances()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__35846e4557b60a659093adb8b753847181b1e11854578de985d34a3385e7ffd3)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Servicediscovery", jsii.invoke(self, "ifNamespaceName", [value, operator]))

    @jsii.member(jsii_name="ifServiceArn")
    def if_service_arn(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Servicediscovery":
        '''(experimental) Filters access by specifying the Amazon Resource Name (ARN) for the related service.

        https://docs.aws.amazon.com/cloud-map/latest/dg/access-control-overview.html#specifying-conditions

        Applies to actions:

        - .toDeregisterInstance()
        - .toGetInstance()
        - .toGetInstancesHealthStatus()
        - .toListInstances()
        - .toRegisterInstance()
        - .toUpdateInstanceCustomHealthStatus()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__85154aa6d52c39b16007ac6d327562ab63154cc50d82d6cd17dddd28dad5550c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Servicediscovery", jsii.invoke(self, "ifServiceArn", [value, operator]))

    @jsii.member(jsii_name="ifServiceName")
    def if_service_name(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Servicediscovery":
        '''(experimental) Filters access by specifying the name of the related service.

        https://docs.aws.amazon.com/cloud-map/latest/dg/access-control-overview.html#specifying-conditions

        Applies to actions:

        - .toDiscoverInstances()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3c76c851b7c52b045ed759af1b6444a134f7bc5e9ae081ee982a7d67c4c7784d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Servicediscovery", jsii.invoke(self, "ifServiceName", [value, operator]))

    @jsii.member(jsii_name="onNamespace")
    def on_namespace(
        self,
        namespace_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Servicediscovery":
        '''(experimental) Adds a resource of type namespace to the statement.

        https://docs.aws.amazon.com/cloud-map/latest/dg/API_Namespace.html

        :param namespace_id: - Identifier for the namespaceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a98259f9400bd267d1c4390ac2f844dd4b5e99c44e2c7b3fa975a18d8833aee9)
            check_type(argname="argument namespace_id", value=namespace_id, expected_type=type_hints["namespace_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Servicediscovery", jsii.invoke(self, "onNamespace", [namespace_id, account, region, partition]))

    @jsii.member(jsii_name="onService")
    def on_service(
        self,
        service_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Servicediscovery":
        '''(experimental) Adds a resource of type service to the statement.

        https://docs.aws.amazon.com/cloud-map/latest/dg/API_Service.html

        :param service_id: - Identifier for the serviceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2cdc586eacac80798e6f7893437e628fd5d10c28353e02ef076208a00df05b52)
            check_type(argname="argument service_id", value=service_id, expected_type=type_hints["service_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Servicediscovery", jsii.invoke(self, "onService", [service_id, account, region, partition]))

    @jsii.member(jsii_name="toCreateHttpNamespace")
    def to_create_http_namespace(self) -> "Servicediscovery":
        '''(experimental) Grants permission to create an HTTP namespace.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/cloud-map/latest/api/API_CreateHttpNamespace.html

        :stability: experimental
        '''
        return typing.cast("Servicediscovery", jsii.invoke(self, "toCreateHttpNamespace", []))

    @jsii.member(jsii_name="toCreatePrivateDnsNamespace")
    def to_create_private_dns_namespace(self) -> "Servicediscovery":
        '''(experimental) Grants permission to create a private namespace based on DNS, which will be visible only inside a specified Amazon VPC.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/cloud-map/latest/api/API_CreatePrivateDnsNamespace.html

        :stability: experimental
        '''
        return typing.cast("Servicediscovery", jsii.invoke(self, "toCreatePrivateDnsNamespace", []))

    @jsii.member(jsii_name="toCreatePublicDnsNamespace")
    def to_create_public_dns_namespace(self) -> "Servicediscovery":
        '''(experimental) Grants permission to create a public namespace based on DNS, which will be visible on the internet.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/cloud-map/latest/api/API_CreatePublicDnsNamespace.html

        :stability: experimental
        '''
        return typing.cast("Servicediscovery", jsii.invoke(self, "toCreatePublicDnsNamespace", []))

    @jsii.member(jsii_name="toCreateService")
    def to_create_service(self) -> "Servicediscovery":
        '''(experimental) Grants permission to create a service.

        Access Level: Write

        Possible conditions:

        - .ifNamespaceArn()
        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/cloud-map/latest/api/API_CreateService.html

        :stability: experimental
        '''
        return typing.cast("Servicediscovery", jsii.invoke(self, "toCreateService", []))

    @jsii.member(jsii_name="toDeleteNamespace")
    def to_delete_namespace(self) -> "Servicediscovery":
        '''(experimental) Grants permission to delete a specified namespace.

        Access Level: Write

        https://docs.aws.amazon.com/cloud-map/latest/api/API_DeleteNamespace.html

        :stability: experimental
        '''
        return typing.cast("Servicediscovery", jsii.invoke(self, "toDeleteNamespace", []))

    @jsii.member(jsii_name="toDeleteService")
    def to_delete_service(self) -> "Servicediscovery":
        '''(experimental) Grants permission to delete a specified service.

        Access Level: Write

        https://docs.aws.amazon.com/cloud-map/latest/api/API_DeleteService.html

        :stability: experimental
        '''
        return typing.cast("Servicediscovery", jsii.invoke(self, "toDeleteService", []))

    @jsii.member(jsii_name="toDeregisterInstance")
    def to_deregister_instance(self) -> "Servicediscovery":
        '''(experimental) Grants permission to delete the records and the health check, if any, that Amazon Route 53 created for the specified instance.

        Access Level: Write

        Possible conditions:

        - .ifServiceArn()

        https://docs.aws.amazon.com/cloud-map/latest/api/API_DeregisterInstance.html

        :stability: experimental
        '''
        return typing.cast("Servicediscovery", jsii.invoke(self, "toDeregisterInstance", []))

    @jsii.member(jsii_name="toDiscoverInstances")
    def to_discover_instances(self) -> "Servicediscovery":
        '''(experimental) Grants permission to discover registered instances for a specified namespace and service.

        Access Level: Read

        Possible conditions:

        - .ifNamespaceName()
        - .ifServiceName()

        https://docs.aws.amazon.com/cloud-map/latest/api/API_DiscoverInstances.html

        :stability: experimental
        '''
        return typing.cast("Servicediscovery", jsii.invoke(self, "toDiscoverInstances", []))

    @jsii.member(jsii_name="toGetInstance")
    def to_get_instance(self) -> "Servicediscovery":
        '''(experimental) Grants permission to get information about a specified instance.

        Access Level: Read

        Possible conditions:

        - .ifServiceArn()

        https://docs.aws.amazon.com/cloud-map/latest/api/API_GetInstance.html

        :stability: experimental
        '''
        return typing.cast("Servicediscovery", jsii.invoke(self, "toGetInstance", []))

    @jsii.member(jsii_name="toGetInstancesHealthStatus")
    def to_get_instances_health_status(self) -> "Servicediscovery":
        '''(experimental) Grants permission to get the current health status (Healthy, Unhealthy, or Unknown) of one or more instances.

        Access Level: Read

        Possible conditions:

        - .ifServiceArn()

        https://docs.aws.amazon.com/cloud-map/latest/api/API_GetInstancesHealthStatus.html

        :stability: experimental
        '''
        return typing.cast("Servicediscovery", jsii.invoke(self, "toGetInstancesHealthStatus", []))

    @jsii.member(jsii_name="toGetNamespace")
    def to_get_namespace(self) -> "Servicediscovery":
        '''(experimental) Grants permission to get information about a namespace.

        Access Level: Read

        https://docs.aws.amazon.com/cloud-map/latest/api/API_GetNamespace.html

        :stability: experimental
        '''
        return typing.cast("Servicediscovery", jsii.invoke(self, "toGetNamespace", []))

    @jsii.member(jsii_name="toGetOperation")
    def to_get_operation(self) -> "Servicediscovery":
        '''(experimental) Grants permission to get information about a specific operation.

        Access Level: Read

        https://docs.aws.amazon.com/cloud-map/latest/api/API_GetOperation.html

        :stability: experimental
        '''
        return typing.cast("Servicediscovery", jsii.invoke(self, "toGetOperation", []))

    @jsii.member(jsii_name="toGetService")
    def to_get_service(self) -> "Servicediscovery":
        '''(experimental) Grants permission to get the settings for a specified service.

        Access Level: Read

        https://docs.aws.amazon.com/cloud-map/latest/api/API_GetService.html

        :stability: experimental
        '''
        return typing.cast("Servicediscovery", jsii.invoke(self, "toGetService", []))

    @jsii.member(jsii_name="toListInstances")
    def to_list_instances(self) -> "Servicediscovery":
        '''(experimental) Grants permission to get summary information about the instances that were registered with a specified service.

        Access Level: Read

        Possible conditions:

        - .ifServiceArn()

        https://docs.aws.amazon.com/cloud-map/latest/api/API_ListInstances.html

        :stability: experimental
        '''
        return typing.cast("Servicediscovery", jsii.invoke(self, "toListInstances", []))

    @jsii.member(jsii_name="toListNamespaces")
    def to_list_namespaces(self) -> "Servicediscovery":
        '''(experimental) Grants permission to get information about the namespaces.

        Access Level: Read

        https://docs.aws.amazon.com/cloud-map/latest/api/API_ListNamespaces.html

        :stability: experimental
        '''
        return typing.cast("Servicediscovery", jsii.invoke(self, "toListNamespaces", []))

    @jsii.member(jsii_name="toListOperations")
    def to_list_operations(self) -> "Servicediscovery":
        '''(experimental) Grants permission to list operations that match the criteria that you specify.

        Access Level: List

        https://docs.aws.amazon.com/cloud-map/latest/api/API_ListOperations.html

        :stability: experimental
        '''
        return typing.cast("Servicediscovery", jsii.invoke(self, "toListOperations", []))

    @jsii.member(jsii_name="toListServices")
    def to_list_services(self) -> "Servicediscovery":
        '''(experimental) Grants permission to get settings for all the services that match specified filters.

        Access Level: Read

        https://docs.aws.amazon.com/cloud-map/latest/api/API_ListServices.html

        :stability: experimental
        '''
        return typing.cast("Servicediscovery", jsii.invoke(self, "toListServices", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Servicediscovery":
        '''(experimental) Grants permission to lists tags for the specified resource.

        Access Level: Read

        https://docs.aws.amazon.com/cloud-map/latest/api/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("Servicediscovery", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toRegisterInstance")
    def to_register_instance(self) -> "Servicediscovery":
        '''(experimental) Grants permission to register an instance based on the settings in a specified service.

        Access Level: Write

        Possible conditions:

        - .ifServiceArn()

        https://docs.aws.amazon.com/cloud-map/latest/api/API_RegisterInstance.html

        :stability: experimental
        '''
        return typing.cast("Servicediscovery", jsii.invoke(self, "toRegisterInstance", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Servicediscovery":
        '''(experimental) Grants permission to add one or more tags to the specified resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/cloud-map/latest/api/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("Servicediscovery", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Servicediscovery":
        '''(experimental) Grants permission to remove one or more tags from the specified resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/cloud-map/latest/api/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("Servicediscovery", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateHttpNamespace")
    def to_update_http_namespace(self) -> "Servicediscovery":
        '''(experimental) Grants permission to update the settings for a HTTP namespace.

        Access Level: Write

        https://docs.aws.amazon.com/cloud-map/latest/api/API_UpdateHttpNamespace.html

        :stability: experimental
        '''
        return typing.cast("Servicediscovery", jsii.invoke(self, "toUpdateHttpNamespace", []))

    @jsii.member(jsii_name="toUpdateInstanceCustomHealthStatus")
    def to_update_instance_custom_health_status(self) -> "Servicediscovery":
        '''(experimental) Grants permission to update the current health status for an instance that has a custom health check.

        Access Level: Write

        Possible conditions:

        - .ifServiceArn()

        https://docs.aws.amazon.com/cloud-map/latest/api/API_UpdateInstanceCustomHealthStatus.html

        :stability: experimental
        '''
        return typing.cast("Servicediscovery", jsii.invoke(self, "toUpdateInstanceCustomHealthStatus", []))

    @jsii.member(jsii_name="toUpdatePrivateDnsNamespace")
    def to_update_private_dns_namespace(self) -> "Servicediscovery":
        '''(experimental) Grants permission to update the settings for a private DNS namespace.

        Access Level: Write

        https://docs.aws.amazon.com/cloud-map/latest/api/API_UpdatePrivateDnsNamespace.html

        :stability: experimental
        '''
        return typing.cast("Servicediscovery", jsii.invoke(self, "toUpdatePrivateDnsNamespace", []))

    @jsii.member(jsii_name="toUpdatePublicDnsNamespace")
    def to_update_public_dns_namespace(self) -> "Servicediscovery":
        '''(experimental) Grants permission to update the settings for a public DNS namespace.

        Access Level: Write

        https://docs.aws.amazon.com/cloud-map/latest/api/API_UpdatePublicDnsNamespace.html

        :stability: experimental
        '''
        return typing.cast("Servicediscovery", jsii.invoke(self, "toUpdatePublicDnsNamespace", []))

    @jsii.member(jsii_name="toUpdateService")
    def to_update_service(self) -> "Servicediscovery":
        '''(experimental) Grants permission to update the settings in a specified service.

        Access Level: Write

        https://docs.aws.amazon.com/cloud-map/latest/api/API_UpdateService.html

        :stability: experimental
        '''
        return typing.cast("Servicediscovery", jsii.invoke(self, "toUpdateService", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__591c405c2d795e6fb8cc77d7d755382ca979fef249fe63ec429dda6b992a9910)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2f604f3e3261da2bceb6055a30d30616d4e9f0515f34701878b2f68de8f373bf)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Serviceextract(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Serviceextract",
):
    '''(experimental) Statement provider for service `serviceextract <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsmicroserviceextractorfor.net.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `serviceextract <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsmicroserviceextractorfor.net.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="toGetConfig")
    def to_get_config(self) -> "Serviceextract":
        '''(experimental) Grants permission to get required configuration for the AWS Microservice Extractor for .NET desktop client.

        Access Level: Read

        https://docs.aws.amazon.com/microservice-extractor/latest/userguide/what-is-microservice-extractor.html

        :stability: experimental
        '''
        return typing.cast("Serviceextract", jsii.invoke(self, "toGetConfig", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1c70f36014709d0be141498db9437ae2ad61980eab76fc4ba8284f2ace00caab)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5130a0754262bdefe53dfe3a5127bead93f3744059f44c6297d637246caa8715)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Servicequotas(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Servicequotas",
):
    '''(experimental) Statement provider for service `servicequotas <https://docs.aws.amazon.com/service-authorization/latest/reference/list_servicequotas.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `servicequotas <https://docs.aws.amazon.com/service-authorization/latest/reference/list_servicequotas.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="ifService")
    def if_service(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Servicequotas":
        '''(experimental) Filters access by the specified AWS service.

        https://docs.aws.amazon.com/servicequotas/latest/userguide/identity-access-management.html#condition-keys

        Applies to actions:

        - .toPutServiceQuotaIncreaseRequestIntoTemplate()
        - .toRequestServiceQuotaIncrease()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0831bbea28a3f4619d310da1c0a503191f4901b3f485791f7499a7f556f9a99d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Servicequotas", jsii.invoke(self, "ifService", [value, operator]))

    @jsii.member(jsii_name="onQuota")
    def on_quota(
        self,
        service_code: builtins.str,
        quota_code: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Servicequotas":
        '''(experimental) Adds a resource of type quota to the statement.

        https://docs.aws.amazon.com/servicequotas/latest/userguide/identity-access-management.html#resources

        :param service_code: - Identifier for the serviceCode.
        :param quota_code: - Identifier for the quotaCode.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6da2f3b6810b0f888b887460664ce0a54d05a18d8043fba813eb51f70f20f0a3)
            check_type(argname="argument service_code", value=service_code, expected_type=type_hints["service_code"])
            check_type(argname="argument quota_code", value=quota_code, expected_type=type_hints["quota_code"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Servicequotas", jsii.invoke(self, "onQuota", [service_code, quota_code, account, region, partition]))

    @jsii.member(jsii_name="toAssociateServiceQuotaTemplate")
    def to_associate_service_quota_template(self) -> "Servicequotas":
        '''(experimental) Grants permission to associate the Service Quotas template with your organization.

        Access Level: Write

        https://docs.aws.amazon.com/servicequotas/2019-06-24/apireference/API_AssociateServiceQuotaTemplate.html

        :stability: experimental
        '''
        return typing.cast("Servicequotas", jsii.invoke(self, "toAssociateServiceQuotaTemplate", []))

    @jsii.member(jsii_name="toDeleteServiceQuotaIncreaseRequestFromTemplate")
    def to_delete_service_quota_increase_request_from_template(self) -> "Servicequotas":
        '''(experimental) Grants permission to remove the specified service quota from the service quota template.

        Access Level: Write

        https://docs.aws.amazon.com/servicequotas/2019-06-24/apireference/API_DeleteServiceQuotaIncreaseRequestFromTemplate.html

        :stability: experimental
        '''
        return typing.cast("Servicequotas", jsii.invoke(self, "toDeleteServiceQuotaIncreaseRequestFromTemplate", []))

    @jsii.member(jsii_name="toDisassociateServiceQuotaTemplate")
    def to_disassociate_service_quota_template(self) -> "Servicequotas":
        '''(experimental) Grants permission to disassociate the Service Quotas template from your organization.

        Access Level: Write

        https://docs.aws.amazon.com/servicequotas/2019-06-24/apireference/API_DisassociateServiceQuotaTemplate.html

        :stability: experimental
        '''
        return typing.cast("Servicequotas", jsii.invoke(self, "toDisassociateServiceQuotaTemplate", []))

    @jsii.member(jsii_name="toGetAssociationForServiceQuotaTemplate")
    def to_get_association_for_service_quota_template(self) -> "Servicequotas":
        '''(experimental) Grants permission to retrieve the ServiceQuotaTemplateAssociationStatus value, which tells you if the Service Quotas template is associated with an organization.

        Access Level: Read

        https://docs.aws.amazon.com/servicequotas/2019-06-24/apireference/API_GetAssociationForServiceQuotaTemplate.html

        :stability: experimental
        '''
        return typing.cast("Servicequotas", jsii.invoke(self, "toGetAssociationForServiceQuotaTemplate", []))

    @jsii.member(jsii_name="toGetAWSDefaultServiceQuota")
    def to_get_aws_default_service_quota(self) -> "Servicequotas":
        '''(experimental) Grants permission to return the details for the specified service quota, including the AWS default value.

        Access Level: Read

        https://docs.aws.amazon.com/servicequotas/2019-06-24/apireference/API_GetAWSDefaultServiceQuota.html

        :stability: experimental
        '''
        return typing.cast("Servicequotas", jsii.invoke(self, "toGetAWSDefaultServiceQuota", []))

    @jsii.member(jsii_name="toGetRequestedServiceQuotaChange")
    def to_get_requested_service_quota_change(self) -> "Servicequotas":
        '''(experimental) Grants permission to retrieve the details for a particular service quota increase request.

        Access Level: Read

        https://docs.aws.amazon.com/servicequotas/2019-06-24/apireference/API_GetRequestedServiceQuotaChange.html

        :stability: experimental
        '''
        return typing.cast("Servicequotas", jsii.invoke(self, "toGetRequestedServiceQuotaChange", []))

    @jsii.member(jsii_name="toGetServiceQuota")
    def to_get_service_quota(self) -> "Servicequotas":
        '''(experimental) Grants permission to return the details for the specified service quota, including the applied value.

        Access Level: Read

        https://docs.aws.amazon.com/servicequotas/2019-06-24/apireference/API_GetServiceQuota.html

        :stability: experimental
        '''
        return typing.cast("Servicequotas", jsii.invoke(self, "toGetServiceQuota", []))

    @jsii.member(jsii_name="toGetServiceQuotaIncreaseRequestFromTemplate")
    def to_get_service_quota_increase_request_from_template(self) -> "Servicequotas":
        '''(experimental) Grants permission to retrieve the details for a service quota increase request from the service quota template.

        Access Level: Read

        https://docs.aws.amazon.com/servicequotas/2019-06-24/apireference/API_GetServiceQuotaIncreaseRequestFromTemplate.html

        :stability: experimental
        '''
        return typing.cast("Servicequotas", jsii.invoke(self, "toGetServiceQuotaIncreaseRequestFromTemplate", []))

    @jsii.member(jsii_name="toListAWSDefaultServiceQuotas")
    def to_list_aws_default_service_quotas(self) -> "Servicequotas":
        '''(experimental) Grants permission to list all default service quotas for the specified AWS service.

        Access Level: Read

        https://docs.aws.amazon.com/servicequotas/2019-06-24/apireference/API_ListAWSDefaultServiceQuotas.html

        :stability: experimental
        '''
        return typing.cast("Servicequotas", jsii.invoke(self, "toListAWSDefaultServiceQuotas", []))

    @jsii.member(jsii_name="toListRequestedServiceQuotaChangeHistory")
    def to_list_requested_service_quota_change_history(self) -> "Servicequotas":
        '''(experimental) Grants permission to request a list of the changes to quotas for a service.

        Access Level: Read

        https://docs.aws.amazon.com/servicequotas/2019-06-24/apireference/API_ListRequestedServiceQuotaChangeHistory.html

        :stability: experimental
        '''
        return typing.cast("Servicequotas", jsii.invoke(self, "toListRequestedServiceQuotaChangeHistory", []))

    @jsii.member(jsii_name="toListRequestedServiceQuotaChangeHistoryByQuota")
    def to_list_requested_service_quota_change_history_by_quota(
        self,
    ) -> "Servicequotas":
        '''(experimental) Grants permission to request a list of the changes to specific service quotas.

        Access Level: Read

        https://docs.aws.amazon.com/servicequotas/2019-06-24/apireference/API_ListRequestedServiceQuotaChangeHistoryByQuota.html

        :stability: experimental
        '''
        return typing.cast("Servicequotas", jsii.invoke(self, "toListRequestedServiceQuotaChangeHistoryByQuota", []))

    @jsii.member(jsii_name="toListServiceQuotaIncreaseRequestsInTemplate")
    def to_list_service_quota_increase_requests_in_template(self) -> "Servicequotas":
        '''(experimental) Grants permission to return a list of the service quota increase requests from the service quota template.

        Access Level: Read

        https://docs.aws.amazon.com/servicequotas/2019-06-24/apireference/API_ListServiceQuotaIncreaseRequestsInTemplate

        :stability: experimental
        '''
        return typing.cast("Servicequotas", jsii.invoke(self, "toListServiceQuotaIncreaseRequestsInTemplate", []))

    @jsii.member(jsii_name="toListServiceQuotas")
    def to_list_service_quotas(self) -> "Servicequotas":
        '''(experimental) Grants permission to list all service quotas for the specified AWS service, in that account, in that Region.

        Access Level: Read

        https://docs.aws.amazon.com/servicequotas/2019-06-24/apireference/API_ListServiceQuotas.html

        :stability: experimental
        '''
        return typing.cast("Servicequotas", jsii.invoke(self, "toListServiceQuotas", []))

    @jsii.member(jsii_name="toListServices")
    def to_list_services(self) -> "Servicequotas":
        '''(experimental) Grants permission to list the AWS services available in Service Quotas.

        Access Level: Read

        https://docs.aws.amazon.com/servicequotas/2019-06-24/apireference/API_ListServices.html

        :stability: experimental
        '''
        return typing.cast("Servicequotas", jsii.invoke(self, "toListServices", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Servicequotas":
        '''(experimental) Grants permission to view the existing tags on a SQ resource.

        Access Level: Read

        https://docs.aws.amazon.com/servicequotas/2019-06-24/apireference/API_ListTagsForResource

        :stability: experimental
        '''
        return typing.cast("Servicequotas", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toPutServiceQuotaIncreaseRequestIntoTemplate")
    def to_put_service_quota_increase_request_into_template(self) -> "Servicequotas":
        '''(experimental) Grants permission to define and add a quota to the service quota template.

        Access Level: Write

        Possible conditions:

        - .ifService()

        https://docs.aws.amazon.com/servicequotas/2019-06-24/apireference/API_PutServiceQuotaIncreaseRequestIntoTemplate.html

        :stability: experimental
        '''
        return typing.cast("Servicequotas", jsii.invoke(self, "toPutServiceQuotaIncreaseRequestIntoTemplate", []))

    @jsii.member(jsii_name="toRequestServiceQuotaIncrease")
    def to_request_service_quota_increase(self) -> "Servicequotas":
        '''(experimental) Grants permission to submit the request for a service quota increase.

        Access Level: Write

        Possible conditions:

        - .ifService()

        https://docs.aws.amazon.com/servicequotas/2019-06-24/apireference/API_RequestServiceQuotaIncrease.html

        :stability: experimental
        '''
        return typing.cast("Servicequotas", jsii.invoke(self, "toRequestServiceQuotaIncrease", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Servicequotas":
        '''(experimental) Grants permission to associate a set of tags with an existing SQ resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/servicequotas/2019-06-24/apireference/API_TagResource

        :stability: experimental
        '''
        return typing.cast("Servicequotas", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Servicequotas":
        '''(experimental) Grants permission to remove a set of tags from a SQ resource, where tags to be removed match a set of customer-supplied tag keys.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/servicequotas/2019-06-24/apireference/API_UntagResource

        :stability: experimental
        '''
        return typing.cast("Servicequotas", jsii.invoke(self, "toUntagResource", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4d9f11db186615b61196cb1f0b89f5adf215e8984f66dd91fa2eb953438a8d76)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3e6671f37c226b1cdcf6a270064a9263d00e8d5a14830601d9a8941612e12bc9)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Ses(PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Ses"):
    '''(experimental) Statement provider for service `ses <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonses.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `ses <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonses.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="ifApiVersion")
    def if_api_version(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Ses":
        '''(experimental) Filters actions based on the SES API version.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonses.html#amazonses-policy-keys

        Applies to actions:

        - .toCloneReceiptRuleSet()
        - .toCreateConfigurationSet()
        - .toCreateConfigurationSetEventDestination()
        - .toCreateConfigurationSetTrackingOptions()
        - .toCreateCustomVerificationEmailTemplate()
        - .toCreateReceiptFilter()
        - .toCreateReceiptRule()
        - .toCreateReceiptRuleSet()
        - .toCreateTemplate()
        - .toDeleteConfigurationSet()
        - .toDeleteConfigurationSetEventDestination()
        - .toDeleteConfigurationSetTrackingOptions()
        - .toDeleteCustomVerificationEmailTemplate()
        - .toDeleteIdentity()
        - .toDeleteIdentityPolicy()
        - .toDeleteReceiptFilter()
        - .toDeleteReceiptRule()
        - .toDeleteReceiptRuleSet()
        - .toDeleteTemplate()
        - .toDeleteVerifiedEmailAddress()
        - .toDescribeActiveReceiptRuleSet()
        - .toDescribeConfigurationSet()
        - .toDescribeReceiptRule()
        - .toDescribeReceiptRuleSet()
        - .toGetAccountSendingEnabled()
        - .toGetCustomVerificationEmailTemplate()
        - .toGetIdentityDkimAttributes()
        - .toGetIdentityMailFromDomainAttributes()
        - .toGetIdentityNotificationAttributes()
        - .toGetIdentityPolicies()
        - .toGetIdentityVerificationAttributes()
        - .toGetSendQuota()
        - .toGetSendStatistics()
        - .toGetTemplate()
        - .toListConfigurationSets()
        - .toListCustomVerificationEmailTemplates()
        - .toListIdentities()
        - .toListIdentityPolicies()
        - .toListReceiptFilters()
        - .toListReceiptRuleSets()
        - .toListTemplates()
        - .toListVerifiedEmailAddresses()
        - .toPutConfigurationSetDeliveryOptions()
        - .toPutIdentityPolicy()
        - .toReorderReceiptRuleSet()
        - .toSendBounce()
        - .toSendBulkTemplatedEmail()
        - .toSendCustomVerificationEmail()
        - .toSendEmail()
        - .toSendRawEmail()
        - .toSendTemplatedEmail()
        - .toSetActiveReceiptRuleSet()
        - .toSetIdentityDkimEnabled()
        - .toSetIdentityFeedbackForwardingEnabled()
        - .toSetIdentityHeadersInNotificationsEnabled()
        - .toSetIdentityMailFromDomain()
        - .toSetIdentityNotificationTopic()
        - .toSetReceiptRulePosition()
        - .toTestRenderTemplate()
        - .toUpdateAccountSendingEnabled()
        - .toUpdateConfigurationSetEventDestination()
        - .toUpdateConfigurationSetReputationMetricsEnabled()
        - .toUpdateConfigurationSetSendingEnabled()
        - .toUpdateConfigurationSetTrackingOptions()
        - .toUpdateCustomVerificationEmailTemplate()
        - .toUpdateReceiptRule()
        - .toUpdateTemplate()
        - .toVerifyDomainDkim()
        - .toVerifyDomainIdentity()
        - .toVerifyEmailAddress()
        - .toVerifyEmailIdentity()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__387dcdfe1152f12c74ae4e803b657af5f03f2978f223c3db721ceb9e80fbf5d3)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Ses", jsii.invoke(self, "ifApiVersion", [value, operator]))

    @jsii.member(jsii_name="ifFeedbackAddress")
    def if_feedback_address(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Ses":
        '''(experimental) Filters actions based on the "Return-Path" address, which specifies where bounces and complaints are sent by email feedback forwarding.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonses.html#amazonses-policy-keys

        Applies to actions:

        - .toSendBulkTemplatedEmail()
        - .toSendCustomVerificationEmail()
        - .toSendEmail()
        - .toSendRawEmail()
        - .toSendTemplatedEmail()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__aa566fe7aca358c6dba44988af8918e3d9fb99ef6024ed9235b6dd2d781a6787)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Ses", jsii.invoke(self, "ifFeedbackAddress", [value, operator]))

    @jsii.member(jsii_name="ifFromAddress")
    def if_from_address(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Ses":
        '''(experimental) Filters actions based on the "From" address of a message.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonses.html#amazonses-policy-keys

        Applies to actions:

        - .toSendBounce()
        - .toSendBulkTemplatedEmail()
        - .toSendCustomVerificationEmail()
        - .toSendEmail()
        - .toSendRawEmail()
        - .toSendTemplatedEmail()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3ce3d524d24d32914d042e254eadbe452c43c5b7b07bfa7a8e95ef258b131668)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Ses", jsii.invoke(self, "ifFromAddress", [value, operator]))

    @jsii.member(jsii_name="ifFromDisplayName")
    def if_from_display_name(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Ses":
        '''(experimental) Filters actions based on the "From" address that is used as the display name of a message.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonses.html#amazonses-policy-keys

        Applies to actions:

        - .toSendBulkTemplatedEmail()
        - .toSendCustomVerificationEmail()
        - .toSendEmail()
        - .toSendRawEmail()
        - .toSendTemplatedEmail()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b82c8483127cde30d526f2d2fa202fdabda52a045fcee658eb0c358cf4152466)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Ses", jsii.invoke(self, "ifFromDisplayName", [value, operator]))

    @jsii.member(jsii_name="ifRecipients")
    def if_recipients(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Ses":
        '''(experimental) Filters actions based on the recipient addresses of a message, which include the "To", "CC", and "BCC" addresses.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonses.html#amazonses-policy-keys

        Applies to actions:

        - .toSendBulkTemplatedEmail()
        - .toSendCustomVerificationEmail()
        - .toSendEmail()
        - .toSendRawEmail()
        - .toSendTemplatedEmail()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b1b2421dec5b96e466cfc9355730190aa7a0dea92548ac5a15379e1a54197e5f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Ses", jsii.invoke(self, "ifRecipients", [value, operator]))

    @jsii.member(jsii_name="onConfigurationSet")
    def on_configuration_set(
        self,
        configuration_set_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Ses":
        '''(experimental) Adds a resource of type configuration-set to the statement.

        https://docs.aws.amazon.com/ses/latest/APIReference/API_ConfigurationSet.html

        :param configuration_set_name: - Identifier for the configurationSetName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a87353c6ae5002b669c24e05a4200d53c4d8f099da89d23b13bf6aecd7ab1238)
            check_type(argname="argument configuration_set_name", value=configuration_set_name, expected_type=type_hints["configuration_set_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Ses", jsii.invoke(self, "onConfigurationSet", [configuration_set_name, account, region, partition]))

    @jsii.member(jsii_name="onCustomVerificationEmailTemplate")
    def on_custom_verification_email_template(
        self,
        template_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Ses":
        '''(experimental) Adds a resource of type custom-verification-email-template to the statement.

        https://docs.aws.amazon.com/ses/latest/APIReference/API_CustomVerificationEmailTemplate.html

        :param template_name: - Identifier for the templateName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2d6b19a9f311d3eb1a98ccfa8833c026c683a4386918edc705cce2699e85524c)
            check_type(argname="argument template_name", value=template_name, expected_type=type_hints["template_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Ses", jsii.invoke(self, "onCustomVerificationEmailTemplate", [template_name, account, region, partition]))

    @jsii.member(jsii_name="onIdentity")
    def on_identity(
        self,
        identity_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Ses":
        '''(experimental) Adds a resource of type identity to the statement.

        https://docs.aws.amazon.com/ses/latest/APIReference-V2/API_IdentityInfo.html

        :param identity_name: - Identifier for the identityName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c60ed7f119383c8e428444dd3b090e38b231ba2bfadfa55ffcbc2ef3c576e0f8)
            check_type(argname="argument identity_name", value=identity_name, expected_type=type_hints["identity_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Ses", jsii.invoke(self, "onIdentity", [identity_name, account, region, partition]))

    @jsii.member(jsii_name="onTemplate")
    def on_template(
        self,
        template_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Ses":
        '''(experimental) Adds a resource of type template to the statement.

        https://docs.aws.amazon.com/ses/latest/APIReference/API_Template.html

        :param template_name: - Identifier for the templateName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__36a7c9eb1ae5b3442bb9f2c5cfb39c797a0bf2835fcb483e6e0d24e46d1167ac)
            check_type(argname="argument template_name", value=template_name, expected_type=type_hints["template_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Ses", jsii.invoke(self, "onTemplate", [template_name, account, region, partition]))

    @jsii.member(jsii_name="toCloneReceiptRuleSet")
    def to_clone_receipt_rule_set(self) -> "Ses":
        '''(experimental) Grants permission to create a receipt rule set by cloning an existing one.

        Access Level: Write

        Possible conditions:

        - .ifApiVersion()

        https://docs.aws.amazon.com/ses/latest/APIReference/API_CloneReceiptRuleSet.html

        :stability: experimental
        '''
        return typing.cast("Ses", jsii.invoke(self, "toCloneReceiptRuleSet", []))

    @jsii.member(jsii_name="toCreateConfigurationSet")
    def to_create_configuration_set(self) -> "Ses":
        '''(experimental) Grants permission to create a new configuration set.

        Access Level: Write

        Possible conditions:

        - .ifApiVersion()

        https://docs.aws.amazon.com/ses/latest/APIReference/API_CreateConfigurationSet.html

        :stability: experimental
        '''
        return typing.cast("Ses", jsii.invoke(self, "toCreateConfigurationSet", []))

    @jsii.member(jsii_name="toCreateConfigurationSetEventDestination")
    def to_create_configuration_set_event_destination(self) -> "Ses":
        '''(experimental) Grants permission to create a configuration set event destination.

        Access Level: Write

        Possible conditions:

        - .ifApiVersion()

        https://docs.aws.amazon.com/ses/latest/APIReference/API_CreateConfigurationSetEventDestination.html

        :stability: experimental
        '''
        return typing.cast("Ses", jsii.invoke(self, "toCreateConfigurationSetEventDestination", []))

    @jsii.member(jsii_name="toCreateConfigurationSetTrackingOptions")
    def to_create_configuration_set_tracking_options(self) -> "Ses":
        '''(experimental) Grants permission to creates an association between a configuration set and a custom domain for open and click event tracking.

        Access Level: Write

        Possible conditions:

        - .ifApiVersion()

        https://docs.aws.amazon.com/ses/latest/APIReference/API_CreateConfigurationSetTrackingOptions.html

        :stability: experimental
        '''
        return typing.cast("Ses", jsii.invoke(self, "toCreateConfigurationSetTrackingOptions", []))

    @jsii.member(jsii_name="toCreateCustomVerificationEmailTemplate")
    def to_create_custom_verification_email_template(self) -> "Ses":
        '''(experimental) Grants permission to create a new custom verification email template.

        Access Level: Write

        Possible conditions:

        - .ifApiVersion()

        https://docs.aws.amazon.com/ses/latest/APIReference/API_CreateCustomVerificationEmailTemplate.html

        :stability: experimental
        '''
        return typing.cast("Ses", jsii.invoke(self, "toCreateCustomVerificationEmailTemplate", []))

    @jsii.member(jsii_name="toCreateReceiptFilter")
    def to_create_receipt_filter(self) -> "Ses":
        '''(experimental) Grants permission to create a new IP address filter.

        Access Level: Write

        Possible conditions:

        - .ifApiVersion()

        https://docs.aws.amazon.com/ses/latest/APIReference/API_CreateReceiptFilter.html

        :stability: experimental
        '''
        return typing.cast("Ses", jsii.invoke(self, "toCreateReceiptFilter", []))

    @jsii.member(jsii_name="toCreateReceiptRule")
    def to_create_receipt_rule(self) -> "Ses":
        '''(experimental) Grants permission to create a receipt rule.

        Access Level: Write

        Possible conditions:

        - .ifApiVersion()

        https://docs.aws.amazon.com/ses/latest/APIReference/API_CreateReceiptRule.html

        :stability: experimental
        '''
        return typing.cast("Ses", jsii.invoke(self, "toCreateReceiptRule", []))

    @jsii.member(jsii_name="toCreateReceiptRuleSet")
    def to_create_receipt_rule_set(self) -> "Ses":
        '''(experimental) Grants permission to create an empty receipt rule set.

        Access Level: Write

        Possible conditions:

        - .ifApiVersion()

        https://docs.aws.amazon.com/ses/latest/APIReference/API_CreateReceiptRuleSet.html

        :stability: experimental
        '''
        return typing.cast("Ses", jsii.invoke(self, "toCreateReceiptRuleSet", []))

    @jsii.member(jsii_name="toCreateTemplate")
    def to_create_template(self) -> "Ses":
        '''(experimental) Grants permission to creates an email template.

        Access Level: Write

        Possible conditions:

        - .ifApiVersion()

        https://docs.aws.amazon.com/ses/latest/APIReference/API_CreateTemplate.html

        :stability: experimental
        '''
        return typing.cast("Ses", jsii.invoke(self, "toCreateTemplate", []))

    @jsii.member(jsii_name="toDeleteConfigurationSet")
    def to_delete_configuration_set(self) -> "Ses":
        '''(experimental) Grants permission to delete an existing configuration set.

        Access Level: Write

        Possible conditions:

        - .ifApiVersion()

        https://docs.aws.amazon.com/ses/latest/APIReference/API_DeleteConfigurationSet.html

        :stability: experimental
        '''
        return typing.cast("Ses", jsii.invoke(self, "toDeleteConfigurationSet", []))

    @jsii.member(jsii_name="toDeleteConfigurationSetEventDestination")
    def to_delete_configuration_set_event_destination(self) -> "Ses":
        '''(experimental) Grants permission to delete an event destination.

        Access Level: Write

        Possible conditions:

        - .ifApiVersion()

        https://docs.aws.amazon.com/ses/latest/APIReference/API_DeleteConfigurationSetEventDestination.html

        :stability: experimental
        '''
        return typing.cast("Ses", jsii.invoke(self, "toDeleteConfigurationSetEventDestination", []))

    @jsii.member(jsii_name="toDeleteConfigurationSetTrackingOptions")
    def to_delete_configuration_set_tracking_options(self) -> "Ses":
        '''(experimental) Grants permission to delete an association between a configuration set and a custom domain for open and click event tracking.

        Access Level: Write

        Possible conditions:

        - .ifApiVersion()

        https://docs.aws.amazon.com/ses/latest/APIReference/API_DeleteConfigurationSetTrackingOptions.html

        :stability: experimental
        '''
        return typing.cast("Ses", jsii.invoke(self, "toDeleteConfigurationSetTrackingOptions", []))

    @jsii.member(jsii_name="toDeleteCustomVerificationEmailTemplate")
    def to_delete_custom_verification_email_template(self) -> "Ses":
        '''(experimental) Grants permission to delete an existing custom verification email template.

        Access Level: Write

        Possible conditions:

        - .ifApiVersion()

        https://docs.aws.amazon.com/ses/latest/APIReference/API_DeleteCustomVerificationEmailTemplate.html

        :stability: experimental
        '''
        return typing.cast("Ses", jsii.invoke(self, "toDeleteCustomVerificationEmailTemplate", []))

    @jsii.member(jsii_name="toDeleteIdentity")
    def to_delete_identity(self) -> "Ses":
        '''(experimental) Grants permission to delete the specified identity.

        Access Level: Write

        Possible conditions:

        - .ifApiVersion()

        https://docs.aws.amazon.com/ses/latest/APIReference/API_DeleteIdentity.html

        :stability: experimental
        '''
        return typing.cast("Ses", jsii.invoke(self, "toDeleteIdentity", []))

    @jsii.member(jsii_name="toDeleteIdentityPolicy")
    def to_delete_identity_policy(self) -> "Ses":
        '''(experimental) Grants permission to delete the specified sending authorization policy for the given identity (an email address or a domain).

        Access Level: Permissions management

        Possible conditions:

        - .ifApiVersion()

        https://docs.aws.amazon.com/ses/latest/APIReference/API_DeleteIdentityPolicy.html

        :stability: experimental
        '''
        return typing.cast("Ses", jsii.invoke(self, "toDeleteIdentityPolicy", []))

    @jsii.member(jsii_name="toDeleteReceiptFilter")
    def to_delete_receipt_filter(self) -> "Ses":
        '''(experimental) Grants permission to delete the specified IP address filter.

        Access Level: Write

        Possible conditions:

        - .ifApiVersion()

        https://docs.aws.amazon.com/ses/latest/APIReference/API_DeleteReceiptFilter.html

        :stability: experimental
        '''
        return typing.cast("Ses", jsii.invoke(self, "toDeleteReceiptFilter", []))

    @jsii.member(jsii_name="toDeleteReceiptRule")
    def to_delete_receipt_rule(self) -> "Ses":
        '''(experimental) Grants permission to delete the specified receipt rule.

        Access Level: Write

        Possible conditions:

        - .ifApiVersion()

        https://docs.aws.amazon.com/ses/latest/APIReference/API_DeleteReceiptRule.html

        :stability: experimental
        '''
        return typing.cast("Ses", jsii.invoke(self, "toDeleteReceiptRule", []))

    @jsii.member(jsii_name="toDeleteReceiptRuleSet")
    def to_delete_receipt_rule_set(self) -> "Ses":
        '''(experimental) Grants permission to delete the specified receipt rule set and all of the receipt rules it contains.

        Access Level: Write

        Possible conditions:

        - .ifApiVersion()

        https://docs.aws.amazon.com/ses/latest/APIReference/API_DeleteReceiptRuleSet.html

        :stability: experimental
        '''
        return typing.cast("Ses", jsii.invoke(self, "toDeleteReceiptRuleSet", []))

    @jsii.member(jsii_name="toDeleteTemplate")
    def to_delete_template(self) -> "Ses":
        '''(experimental) Grants permission to delete an email template.

        Access Level: Write

        Possible conditions:

        - .ifApiVersion()

        https://docs.aws.amazon.com/ses/latest/APIReference/API_DeleteTemplate.html

        :stability: experimental
        '''
        return typing.cast("Ses", jsii.invoke(self, "toDeleteTemplate", []))

    @jsii.member(jsii_name="toDeleteVerifiedEmailAddress")
    def to_delete_verified_email_address(self) -> "Ses":
        '''(experimental) Grants permission to delete the specified email address from the list of verified addresses.

        Access Level: Write

        Possible conditions:

        - .ifApiVersion()

        https://docs.aws.amazon.com/ses/latest/APIReference/API_DeleteVerifiedEmailAddress.html

        :stability: experimental
        '''
        return typing.cast("Ses", jsii.invoke(self, "toDeleteVerifiedEmailAddress", []))

    @jsii.member(jsii_name="toDescribeActiveReceiptRuleSet")
    def to_describe_active_receipt_rule_set(self) -> "Ses":
        '''(experimental) Grants permission to return the metadata and receipt rules for the receipt rule set that is currently active.

        Access Level: Read

        Possible conditions:

        - .ifApiVersion()

        https://docs.aws.amazon.com/ses/latest/APIReference/API_DescribeActiveReceiptRuleSet.html

        :stability: experimental
        '''
        return typing.cast("Ses", jsii.invoke(self, "toDescribeActiveReceiptRuleSet", []))

    @jsii.member(jsii_name="toDescribeConfigurationSet")
    def to_describe_configuration_set(self) -> "Ses":
        '''(experimental) Grants permission to return the details of the specified configuration set.

        Access Level: Read

        Possible conditions:

        - .ifApiVersion()

        https://docs.aws.amazon.com/ses/latest/APIReference/API_DescribeConfigurationSet.html

        :stability: experimental
        '''
        return typing.cast("Ses", jsii.invoke(self, "toDescribeConfigurationSet", []))

    @jsii.member(jsii_name="toDescribeReceiptRule")
    def to_describe_receipt_rule(self) -> "Ses":
        '''(experimental) Grants permission to return the details of the specified receipt rule.

        Access Level: Read

        Possible conditions:

        - .ifApiVersion()

        https://docs.aws.amazon.com/ses/latest/APIReference/API_DescribeReceiptRule.html

        :stability: experimental
        '''
        return typing.cast("Ses", jsii.invoke(self, "toDescribeReceiptRule", []))

    @jsii.member(jsii_name="toDescribeReceiptRuleSet")
    def to_describe_receipt_rule_set(self) -> "Ses":
        '''(experimental) Grants permission to return the details of the specified receipt rule set.

        Access Level: Read

        Possible conditions:

        - .ifApiVersion()

        https://docs.aws.amazon.com/ses/latest/APIReference/API_DescribeReceiptRuleSet.html

        :stability: experimental
        '''
        return typing.cast("Ses", jsii.invoke(self, "toDescribeReceiptRuleSet", []))

    @jsii.member(jsii_name="toGetAccountSendingEnabled")
    def to_get_account_sending_enabled(self) -> "Ses":
        '''(experimental) Grants permission to return the email sending status of your account.

        Access Level: Read

        Possible conditions:

        - .ifApiVersion()

        https://docs.aws.amazon.com/ses/latest/APIReference/API_GetAccountSendingEnabled.html

        :stability: experimental
        '''
        return typing.cast("Ses", jsii.invoke(self, "toGetAccountSendingEnabled", []))

    @jsii.member(jsii_name="toGetCustomVerificationEmailTemplate")
    def to_get_custom_verification_email_template(self) -> "Ses":
        '''(experimental) Grants permission to return the custom email verification template for the template name you specify.

        Access Level: Read

        Possible conditions:

        - .ifApiVersion()

        https://docs.aws.amazon.com/ses/latest/APIReference/API_GetCustomVerificationEmailTemplate.html

        :stability: experimental
        '''
        return typing.cast("Ses", jsii.invoke(self, "toGetCustomVerificationEmailTemplate", []))

    @jsii.member(jsii_name="toGetIdentityDkimAttributes")
    def to_get_identity_dkim_attributes(self) -> "Ses":
        '''(experimental) Grants permission to return the current status of Easy DKIM signing for an entity.

        Access Level: Read

        Possible conditions:

        - .ifApiVersion()

        https://docs.aws.amazon.com/ses/latest/APIReference/API_GetIdentityDkimAttributes.html

        :stability: experimental
        '''
        return typing.cast("Ses", jsii.invoke(self, "toGetIdentityDkimAttributes", []))

    @jsii.member(jsii_name="toGetIdentityMailFromDomainAttributes")
    def to_get_identity_mail_from_domain_attributes(self) -> "Ses":
        '''(experimental) Grants permission to return the custom MAIL FROM attributes for a list of identities (email addresses and/or domains).

        Access Level: Read

        Possible conditions:

        - .ifApiVersion()

        https://docs.aws.amazon.com/ses/latest/APIReference/API_GetIdentityMailFromDomainAttributes.html

        :stability: experimental
        '''
        return typing.cast("Ses", jsii.invoke(self, "toGetIdentityMailFromDomainAttributes", []))

    @jsii.member(jsii_name="toGetIdentityNotificationAttributes")
    def to_get_identity_notification_attributes(self) -> "Ses":
        '''(experimental) Grants permission to return a structure describing identity notification attributes for a list of verified identities (email addresses and/or domains),.

        Access Level: Read

        Possible conditions:

        - .ifApiVersion()

        https://docs.aws.amazon.com/ses/latest/APIReference/API_GetIdentityNotificationAttributes.html

        :stability: experimental
        '''
        return typing.cast("Ses", jsii.invoke(self, "toGetIdentityNotificationAttributes", []))

    @jsii.member(jsii_name="toGetIdentityPolicies")
    def to_get_identity_policies(self) -> "Ses":
        '''(experimental) Grants permission to return the requested sending authorization policies for the given identity (an email address or a domain).

        Access Level: Read

        Possible conditions:

        - .ifApiVersion()

        https://docs.aws.amazon.com/ses/latest/APIReference/API_GetIdentityPolicies.html

        :stability: experimental
        '''
        return typing.cast("Ses", jsii.invoke(self, "toGetIdentityPolicies", []))

    @jsii.member(jsii_name="toGetIdentityVerificationAttributes")
    def to_get_identity_verification_attributes(self) -> "Ses":
        '''(experimental) Grants permission to return the verification status and (for domain identities) the verification token for a list of identities.

        Access Level: Read

        Possible conditions:

        - .ifApiVersion()

        https://docs.aws.amazon.com/ses/latest/APIReference/API_GetIdentityVerificationAttributes.html

        :stability: experimental
        '''
        return typing.cast("Ses", jsii.invoke(self, "toGetIdentityVerificationAttributes", []))

    @jsii.member(jsii_name="toGetSendQuota")
    def to_get_send_quota(self) -> "Ses":
        '''(experimental) Grants permission to return the user's current sending limits.

        Access Level: Read

        Possible conditions:

        - .ifApiVersion()

        https://docs.aws.amazon.com/ses/latest/APIReference/API_GetSendQuota.html

        :stability: experimental
        '''
        return typing.cast("Ses", jsii.invoke(self, "toGetSendQuota", []))

    @jsii.member(jsii_name="toGetSendStatistics")
    def to_get_send_statistics(self) -> "Ses":
        '''(experimental) Grants permission to returns the user's sending statistics.

        Access Level: Read

        Possible conditions:

        - .ifApiVersion()

        https://docs.aws.amazon.com/ses/latest/APIReference/API_GetSendStatistics.html

        :stability: experimental
        '''
        return typing.cast("Ses", jsii.invoke(self, "toGetSendStatistics", []))

    @jsii.member(jsii_name="toGetTemplate")
    def to_get_template(self) -> "Ses":
        '''(experimental) Grants permission to return the template object, which includes the subject line, HTML par, and text part for the template you specify.

        Access Level: Read

        Possible conditions:

        - .ifApiVersion()

        https://docs.aws.amazon.com/ses/latest/APIReference/API_GetTemplate.html

        :stability: experimental
        '''
        return typing.cast("Ses", jsii.invoke(self, "toGetTemplate", []))

    @jsii.member(jsii_name="toListConfigurationSets")
    def to_list_configuration_sets(self) -> "Ses":
        '''(experimental) Grants permission to list all of the configuration sets for your account.

        Access Level: List

        Possible conditions:

        - .ifApiVersion()

        https://docs.aws.amazon.com/ses/latest/APIReference/API_ListConfigurationSets.html

        :stability: experimental
        '''
        return typing.cast("Ses", jsii.invoke(self, "toListConfigurationSets", []))

    @jsii.member(jsii_name="toListCustomVerificationEmailTemplates")
    def to_list_custom_verification_email_templates(self) -> "Ses":
        '''(experimental) Grants permission to list all of the existing custom verification email templates for your account.

        Access Level: List

        Possible conditions:

        - .ifApiVersion()

        https://docs.aws.amazon.com/ses/latest/APIReference/API_ListCustomVerificationEmailTemplates.html

        :stability: experimental
        '''
        return typing.cast("Ses", jsii.invoke(self, "toListCustomVerificationEmailTemplates", []))

    @jsii.member(jsii_name="toListIdentities")
    def to_list_identities(self) -> "Ses":
        '''(experimental) Grants permission to list the email identities for your account.

        Access Level: List

        Possible conditions:

        - .ifApiVersion()

        https://docs.aws.amazon.com/ses/latest/APIReference/API_ListIdentities.html

        :stability: experimental
        '''
        return typing.cast("Ses", jsii.invoke(self, "toListIdentities", []))

    @jsii.member(jsii_name="toListIdentityPolicies")
    def to_list_identity_policies(self) -> "Ses":
        '''(experimental) Grants permission to list all of the email templates for your account.

        Access Level: List

        Possible conditions:

        - .ifApiVersion()

        https://docs.aws.amazon.com/ses/latest/APIReference/API_ListIdentityPolicies.html

        :stability: experimental
        '''
        return typing.cast("Ses", jsii.invoke(self, "toListIdentityPolicies", []))

    @jsii.member(jsii_name="toListReceiptFilters")
    def to_list_receipt_filters(self) -> "Ses":
        '''(experimental) Grants permission to list the IP address filters associated with your account.

        Access Level: Read

        Possible conditions:

        - .ifApiVersion()

        https://docs.aws.amazon.com/ses/latest/APIReference/API_ListReceiptFilters.html

        :stability: experimental
        '''
        return typing.cast("Ses", jsii.invoke(self, "toListReceiptFilters", []))

    @jsii.member(jsii_name="toListReceiptRuleSets")
    def to_list_receipt_rule_sets(self) -> "Ses":
        '''(experimental) Grants permission to list the receipt rule sets that exist under your account.

        Access Level: Read

        Possible conditions:

        - .ifApiVersion()

        https://docs.aws.amazon.com/ses/latest/APIReference/API_ListReceiptRuleSets.html

        :stability: experimental
        '''
        return typing.cast("Ses", jsii.invoke(self, "toListReceiptRuleSets", []))

    @jsii.member(jsii_name="toListTemplates")
    def to_list_templates(self) -> "Ses":
        '''(experimental) Grants permission to list the email templates present in your account.

        Access Level: List

        Possible conditions:

        - .ifApiVersion()

        https://docs.aws.amazon.com/ses/latest/APIReference/API_ListTemplates.html

        :stability: experimental
        '''
        return typing.cast("Ses", jsii.invoke(self, "toListTemplates", []))

    @jsii.member(jsii_name="toListVerifiedEmailAddresses")
    def to_list_verified_email_addresses(self) -> "Ses":
        '''(experimental) Grants permission to list all of the email addresses that have been verified in your account.

        Access Level: Read

        Possible conditions:

        - .ifApiVersion()

        https://docs.aws.amazon.com/ses/latest/APIReference/API_ListVerifiedEmailAddresses.html

        :stability: experimental
        '''
        return typing.cast("Ses", jsii.invoke(self, "toListVerifiedEmailAddresses", []))

    @jsii.member(jsii_name="toPutConfigurationSetDeliveryOptions")
    def to_put_configuration_set_delivery_options(self) -> "Ses":
        '''(experimental) Grants permission to add or update the delivery options for a configuration set.

        Access Level: Write

        Possible conditions:

        - .ifApiVersion()

        https://docs.aws.amazon.com/ses/latest/APIReference/API_PutConfigurationSetDeliveryOptions.html

        :stability: experimental
        '''
        return typing.cast("Ses", jsii.invoke(self, "toPutConfigurationSetDeliveryOptions", []))

    @jsii.member(jsii_name="toPutIdentityPolicy")
    def to_put_identity_policy(self) -> "Ses":
        '''(experimental) Grants permission to add or update a sending authorization policy for the specified identity (an email address or a domain).

        Access Level: Permissions management

        Possible conditions:

        - .ifApiVersion()

        https://docs.aws.amazon.com/ses/latest/APIReference/API_PutIdentityPolicy.html

        :stability: experimental
        '''
        return typing.cast("Ses", jsii.invoke(self, "toPutIdentityPolicy", []))

    @jsii.member(jsii_name="toReorderReceiptRuleSet")
    def to_reorder_receipt_rule_set(self) -> "Ses":
        '''(experimental) Grants permission to reorder the receipt rules within a receipt rule set.

        Access Level: Write

        Possible conditions:

        - .ifApiVersion()

        https://docs.aws.amazon.com/ses/latest/APIReference/API_ReorderReceiptRuleSet.html

        :stability: experimental
        '''
        return typing.cast("Ses", jsii.invoke(self, "toReorderReceiptRuleSet", []))

    @jsii.member(jsii_name="toSendBounce")
    def to_send_bounce(self) -> "Ses":
        '''(experimental) Grants permission to generate and send a bounce message to the sender of an email you received through Amazon SES.

        Access Level: Write

        Possible conditions:

        - .ifApiVersion()
        - .ifFromAddress()

        https://docs.aws.amazon.com/ses/latest/APIReference/API_SendBounce.html

        :stability: experimental
        '''
        return typing.cast("Ses", jsii.invoke(self, "toSendBounce", []))

    @jsii.member(jsii_name="toSendBulkTemplatedEmail")
    def to_send_bulk_templated_email(self) -> "Ses":
        '''(experimental) Grants permission to compose an email message to multiple destinations.

        Access Level: Write

        Possible conditions:

        - .ifApiVersion()
        - .ifFeedbackAddress()
        - .ifFromAddress()
        - .ifFromDisplayName()
        - .ifRecipients()

        https://docs.aws.amazon.com/ses/latest/APIReference/API_SendBulkTemplatedEmail.html

        :stability: experimental
        '''
        return typing.cast("Ses", jsii.invoke(self, "toSendBulkTemplatedEmail", []))

    @jsii.member(jsii_name="toSendCustomVerificationEmail")
    def to_send_custom_verification_email(self) -> "Ses":
        '''(experimental) Grants permission to add an email address to the list of identities and attempts to verify it for your account.

        Access Level: Write

        Possible conditions:

        - .ifApiVersion()
        - .ifFeedbackAddress()
        - .ifFromAddress()
        - .ifFromDisplayName()
        - .ifRecipients()

        https://docs.aws.amazon.com/ses/latest/APIReference/API_SendCustomVerificationEmail.html

        :stability: experimental
        '''
        return typing.cast("Ses", jsii.invoke(self, "toSendCustomVerificationEmail", []))

    @jsii.member(jsii_name="toSendEmail")
    def to_send_email(self) -> "Ses":
        '''(experimental) Grants permission to send an email message.

        Access Level: Write

        Possible conditions:

        - .ifApiVersion()
        - .ifFeedbackAddress()
        - .ifFromAddress()
        - .ifFromDisplayName()
        - .ifRecipients()

        https://docs.aws.amazon.com/ses/latest/APIReference/API_SendEmail.html

        :stability: experimental
        '''
        return typing.cast("Ses", jsii.invoke(self, "toSendEmail", []))

    @jsii.member(jsii_name="toSendRawEmail")
    def to_send_raw_email(self) -> "Ses":
        '''(experimental) Grants permission to send an email message, with header and content specified by the client.

        Access Level: Write

        Possible conditions:

        - .ifApiVersion()
        - .ifFeedbackAddress()
        - .ifFromAddress()
        - .ifFromDisplayName()
        - .ifRecipients()

        https://docs.aws.amazon.com/ses/latest/APIReference/API_SendRawEmail.html

        :stability: experimental
        '''
        return typing.cast("Ses", jsii.invoke(self, "toSendRawEmail", []))

    @jsii.member(jsii_name="toSendTemplatedEmail")
    def to_send_templated_email(self) -> "Ses":
        '''(experimental) Grants permission to compose an email message using an email template.

        Access Level: Write

        Possible conditions:

        - .ifApiVersion()
        - .ifFeedbackAddress()
        - .ifFromAddress()
        - .ifFromDisplayName()
        - .ifRecipients()

        https://docs.aws.amazon.com/ses/latest/APIReference/API_SendTemplatedEmail.html

        :stability: experimental
        '''
        return typing.cast("Ses", jsii.invoke(self, "toSendTemplatedEmail", []))

    @jsii.member(jsii_name="toSetActiveReceiptRuleSet")
    def to_set_active_receipt_rule_set(self) -> "Ses":
        '''(experimental) Grants permission to set the specified receipt rule set as the active receipt rule set.

        Access Level: Write

        Possible conditions:

        - .ifApiVersion()

        https://docs.aws.amazon.com/ses/latest/APIReference/API_SetActiveReceiptRuleSet.html

        :stability: experimental
        '''
        return typing.cast("Ses", jsii.invoke(self, "toSetActiveReceiptRuleSet", []))

    @jsii.member(jsii_name="toSetIdentityDkimEnabled")
    def to_set_identity_dkim_enabled(self) -> "Ses":
        '''(experimental) Grants permission to enable or disable Easy DKIM signing of email sent from an identity.

        Access Level: Write

        Possible conditions:

        - .ifApiVersion()

        https://docs.aws.amazon.com/ses/latest/APIReference/API_SetIdentityDkimEnabled.html

        :stability: experimental
        '''
        return typing.cast("Ses", jsii.invoke(self, "toSetIdentityDkimEnabled", []))

    @jsii.member(jsii_name="toSetIdentityFeedbackForwardingEnabled")
    def to_set_identity_feedback_forwarding_enabled(self) -> "Ses":
        '''(experimental) Grants permission to enable or disable whether Amazon SES forwards bounce and complaint notifications for an identity (an email address or a domain).

        Access Level: Write

        Possible conditions:

        - .ifApiVersion()

        https://docs.aws.amazon.com/ses/latest/APIReference/API_SetIdentityFeedbackForwardingEnabled.html

        :stability: experimental
        '''
        return typing.cast("Ses", jsii.invoke(self, "toSetIdentityFeedbackForwardingEnabled", []))

    @jsii.member(jsii_name="toSetIdentityHeadersInNotificationsEnabled")
    def to_set_identity_headers_in_notifications_enabled(self) -> "Ses":
        '''(experimental) Grants permission to set whether Amazon SES includes the original email headers in the Amazon Simple Notification Service (Amazon SNS) notifications of a specified type for a given identity (an email address or a domain).

        Access Level: Write

        Possible conditions:

        - .ifApiVersion()

        https://docs.aws.amazon.com/ses/latest/APIReference/API_SetIdentityHeadersInNotificationsEnabled.html

        :stability: experimental
        '''
        return typing.cast("Ses", jsii.invoke(self, "toSetIdentityHeadersInNotificationsEnabled", []))

    @jsii.member(jsii_name="toSetIdentityMailFromDomain")
    def to_set_identity_mail_from_domain(self) -> "Ses":
        '''(experimental) Grants permission to enable or disable the custom MAIL FROM domain setup for a verified identity.

        Access Level: Write

        Possible conditions:

        - .ifApiVersion()

        https://docs.aws.amazon.com/ses/latest/APIReference/API_SetIdentityMailFromDomain.html

        :stability: experimental
        '''
        return typing.cast("Ses", jsii.invoke(self, "toSetIdentityMailFromDomain", []))

    @jsii.member(jsii_name="toSetIdentityNotificationTopic")
    def to_set_identity_notification_topic(self) -> "Ses":
        '''(experimental) Grants permission to set an Amazon Simple Notification Service (Amazon SNS) topic to use when delivering notifications for a verified identity.

        Access Level: Write

        Possible conditions:

        - .ifApiVersion()

        https://docs.aws.amazon.com/ses/latest/APIReference/API_SetIdentityNotificationTopic.html

        :stability: experimental
        '''
        return typing.cast("Ses", jsii.invoke(self, "toSetIdentityNotificationTopic", []))

    @jsii.member(jsii_name="toSetReceiptRulePosition")
    def to_set_receipt_rule_position(self) -> "Ses":
        '''(experimental) Grants permission to set the position of the specified receipt rule in the receipt rule set.

        Access Level: Write

        Possible conditions:

        - .ifApiVersion()

        https://docs.aws.amazon.com/ses/latest/APIReference/API_SetReceiptRulePosition.html

        :stability: experimental
        '''
        return typing.cast("Ses", jsii.invoke(self, "toSetReceiptRulePosition", []))

    @jsii.member(jsii_name="toTestRenderTemplate")
    def to_test_render_template(self) -> "Ses":
        '''(experimental) Grants permission to create a preview of the MIME content of an email when provided with a template and a set of replacement data.

        Access Level: Write

        Possible conditions:

        - .ifApiVersion()

        https://docs.aws.amazon.com/ses/latest/APIReference/API_TestRenderTemplate.html

        :stability: experimental
        '''
        return typing.cast("Ses", jsii.invoke(self, "toTestRenderTemplate", []))

    @jsii.member(jsii_name="toUpdateAccountSendingEnabled")
    def to_update_account_sending_enabled(self) -> "Ses":
        '''(experimental) Grants permission to enable or disable email sending for your account.

        Access Level: Write

        Possible conditions:

        - .ifApiVersion()

        https://docs.aws.amazon.com/ses/latest/APIReference/API_UpdateAccountSendingEnabled.html

        :stability: experimental
        '''
        return typing.cast("Ses", jsii.invoke(self, "toUpdateAccountSendingEnabled", []))

    @jsii.member(jsii_name="toUpdateConfigurationSetEventDestination")
    def to_update_configuration_set_event_destination(self) -> "Ses":
        '''(experimental) Grants permission to update the event destination of a configuration set.

        Access Level: Write

        Possible conditions:

        - .ifApiVersion()

        https://docs.aws.amazon.com/ses/latest/APIReference/API_UpdateConfigurationSetEventDestination.html

        :stability: experimental
        '''
        return typing.cast("Ses", jsii.invoke(self, "toUpdateConfigurationSetEventDestination", []))

    @jsii.member(jsii_name="toUpdateConfigurationSetReputationMetricsEnabled")
    def to_update_configuration_set_reputation_metrics_enabled(self) -> "Ses":
        '''(experimental) Grants permission to enable or disable the publishing of reputation metrics for emails sent using a specific configuration set.

        Access Level: Write

        Possible conditions:

        - .ifApiVersion()

        https://docs.aws.amazon.com/ses/latest/APIReference/API_UpdateConfigurationSetReputationMetricsEnabled.html

        :stability: experimental
        '''
        return typing.cast("Ses", jsii.invoke(self, "toUpdateConfigurationSetReputationMetricsEnabled", []))

    @jsii.member(jsii_name="toUpdateConfigurationSetSendingEnabled")
    def to_update_configuration_set_sending_enabled(self) -> "Ses":
        '''(experimental) Grants permission to enable or disable email sending for messages sent using a specific configuration set.

        Access Level: Write

        Possible conditions:

        - .ifApiVersion()

        https://docs.aws.amazon.com/ses/latest/APIReference/API_UpdateConfigurationSetSendingEnabled.html

        :stability: experimental
        '''
        return typing.cast("Ses", jsii.invoke(self, "toUpdateConfigurationSetSendingEnabled", []))

    @jsii.member(jsii_name="toUpdateConfigurationSetTrackingOptions")
    def to_update_configuration_set_tracking_options(self) -> "Ses":
        '''(experimental) Grants permission to modify an association between a configuration set and a custom domain for open and click event tracking.

        Access Level: Write

        Possible conditions:

        - .ifApiVersion()

        https://docs.aws.amazon.com/ses/latest/APIReference/API_UpdateConfigurationSetTrackingOptions.html

        :stability: experimental
        '''
        return typing.cast("Ses", jsii.invoke(self, "toUpdateConfigurationSetTrackingOptions", []))

    @jsii.member(jsii_name="toUpdateCustomVerificationEmailTemplate")
    def to_update_custom_verification_email_template(self) -> "Ses":
        '''(experimental) Grants permission to update an existing custom verification email template.

        Access Level: Write

        Possible conditions:

        - .ifApiVersion()

        https://docs.aws.amazon.com/ses/latest/APIReference/API_UpdateCustomVerificationEmailTemplate.html

        :stability: experimental
        '''
        return typing.cast("Ses", jsii.invoke(self, "toUpdateCustomVerificationEmailTemplate", []))

    @jsii.member(jsii_name="toUpdateReceiptRule")
    def to_update_receipt_rule(self) -> "Ses":
        '''(experimental) Grants permission to update a receipt rule.

        Access Level: Write

        Possible conditions:

        - .ifApiVersion()

        https://docs.aws.amazon.com/ses/latest/APIReference/API_UpdateReceiptRule.html

        :stability: experimental
        '''
        return typing.cast("Ses", jsii.invoke(self, "toUpdateReceiptRule", []))

    @jsii.member(jsii_name="toUpdateTemplate")
    def to_update_template(self) -> "Ses":
        '''(experimental) Grants permission to update an email template.

        Access Level: Write

        Possible conditions:

        - .ifApiVersion()

        https://docs.aws.amazon.com/ses/latest/APIReference/API_UpdateTemplate.html

        :stability: experimental
        '''
        return typing.cast("Ses", jsii.invoke(self, "toUpdateTemplate", []))

    @jsii.member(jsii_name="toVerifyDomainDkim")
    def to_verify_domain_dkim(self) -> "Ses":
        '''(experimental) Grants permission to return a set of DKIM tokens for a domain.

        Access Level: Write

        Possible conditions:

        - .ifApiVersion()

        https://docs.aws.amazon.com/ses/latest/APIReference/API_VerifyDomainDkim.html

        :stability: experimental
        '''
        return typing.cast("Ses", jsii.invoke(self, "toVerifyDomainDkim", []))

    @jsii.member(jsii_name="toVerifyDomainIdentity")
    def to_verify_domain_identity(self) -> "Ses":
        '''(experimental) Grants permission to verify a domain.

        Access Level: Write

        Possible conditions:

        - .ifApiVersion()

        https://docs.aws.amazon.com/ses/latest/APIReference/API_VerifyDomainIdentity.html

        :stability: experimental
        '''
        return typing.cast("Ses", jsii.invoke(self, "toVerifyDomainIdentity", []))

    @jsii.member(jsii_name="toVerifyEmailAddress")
    def to_verify_email_address(self) -> "Ses":
        '''(experimental) Grants permission to verify an email address.

        Access Level: Write

        Possible conditions:

        - .ifApiVersion()

        https://docs.aws.amazon.com/ses/latest/APIReference/API_VerifyEmailAddress.html

        :stability: experimental
        '''
        return typing.cast("Ses", jsii.invoke(self, "toVerifyEmailAddress", []))

    @jsii.member(jsii_name="toVerifyEmailIdentity")
    def to_verify_email_identity(self) -> "Ses":
        '''(experimental) Grants permission to verify an email identity.

        Access Level: Write

        Possible conditions:

        - .ifApiVersion()

        https://docs.aws.amazon.com/ses/latest/APIReference/API_VerifyEmailIdentity.html

        :stability: experimental
        '''
        return typing.cast("Ses", jsii.invoke(self, "toVerifyEmailIdentity", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f6c136e3e508cadbb9c4d3d86806a19a78b73be951fd6f8588b61719fd08bf78)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bac1a84f1b61b531f687d8707ddc6d48588f011549368c5f700f83d47d336874)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class SesPinpoint(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.SesPinpoint",
):
    '''(experimental) Statement provider for service `ses-pinpoint <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonpinpointemailservice.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `ses-pinpoint <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonpinpointemailservice.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="ifApiVersion")
    def if_api_version(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "SesPinpoint":
        '''(experimental) Filters actions based on the SES API version.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonses.html#amazonses-policy-keys

        Applies to actions:

        - .toCreateConfigurationSet()
        - .toCreateConfigurationSetEventDestination()
        - .toCreateDedicatedIpPool()
        - .toCreateDeliverabilityTestReport()
        - .toCreateEmailIdentity()
        - .toDeleteConfigurationSet()
        - .toDeleteConfigurationSetEventDestination()
        - .toDeleteDedicatedIpPool()
        - .toDeleteEmailIdentity()
        - .toGetAccount()
        - .toGetBlacklistReports()
        - .toGetConfigurationSet()
        - .toGetConfigurationSetEventDestinations()
        - .toGetDedicatedIp()
        - .toGetDedicatedIps()
        - .toGetDeliverabilityDashboardOptions()
        - .toGetDeliverabilityTestReport()
        - .toGetDomainDeliverabilityCampaign()
        - .toGetDomainStatisticsReport()
        - .toGetEmailIdentity()
        - .toListConfigurationSets()
        - .toListDedicatedIpPools()
        - .toListDeliverabilityTestReports()
        - .toListDomainDeliverabilityCampaigns()
        - .toListEmailIdentities()
        - .toListTagsForResource()
        - .toPutAccountDedicatedIpWarmupAttributes()
        - .toPutAccountSendingAttributes()
        - .toPutConfigurationSetDeliveryOptions()
        - .toPutConfigurationSetReputationOptions()
        - .toPutConfigurationSetSendingOptions()
        - .toPutConfigurationSetTrackingOptions()
        - .toPutDedicatedIpInPool()
        - .toPutDedicatedIpWarmupAttributes()
        - .toPutDeliverabilityDashboardOption()
        - .toPutEmailIdentityDkimAttributes()
        - .toPutEmailIdentityFeedbackAttributes()
        - .toPutEmailIdentityMailFromAttributes()
        - .toSendEmail()
        - .toTagResource()
        - .toUntagResource()
        - .toUpdateConfigurationSetEventDestination()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c37e725fed529ef1f6eb6475400976d0c46acd383039848f37a109129cf6e980)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("SesPinpoint", jsii.invoke(self, "ifApiVersion", [value, operator]))

    @jsii.member(jsii_name="ifFeedbackAddress")
    def if_feedback_address(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "SesPinpoint":
        '''(experimental) Filters actions based on the "Return-Path" address, which specifies where bounces and complaints are sent by email feedback forwarding.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonses.html#amazonses-policy-keys

        Applies to actions:

        - .toSendEmail()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__52e7d7fd7abbcd7506f612406a2568d2573bf641f1855752cb035083acf6902c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("SesPinpoint", jsii.invoke(self, "ifFeedbackAddress", [value, operator]))

    @jsii.member(jsii_name="ifFromAddress")
    def if_from_address(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "SesPinpoint":
        '''(experimental) Filters actions based on the "From" address of a message.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonses.html#amazonses-policy-keys

        Applies to actions:

        - .toSendEmail()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ecedaa9797e97e1b0ec885fc7a972544ca46c651ea4f3afdf7c1977ff33b521f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("SesPinpoint", jsii.invoke(self, "ifFromAddress", [value, operator]))

    @jsii.member(jsii_name="ifFromDisplayName")
    def if_from_display_name(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "SesPinpoint":
        '''(experimental) Filters actions based on the "From" address that is used as the display name of a message.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonses.html#amazonses-policy-keys

        Applies to actions:

        - .toSendEmail()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__aec92d60b942fe65b9671baf6ab9ecebb951c2d27acfa9d5680a0e4f594b1e01)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("SesPinpoint", jsii.invoke(self, "ifFromDisplayName", [value, operator]))

    @jsii.member(jsii_name="ifRecipients")
    def if_recipients(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "SesPinpoint":
        '''(experimental) Filters actions based on the recipient addresses of a message, which include the "To", "CC", and "BCC" addresses.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonses.html#amazonses-policy-keys

        Applies to actions:

        - .toSendEmail()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__72849d5183391a7ed0be6a2e0e1d5dd878fbf8129c09d73544ec1262af55f594)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("SesPinpoint", jsii.invoke(self, "ifRecipients", [value, operator]))

    @jsii.member(jsii_name="onConfigurationSet")
    def on_configuration_set(
        self,
        configuration_set_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "SesPinpoint":
        '''(experimental) Adds a resource of type configuration-set to the statement.

        https://docs.aws.amazon.com/pinpoint-email/latest/APIReference/API_CreateConfigurationSet.html

        :param configuration_set_name: - Identifier for the configurationSetName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ad193f3301d05331fc1f0c2c30ced9f53f17af816fd37a75677ad92f2d0f28bc)
            check_type(argname="argument configuration_set_name", value=configuration_set_name, expected_type=type_hints["configuration_set_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("SesPinpoint", jsii.invoke(self, "onConfigurationSet", [configuration_set_name, account, region, partition]))

    @jsii.member(jsii_name="onDedicatedIpPool")
    def on_dedicated_ip_pool(
        self,
        dedicated_ip_pool: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "SesPinpoint":
        '''(experimental) Adds a resource of type dedicated-ip-pool to the statement.

        https://docs.aws.amazon.com/pinpoint-email/latest/APIReference/API_DedicatedIp.html

        :param dedicated_ip_pool: - Identifier for the dedicatedIPPool.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d888ddb1c3480311a90a3b259f3ca714a034b6425b75d298e9ab9b0863ba9b85)
            check_type(argname="argument dedicated_ip_pool", value=dedicated_ip_pool, expected_type=type_hints["dedicated_ip_pool"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("SesPinpoint", jsii.invoke(self, "onDedicatedIpPool", [dedicated_ip_pool, account, region, partition]))

    @jsii.member(jsii_name="onDeliverabilityTestReport")
    def on_deliverability_test_report(
        self,
        report_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "SesPinpoint":
        '''(experimental) Adds a resource of type deliverability-test-report to the statement.

        https://docs.aws.amazon.com/pinpoint-email/latest/APIReference/API_DeliverabilityTestReport.html

        :param report_id: - Identifier for the reportId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7e2eb35be2a4fc79954f592621610f0fc4e3d639ce7f0d80aadb8448596ae7fa)
            check_type(argname="argument report_id", value=report_id, expected_type=type_hints["report_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("SesPinpoint", jsii.invoke(self, "onDeliverabilityTestReport", [report_id, account, region, partition]))

    @jsii.member(jsii_name="onIdentity")
    def on_identity(
        self,
        identity_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "SesPinpoint":
        '''(experimental) Adds a resource of type identity to the statement.

        https://docs.aws.amazon.com/pinpoint-email/latest/APIReference/API_IdentityInfo.html

        :param identity_name: - Identifier for the identityName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__91ce7a1baac649a0d9b201a9048995cdce68a49b2b26fd2e01433d17665ceb59)
            check_type(argname="argument identity_name", value=identity_name, expected_type=type_hints["identity_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("SesPinpoint", jsii.invoke(self, "onIdentity", [identity_name, account, region, partition]))

    @jsii.member(jsii_name="toCreateConfigurationSet")
    def to_create_configuration_set(self) -> "SesPinpoint":
        '''(experimental) Grants permission to create a configuration set.

        Access Level: Write

        Possible conditions:

        - .ifApiVersion()
        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/pinpoint-email/latest/APIReference/API_CreateConfigurationSet.html

        :stability: experimental
        '''
        return typing.cast("SesPinpoint", jsii.invoke(self, "toCreateConfigurationSet", []))

    @jsii.member(jsii_name="toCreateConfigurationSetEventDestination")
    def to_create_configuration_set_event_destination(self) -> "SesPinpoint":
        '''(experimental) Grants permission to create a configuration set event destination.

        Access Level: Write

        Possible conditions:

        - .ifApiVersion()
        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/pinpoint-email/latest/APIReference/API_CreateConfigurationSetEventDestination.html

        :stability: experimental
        '''
        return typing.cast("SesPinpoint", jsii.invoke(self, "toCreateConfigurationSetEventDestination", []))

    @jsii.member(jsii_name="toCreateDedicatedIpPool")
    def to_create_dedicated_ip_pool(self) -> "SesPinpoint":
        '''(experimental) Grants permission to create a new pool of dedicated IP addresses.

        Access Level: Write

        Possible conditions:

        - .ifApiVersion()
        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/pinpoint-email/latest/APIReference/API_CreateDedicatedIpPool.html

        :stability: experimental
        '''
        return typing.cast("SesPinpoint", jsii.invoke(self, "toCreateDedicatedIpPool", []))

    @jsii.member(jsii_name="toCreateDeliverabilityTestReport")
    def to_create_deliverability_test_report(self) -> "SesPinpoint":
        '''(experimental) Grants permission to create a new predictive inbox placement test.

        Access Level: Write

        Possible conditions:

        - .ifApiVersion()
        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/pinpoint-email/latest/APIReference/API_CreateDeliverabilityTestReport.html

        :stability: experimental
        '''
        return typing.cast("SesPinpoint", jsii.invoke(self, "toCreateDeliverabilityTestReport", []))

    @jsii.member(jsii_name="toCreateEmailIdentity")
    def to_create_email_identity(self) -> "SesPinpoint":
        '''(experimental) Grants permission to start the process of verifying an email identity.

        Access Level: Write

        Possible conditions:

        - .ifApiVersion()
        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/pinpoint-email/latest/APIReference/API_CreateEmailIdentity.html

        :stability: experimental
        '''
        return typing.cast("SesPinpoint", jsii.invoke(self, "toCreateEmailIdentity", []))

    @jsii.member(jsii_name="toDeleteConfigurationSet")
    def to_delete_configuration_set(self) -> "SesPinpoint":
        '''(experimental) Grants permission to delete an existing configuration set.

        Access Level: Write

        Possible conditions:

        - .ifApiVersion()
        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/pinpoint-email/latest/APIReference/API_DeleteConfigurationSet.html

        :stability: experimental
        '''
        return typing.cast("SesPinpoint", jsii.invoke(self, "toDeleteConfigurationSet", []))

    @jsii.member(jsii_name="toDeleteConfigurationSetEventDestination")
    def to_delete_configuration_set_event_destination(self) -> "SesPinpoint":
        '''(experimental) Grants permission to delete an event destination.

        Access Level: Write

        Possible conditions:

        - .ifApiVersion()
        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/pinpoint-email/latest/APIReference/API_DeleteConfigurationSetEventDestination.html

        :stability: experimental
        '''
        return typing.cast("SesPinpoint", jsii.invoke(self, "toDeleteConfigurationSetEventDestination", []))

    @jsii.member(jsii_name="toDeleteDedicatedIpPool")
    def to_delete_dedicated_ip_pool(self) -> "SesPinpoint":
        '''(experimental) Grants permission to delete a dedicated IP pool.

        Access Level: Write

        Possible conditions:

        - .ifApiVersion()
        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/pinpoint-email/latest/APIReference/API_DeleteDedicatedIpPool.html

        :stability: experimental
        '''
        return typing.cast("SesPinpoint", jsii.invoke(self, "toDeleteDedicatedIpPool", []))

    @jsii.member(jsii_name="toDeleteEmailIdentity")
    def to_delete_email_identity(self) -> "SesPinpoint":
        '''(experimental) Grants permission to delete an email identity that you previously verified.

        Access Level: Write

        Possible conditions:

        - .ifApiVersion()
        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/pinpoint-email/latest/APIReference/API_DeleteEmailIdentity.html

        :stability: experimental
        '''
        return typing.cast("SesPinpoint", jsii.invoke(self, "toDeleteEmailIdentity", []))

    @jsii.member(jsii_name="toGetAccount")
    def to_get_account(self) -> "SesPinpoint":
        '''(experimental) Grants permission to get information about the email-sending status and capabilities.

        Access Level: Read

        Possible conditions:

        - .ifApiVersion()

        https://docs.aws.amazon.com/pinpoint-email/latest/APIReference/API_GetAccount.html

        :stability: experimental
        '''
        return typing.cast("SesPinpoint", jsii.invoke(self, "toGetAccount", []))

    @jsii.member(jsii_name="toGetBlacklistReports")
    def to_get_blacklist_reports(self) -> "SesPinpoint":
        '''(experimental) Grants permission to retrieve a list of the deny lists on which your dedicated IP addresses appear.

        Access Level: Read

        Possible conditions:

        - .ifApiVersion()

        https://docs.aws.amazon.com/pinpoint-email/latest/APIReference/API_GetBlacklistReports.html

        :stability: experimental
        '''
        return typing.cast("SesPinpoint", jsii.invoke(self, "toGetBlacklistReports", []))

    @jsii.member(jsii_name="toGetConfigurationSet")
    def to_get_configuration_set(self) -> "SesPinpoint":
        '''(experimental) Grants permission to get information about an existing configuration set.

        Access Level: Read

        Possible conditions:

        - .ifApiVersion()
        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/pinpoint-email/latest/APIReference/API_GetConfigurationSet.html

        :stability: experimental
        '''
        return typing.cast("SesPinpoint", jsii.invoke(self, "toGetConfigurationSet", []))

    @jsii.member(jsii_name="toGetConfigurationSetEventDestinations")
    def to_get_configuration_set_event_destinations(self) -> "SesPinpoint":
        '''(experimental) Grants permission to retrieve a list of event destinations that are associated with a configuration set.

        Access Level: Read

        Possible conditions:

        - .ifApiVersion()
        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/pinpoint-email/latest/APIReference/API_GetConfigurationSetEventDestinations.html

        :stability: experimental
        '''
        return typing.cast("SesPinpoint", jsii.invoke(self, "toGetConfigurationSetEventDestinations", []))

    @jsii.member(jsii_name="toGetDedicatedIp")
    def to_get_dedicated_ip(self) -> "SesPinpoint":
        '''(experimental) Grants permission to get information about a dedicated IP address.

        Access Level: Read

        Possible conditions:

        - .ifApiVersion()

        https://docs.aws.amazon.com/pinpoint-email/latest/APIReference/API_GetDedicatedIp.html

        :stability: experimental
        '''
        return typing.cast("SesPinpoint", jsii.invoke(self, "toGetDedicatedIp", []))

    @jsii.member(jsii_name="toGetDedicatedIps")
    def to_get_dedicated_ips(self) -> "SesPinpoint":
        '''(experimental) Grants permission to list the dedicated IP addresses that are associated with your account.

        Access Level: Read

        Possible conditions:

        - .ifApiVersion()
        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/pinpoint-email/latest/APIReference/API_GetDedicatedIps.html

        :stability: experimental
        '''
        return typing.cast("SesPinpoint", jsii.invoke(self, "toGetDedicatedIps", []))

    @jsii.member(jsii_name="toGetDeliverabilityDashboardOptions")
    def to_get_deliverability_dashboard_options(self) -> "SesPinpoint":
        '''(experimental) Grants permission to get the status of the Deliverability dashboard.

        Access Level: Read

        Possible conditions:

        - .ifApiVersion()

        https://docs.aws.amazon.com/pinpoint-email/latest/APIReference/API_GetDeliverabilityDashboardOptions.html

        :stability: experimental
        '''
        return typing.cast("SesPinpoint", jsii.invoke(self, "toGetDeliverabilityDashboardOptions", []))

    @jsii.member(jsii_name="toGetDeliverabilityTestReport")
    def to_get_deliverability_test_report(self) -> "SesPinpoint":
        '''(experimental) Grants permission to retrieve the results of a predictive inbox placement test.

        Access Level: Read

        Possible conditions:

        - .ifApiVersion()
        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/pinpoint-email/latest/APIReference/API_GetDeliverabilityTestReport.html

        :stability: experimental
        '''
        return typing.cast("SesPinpoint", jsii.invoke(self, "toGetDeliverabilityTestReport", []))

    @jsii.member(jsii_name="toGetDomainDeliverabilityCampaign")
    def to_get_domain_deliverability_campaign(self) -> "SesPinpoint":
        '''(experimental) Grants permission to retrieve all the deliverability data for a specific campaign.

        Access Level: Read

        Possible conditions:

        - .ifApiVersion()

        https://docs.aws.amazon.com/pinpoint-email/latest/APIReference/API_GetDomainDeliverabilityCampaign.html

        :stability: experimental
        '''
        return typing.cast("SesPinpoint", jsii.invoke(self, "toGetDomainDeliverabilityCampaign", []))

    @jsii.member(jsii_name="toGetDomainStatisticsReport")
    def to_get_domain_statistics_report(self) -> "SesPinpoint":
        '''(experimental) Grants permission to retrieve inbox placement and engagement rates for the domains that you use to send email.

        Access Level: Read

        Possible conditions:

        - .ifApiVersion()
        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/pinpoint-email/latest/APIReference/API_GetDomainStatisticsReport.html

        :stability: experimental
        '''
        return typing.cast("SesPinpoint", jsii.invoke(self, "toGetDomainStatisticsReport", []))

    @jsii.member(jsii_name="toGetEmailIdentity")
    def to_get_email_identity(self) -> "SesPinpoint":
        '''(experimental) Grants permission to get information about a specific identity associated with your account.

        Access Level: Read

        Possible conditions:

        - .ifApiVersion()
        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/pinpoint-email/latest/APIReference/API_GetEmailIdentity.html

        :stability: experimental
        '''
        return typing.cast("SesPinpoint", jsii.invoke(self, "toGetEmailIdentity", []))

    @jsii.member(jsii_name="toListConfigurationSets")
    def to_list_configuration_sets(self) -> "SesPinpoint":
        '''(experimental) Grants permission to list all of the configuration sets associated with your account.

        Access Level: List

        Possible conditions:

        - .ifApiVersion()

        https://docs.aws.amazon.com/pinpoint-email/latest/APIReference/API_ListConfigurationSets.html

        :stability: experimental
        '''
        return typing.cast("SesPinpoint", jsii.invoke(self, "toListConfigurationSets", []))

    @jsii.member(jsii_name="toListDedicatedIpPools")
    def to_list_dedicated_ip_pools(self) -> "SesPinpoint":
        '''(experimental) Grants permission to list all of the dedicated IP pools that exist in your account.

        Access Level: List

        Possible conditions:

        - .ifApiVersion()

        https://docs.aws.amazon.com/pinpoint-email/latest/APIReference/API_ListDedicatedIpPools.html

        :stability: experimental
        '''
        return typing.cast("SesPinpoint", jsii.invoke(self, "toListDedicatedIpPools", []))

    @jsii.member(jsii_name="toListDeliverabilityTestReports")
    def to_list_deliverability_test_reports(self) -> "SesPinpoint":
        '''(experimental) Grants permission to retrieve a list of the predictive inbox placement tests that you've performed, regardless of their statuses.

        Access Level: List

        Possible conditions:

        - .ifApiVersion()

        https://docs.aws.amazon.com/pinpoint-email/latest/APIReference/API_ListDeliverabilityTestReports.html

        :stability: experimental
        '''
        return typing.cast("SesPinpoint", jsii.invoke(self, "toListDeliverabilityTestReports", []))

    @jsii.member(jsii_name="toListDomainDeliverabilityCampaigns")
    def to_list_domain_deliverability_campaigns(self) -> "SesPinpoint":
        '''(experimental) Grants permission to retrieve deliverability data for all the campaigns that used a specific domain to send email during a specified time range.

        Access Level: Read

        Possible conditions:

        - .ifApiVersion()

        https://docs.aws.amazon.com/pinpoint-email/latest/APIReference/API_ListDomainDeliverabilityCampaigns.html

        :stability: experimental
        '''
        return typing.cast("SesPinpoint", jsii.invoke(self, "toListDomainDeliverabilityCampaigns", []))

    @jsii.member(jsii_name="toListEmailIdentities")
    def to_list_email_identities(self) -> "SesPinpoint":
        '''(experimental) Grants permission to list all of the email identities that are associated with your account.

        Access Level: List

        Possible conditions:

        - .ifApiVersion()

        https://docs.aws.amazon.com/pinpoint-email/latest/APIReference/API_ListEmailIdentities.html

        :stability: experimental
        '''
        return typing.cast("SesPinpoint", jsii.invoke(self, "toListEmailIdentities", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "SesPinpoint":
        '''(experimental) Grants permission to retrieve a list of the tags (keys and values) that are associated with a specific resource.

        Access Level: Read

        Possible conditions:

        - .ifApiVersion()

        https://docs.aws.amazon.com/pinpoint-email/latest/APIReference/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("SesPinpoint", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toPutAccountDedicatedIpWarmupAttributes")
    def to_put_account_dedicated_ip_warmup_attributes(self) -> "SesPinpoint":
        '''(experimental) Grants permission to enable or disable the automatic warm-up feature for dedicated IP addresses.

        Access Level: Write

        Possible conditions:

        - .ifApiVersion()

        https://docs.aws.amazon.com/pinpoint-email/latest/APIReference/API_PutAccountDedicatedIpWarmupAttributes.html

        :stability: experimental
        '''
        return typing.cast("SesPinpoint", jsii.invoke(self, "toPutAccountDedicatedIpWarmupAttributes", []))

    @jsii.member(jsii_name="toPutAccountSendingAttributes")
    def to_put_account_sending_attributes(self) -> "SesPinpoint":
        '''(experimental) Grants permission to enable or disable the ability of your account to send email.

        Access Level: Write

        Possible conditions:

        - .ifApiVersion()

        https://docs.aws.amazon.com/pinpoint-email/latest/APIReference/API_PutAccountSendingAttributes.html

        :stability: experimental
        '''
        return typing.cast("SesPinpoint", jsii.invoke(self, "toPutAccountSendingAttributes", []))

    @jsii.member(jsii_name="toPutConfigurationSetDeliveryOptions")
    def to_put_configuration_set_delivery_options(self) -> "SesPinpoint":
        '''(experimental) Grants permission to associate a configuration set with a dedicated IP pool.

        Access Level: Write

        Possible conditions:

        - .ifApiVersion()
        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/pinpoint-email/latest/APIReference/API_PutConfigurationSetDeliveryOptions.html

        :stability: experimental
        '''
        return typing.cast("SesPinpoint", jsii.invoke(self, "toPutConfigurationSetDeliveryOptions", []))

    @jsii.member(jsii_name="toPutConfigurationSetReputationOptions")
    def to_put_configuration_set_reputation_options(self) -> "SesPinpoint":
        '''(experimental) Grants permission to enable or disable collection of reputation metrics for emails that you send using a particular configuration set.

        Access Level: Write

        Possible conditions:

        - .ifApiVersion()
        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/pinpoint-email/latest/APIReference/API_PutConfigurationSetReputationOptions.html

        :stability: experimental
        '''
        return typing.cast("SesPinpoint", jsii.invoke(self, "toPutConfigurationSetReputationOptions", []))

    @jsii.member(jsii_name="toPutConfigurationSetSendingOptions")
    def to_put_configuration_set_sending_options(self) -> "SesPinpoint":
        '''(experimental) Grants permission to enable or disable email sending for messages that use a particular configuration set.

        Access Level: Write

        Possible conditions:

        - .ifApiVersion()
        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/pinpoint-email/latest/APIReference/API_PutConfigurationSetSendingOptions.html

        :stability: experimental
        '''
        return typing.cast("SesPinpoint", jsii.invoke(self, "toPutConfigurationSetSendingOptions", []))

    @jsii.member(jsii_name="toPutConfigurationSetTrackingOptions")
    def to_put_configuration_set_tracking_options(self) -> "SesPinpoint":
        '''(experimental) Grants permission to specify a custom domain to use for open and click tracking elements in email that you send using a particular configuration set.

        Access Level: Write

        Possible conditions:

        - .ifApiVersion()
        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/pinpoint-email/latest/APIReference/API_PutConfigurationSetTrackingOptions.html

        :stability: experimental
        '''
        return typing.cast("SesPinpoint", jsii.invoke(self, "toPutConfigurationSetTrackingOptions", []))

    @jsii.member(jsii_name="toPutDedicatedIpInPool")
    def to_put_dedicated_ip_in_pool(self) -> "SesPinpoint":
        '''(experimental) Grants permission to move a dedicated IP address to an existing dedicated IP pool.

        Access Level: Write

        Possible conditions:

        - .ifApiVersion()
        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/pinpoint-email/latest/APIReference/API_PutDedicatedIpInPool.html

        :stability: experimental
        '''
        return typing.cast("SesPinpoint", jsii.invoke(self, "toPutDedicatedIpInPool", []))

    @jsii.member(jsii_name="toPutDedicatedIpWarmupAttributes")
    def to_put_dedicated_ip_warmup_attributes(self) -> "SesPinpoint":
        '''(experimental) Grants permission to enable dedicated IP warm up attributes.

        Access Level: Write

        Possible conditions:

        - .ifApiVersion()

        https://docs.aws.amazon.com/pinpoint-email/latest/APIReference/API_PutDedicatedIpWarmupAttributes.html

        :stability: experimental
        '''
        return typing.cast("SesPinpoint", jsii.invoke(self, "toPutDedicatedIpWarmupAttributes", []))

    @jsii.member(jsii_name="toPutDeliverabilityDashboardOption")
    def to_put_deliverability_dashboard_option(self) -> "SesPinpoint":
        '''(experimental) Grants permission to enable or disable the Deliverability dashboard.

        Access Level: Write

        Possible conditions:

        - .ifApiVersion()

        https://docs.aws.amazon.com/pinpoint-email/latest/APIReference/API_PutDeliverabilityDashboardOption.html

        :stability: experimental
        '''
        return typing.cast("SesPinpoint", jsii.invoke(self, "toPutDeliverabilityDashboardOption", []))

    @jsii.member(jsii_name="toPutEmailIdentityDkimAttributes")
    def to_put_email_identity_dkim_attributes(self) -> "SesPinpoint":
        '''(experimental) Grants permission to enable or disable DKIM authentication for an email identity.

        Access Level: Write

        Possible conditions:

        - .ifApiVersion()
        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/pinpoint-email/latest/APIReference/API_PutEmailIdentityDkimAttributes.html

        :stability: experimental
        '''
        return typing.cast("SesPinpoint", jsii.invoke(self, "toPutEmailIdentityDkimAttributes", []))

    @jsii.member(jsii_name="toPutEmailIdentityFeedbackAttributes")
    def to_put_email_identity_feedback_attributes(self) -> "SesPinpoint":
        '''(experimental) Grants permission to enable or disable feedback forwarding for an identity.

        Access Level: Write

        Possible conditions:

        - .ifApiVersion()
        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/pinpoint-email/latest/APIReference/API_PutEmailIdentityFeedbackAttributes.html

        :stability: experimental
        '''
        return typing.cast("SesPinpoint", jsii.invoke(self, "toPutEmailIdentityFeedbackAttributes", []))

    @jsii.member(jsii_name="toPutEmailIdentityMailFromAttributes")
    def to_put_email_identity_mail_from_attributes(self) -> "SesPinpoint":
        '''(experimental) Grants permission to enable or disable the custom MAIL FROM domain configuration for an email identity.

        Access Level: Write

        Possible conditions:

        - .ifApiVersion()
        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/pinpoint-email/latest/APIReference/API_PutEmailIdentityMailFromAttributes.html

        :stability: experimental
        '''
        return typing.cast("SesPinpoint", jsii.invoke(self, "toPutEmailIdentityMailFromAttributes", []))

    @jsii.member(jsii_name="toSendEmail")
    def to_send_email(self) -> "SesPinpoint":
        '''(experimental) Grants permission to send an email message.

        Access Level: Write

        Possible conditions:

        - .ifApiVersion()
        - .ifFeedbackAddress()
        - .ifFromAddress()
        - .ifFromDisplayName()
        - .ifRecipients()

        https://docs.aws.amazon.com/pinpoint-email/latest/APIReference/API_SendEmail.html

        :stability: experimental
        '''
        return typing.cast("SesPinpoint", jsii.invoke(self, "toSendEmail", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "SesPinpoint":
        '''(experimental) Grants permission to add one or more tags (keys and values) to a specified resource.

        Access Level: Tagging

        Possible conditions:

        - .ifApiVersion()
        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/pinpoint-email/latest/APIReference/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("SesPinpoint", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "SesPinpoint":
        '''(experimental) Grants permission to remove one or more tags (keys and values) from a specified resource.

        Access Level: Tagging

        Possible conditions:

        - .ifApiVersion()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/pinpoint-email/latest/APIReference/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("SesPinpoint", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateConfigurationSetEventDestination")
    def to_update_configuration_set_event_destination(self) -> "SesPinpoint":
        '''(experimental) Grants permission to update the configuration of an event destination for a configuration set.

        Access Level: Write

        Possible conditions:

        - .ifApiVersion()
        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/pinpoint-email/latest/APIReference/API_UpdateConfigurationSetEventDestination.html

        :stability: experimental
        '''
        return typing.cast("SesPinpoint", jsii.invoke(self, "toUpdateConfigurationSetEventDestination", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d45a0ffc8cbdd92bdf9ecd89e96481a0c1ee5dded143c812cd65c5bc95f6d8ad)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e4cdd72b5fb356d57aff7120b554ba0c519c81ec1470d6ab4eda5316a0b04a18)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class SesV2(PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.SesV2"):
    '''(experimental) Statement provider for service `ses-v2 <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonsimpleemailservicev2.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `ses-v2 <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonsimpleemailservicev2.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="ifApiVersion")
    def if_api_version(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "SesV2":
        '''(experimental) Filters actions based on the SES API version.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonses.html#amazonses-policy-keys

        Applies to actions:

        - .toBatchGetMetricData()
        - .toCreateConfigurationSet()
        - .toCreateConfigurationSetEventDestination()
        - .toCreateContact()
        - .toCreateContactList()
        - .toCreateCustomVerificationEmailTemplate()
        - .toCreateDedicatedIpPool()
        - .toCreateDeliverabilityTestReport()
        - .toCreateEmailIdentity()
        - .toCreateEmailIdentityPolicy()
        - .toCreateEmailTemplate()
        - .toCreateImportJob()
        - .toDeleteConfigurationSet()
        - .toDeleteConfigurationSetEventDestination()
        - .toDeleteContact()
        - .toDeleteContactList()
        - .toDeleteCustomVerificationEmailTemplate()
        - .toDeleteDedicatedIpPool()
        - .toDeleteEmailIdentity()
        - .toDeleteEmailIdentityPolicy()
        - .toDeleteEmailTemplate()
        - .toDeleteSuppressedDestination()
        - .toGetAccount()
        - .toGetBlacklistReports()
        - .toGetConfigurationSet()
        - .toGetConfigurationSetEventDestinations()
        - .toGetContact()
        - .toGetContactList()
        - .toGetCustomVerificationEmailTemplate()
        - .toGetDedicatedIp()
        - .toGetDedicatedIpPool()
        - .toGetDedicatedIps()
        - .toGetDeliverabilityDashboardOptions()
        - .toGetDeliverabilityTestReport()
        - .toGetDomainDeliverabilityCampaign()
        - .toGetDomainStatisticsReport()
        - .toGetEmailIdentity()
        - .toGetEmailIdentityPolicies()
        - .toGetEmailTemplate()
        - .toGetImportJob()
        - .toGetSuppressedDestination()
        - .toListConfigurationSets()
        - .toListContactLists()
        - .toListContacts()
        - .toListCustomVerificationEmailTemplates()
        - .toListDedicatedIpPools()
        - .toListDeliverabilityTestReports()
        - .toListDomainDeliverabilityCampaigns()
        - .toListEmailIdentities()
        - .toListEmailTemplates()
        - .toListImportJobs()
        - .toListRecommendations()
        - .toListSuppressedDestinations()
        - .toListTagsForResource()
        - .toPutAccountDedicatedIpWarmupAttributes()
        - .toPutAccountDetails()
        - .toPutAccountSendingAttributes()
        - .toPutAccountSuppressionAttributes()
        - .toPutAccountVdmAttributes()
        - .toPutConfigurationSetDeliveryOptions()
        - .toPutConfigurationSetReputationOptions()
        - .toPutConfigurationSetSendingOptions()
        - .toPutConfigurationSetSuppressionOptions()
        - .toPutConfigurationSetTrackingOptions()
        - .toPutConfigurationSetVdmOptions()
        - .toPutDedicatedIpInPool()
        - .toPutDedicatedIpWarmupAttributes()
        - .toPutDeliverabilityDashboardOption()
        - .toPutEmailIdentityConfigurationSetAttributes()
        - .toPutEmailIdentityDkimAttributes()
        - .toPutEmailIdentityDkimSigningAttributes()
        - .toPutEmailIdentityFeedbackAttributes()
        - .toPutEmailIdentityMailFromAttributes()
        - .toPutSuppressedDestination()
        - .toSendBulkEmail()
        - .toSendCustomVerificationEmail()
        - .toSendEmail()
        - .toTagResource()
        - .toTestRenderEmailTemplate()
        - .toUntagResource()
        - .toUpdateConfigurationSetEventDestination()
        - .toUpdateContact()
        - .toUpdateContactList()
        - .toUpdateCustomVerificationEmailTemplate()
        - .toUpdateEmailIdentityPolicy()
        - .toUpdateEmailTemplate()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9794e60c997ad9fe168b5c813d1efe64ef9bafdf1dbc537bcf856d4086e7d23c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("SesV2", jsii.invoke(self, "ifApiVersion", [value, operator]))

    @jsii.member(jsii_name="ifFeedbackAddress")
    def if_feedback_address(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "SesV2":
        '''(experimental) Filters actions based on the "Return-Path" address, which specifies where bounces and complaints are sent by email feedback forwarding.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonses.html#amazonses-policy-keys

        Applies to actions:

        - .toSendEmail()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__11cf809edb5a37df366f6d96015d905947cab0ce74d1b8c3c2da8b3f694149e4)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("SesV2", jsii.invoke(self, "ifFeedbackAddress", [value, operator]))

    @jsii.member(jsii_name="ifFromAddress")
    def if_from_address(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "SesV2":
        '''(experimental) Filters actions based on the "From" address of a message.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonses.html#amazonses-policy-keys

        Applies to actions:

        - .toSendEmail()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c079d6ad9c321d29d4aae24a2533dd2728d1caa168c2721bad2557938a9be119)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("SesV2", jsii.invoke(self, "ifFromAddress", [value, operator]))

    @jsii.member(jsii_name="ifFromDisplayName")
    def if_from_display_name(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "SesV2":
        '''(experimental) Filters actions based on the "From" address that is used as the display name of a message.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonses.html#amazonses-policy-keys

        Applies to actions:

        - .toSendEmail()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__84fa8a79500e3ffc77004cfe905459cefc27d072449f12bb613209af9b44fbb1)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("SesV2", jsii.invoke(self, "ifFromDisplayName", [value, operator]))

    @jsii.member(jsii_name="ifRecipients")
    def if_recipients(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "SesV2":
        '''(experimental) Filters actions based on the recipient addresses of a message, which include the "To", "CC", and "BCC" addresses.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonses.html#amazonses-policy-keys

        Applies to actions:

        - .toSendEmail()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__19f1362af5312456066e833ee0376735daee6ba9cdf1eaf8682c5ec4ebb72b7f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("SesV2", jsii.invoke(self, "ifRecipients", [value, operator]))

    @jsii.member(jsii_name="onConfigurationSet")
    def on_configuration_set(
        self,
        configuration_set_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "SesV2":
        '''(experimental) Adds a resource of type configuration-set to the statement.

        https://docs.aws.amazon.com/ses/latest/APIReference/API_ConfigurationSet.html

        :param configuration_set_name: - Identifier for the configurationSetName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__09b63806c58657a643b63126a31541b81757c8956ae12723e6afc48f0d66d019)
            check_type(argname="argument configuration_set_name", value=configuration_set_name, expected_type=type_hints["configuration_set_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("SesV2", jsii.invoke(self, "onConfigurationSet", [configuration_set_name, account, region, partition]))

    @jsii.member(jsii_name="onContactList")
    def on_contact_list(
        self,
        contact_list_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "SesV2":
        '''(experimental) Adds a resource of type contact-list to the statement.

        https://docs.aws.amazon.com/ses/latest/APIReference-V2/API_ContactList.html

        :param contact_list_name: - Identifier for the contactListName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__86ce927f15d151eef94a0a21767e58c2316b2e2123c9618a96f6db000120ef62)
            check_type(argname="argument contact_list_name", value=contact_list_name, expected_type=type_hints["contact_list_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("SesV2", jsii.invoke(self, "onContactList", [contact_list_name, account, region, partition]))

    @jsii.member(jsii_name="onCustomVerificationEmailTemplate")
    def on_custom_verification_email_template(
        self,
        template_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "SesV2":
        '''(experimental) Adds a resource of type custom-verification-email-template to the statement.

        https://docs.aws.amazon.com/ses/latest/APIReference-V2/API_CustomVerificationEmailTemplateMetadata.html

        :param template_name: - Identifier for the templateName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ec6c82430254cd660f6391d8e8fd1466ef9fc33524ca0c2b2828910d5ab3d894)
            check_type(argname="argument template_name", value=template_name, expected_type=type_hints["template_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("SesV2", jsii.invoke(self, "onCustomVerificationEmailTemplate", [template_name, account, region, partition]))

    @jsii.member(jsii_name="onDedicatedIpPool")
    def on_dedicated_ip_pool(
        self,
        dedicated_ip_pool: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "SesV2":
        '''(experimental) Adds a resource of type dedicated-ip-pool to the statement.

        https://docs.aws.amazon.com/ses/latest/APIReference-V2/API_DedicatedIp.html

        :param dedicated_ip_pool: - Identifier for the dedicatedIPPool.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3210d7bdef7e60a2db77f5ab26881ba2f9205ca5b492ec0fc5d6f108a4d969bb)
            check_type(argname="argument dedicated_ip_pool", value=dedicated_ip_pool, expected_type=type_hints["dedicated_ip_pool"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("SesV2", jsii.invoke(self, "onDedicatedIpPool", [dedicated_ip_pool, account, region, partition]))

    @jsii.member(jsii_name="onDeliverabilityTestReport")
    def on_deliverability_test_report(
        self,
        report_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "SesV2":
        '''(experimental) Adds a resource of type deliverability-test-report to the statement.

        https://docs.aws.amazon.com/ses/latest/APIReference-V2/API_DeliverabilityTestReport.html

        :param report_id: - Identifier for the reportId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__abff695540da218f6dd2df6a6d79eb304250057c47ebea3f3bc83feb0c272729)
            check_type(argname="argument report_id", value=report_id, expected_type=type_hints["report_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("SesV2", jsii.invoke(self, "onDeliverabilityTestReport", [report_id, account, region, partition]))

    @jsii.member(jsii_name="onIdentity")
    def on_identity(
        self,
        identity_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "SesV2":
        '''(experimental) Adds a resource of type identity to the statement.

        https://docs.aws.amazon.com/ses/latest/APIReference-V2/API_IdentityInfo.html

        :param identity_name: - Identifier for the identityName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0891ead7383be1bc68eaaa31ba2124f2801c17d398d5d690e85c38ba1f6e5eb9)
            check_type(argname="argument identity_name", value=identity_name, expected_type=type_hints["identity_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("SesV2", jsii.invoke(self, "onIdentity", [identity_name, account, region, partition]))

    @jsii.member(jsii_name="onImportJob")
    def on_import_job(
        self,
        import_job_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "SesV2":
        '''(experimental) Adds a resource of type import-job to the statement.

        https://docs.aws.amazon.com/ses/latest/APIReference-V2/API_ImportJobSummary.html

        :param import_job_id: - Identifier for the importJobId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__484284e04322d5950d2efa1486a15948ec9f4787fe6d41c7e8aee059d2383c43)
            check_type(argname="argument import_job_id", value=import_job_id, expected_type=type_hints["import_job_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("SesV2", jsii.invoke(self, "onImportJob", [import_job_id, account, region, partition]))

    @jsii.member(jsii_name="onTemplate")
    def on_template(
        self,
        template_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "SesV2":
        '''(experimental) Adds a resource of type template to the statement.

        https://docs.aws.amazon.com/ses/latest/APIReference-V2/API_Template.html

        :param template_name: - Identifier for the templateName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a248572a1f7c7f4bda1a58c8285a6d43c1462c6db80e6096bc78b826bdf091db)
            check_type(argname="argument template_name", value=template_name, expected_type=type_hints["template_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("SesV2", jsii.invoke(self, "onTemplate", [template_name, account, region, partition]))

    @jsii.member(jsii_name="toBatchGetMetricData")
    def to_batch_get_metric_data(self) -> "SesV2":
        '''(experimental) Grants permission to get metric data on your activity.

        Access Level: Read

        Possible conditions:

        - .ifApiVersion()
        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/ses/latest/APIReference-V2/API_BatchGetMetricData.html

        :stability: experimental
        '''
        return typing.cast("SesV2", jsii.invoke(self, "toBatchGetMetricData", []))

    @jsii.member(jsii_name="toCreateConfigurationSet")
    def to_create_configuration_set(self) -> "SesV2":
        '''(experimental) Grants permission to create a new configuration set.

        Access Level: Write

        Possible conditions:

        - .ifApiVersion()
        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/ses/latest/APIReference-V2/API_CreateConfigurationSet.html

        :stability: experimental
        '''
        return typing.cast("SesV2", jsii.invoke(self, "toCreateConfigurationSet", []))

    @jsii.member(jsii_name="toCreateConfigurationSetEventDestination")
    def to_create_configuration_set_event_destination(self) -> "SesV2":
        '''(experimental) Grants permission to create a configuration set event destination.

        Access Level: Write

        Possible conditions:

        - .ifApiVersion()
        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/ses/latest/APIReference-V2/API_CreateConfigurationSetEventDestination.html

        :stability: experimental
        '''
        return typing.cast("SesV2", jsii.invoke(self, "toCreateConfigurationSetEventDestination", []))

    @jsii.member(jsii_name="toCreateContact")
    def to_create_contact(self) -> "SesV2":
        '''(experimental) Grants permission to create a contact.

        Access Level: Write

        Possible conditions:

        - .ifApiVersion()
        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/ses/latest/APIReference-V2/API_CreateContact.html

        :stability: experimental
        '''
        return typing.cast("SesV2", jsii.invoke(self, "toCreateContact", []))

    @jsii.member(jsii_name="toCreateContactList")
    def to_create_contact_list(self) -> "SesV2":
        '''(experimental) Grants permission to create a contact list.

        Access Level: Write

        Possible conditions:

        - .ifApiVersion()
        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/ses/latest/APIReference-V2/API_CreateContactList.html

        :stability: experimental
        '''
        return typing.cast("SesV2", jsii.invoke(self, "toCreateContactList", []))

    @jsii.member(jsii_name="toCreateCustomVerificationEmailTemplate")
    def to_create_custom_verification_email_template(self) -> "SesV2":
        '''(experimental) Grants permission to create a new custom verification email template.

        Access Level: Write

        Possible conditions:

        - .ifApiVersion()

        https://docs.aws.amazon.com/ses/latest/APIReference-V2/API_CreateCustomVerificationEmailTemplate.html

        :stability: experimental
        '''
        return typing.cast("SesV2", jsii.invoke(self, "toCreateCustomVerificationEmailTemplate", []))

    @jsii.member(jsii_name="toCreateDedicatedIpPool")
    def to_create_dedicated_ip_pool(self) -> "SesV2":
        '''(experimental) Grants permission to create a new pool of dedicated IP addresses.

        Access Level: Write

        Possible conditions:

        - .ifApiVersion()
        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/ses/latest/APIReference-V2/API_CreateDedicatedIpPool.html

        :stability: experimental
        '''
        return typing.cast("SesV2", jsii.invoke(self, "toCreateDedicatedIpPool", []))

    @jsii.member(jsii_name="toCreateDeliverabilityTestReport")
    def to_create_deliverability_test_report(self) -> "SesV2":
        '''(experimental) Grants permission to create a new predictive inbox placement test.

        Access Level: Write

        Possible conditions:

        - .ifApiVersion()
        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/ses/latest/APIReference-V2/API_CreateDeliverabilityTestReport.html

        :stability: experimental
        '''
        return typing.cast("SesV2", jsii.invoke(self, "toCreateDeliverabilityTestReport", []))

    @jsii.member(jsii_name="toCreateEmailIdentity")
    def to_create_email_identity(self) -> "SesV2":
        '''(experimental) Grants permission to start the process of verifying an email identity.

        Access Level: Write

        Possible conditions:

        - .ifApiVersion()
        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/ses/latest/APIReference-V2/API_CreateEmailIdentity.html

        :stability: experimental
        '''
        return typing.cast("SesV2", jsii.invoke(self, "toCreateEmailIdentity", []))

    @jsii.member(jsii_name="toCreateEmailIdentityPolicy")
    def to_create_email_identity_policy(self) -> "SesV2":
        '''(experimental) Grants permission to create the specified sending authorization policy for the given identity.

        Access Level: Permissions management

        Possible conditions:

        - .ifApiVersion()
        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/ses/latest/APIReference-V2/API_CreateEmailIdentityPolicy.html

        :stability: experimental
        '''
        return typing.cast("SesV2", jsii.invoke(self, "toCreateEmailIdentityPolicy", []))

    @jsii.member(jsii_name="toCreateEmailTemplate")
    def to_create_email_template(self) -> "SesV2":
        '''(experimental) Grants permission to create an email template.

        Access Level: Write

        Possible conditions:

        - .ifApiVersion()

        https://docs.aws.amazon.com/ses/latest/APIReference-V2/API_CreateEmailTemplate.html

        :stability: experimental
        '''
        return typing.cast("SesV2", jsii.invoke(self, "toCreateEmailTemplate", []))

    @jsii.member(jsii_name="toCreateImportJob")
    def to_create_import_job(self) -> "SesV2":
        '''(experimental) Grants permission to creates an import job for a data destination.

        Access Level: Write

        Possible conditions:

        - .ifApiVersion()

        https://docs.aws.amazon.com/ses/latest/APIReference-V2/API_CreateImportJob.html

        :stability: experimental
        '''
        return typing.cast("SesV2", jsii.invoke(self, "toCreateImportJob", []))

    @jsii.member(jsii_name="toDeleteConfigurationSet")
    def to_delete_configuration_set(self) -> "SesV2":
        '''(experimental) Grants permission to delete an existing configuration set.

        Access Level: Write

        Possible conditions:

        - .ifApiVersion()
        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/ses/latest/APIReference-V2/API_DeleteConfigurationSet.html

        :stability: experimental
        '''
        return typing.cast("SesV2", jsii.invoke(self, "toDeleteConfigurationSet", []))

    @jsii.member(jsii_name="toDeleteConfigurationSetEventDestination")
    def to_delete_configuration_set_event_destination(self) -> "SesV2":
        '''(experimental) Grants permission to delete an event destination.

        Access Level: Write

        Possible conditions:

        - .ifApiVersion()
        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/ses/latest/APIReference-V2/API_DeleteConfigurationSetEventDestination.html

        :stability: experimental
        '''
        return typing.cast("SesV2", jsii.invoke(self, "toDeleteConfigurationSetEventDestination", []))

    @jsii.member(jsii_name="toDeleteContact")
    def to_delete_contact(self) -> "SesV2":
        '''(experimental) Grants permission to delete a contact from a contact list.

        Access Level: Write

        Possible conditions:

        - .ifApiVersion()
        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/ses/latest/APIReference-V2/API_DeleteContact.html

        :stability: experimental
        '''
        return typing.cast("SesV2", jsii.invoke(self, "toDeleteContact", []))

    @jsii.member(jsii_name="toDeleteContactList")
    def to_delete_contact_list(self) -> "SesV2":
        '''(experimental) Grants permission to delete a contact list with all of its contacts.

        Access Level: Write

        Possible conditions:

        - .ifApiVersion()
        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/ses/latest/APIReference-V2/API_DeleteContactList.html

        :stability: experimental
        '''
        return typing.cast("SesV2", jsii.invoke(self, "toDeleteContactList", []))

    @jsii.member(jsii_name="toDeleteCustomVerificationEmailTemplate")
    def to_delete_custom_verification_email_template(self) -> "SesV2":
        '''(experimental) Grants permission to delete an existing custom verification email template.

        Access Level: Write

        Possible conditions:

        - .ifApiVersion()

        https://docs.aws.amazon.com/ses/latest/APIReference-V2/API_DeleteCustomVerificationEmailTemplate.html

        :stability: experimental
        '''
        return typing.cast("SesV2", jsii.invoke(self, "toDeleteCustomVerificationEmailTemplate", []))

    @jsii.member(jsii_name="toDeleteDedicatedIpPool")
    def to_delete_dedicated_ip_pool(self) -> "SesV2":
        '''(experimental) Grants permission to delete a dedicated IP pool.

        Access Level: Write

        Possible conditions:

        - .ifApiVersion()
        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/ses/latest/APIReference-V2/API_DeleteDedicatedIpPool.html

        :stability: experimental
        '''
        return typing.cast("SesV2", jsii.invoke(self, "toDeleteDedicatedIpPool", []))

    @jsii.member(jsii_name="toDeleteEmailIdentity")
    def to_delete_email_identity(self) -> "SesV2":
        '''(experimental) Grants permission to delete an email identity.

        Access Level: Write

        Possible conditions:

        - .ifApiVersion()
        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/ses/latest/APIReference-V2/API_DeleteEmailIdentity.html

        :stability: experimental
        '''
        return typing.cast("SesV2", jsii.invoke(self, "toDeleteEmailIdentity", []))

    @jsii.member(jsii_name="toDeleteEmailIdentityPolicy")
    def to_delete_email_identity_policy(self) -> "SesV2":
        '''(experimental) Grants permission to delete the specified sending authorization policy for the given identity (an email address or a domain).

        Access Level: Permissions management

        Possible conditions:

        - .ifApiVersion()
        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/ses/latest/APIReference-V2/API_DeleteEmailIdentityPolicy.html

        :stability: experimental
        '''
        return typing.cast("SesV2", jsii.invoke(self, "toDeleteEmailIdentityPolicy", []))

    @jsii.member(jsii_name="toDeleteEmailTemplate")
    def to_delete_email_template(self) -> "SesV2":
        '''(experimental) Grants permission to delete an email template.

        Access Level: Write

        Possible conditions:

        - .ifApiVersion()

        https://docs.aws.amazon.com/ses/latest/APIReference-V2/API_DeleteEmailTemplate.html

        :stability: experimental
        '''
        return typing.cast("SesV2", jsii.invoke(self, "toDeleteEmailTemplate", []))

    @jsii.member(jsii_name="toDeleteSuppressedDestination")
    def to_delete_suppressed_destination(self) -> "SesV2":
        '''(experimental) Grants permission to remove an email address from the suppression list for your account.

        Access Level: Write

        Possible conditions:

        - .ifApiVersion()

        https://docs.aws.amazon.com/ses/latest/APIReference-V2/API_DeleteSuppressedDestination.html

        :stability: experimental
        '''
        return typing.cast("SesV2", jsii.invoke(self, "toDeleteSuppressedDestination", []))

    @jsii.member(jsii_name="toGetAccount")
    def to_get_account(self) -> "SesV2":
        '''(experimental) Grants permission to get information about the email-sending status and capabilities for your account.

        Access Level: Read

        Possible conditions:

        - .ifApiVersion()

        https://docs.aws.amazon.com/ses/latest/APIReference-V2/API_GetAccount.html

        :stability: experimental
        '''
        return typing.cast("SesV2", jsii.invoke(self, "toGetAccount", []))

    @jsii.member(jsii_name="toGetBlacklistReports")
    def to_get_blacklist_reports(self) -> "SesV2":
        '''(experimental) Grants permission to retrieve a list of the deny lists on which your dedicated IP addresses or tracked domains appear.

        Access Level: Read

        Possible conditions:

        - .ifApiVersion()

        https://docs.aws.amazon.com/ses/latest/APIReference-V2/API_GetBlacklistReports.html

        :stability: experimental
        '''
        return typing.cast("SesV2", jsii.invoke(self, "toGetBlacklistReports", []))

    @jsii.member(jsii_name="toGetConfigurationSet")
    def to_get_configuration_set(self) -> "SesV2":
        '''(experimental) Grants permission to get information about an existing configuration set.

        Access Level: Read

        Possible conditions:

        - .ifApiVersion()
        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/ses/latest/APIReference-V2/API_GetConfigurationSet.html

        :stability: experimental
        '''
        return typing.cast("SesV2", jsii.invoke(self, "toGetConfigurationSet", []))

    @jsii.member(jsii_name="toGetConfigurationSetEventDestinations")
    def to_get_configuration_set_event_destinations(self) -> "SesV2":
        '''(experimental) Grants permission to retrieve a list of event destinations that are associated with a configuration set.

        Access Level: Read

        Possible conditions:

        - .ifApiVersion()
        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/ses/latest/APIReference-V2/API_GetConfigurationSetEventDestinations.html

        :stability: experimental
        '''
        return typing.cast("SesV2", jsii.invoke(self, "toGetConfigurationSetEventDestinations", []))

    @jsii.member(jsii_name="toGetContact")
    def to_get_contact(self) -> "SesV2":
        '''(experimental) Grants permission to return a contact from a contact list.

        Access Level: Read

        Possible conditions:

        - .ifApiVersion()
        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/ses/latest/APIReference-V2/API_GetContact.html

        :stability: experimental
        '''
        return typing.cast("SesV2", jsii.invoke(self, "toGetContact", []))

    @jsii.member(jsii_name="toGetContactList")
    def to_get_contact_list(self) -> "SesV2":
        '''(experimental) Grants permission to return contact list metadata.

        Access Level: Read

        Possible conditions:

        - .ifApiVersion()

        https://docs.aws.amazon.com/ses/latest/APIReference-V2/API_GetContactList.html

        :stability: experimental
        '''
        return typing.cast("SesV2", jsii.invoke(self, "toGetContactList", []))

    @jsii.member(jsii_name="toGetCustomVerificationEmailTemplate")
    def to_get_custom_verification_email_template(self) -> "SesV2":
        '''(experimental) Grants permission to return the custom email verification template for the template name you specify.

        Access Level: Read

        Possible conditions:

        - .ifApiVersion()

        https://docs.aws.amazon.com/ses/latest/APIReference-V2/API_GetCustomVerificationEmailTemplate.html

        :stability: experimental
        '''
        return typing.cast("SesV2", jsii.invoke(self, "toGetCustomVerificationEmailTemplate", []))

    @jsii.member(jsii_name="toGetDedicatedIp")
    def to_get_dedicated_ip(self) -> "SesV2":
        '''(experimental) Grants permission to get information about a dedicated IP address.

        Access Level: Read

        Possible conditions:

        - .ifApiVersion()

        https://docs.aws.amazon.com/ses/latest/APIReference-V2/API_GetDedicatedIp.html

        :stability: experimental
        '''
        return typing.cast("SesV2", jsii.invoke(self, "toGetDedicatedIp", []))

    @jsii.member(jsii_name="toGetDedicatedIpPool")
    def to_get_dedicated_ip_pool(self) -> "SesV2":
        '''(experimental) Grants permission to get information about a dedicated IP pool.

        Access Level: Read

        Possible conditions:

        - .ifApiVersion()
        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/ses/latest/APIReference-V2/API_GetDedicatedIpPool.html

        :stability: experimental
        '''
        return typing.cast("SesV2", jsii.invoke(self, "toGetDedicatedIpPool", []))

    @jsii.member(jsii_name="toGetDedicatedIps")
    def to_get_dedicated_ips(self) -> "SesV2":
        '''(experimental) Grants permission to list the dedicated IP addresses a dedicated IP pool.

        Access Level: Read

        Possible conditions:

        - .ifApiVersion()
        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/ses/latest/APIReference-V2/API_GetDedicatedIps.html

        :stability: experimental
        '''
        return typing.cast("SesV2", jsii.invoke(self, "toGetDedicatedIps", []))

    @jsii.member(jsii_name="toGetDeliverabilityDashboardOptions")
    def to_get_deliverability_dashboard_options(self) -> "SesV2":
        '''(experimental) Grants permission to get the status of the Deliverability dashboard.

        Access Level: Read

        Possible conditions:

        - .ifApiVersion()

        https://docs.aws.amazon.com/ses/latest/APIReference-V2/API_GetDeliverabilityDashboardOptions.html

        :stability: experimental
        '''
        return typing.cast("SesV2", jsii.invoke(self, "toGetDeliverabilityDashboardOptions", []))

    @jsii.member(jsii_name="toGetDeliverabilityTestReport")
    def to_get_deliverability_test_report(self) -> "SesV2":
        '''(experimental) Grants permission to retrieve the results of a predictive inbox placement test.

        Access Level: Read

        Possible conditions:

        - .ifApiVersion()
        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/ses/latest/APIReference-V2/API_GetDeliverabilityTestReport.html

        :stability: experimental
        '''
        return typing.cast("SesV2", jsii.invoke(self, "toGetDeliverabilityTestReport", []))

    @jsii.member(jsii_name="toGetDomainDeliverabilityCampaign")
    def to_get_domain_deliverability_campaign(self) -> "SesV2":
        '''(experimental) Grants permission to retrieve all the deliverability data for a specific campaign.

        Access Level: Read

        Possible conditions:

        - .ifApiVersion()

        https://docs.aws.amazon.com/ses/latest/APIReference-V2/API_GetDomainDeliverabilityCampaign.html

        :stability: experimental
        '''
        return typing.cast("SesV2", jsii.invoke(self, "toGetDomainDeliverabilityCampaign", []))

    @jsii.member(jsii_name="toGetDomainStatisticsReport")
    def to_get_domain_statistics_report(self) -> "SesV2":
        '''(experimental) Grants permission to retrieve inbox placement and engagement rates for the domains that you use to send email.

        Access Level: Read

        Possible conditions:

        - .ifApiVersion()
        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/ses/latest/APIReference-V2/API_GetDomainStatisticsReport.html

        :stability: experimental
        '''
        return typing.cast("SesV2", jsii.invoke(self, "toGetDomainStatisticsReport", []))

    @jsii.member(jsii_name="toGetEmailIdentity")
    def to_get_email_identity(self) -> "SesV2":
        '''(experimental) Grants permission to get information about a specific identity.

        Access Level: Read

        Possible conditions:

        - .ifApiVersion()
        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/ses/latest/APIReference-V2/API_GetEmailIdentity.html

        :stability: experimental
        '''
        return typing.cast("SesV2", jsii.invoke(self, "toGetEmailIdentity", []))

    @jsii.member(jsii_name="toGetEmailIdentityPolicies")
    def to_get_email_identity_policies(self) -> "SesV2":
        '''(experimental) Grants permission to return the requested sending authorization policies for the given identity (an email address or a domain).

        Access Level: Read

        Possible conditions:

        - .ifApiVersion()
        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/ses/latest/APIReference-V2/API_GetEmailIdentityPolicies.html

        :stability: experimental
        '''
        return typing.cast("SesV2", jsii.invoke(self, "toGetEmailIdentityPolicies", []))

    @jsii.member(jsii_name="toGetEmailTemplate")
    def to_get_email_template(self) -> "SesV2":
        '''(experimental) Grants permission to return the template object, which includes the subject line, HTML part, and text part for the template you specify.

        Access Level: Read

        Possible conditions:

        - .ifApiVersion()

        https://docs.aws.amazon.com/ses/latest/APIReference-V2/API_GetEmailTemplate.html

        :stability: experimental
        '''
        return typing.cast("SesV2", jsii.invoke(self, "toGetEmailTemplate", []))

    @jsii.member(jsii_name="toGetImportJob")
    def to_get_import_job(self) -> "SesV2":
        '''(experimental) Grants permission to provide information about an import job.

        Access Level: Read

        Possible conditions:

        - .ifApiVersion()

        https://docs.aws.amazon.com/ses/latest/APIReference-V2/API_GetImportJob.html

        :stability: experimental
        '''
        return typing.cast("SesV2", jsii.invoke(self, "toGetImportJob", []))

    @jsii.member(jsii_name="toGetSuppressedDestination")
    def to_get_suppressed_destination(self) -> "SesV2":
        '''(experimental) Grants permission to retrieve information about a specific email address that's on the suppression list for your account.

        Access Level: Read

        Possible conditions:

        - .ifApiVersion()

        https://docs.aws.amazon.com/ses/latest/APIReference-V2/API_GetSuppressedDestination.html

        :stability: experimental
        '''
        return typing.cast("SesV2", jsii.invoke(self, "toGetSuppressedDestination", []))

    @jsii.member(jsii_name="toListConfigurationSets")
    def to_list_configuration_sets(self) -> "SesV2":
        '''(experimental) Grants permission to list all of the configuration sets for your account.

        Access Level: List

        Possible conditions:

        - .ifApiVersion()

        https://docs.aws.amazon.com/ses/latest/APIReference-V2/API_ListConfigurationSets.html

        :stability: experimental
        '''
        return typing.cast("SesV2", jsii.invoke(self, "toListConfigurationSets", []))

    @jsii.member(jsii_name="toListContactLists")
    def to_list_contact_lists(self) -> "SesV2":
        '''(experimental) Grants permission to list all of the contact lists available for your account.

        Access Level: List

        Possible conditions:

        - .ifApiVersion()

        https://docs.aws.amazon.com/ses/latest/APIReference-V2/API_ListContactLists.html

        :stability: experimental
        '''
        return typing.cast("SesV2", jsii.invoke(self, "toListContactLists", []))

    @jsii.member(jsii_name="toListContacts")
    def to_list_contacts(self) -> "SesV2":
        '''(experimental) Grants permission to list the contacts present in a specific contact list.

        Access Level: List

        Possible conditions:

        - .ifApiVersion()

        https://docs.aws.amazon.com/ses/latest/APIReference-V2/API_ListContacts.html

        :stability: experimental
        '''
        return typing.cast("SesV2", jsii.invoke(self, "toListContacts", []))

    @jsii.member(jsii_name="toListCustomVerificationEmailTemplates")
    def to_list_custom_verification_email_templates(self) -> "SesV2":
        '''(experimental) Grants permission to list all of the existing custom verification email templates for your account.

        Access Level: List

        Possible conditions:

        - .ifApiVersion()

        https://docs.aws.amazon.com/ses/latest/APIReference-V2/API_ListCustomVerificationEmailTemplates.html

        :stability: experimental
        '''
        return typing.cast("SesV2", jsii.invoke(self, "toListCustomVerificationEmailTemplates", []))

    @jsii.member(jsii_name="toListDedicatedIpPools")
    def to_list_dedicated_ip_pools(self) -> "SesV2":
        '''(experimental) Grants permission to list all of the dedicated IP pools for your account.

        Access Level: List

        Possible conditions:

        - .ifApiVersion()

        https://docs.aws.amazon.com/ses/latest/APIReference-V2/API_ListDedicatedIpPools.html

        :stability: experimental
        '''
        return typing.cast("SesV2", jsii.invoke(self, "toListDedicatedIpPools", []))

    @jsii.member(jsii_name="toListDeliverabilityTestReports")
    def to_list_deliverability_test_reports(self) -> "SesV2":
        '''(experimental) Grants permission to retrieve the list of the predictive inbox placement tests that you've performed, regardless of their statuses, for your account.

        Access Level: List

        Possible conditions:

        - .ifApiVersion()

        https://docs.aws.amazon.com/ses/latest/APIReference-V2/API_ListDeliverabilityTestReports.html

        :stability: experimental
        '''
        return typing.cast("SesV2", jsii.invoke(self, "toListDeliverabilityTestReports", []))

    @jsii.member(jsii_name="toListDomainDeliverabilityCampaigns")
    def to_list_domain_deliverability_campaigns(self) -> "SesV2":
        '''(experimental) Grants permission to list deliverability data for campaigns that used a specific domain to send email during a specified time range.

        Access Level: Read

        Possible conditions:

        - .ifApiVersion()

        https://docs.aws.amazon.com/ses/latest/APIReference-V2/API_ListDomainDeliverabilityCampaigns.html

        :stability: experimental
        '''
        return typing.cast("SesV2", jsii.invoke(self, "toListDomainDeliverabilityCampaigns", []))

    @jsii.member(jsii_name="toListEmailIdentities")
    def to_list_email_identities(self) -> "SesV2":
        '''(experimental) Grants permission to list the email identities for your account.

        Access Level: List

        Possible conditions:

        - .ifApiVersion()

        https://docs.aws.amazon.com/ses/latest/APIReference-V2/API_ListEmailIdentities.html

        :stability: experimental
        '''
        return typing.cast("SesV2", jsii.invoke(self, "toListEmailIdentities", []))

    @jsii.member(jsii_name="toListEmailTemplates")
    def to_list_email_templates(self) -> "SesV2":
        '''(experimental) Grants permission to list all of the email templates for your account.

        Access Level: List

        Possible conditions:

        - .ifApiVersion()

        https://docs.aws.amazon.com/ses/latest/APIReference-V2/API_ListEmailTemplates.html

        :stability: experimental
        '''
        return typing.cast("SesV2", jsii.invoke(self, "toListEmailTemplates", []))

    @jsii.member(jsii_name="toListImportJobs")
    def to_list_import_jobs(self) -> "SesV2":
        '''(experimental) Grants permission to list all of the import jobs for your account.

        Access Level: List

        Possible conditions:

        - .ifApiVersion()

        https://docs.aws.amazon.com/ses/latest/APIReference-V2/API_ListImportJobs.html

        :stability: experimental
        '''
        return typing.cast("SesV2", jsii.invoke(self, "toListImportJobs", []))

    @jsii.member(jsii_name="toListRecommendations")
    def to_list_recommendations(self) -> "SesV2":
        '''(experimental) Grants permission to list recommendations for your account.

        Access Level: Read

        Possible conditions:

        - .ifApiVersion()
        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/ses/latest/APIReference-V2/API_ListRecommendations.html

        :stability: experimental
        '''
        return typing.cast("SesV2", jsii.invoke(self, "toListRecommendations", []))

    @jsii.member(jsii_name="toListSuppressedDestinations")
    def to_list_suppressed_destinations(self) -> "SesV2":
        '''(experimental) Grants permission to list email addresses that are on the suppression list for your account.

        Access Level: Read

        Possible conditions:

        - .ifApiVersion()

        https://docs.aws.amazon.com/ses/latest/APIReference-V2/API_ListSuppressedDestinations.html

        :stability: experimental
        '''
        return typing.cast("SesV2", jsii.invoke(self, "toListSuppressedDestinations", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "SesV2":
        '''(experimental) Grants permission to retrieve a list of the tags (keys and values) that are associated with a specific resource for your account.

        Access Level: Read

        Possible conditions:

        - .ifApiVersion()

        https://docs.aws.amazon.com/ses/latest/APIReference-V2/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("SesV2", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toPutAccountDedicatedIpWarmupAttributes")
    def to_put_account_dedicated_ip_warmup_attributes(self) -> "SesV2":
        '''(experimental) Grants permission to enable or disable the automatic warm-up feature for dedicated IP addresses.

        Access Level: Write

        Possible conditions:

        - .ifApiVersion()

        https://docs.aws.amazon.com/ses/latest/APIReference-V2/API_PutAccountDedicatedIpWarmupAttributes.html

        :stability: experimental
        '''
        return typing.cast("SesV2", jsii.invoke(self, "toPutAccountDedicatedIpWarmupAttributes", []))

    @jsii.member(jsii_name="toPutAccountDetails")
    def to_put_account_details(self) -> "SesV2":
        '''(experimental) Grants permission to update your account details.

        Access Level: Write

        Possible conditions:

        - .ifApiVersion()

        https://docs.aws.amazon.com/ses/latest/APIReference-V2/API_PutAccountDetails.html

        :stability: experimental
        '''
        return typing.cast("SesV2", jsii.invoke(self, "toPutAccountDetails", []))

    @jsii.member(jsii_name="toPutAccountSendingAttributes")
    def to_put_account_sending_attributes(self) -> "SesV2":
        '''(experimental) Grants permission to enable or disable the ability to send email for your account.

        Access Level: Write

        Possible conditions:

        - .ifApiVersion()

        https://docs.aws.amazon.com/ses/latest/APIReference-V2/API_PutAccountSendingAttributes.html

        :stability: experimental
        '''
        return typing.cast("SesV2", jsii.invoke(self, "toPutAccountSendingAttributes", []))

    @jsii.member(jsii_name="toPutAccountSuppressionAttributes")
    def to_put_account_suppression_attributes(self) -> "SesV2":
        '''(experimental) Grants permission to change the settings for the account-level suppression list.

        Access Level: Write

        Possible conditions:

        - .ifApiVersion()

        https://docs.aws.amazon.com/ses/latest/APIReference-V2/API_PutAccountSuppressionAttributes.html

        :stability: experimental
        '''
        return typing.cast("SesV2", jsii.invoke(self, "toPutAccountSuppressionAttributes", []))

    @jsii.member(jsii_name="toPutAccountVdmAttributes")
    def to_put_account_vdm_attributes(self) -> "SesV2":
        '''(experimental) Grants permission to change the settings for VDM for your account.

        Access Level: Write

        Possible conditions:

        - .ifApiVersion()

        https://docs.aws.amazon.com/ses/latest/APIReference-V2/API_PutAccountVdmAttributes.html

        :stability: experimental
        '''
        return typing.cast("SesV2", jsii.invoke(self, "toPutAccountVdmAttributes", []))

    @jsii.member(jsii_name="toPutConfigurationSetDeliveryOptions")
    def to_put_configuration_set_delivery_options(self) -> "SesV2":
        '''(experimental) Grants permission to associate a configuration set with a dedicated IP pool.

        Access Level: Write

        Possible conditions:

        - .ifApiVersion()
        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/ses/latest/APIReference-V2/API_PutConfigurationSetDeliveryOptions.html

        :stability: experimental
        '''
        return typing.cast("SesV2", jsii.invoke(self, "toPutConfigurationSetDeliveryOptions", []))

    @jsii.member(jsii_name="toPutConfigurationSetReputationOptions")
    def to_put_configuration_set_reputation_options(self) -> "SesV2":
        '''(experimental) Grants permission to enable or disable collection of reputation metrics for emails that you send using a particular configuration set.

        Access Level: Write

        Possible conditions:

        - .ifApiVersion()
        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/ses/latest/APIReference-V2/API_PutConfigurationSetReputationOptions.html

        :stability: experimental
        '''
        return typing.cast("SesV2", jsii.invoke(self, "toPutConfigurationSetReputationOptions", []))

    @jsii.member(jsii_name="toPutConfigurationSetSendingOptions")
    def to_put_configuration_set_sending_options(self) -> "SesV2":
        '''(experimental) Grants permission to enable or disable email sending for messages that use a particular configuration set.

        Access Level: Write

        Possible conditions:

        - .ifApiVersion()
        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/ses/latest/APIReference-V2/API_PutConfigurationSetSendingOptions.html

        :stability: experimental
        '''
        return typing.cast("SesV2", jsii.invoke(self, "toPutConfigurationSetSendingOptions", []))

    @jsii.member(jsii_name="toPutConfigurationSetSuppressionOptions")
    def to_put_configuration_set_suppression_options(self) -> "SesV2":
        '''(experimental) Grants permission to specify the account suppression list preferences for a particular configuration set.

        Access Level: Write

        Possible conditions:

        - .ifApiVersion()
        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/ses/latest/APIReference-V2/API_PutConfigurationSetSuppressionOptions.html

        :stability: experimental
        '''
        return typing.cast("SesV2", jsii.invoke(self, "toPutConfigurationSetSuppressionOptions", []))

    @jsii.member(jsii_name="toPutConfigurationSetTrackingOptions")
    def to_put_configuration_set_tracking_options(self) -> "SesV2":
        '''(experimental) Grants permission to specify a custom domain to use for open and click tracking elements in email that you send for a particular configuration set.

        Access Level: Write

        Possible conditions:

        - .ifApiVersion()
        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/ses/latest/APIReference-V2/API_PutConfigurationSetTrackingOptions.html

        :stability: experimental
        '''
        return typing.cast("SesV2", jsii.invoke(self, "toPutConfigurationSetTrackingOptions", []))

    @jsii.member(jsii_name="toPutConfigurationSetVdmOptions")
    def to_put_configuration_set_vdm_options(self) -> "SesV2":
        '''(experimental) Grants permission to override account-level VDM settings for a particular configuration set.

        Access Level: Write

        Possible conditions:

        - .ifApiVersion()
        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/ses/latest/APIReference-V2/API_PutConfigurationSetVdmOptions.html

        :stability: experimental
        '''
        return typing.cast("SesV2", jsii.invoke(self, "toPutConfigurationSetVdmOptions", []))

    @jsii.member(jsii_name="toPutDedicatedIpInPool")
    def to_put_dedicated_ip_in_pool(self) -> "SesV2":
        '''(experimental) Grants permission to move a dedicated IP address to an existing dedicated IP pool.

        Access Level: Write

        Possible conditions:

        - .ifApiVersion()
        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/ses/latest/APIReference-V2/API_PutDedicatedIpInPool.html

        :stability: experimental
        '''
        return typing.cast("SesV2", jsii.invoke(self, "toPutDedicatedIpInPool", []))

    @jsii.member(jsii_name="toPutDedicatedIpWarmupAttributes")
    def to_put_dedicated_ip_warmup_attributes(self) -> "SesV2":
        '''(experimental) Grants permission to put Dedicated IP warm up attributes.

        Access Level: Write

        Possible conditions:

        - .ifApiVersion()

        https://docs.aws.amazon.com/ses/latest/APIReference-V2/API_PutDedicatedIpWarmupAttributes.html

        :stability: experimental
        '''
        return typing.cast("SesV2", jsii.invoke(self, "toPutDedicatedIpWarmupAttributes", []))

    @jsii.member(jsii_name="toPutDeliverabilityDashboardOption")
    def to_put_deliverability_dashboard_option(self) -> "SesV2":
        '''(experimental) Grants permission to enable or disable the Deliverability dashboard.

        Access Level: Write

        Possible conditions:

        - .ifApiVersion()

        https://docs.aws.amazon.com/ses/latest/APIReference-V2/API_PutDeliverabilityDashboardOption.html

        :stability: experimental
        '''
        return typing.cast("SesV2", jsii.invoke(self, "toPutDeliverabilityDashboardOption", []))

    @jsii.member(jsii_name="toPutEmailIdentityConfigurationSetAttributes")
    def to_put_email_identity_configuration_set_attributes(self) -> "SesV2":
        '''(experimental) Grants permission to associate a configuration set with an email identity.

        Access Level: Write

        Possible conditions:

        - .ifApiVersion()
        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/ses/latest/APIReference-V2/API_PutEmailIdentityConfigurationSetAttributes.html

        :stability: experimental
        '''
        return typing.cast("SesV2", jsii.invoke(self, "toPutEmailIdentityConfigurationSetAttributes", []))

    @jsii.member(jsii_name="toPutEmailIdentityDkimAttributes")
    def to_put_email_identity_dkim_attributes(self) -> "SesV2":
        '''(experimental) Grants permission to enable or disable DKIM authentication for an email identity.

        Access Level: Write

        Possible conditions:

        - .ifApiVersion()
        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/ses/latest/APIReference-V2/API_PutEmailIdentityDkimAttributes.html

        :stability: experimental
        '''
        return typing.cast("SesV2", jsii.invoke(self, "toPutEmailIdentityDkimAttributes", []))

    @jsii.member(jsii_name="toPutEmailIdentityDkimSigningAttributes")
    def to_put_email_identity_dkim_signing_attributes(self) -> "SesV2":
        '''(experimental) Grants permission to configure or change the DKIM authentication settings for an email domain identity.

        Access Level: Write

        Possible conditions:

        - .ifApiVersion()
        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/ses/latest/APIReference-V2/API_PutEmailIdentityDkimSigningAttributes.html

        :stability: experimental
        '''
        return typing.cast("SesV2", jsii.invoke(self, "toPutEmailIdentityDkimSigningAttributes", []))

    @jsii.member(jsii_name="toPutEmailIdentityFeedbackAttributes")
    def to_put_email_identity_feedback_attributes(self) -> "SesV2":
        '''(experimental) Grants permission to enable or disable feedback forwarding for an email identity.

        Access Level: Write

        Possible conditions:

        - .ifApiVersion()
        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/ses/latest/APIReference-V2/API_PutEmailIdentityFeedbackAttributes.html

        :stability: experimental
        '''
        return typing.cast("SesV2", jsii.invoke(self, "toPutEmailIdentityFeedbackAttributes", []))

    @jsii.member(jsii_name="toPutEmailIdentityMailFromAttributes")
    def to_put_email_identity_mail_from_attributes(self) -> "SesV2":
        '''(experimental) Grants permission to enable or disable the custom MAIL FROM domain configuration for an email identity.

        Access Level: Write

        Possible conditions:

        - .ifApiVersion()
        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/ses/latest/APIReference-V2/API_PutEmailIdentityMailFromAttributes.html

        :stability: experimental
        '''
        return typing.cast("SesV2", jsii.invoke(self, "toPutEmailIdentityMailFromAttributes", []))

    @jsii.member(jsii_name="toPutSuppressedDestination")
    def to_put_suppressed_destination(self) -> "SesV2":
        '''(experimental) Grants permission to add an email address to the suppression list.

        Access Level: Write

        Possible conditions:

        - .ifApiVersion()

        https://docs.aws.amazon.com/ses/latest/APIReference-V2/API_PutSuppressedDestination.html

        :stability: experimental
        '''
        return typing.cast("SesV2", jsii.invoke(self, "toPutSuppressedDestination", []))

    @jsii.member(jsii_name="toSendBulkEmail")
    def to_send_bulk_email(self) -> "SesV2":
        '''(experimental) Grants permission to compose an email message to multiple destinations.

        Access Level: Write

        Possible conditions:

        - .ifApiVersion()

        https://docs.aws.amazon.com/ses/latest/APIReference-V2/API_SendBulkEmail.html

        :stability: experimental
        '''
        return typing.cast("SesV2", jsii.invoke(self, "toSendBulkEmail", []))

    @jsii.member(jsii_name="toSendCustomVerificationEmail")
    def to_send_custom_verification_email(self) -> "SesV2":
        '''(experimental) Grants permission to add an email address to the list of identities and attempts to verify it.

        Access Level: Write

        Possible conditions:

        - .ifApiVersion()

        https://docs.aws.amazon.com/ses/latest/APIReference-V2/API_SendCustomVerificationEmail.html

        :stability: experimental
        '''
        return typing.cast("SesV2", jsii.invoke(self, "toSendCustomVerificationEmail", []))

    @jsii.member(jsii_name="toSendEmail")
    def to_send_email(self) -> "SesV2":
        '''(experimental) Grants permission to send an email message.

        Access Level: Write

        Possible conditions:

        - .ifApiVersion()
        - .ifFeedbackAddress()
        - .ifFromAddress()
        - .ifFromDisplayName()
        - .ifRecipients()

        https://docs.aws.amazon.com/ses/latest/APIReference-V2/API_SendEmail.html

        :stability: experimental
        '''
        return typing.cast("SesV2", jsii.invoke(self, "toSendEmail", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "SesV2":
        '''(experimental) Grants permission to add one or more tags (keys and values) to a specified resource.

        Access Level: Tagging

        Possible conditions:

        - .ifApiVersion()
        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/ses/latest/APIReference-V2/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("SesV2", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toTestRenderEmailTemplate")
    def to_test_render_email_template(self) -> "SesV2":
        '''(experimental) Grants permission to create a preview of the MIME content of an email when provided with a template and a set of replacement data.

        Access Level: Write

        Possible conditions:

        - .ifApiVersion()

        https://docs.aws.amazon.com/ses/latest/APIReference-V2/API_TestRenderEmailTemplate.html

        :stability: experimental
        '''
        return typing.cast("SesV2", jsii.invoke(self, "toTestRenderEmailTemplate", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "SesV2":
        '''(experimental) Grants permission to remove one or more tags (keys and values) from a specified resource.

        Access Level: Tagging

        Possible conditions:

        - .ifApiVersion()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/ses/latest/APIReference-V2/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("SesV2", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateConfigurationSetEventDestination")
    def to_update_configuration_set_event_destination(self) -> "SesV2":
        '''(experimental) Grants permission to update the configuration of an event destination for a configuration set.

        Access Level: Write

        Possible conditions:

        - .ifApiVersion()
        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/ses/latest/APIReference-V2/API_UpdateConfigurationSetEventDestination.html

        :stability: experimental
        '''
        return typing.cast("SesV2", jsii.invoke(self, "toUpdateConfigurationSetEventDestination", []))

    @jsii.member(jsii_name="toUpdateContact")
    def to_update_contact(self) -> "SesV2":
        '''(experimental) Grants permission to update a contact's preferences for a list.

        Access Level: Write

        Possible conditions:

        - .ifApiVersion()
        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/ses/latest/APIReference-V2/API_UpdateContact.html

        :stability: experimental
        '''
        return typing.cast("SesV2", jsii.invoke(self, "toUpdateContact", []))

    @jsii.member(jsii_name="toUpdateContactList")
    def to_update_contact_list(self) -> "SesV2":
        '''(experimental) Grants permission to update contact list metadata.

        Access Level: Write

        Possible conditions:

        - .ifApiVersion()
        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/ses/latest/APIReference-V2/API_UpdateContactList.html

        :stability: experimental
        '''
        return typing.cast("SesV2", jsii.invoke(self, "toUpdateContactList", []))

    @jsii.member(jsii_name="toUpdateCustomVerificationEmailTemplate")
    def to_update_custom_verification_email_template(self) -> "SesV2":
        '''(experimental) Grants permission to update an existing custom verification email template.

        Access Level: Write

        Possible conditions:

        - .ifApiVersion()

        https://docs.aws.amazon.com/ses/latest/APIReference-V2/API_UpdateCustomVerificationEmailTemplate.html

        :stability: experimental
        '''
        return typing.cast("SesV2", jsii.invoke(self, "toUpdateCustomVerificationEmailTemplate", []))

    @jsii.member(jsii_name="toUpdateEmailIdentityPolicy")
    def to_update_email_identity_policy(self) -> "SesV2":
        '''(experimental) Grants permission to update the specified sending authorization policy for the given identity (an email address or a domain).

        Access Level: Permissions management

        Possible conditions:

        - .ifApiVersion()
        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/ses/latest/APIReference-V2/API_UpdateEmailIdentityPolicy.html

        :stability: experimental
        '''
        return typing.cast("SesV2", jsii.invoke(self, "toUpdateEmailIdentityPolicy", []))

    @jsii.member(jsii_name="toUpdateEmailTemplate")
    def to_update_email_template(self) -> "SesV2":
        '''(experimental) Grants permission to update an email template.

        Access Level: Write

        Possible conditions:

        - .ifApiVersion()

        https://docs.aws.amazon.com/ses/latest/APIReference-V2/API_UpdateEmailTemplate.html

        :stability: experimental
        '''
        return typing.cast("SesV2", jsii.invoke(self, "toUpdateEmailTemplate", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4c2e74f688bf29a96ac18f93a327154033c572e971d8334a8275d457faac1422)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__39de02d1c99a24e67672726fc0a1d9ec3032411fe9aa2083ec2cdb28b5f6fb59)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Shield(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Shield",
):
    '''(experimental) Statement provider for service `shield <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsshield.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `shield <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsshield.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onAttack")
    def on_attack(
        self,
        id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Shield":
        '''(experimental) Adds a resource of type attack to the statement.

        https://docs.aws.amazon.com/waf/latest/DDOSAPIReference/API_AttackDetail.html

        :param id: - Identifier for the id.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fab4eff93c1fb643f1ff6d99e34d8aaa8ec9d04f349541829381469e55541691)
            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Shield", jsii.invoke(self, "onAttack", [id, account, partition]))

    @jsii.member(jsii_name="onProtection")
    def on_protection(
        self,
        id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Shield":
        '''(experimental) Adds a resource of type protection to the statement.

        https://docs.aws.amazon.com/waf/latest/DDOSAPIReference/API_Protection.html

        :param id: - Identifier for the id.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9ca97cdc46bc44d75f8b323115c9b75468a488d501ebfbb400ac24c9fae036b5)
            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Shield", jsii.invoke(self, "onProtection", [id, account, partition]))

    @jsii.member(jsii_name="onProtectionGroup")
    def on_protection_group(
        self,
        id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Shield":
        '''(experimental) Adds a resource of type protection-group to the statement.

        https://docs.aws.amazon.com/waf/latest/DDOSAPIReference/API_ProtectionGroup.html

        :param id: - Identifier for the id.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__93ca1abfa21b347149804d46b850ad9ebe59e46d8e2fa35be0b87aa20400f424)
            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Shield", jsii.invoke(self, "onProtectionGroup", [id, account, partition]))

    @jsii.member(jsii_name="toAssociateDRTLogBucket")
    def to_associate_drt_log_bucket(self) -> "Shield":
        '''(experimental) Grants permission to authorize the DDoS Response team to access the specified Amazon S3 bucket containing your flow logs.

        Access Level: Write

        Dependent actions:

        - s3:GetBucketPolicy
        - s3:PutBucketPolicy

        https://docs.aws.amazon.com/waf/latest/DDOSAPIReference/API_AssociateDRTLogBucket.html

        :stability: experimental
        '''
        return typing.cast("Shield", jsii.invoke(self, "toAssociateDRTLogBucket", []))

    @jsii.member(jsii_name="toAssociateDRTRole")
    def to_associate_drt_role(self) -> "Shield":
        '''(experimental) Grants permission to authorize the DDoS Response team using the specified role, to access your AWS account to assist with DDoS attack mitigation during potential attacks.

        Access Level: Write

        Dependent actions:

        - iam:GetRole
        - iam:ListAttachedRolePolicies
        - iam:PassRole

        https://docs.aws.amazon.com/waf/latest/DDOSAPIReference/API_AssociateDRTRole.html

        :stability: experimental
        '''
        return typing.cast("Shield", jsii.invoke(self, "toAssociateDRTRole", []))

    @jsii.member(jsii_name="toAssociateHealthCheck")
    def to_associate_health_check(self) -> "Shield":
        '''(experimental) Grants permission to add health-based detection to the Shield Advanced protection for a resource.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        Dependent actions:

        - route53:GetHealthCheck

        https://docs.aws.amazon.com/waf/latest/DDOSAPIReference/API_AssociateHealthCheck.html

        :stability: experimental
        '''
        return typing.cast("Shield", jsii.invoke(self, "toAssociateHealthCheck", []))

    @jsii.member(jsii_name="toAssociateProactiveEngagementDetails")
    def to_associate_proactive_engagement_details(self) -> "Shield":
        '''(experimental) Grants permission to initialize proactive engagement and set the list of contacts for the DDoS Response Team (DRT) to use.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/DDOSAPIReference/API_AssociateProactiveEngagementDetails.html

        :stability: experimental
        '''
        return typing.cast("Shield", jsii.invoke(self, "toAssociateProactiveEngagementDetails", []))

    @jsii.member(jsii_name="toCreateProtection")
    def to_create_protection(self) -> "Shield":
        '''(experimental) Grants permission to activate DDoS protection service for a given resource ARN.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/waf/latest/DDOSAPIReference/API_CreateProtection.html

        :stability: experimental
        '''
        return typing.cast("Shield", jsii.invoke(self, "toCreateProtection", []))

    @jsii.member(jsii_name="toCreateProtectionGroup")
    def to_create_protection_group(self) -> "Shield":
        '''(experimental) Grants permission to create a grouping of protected resources so they can be handled as a collective.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/waf/latest/DDOSAPIReference/API_CreateProtectionGroup.html

        :stability: experimental
        '''
        return typing.cast("Shield", jsii.invoke(self, "toCreateProtectionGroup", []))

    @jsii.member(jsii_name="toCreateSubscription")
    def to_create_subscription(self) -> "Shield":
        '''(experimental) Grants permission to activate subscription.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/DDOSAPIReference/API_CreateSubscription.html

        :stability: experimental
        '''
        return typing.cast("Shield", jsii.invoke(self, "toCreateSubscription", []))

    @jsii.member(jsii_name="toDeleteProtection")
    def to_delete_protection(self) -> "Shield":
        '''(experimental) Grants permission to delete an existing protection.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/waf/latest/DDOSAPIReference/API_DeleteProtection.html

        :stability: experimental
        '''
        return typing.cast("Shield", jsii.invoke(self, "toDeleteProtection", []))

    @jsii.member(jsii_name="toDeleteProtectionGroup")
    def to_delete_protection_group(self) -> "Shield":
        '''(experimental) Grants permission to remove the specified protection group.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/waf/latest/DDOSAPIReference/API_DeleteProtectionGroup.html

        :stability: experimental
        '''
        return typing.cast("Shield", jsii.invoke(self, "toDeleteProtectionGroup", []))

    @jsii.member(jsii_name="toDeleteSubscription")
    def to_delete_subscription(self) -> "Shield":
        '''(experimental) Grants permission to deactivate subscription.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/DDOSAPIReference/API_DeleteSubscription.html

        :stability: experimental
        '''
        return typing.cast("Shield", jsii.invoke(self, "toDeleteSubscription", []))

    @jsii.member(jsii_name="toDescribeAttack")
    def to_describe_attack(self) -> "Shield":
        '''(experimental) Grants permission to get attack details.

        Access Level: Read

        https://docs.aws.amazon.com/waf/latest/DDOSAPIReference/API_DescribeAttack.html

        :stability: experimental
        '''
        return typing.cast("Shield", jsii.invoke(self, "toDescribeAttack", []))

    @jsii.member(jsii_name="toDescribeAttackStatistics")
    def to_describe_attack_statistics(self) -> "Shield":
        '''(experimental) Grants permission to describe information about the number and type of attacks AWS Shield has detected in the last year.

        Access Level: Read

        https://docs.aws.amazon.com/waf/latest/DDOSAPIReference/API_DescribeAttackStatistics.html

        :stability: experimental
        '''
        return typing.cast("Shield", jsii.invoke(self, "toDescribeAttackStatistics", []))

    @jsii.member(jsii_name="toDescribeDRTAccess")
    def to_describe_drt_access(self) -> "Shield":
        '''(experimental) Grants permission to describe the current role and list of Amazon S3 log buckets used by the DDoS Response team to access your AWS account while assisting with attack mitigation.

        Access Level: Read

        https://docs.aws.amazon.com/waf/latest/DDOSAPIReference/API_DescribeDRTAccess.html

        :stability: experimental
        '''
        return typing.cast("Shield", jsii.invoke(self, "toDescribeDRTAccess", []))

    @jsii.member(jsii_name="toDescribeEmergencyContactSettings")
    def to_describe_emergency_contact_settings(self) -> "Shield":
        '''(experimental) Grants permission to list the email addresses that the DRT can use to contact you during a suspected attack.

        Access Level: Read

        https://docs.aws.amazon.com/waf/latest/DDOSAPIReference/API_DescribeEmergencyContactSettings.html

        :stability: experimental
        '''
        return typing.cast("Shield", jsii.invoke(self, "toDescribeEmergencyContactSettings", []))

    @jsii.member(jsii_name="toDescribeProtection")
    def to_describe_protection(self) -> "Shield":
        '''(experimental) Grants permission to get protection details.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/waf/latest/DDOSAPIReference/API_DescribeProtection.html

        :stability: experimental
        '''
        return typing.cast("Shield", jsii.invoke(self, "toDescribeProtection", []))

    @jsii.member(jsii_name="toDescribeProtectionGroup")
    def to_describe_protection_group(self) -> "Shield":
        '''(experimental) Grants permission to describe the specification for the specified protection group.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/waf/latest/DDOSAPIReference/API_DescribeProtectionGroup.html

        :stability: experimental
        '''
        return typing.cast("Shield", jsii.invoke(self, "toDescribeProtectionGroup", []))

    @jsii.member(jsii_name="toDescribeSubscription")
    def to_describe_subscription(self) -> "Shield":
        '''(experimental) Grants permission to get subscription details, such as start time.

        Access Level: Read

        https://docs.aws.amazon.com/waf/latest/DDOSAPIReference/API_DescribeSubscription.html

        :stability: experimental
        '''
        return typing.cast("Shield", jsii.invoke(self, "toDescribeSubscription", []))

    @jsii.member(jsii_name="toDisableApplicationLayerAutomaticResponse")
    def to_disable_application_layer_automatic_response(self) -> "Shield":
        '''(experimental) Grants permission to disable application layer automatic response for Shield Advanced protection for a resource.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/DDOSAPIReference/API_DisableApplicationLayerAutomaticResponse.html

        :stability: experimental
        '''
        return typing.cast("Shield", jsii.invoke(self, "toDisableApplicationLayerAutomaticResponse", []))

    @jsii.member(jsii_name="toDisableProactiveEngagement")
    def to_disable_proactive_engagement(self) -> "Shield":
        '''(experimental) Grants permission to remove authorization from the DDoS Response Team (DRT) to notify contacts about escalations.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/DDOSAPIReference/API_DisableProactiveEngagement.html

        :stability: experimental
        '''
        return typing.cast("Shield", jsii.invoke(self, "toDisableProactiveEngagement", []))

    @jsii.member(jsii_name="toDisassociateDRTLogBucket")
    def to_disassociate_drt_log_bucket(self) -> "Shield":
        '''(experimental) Grants permission to remove the DDoS Response team's access to the specified Amazon S3 bucket containing your flow logs.

        Access Level: Write

        Dependent actions:

        - s3:DeleteBucketPolicy
        - s3:GetBucketPolicy
        - s3:PutBucketPolicy

        https://docs.aws.amazon.com/waf/latest/DDOSAPIReference/API_DisassociateDRTLogBucket.html

        :stability: experimental
        '''
        return typing.cast("Shield", jsii.invoke(self, "toDisassociateDRTLogBucket", []))

    @jsii.member(jsii_name="toDisassociateDRTRole")
    def to_disassociate_drt_role(self) -> "Shield":
        '''(experimental) Grants permission to remove the DDoS Response team's access to your AWS account.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/DDOSAPIReference/API_DisassociateDRTRole.html

        :stability: experimental
        '''
        return typing.cast("Shield", jsii.invoke(self, "toDisassociateDRTRole", []))

    @jsii.member(jsii_name="toDisassociateHealthCheck")
    def to_disassociate_health_check(self) -> "Shield":
        '''(experimental) Grants permission to remove health-based detection from the Shield Advanced protection for a resource.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/waf/latest/DDOSAPIReference/API_DisassociateHealthCheck.html

        :stability: experimental
        '''
        return typing.cast("Shield", jsii.invoke(self, "toDisassociateHealthCheck", []))

    @jsii.member(jsii_name="toEnableApplicationLayerAutomaticResponse")
    def to_enable_application_layer_automatic_response(self) -> "Shield":
        '''(experimental) Grants permission to enable application layer automatic response for Shield Advanced protection for a resource.

        Access Level: Write

        Dependent actions:

        - cloudfront:GetDistribution
        - iam:CreateServiceLinkedRole
        - iam:GetRole

        https://docs.aws.amazon.com/waf/latest/DDOSAPIReference/API_EnableApplicationLayerAutomaticResponse.html

        :stability: experimental
        '''
        return typing.cast("Shield", jsii.invoke(self, "toEnableApplicationLayerAutomaticResponse", []))

    @jsii.member(jsii_name="toEnableProactiveEngagement")
    def to_enable_proactive_engagement(self) -> "Shield":
        '''(experimental) Grants permission to authorize the DDoS Response Team (DRT) to use email and phone to notify contacts about escalations.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/DDOSAPIReference/API_EnableProactiveEngagement.html

        :stability: experimental
        '''
        return typing.cast("Shield", jsii.invoke(self, "toEnableProactiveEngagement", []))

    @jsii.member(jsii_name="toGetSubscriptionState")
    def to_get_subscription_state(self) -> "Shield":
        '''(experimental) Grants permission to get subscription state.

        Access Level: Read

        https://docs.aws.amazon.com/waf/latest/DDOSAPIReference/API_GetSubscriptionState.html

        :stability: experimental
        '''
        return typing.cast("Shield", jsii.invoke(self, "toGetSubscriptionState", []))

    @jsii.member(jsii_name="toListAttacks")
    def to_list_attacks(self) -> "Shield":
        '''(experimental) Grants permission to list all existing attacks.

        Access Level: List

        https://docs.aws.amazon.com/waf/latest/DDOSAPIReference/API_ListAttacks.html

        :stability: experimental
        '''
        return typing.cast("Shield", jsii.invoke(self, "toListAttacks", []))

    @jsii.member(jsii_name="toListProtectionGroups")
    def to_list_protection_groups(self) -> "Shield":
        '''(experimental) Grants permission to retrieve the protection groups for the account.

        Access Level: List

        https://docs.aws.amazon.com/waf/latest/DDOSAPIReference/API_ListProtectionGroups.html

        :stability: experimental
        '''
        return typing.cast("Shield", jsii.invoke(self, "toListProtectionGroups", []))

    @jsii.member(jsii_name="toListProtections")
    def to_list_protections(self) -> "Shield":
        '''(experimental) Grants permission to list all existing protections.

        Access Level: List

        https://docs.aws.amazon.com/waf/latest/DDOSAPIReference/API_ListProtections.html

        :stability: experimental
        '''
        return typing.cast("Shield", jsii.invoke(self, "toListProtections", []))

    @jsii.member(jsii_name="toListResourcesInProtectionGroup")
    def to_list_resources_in_protection_group(self) -> "Shield":
        '''(experimental) Grants permission to retrieve the resources that are included in the protection group.

        Access Level: List

        https://docs.aws.amazon.com/waf/latest/DDOSAPIReference/API_ListResourcesInProtectionGroup.html

        :stability: experimental
        '''
        return typing.cast("Shield", jsii.invoke(self, "toListResourcesInProtectionGroup", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Shield":
        '''(experimental) Grants permission to get information about AWS tags for a specified Amazon Resource Name (ARN) in AWS Shield.

        Access Level: Read

        https://docs.aws.amazon.com/waf/latest/DDOSAPIReference/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("Shield", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Shield":
        '''(experimental) Grants permission to add or updates tags for a resource in AWS Shield.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/waf/latest/DDOSAPIReference/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("Shield", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Shield":
        '''(experimental) Grants permission to remove tags from a resource in AWS Shield.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/waf/latest/DDOSAPIReference/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("Shield", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateApplicationLayerAutomaticResponse")
    def to_update_application_layer_automatic_response(self) -> "Shield":
        '''(experimental) Grants permission to update application layer automatic response for Shield Advanced protection for a resource.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/DDOSAPIReference/API_UpdateApplicationLayerAutomaticResponse.html

        :stability: experimental
        '''
        return typing.cast("Shield", jsii.invoke(self, "toUpdateApplicationLayerAutomaticResponse", []))

    @jsii.member(jsii_name="toUpdateEmergencyContactSettings")
    def to_update_emergency_contact_settings(self) -> "Shield":
        '''(experimental) Grants permission to update the details of the list of email addresses that the DRT can use to contact you during a suspected attack.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/DDOSAPIReference/API_UpdateEmergencyContactSettings.html

        :stability: experimental
        '''
        return typing.cast("Shield", jsii.invoke(self, "toUpdateEmergencyContactSettings", []))

    @jsii.member(jsii_name="toUpdateProtectionGroup")
    def to_update_protection_group(self) -> "Shield":
        '''(experimental) Grants permission to update an existing protection group.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/waf/latest/DDOSAPIReference/API_UpdateProtectionGroup.html

        :stability: experimental
        '''
        return typing.cast("Shield", jsii.invoke(self, "toUpdateProtectionGroup", []))

    @jsii.member(jsii_name="toUpdateSubscription")
    def to_update_subscription(self) -> "Shield":
        '''(experimental) Grants permission to update the details of an existing subscription.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/DDOSAPIReference/API_UpdateSubscription.html

        :stability: experimental
        '''
        return typing.cast("Shield", jsii.invoke(self, "toUpdateSubscription", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e739906e6af43b93419095f90b8782d57566756de466265d781cff78337dcb28)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__87233394db63df39c1b459f95aca4ca734e40f14e6ab5ea46c0bfc26600e41ec)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Signer(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Signer",
):
    '''(experimental) Statement provider for service `signer <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awssigner.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `signer <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awssigner.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="ifProfileVersion")
    def if_profile_version(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Signer":
        '''(experimental) Filters access by version of the Signing Profile.

        https://docs.aws.amazon.com/signer/latest/developerguide/authen-apipermissions.html

        Applies to actions:

        - .toAddProfilePermission()
        - .toCancelSigningProfile()
        - .toGetSigningProfile()
        - .toRemoveProfilePermission()
        - .toRevokeSignature()
        - .toRevokeSigningProfile()
        - .toStartSigningJob()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f598e02c845bb35f35a9a0e4966cff902846dd9ce502e495babddc40c54d93b2)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Signer", jsii.invoke(self, "ifProfileVersion", [value, operator]))

    @jsii.member(jsii_name="onSigningJob")
    def on_signing_job(
        self,
        job_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Signer":
        '''(experimental) Adds a resource of type signing-job to the statement.

        https://docs.aws.amazon.com/signer/latest/developerguide/gs-job.html

        :param job_id: - Identifier for the jobId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7964e93ebf4bd5a2aae91eaed4023207822ce36c3e1896bc2e41e3f6bb96c35b)
            check_type(argname="argument job_id", value=job_id, expected_type=type_hints["job_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Signer", jsii.invoke(self, "onSigningJob", [job_id, account, region, partition]))

    @jsii.member(jsii_name="onSigningProfile")
    def on_signing_profile(
        self,
        profile_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Signer":
        '''(experimental) Adds a resource of type signing-profile to the statement.

        https://docs.aws.amazon.com/signer/latest/developerguide/gs-profile.html

        :param profile_name: - Identifier for the profileName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__883ac2e4b711d7e11d4d69f1f8558d0e715c656d8e27411f9d16fd2033886374)
            check_type(argname="argument profile_name", value=profile_name, expected_type=type_hints["profile_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Signer", jsii.invoke(self, "onSigningProfile", [profile_name, account, region, partition]))

    @jsii.member(jsii_name="toAddProfilePermission")
    def to_add_profile_permission(self) -> "Signer":
        '''(experimental) Grants permission to add cross-account permissions to a Signing Profile.

        Access Level: Permissions management

        Possible conditions:

        - .ifProfileVersion()

        https://docs.aws.amazon.com/signer/latest/api/API_AddProfilePermission.html

        :stability: experimental
        '''
        return typing.cast("Signer", jsii.invoke(self, "toAddProfilePermission", []))

    @jsii.member(jsii_name="toCancelSigningProfile")
    def to_cancel_signing_profile(self) -> "Signer":
        '''(experimental) Grants permission to change the state of a Signing Profile to CANCELED.

        Access Level: Write

        Possible conditions:

        - .ifProfileVersion()

        https://docs.aws.amazon.com/signer/latest/api/API_CancelSigningProfile.html

        :stability: experimental
        '''
        return typing.cast("Signer", jsii.invoke(self, "toCancelSigningProfile", []))

    @jsii.member(jsii_name="toDescribeSigningJob")
    def to_describe_signing_job(self) -> "Signer":
        '''(experimental) Grants permission to return information about a specific Signing Job.

        Access Level: Read

        https://docs.aws.amazon.com/signer/latest/api/API_DescribeSigningJob.html

        :stability: experimental
        '''
        return typing.cast("Signer", jsii.invoke(self, "toDescribeSigningJob", []))

    @jsii.member(jsii_name="toGetSigningPlatform")
    def to_get_signing_platform(self) -> "Signer":
        '''(experimental) Grants permission to return information about a specific Signing Platform.

        Access Level: Read

        https://docs.aws.amazon.com/signer/latest/api/API_GetSigningPlatform.html

        :stability: experimental
        '''
        return typing.cast("Signer", jsii.invoke(self, "toGetSigningPlatform", []))

    @jsii.member(jsii_name="toGetSigningProfile")
    def to_get_signing_profile(self) -> "Signer":
        '''(experimental) Grants permission to return information about a specific Signing Profile.

        Access Level: Read

        Possible conditions:

        - .ifProfileVersion()

        https://docs.aws.amazon.com/signer/latest/api/API_GetSigningProfile.html

        :stability: experimental
        '''
        return typing.cast("Signer", jsii.invoke(self, "toGetSigningProfile", []))

    @jsii.member(jsii_name="toListProfilePermissions")
    def to_list_profile_permissions(self) -> "Signer":
        '''(experimental) Grants permission to list the cross-account permissions associated with a Signing Profile.

        Access Level: Read

        https://docs.aws.amazon.com/signer/latest/api/API_ListProfilePermissions.html

        :stability: experimental
        '''
        return typing.cast("Signer", jsii.invoke(self, "toListProfilePermissions", []))

    @jsii.member(jsii_name="toListSigningJobs")
    def to_list_signing_jobs(self) -> "Signer":
        '''(experimental) Grants permission to list all Signing Jobs in your account.

        Access Level: List

        https://docs.aws.amazon.com/signer/latest/api/API_ListSigningJobs.html

        :stability: experimental
        '''
        return typing.cast("Signer", jsii.invoke(self, "toListSigningJobs", []))

    @jsii.member(jsii_name="toListSigningPlatforms")
    def to_list_signing_platforms(self) -> "Signer":
        '''(experimental) Grants permission to list all available Signing Platforms.

        Access Level: List

        https://docs.aws.amazon.com/signer/latest/api/API_ListSigningPlatforms.html

        :stability: experimental
        '''
        return typing.cast("Signer", jsii.invoke(self, "toListSigningPlatforms", []))

    @jsii.member(jsii_name="toListSigningProfiles")
    def to_list_signing_profiles(self) -> "Signer":
        '''(experimental) Grants permission to list all Signing Profiles in your account.

        Access Level: List

        https://docs.aws.amazon.com/signer/latest/api/API_ListSigningProfiles.html

        :stability: experimental
        '''
        return typing.cast("Signer", jsii.invoke(self, "toListSigningProfiles", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Signer":
        '''(experimental) Grants permission to list the tags associated with a Signing Profile.

        Access Level: Read

        https://docs.aws.amazon.com/signer/latest/api/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("Signer", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toPutSigningProfile")
    def to_put_signing_profile(self) -> "Signer":
        '''(experimental) Grants permission to create a new Signing Profile.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/signer/latest/api/API_PutSigningProfile.html

        :stability: experimental
        '''
        return typing.cast("Signer", jsii.invoke(self, "toPutSigningProfile", []))

    @jsii.member(jsii_name="toRemoveProfilePermission")
    def to_remove_profile_permission(self) -> "Signer":
        '''(experimental) Grants permission to remove cross-account permissions from a Signing Profile.

        Access Level: Permissions management

        Possible conditions:

        - .ifProfileVersion()

        https://docs.aws.amazon.com/signer/latest/api/API_RemoveProfilePermission.html

        :stability: experimental
        '''
        return typing.cast("Signer", jsii.invoke(self, "toRemoveProfilePermission", []))

    @jsii.member(jsii_name="toRevokeSignature")
    def to_revoke_signature(self) -> "Signer":
        '''(experimental) Grants permission to change the state of a Signing Job to REVOKED.

        Access Level: Write

        Possible conditions:

        - .ifProfileVersion()

        https://docs.aws.amazon.com/signer/latest/api/API_RevokeSignature.html

        :stability: experimental
        '''
        return typing.cast("Signer", jsii.invoke(self, "toRevokeSignature", []))

    @jsii.member(jsii_name="toRevokeSigningProfile")
    def to_revoke_signing_profile(self) -> "Signer":
        '''(experimental) Grants permission to change the state of a Signing Profile to REVOKED.

        Access Level: Write

        Possible conditions:

        - .ifProfileVersion()

        https://docs.aws.amazon.com/signer/latest/api/API_RevokeSigningProfile.html

        :stability: experimental
        '''
        return typing.cast("Signer", jsii.invoke(self, "toRevokeSigningProfile", []))

    @jsii.member(jsii_name="toStartSigningJob")
    def to_start_signing_job(self) -> "Signer":
        '''(experimental) Grants permission to initiate a Signing Job on the provided code.

        Access Level: Write

        Possible conditions:

        - .ifProfileVersion()

        https://docs.aws.amazon.com/signer/latest/api/API_StartSigningJob.html

        :stability: experimental
        '''
        return typing.cast("Signer", jsii.invoke(self, "toStartSigningJob", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Signer":
        '''(experimental) Grants permission to add one or more tags to a Signing Profile.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/signer/latest/api/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("Signer", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Signer":
        '''(experimental) Grants permission to remove one or more tags from a Signing Profile.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/signer/latest/api/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("Signer", jsii.invoke(self, "toUntagResource", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__16fc0b464404da25b3bd2620a1c7dd28235e927306c4bb1210fe63addc95af77)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3660c5813f5e7e11b630e3f2847c16a246fdb013ed4d9b0cd8d0a79f6e8e2759)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Simspaceweaver(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Simspaceweaver",
):
    '''(experimental) Statement provider for service `simspaceweaver <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awssimspaceweaver.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `simspaceweaver <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awssimspaceweaver.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onSimulation")
    def on_simulation(
        self,
        simulation_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Simspaceweaver":
        '''(experimental) Adds a resource of type Simulation to the statement.

        https://docs.aws.amazon.com/simspaceweaver/latest/userguide/working-with_configuring-simulation.html

        :param simulation_name: - Identifier for the simulationName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7693ce77c3124dd1c729f1d0cc86d0454d17fef5958a4c1b63baac2a4fc36691)
            check_type(argname="argument simulation_name", value=simulation_name, expected_type=type_hints["simulation_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Simspaceweaver", jsii.invoke(self, "onSimulation", [simulation_name, account, region, partition]))

    @jsii.member(jsii_name="toDeleteApp")
    def to_delete_app(self) -> "Simspaceweaver":
        '''(experimental) Grants permission to delete an app.

        Access Level: Write

        https://docs.aws.amazon.com/simspaceweaver/latest/APIReference/API_DeleteApp.html

        :stability: experimental
        '''
        return typing.cast("Simspaceweaver", jsii.invoke(self, "toDeleteApp", []))

    @jsii.member(jsii_name="toDeleteSimulation")
    def to_delete_simulation(self) -> "Simspaceweaver":
        '''(experimental) Grants permission to delete a simulation.

        Access Level: Write

        https://docs.aws.amazon.com/simspaceweaver/latest/APIReference/API_DeleteSimulation.html

        :stability: experimental
        '''
        return typing.cast("Simspaceweaver", jsii.invoke(self, "toDeleteSimulation", []))

    @jsii.member(jsii_name="toDescribeApp")
    def to_describe_app(self) -> "Simspaceweaver":
        '''(experimental) Grants permission to describe an app.

        Access Level: Read

        https://docs.aws.amazon.com/simspaceweaver/latest/APIReference/API_DescribeApp.html

        :stability: experimental
        '''
        return typing.cast("Simspaceweaver", jsii.invoke(self, "toDescribeApp", []))

    @jsii.member(jsii_name="toDescribeSimulation")
    def to_describe_simulation(self) -> "Simspaceweaver":
        '''(experimental) Grants permission to describe a simulation.

        Access Level: Read

        https://docs.aws.amazon.com/simspaceweaver/latest/APIReference/API_DescribeSimulation.html

        :stability: experimental
        '''
        return typing.cast("Simspaceweaver", jsii.invoke(self, "toDescribeSimulation", []))

    @jsii.member(jsii_name="toListApps")
    def to_list_apps(self) -> "Simspaceweaver":
        '''(experimental) Grants permission to list apps.

        Access Level: Read

        https://docs.aws.amazon.com/simspaceweaver/latest/APIReference/API_ListApps.html

        :stability: experimental
        '''
        return typing.cast("Simspaceweaver", jsii.invoke(self, "toListApps", []))

    @jsii.member(jsii_name="toListSimulations")
    def to_list_simulations(self) -> "Simspaceweaver":
        '''(experimental) Grants permission to list simulations.

        Access Level: List

        https://docs.aws.amazon.com/simspaceweaver/latest/APIReference/API_ListSimulations.html

        :stability: experimental
        '''
        return typing.cast("Simspaceweaver", jsii.invoke(self, "toListSimulations", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Simspaceweaver":
        '''(experimental) Grants permission to list the tags for a resource.

        Access Level: Read

        https://docs.aws.amazon.com/simspaceweaver/latest/APIReference/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("Simspaceweaver", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toStartApp")
    def to_start_app(self) -> "Simspaceweaver":
        '''(experimental) Grants permission to start an app.

        Access Level: Write

        https://docs.aws.amazon.com/simspaceweaver/latest/APIReference/API_StartApp.html

        :stability: experimental
        '''
        return typing.cast("Simspaceweaver", jsii.invoke(self, "toStartApp", []))

    @jsii.member(jsii_name="toStartClock")
    def to_start_clock(self) -> "Simspaceweaver":
        '''(experimental) Grants permission to start a simulation clock.

        Access Level: Write

        https://docs.aws.amazon.com/simspaceweaver/latest/APIReference/API_StartClock.html

        :stability: experimental
        '''
        return typing.cast("Simspaceweaver", jsii.invoke(self, "toStartClock", []))

    @jsii.member(jsii_name="toStartSimulation")
    def to_start_simulation(self) -> "Simspaceweaver":
        '''(experimental) Grants permission to start a simulation.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/simspaceweaver/latest/APIReference/API_StartSimulation.html

        :stability: experimental
        '''
        return typing.cast("Simspaceweaver", jsii.invoke(self, "toStartSimulation", []))

    @jsii.member(jsii_name="toStopApp")
    def to_stop_app(self) -> "Simspaceweaver":
        '''(experimental) Grants permission to stop an app.

        Access Level: Write

        https://docs.aws.amazon.com/simspaceweaver/latest/APIReference/API_StopApp.html

        :stability: experimental
        '''
        return typing.cast("Simspaceweaver", jsii.invoke(self, "toStopApp", []))

    @jsii.member(jsii_name="toStopClock")
    def to_stop_clock(self) -> "Simspaceweaver":
        '''(experimental) Grants permission to stop a simulation clock.

        Access Level: Write

        https://docs.aws.amazon.com/simspaceweaver/latest/APIReference/API_StopClock.html

        :stability: experimental
        '''
        return typing.cast("Simspaceweaver", jsii.invoke(self, "toStopClock", []))

    @jsii.member(jsii_name="toStopSimulation")
    def to_stop_simulation(self) -> "Simspaceweaver":
        '''(experimental) Grants permission to stop a simulation.

        Access Level: Write

        https://docs.aws.amazon.com/simspaceweaver/latest/APIReference/API_StopSimulation.html

        :stability: experimental
        '''
        return typing.cast("Simspaceweaver", jsii.invoke(self, "toStopSimulation", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Simspaceweaver":
        '''(experimental) Grants permission to tag a resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/simspaceweaver/latest/APIReference/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("Simspaceweaver", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Simspaceweaver":
        '''(experimental) Grants permission to untag a resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/simspaceweaver/latest/APIReference/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("Simspaceweaver", jsii.invoke(self, "toUntagResource", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7dbe10466146751b9795f869e4a37afcbf92259e1e5496c9b53d365bc8ac1a34)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__60a958dc74a926de483ae84207dcc6f6b9465fa48a8036788f668bce1b0a805e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Sms(PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Sms"):
    '''(experimental) Statement provider for service `sms <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsservermigrationservice.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `sms <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsservermigrationservice.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="toCreateApp")
    def to_create_app(self) -> "Sms":
        '''(experimental) Grants permission to create an application configuration to migrate on-premise application onto AWS.

        Access Level: Write

        https://docs.aws.amazon.com/server-migration-service/latest/APIReference/API_CreateApp.html

        :stability: experimental
        '''
        return typing.cast("Sms", jsii.invoke(self, "toCreateApp", []))

    @jsii.member(jsii_name="toCreateReplicationJob")
    def to_create_replication_job(self) -> "Sms":
        '''(experimental) Grants permission to create a job to migrate on-premise server onto AWS.

        Access Level: Write

        https://docs.aws.amazon.com/server-migration-service/latest/APIReference/API_CreateReplicationJob.html

        :stability: experimental
        '''
        return typing.cast("Sms", jsii.invoke(self, "toCreateReplicationJob", []))

    @jsii.member(jsii_name="toDeleteApp")
    def to_delete_app(self) -> "Sms":
        '''(experimental) Grants permission to delete an existing application configuration.

        Access Level: Write

        https://docs.aws.amazon.com/server-migration-service/latest/APIReference/API_DeleteApp.html

        :stability: experimental
        '''
        return typing.cast("Sms", jsii.invoke(self, "toDeleteApp", []))

    @jsii.member(jsii_name="toDeleteAppLaunchConfiguration")
    def to_delete_app_launch_configuration(self) -> "Sms":
        '''(experimental) Grants permission to delete launch configuration for an existing application.

        Access Level: Write

        https://docs.aws.amazon.com/server-migration-service/latest/APIReference/API_DeleteAppLaunchConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Sms", jsii.invoke(self, "toDeleteAppLaunchConfiguration", []))

    @jsii.member(jsii_name="toDeleteAppReplicationConfiguration")
    def to_delete_app_replication_configuration(self) -> "Sms":
        '''(experimental) Grants permission to delete replication configuration for an existing application.

        Access Level: Write

        https://docs.aws.amazon.com/server-migration-service/latest/APIReference/API_DeleteAppReplicationConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Sms", jsii.invoke(self, "toDeleteAppReplicationConfiguration", []))

    @jsii.member(jsii_name="toDeleteAppValidationConfiguration")
    def to_delete_app_validation_configuration(self) -> "Sms":
        '''(experimental) Grants permission to delete validation configuration for an existing application.

        Access Level: Write

        https://docs.aws.amazon.com/server-migration-service/latest/APIReference/API_DeleteAppValidationConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Sms", jsii.invoke(self, "toDeleteAppValidationConfiguration", []))

    @jsii.member(jsii_name="toDeleteReplicationJob")
    def to_delete_replication_job(self) -> "Sms":
        '''(experimental) Grants permission to delete an existing job to migrate on-premise server onto AWS.

        Access Level: Write

        https://docs.aws.amazon.com/server-migration-service/latest/APIReference/API_DeleteReplicationJob.html

        :stability: experimental
        '''
        return typing.cast("Sms", jsii.invoke(self, "toDeleteReplicationJob", []))

    @jsii.member(jsii_name="toDeleteServerCatalog")
    def to_delete_server_catalog(self) -> "Sms":
        '''(experimental) Grants permission to delete the complete list of on-premise servers gathered into AWS.

        Access Level: Write

        https://docs.aws.amazon.com/server-migration-service/latest/APIReference/API_DeleteServerCatalog.html

        :stability: experimental
        '''
        return typing.cast("Sms", jsii.invoke(self, "toDeleteServerCatalog", []))

    @jsii.member(jsii_name="toDisassociateConnector")
    def to_disassociate_connector(self) -> "Sms":
        '''(experimental) Grants permission to disassociate a connector that has been associated.

        Access Level: Write

        https://docs.aws.amazon.com/server-migration-service/latest/APIReference/API_DisassociateConnector.html

        :stability: experimental
        '''
        return typing.cast("Sms", jsii.invoke(self, "toDisassociateConnector", []))

    @jsii.member(jsii_name="toGenerateChangeSet")
    def to_generate_change_set(self) -> "Sms":
        '''(experimental) Grants permission to generate a changeSet for the CloudFormation stack of an application.

        Access Level: Write

        https://docs.aws.amazon.com/server-migration-service/latest/APIReference/API_GenerateChangeSet.html

        :stability: experimental
        '''
        return typing.cast("Sms", jsii.invoke(self, "toGenerateChangeSet", []))

    @jsii.member(jsii_name="toGenerateTemplate")
    def to_generate_template(self) -> "Sms":
        '''(experimental) Grants permission to generate a CloudFormation template for an existing application.

        Access Level: Write

        https://docs.aws.amazon.com/server-migration-service/latest/APIReference/API_GenerateTemplate.html

        :stability: experimental
        '''
        return typing.cast("Sms", jsii.invoke(self, "toGenerateTemplate", []))

    @jsii.member(jsii_name="toGetApp")
    def to_get_app(self) -> "Sms":
        '''(experimental) Grants permission to get the configuration and statuses for an existing application.

        Access Level: Read

        https://docs.aws.amazon.com/server-migration-service/latest/APIReference/API_GetApp.html

        :stability: experimental
        '''
        return typing.cast("Sms", jsii.invoke(self, "toGetApp", []))

    @jsii.member(jsii_name="toGetAppLaunchConfiguration")
    def to_get_app_launch_configuration(self) -> "Sms":
        '''(experimental) Grants permission to get launch configuration for an existing application.

        Access Level: Read

        https://docs.aws.amazon.com/server-migration-service/latest/APIReference/API_GetAppLaunchConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Sms", jsii.invoke(self, "toGetAppLaunchConfiguration", []))

    @jsii.member(jsii_name="toGetAppReplicationConfiguration")
    def to_get_app_replication_configuration(self) -> "Sms":
        '''(experimental) Grants permission to get replication configuration for an existing application.

        Access Level: Read

        https://docs.aws.amazon.com/server-migration-service/latest/APIReference/API_GetAppReplicationConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Sms", jsii.invoke(self, "toGetAppReplicationConfiguration", []))

    @jsii.member(jsii_name="toGetAppValidationConfiguration")
    def to_get_app_validation_configuration(self) -> "Sms":
        '''(experimental) Grants permission to get validation configuration for an existing application.

        Access Level: Read

        https://docs.aws.amazon.com/server-migration-service/latest/APIReference/API_GetAppValidationConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Sms", jsii.invoke(self, "toGetAppValidationConfiguration", []))

    @jsii.member(jsii_name="toGetAppValidationOutput")
    def to_get_app_validation_output(self) -> "Sms":
        '''(experimental) Grants permission to get notification sent from application validation script.

        Access Level: Read

        https://docs.aws.amazon.com/server-migration-service/latest/APIReference/API_GetAppValidationOutput.html

        :stability: experimental
        '''
        return typing.cast("Sms", jsii.invoke(self, "toGetAppValidationOutput", []))

    @jsii.member(jsii_name="toGetConnectors")
    def to_get_connectors(self) -> "Sms":
        '''(experimental) Grants permission to get all connectors that have been associated.

        Access Level: Read

        https://docs.aws.amazon.com/server-migration-service/latest/APIReference/API_GetConnectors.html

        :stability: experimental
        '''
        return typing.cast("Sms", jsii.invoke(self, "toGetConnectors", []))

    @jsii.member(jsii_name="toGetMessages")
    def to_get_messages(self) -> "Sms":
        '''(experimental) Grants permission to gets messages from AWS Server Migration Service to Server Migration Connector.

        Access Level: Read

        :stability: experimental
        '''
        return typing.cast("Sms", jsii.invoke(self, "toGetMessages", []))

    @jsii.member(jsii_name="toGetReplicationJobs")
    def to_get_replication_jobs(self) -> "Sms":
        '''(experimental) Grants permission to get all existing jobs to migrate on-premise servers onto AWS.

        Access Level: Read

        https://docs.aws.amazon.com/server-migration-service/latest/APIReference/API_GetReplicationJobs.html

        :stability: experimental
        '''
        return typing.cast("Sms", jsii.invoke(self, "toGetReplicationJobs", []))

    @jsii.member(jsii_name="toGetReplicationRuns")
    def to_get_replication_runs(self) -> "Sms":
        '''(experimental) Grants permission to get all runs for an existing job.

        Access Level: Read

        https://docs.aws.amazon.com/server-migration-service/latest/APIReference/API_GetReplicationRuns.html

        :stability: experimental
        '''
        return typing.cast("Sms", jsii.invoke(self, "toGetReplicationRuns", []))

    @jsii.member(jsii_name="toGetServers")
    def to_get_servers(self) -> "Sms":
        '''(experimental) Grants permission to get all servers that have been imported.

        Access Level: Read

        https://docs.aws.amazon.com/server-migration-service/latest/APIReference/API_GetServers.html

        :stability: experimental
        '''
        return typing.cast("Sms", jsii.invoke(self, "toGetServers", []))

    @jsii.member(jsii_name="toImportAppCatalog")
    def to_import_app_catalog(self) -> "Sms":
        '''(experimental) Grants permission to import application catalog from AWS Application Discovery Service.

        Access Level: Write

        https://docs.aws.amazon.com/server-migration-service/latest/APIReference/API_ImportAppCatalog.html

        :stability: experimental
        '''
        return typing.cast("Sms", jsii.invoke(self, "toImportAppCatalog", []))

    @jsii.member(jsii_name="toImportServerCatalog")
    def to_import_server_catalog(self) -> "Sms":
        '''(experimental) Grants permission to gather a complete list of on-premise servers.

        Access Level: Write

        https://docs.aws.amazon.com/server-migration-service/latest/APIReference/API_ImportServerCatalog.html

        :stability: experimental
        '''
        return typing.cast("Sms", jsii.invoke(self, "toImportServerCatalog", []))

    @jsii.member(jsii_name="toLaunchApp")
    def to_launch_app(self) -> "Sms":
        '''(experimental) Grants permission to create and launch a CloudFormation stack for an existing application.

        Access Level: Write

        https://docs.aws.amazon.com/server-migration-service/latest/APIReference/API_LaunchApp.html

        :stability: experimental
        '''
        return typing.cast("Sms", jsii.invoke(self, "toLaunchApp", []))

    @jsii.member(jsii_name="toListApps")
    def to_list_apps(self) -> "Sms":
        '''(experimental) Grants permission to get a list of summaries for existing applications.

        Access Level: List

        https://docs.aws.amazon.com/server-migration-service/latest/APIReference/API_ListAppss.html

        :stability: experimental
        '''
        return typing.cast("Sms", jsii.invoke(self, "toListApps", []))

    @jsii.member(jsii_name="toNotifyAppValidationOutput")
    def to_notify_app_validation_output(self) -> "Sms":
        '''(experimental) Grants permission to send notification for application validation script.

        Access Level: Write

        https://docs.aws.amazon.com/server-migration-service/latest/APIReference/API_NotifyAppValidationOutput.html

        :stability: experimental
        '''
        return typing.cast("Sms", jsii.invoke(self, "toNotifyAppValidationOutput", []))

    @jsii.member(jsii_name="toPutAppLaunchConfiguration")
    def to_put_app_launch_configuration(self) -> "Sms":
        '''(experimental) Grants permission to create or update launch configuration for an existing application.

        Access Level: Write

        https://docs.aws.amazon.com/server-migration-service/latest/APIReference/API_PutAppLaunchConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Sms", jsii.invoke(self, "toPutAppLaunchConfiguration", []))

    @jsii.member(jsii_name="toPutAppReplicationConfiguration")
    def to_put_app_replication_configuration(self) -> "Sms":
        '''(experimental) Grants permission to create or update replication configuration for an existing application.

        Access Level: Write

        https://docs.aws.amazon.com/server-migration-service/latest/APIReference/API_PutAppReplicationConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Sms", jsii.invoke(self, "toPutAppReplicationConfiguration", []))

    @jsii.member(jsii_name="toPutAppValidationConfiguration")
    def to_put_app_validation_configuration(self) -> "Sms":
        '''(experimental) Grants permission to put validation configuration for an existing application.

        Access Level: Write

        https://docs.aws.amazon.com/server-migration-service/latest/APIReference/API_PutAppValidationConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Sms", jsii.invoke(self, "toPutAppValidationConfiguration", []))

    @jsii.member(jsii_name="toSendMessage")
    def to_send_message(self) -> "Sms":
        '''(experimental) Grants permission to send message from Server Migration Connector to AWS Server Migration Service.

        Access Level: Write

        :stability: experimental
        '''
        return typing.cast("Sms", jsii.invoke(self, "toSendMessage", []))

    @jsii.member(jsii_name="toStartAppReplication")
    def to_start_app_replication(self) -> "Sms":
        '''(experimental) Grants permission to create and start replication jobs for an existing application.

        Access Level: Write

        https://docs.aws.amazon.com/server-migration-service/latest/APIReference/API_StartAppReplication.html

        :stability: experimental
        '''
        return typing.cast("Sms", jsii.invoke(self, "toStartAppReplication", []))

    @jsii.member(jsii_name="toStartOnDemandAppReplication")
    def to_start_on_demand_app_replication(self) -> "Sms":
        '''(experimental) Grants permission to start a replication run for an existing application.

        Access Level: Write

        https://docs.aws.amazon.com/server-migration-service/latest/APIReference/API_StartOnDemandAppReplication.html

        :stability: experimental
        '''
        return typing.cast("Sms", jsii.invoke(self, "toStartOnDemandAppReplication", []))

    @jsii.member(jsii_name="toStartOnDemandReplicationRun")
    def to_start_on_demand_replication_run(self) -> "Sms":
        '''(experimental) Grants permission to start a replication run for an existing replication job.

        Access Level: Write

        https://docs.aws.amazon.com/server-migration-service/latest/APIReference/API_StartOnDemandReplicationRun.html

        :stability: experimental
        '''
        return typing.cast("Sms", jsii.invoke(self, "toStartOnDemandReplicationRun", []))

    @jsii.member(jsii_name="toStopAppReplication")
    def to_stop_app_replication(self) -> "Sms":
        '''(experimental) Grants permission to stop and delete replication jobs for an existing application.

        Access Level: Write

        https://docs.aws.amazon.com/server-migration-service/latest/APIReference/API_StopAppReplication.html

        :stability: experimental
        '''
        return typing.cast("Sms", jsii.invoke(self, "toStopAppReplication", []))

    @jsii.member(jsii_name="toTerminateApp")
    def to_terminate_app(self) -> "Sms":
        '''(experimental) Grants permission to terminate the CloudFormation stack for an existing application.

        Access Level: Write

        https://docs.aws.amazon.com/server-migration-service/latest/APIReference/API_TerminateApp.html

        :stability: experimental
        '''
        return typing.cast("Sms", jsii.invoke(self, "toTerminateApp", []))

    @jsii.member(jsii_name="toUpdateApp")
    def to_update_app(self) -> "Sms":
        '''(experimental) Grants permission to update an existing application configuration.

        Access Level: Write

        https://docs.aws.amazon.com/server-migration-service/latest/APIReference/API_UpdateApp.html

        :stability: experimental
        '''
        return typing.cast("Sms", jsii.invoke(self, "toUpdateApp", []))

    @jsii.member(jsii_name="toUpdateReplicationJob")
    def to_update_replication_job(self) -> "Sms":
        '''(experimental) Grants permission to update an existing job to migrate on-premise server onto AWS.

        Access Level: Write

        https://docs.aws.amazon.com/server-migration-service/latest/APIReference/API_UpdateReplicationJob.html

        :stability: experimental
        '''
        return typing.cast("Sms", jsii.invoke(self, "toUpdateReplicationJob", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2a90d2fda4ecf4cf2c3c00bd33b3f904dd96e83e2bb82c1d51a9ec828966a7b6)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3bfa4364b8d635a823abe6d4a3d175263dafa4b1ab273125365ec40c60f2261a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class SmsVoice(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.SmsVoice",
):
    '''(experimental) Statement provider for service `sms-voice <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonpinpointsmsandvoiceservice.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `sms-voice <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonpinpointsmsandvoiceservice.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="toCreateConfigurationSet")
    def to_create_configuration_set(self) -> "SmsVoice":
        '''(experimental) Create a new configuration set.

        After you create the configuration set, you can add one or more event destinations to it.

        Access Level: Write

        https://docs.aws.amazon.com/pinpoint-sms-voice/latest/APIReference/v1-sms-voice-configuration-sets.html

        :stability: experimental
        '''
        return typing.cast("SmsVoice", jsii.invoke(self, "toCreateConfigurationSet", []))

    @jsii.member(jsii_name="toCreateConfigurationSetEventDestination")
    def to_create_configuration_set_event_destination(self) -> "SmsVoice":
        '''(experimental) Create a new event destination in a configuration set.

        Access Level: Write

        Dependent actions:

        - iam:PassRole

        https://docs.aws.amazon.com/pinpoint-sms-voice/latest/APIReference/v1-sms-voice-configuration-sets-configurationsetname-event-destinations.html

        :stability: experimental
        '''
        return typing.cast("SmsVoice", jsii.invoke(self, "toCreateConfigurationSetEventDestination", []))

    @jsii.member(jsii_name="toDeleteConfigurationSet")
    def to_delete_configuration_set(self) -> "SmsVoice":
        '''(experimental) Deletes an existing configuration set.

        Access Level: Write

        https://docs.aws.amazon.com/pinpoint-sms-voice/latest/APIReference/v1-sms-voice-configuration-sets-configurationsetname.html

        :stability: experimental
        '''
        return typing.cast("SmsVoice", jsii.invoke(self, "toDeleteConfigurationSet", []))

    @jsii.member(jsii_name="toDeleteConfigurationSetEventDestination")
    def to_delete_configuration_set_event_destination(self) -> "SmsVoice":
        '''(experimental) Deletes an event destination in a configuration set.

        Access Level: Write

        https://docs.aws.amazon.com/pinpoint-sms-voice/latest/APIReference/v1-sms-voice-configuration-sets-configurationsetname-event-destinations-eventdestinationname.html

        :stability: experimental
        '''
        return typing.cast("SmsVoice", jsii.invoke(self, "toDeleteConfigurationSetEventDestination", []))

    @jsii.member(jsii_name="toGetConfigurationSetEventDestinations")
    def to_get_configuration_set_event_destinations(self) -> "SmsVoice":
        '''(experimental) Obtain information about an event destination, including the types of events it reports, the Amazon Resource Name (ARN) of the destination, and the name of the event destination.

        Access Level: Read

        https://docs.aws.amazon.com/pinpoint-sms-voice/latest/APIReference/v1-sms-voice-configuration-sets-configurationsetname-event-destinations.html

        :stability: experimental
        '''
        return typing.cast("SmsVoice", jsii.invoke(self, "toGetConfigurationSetEventDestinations", []))

    @jsii.member(jsii_name="toListConfigurationSets")
    def to_list_configuration_sets(self) -> "SmsVoice":
        '''(experimental) Return a list of configuration sets.

        This operation only returns the configuration sets that are associated with your account in the current AWS Region.

        Access Level: Read

        https://docs.aws.amazon.com/pinpoint-sms-voice/latest/APIReference/v1-sms-voice-configuration-sets.html

        :stability: experimental
        '''
        return typing.cast("SmsVoice", jsii.invoke(self, "toListConfigurationSets", []))

    @jsii.member(jsii_name="toSendVoiceMessage")
    def to_send_voice_message(self) -> "SmsVoice":
        '''(experimental) Create a new voice message and send it to a recipient's phone number.

        Access Level: Write

        https://docs.aws.amazon.com/pinpoint-sms-voice/latest/APIReference/v1-sms-voice-voice-message.html

        :stability: experimental
        '''
        return typing.cast("SmsVoice", jsii.invoke(self, "toSendVoiceMessage", []))

    @jsii.member(jsii_name="toUpdateConfigurationSetEventDestination")
    def to_update_configuration_set_event_destination(self) -> "SmsVoice":
        '''(experimental) Update an event destination in a configuration set.

        An event destination is a location that you publish information about your voice calls to. For example, you can log an event to an Amazon CloudWatch destination when a call fails.

        Access Level: Write

        Dependent actions:

        - iam:PassRole

        https://docs.aws.amazon.com/pinpoint-sms-voice/latest/APIReference/v1-sms-voice-configuration-sets-configurationsetname-event-destinations-eventdestinationname.html

        :stability: experimental
        '''
        return typing.cast("SmsVoice", jsii.invoke(self, "toUpdateConfigurationSetEventDestination", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__14e640f700219f83fb0e04d1deca576bae84cbefa81235e458c74c9cc7378587)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__65af6936c0af90237e5d5b44067d94ede2cf578012d2ed895eb77856d896fc93)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class SmsVoiceV2(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.SmsVoiceV2",
):
    '''(experimental) Statement provider for service `sms-voice-v2 <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonpinpointsmsvoicev2.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `sms-voice-v2 <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonpinpointsmsvoicev2.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onConfigurationSet")
    def on_configuration_set(
        self,
        configuration_set_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "SmsVoiceV2":
        '''(experimental) Adds a resource of type ConfigurationSet to the statement.

        https://docs.aws.amazon.com/pinpoint/latest/apireference_smsvoicev2/API_CreateConfigurationSet.html

        :param configuration_set_name: - Identifier for the configurationSetName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__86eed1cd175f6e3abc623e56d59f89e89f723af1b3e6968cb27861eb41da3f6e)
            check_type(argname="argument configuration_set_name", value=configuration_set_name, expected_type=type_hints["configuration_set_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("SmsVoiceV2", jsii.invoke(self, "onConfigurationSet", [configuration_set_name, account, region, partition]))

    @jsii.member(jsii_name="onOptOutList")
    def on_opt_out_list(
        self,
        opt_out_list_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "SmsVoiceV2":
        '''(experimental) Adds a resource of type OptOutList to the statement.

        https://docs.aws.amazon.com/pinpoint/latest/apireference_smsvoicev2/API_CreateOptOutList.html

        :param opt_out_list_name: - Identifier for the optOutListName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0a3305f72aedec0dd7848f39222777623c2f0b34feb2cf6f214419d4eaa65b13)
            check_type(argname="argument opt_out_list_name", value=opt_out_list_name, expected_type=type_hints["opt_out_list_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("SmsVoiceV2", jsii.invoke(self, "onOptOutList", [opt_out_list_name, account, region, partition]))

    @jsii.member(jsii_name="onPhoneNumber")
    def on_phone_number(
        self,
        phone_number_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "SmsVoiceV2":
        '''(experimental) Adds a resource of type PhoneNumber to the statement.

        https://docs.aws.amazon.com/pinpoint/latest/apireference_smsvoicev2/API_RequestPhoneNumber.html

        :param phone_number_id: - Identifier for the phoneNumberId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6edf3a2c0771a224e9399709307488ea656f9f53186a0735df50b5aa2b466ca5)
            check_type(argname="argument phone_number_id", value=phone_number_id, expected_type=type_hints["phone_number_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("SmsVoiceV2", jsii.invoke(self, "onPhoneNumber", [phone_number_id, account, region, partition]))

    @jsii.member(jsii_name="onPool")
    def on_pool(
        self,
        pool_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "SmsVoiceV2":
        '''(experimental) Adds a resource of type Pool to the statement.

        https://docs.aws.amazon.com/pinpoint/latest/apireference_smsvoicev2/API_CreatePool.html

        :param pool_id: - Identifier for the poolId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__859a92bfb5e70c384fa038eab8dfa9d4b249184f13a2cac8a338175e2a23cd27)
            check_type(argname="argument pool_id", value=pool_id, expected_type=type_hints["pool_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("SmsVoiceV2", jsii.invoke(self, "onPool", [pool_id, account, region, partition]))

    @jsii.member(jsii_name="onSenderId")
    def on_sender_id(
        self,
        sender_id: builtins.str,
        iso_country_code: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "SmsVoiceV2":
        '''(experimental) Adds a resource of type SenderId to the statement.

        https://docs.aws.amazon.com/pinpoint/latest/apireference_smsvoicev2/API_DescribeSenderIds.html

        :param sender_id: - Identifier for the senderId.
        :param iso_country_code: - Identifier for the isoCountryCode.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__de6e6e77656508d83f7f68b5944309ebd58915b0a72d4499c6bf9b91be64f04f)
            check_type(argname="argument sender_id", value=sender_id, expected_type=type_hints["sender_id"])
            check_type(argname="argument iso_country_code", value=iso_country_code, expected_type=type_hints["iso_country_code"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("SmsVoiceV2", jsii.invoke(self, "onSenderId", [sender_id, iso_country_code, account, region, partition]))

    @jsii.member(jsii_name="toAssociateOriginationIdentity")
    def to_associate_origination_identity(self) -> "SmsVoiceV2":
        '''(experimental) Grants permission to associate an origination phone number or sender ID to a pool.

        Access Level: Write

        https://docs.aws.amazon.com/pinpoint/latest/apireference_smsvoicev2/API_AssociateOriginationIdentity.html

        :stability: experimental
        '''
        return typing.cast("SmsVoiceV2", jsii.invoke(self, "toAssociateOriginationIdentity", []))

    @jsii.member(jsii_name="toCreateConfigurationSet")
    def to_create_configuration_set(self) -> "SmsVoiceV2":
        '''(experimental) Grants permission to create a configuration set.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - sms-voice:TagResource

        https://docs.aws.amazon.com/pinpoint/latest/apireference_smsvoicev2/API_CreateConfigurationSet.html

        :stability: experimental
        '''
        return typing.cast("SmsVoiceV2", jsii.invoke(self, "toCreateConfigurationSet", []))

    @jsii.member(jsii_name="toCreateEventDestination")
    def to_create_event_destination(self) -> "SmsVoiceV2":
        '''(experimental) Grants permission to create an event destination within a configuration set.

        Access Level: Write

        Dependent actions:

        - iam:PassRole

        https://docs.aws.amazon.com/pinpoint/latest/apireference_smsvoicev2/API_CreateEventDestination.html

        :stability: experimental
        '''
        return typing.cast("SmsVoiceV2", jsii.invoke(self, "toCreateEventDestination", []))

    @jsii.member(jsii_name="toCreateOptOutList")
    def to_create_opt_out_list(self) -> "SmsVoiceV2":
        '''(experimental) Grants permission to create an opt-out list.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - sms-voice:TagResource

        https://docs.aws.amazon.com/pinpoint/latest/apireference_smsvoicev2/API_CreateOptOutList.html

        :stability: experimental
        '''
        return typing.cast("SmsVoiceV2", jsii.invoke(self, "toCreateOptOutList", []))

    @jsii.member(jsii_name="toCreatePool")
    def to_create_pool(self) -> "SmsVoiceV2":
        '''(experimental) Grants permission to create a pool.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - sms-voice:TagResource

        https://docs.aws.amazon.com/pinpoint/latest/apireference_smsvoicev2/API_CreatePool.html

        :stability: experimental
        '''
        return typing.cast("SmsVoiceV2", jsii.invoke(self, "toCreatePool", []))

    @jsii.member(jsii_name="toDeleteConfigurationSet")
    def to_delete_configuration_set(self) -> "SmsVoiceV2":
        '''(experimental) Grants permission to delete a configuration set.

        Access Level: Write

        https://docs.aws.amazon.com/pinpoint/latest/apireference_smsvoicev2/API_DeleteConfigurationSet.html

        :stability: experimental
        '''
        return typing.cast("SmsVoiceV2", jsii.invoke(self, "toDeleteConfigurationSet", []))

    @jsii.member(jsii_name="toDeleteDefaultMessageType")
    def to_delete_default_message_type(self) -> "SmsVoiceV2":
        '''(experimental) Grants permission to delete the default message type for a configuration set.

        Access Level: Write

        https://docs.aws.amazon.com/pinpoint/latest/apireference_smsvoicev2/API_DeleteDefaultMessageType.html

        :stability: experimental
        '''
        return typing.cast("SmsVoiceV2", jsii.invoke(self, "toDeleteDefaultMessageType", []))

    @jsii.member(jsii_name="toDeleteDefaultSenderId")
    def to_delete_default_sender_id(self) -> "SmsVoiceV2":
        '''(experimental) Grants permission to delete the default sender ID for a configuration set.

        Access Level: Write

        https://docs.aws.amazon.com/pinpoint/latest/apireference_smsvoicev2/API_DeleteDefaultSenderId.html

        :stability: experimental
        '''
        return typing.cast("SmsVoiceV2", jsii.invoke(self, "toDeleteDefaultSenderId", []))

    @jsii.member(jsii_name="toDeleteEventDestination")
    def to_delete_event_destination(self) -> "SmsVoiceV2":
        '''(experimental) Grants permission to delete an event destination within a configuration set.

        Access Level: Write

        https://docs.aws.amazon.com/pinpoint/latest/apireference_smsvoicev2/API_DeleteEventDestination.html

        :stability: experimental
        '''
        return typing.cast("SmsVoiceV2", jsii.invoke(self, "toDeleteEventDestination", []))

    @jsii.member(jsii_name="toDeleteKeyword")
    def to_delete_keyword(self) -> "SmsVoiceV2":
        '''(experimental) Grants permission to delete a keyword for a pool or origination phone number.

        Access Level: Write

        https://docs.aws.amazon.com/pinpoint/latest/apireference_smsvoicev2/API_DeleteKeyword.html

        :stability: experimental
        '''
        return typing.cast("SmsVoiceV2", jsii.invoke(self, "toDeleteKeyword", []))

    @jsii.member(jsii_name="toDeleteOptedOutNumber")
    def to_delete_opted_out_number(self) -> "SmsVoiceV2":
        '''(experimental) Grants permission to delete a destination phone number from an opt-out list.

        Access Level: Write

        https://docs.aws.amazon.com/pinpoint/latest/apireference_smsvoicev2/API_DeleteOptedOutNumber.html

        :stability: experimental
        '''
        return typing.cast("SmsVoiceV2", jsii.invoke(self, "toDeleteOptedOutNumber", []))

    @jsii.member(jsii_name="toDeleteOptOutList")
    def to_delete_opt_out_list(self) -> "SmsVoiceV2":
        '''(experimental) Grants permission to delete an opt-out list.

        Access Level: Write

        https://docs.aws.amazon.com/pinpoint/latest/apireference_smsvoicev2/API_DeleteOptOutList.html

        :stability: experimental
        '''
        return typing.cast("SmsVoiceV2", jsii.invoke(self, "toDeleteOptOutList", []))

    @jsii.member(jsii_name="toDeletePool")
    def to_delete_pool(self) -> "SmsVoiceV2":
        '''(experimental) Grants permission to delete a pool.

        Access Level: Write

        https://docs.aws.amazon.com/pinpoint/latest/apireference_smsvoicev2/API_DeletePool.html

        :stability: experimental
        '''
        return typing.cast("SmsVoiceV2", jsii.invoke(self, "toDeletePool", []))

    @jsii.member(jsii_name="toDeleteTextMessageSpendLimitOverride")
    def to_delete_text_message_spend_limit_override(self) -> "SmsVoiceV2":
        '''(experimental) Grants permission to delete an override for your account's text messaging monthly spend limit.

        Access Level: Write

        https://docs.aws.amazon.com/pinpoint/latest/apireference_smsvoicev2/API_DeleteTextMessageSpendLimitOverride.html

        :stability: experimental
        '''
        return typing.cast("SmsVoiceV2", jsii.invoke(self, "toDeleteTextMessageSpendLimitOverride", []))

    @jsii.member(jsii_name="toDeleteVoiceMessageSpendLimitOverride")
    def to_delete_voice_message_spend_limit_override(self) -> "SmsVoiceV2":
        '''(experimental) Grants permission to delete an override for your account's voice messaging monthly spend limit.

        Access Level: Write

        https://docs.aws.amazon.com/pinpoint/latest/apireference_smsvoicev2/API_DeleteVoiceMessageSpendLimitOverride.html

        :stability: experimental
        '''
        return typing.cast("SmsVoiceV2", jsii.invoke(self, "toDeleteVoiceMessageSpendLimitOverride", []))

    @jsii.member(jsii_name="toDescribeAccountAttributes")
    def to_describe_account_attributes(self) -> "SmsVoiceV2":
        '''(experimental) Grants permission to describe the attributes of your account.

        Access Level: Read

        https://docs.aws.amazon.com/pinpoint/latest/apireference_smsvoicev2/API_DescribeAccountAttributes.html

        :stability: experimental
        '''
        return typing.cast("SmsVoiceV2", jsii.invoke(self, "toDescribeAccountAttributes", []))

    @jsii.member(jsii_name="toDescribeAccountLimits")
    def to_describe_account_limits(self) -> "SmsVoiceV2":
        '''(experimental) Grants permission to describe the service quotas for your account.

        Access Level: Read

        https://docs.aws.amazon.com/pinpoint/latest/apireference_smsvoicev2/API_DescribeAccountLimits.html

        :stability: experimental
        '''
        return typing.cast("SmsVoiceV2", jsii.invoke(self, "toDescribeAccountLimits", []))

    @jsii.member(jsii_name="toDescribeConfigurationSets")
    def to_describe_configuration_sets(self) -> "SmsVoiceV2":
        '''(experimental) Grants permission to describe the configuration sets in your account.

        Access Level: Read

        https://docs.aws.amazon.com/pinpoint/latest/apireference_smsvoicev2/API_DescribeConfigurationSets.html

        :stability: experimental
        '''
        return typing.cast("SmsVoiceV2", jsii.invoke(self, "toDescribeConfigurationSets", []))

    @jsii.member(jsii_name="toDescribeKeywords")
    def to_describe_keywords(self) -> "SmsVoiceV2":
        '''(experimental) Grants permission to describe the keywords for a pool or origination phone number.

        Access Level: Read

        https://docs.aws.amazon.com/pinpoint/latest/apireference_smsvoicev2/API_DescribeKeywords.html

        :stability: experimental
        '''
        return typing.cast("SmsVoiceV2", jsii.invoke(self, "toDescribeKeywords", []))

    @jsii.member(jsii_name="toDescribeOptedOutNumbers")
    def to_describe_opted_out_numbers(self) -> "SmsVoiceV2":
        '''(experimental) Grants permission to describe the destination phone numbers in an opt-out list.

        Access Level: Read

        https://docs.aws.amazon.com/pinpoint/latest/apireference_smsvoicev2/API_DescribeOptedOutNumbers.html

        :stability: experimental
        '''
        return typing.cast("SmsVoiceV2", jsii.invoke(self, "toDescribeOptedOutNumbers", []))

    @jsii.member(jsii_name="toDescribeOptOutLists")
    def to_describe_opt_out_lists(self) -> "SmsVoiceV2":
        '''(experimental) Grants permission to describe the opt-out lists in your account.

        Access Level: Read

        https://docs.aws.amazon.com/pinpoint/latest/apireference_smsvoicev2/API_DescribeOptOutLists.html

        :stability: experimental
        '''
        return typing.cast("SmsVoiceV2", jsii.invoke(self, "toDescribeOptOutLists", []))

    @jsii.member(jsii_name="toDescribePhoneNumbers")
    def to_describe_phone_numbers(self) -> "SmsVoiceV2":
        '''(experimental) Grants permission to describe the origination phone numbers in your account.

        Access Level: Read

        https://docs.aws.amazon.com/pinpoint/latest/apireference_smsvoicev2/API_DescribePhoneNumbers.html

        :stability: experimental
        '''
        return typing.cast("SmsVoiceV2", jsii.invoke(self, "toDescribePhoneNumbers", []))

    @jsii.member(jsii_name="toDescribePools")
    def to_describe_pools(self) -> "SmsVoiceV2":
        '''(experimental) Grants permission to describe the pools in your account.

        Access Level: Read

        https://docs.aws.amazon.com/pinpoint/latest/apireference_smsvoicev2/API_DescribePools.html

        :stability: experimental
        '''
        return typing.cast("SmsVoiceV2", jsii.invoke(self, "toDescribePools", []))

    @jsii.member(jsii_name="toDescribeSenderIds")
    def to_describe_sender_ids(self) -> "SmsVoiceV2":
        '''(experimental) Grants permission to describe the sender IDs in your account.

        Access Level: Read

        https://docs.aws.amazon.com/pinpoint/latest/apireference_smsvoicev2/API_DescribeSenderIds.html

        :stability: experimental
        '''
        return typing.cast("SmsVoiceV2", jsii.invoke(self, "toDescribeSenderIds", []))

    @jsii.member(jsii_name="toDescribeSpendLimits")
    def to_describe_spend_limits(self) -> "SmsVoiceV2":
        '''(experimental) Grants permission to describe the monthly spend limits for your account.

        Access Level: Read

        https://docs.aws.amazon.com/pinpoint/latest/apireference_smsvoicev2/API_DescribeSpendLimits.html

        :stability: experimental
        '''
        return typing.cast("SmsVoiceV2", jsii.invoke(self, "toDescribeSpendLimits", []))

    @jsii.member(jsii_name="toDisassociateOriginationIdentity")
    def to_disassociate_origination_identity(self) -> "SmsVoiceV2":
        '''(experimental) Grants permission to disassociate an origination phone number or sender ID from a pool.

        Access Level: Write

        https://docs.aws.amazon.com/pinpoint/latest/apireference_smsvoicev2/API_DisassociateOriginationIdentity.html

        :stability: experimental
        '''
        return typing.cast("SmsVoiceV2", jsii.invoke(self, "toDisassociateOriginationIdentity", []))

    @jsii.member(jsii_name="toListPoolOriginationIdentities")
    def to_list_pool_origination_identities(self) -> "SmsVoiceV2":
        '''(experimental) Grants permission to list all origination phone numbers and sender IDs associated to a pool.

        Access Level: Read

        https://docs.aws.amazon.com/pinpoint/latest/apireference_smsvoicev2/API_ListPoolOriginationIdentities.html

        :stability: experimental
        '''
        return typing.cast("SmsVoiceV2", jsii.invoke(self, "toListPoolOriginationIdentities", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "SmsVoiceV2":
        '''(experimental) Grants permission to list the tags for a resource.

        Access Level: Read

        https://docs.aws.amazon.com/pinpoint/latest/apireference_smsvoicev2/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("SmsVoiceV2", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toPutKeyword")
    def to_put_keyword(self) -> "SmsVoiceV2":
        '''(experimental) Grants permission to create or update a keyword for a pool or origination phone number.

        Access Level: Write

        https://docs.aws.amazon.com/pinpoint/latest/apireference_smsvoicev2/API_PutKeyword.html

        :stability: experimental
        '''
        return typing.cast("SmsVoiceV2", jsii.invoke(self, "toPutKeyword", []))

    @jsii.member(jsii_name="toPutOptedOutNumber")
    def to_put_opted_out_number(self) -> "SmsVoiceV2":
        '''(experimental) Grants permission to put a destination phone number into an opt-out list.

        Access Level: Write

        https://docs.aws.amazon.com/pinpoint/latest/apireference_smsvoicev2/API_PutOptedOutNumber.html

        :stability: experimental
        '''
        return typing.cast("SmsVoiceV2", jsii.invoke(self, "toPutOptedOutNumber", []))

    @jsii.member(jsii_name="toReleasePhoneNumber")
    def to_release_phone_number(self) -> "SmsVoiceV2":
        '''(experimental) Grants permission to release an origination phone number.

        Access Level: Write

        https://docs.aws.amazon.com/pinpoint/latest/apireference_smsvoicev2/API_ReleasePhoneNumber.html

        :stability: experimental
        '''
        return typing.cast("SmsVoiceV2", jsii.invoke(self, "toReleasePhoneNumber", []))

    @jsii.member(jsii_name="toRequestPhoneNumber")
    def to_request_phone_number(self) -> "SmsVoiceV2":
        '''(experimental) Grants permission to request an origination phone number.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - sms-voice:AssociateOriginationIdentity
        - sms-voice:TagResource

        https://docs.aws.amazon.com/pinpoint/latest/apireference_smsvoicev2/API_RequestPhoneNumber.html

        :stability: experimental
        '''
        return typing.cast("SmsVoiceV2", jsii.invoke(self, "toRequestPhoneNumber", []))

    @jsii.member(jsii_name="toSendTextMessage")
    def to_send_text_message(self) -> "SmsVoiceV2":
        '''(experimental) Grants permission to send a text message to a destination phone number.

        Access Level: Write

        https://docs.aws.amazon.com/pinpoint/latest/apireference_smsvoicev2/API_SendTextMessage.html

        :stability: experimental
        '''
        return typing.cast("SmsVoiceV2", jsii.invoke(self, "toSendTextMessage", []))

    @jsii.member(jsii_name="toSendVoiceMessage")
    def to_send_voice_message(self) -> "SmsVoiceV2":
        '''(experimental) Grants permission to send a voice message to a destination phone number.

        Access Level: Write

        https://docs.aws.amazon.com/pinpoint/latest/apireference_smsvoicev2/API_SendVoiceMessage.html

        :stability: experimental
        '''
        return typing.cast("SmsVoiceV2", jsii.invoke(self, "toSendVoiceMessage", []))

    @jsii.member(jsii_name="toSetDefaultMessageType")
    def to_set_default_message_type(self) -> "SmsVoiceV2":
        '''(experimental) Grants permission to set the default message type for a configuration set.

        Access Level: Write

        https://docs.aws.amazon.com/pinpoint/latest/apireference_smsvoicev2/API_SetDefaultMessageType.html

        :stability: experimental
        '''
        return typing.cast("SmsVoiceV2", jsii.invoke(self, "toSetDefaultMessageType", []))

    @jsii.member(jsii_name="toSetDefaultSenderId")
    def to_set_default_sender_id(self) -> "SmsVoiceV2":
        '''(experimental) Grants permission to set the default sender ID for a configuration set.

        Access Level: Write

        https://docs.aws.amazon.com/pinpoint/latest/apireference_smsvoicev2/API_SetDefaultSenderId.html

        :stability: experimental
        '''
        return typing.cast("SmsVoiceV2", jsii.invoke(self, "toSetDefaultSenderId", []))

    @jsii.member(jsii_name="toSetTextMessageSpendLimitOverride")
    def to_set_text_message_spend_limit_override(self) -> "SmsVoiceV2":
        '''(experimental) Grants permission to set an override for your account's text messaging monthly spend limit.

        Access Level: Write

        https://docs.aws.amazon.com/pinpoint/latest/apireference_smsvoicev2/API_SetTextMessageSpendLimitOverride.html

        :stability: experimental
        '''
        return typing.cast("SmsVoiceV2", jsii.invoke(self, "toSetTextMessageSpendLimitOverride", []))

    @jsii.member(jsii_name="toSetVoiceMessageSpendLimitOverride")
    def to_set_voice_message_spend_limit_override(self) -> "SmsVoiceV2":
        '''(experimental) Grants permission to set an override for your account's voice messaging monthly spend limit.

        Access Level: Write

        https://docs.aws.amazon.com/pinpoint/latest/apireference_smsvoicev2/API_SetVoiceMessageSpendLimitOverride.html

        :stability: experimental
        '''
        return typing.cast("SmsVoiceV2", jsii.invoke(self, "toSetVoiceMessageSpendLimitOverride", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "SmsVoiceV2":
        '''(experimental) Grants permission to add tags to a resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/pinpoint/latest/apireference_smsvoicev2/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("SmsVoiceV2", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "SmsVoiceV2":
        '''(experimental) Grants permission to remove tags from a resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/pinpoint/latest/apireference_smsvoicev2/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("SmsVoiceV2", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateEventDestination")
    def to_update_event_destination(self) -> "SmsVoiceV2":
        '''(experimental) Grants permission to update an event destination within a configuration set.

        Access Level: Write

        Dependent actions:

        - iam:PassRole

        https://docs.aws.amazon.com/pinpoint/latest/apireference_smsvoicev2/API_UpdateEventDestination.html

        :stability: experimental
        '''
        return typing.cast("SmsVoiceV2", jsii.invoke(self, "toUpdateEventDestination", []))

    @jsii.member(jsii_name="toUpdatePhoneNumber")
    def to_update_phone_number(self) -> "SmsVoiceV2":
        '''(experimental) Grants permission to update an origination phone number's configuration.

        Access Level: Write

        https://docs.aws.amazon.com/pinpoint/latest/apireference_smsvoicev2/API_UpdatePhoneNumber.html

        :stability: experimental
        '''
        return typing.cast("SmsVoiceV2", jsii.invoke(self, "toUpdatePhoneNumber", []))

    @jsii.member(jsii_name="toUpdatePool")
    def to_update_pool(self) -> "SmsVoiceV2":
        '''(experimental) Grants permission to update a pool's configuration.

        Access Level: Write

        https://docs.aws.amazon.com/pinpoint/latest/apireference_smsvoicev2/API_UpdatePool.html

        :stability: experimental
        '''
        return typing.cast("SmsVoiceV2", jsii.invoke(self, "toUpdatePool", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__63d7a1cda54aeba2922782e1360c4486fc833ddbf0a8c742733af7c080ca3408)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__22049c913363b17c9a0bf6a7767e4080d6482dc40b7983fb78466e6f8e6429c0)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class SnowDeviceManagement(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.SnowDeviceManagement",
):
    '''(experimental) Statement provider for service `snow-device-management <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awssnowdevicemanagement.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `snow-device-management <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awssnowdevicemanagement.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onManagedDevice")
    def on_managed_device(
        self,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "SnowDeviceManagement":
        '''(experimental) Adds a resource of type managed-device to the statement.

        https://docs.aws.amazon.com/snowball/latest/snowcone-guide/aws-sdms.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__df1ea6aa2e4f5dba3b1b5adeecd243d003e81209ddd095aac86cde5d2ce78ba2)
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("SnowDeviceManagement", jsii.invoke(self, "onManagedDevice", [resource_id, account, region, partition]))

    @jsii.member(jsii_name="onTask")
    def on_task(
        self,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "SnowDeviceManagement":
        '''(experimental) Adds a resource of type task to the statement.

        https://docs.aws.amazon.com/snowball/latest/snowcone-guide/aws-sdms.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__415b46c4108b03c48d4bbeec789712de0f52e99a4ea51d12e5ede27e3274f994)
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("SnowDeviceManagement", jsii.invoke(self, "onTask", [resource_id, account, region, partition]))

    @jsii.member(jsii_name="toCancelTask")
    def to_cancel_task(self) -> "SnowDeviceManagement":
        '''(experimental) Grants permission to cancel tasks on remote devices.

        Access Level: Write

        https://docs.aws.amazon.com/snowball/latest/snowcone-guide/sdms-cli-cancel-task.html

        :stability: experimental
        '''
        return typing.cast("SnowDeviceManagement", jsii.invoke(self, "toCancelTask", []))

    @jsii.member(jsii_name="toCreateTask")
    def to_create_task(self) -> "SnowDeviceManagement":
        '''(experimental) Grants permission to create tasks on remote devices.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/snowball/latest/snowcone-guide/sdms-cli-create-task.html

        :stability: experimental
        '''
        return typing.cast("SnowDeviceManagement", jsii.invoke(self, "toCreateTask", []))

    @jsii.member(jsii_name="toDescribeDevice")
    def to_describe_device(self) -> "SnowDeviceManagement":
        '''(experimental) Grants permission to describe a remotely-managed device.

        Access Level: Read

        https://docs.aws.amazon.com/snowball/latest/snowcone-guide/sdms-cli-describe-device.html

        :stability: experimental
        '''
        return typing.cast("SnowDeviceManagement", jsii.invoke(self, "toDescribeDevice", []))

    @jsii.member(jsii_name="toDescribeDeviceEc2Instances")
    def to_describe_device_ec2_instances(self) -> "SnowDeviceManagement":
        '''(experimental) Grants permission to describe a remotely-managed device's EC2 instances.

        Access Level: Read

        https://docs.aws.amazon.com/snowball/latest/snowcone-guide/sdms-cli-describe-ec2-instances.html

        :stability: experimental
        '''
        return typing.cast("SnowDeviceManagement", jsii.invoke(self, "toDescribeDeviceEc2Instances", []))

    @jsii.member(jsii_name="toDescribeExecution")
    def to_describe_execution(self) -> "SnowDeviceManagement":
        '''(experimental) Grants permission to describe task executions.

        Access Level: Read

        https://docs.aws.amazon.com/snowball/latest/snowcone-guide/sdms-cli-describe-execution.html

        :stability: experimental
        '''
        return typing.cast("SnowDeviceManagement", jsii.invoke(self, "toDescribeExecution", []))

    @jsii.member(jsii_name="toDescribeTask")
    def to_describe_task(self) -> "SnowDeviceManagement":
        '''(experimental) Grants permission to describe a task.

        Access Level: Read

        https://docs.aws.amazon.com/snowball/latest/snowcone-guide/sdms-cli-describe-task.html

        :stability: experimental
        '''
        return typing.cast("SnowDeviceManagement", jsii.invoke(self, "toDescribeTask", []))

    @jsii.member(jsii_name="toListDeviceResources")
    def to_list_device_resources(self) -> "SnowDeviceManagement":
        '''(experimental) Grants permission to list a remotely-managed device's resources.

        Access Level: List

        https://docs.aws.amazon.com/snowball/latest/snowcone-guide/sdms-cli-list-device-resources.html

        :stability: experimental
        '''
        return typing.cast("SnowDeviceManagement", jsii.invoke(self, "toListDeviceResources", []))

    @jsii.member(jsii_name="toListDevices")
    def to_list_devices(self) -> "SnowDeviceManagement":
        '''(experimental) Grants permission to list remotely-managed devices.

        Access Level: List

        https://docs.aws.amazon.com/snowball/latest/snowcone-guide/sdms-cli-list-devices.html

        :stability: experimental
        '''
        return typing.cast("SnowDeviceManagement", jsii.invoke(self, "toListDevices", []))

    @jsii.member(jsii_name="toListExecutions")
    def to_list_executions(self) -> "SnowDeviceManagement":
        '''(experimental) Grants permission to list task executions.

        Access Level: List

        https://docs.aws.amazon.com/snowball/latest/snowcone-guide/sdms-cli-list-executions.html

        :stability: experimental
        '''
        return typing.cast("SnowDeviceManagement", jsii.invoke(self, "toListExecutions", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "SnowDeviceManagement":
        '''(experimental) Grants permission to list the tags for a resource (device or task).

        Access Level: Read

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/snowball/latest/snowcone-guide/sdms-cli-list-tags-for-resource.html

        :stability: experimental
        '''
        return typing.cast("SnowDeviceManagement", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toListTasks")
    def to_list_tasks(self) -> "SnowDeviceManagement":
        '''(experimental) Grants permission to list tasks.

        Access Level: List

        https://docs.aws.amazon.com/snowball/latest/snowcone-guide/sdms-cli-list-tasks.html

        :stability: experimental
        '''
        return typing.cast("SnowDeviceManagement", jsii.invoke(self, "toListTasks", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "SnowDeviceManagement":
        '''(experimental) Grants permission to tag a resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/snowball/latest/snowcone-guide/sdms-cli-tag-resource.html

        :stability: experimental
        '''
        return typing.cast("SnowDeviceManagement", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "SnowDeviceManagement":
        '''(experimental) Grants permission to untag a resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/snowball/latest/snowcone-guide/sdms-cli-untag-resources.html

        :stability: experimental
        '''
        return typing.cast("SnowDeviceManagement", jsii.invoke(self, "toUntagResource", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__84225be3dd2592028e1d0d7b399d79d6e610b9f9abf2dbffdb74318533678652)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4cbc6a0e2db3b6627f588349344eb95a8d2ef7daf88f111cf56239c1ce7d0f2a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Snowball(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Snowball",
):
    '''(experimental) Statement provider for service `snowball <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awssnowball.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `snowball <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awssnowball.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="toCancelCluster")
    def to_cancel_cluster(self) -> "Snowball":
        '''(experimental) Cancels a cluster job.

        Access Level: Write

        https://docs.aws.amazon.com/snowball/latest/api-reference/API_CancelCluster.html

        :stability: experimental
        '''
        return typing.cast("Snowball", jsii.invoke(self, "toCancelCluster", []))

    @jsii.member(jsii_name="toCancelJob")
    def to_cancel_job(self) -> "Snowball":
        '''(experimental) Cancels the specified job.

        Access Level: Write

        https://docs.aws.amazon.com/snowball/latest/api-reference/API_CancelJob.html

        :stability: experimental
        '''
        return typing.cast("Snowball", jsii.invoke(self, "toCancelJob", []))

    @jsii.member(jsii_name="toCreateAddress")
    def to_create_address(self) -> "Snowball":
        '''(experimental) Creates an address for a Snowball to be shipped to.

        Access Level: Write

        https://docs.aws.amazon.com/snowball/latest/api-reference/API_CreateAddress.html

        :stability: experimental
        '''
        return typing.cast("Snowball", jsii.invoke(self, "toCreateAddress", []))

    @jsii.member(jsii_name="toCreateCluster")
    def to_create_cluster(self) -> "Snowball":
        '''(experimental) Creates an empty cluster.

        Access Level: Write

        https://docs.aws.amazon.com/snowball/latest/api-reference/API_CreateCluster.html

        :stability: experimental
        '''
        return typing.cast("Snowball", jsii.invoke(self, "toCreateCluster", []))

    @jsii.member(jsii_name="toCreateJob")
    def to_create_job(self) -> "Snowball":
        '''(experimental) Creates a job to import or export data between Amazon S3 and your on-premises data center.

        Access Level: Write

        https://docs.aws.amazon.com/snowball/latest/api-reference/API_CreateJob.html

        :stability: experimental
        '''
        return typing.cast("Snowball", jsii.invoke(self, "toCreateJob", []))

    @jsii.member(jsii_name="toCreateLongTermPricing")
    def to_create_long_term_pricing(self) -> "Snowball":
        '''(experimental) Grants permission to creates a LongTermPricingListEntry for allowing customers to add an upfront billing contract for a job.

        Access Level: Write

        https://docs.aws.amazon.com/snowball/latest/api-reference/API_CreateLongTermPricing.html

        :stability: experimental
        '''
        return typing.cast("Snowball", jsii.invoke(self, "toCreateLongTermPricing", []))

    @jsii.member(jsii_name="toCreateReturnShippingLabel")
    def to_create_return_shipping_label(self) -> "Snowball":
        '''(experimental) Creates a shipping label that will be used to return the Snow device to AWS.

        Access Level: Write

        https://docs.aws.amazon.com/snowball/latest/api-reference/API_CreateReturnShippingLabel.html

        :stability: experimental
        '''
        return typing.cast("Snowball", jsii.invoke(self, "toCreateReturnShippingLabel", []))

    @jsii.member(jsii_name="toDescribeAddress")
    def to_describe_address(self) -> "Snowball":
        '''(experimental) Takes an AddressId and returns specific details about that address in the form of an Address object.

        Access Level: Read

        https://docs.aws.amazon.com/snowball/latest/api-reference/API_DescribeAddress.html

        :stability: experimental
        '''
        return typing.cast("Snowball", jsii.invoke(self, "toDescribeAddress", []))

    @jsii.member(jsii_name="toDescribeAddresses")
    def to_describe_addresses(self) -> "Snowball":
        '''(experimental) Returns a specified number of ADDRESS objects.

        Access Level: List

        https://docs.aws.amazon.com/snowball/latest/api-reference/API_DescribeAddresses.html

        :stability: experimental
        '''
        return typing.cast("Snowball", jsii.invoke(self, "toDescribeAddresses", []))

    @jsii.member(jsii_name="toDescribeCluster")
    def to_describe_cluster(self) -> "Snowball":
        '''(experimental) Returns information about a specific cluster including shipping information, cluster status, and other important metadata.

        Access Level: Read

        https://docs.aws.amazon.com/snowball/latest/api-reference/API_DescribeCluster.html

        :stability: experimental
        '''
        return typing.cast("Snowball", jsii.invoke(self, "toDescribeCluster", []))

    @jsii.member(jsii_name="toDescribeJob")
    def to_describe_job(self) -> "Snowball":
        '''(experimental) Returns information about a specific job including shipping information, job status, and other important metadata.

        Access Level: Read

        https://docs.aws.amazon.com/snowball/latest/api-reference/API_DescribeJob.html

        :stability: experimental
        '''
        return typing.cast("Snowball", jsii.invoke(self, "toDescribeJob", []))

    @jsii.member(jsii_name="toDescribeReturnShippingLabel")
    def to_describe_return_shipping_label(self) -> "Snowball":
        '''(experimental) Information on the shipping label of a Snow device that is being returned to AWS.

        Access Level: Read

        https://docs.aws.amazon.com/snowball/latest/api-reference/API_DescribeReturnShippingLabel.html

        :stability: experimental
        '''
        return typing.cast("Snowball", jsii.invoke(self, "toDescribeReturnShippingLabel", []))

    @jsii.member(jsii_name="toGetJobManifest")
    def to_get_job_manifest(self) -> "Snowball":
        '''(experimental) Returns a link to an Amazon S3 presigned URL for the manifest file associated with the specified JobId value.

        Access Level: Read

        https://docs.aws.amazon.com/snowball/latest/api-reference/API_GetJobManifest.html

        :stability: experimental
        '''
        return typing.cast("Snowball", jsii.invoke(self, "toGetJobManifest", []))

    @jsii.member(jsii_name="toGetJobUnlockCode")
    def to_get_job_unlock_code(self) -> "Snowball":
        '''(experimental) Returns the UnlockCode code value for the specified job.

        Access Level: Read

        https://docs.aws.amazon.com/snowball/latest/api-reference/API_GetJobUnlockCode.html

        :stability: experimental
        '''
        return typing.cast("Snowball", jsii.invoke(self, "toGetJobUnlockCode", []))

    @jsii.member(jsii_name="toGetSnowballUsage")
    def to_get_snowball_usage(self) -> "Snowball":
        '''(experimental) Returns information about the Snowball service limit for your account, and also the number of Snowballs your account has in use.

        Access Level: Read

        https://docs.aws.amazon.com/snowball/latest/api-reference/API_GetSnowballUsage.html

        :stability: experimental
        '''
        return typing.cast("Snowball", jsii.invoke(self, "toGetSnowballUsage", []))

    @jsii.member(jsii_name="toGetSoftwareUpdates")
    def to_get_software_updates(self) -> "Snowball":
        '''(experimental) Returns an Amazon S3 presigned URL for an update file associated with a specified JobId.

        Access Level: Read

        https://docs.aws.amazon.com/snowball/latest/api-reference/API_GetSoftwareUpdates.html

        :stability: experimental
        '''
        return typing.cast("Snowball", jsii.invoke(self, "toGetSoftwareUpdates", []))

    @jsii.member(jsii_name="toListClusterJobs")
    def to_list_cluster_jobs(self) -> "Snowball":
        '''(experimental) Returns an array of JobListEntry objects of the specified length.

        Access Level: List

        https://docs.aws.amazon.com/snowball/latest/api-reference/API_ListClusterJobs.html

        :stability: experimental
        '''
        return typing.cast("Snowball", jsii.invoke(self, "toListClusterJobs", []))

    @jsii.member(jsii_name="toListClusters")
    def to_list_clusters(self) -> "Snowball":
        '''(experimental) Returns an array of ClusterListEntry objects of the specified length.

        Access Level: List

        https://docs.aws.amazon.com/snowball/latest/api-reference/API_ListClusters.html

        :stability: experimental
        '''
        return typing.cast("Snowball", jsii.invoke(self, "toListClusters", []))

    @jsii.member(jsii_name="toListCompatibleImages")
    def to_list_compatible_images(self) -> "Snowball":
        '''(experimental) This action returns a list of the different Amazon EC2 Amazon Machine Images (AMIs) that are owned by your AWS account that would be supported for use on a Snow device.

        Access Level: List

        https://docs.aws.amazon.com/snowball/latest/api-reference/API_ListCompatibleImages.html

        :stability: experimental
        '''
        return typing.cast("Snowball", jsii.invoke(self, "toListCompatibleImages", []))

    @jsii.member(jsii_name="toListJobs")
    def to_list_jobs(self) -> "Snowball":
        '''(experimental) Returns an array of JobListEntry objects of the specified length.

        Access Level: List

        https://docs.aws.amazon.com/snowball/latest/api-reference/API_ListJobs.html

        :stability: experimental
        '''
        return typing.cast("Snowball", jsii.invoke(self, "toListJobs", []))

    @jsii.member(jsii_name="toListLongTermPricing")
    def to_list_long_term_pricing(self) -> "Snowball":
        '''(experimental) Grants permission to list LongTermPricingListEntry objects for the account making the request.

        Access Level: Read

        https://docs.aws.amazon.com/snowball/latest/api-reference/API_ListLongTermPricing.html

        :stability: experimental
        '''
        return typing.cast("Snowball", jsii.invoke(self, "toListLongTermPricing", []))

    @jsii.member(jsii_name="toUpdateCluster")
    def to_update_cluster(self) -> "Snowball":
        '''(experimental) While a cluster's ClusterState value is in the AwaitingQuorum state, you can update some of the information associated with a cluster.

        Access Level: Write

        https://docs.aws.amazon.com/snowball/latest/api-reference/API_UpdateCluster.html

        :stability: experimental
        '''
        return typing.cast("Snowball", jsii.invoke(self, "toUpdateCluster", []))

    @jsii.member(jsii_name="toUpdateJob")
    def to_update_job(self) -> "Snowball":
        '''(experimental) While a job's JobState value is New, you can update some of the information associated with a job.

        Access Level: Write

        https://docs.aws.amazon.com/snowball/latest/api-reference/API_UpdateJob.html

        :stability: experimental
        '''
        return typing.cast("Snowball", jsii.invoke(self, "toUpdateJob", []))

    @jsii.member(jsii_name="toUpdateJobShipmentState")
    def to_update_job_shipment_state(self) -> "Snowball":
        '''(experimental) Updates the state when a the shipment states changes to a different state.

        Access Level: Write

        https://docs.aws.amazon.com/snowball/latest/api-reference/API_UpdateJobShipmentState.html

        :stability: experimental
        '''
        return typing.cast("Snowball", jsii.invoke(self, "toUpdateJobShipmentState", []))

    @jsii.member(jsii_name="toUpdateLongTermPricing")
    def to_update_long_term_pricing(self) -> "Snowball":
        '''(experimental) Grants permission to update a specific upfront billing contract for a job.

        Access Level: Write

        https://docs.aws.amazon.com/snowball/latest/api-reference/API_UpdateLongTermPricing.html

        :stability: experimental
        '''
        return typing.cast("Snowball", jsii.invoke(self, "toUpdateLongTermPricing", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e9afe3583a13b4b86ded194ee791d672fa675fe01a3de17b1bf7c08e1fadffb8)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8c0be3a9aa08734664b4fc64c1051b797792265c2a6fadeb0c9820d2577cc1f9)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Sns(PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Sns"):
    '''(experimental) Statement provider for service `sns <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonsns.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `sns <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonsns.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="ifEndpoint")
    def if_endpoint(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Sns":
        '''(experimental) Filters access by the URL, email address, or ARN from a Subscribe request or a previously confirmed subscription.

        https://docs.aws.amazon.com/sns/latest/dg/UsingIAMwithSNS.html#w2ab1c11c23c19

        Applies to actions:

        - .toSubscribe()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__153699a4d5b49cc6fb524caa1ad31ae0e4d21f42eae05b5b36ab19ceaec8627b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Sns", jsii.invoke(self, "ifEndpoint", [value, operator]))

    @jsii.member(jsii_name="ifProtocol")
    def if_protocol(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Sns":
        '''(experimental) Filters access by the protocol value from a Subscribe request or a previously confirmed subscription.

        https://docs.aws.amazon.com/sns/latest/dg/UsingIAMwithSNS.html#w2ab1c11c23c19

        Applies to actions:

        - .toSubscribe()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__73bdc44533e63550d9e78985f09dfa664906aa7dce47a7335edd7463d09b9c72)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Sns", jsii.invoke(self, "ifProtocol", [value, operator]))

    @jsii.member(jsii_name="onTopic")
    def on_topic(
        self,
        topic_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Sns":
        '''(experimental) Adds a resource of type topic to the statement.

        https://docs.aws.amazon.com/sns/latest/dg/CreateTopic.html

        :param topic_name: - Identifier for the topicName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__372dddbfc823b08373295d671ab1c9c74e7f19e54eb9ab3ecdb773af8e272d85)
            check_type(argname="argument topic_name", value=topic_name, expected_type=type_hints["topic_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Sns", jsii.invoke(self, "onTopic", [topic_name, account, region, partition]))

    @jsii.member(jsii_name="toAddPermission")
    def to_add_permission(self) -> "Sns":
        '''(experimental) Grants permission to add a statement to a topic's access control policy, granting access for the specified AWS accounts to the specified actions.

        Access Level: Permissions management

        https://docs.aws.amazon.com/sns/latest/api/API_AddPermission.html

        :stability: experimental
        '''
        return typing.cast("Sns", jsii.invoke(self, "toAddPermission", []))

    @jsii.member(jsii_name="toCheckIfPhoneNumberIsOptedOut")
    def to_check_if_phone_number_is_opted_out(self) -> "Sns":
        '''(experimental) Grants permission to accept a phone number and indicate whether the phone holder has opted out of receiving SMS messages from your account.

        Access Level: Read

        https://docs.aws.amazon.com/sns/latest/api/API_CheckIfPhoneNumberIsOptedOut.html

        :stability: experimental
        '''
        return typing.cast("Sns", jsii.invoke(self, "toCheckIfPhoneNumberIsOptedOut", []))

    @jsii.member(jsii_name="toConfirmSubscription")
    def to_confirm_subscription(self) -> "Sns":
        '''(experimental) Grants permission to verify an endpoint owner's intent to receive messages by validating the token sent to the endpoint by an earlier Subscribe action.

        Access Level: Write

        https://docs.aws.amazon.com/sns/latest/api/API_ConfirmSubscription.html

        :stability: experimental
        '''
        return typing.cast("Sns", jsii.invoke(self, "toConfirmSubscription", []))

    @jsii.member(jsii_name="toCreatePlatformApplication")
    def to_create_platform_application(self) -> "Sns":
        '''(experimental) Grants permission to create a platform application object for one of the supported push notification services, such as APNS and GCM, to which devices and mobile apps may register.

        Access Level: Write

        Dependent actions:

        - iam:PassRole

        https://docs.aws.amazon.com/sns/latest/api/API_CreatePlatformApplication.html

        :stability: experimental
        '''
        return typing.cast("Sns", jsii.invoke(self, "toCreatePlatformApplication", []))

    @jsii.member(jsii_name="toCreatePlatformEndpoint")
    def to_create_platform_endpoint(self) -> "Sns":
        '''(experimental) Grants permission to create an endpoint for a device and mobile app on one of the supported push notification services, such as GCM and APNS.

        Access Level: Write

        https://docs.aws.amazon.com/sns/latest/api/API_CreatePlatformEndpoint.html

        :stability: experimental
        '''
        return typing.cast("Sns", jsii.invoke(self, "toCreatePlatformEndpoint", []))

    @jsii.member(jsii_name="toCreateSMSSandboxPhoneNumber")
    def to_create_sms_sandbox_phone_number(self) -> "Sns":
        '''(experimental) Grants permission to add a destination phone number and send a one-time password (OTP) to that phone number for an AWS account.

        Access Level: Write

        https://docs.aws.amazon.com/sns/latest/api/API_CreateSMSSandboxPhoneNumber.html

        :stability: experimental
        '''
        return typing.cast("Sns", jsii.invoke(self, "toCreateSMSSandboxPhoneNumber", []))

    @jsii.member(jsii_name="toCreateTopic")
    def to_create_topic(self) -> "Sns":
        '''(experimental) Grants permission to create a topic to which notifications can be published.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - iam:PassRole

        https://docs.aws.amazon.com/sns/latest/api/API_CreateTopic.html

        :stability: experimental
        '''
        return typing.cast("Sns", jsii.invoke(self, "toCreateTopic", []))

    @jsii.member(jsii_name="toDeleteEndpoint")
    def to_delete_endpoint(self) -> "Sns":
        '''(experimental) Grants permission to delete the endpoint for a device and mobile app from Amazon SNS.

        Access Level: Write

        https://docs.aws.amazon.com/sns/latest/api/API_DeleteEndpoint.html

        :stability: experimental
        '''
        return typing.cast("Sns", jsii.invoke(self, "toDeleteEndpoint", []))

    @jsii.member(jsii_name="toDeletePlatformApplication")
    def to_delete_platform_application(self) -> "Sns":
        '''(experimental) Grants permission to delete a platform application object for one of the supported push notification services, such as APNS and GCM.

        Access Level: Write

        https://docs.aws.amazon.com/sns/latest/api/API_DeletePlatformApplication.html

        :stability: experimental
        '''
        return typing.cast("Sns", jsii.invoke(self, "toDeletePlatformApplication", []))

    @jsii.member(jsii_name="toDeleteSMSSandboxPhoneNumber")
    def to_delete_sms_sandbox_phone_number(self) -> "Sns":
        '''(experimental) Grants permission to delete an AWS account's verified or pending phone number.

        Access Level: Write

        https://docs.aws.amazon.com/sns/latest/api/API_DeleteSMSSandboxPhoneNumber.html

        :stability: experimental
        '''
        return typing.cast("Sns", jsii.invoke(self, "toDeleteSMSSandboxPhoneNumber", []))

    @jsii.member(jsii_name="toDeleteTopic")
    def to_delete_topic(self) -> "Sns":
        '''(experimental) Grants permission to delete a topic and all its subscriptions.

        Access Level: Write

        https://docs.aws.amazon.com/sns/latest/api/API_DeleteTopic.html

        :stability: experimental
        '''
        return typing.cast("Sns", jsii.invoke(self, "toDeleteTopic", []))

    @jsii.member(jsii_name="toGetDataProtectionPolicy")
    def to_get_data_protection_policy(self) -> "Sns":
        '''(experimental) Grants permission to return the data protection policy of the topic.

        Access Level: Read

        https://docs.aws.amazon.com/sns/latest/api/API_GetDataProtectionPolicy.html

        :stability: experimental
        '''
        return typing.cast("Sns", jsii.invoke(self, "toGetDataProtectionPolicy", []))

    @jsii.member(jsii_name="toGetEndpointAttributes")
    def to_get_endpoint_attributes(self) -> "Sns":
        '''(experimental) Grants permission to retrieve the endpoint attributes for a device on one of the supported push notification services, such as GCM and APNS.

        Access Level: Read

        https://docs.aws.amazon.com/sns/latest/api/API_GetEndpointAttributes.html

        :stability: experimental
        '''
        return typing.cast("Sns", jsii.invoke(self, "toGetEndpointAttributes", []))

    @jsii.member(jsii_name="toGetPlatformApplicationAttributes")
    def to_get_platform_application_attributes(self) -> "Sns":
        '''(experimental) Grants permission to retrieve the attributes of the platform application object for the supported push notification services, such as APNS and GCM.

        Access Level: Read

        https://docs.aws.amazon.com/sns/latest/api/API_GetPlatformApplicationAttributes.html

        :stability: experimental
        '''
        return typing.cast("Sns", jsii.invoke(self, "toGetPlatformApplicationAttributes", []))

    @jsii.member(jsii_name="toGetSMSAttributes")
    def to_get_sms_attributes(self) -> "Sns":
        '''(experimental) Grants permission to return the settings for sending SMS messages from your account.

        Access Level: Read

        https://docs.aws.amazon.com/sns/latest/api/API_GetSMSAttributes.html

        :stability: experimental
        '''
        return typing.cast("Sns", jsii.invoke(self, "toGetSMSAttributes", []))

    @jsii.member(jsii_name="toGetSMSSandboxAccountStatus")
    def to_get_sms_sandbox_account_status(self) -> "Sns":
        '''(experimental) Grants permission to retrieve the sandbox status for the calling account in the target region.

        Access Level: Read

        https://docs.aws.amazon.com/sns/latest/api/API_GetSMSSandboxAccountStatus.html

        :stability: experimental
        '''
        return typing.cast("Sns", jsii.invoke(self, "toGetSMSSandboxAccountStatus", []))

    @jsii.member(jsii_name="toGetSubscriptionAttributes")
    def to_get_subscription_attributes(self) -> "Sns":
        '''(experimental) Grants permission to return all of the properties of a subscription.

        Access Level: Read

        https://docs.aws.amazon.com/sns/latest/api/API_GetSubscriptionAttributes.html

        :stability: experimental
        '''
        return typing.cast("Sns", jsii.invoke(self, "toGetSubscriptionAttributes", []))

    @jsii.member(jsii_name="toGetTopicAttributes")
    def to_get_topic_attributes(self) -> "Sns":
        '''(experimental) Grants permission to return all of the properties of a topic.

        Access Level: Read

        https://docs.aws.amazon.com/sns/latest/api/API_GetTopicAttributes.html

        :stability: experimental
        '''
        return typing.cast("Sns", jsii.invoke(self, "toGetTopicAttributes", []))

    @jsii.member(jsii_name="toListEndpointsByPlatformApplication")
    def to_list_endpoints_by_platform_application(self) -> "Sns":
        '''(experimental) Grants permission to list the endpoints and endpoint attributes for devices in a supported push notification service, such as GCM and APNS.

        Access Level: List

        https://docs.aws.amazon.com/sns/latest/api/API_ListEndpointsByPlatformApplication.html

        :stability: experimental
        '''
        return typing.cast("Sns", jsii.invoke(self, "toListEndpointsByPlatformApplication", []))

    @jsii.member(jsii_name="toListOriginationNumbers")
    def to_list_origination_numbers(self) -> "Sns":
        '''(experimental) Grants permission to list all origination numbers, and their metadata.

        Access Level: List

        https://docs.aws.amazon.com/sns/latest/api/API_ListOriginationNumbers.html

        :stability: experimental
        '''
        return typing.cast("Sns", jsii.invoke(self, "toListOriginationNumbers", []))

    @jsii.member(jsii_name="toListPhoneNumbersOptedOut")
    def to_list_phone_numbers_opted_out(self) -> "Sns":
        '''(experimental) Grants permission to return a list of phone numbers that are opted out, meaning you cannot send SMS messages to them.

        Access Level: Read

        https://docs.aws.amazon.com/sns/latest/api/API_ListPhoneNumbersOptedOut.html

        :stability: experimental
        '''
        return typing.cast("Sns", jsii.invoke(self, "toListPhoneNumbersOptedOut", []))

    @jsii.member(jsii_name="toListPlatformApplications")
    def to_list_platform_applications(self) -> "Sns":
        '''(experimental) Grants permission to list the platform application objects for the supported push notification services, such as APNS and GCM.

        Access Level: List

        https://docs.aws.amazon.com/sns/latest/api/API_ListPlatformApplications.html

        :stability: experimental
        '''
        return typing.cast("Sns", jsii.invoke(self, "toListPlatformApplications", []))

    @jsii.member(jsii_name="toListSMSSandboxPhoneNumbers")
    def to_list_sms_sandbox_phone_numbers(self) -> "Sns":
        '''(experimental) Grants permission to list the calling account's current pending and verified destination phone numbers.

        Access Level: List

        https://docs.aws.amazon.com/sns/latest/api/API_ListSMSSandboxPhoneNumbers.html

        :stability: experimental
        '''
        return typing.cast("Sns", jsii.invoke(self, "toListSMSSandboxPhoneNumbers", []))

    @jsii.member(jsii_name="toListSubscriptions")
    def to_list_subscriptions(self) -> "Sns":
        '''(experimental) Grants permission to return a list of the requester's subscriptions.

        Access Level: List

        https://docs.aws.amazon.com/sns/latest/api/API_ListSubscriptions.html

        :stability: experimental
        '''
        return typing.cast("Sns", jsii.invoke(self, "toListSubscriptions", []))

    @jsii.member(jsii_name="toListSubscriptionsByTopic")
    def to_list_subscriptions_by_topic(self) -> "Sns":
        '''(experimental) Grants permission to return a list of the subscriptions to a specific topic.

        Access Level: List

        https://docs.aws.amazon.com/sns/latest/api/API_ListSubscriptionsByTopic.html

        :stability: experimental
        '''
        return typing.cast("Sns", jsii.invoke(self, "toListSubscriptionsByTopic", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Sns":
        '''(experimental) Grants permission to list all tags added to the specified Amazon SNS topic.

        Access Level: Read

        https://docs.aws.amazon.com/sns/latest/api/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("Sns", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toListTopics")
    def to_list_topics(self) -> "Sns":
        '''(experimental) Grants permission to return a list of the requester's topics.

        Access Level: List

        https://docs.aws.amazon.com/sns/latest/api/API_ListTopics.html

        :stability: experimental
        '''
        return typing.cast("Sns", jsii.invoke(self, "toListTopics", []))

    @jsii.member(jsii_name="toOptInPhoneNumber")
    def to_opt_in_phone_number(self) -> "Sns":
        '''(experimental) Grants permission to opt in a phone number that is currently opted out, which enables you to resume sending SMS messages to the number.

        Access Level: Write

        https://docs.aws.amazon.com/sns/latest/api/API_OptInPhoneNumber.html

        :stability: experimental
        '''
        return typing.cast("Sns", jsii.invoke(self, "toOptInPhoneNumber", []))

    @jsii.member(jsii_name="toPublish")
    def to_publish(self) -> "Sns":
        '''(experimental) Grants permission to send a message to all of a topic's subscribed endpoints.

        Access Level: Write

        https://docs.aws.amazon.com/sns/latest/api/API_Publish.html

        :stability: experimental
        '''
        return typing.cast("Sns", jsii.invoke(self, "toPublish", []))

    @jsii.member(jsii_name="toPutDataProtectionPolicy")
    def to_put_data_protection_policy(self) -> "Sns":
        '''(experimental) Grants permission to allow a topic owner to set the data protection policy.

        Access Level: Write

        https://docs.aws.amazon.com/sns/latest/api/API_PutDataProtectionPolicy.html

        :stability: experimental
        '''
        return typing.cast("Sns", jsii.invoke(self, "toPutDataProtectionPolicy", []))

    @jsii.member(jsii_name="toRemovePermission")
    def to_remove_permission(self) -> "Sns":
        '''(experimental) Grants permission to remove a statement from a topic's access control policy.

        Access Level: Permissions management

        https://docs.aws.amazon.com/sns/latest/api/API_RemovePermission.html

        :stability: experimental
        '''
        return typing.cast("Sns", jsii.invoke(self, "toRemovePermission", []))

    @jsii.member(jsii_name="toSetEndpointAttributes")
    def to_set_endpoint_attributes(self) -> "Sns":
        '''(experimental) Grants permission to set the attributes for an endpoint for a device on one of the supported push notification services, such as GCM and APNS.

        Access Level: Write

        https://docs.aws.amazon.com/sns/latest/api/API_SetEndpointAttributes.html

        :stability: experimental
        '''
        return typing.cast("Sns", jsii.invoke(self, "toSetEndpointAttributes", []))

    @jsii.member(jsii_name="toSetPlatformApplicationAttributes")
    def to_set_platform_application_attributes(self) -> "Sns":
        '''(experimental) Grants permission to set the attributes of the platform application object for the supported push notification services, such as APNS and GCM.

        Access Level: Write

        Dependent actions:

        - iam:PassRole

        https://docs.aws.amazon.com/sns/latest/api/API_SetPlatformApplicationAttributes.html

        :stability: experimental
        '''
        return typing.cast("Sns", jsii.invoke(self, "toSetPlatformApplicationAttributes", []))

    @jsii.member(jsii_name="toSetSMSAttributes")
    def to_set_sms_attributes(self) -> "Sns":
        '''(experimental) Grants permission to set the default settings for sending SMS messages and receiving daily SMS usage reports.

        Access Level: Write

        https://docs.aws.amazon.com/sns/latest/api/API_SetSMSAttributes.html

        :stability: experimental
        '''
        return typing.cast("Sns", jsii.invoke(self, "toSetSMSAttributes", []))

    @jsii.member(jsii_name="toSetSubscriptionAttributes")
    def to_set_subscription_attributes(self) -> "Sns":
        '''(experimental) Grants permission to allow a subscription owner to set an attribute of the topic to a new value.

        Access Level: Write

        https://docs.aws.amazon.com/sns/latest/api/API_SetSubscriptionAttributes.html

        :stability: experimental
        '''
        return typing.cast("Sns", jsii.invoke(self, "toSetSubscriptionAttributes", []))

    @jsii.member(jsii_name="toSetTopicAttributes")
    def to_set_topic_attributes(self) -> "Sns":
        '''(experimental) Grants permission to allow a topic owner to set an attribute of the topic to a new value.

        Access Level: Permissions management

        Dependent actions:

        - iam:PassRole

        https://docs.aws.amazon.com/sns/latest/api/API_SetTopicAttributes.html

        :stability: experimental
        '''
        return typing.cast("Sns", jsii.invoke(self, "toSetTopicAttributes", []))

    @jsii.member(jsii_name="toSubscribe")
    def to_subscribe(self) -> "Sns":
        '''(experimental) Grants permission to prepare to subscribe an endpoint by sending the endpoint a confirmation message.

        Access Level: Write

        Possible conditions:

        - .ifEndpoint()
        - .ifProtocol()

        https://docs.aws.amazon.com/sns/latest/api/API_Subscribe.html

        :stability: experimental
        '''
        return typing.cast("Sns", jsii.invoke(self, "toSubscribe", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Sns":
        '''(experimental) Grants permission to add tags to the specified Amazon SNS topic.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/sns/latest/api/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("Sns", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUnsubscribe")
    def to_unsubscribe(self) -> "Sns":
        '''(experimental) Grants permission to delete a subscription.

        Access Level: Write

        https://docs.aws.amazon.com/sns/latest/api/API_Unsubscribe.html

        :stability: experimental
        '''
        return typing.cast("Sns", jsii.invoke(self, "toUnsubscribe", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Sns":
        '''(experimental) Grants permission to remove tags from the specified Amazon SNS topic.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/sns/latest/api/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("Sns", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toVerifySMSSandboxPhoneNumber")
    def to_verify_sms_sandbox_phone_number(self) -> "Sns":
        '''(experimental) Grants permission to verify a destination phone number with a one-time password (OTP) for an AWS account.

        Access Level: Write

        https://docs.aws.amazon.com/sns/latest/api/API_VerifySMSSandboxPhoneNumber.html

        :stability: experimental
        '''
        return typing.cast("Sns", jsii.invoke(self, "toVerifySMSSandboxPhoneNumber", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__cf1e89385bfae51ecccb35308d61d17e1f52bab24f8acdf273adfb8b4175550b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b3a9e8c49c4319f045770e135ca4890c031ca584371289a624e76900264a7783)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Sqlworkbench(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Sqlworkbench",
):
    '''(experimental) Statement provider for service `sqlworkbench <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awssqlworkbench.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `sqlworkbench <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awssqlworkbench.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onChart")
    def on_chart(
        self,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Sqlworkbench":
        '''(experimental) Adds a resource of type chart to the statement.

        https://docs.aws.amazon.com/redshift/latest/mgmt/query-editor-v2.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__307bedf56a508d015807ea5592309cc0048629a2f16412887b62e94e416dc870)
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Sqlworkbench", jsii.invoke(self, "onChart", [resource_id, account, region, partition]))

    @jsii.member(jsii_name="onConnection")
    def on_connection(
        self,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Sqlworkbench":
        '''(experimental) Adds a resource of type connection to the statement.

        https://docs.aws.amazon.com/redshift/latest/mgmt/query-editor-v2.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__17eb2ba9fea790b7f15d0ea82ef40da0bf0a003d80e8fdf1b5d5ed4886a4f293)
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Sqlworkbench", jsii.invoke(self, "onConnection", [resource_id, account, region, partition]))

    @jsii.member(jsii_name="onNotebook")
    def on_notebook(
        self,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Sqlworkbench":
        '''(experimental) Adds a resource of type notebook to the statement.

        https://docs.aws.amazon.com/redshift/latest/mgmt/query-editor-v2.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__386930d738d50856cb0e4eaf306064046b178ae3f48c1b1882a20e148f26e317)
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Sqlworkbench", jsii.invoke(self, "onNotebook", [resource_id, account, region, partition]))

    @jsii.member(jsii_name="onQuery")
    def on_query(
        self,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Sqlworkbench":
        '''(experimental) Adds a resource of type query to the statement.

        https://docs.aws.amazon.com/redshift/latest/mgmt/query-editor-v2.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e671b20ed0a690b4a05021fa68616fd6e21623e251d3494b6c2c9105f91145c2)
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Sqlworkbench", jsii.invoke(self, "onQuery", [resource_id, account, region, partition]))

    @jsii.member(jsii_name="toAssociateConnectionWithChart")
    def to_associate_connection_with_chart(self) -> "Sqlworkbench":
        '''(experimental) Grants permission to associate connection to a chart.

        Access Level: Write

        https://docs.aws.amazon.com/redshift/latest/mgmt/redshift-policy-resources.resource-permissions.html

        :stability: experimental
        '''
        return typing.cast("Sqlworkbench", jsii.invoke(self, "toAssociateConnectionWithChart", []))

    @jsii.member(jsii_name="toAssociateConnectionWithTab")
    def to_associate_connection_with_tab(self) -> "Sqlworkbench":
        '''(experimental) Grants permission to associate connection to a tab.

        Access Level: Write

        https://docs.aws.amazon.com/redshift/latest/mgmt/redshift-policy-resources.resource-permissions.html

        :stability: experimental
        '''
        return typing.cast("Sqlworkbench", jsii.invoke(self, "toAssociateConnectionWithTab", []))

    @jsii.member(jsii_name="toAssociateQueryWithTab")
    def to_associate_query_with_tab(self) -> "Sqlworkbench":
        '''(experimental) Grants permission to associate query to a tab.

        Access Level: Write

        https://docs.aws.amazon.com/redshift/latest/mgmt/redshift-policy-resources.resource-permissions.html

        :stability: experimental
        '''
        return typing.cast("Sqlworkbench", jsii.invoke(self, "toAssociateQueryWithTab", []))

    @jsii.member(jsii_name="toBatchDeleteFolder")
    def to_batch_delete_folder(self) -> "Sqlworkbench":
        '''(experimental) Grants permission to delete folders on your account.

        Access Level: Write

        https://docs.aws.amazon.com/redshift/latest/mgmt/redshift-policy-resources.resource-permissions.html

        :stability: experimental
        '''
        return typing.cast("Sqlworkbench", jsii.invoke(self, "toBatchDeleteFolder", []))

    @jsii.member(jsii_name="toBatchGetNotebookCell")
    def to_batch_get_notebook_cell(self) -> "Sqlworkbench":
        '''(experimental) Grants permission to get notebook cells content on your account.

        Access Level: Read

        https://docs.aws.amazon.com/redshift/latest/mgmt/redshift-policy-resources.resource-permissions.html

        :stability: experimental
        '''
        return typing.cast("Sqlworkbench", jsii.invoke(self, "toBatchGetNotebookCell", []))

    @jsii.member(jsii_name="toCreateAccount")
    def to_create_account(self) -> "Sqlworkbench":
        '''(experimental) Grants permission to create SQLWorkbench account.

        Access Level: Write

        https://docs.aws.amazon.com/redshift/latest/mgmt/redshift-policy-resources.resource-permissions.html

        :stability: experimental
        '''
        return typing.cast("Sqlworkbench", jsii.invoke(self, "toCreateAccount", []))

    @jsii.member(jsii_name="toCreateChart")
    def to_create_chart(self) -> "Sqlworkbench":
        '''(experimental) Grants permission to create new saved chart on your account.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/redshift/latest/mgmt/redshift-policy-resources.resource-permissions.html

        :stability: experimental
        '''
        return typing.cast("Sqlworkbench", jsii.invoke(self, "toCreateChart", []))

    @jsii.member(jsii_name="toCreateConnection")
    def to_create_connection(self) -> "Sqlworkbench":
        '''(experimental) Grants permission to create a new connection on your account.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/redshift/latest/mgmt/redshift-policy-resources.resource-permissions.html

        :stability: experimental
        '''
        return typing.cast("Sqlworkbench", jsii.invoke(self, "toCreateConnection", []))

    @jsii.member(jsii_name="toCreateFolder")
    def to_create_folder(self) -> "Sqlworkbench":
        '''(experimental) Grants permission to create folder on your account.

        Access Level: Write

        https://docs.aws.amazon.com/redshift/latest/mgmt/redshift-policy-resources.resource-permissions.html

        :stability: experimental
        '''
        return typing.cast("Sqlworkbench", jsii.invoke(self, "toCreateFolder", []))

    @jsii.member(jsii_name="toCreateNotebook")
    def to_create_notebook(self) -> "Sqlworkbench":
        '''(experimental) Grants permission to create a new notebook on your account.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/redshift/latest/mgmt/redshift-policy-resources.resource-permissions.html

        :stability: experimental
        '''
        return typing.cast("Sqlworkbench", jsii.invoke(self, "toCreateNotebook", []))

    @jsii.member(jsii_name="toCreateNotebookCell")
    def to_create_notebook_cell(self) -> "Sqlworkbench":
        '''(experimental) Grants permission to create a notebook cell on your account.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/redshift/latest/mgmt/redshift-policy-resources.resource-permissions.html

        :stability: experimental
        '''
        return typing.cast("Sqlworkbench", jsii.invoke(self, "toCreateNotebookCell", []))

    @jsii.member(jsii_name="toCreateNotebookFromVersion")
    def to_create_notebook_from_version(self) -> "Sqlworkbench":
        '''(experimental) Grants permission to create a new notebook from a notebook version on your account.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/redshift/latest/mgmt/redshift-policy-resources.resource-permissions.html

        :stability: experimental
        '''
        return typing.cast("Sqlworkbench", jsii.invoke(self, "toCreateNotebookFromVersion", []))

    @jsii.member(jsii_name="toCreateNotebookVersion")
    def to_create_notebook_version(self) -> "Sqlworkbench":
        '''(experimental) Grants permission to create a notebook version on your account.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/redshift/latest/mgmt/redshift-policy-resources.resource-permissions.html

        :stability: experimental
        '''
        return typing.cast("Sqlworkbench", jsii.invoke(self, "toCreateNotebookVersion", []))

    @jsii.member(jsii_name="toCreateSavedQuery")
    def to_create_saved_query(self) -> "Sqlworkbench":
        '''(experimental) Grants permission to create a new saved query on your account.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/redshift/latest/mgmt/redshift-policy-resources.resource-permissions.html

        :stability: experimental
        '''
        return typing.cast("Sqlworkbench", jsii.invoke(self, "toCreateSavedQuery", []))

    @jsii.member(jsii_name="toDeleteChart")
    def to_delete_chart(self) -> "Sqlworkbench":
        '''(experimental) Grants permission to remove charts on your account.

        Access Level: Write

        https://docs.aws.amazon.com/redshift/latest/mgmt/redshift-policy-resources.resource-permissions.html

        :stability: experimental
        '''
        return typing.cast("Sqlworkbench", jsii.invoke(self, "toDeleteChart", []))

    @jsii.member(jsii_name="toDeleteConnection")
    def to_delete_connection(self) -> "Sqlworkbench":
        '''(experimental) Grants permission to remove connections on your account.

        Access Level: Write

        https://docs.aws.amazon.com/redshift/latest/mgmt/redshift-policy-resources.resource-permissions.html

        :stability: experimental
        '''
        return typing.cast("Sqlworkbench", jsii.invoke(self, "toDeleteConnection", []))

    @jsii.member(jsii_name="toDeleteNotebook")
    def to_delete_notebook(self) -> "Sqlworkbench":
        '''(experimental) Grants permission to remove notebooks on your account.

        Access Level: Write

        https://docs.aws.amazon.com/redshift/latest/mgmt/redshift-policy-resources.resource-permissions.html

        :stability: experimental
        '''
        return typing.cast("Sqlworkbench", jsii.invoke(self, "toDeleteNotebook", []))

    @jsii.member(jsii_name="toDeleteNotebookCell")
    def to_delete_notebook_cell(self) -> "Sqlworkbench":
        '''(experimental) Grants permission to remove notebooks cells on your account.

        Access Level: Write

        https://docs.aws.amazon.com/redshift/latest/mgmt/redshift-policy-resources.resource-permissions.html

        :stability: experimental
        '''
        return typing.cast("Sqlworkbench", jsii.invoke(self, "toDeleteNotebookCell", []))

    @jsii.member(jsii_name="toDeleteNotebookVersion")
    def to_delete_notebook_version(self) -> "Sqlworkbench":
        '''(experimental) Grants permission to remove notebooks cells on your account.

        Access Level: Write

        https://docs.aws.amazon.com/redshift/latest/mgmt/redshift-policy-resources.resource-permissions.html

        :stability: experimental
        '''
        return typing.cast("Sqlworkbench", jsii.invoke(self, "toDeleteNotebookVersion", []))

    @jsii.member(jsii_name="toDeleteSavedQuery")
    def to_delete_saved_query(self) -> "Sqlworkbench":
        '''(experimental) Grants permission to remove saved queries on your account.

        Access Level: Write

        https://docs.aws.amazon.com/redshift/latest/mgmt/redshift-policy-resources.resource-permissions.html

        :stability: experimental
        '''
        return typing.cast("Sqlworkbench", jsii.invoke(self, "toDeleteSavedQuery", []))

    @jsii.member(jsii_name="toDeleteTab")
    def to_delete_tab(self) -> "Sqlworkbench":
        '''(experimental) Grants permission to remove a tab on your account.

        Access Level: Write

        https://docs.aws.amazon.com/redshift/latest/mgmt/redshift-policy-resources.resource-permissions.html

        :stability: experimental
        '''
        return typing.cast("Sqlworkbench", jsii.invoke(self, "toDeleteTab", []))

    @jsii.member(jsii_name="toDriverExecute")
    def to_driver_execute(self) -> "Sqlworkbench":
        '''(experimental) Grants permission to execute a query in your redshift cluster.

        Access Level: Write

        https://docs.aws.amazon.com/redshift/latest/mgmt/redshift-policy-resources.resource-permissions.html

        :stability: experimental
        '''
        return typing.cast("Sqlworkbench", jsii.invoke(self, "toDriverExecute", []))

    @jsii.member(jsii_name="toDuplicateNotebook")
    def to_duplicate_notebook(self) -> "Sqlworkbench":
        '''(experimental) Grants permission to create a new notebook by duplicating an existing one on your account.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/redshift/latest/mgmt/redshift-policy-resources.resource-permissions.html

        :stability: experimental
        '''
        return typing.cast("Sqlworkbench", jsii.invoke(self, "toDuplicateNotebook", []))

    @jsii.member(jsii_name="toExportNotebook")
    def to_export_notebook(self) -> "Sqlworkbench":
        '''(experimental) Grants permission to export a notebook on your account.

        Access Level: Read

        https://docs.aws.amazon.com/redshift/latest/mgmt/redshift-policy-resources.resource-permissions.html

        :stability: experimental
        '''
        return typing.cast("Sqlworkbench", jsii.invoke(self, "toExportNotebook", []))

    @jsii.member(jsii_name="toGenerateSession")
    def to_generate_session(self) -> "Sqlworkbench":
        '''(experimental) Grants permission to generate a new session on your account.

        Access Level: Write

        https://docs.aws.amazon.com/redshift/latest/mgmt/redshift-policy-resources.resource-permissions.html

        :stability: experimental
        '''
        return typing.cast("Sqlworkbench", jsii.invoke(self, "toGenerateSession", []))

    @jsii.member(jsii_name="toGetAccountInfo")
    def to_get_account_info(self) -> "Sqlworkbench":
        '''(experimental) Grants permission to get account info.

        Access Level: Read

        https://docs.aws.amazon.com/redshift/latest/mgmt/redshift-policy-resources.resource-permissions.html

        :stability: experimental
        '''
        return typing.cast("Sqlworkbench", jsii.invoke(self, "toGetAccountInfo", []))

    @jsii.member(jsii_name="toGetAccountSettings")
    def to_get_account_settings(self) -> "Sqlworkbench":
        '''(experimental) Grants permission to get account settings.

        Access Level: Read

        https://docs.aws.amazon.com/redshift/latest/mgmt/redshift-policy-resources.resource-permissions.html

        :stability: experimental
        '''
        return typing.cast("Sqlworkbench", jsii.invoke(self, "toGetAccountSettings", []))

    @jsii.member(jsii_name="toGetChart")
    def to_get_chart(self) -> "Sqlworkbench":
        '''(experimental) Grants permission to get charts on your account.

        Access Level: Read

        https://docs.aws.amazon.com/redshift/latest/mgmt/redshift-policy-resources.resource-permissions.html

        :stability: experimental
        '''
        return typing.cast("Sqlworkbench", jsii.invoke(self, "toGetChart", []))

    @jsii.member(jsii_name="toGetConnection")
    def to_get_connection(self) -> "Sqlworkbench":
        '''(experimental) Grants permission to get connections on your account.

        Access Level: Read

        https://docs.aws.amazon.com/redshift/latest/mgmt/redshift-policy-resources.resource-permissions.html

        :stability: experimental
        '''
        return typing.cast("Sqlworkbench", jsii.invoke(self, "toGetConnection", []))

    @jsii.member(jsii_name="toGetNotebook")
    def to_get_notebook(self) -> "Sqlworkbench":
        '''(experimental) Grants permission to get notebook metadata on your account.

        Access Level: Read

        https://docs.aws.amazon.com/redshift/latest/mgmt/redshift-policy-resources.resource-permissions.html

        :stability: experimental
        '''
        return typing.cast("Sqlworkbench", jsii.invoke(self, "toGetNotebook", []))

    @jsii.member(jsii_name="toGetNotebookVersion")
    def to_get_notebook_version(self) -> "Sqlworkbench":
        '''(experimental) Grants permission to get the content of a notebook version on your account.

        Access Level: Read

        https://docs.aws.amazon.com/redshift/latest/mgmt/redshift-policy-resources.resource-permissions.html

        :stability: experimental
        '''
        return typing.cast("Sqlworkbench", jsii.invoke(self, "toGetNotebookVersion", []))

    @jsii.member(jsii_name="toGetQueryExecutionHistory")
    def to_get_query_execution_history(self) -> "Sqlworkbench":
        '''(experimental) Grants permission to get the query execution history on your account.

        Access Level: Read

        https://docs.aws.amazon.com/redshift/latest/mgmt/redshift-policy-resources.resource-permissions.html

        :stability: experimental
        '''
        return typing.cast("Sqlworkbench", jsii.invoke(self, "toGetQueryExecutionHistory", []))

    @jsii.member(jsii_name="toGetSavedQuery")
    def to_get_saved_query(self) -> "Sqlworkbench":
        '''(experimental) Grants permission to get saved query on your account.

        Access Level: Read

        https://docs.aws.amazon.com/redshift/latest/mgmt/redshift-policy-resources.resource-permissions.html

        :stability: experimental
        '''
        return typing.cast("Sqlworkbench", jsii.invoke(self, "toGetSavedQuery", []))

    @jsii.member(jsii_name="toGetUserInfo")
    def to_get_user_info(self) -> "Sqlworkbench":
        '''(experimental) Grants permission to get user info.

        Access Level: Read

        https://docs.aws.amazon.com/redshift/latest/mgmt/redshift-policy-resources.resource-permissions.html

        :stability: experimental
        '''
        return typing.cast("Sqlworkbench", jsii.invoke(self, "toGetUserInfo", []))

    @jsii.member(jsii_name="toGetUserWorkspaceSettings")
    def to_get_user_workspace_settings(self) -> "Sqlworkbench":
        '''(experimental) Grants permission to get workspace settings on your account.

        Access Level: Read

        https://docs.aws.amazon.com/redshift/latest/mgmt/redshift-policy-resources.resource-permissions.html

        :stability: experimental
        '''
        return typing.cast("Sqlworkbench", jsii.invoke(self, "toGetUserWorkspaceSettings", []))

    @jsii.member(jsii_name="toImportNotebook")
    def to_import_notebook(self) -> "Sqlworkbench":
        '''(experimental) Grants permission to import a notebook on your account.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/redshift/latest/mgmt/redshift-policy-resources.resource-permissions.html

        :stability: experimental
        '''
        return typing.cast("Sqlworkbench", jsii.invoke(self, "toImportNotebook", []))

    @jsii.member(jsii_name="toListConnections")
    def to_list_connections(self) -> "Sqlworkbench":
        '''(experimental) Grants permission to list the connections on your account.

        Access Level: List

        https://docs.aws.amazon.com/redshift/latest/mgmt/redshift-policy-resources.resource-permissions.html

        :stability: experimental
        '''
        return typing.cast("Sqlworkbench", jsii.invoke(self, "toListConnections", []))

    @jsii.member(jsii_name="toListDatabases")
    def to_list_databases(self) -> "Sqlworkbench":
        '''(experimental) Grants permission to list databases of your redshift cluster.

        Access Level: List

        https://docs.aws.amazon.com/redshift/latest/mgmt/redshift-policy-resources.resource-permissions.html

        :stability: experimental
        '''
        return typing.cast("Sqlworkbench", jsii.invoke(self, "toListDatabases", []))

    @jsii.member(jsii_name="toListFiles")
    def to_list_files(self) -> "Sqlworkbench":
        '''(experimental) Grants permission to list files and folders.

        Access Level: List

        https://docs.aws.amazon.com/redshift/latest/mgmt/redshift-policy-resources.resource-permissions.html

        :stability: experimental
        '''
        return typing.cast("Sqlworkbench", jsii.invoke(self, "toListFiles", []))

    @jsii.member(jsii_name="toListNotebooks")
    def to_list_notebooks(self) -> "Sqlworkbench":
        '''(experimental) Grants permission to list the notebooks on your account.

        Access Level: List

        https://docs.aws.amazon.com/redshift/latest/mgmt/redshift-policy-resources.resource-permissions.html

        :stability: experimental
        '''
        return typing.cast("Sqlworkbench", jsii.invoke(self, "toListNotebooks", []))

    @jsii.member(jsii_name="toListNotebookVersions")
    def to_list_notebook_versions(self) -> "Sqlworkbench":
        '''(experimental) Grants permission to get notebook versions metadata on your account.

        Access Level: List

        https://docs.aws.amazon.com/redshift/latest/mgmt/redshift-policy-resources.resource-permissions.html

        :stability: experimental
        '''
        return typing.cast("Sqlworkbench", jsii.invoke(self, "toListNotebookVersions", []))

    @jsii.member(jsii_name="toListQueryExecutionHistory")
    def to_list_query_execution_history(self) -> "Sqlworkbench":
        '''(experimental) Grants permission to list the query execution history on your account.

        Access Level: List

        https://docs.aws.amazon.com/redshift/latest/mgmt/redshift-policy-resources.resource-permissions.html

        :stability: experimental
        '''
        return typing.cast("Sqlworkbench", jsii.invoke(self, "toListQueryExecutionHistory", []))

    @jsii.member(jsii_name="toListRedshiftClusters")
    def to_list_redshift_clusters(self) -> "Sqlworkbench":
        '''(experimental) Grants permission to list redshift clusters on your account.

        Access Level: List

        https://docs.aws.amazon.com/redshift/latest/mgmt/redshift-policy-resources.resource-permissions.html

        :stability: experimental
        '''
        return typing.cast("Sqlworkbench", jsii.invoke(self, "toListRedshiftClusters", []))

    @jsii.member(jsii_name="toListSampleDatabases")
    def to_list_sample_databases(self) -> "Sqlworkbench":
        '''(experimental) Grants permission to list sample databases.

        Access Level: Read

        https://docs.aws.amazon.com/redshift/latest/mgmt/redshift-policy-resources.resource-permissions.html

        :stability: experimental
        '''
        return typing.cast("Sqlworkbench", jsii.invoke(self, "toListSampleDatabases", []))

    @jsii.member(jsii_name="toListSavedQueryVersions")
    def to_list_saved_query_versions(self) -> "Sqlworkbench":
        '''(experimental) Grants permission to list versions of saved query on your account.

        Access Level: List

        https://docs.aws.amazon.com/redshift/latest/mgmt/redshift-policy-resources.resource-permissions.html

        :stability: experimental
        '''
        return typing.cast("Sqlworkbench", jsii.invoke(self, "toListSavedQueryVersions", []))

    @jsii.member(jsii_name="toListTabs")
    def to_list_tabs(self) -> "Sqlworkbench":
        '''(experimental) Grants permission to list tabs on your account.

        Access Level: List

        https://docs.aws.amazon.com/redshift/latest/mgmt/redshift-policy-resources.resource-permissions.html

        :stability: experimental
        '''
        return typing.cast("Sqlworkbench", jsii.invoke(self, "toListTabs", []))

    @jsii.member(jsii_name="toListTaggedResources")
    def to_list_tagged_resources(self) -> "Sqlworkbench":
        '''(experimental) Grants permission to list tagged resources.

        Access Level: Read

        https://docs.aws.amazon.com/redshift/latest/mgmt/redshift-policy-resources.resource-permissions.html

        :stability: experimental
        '''
        return typing.cast("Sqlworkbench", jsii.invoke(self, "toListTaggedResources", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Sqlworkbench":
        '''(experimental) Grants permission to list the tags of an sqlworkbench resource.

        Access Level: Read

        https://docs.aws.amazon.com/redshift/latest/mgmt/redshift-policy-resources.resource-permissions.html

        :stability: experimental
        '''
        return typing.cast("Sqlworkbench", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toPutTab")
    def to_put_tab(self) -> "Sqlworkbench":
        '''(experimental) Grants permission to create or update a tab on your account.

        Access Level: Write

        https://docs.aws.amazon.com/redshift/latest/mgmt/redshift-policy-resources.resource-permissions.html

        :stability: experimental
        '''
        return typing.cast("Sqlworkbench", jsii.invoke(self, "toPutTab", []))

    @jsii.member(jsii_name="toPutUserWorkspaceSettings")
    def to_put_user_workspace_settings(self) -> "Sqlworkbench":
        '''(experimental) Grants permission to update workspace settings on your account.

        Access Level: Write

        https://docs.aws.amazon.com/redshift/latest/mgmt/redshift-policy-resources.resource-permissions.html

        :stability: experimental
        '''
        return typing.cast("Sqlworkbench", jsii.invoke(self, "toPutUserWorkspaceSettings", []))

    @jsii.member(jsii_name="toRestoreNotebookVersion")
    def to_restore_notebook_version(self) -> "Sqlworkbench":
        '''(experimental) Grants permission to restore a notebook on your account to a version.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/redshift/latest/mgmt/redshift-policy-resources.resource-permissions.html

        :stability: experimental
        '''
        return typing.cast("Sqlworkbench", jsii.invoke(self, "toRestoreNotebookVersion", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Sqlworkbench":
        '''(experimental) Grants permission to tag an sqlworkbench resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/redshift/latest/mgmt/redshift-policy-resources.resource-permissions.html

        :stability: experimental
        '''
        return typing.cast("Sqlworkbench", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Sqlworkbench":
        '''(experimental) Grants permission to untag an sqlworkbench resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/redshift/latest/mgmt/redshift-policy-resources.resource-permissions.html

        :stability: experimental
        '''
        return typing.cast("Sqlworkbench", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateAccountConnectionSettings")
    def to_update_account_connection_settings(self) -> "Sqlworkbench":
        '''(experimental) Grants permission to update account-wide connection settings.

        Access Level: Write

        https://docs.aws.amazon.com/redshift/latest/mgmt/redshift-policy-resources.resource-permissions.html

        :stability: experimental
        '''
        return typing.cast("Sqlworkbench", jsii.invoke(self, "toUpdateAccountConnectionSettings", []))

    @jsii.member(jsii_name="toUpdateAccountExportSettings")
    def to_update_account_export_settings(self) -> "Sqlworkbench":
        '''(experimental) Grants permission to update account-wide export settings.

        Access Level: Write

        https://docs.aws.amazon.com/redshift/latest/mgmt/redshift-policy-resources.resource-permissions.html

        :stability: experimental
        '''
        return typing.cast("Sqlworkbench", jsii.invoke(self, "toUpdateAccountExportSettings", []))

    @jsii.member(jsii_name="toUpdateAccountGeneralSettings")
    def to_update_account_general_settings(self) -> "Sqlworkbench":
        '''(experimental) Grants permission to update account-wide general settings.

        Access Level: Write

        https://docs.aws.amazon.com/redshift/latest/mgmt/redshift-policy-resources.resource-permissions.html

        :stability: experimental
        '''
        return typing.cast("Sqlworkbench", jsii.invoke(self, "toUpdateAccountGeneralSettings", []))

    @jsii.member(jsii_name="toUpdateChart")
    def to_update_chart(self) -> "Sqlworkbench":
        '''(experimental) Grants permission to update a chart on your account.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/redshift/latest/mgmt/redshift-policy-resources.resource-permissions.html

        :stability: experimental
        '''
        return typing.cast("Sqlworkbench", jsii.invoke(self, "toUpdateChart", []))

    @jsii.member(jsii_name="toUpdateConnection")
    def to_update_connection(self) -> "Sqlworkbench":
        '''(experimental) Grants permission to update a connection on your account.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/redshift/latest/mgmt/redshift-policy-resources.resource-permissions.html

        :stability: experimental
        '''
        return typing.cast("Sqlworkbench", jsii.invoke(self, "toUpdateConnection", []))

    @jsii.member(jsii_name="toUpdateFileFolder")
    def to_update_file_folder(self) -> "Sqlworkbench":
        '''(experimental) Grants permission to move files on your account.

        Access Level: Write

        https://docs.aws.amazon.com/redshift/latest/mgmt/redshift-policy-resources.resource-permissions.html

        :stability: experimental
        '''
        return typing.cast("Sqlworkbench", jsii.invoke(self, "toUpdateFileFolder", []))

    @jsii.member(jsii_name="toUpdateFolder")
    def to_update_folder(self) -> "Sqlworkbench":
        '''(experimental) Grants permission to update a folder's name and details on your account.

        Access Level: Write

        https://docs.aws.amazon.com/redshift/latest/mgmt/redshift-policy-resources.resource-permissions.html

        :stability: experimental
        '''
        return typing.cast("Sqlworkbench", jsii.invoke(self, "toUpdateFolder", []))

    @jsii.member(jsii_name="toUpdateNotebook")
    def to_update_notebook(self) -> "Sqlworkbench":
        '''(experimental) Grants permission to update a notebook metadata on your account.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/redshift/latest/mgmt/redshift-policy-resources.resource-permissions.html

        :stability: experimental
        '''
        return typing.cast("Sqlworkbench", jsii.invoke(self, "toUpdateNotebook", []))

    @jsii.member(jsii_name="toUpdateNotebookCellContent")
    def to_update_notebook_cell_content(self) -> "Sqlworkbench":
        '''(experimental) Grants permission to update a notebook cell content on your account.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/redshift/latest/mgmt/redshift-policy-resources.resource-permissions.html

        :stability: experimental
        '''
        return typing.cast("Sqlworkbench", jsii.invoke(self, "toUpdateNotebookCellContent", []))

    @jsii.member(jsii_name="toUpdateNotebookCellLayout")
    def to_update_notebook_cell_layout(self) -> "Sqlworkbench":
        '''(experimental) Grants permission to update a notebook cell layout on your account.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/redshift/latest/mgmt/redshift-policy-resources.resource-permissions.html

        :stability: experimental
        '''
        return typing.cast("Sqlworkbench", jsii.invoke(self, "toUpdateNotebookCellLayout", []))

    @jsii.member(jsii_name="toUpdateSavedQuery")
    def to_update_saved_query(self) -> "Sqlworkbench":
        '''(experimental) Grants permission to update a saved query on your account.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/redshift/latest/mgmt/redshift-policy-resources.resource-permissions.html

        :stability: experimental
        '''
        return typing.cast("Sqlworkbench", jsii.invoke(self, "toUpdateSavedQuery", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__80daabbbd77d1e438b1e8155ba1a5fe88e4d56a630d39766636dd3a029bcb922)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__100ec1b9b86b7870842b4650a09c919f47d533b31d42b7086d222883ad8dce0f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Sqs(PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Sqs"):
    '''(experimental) Statement provider for service `sqs <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonsqs.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `sqs <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonsqs.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onQueue")
    def on_queue(
        self,
        queue_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Sqs":
        '''(experimental) Adds a resource of type queue to the statement.

        https://docs.aws.amazon.com/AWSSimpleQueueService/latest/SQSDeveloperGuide/sqs-queue-types.html

        :param queue_name: - Identifier for the queueName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__20996415c184829a62620e5aeeb881375bd12ffbf3f3181e367098ae1f35361e)
            check_type(argname="argument queue_name", value=queue_name, expected_type=type_hints["queue_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Sqs", jsii.invoke(self, "onQueue", [queue_name, account, region, partition]))

    @jsii.member(jsii_name="toAddPermission")
    def to_add_permission(self) -> "Sqs":
        '''(experimental) Grants permission to a queue for a specific principal.

        Access Level: Permissions management

        https://docs.aws.amazon.com/AWSSimpleQueueService/latest/APIReference/API_AddPermission.html

        :stability: experimental
        '''
        return typing.cast("Sqs", jsii.invoke(self, "toAddPermission", []))

    @jsii.member(jsii_name="toChangeMessageVisibility")
    def to_change_message_visibility(self) -> "Sqs":
        '''(experimental) Grants permission to change the visibility timeout of a specified message in a queue to a new value.

        Access Level: Write

        https://docs.aws.amazon.com/AWSSimpleQueueService/latest/APIReference/API_ChangeMessageVisibility.html

        :stability: experimental
        '''
        return typing.cast("Sqs", jsii.invoke(self, "toChangeMessageVisibility", []))

    @jsii.member(jsii_name="toCreateQueue")
    def to_create_queue(self) -> "Sqs":
        '''(experimental) Grants permission to create a new queue, or returns the URL of an existing one.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/AWSSimpleQueueService/latest/APIReference/API_CreateQueue.html

        :stability: experimental
        '''
        return typing.cast("Sqs", jsii.invoke(self, "toCreateQueue", []))

    @jsii.member(jsii_name="toDeleteMessage")
    def to_delete_message(self) -> "Sqs":
        '''(experimental) Grants permission to delete the specified message from the specified queue.

        Access Level: Write

        https://docs.aws.amazon.com/AWSSimpleQueueService/latest/APIReference/API_DeleteMessage.html

        :stability: experimental
        '''
        return typing.cast("Sqs", jsii.invoke(self, "toDeleteMessage", []))

    @jsii.member(jsii_name="toDeleteQueue")
    def to_delete_queue(self) -> "Sqs":
        '''(experimental) Grants permission to delete the queue specified by the queue URL, regardless of whether the queue is empty.

        Access Level: Write

        https://docs.aws.amazon.com/AWSSimpleQueueService/latest/APIReference/API_DeleteQueue.html

        :stability: experimental
        '''
        return typing.cast("Sqs", jsii.invoke(self, "toDeleteQueue", []))

    @jsii.member(jsii_name="toGetQueueAttributes")
    def to_get_queue_attributes(self) -> "Sqs":
        '''(experimental) Grants permission to get attributes for the specified queue.

        Access Level: Read

        https://docs.aws.amazon.com/AWSSimpleQueueService/latest/APIReference/API_GetQueueAttributes.html

        :stability: experimental
        '''
        return typing.cast("Sqs", jsii.invoke(self, "toGetQueueAttributes", []))

    @jsii.member(jsii_name="toGetQueueUrl")
    def to_get_queue_url(self) -> "Sqs":
        '''(experimental) Grants permission to return the URL of an existing queue.

        Access Level: Read

        https://docs.aws.amazon.com/AWSSimpleQueueService/latest/APIReference/API_GetQueueUrl.html

        :stability: experimental
        '''
        return typing.cast("Sqs", jsii.invoke(self, "toGetQueueUrl", []))

    @jsii.member(jsii_name="toListDeadLetterSourceQueues")
    def to_list_dead_letter_source_queues(self) -> "Sqs":
        '''(experimental) Grants permission to return a list of your queues that have the RedrivePolicy queue attribute configured with a dead letter queue.

        Access Level: Read

        https://docs.aws.amazon.com/AWSSimpleQueueService/latest/APIReference/API_ListDeadLetterSourceQueues.html

        :stability: experimental
        '''
        return typing.cast("Sqs", jsii.invoke(self, "toListDeadLetterSourceQueues", []))

    @jsii.member(jsii_name="toListQueues")
    def to_list_queues(self) -> "Sqs":
        '''(experimental) Grants permission to return a list of your queues.

        Access Level: Read

        https://docs.aws.amazon.com/AWSSimpleQueueService/latest/APIReference/API_ListQueues.html

        :stability: experimental
        '''
        return typing.cast("Sqs", jsii.invoke(self, "toListQueues", []))

    @jsii.member(jsii_name="toListQueueTags")
    def to_list_queue_tags(self) -> "Sqs":
        '''(experimental) Grants permission to list tags added to an SQS queue.

        Access Level: Read

        https://docs.aws.amazon.com/AWSSimpleQueueService/latest/APIReference/API_ListQueueTags.html

        :stability: experimental
        '''
        return typing.cast("Sqs", jsii.invoke(self, "toListQueueTags", []))

    @jsii.member(jsii_name="toPurgeQueue")
    def to_purge_queue(self) -> "Sqs":
        '''(experimental) Grants permission to delete the messages in a queue specified by the queue URL.

        Access Level: Write

        https://docs.aws.amazon.com/AWSSimpleQueueService/latest/APIReference/API_PurgeQueue.html

        :stability: experimental
        '''
        return typing.cast("Sqs", jsii.invoke(self, "toPurgeQueue", []))

    @jsii.member(jsii_name="toReceiveMessage")
    def to_receive_message(self) -> "Sqs":
        '''(experimental) Grants permission to retrieve one or more messages, with a maximum limit of 10 messages, from the specified queue.

        Access Level: Read

        https://docs.aws.amazon.com/AWSSimpleQueueService/latest/APIReference/API_ReceiveMessage.html

        :stability: experimental
        '''
        return typing.cast("Sqs", jsii.invoke(self, "toReceiveMessage", []))

    @jsii.member(jsii_name="toRemovePermission")
    def to_remove_permission(self) -> "Sqs":
        '''(experimental) Grants permission to revoke any permissions in the queue policy that matches the specified Label parameter.

        Access Level: Permissions management

        https://docs.aws.amazon.com/AWSSimpleQueueService/latest/APIReference/API_RemovePermission.html

        :stability: experimental
        '''
        return typing.cast("Sqs", jsii.invoke(self, "toRemovePermission", []))

    @jsii.member(jsii_name="toSendMessage")
    def to_send_message(self) -> "Sqs":
        '''(experimental) Grants permission to deliver a message to the specified queue.

        Access Level: Write

        https://docs.aws.amazon.com/AWSSimpleQueueService/latest/APIReference/API_SendMessage.html

        :stability: experimental
        '''
        return typing.cast("Sqs", jsii.invoke(self, "toSendMessage", []))

    @jsii.member(jsii_name="toSetQueueAttributes")
    def to_set_queue_attributes(self) -> "Sqs":
        '''(experimental) Grants permission to set the value of one or more queue attributes.

        Access Level: Write

        https://docs.aws.amazon.com/AWSSimpleQueueService/latest/APIReference/API_SetQueueAttributes.html

        :stability: experimental
        '''
        return typing.cast("Sqs", jsii.invoke(self, "toSetQueueAttributes", []))

    @jsii.member(jsii_name="toTagQueue")
    def to_tag_queue(self) -> "Sqs":
        '''(experimental) Grants permission to add tags to the specified SQS queue.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/AWSSimpleQueueService/latest/APIReference/API_TagQueue.html

        :stability: experimental
        '''
        return typing.cast("Sqs", jsii.invoke(self, "toTagQueue", []))

    @jsii.member(jsii_name="toUntagQueue")
    def to_untag_queue(self) -> "Sqs":
        '''(experimental) Grants permission to remove tags from the specified SQS queue.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/AWSSimpleQueueService/latest/APIReference/API_UntagQueue.html

        :stability: experimental
        '''
        return typing.cast("Sqs", jsii.invoke(self, "toUntagQueue", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5952b77f830ca1cf438ecdda0bb5965d129e42e7d01c4cfc6fb22ade605e3c5b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4c2287fd3a2092de8e73aa8188fdc927ecdac9bd038ff92f58f34edd123d5f68)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Ssm(PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Ssm"):
    '''(experimental) Statement provider for service `ssm <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awssystemsmanager.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `ssm <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awssystemsmanager.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="ifAutoApprove")
    def if_auto_approve(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Ssm":
        '''(experimental) Filters access by verifying that a user has permission to start Change Manager workflows without a review step (with the exception of change freeze events).

        https://docs.aws.amazon.com/systems-manager/latest/userguide/change-manager-auto-approval-access.html

        Applies to actions:

        - .toStartChangeRequestExecution()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8a288b787f43e6dfcdf79d96ea0c04383caaadfb5729aa80a49e92ced648b0d5)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Ssm", jsii.invoke(self, "ifAutoApprove", [value, operator]))

    @jsii.member(jsii_name="ifDocumentCategories")
    def if_document_categories(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Ssm":
        '''(experimental) Filters access by verifying that a user has permission to access a document belonging to a specific category enum.

        https://docs.aws.amazon.com/systems-manager/latest/userguide/auth-and-access-control-iam-access-control-identity-based.html#policy-conditions

        Applies to actions:

        - .toGetDocument()

        Applies to resource types:

        - document

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9c11b836938d9d11bf9b922a4eba778e4602e9fb849c7e7d7f6878d10f6363a8)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Ssm", jsii.invoke(self, "ifDocumentCategories", [value, operator]))

    @jsii.member(jsii_name="ifOverwrite")
    def if_overwrite(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Ssm":
        '''(experimental) Filters access by allowing Systems Manager parameters to be overwritten.

        https://docs.aws.amazon.com/systems-manager/latest/userguide/auth-and-access-control-iam-access-control-identity-based.html#policy-conditions

        Applies to actions:

        - .toPutParameter()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__79c288869eeb4c08e939f30a8c19fc6bb6030a98984e4ba3fff5cf12b820ce52)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Ssm", jsii.invoke(self, "ifOverwrite", [value, operator]))

    @jsii.member(jsii_name="ifRecursive")
    def if_recursive(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Ssm":
        '''(experimental) Filters access by allowing traversing hierarchical structure of the Systems Manager parameters.

        https://docs.aws.amazon.com/systems-manager/latest/userguide/auth-and-access-control-iam-access-control-identity-based.html#policy-conditions

        Applies to actions:

        - .toGetParametersByPath()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__61169003391da8022d8e921c7ca689e400e5b46e1428c1a6ffe46e5c7a423512)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Ssm", jsii.invoke(self, "ifRecursive", [value, operator]))

    @jsii.member(jsii_name="ifResourceTag")
    def if_resource_tag(
        self,
        tag_key: builtins.str,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Ssm":
        '''(experimental) Filters access by allowing access based on a tag key-value pair assigned to the Systems Manager resource.

        https://docs.aws.amazon.com/systems-manager/latest/userguide/auth-and-access-control-iam-access-control-identity-based.html#policy-conditions

        Applies to actions:

        - .toDeregisterManagedInstance()
        - .toGetConnectionStatus()
        - .toSendCommand()
        - .toStartSession()
        - .toUpdateManagedInstanceRole()

        Applies to resource types:

        - automation-execution
        - instance
        - maintenancewindow
        - managed-instance
        - opsmetadata
        - parameter
        - patchbaseline

        :param tag_key: The tag key to check.
        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__63557b374d81fc214bb519b5a2dd60f61af373eea45dd46bc9891d626c2c38c3)
            check_type(argname="argument tag_key", value=tag_key, expected_type=type_hints["tag_key"])
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Ssm", jsii.invoke(self, "ifResourceTag", [tag_key, value, operator]))

    @jsii.member(jsii_name="ifSessionDocumentAccessCheck")
    def if_session_document_access_check(
        self,
        value: typing.Optional[builtins.bool] = None,
    ) -> "Ssm":
        '''(experimental) Filters access by verifying that a user has permission to access either the default Session Manager configuration document or the custom configuration document specified in a request.

        https://docs.aws.amazon.com/systems-manager/latest/userguide/getting-started-sessiondocumentaccesscheck.html

        Applies to actions:

        - .toStartSession()

        :param value: ``true`` or ``false``. **Default:** ``true``

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b59047424aae669ff7b2ca74cfaf2861ab28fc1090c417f1d6d9765e98d9c7c1)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast("Ssm", jsii.invoke(self, "ifSessionDocumentAccessCheck", [value]))

    @jsii.member(jsii_name="ifSourceInstanceARN")
    def if_source_instance_arn(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Ssm":
        '''(experimental) Filters access by verifying the Amazon Resource Name (ARN) of the AWS Systems Manager's managed instance from which the request is made.

        This key is not present when the request comes from the managed instance authenticated with an IAM role associated with EC2 instance profile

        https://docs.aws.amazon.com/systems-manager/latest/userguide/service-authorization/latest/reference/list_awssystemsmanager.html#awssystemsmanager-policy-keys

        Applies to actions:

        - .toUpdateAssociationStatus()
        - .toUpdateInstanceAssociationStatus()
        - .toUpdateInstanceInformation()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ee78a5e5214d8168436be934338d4909c57ee2a982395cb780411fa033a0c788)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Ssm", jsii.invoke(self, "ifSourceInstanceARN", [value, operator]))

    @jsii.member(jsii_name="ifSyncType")
    def if_sync_type(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Ssm":
        '''(experimental) Filters access by verifying that a user also has access to the ResourceDataSync SyncType specified in the request.

        https://docs.aws.amazon.com/systems-manager/latest/userguide/auth-and-access-control-iam-access-control-identity-based.html#policy-conditions

        Applies to actions:

        - .toCreateResourceDataSync()
        - .toDeleteResourceDataSync()
        - .toListResourceDataSync()
        - .toUpdateResourceDataSync()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8858b3ed0ab05baed507da4f2b655d85a2ddc3b99467932bc40af0ba0d8617c9)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Ssm", jsii.invoke(self, "ifSyncType", [value, operator]))

    @jsii.member(jsii_name="onAssociation")
    def on_association(
        self,
        association_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Ssm":
        '''(experimental) Adds a resource of type association to the statement.

        https://docs.aws.amazon.com/systems-manager/latest/userguide/systems-manager-associations.html

        :param association_id: - Identifier for the associationId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__63d34726cae3bf54acc7e53bbbd498a179c96290697813f9ac23b6263692da64)
            check_type(argname="argument association_id", value=association_id, expected_type=type_hints["association_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Ssm", jsii.invoke(self, "onAssociation", [association_id, account, region, partition]))

    @jsii.member(jsii_name="onAutomationDefinition")
    def on_automation_definition(
        self,
        automation_definition_name: builtins.str,
        version_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Ssm":
        '''(experimental) Adds a resource of type automation-definition to the statement.

        https://docs.aws.amazon.com/systems-manager/latest/userguide/automation-documents.html

        :param automation_definition_name: - Identifier for the automationDefinitionName.
        :param version_id: - Identifier for the versionId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__015311cd3855957d4f19eaac253a7c3ec4bebbfe7bc78e933c4bcefe50182f87)
            check_type(argname="argument automation_definition_name", value=automation_definition_name, expected_type=type_hints["automation_definition_name"])
            check_type(argname="argument version_id", value=version_id, expected_type=type_hints["version_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Ssm", jsii.invoke(self, "onAutomationDefinition", [automation_definition_name, version_id, account, region, partition]))

    @jsii.member(jsii_name="onAutomationExecution")
    def on_automation_execution(
        self,
        automation_execution_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Ssm":
        '''(experimental) Adds a resource of type automation-execution to the statement.

        https://docs.aws.amazon.com/systems-manager/latest/userguide/automation-working.html

        :param automation_execution_id: - Identifier for the automationExecutionId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag() - .ifResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e1f8b2c1be534afdfcbeb97eb308f8e98fd9aff1979994af3e8d3262bf0f3929)
            check_type(argname="argument automation_execution_id", value=automation_execution_id, expected_type=type_hints["automation_execution_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Ssm", jsii.invoke(self, "onAutomationExecution", [automation_execution_id, account, region, partition]))

    @jsii.member(jsii_name="onBucket")
    def on_bucket(
        self,
        bucket_name: builtins.str,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Ssm":
        '''(experimental) Adds a resource of type bucket to the statement.

        https://docs.aws.amazon.com/AmazonS3/latest/dev/UsingBucket.html

        :param bucket_name: - Identifier for the bucketName.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__631c4c22026eea95b376d4e5922cd8ede02f46ef397009d304fa7b19fd4c3193)
            check_type(argname="argument bucket_name", value=bucket_name, expected_type=type_hints["bucket_name"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Ssm", jsii.invoke(self, "onBucket", [bucket_name, partition]))

    @jsii.member(jsii_name="onDocument")
    def on_document(
        self,
        document_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Ssm":
        '''(experimental) Adds a resource of type document to the statement.

        https://docs.aws.amazon.com/systems-manager/latest/userguide/sysman-ssm-docs.html

        :param document_name: - Identifier for the documentName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag() - .ifDocumentCategories()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__02352e33d632779acccf7f60960b5e0029289374168c3a0cc625000423816a6f)
            check_type(argname="argument document_name", value=document_name, expected_type=type_hints["document_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Ssm", jsii.invoke(self, "onDocument", [document_name, account, region, partition]))

    @jsii.member(jsii_name="onInstance")
    def on_instance(
        self,
        instance_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Ssm":
        '''(experimental) Adds a resource of type instance to the statement.

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/iam-policy-structure.html#EC2_ARN_Format

        :param instance_id: - Identifier for the instanceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag() - .ifResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3c94e9249304fbc327295b43cd5e88762044bf9759ce94ac91101d414e2b9e51)
            check_type(argname="argument instance_id", value=instance_id, expected_type=type_hints["instance_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Ssm", jsii.invoke(self, "onInstance", [instance_id, account, region, partition]))

    @jsii.member(jsii_name="onMaintenancewindow")
    def on_maintenancewindow(
        self,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Ssm":
        '''(experimental) Adds a resource of type maintenancewindow to the statement.

        https://docs.aws.amazon.com/systems-manager/latest/userguide/systems-manager-maintenance.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag() - .ifResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b4c7f3ba39e5b850a0804e229bc268488b00cc54b0145d60e2ba51eb703ab111)
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Ssm", jsii.invoke(self, "onMaintenancewindow", [resource_id, account, region, partition]))

    @jsii.member(jsii_name="onManagedInstance")
    def on_managed_instance(
        self,
        instance_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Ssm":
        '''(experimental) Adds a resource of type managed-instance to the statement.

        https://docs.aws.amazon.com/systems-manager/latest/userguide/what-is-systems-manager.html

        :param instance_id: - Identifier for the instanceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag() - .ifResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__60de7a0f4023f4179cdb1e33e9ca9fcf8bdf89d2ed1c29655400289d7b58f41e)
            check_type(argname="argument instance_id", value=instance_id, expected_type=type_hints["instance_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Ssm", jsii.invoke(self, "onManagedInstance", [instance_id, account, region, partition]))

    @jsii.member(jsii_name="onManagedInstanceInventory")
    def on_managed_instance_inventory(
        self,
        instance_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Ssm":
        '''(experimental) Adds a resource of type managed-instance-inventory to the statement.

        https://docs.aws.amazon.com/systems-manager/latest/userguide/sysman-inventory-configuring.html

        :param instance_id: - Identifier for the instanceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d955ebbc774a7f4ba6068417fc678679d434b425f467dab454295eaf1688a301)
            check_type(argname="argument instance_id", value=instance_id, expected_type=type_hints["instance_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Ssm", jsii.invoke(self, "onManagedInstanceInventory", [instance_id, account, region, partition]))

    @jsii.member(jsii_name="onOpsitem")
    def on_opsitem(
        self,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Ssm":
        '''(experimental) Adds a resource of type opsitem to the statement.

        https://docs.aws.amazon.com/systems-manager/latest/userguide/OpsCenter-working-with-OpsItems.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8b32a0d9df7c215ef6cecfb7160a45caf3979d10a21b7b2bdb51e2066274b4af)
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Ssm", jsii.invoke(self, "onOpsitem", [resource_id, account, region, partition]))

    @jsii.member(jsii_name="onOpsmetadata")
    def on_opsmetadata(
        self,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Ssm":
        '''(experimental) Adds a resource of type opsmetadata to the statement.

        https://docs.aws.amazon.com/systems-manager/latest/userguide/application-manager.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag() - .ifResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b2404499ef69fe959b97333d4e3da566ee9caa5c3ae10320160f2501e96a91de)
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Ssm", jsii.invoke(self, "onOpsmetadata", [resource_id, account, region, partition]))

    @jsii.member(jsii_name="onParameter")
    def on_parameter(
        self,
        parameter_name_without_leading_slash: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Ssm":
        '''(experimental) Adds a resource of type parameter to the statement.

        https://docs.aws.amazon.com/systems-manager/latest/userguide/systems-manager-parameter-store.html

        :param parameter_name_without_leading_slash: - Identifier for the parameterNameWithoutLeadingSlash.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag() - .ifResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c88d724605124d1a43b3a0e7f4c4193a66d0df620f6a9b86eb65d8d174cf5606)
            check_type(argname="argument parameter_name_without_leading_slash", value=parameter_name_without_leading_slash, expected_type=type_hints["parameter_name_without_leading_slash"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Ssm", jsii.invoke(self, "onParameter", [parameter_name_without_leading_slash, account, region, partition]))

    @jsii.member(jsii_name="onPatchbaseline")
    def on_patchbaseline(
        self,
        patch_baseline_id_resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Ssm":
        '''(experimental) Adds a resource of type patchbaseline to the statement.

        https://docs.aws.amazon.com/systems-manager/latest/userguide/systems-manager-patch.html

        :param patch_baseline_id_resource_id: - Identifier for the patchBaselineIdResourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag() - .ifResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__08f1336bbbab533a52e781c5b3e70f3f4c66ed2e645884399757ac6895332021)
            check_type(argname="argument patch_baseline_id_resource_id", value=patch_baseline_id_resource_id, expected_type=type_hints["patch_baseline_id_resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Ssm", jsii.invoke(self, "onPatchbaseline", [patch_baseline_id_resource_id, account, region, partition]))

    @jsii.member(jsii_name="onResourcedatasync")
    def on_resourcedatasync(
        self,
        sync_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Ssm":
        '''(experimental) Adds a resource of type resourcedatasync to the statement.

        https://docs.aws.amazon.com/systems-manager/latest/userguide/sysman-inventory-datasync.html

        :param sync_name: - Identifier for the syncName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__04b8161381bc5c675e122c8bd3bad4d822f1a34d5f865dbb441259cc7cdbc010)
            check_type(argname="argument sync_name", value=sync_name, expected_type=type_hints["sync_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Ssm", jsii.invoke(self, "onResourcedatasync", [sync_name, account, region, partition]))

    @jsii.member(jsii_name="onServicesetting")
    def on_servicesetting(
        self,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Ssm":
        '''(experimental) Adds a resource of type servicesetting to the statement.

        https://docs.aws.amazon.com/systems-manager/latest/userguide/API_ServiceSetting.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a46715388b50704574e1283dd31bc550bfb8e68b31b1a278fbf8e27fd11125cd)
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Ssm", jsii.invoke(self, "onServicesetting", [resource_id, account, region, partition]))

    @jsii.member(jsii_name="onSession")
    def on_session(
        self,
        session_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Ssm":
        '''(experimental) Adds a resource of type session to the statement.

        https://docs.aws.amazon.com/systems-manager/latest/userguide/session-manager.html

        :param session_id: - Identifier for the sessionId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2aa9ec9450a711f810483308b6c4182411911a265a0a1c0ae6f83fbd153336b7)
            check_type(argname="argument session_id", value=session_id, expected_type=type_hints["session_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Ssm", jsii.invoke(self, "onSession", [session_id, account, region, partition]))

    @jsii.member(jsii_name="onTask")
    def on_task(
        self,
        task_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Ssm":
        '''(experimental) Adds a resource of type task to the statement.

        https://docs.aws.amazon.com/AmazonECS/latest/developerguide/scheduling_tasks.html

        :param task_id: - Identifier for the taskId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c45b854687dc6bda37b19b4b26a8609f6bc36733d6621cf92a163f563c4aebd1)
            check_type(argname="argument task_id", value=task_id, expected_type=type_hints["task_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Ssm", jsii.invoke(self, "onTask", [task_id, account, region, partition]))

    @jsii.member(jsii_name="onWindowtarget")
    def on_windowtarget(
        self,
        window_target_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Ssm":
        '''(experimental) Adds a resource of type windowtarget to the statement.

        https://docs.aws.amazon.com/systems-manager/latest/userguide/sysman-maintenance-assign-targets.html

        :param window_target_id: - Identifier for the windowTargetId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9aaed0026187eb78db95f9ac612000370f5f4164bb6234cf127f4e5a7484454d)
            check_type(argname="argument window_target_id", value=window_target_id, expected_type=type_hints["window_target_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Ssm", jsii.invoke(self, "onWindowtarget", [window_target_id, account, region, partition]))

    @jsii.member(jsii_name="onWindowtask")
    def on_windowtask(
        self,
        window_task_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Ssm":
        '''(experimental) Adds a resource of type windowtask to the statement.

        https://docs.aws.amazon.com/systems-manager/latest/userguide/sysman-maintenance-assign-tasks.html

        :param window_task_id: - Identifier for the windowTaskId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c8699d90f5743aa421378b5ec2966471694fffc27ca9918786f8efedd58c7f0a)
            check_type(argname="argument window_task_id", value=window_task_id, expected_type=type_hints["window_task_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Ssm", jsii.invoke(self, "onWindowtask", [window_task_id, account, region, partition]))

    @jsii.member(jsii_name="toAddTagsToResource")
    def to_add_tags_to_resource(self) -> "Ssm":
        '''(experimental) Grants permission to add or overwrite one or more tags for a specified AWS resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_AddTagsToResource.html

        :stability: experimental
        '''
        return typing.cast("Ssm", jsii.invoke(self, "toAddTagsToResource", []))

    @jsii.member(jsii_name="toAssociateOpsItemRelatedItem")
    def to_associate_ops_item_related_item(self) -> "Ssm":
        '''(experimental) Grants permission to associate RelatedItem to an OpsItem.

        Access Level: Write

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_AssociateOpsItemRelatedItem.html

        :stability: experimental
        '''
        return typing.cast("Ssm", jsii.invoke(self, "toAssociateOpsItemRelatedItem", []))

    @jsii.member(jsii_name="toCancelCommand")
    def to_cancel_command(self) -> "Ssm":
        '''(experimental) Grants permission to cancel a specified Run Command command.

        Access Level: Write

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_CancelCommand.html

        :stability: experimental
        '''
        return typing.cast("Ssm", jsii.invoke(self, "toCancelCommand", []))

    @jsii.member(jsii_name="toCancelMaintenanceWindowExecution")
    def to_cancel_maintenance_window_execution(self) -> "Ssm":
        '''(experimental) Grants permission to cancel an in-progress maintenance window execution.

        Access Level: Write

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_CancelMaintenanceWindowExecution.html

        :stability: experimental
        '''
        return typing.cast("Ssm", jsii.invoke(self, "toCancelMaintenanceWindowExecution", []))

    @jsii.member(jsii_name="toCreateActivation")
    def to_create_activation(self) -> "Ssm":
        '''(experimental) Grants permission to create an activation that is used to register on-premises servers and virtual machines (VMs) with Systems Manager.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_CreateActivation.html

        :stability: experimental
        '''
        return typing.cast("Ssm", jsii.invoke(self, "toCreateActivation", []))

    @jsii.member(jsii_name="toCreateAssociation")
    def to_create_association(self) -> "Ssm":
        '''(experimental) Grants permission to associate a specified Systems Manager document with specified instances or other targets.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_CreateAssociation.html

        :stability: experimental
        '''
        return typing.cast("Ssm", jsii.invoke(self, "toCreateAssociation", []))

    @jsii.member(jsii_name="toCreateAssociationBatch")
    def to_create_association_batch(self) -> "Ssm":
        '''(experimental) Grants permission to combine entries for multiple CreateAssociation operations in a single command.

        Access Level: Write

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_CreateAssociationBatch.html

        :stability: experimental
        '''
        return typing.cast("Ssm", jsii.invoke(self, "toCreateAssociationBatch", []))

    @jsii.member(jsii_name="toCreateDocument")
    def to_create_document(self) -> "Ssm":
        '''(experimental) Grants permission to create a Systems Manager SSM document.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - iam:PassRole

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_CreateDocument.html

        :stability: experimental
        '''
        return typing.cast("Ssm", jsii.invoke(self, "toCreateDocument", []))

    @jsii.member(jsii_name="toCreateMaintenanceWindow")
    def to_create_maintenance_window(self) -> "Ssm":
        '''(experimental) Grants permission to create a maintenance window.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_CreateMaintenanceWindow.html

        :stability: experimental
        '''
        return typing.cast("Ssm", jsii.invoke(self, "toCreateMaintenanceWindow", []))

    @jsii.member(jsii_name="toCreateOpsItem")
    def to_create_ops_item(self) -> "Ssm":
        '''(experimental) Grants permission to create an OpsItem in OpsCenter.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_CreateOpsItem.html

        :stability: experimental
        '''
        return typing.cast("Ssm", jsii.invoke(self, "toCreateOpsItem", []))

    @jsii.member(jsii_name="toCreateOpsMetadata")
    def to_create_ops_metadata(self) -> "Ssm":
        '''(experimental) Grants permission to create an OpsMetadata object for an AWS resource.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_CreateOpsMetadata.html

        :stability: experimental
        '''
        return typing.cast("Ssm", jsii.invoke(self, "toCreateOpsMetadata", []))

    @jsii.member(jsii_name="toCreatePatchBaseline")
    def to_create_patch_baseline(self) -> "Ssm":
        '''(experimental) Grants permission to create a patch baseline.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_CreatePatchBaseline.html

        :stability: experimental
        '''
        return typing.cast("Ssm", jsii.invoke(self, "toCreatePatchBaseline", []))

    @jsii.member(jsii_name="toCreateResourceDataSync")
    def to_create_resource_data_sync(self) -> "Ssm":
        '''(experimental) Grants permission to create a resource data sync configuration, which regularly collects inventory data from managed instances and updates the data in an Amazon S3 bucket.

        Access Level: Write

        Possible conditions:

        - .ifSyncType()

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_CreateResourceDataSync.html

        :stability: experimental
        '''
        return typing.cast("Ssm", jsii.invoke(self, "toCreateResourceDataSync", []))

    @jsii.member(jsii_name="toDeleteActivation")
    def to_delete_activation(self) -> "Ssm":
        '''(experimental) Grants permission to delete a specified activation for managed instances.

        Access Level: Write

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_DeleteActivation.html

        :stability: experimental
        '''
        return typing.cast("Ssm", jsii.invoke(self, "toDeleteActivation", []))

    @jsii.member(jsii_name="toDeleteAssociation")
    def to_delete_association(self) -> "Ssm":
        '''(experimental) Grants permission to disassociate a specified SSM document from a specified instance.

        Access Level: Write

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_DeleteAssociation.html

        :stability: experimental
        '''
        return typing.cast("Ssm", jsii.invoke(self, "toDeleteAssociation", []))

    @jsii.member(jsii_name="toDeleteDocument")
    def to_delete_document(self) -> "Ssm":
        '''(experimental) Grants permission to delete a specified SSM document and its instance associations.

        Access Level: Write

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_DeleteDocument.html

        :stability: experimental
        '''
        return typing.cast("Ssm", jsii.invoke(self, "toDeleteDocument", []))

    @jsii.member(jsii_name="toDeleteInventory")
    def to_delete_inventory(self) -> "Ssm":
        '''(experimental) Grants permission to delete a specified custom inventory type, or the data associated with a custom inventory type.

        Access Level: Write

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_DeleteInventory.html

        :stability: experimental
        '''
        return typing.cast("Ssm", jsii.invoke(self, "toDeleteInventory", []))

    @jsii.member(jsii_name="toDeleteMaintenanceWindow")
    def to_delete_maintenance_window(self) -> "Ssm":
        '''(experimental) Grants permission to delete a specified maintenance window.

        Access Level: Write

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_DeleteMaintenanceWindow.html

        :stability: experimental
        '''
        return typing.cast("Ssm", jsii.invoke(self, "toDeleteMaintenanceWindow", []))

    @jsii.member(jsii_name="toDeleteOpsMetadata")
    def to_delete_ops_metadata(self) -> "Ssm":
        '''(experimental) Grants permission to delete an OpsMetadata object.

        Access Level: Write

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_DeleteOpsMetadata.html

        :stability: experimental
        '''
        return typing.cast("Ssm", jsii.invoke(self, "toDeleteOpsMetadata", []))

    @jsii.member(jsii_name="toDeleteParameter")
    def to_delete_parameter(self) -> "Ssm":
        '''(experimental) Grants permission to delete a specified SSM parameter.

        Access Level: Write

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_DeleteParameter.html

        :stability: experimental
        '''
        return typing.cast("Ssm", jsii.invoke(self, "toDeleteParameter", []))

    @jsii.member(jsii_name="toDeleteParameters")
    def to_delete_parameters(self) -> "Ssm":
        '''(experimental) Grants permission to delete multiple specified SSM parameters.

        Access Level: Write

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_DeleteParameters.html

        :stability: experimental
        '''
        return typing.cast("Ssm", jsii.invoke(self, "toDeleteParameters", []))

    @jsii.member(jsii_name="toDeletePatchBaseline")
    def to_delete_patch_baseline(self) -> "Ssm":
        '''(experimental) Grants permission to delete a specified patch baseline.

        Access Level: Write

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_DeletePatchBaseline.html

        :stability: experimental
        '''
        return typing.cast("Ssm", jsii.invoke(self, "toDeletePatchBaseline", []))

    @jsii.member(jsii_name="toDeleteResourceDataSync")
    def to_delete_resource_data_sync(self) -> "Ssm":
        '''(experimental) Grants permission to delete a specified resource data sync.

        Access Level: Write

        Possible conditions:

        - .ifSyncType()

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_DeleteResourceDataSync.html

        :stability: experimental
        '''
        return typing.cast("Ssm", jsii.invoke(self, "toDeleteResourceDataSync", []))

    @jsii.member(jsii_name="toDeregisterManagedInstance")
    def to_deregister_managed_instance(self) -> "Ssm":
        '''(experimental) Grants permission to deregister a specified on-premises server or virtual machine (VM) from Systems Manager.

        Access Level: Write

        Possible conditions:

        - .ifResourceTag()

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_DeregisterManagedInstance.html

        :stability: experimental
        '''
        return typing.cast("Ssm", jsii.invoke(self, "toDeregisterManagedInstance", []))

    @jsii.member(jsii_name="toDeregisterPatchBaselineForPatchGroup")
    def to_deregister_patch_baseline_for_patch_group(self) -> "Ssm":
        '''(experimental) Grants permission to deregister a specified patch baseline from being the default patch baseline for a specified patch group.

        Access Level: Write

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_DeregisterPatchBaselineForPatchGroup.html

        :stability: experimental
        '''
        return typing.cast("Ssm", jsii.invoke(self, "toDeregisterPatchBaselineForPatchGroup", []))

    @jsii.member(jsii_name="toDeregisterTargetFromMaintenanceWindow")
    def to_deregister_target_from_maintenance_window(self) -> "Ssm":
        '''(experimental) Grants permission to deregister a specified target from a maintenance window.

        Access Level: Write

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_DeregisterTargetFromMaintenanceWindow.html

        :stability: experimental
        '''
        return typing.cast("Ssm", jsii.invoke(self, "toDeregisterTargetFromMaintenanceWindow", []))

    @jsii.member(jsii_name="toDeregisterTaskFromMaintenanceWindow")
    def to_deregister_task_from_maintenance_window(self) -> "Ssm":
        '''(experimental) Grants permission to deregister a specified task from a maintenance window.

        Access Level: Write

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_DeregisterTaskFromMaintenanceWindow.html

        :stability: experimental
        '''
        return typing.cast("Ssm", jsii.invoke(self, "toDeregisterTaskFromMaintenanceWindow", []))

    @jsii.member(jsii_name="toDescribeActivations")
    def to_describe_activations(self) -> "Ssm":
        '''(experimental) Grants permission to view details about a specified managed instance activation, such as when it was created and the number of instances registered using the activation.

        Access Level: Read

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_DescribeActivations.html

        :stability: experimental
        '''
        return typing.cast("Ssm", jsii.invoke(self, "toDescribeActivations", []))

    @jsii.member(jsii_name="toDescribeAssociation")
    def to_describe_association(self) -> "Ssm":
        '''(experimental) Grants permission to view details about the specified association for a specified instance or target.

        Access Level: Read

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_DescribeAssociation.html

        :stability: experimental
        '''
        return typing.cast("Ssm", jsii.invoke(self, "toDescribeAssociation", []))

    @jsii.member(jsii_name="toDescribeAssociationExecutions")
    def to_describe_association_executions(self) -> "Ssm":
        '''(experimental) Grants permission to view all executions for a specified association.

        Access Level: Read

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_DescribeAssociationExecutions.html

        :stability: experimental
        '''
        return typing.cast("Ssm", jsii.invoke(self, "toDescribeAssociationExecutions", []))

    @jsii.member(jsii_name="toDescribeAssociationExecutionTargets")
    def to_describe_association_execution_targets(self) -> "Ssm":
        '''(experimental) Grants permission to view information about a specified association execution.

        Access Level: Read

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_DescribeAssociationExecutionTargets.html

        :stability: experimental
        '''
        return typing.cast("Ssm", jsii.invoke(self, "toDescribeAssociationExecutionTargets", []))

    @jsii.member(jsii_name="toDescribeAutomationExecutions")
    def to_describe_automation_executions(self) -> "Ssm":
        '''(experimental) Grants permission to view details about all active and terminated Automation executions.

        Access Level: Read

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_DescribeAutomationExecutions.html

        :stability: experimental
        '''
        return typing.cast("Ssm", jsii.invoke(self, "toDescribeAutomationExecutions", []))

    @jsii.member(jsii_name="toDescribeAutomationStepExecutions")
    def to_describe_automation_step_executions(self) -> "Ssm":
        '''(experimental) Grants permission to view information about all active and terminated step executions in an Automation workflow.

        Access Level: Read

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_DescribeAutomationStepExecutions.html

        :stability: experimental
        '''
        return typing.cast("Ssm", jsii.invoke(self, "toDescribeAutomationStepExecutions", []))

    @jsii.member(jsii_name="toDescribeAvailablePatches")
    def to_describe_available_patches(self) -> "Ssm":
        '''(experimental) Grants permission to view all patches eligible to include in a patch baseline.

        Access Level: Read

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_DescribeAvailablePatches.html

        :stability: experimental
        '''
        return typing.cast("Ssm", jsii.invoke(self, "toDescribeAvailablePatches", []))

    @jsii.member(jsii_name="toDescribeDocument")
    def to_describe_document(self) -> "Ssm":
        '''(experimental) Grants permission to view details about a specified SSM document.

        Access Level: Read

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_DescribeDocument.html

        :stability: experimental
        '''
        return typing.cast("Ssm", jsii.invoke(self, "toDescribeDocument", []))

    @jsii.member(jsii_name="toDescribeDocumentParameters")
    def to_describe_document_parameters(self) -> "Ssm":
        '''(experimental) Grants permission to display information about SSM document parameters in the Systems Manager console (internal Systems Manager action).

        Access Level: Read

        https://docs.aws.amazon.com/systems-manager/latest/userguide/systems-manager-setting-up-messageAPIs.html

        :stability: experimental
        '''
        return typing.cast("Ssm", jsii.invoke(self, "toDescribeDocumentParameters", []))

    @jsii.member(jsii_name="toDescribeDocumentPermission")
    def to_describe_document_permission(self) -> "Ssm":
        '''(experimental) Grants permission to view the permissions for a specified SSM document.

        Access Level: Read

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_DescribeDocumentPermission.html

        :stability: experimental
        '''
        return typing.cast("Ssm", jsii.invoke(self, "toDescribeDocumentPermission", []))

    @jsii.member(jsii_name="toDescribeEffectiveInstanceAssociations")
    def to_describe_effective_instance_associations(self) -> "Ssm":
        '''(experimental) Grants permission to view all current associations for a specified instance.

        Access Level: Read

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_DescribeEffectiveInstanceAssociations.html

        :stability: experimental
        '''
        return typing.cast("Ssm", jsii.invoke(self, "toDescribeEffectiveInstanceAssociations", []))

    @jsii.member(jsii_name="toDescribeEffectivePatchesForPatchBaseline")
    def to_describe_effective_patches_for_patch_baseline(self) -> "Ssm":
        '''(experimental) Grants permission to view details about the patches currently associated with the specified patch baseline (Windows only).

        Access Level: Read

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_DescribeEffectivePatchesForPatchBaseline.html

        :stability: experimental
        '''
        return typing.cast("Ssm", jsii.invoke(self, "toDescribeEffectivePatchesForPatchBaseline", []))

    @jsii.member(jsii_name="toDescribeInstanceAssociationsStatus")
    def to_describe_instance_associations_status(self) -> "Ssm":
        '''(experimental) Grants permission to view the status of the associations for a specified instance.

        Access Level: Read

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_DescribeInstanceAssociationsStatus.html

        :stability: experimental
        '''
        return typing.cast("Ssm", jsii.invoke(self, "toDescribeInstanceAssociationsStatus", []))

    @jsii.member(jsii_name="toDescribeInstanceInformation")
    def to_describe_instance_information(self) -> "Ssm":
        '''(experimental) Grants permission to view details about a specified instance.

        Access Level: Read

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_DescribeInstanceInformation.html

        :stability: experimental
        '''
        return typing.cast("Ssm", jsii.invoke(self, "toDescribeInstanceInformation", []))

    @jsii.member(jsii_name="toDescribeInstancePatches")
    def to_describe_instance_patches(self) -> "Ssm":
        '''(experimental) Grants permission to view general details about the patches on a specified instance.

        Access Level: Read

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_DescribeInstancePatches.html

        :stability: experimental
        '''
        return typing.cast("Ssm", jsii.invoke(self, "toDescribeInstancePatches", []))

    @jsii.member(jsii_name="toDescribeInstancePatchStates")
    def to_describe_instance_patch_states(self) -> "Ssm":
        '''(experimental) Grants permission to view status details about patches on a specified instance.

        Access Level: Read

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_DescribeInstancePatchStates.html

        :stability: experimental
        '''
        return typing.cast("Ssm", jsii.invoke(self, "toDescribeInstancePatchStates", []))

    @jsii.member(jsii_name="toDescribeInstancePatchStatesForPatchGroup")
    def to_describe_instance_patch_states_for_patch_group(self) -> "Ssm":
        '''(experimental) Grants permission to describe the high-level patch state for the instances in the specified patch group.

        Access Level: Read

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_DescribeInstancePatchStatesForPatchGroup.html

        :stability: experimental
        '''
        return typing.cast("Ssm", jsii.invoke(self, "toDescribeInstancePatchStatesForPatchGroup", []))

    @jsii.member(jsii_name="toDescribeInstanceProperties")
    def to_describe_instance_properties(self) -> "Ssm":
        '''(experimental) Grants permission to user's Amazon EC2 console to render managed instances' nodes.

        Access Level: Read

        https://docs.aws.amazon.com/systems-manager/latest/userguide/systems-manager-setting-up-messageAPIs.html

        :stability: experimental
        '''
        return typing.cast("Ssm", jsii.invoke(self, "toDescribeInstanceProperties", []))

    @jsii.member(jsii_name="toDescribeInventoryDeletions")
    def to_describe_inventory_deletions(self) -> "Ssm":
        '''(experimental) Grants permission to view details about a specified inventory deletion.

        Access Level: Read

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_DescribeInventoryDeletions.html

        :stability: experimental
        '''
        return typing.cast("Ssm", jsii.invoke(self, "toDescribeInventoryDeletions", []))

    @jsii.member(jsii_name="toDescribeMaintenanceWindowExecutions")
    def to_describe_maintenance_window_executions(self) -> "Ssm":
        '''(experimental) Grants permission to view the executions of a specified maintenance window.

        Access Level: List

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_DescribeMaintenanceWindowExecutions.html

        :stability: experimental
        '''
        return typing.cast("Ssm", jsii.invoke(self, "toDescribeMaintenanceWindowExecutions", []))

    @jsii.member(jsii_name="toDescribeMaintenanceWindowExecutionTaskInvocations")
    def to_describe_maintenance_window_execution_task_invocations(self) -> "Ssm":
        '''(experimental) Grants permission to view details of a specified task execution for a maintenance window.

        Access Level: List

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_DescribeMaintenanceWindowExecutionTaskInvocations.html

        :stability: experimental
        '''
        return typing.cast("Ssm", jsii.invoke(self, "toDescribeMaintenanceWindowExecutionTaskInvocations", []))

    @jsii.member(jsii_name="toDescribeMaintenanceWindowExecutionTasks")
    def to_describe_maintenance_window_execution_tasks(self) -> "Ssm":
        '''(experimental) Grants permission to view details about the tasks that ran during a specified maintenance window execution.

        Access Level: List

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_DescribeMaintenanceWindowExecutionTasks.html

        :stability: experimental
        '''
        return typing.cast("Ssm", jsii.invoke(self, "toDescribeMaintenanceWindowExecutionTasks", []))

    @jsii.member(jsii_name="toDescribeMaintenanceWindows")
    def to_describe_maintenance_windows(self) -> "Ssm":
        '''(experimental) Grants permission to view information about all or specified maintenance windows.

        Access Level: List

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_DescribeMaintenanceWindows.html

        :stability: experimental
        '''
        return typing.cast("Ssm", jsii.invoke(self, "toDescribeMaintenanceWindows", []))

    @jsii.member(jsii_name="toDescribeMaintenanceWindowSchedule")
    def to_describe_maintenance_window_schedule(self) -> "Ssm":
        '''(experimental) Grants permission to view details about upcoming executions of a specified maintenance window.

        Access Level: List

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_DescribeMaintenanceWindowSchedule.html

        :stability: experimental
        '''
        return typing.cast("Ssm", jsii.invoke(self, "toDescribeMaintenanceWindowSchedule", []))

    @jsii.member(jsii_name="toDescribeMaintenanceWindowsForTarget")
    def to_describe_maintenance_windows_for_target(self) -> "Ssm":
        '''(experimental) Grants permission to view information about the maintenance window targets and tasks associated with a specified instance.

        Access Level: List

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_DescribeMaintenanceWindowsForTarget.html

        :stability: experimental
        '''
        return typing.cast("Ssm", jsii.invoke(self, "toDescribeMaintenanceWindowsForTarget", []))

    @jsii.member(jsii_name="toDescribeMaintenanceWindowTargets")
    def to_describe_maintenance_window_targets(self) -> "Ssm":
        '''(experimental) Grants permission to view a list of the targets associated with a specified maintenance window.

        Access Level: List

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_DescribeMaintenanceWindowTargets.html

        :stability: experimental
        '''
        return typing.cast("Ssm", jsii.invoke(self, "toDescribeMaintenanceWindowTargets", []))

    @jsii.member(jsii_name="toDescribeMaintenanceWindowTasks")
    def to_describe_maintenance_window_tasks(self) -> "Ssm":
        '''(experimental) Grants permission to view a list of the tasks associated with a specified maintenance window.

        Access Level: List

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_DescribeMaintenanceWindowTasks.html

        :stability: experimental
        '''
        return typing.cast("Ssm", jsii.invoke(self, "toDescribeMaintenanceWindowTasks", []))

    @jsii.member(jsii_name="toDescribeOpsItems")
    def to_describe_ops_items(self) -> "Ssm":
        '''(experimental) Grants permission to view details about specified OpsItems.

        Access Level: Read

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_DescribeOpsItems.html

        :stability: experimental
        '''
        return typing.cast("Ssm", jsii.invoke(self, "toDescribeOpsItems", []))

    @jsii.member(jsii_name="toDescribeParameters")
    def to_describe_parameters(self) -> "Ssm":
        '''(experimental) Grants permission to view details about a specified SSM parameter.

        Access Level: List

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_DescribeParameters.html

        :stability: experimental
        '''
        return typing.cast("Ssm", jsii.invoke(self, "toDescribeParameters", []))

    @jsii.member(jsii_name="toDescribePatchBaselines")
    def to_describe_patch_baselines(self) -> "Ssm":
        '''(experimental) Grants permission to view information about patch baselines that meet the specified criteria.

        Access Level: List

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_DescribePatchBaselines.html

        :stability: experimental
        '''
        return typing.cast("Ssm", jsii.invoke(self, "toDescribePatchBaselines", []))

    @jsii.member(jsii_name="toDescribePatchGroups")
    def to_describe_patch_groups(self) -> "Ssm":
        '''(experimental) Grants permission to view information about the patch baseline for a specified patch group.

        Access Level: List

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_DescribePatchGroups.html

        :stability: experimental
        '''
        return typing.cast("Ssm", jsii.invoke(self, "toDescribePatchGroups", []))

    @jsii.member(jsii_name="toDescribePatchGroupState")
    def to_describe_patch_group_state(self) -> "Ssm":
        '''(experimental) Grants permission to view aggregated status details for patches for a specified patch group.

        Access Level: List

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_DescribePatchGroupState.html

        :stability: experimental
        '''
        return typing.cast("Ssm", jsii.invoke(self, "toDescribePatchGroupState", []))

    @jsii.member(jsii_name="toDescribePatchProperties")
    def to_describe_patch_properties(self) -> "Ssm":
        '''(experimental) Grants permission to view details of available patches for a specified operating system and patch property.

        Access Level: List

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_DescribePatchProperties.html

        :stability: experimental
        '''
        return typing.cast("Ssm", jsii.invoke(self, "toDescribePatchProperties", []))

    @jsii.member(jsii_name="toDescribeSessions")
    def to_describe_sessions(self) -> "Ssm":
        '''(experimental) Grants permission to view a list of recent Session Manager sessions that meet the specified search criteria.

        Access Level: List

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_DescribeSessions.html

        :stability: experimental
        '''
        return typing.cast("Ssm", jsii.invoke(self, "toDescribeSessions", []))

    @jsii.member(jsii_name="toDisassociateOpsItemRelatedItem")
    def to_disassociate_ops_item_related_item(self) -> "Ssm":
        '''(experimental) Grants permission to disassociate RelatedItem from an OpsItem.

        Access Level: Write

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_DisassociateOpsItemRelatedItem.html

        :stability: experimental
        '''
        return typing.cast("Ssm", jsii.invoke(self, "toDisassociateOpsItemRelatedItem", []))

    @jsii.member(jsii_name="toGetAutomationExecution")
    def to_get_automation_execution(self) -> "Ssm":
        '''(experimental) Grants permission to view details of a specified Automation execution.

        Access Level: Read

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_AutomationExecution.html

        :stability: experimental
        '''
        return typing.cast("Ssm", jsii.invoke(self, "toGetAutomationExecution", []))

    @jsii.member(jsii_name="toGetCalendar")
    def to_get_calendar(self) -> "Ssm":
        '''(experimental) Grants permission to view details of a specific calendar.

        Access Level: Read

        :stability: experimental
        '''
        return typing.cast("Ssm", jsii.invoke(self, "toGetCalendar", []))

    @jsii.member(jsii_name="toGetCalendarState")
    def to_get_calendar_state(self) -> "Ssm":
        '''(experimental) Grants permission to view the calendar state for a change calendar or a list of change calendars.

        Access Level: Read

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_GetCalendarState.html

        :stability: experimental
        '''
        return typing.cast("Ssm", jsii.invoke(self, "toGetCalendarState", []))

    @jsii.member(jsii_name="toGetCommandInvocation")
    def to_get_command_invocation(self) -> "Ssm":
        '''(experimental) Grants permission to view details about the command execution of a specified invocation or plugin.

        Access Level: Read

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_GetCommandInvocation.html

        :stability: experimental
        '''
        return typing.cast("Ssm", jsii.invoke(self, "toGetCommandInvocation", []))

    @jsii.member(jsii_name="toGetConnectionStatus")
    def to_get_connection_status(self) -> "Ssm":
        '''(experimental) Grants permission to view the Session Manager connection status for a specified managed instance.

        Access Level: Read

        Possible conditions:

        - .ifResourceTag()
        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_GetConnectionStatus.html

        :stability: experimental
        '''
        return typing.cast("Ssm", jsii.invoke(self, "toGetConnectionStatus", []))

    @jsii.member(jsii_name="toGetDefaultPatchBaseline")
    def to_get_default_patch_baseline(self) -> "Ssm":
        '''(experimental) Grants permission to view the current default patch baseline for a specified operating system type.

        Access Level: Read

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_GetDefaultPatchBaseline.html

        :stability: experimental
        '''
        return typing.cast("Ssm", jsii.invoke(self, "toGetDefaultPatchBaseline", []))

    @jsii.member(jsii_name="toGetDeployablePatchSnapshotForInstance")
    def to_get_deployable_patch_snapshot_for_instance(self) -> "Ssm":
        '''(experimental) Grants permission to retrieve the current patch baseline snapshot for a specified instance.

        Access Level: Read

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_GetDeployablePatchSnapshotForInstance.html

        :stability: experimental
        '''
        return typing.cast("Ssm", jsii.invoke(self, "toGetDeployablePatchSnapshotForInstance", []))

    @jsii.member(jsii_name="toGetDocument")
    def to_get_document(self) -> "Ssm":
        '''(experimental) Grants permission to view the contents of a specified SSM document.

        Access Level: Read

        Possible conditions:

        - .ifDocumentCategories()

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_GetDocument.html

        :stability: experimental
        '''
        return typing.cast("Ssm", jsii.invoke(self, "toGetDocument", []))

    @jsii.member(jsii_name="toGetInventory")
    def to_get_inventory(self) -> "Ssm":
        '''(experimental) Grants permission to view instance inventory details per the specified criteria.

        Access Level: Read

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_GetInventory.html

        :stability: experimental
        '''
        return typing.cast("Ssm", jsii.invoke(self, "toGetInventory", []))

    @jsii.member(jsii_name="toGetInventorySchema")
    def to_get_inventory_schema(self) -> "Ssm":
        '''(experimental) Grants permission to view a list of inventory types or attribute names for a specified inventory item type.

        Access Level: Read

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_GetInventorySchema.html

        :stability: experimental
        '''
        return typing.cast("Ssm", jsii.invoke(self, "toGetInventorySchema", []))

    @jsii.member(jsii_name="toGetMaintenanceWindow")
    def to_get_maintenance_window(self) -> "Ssm":
        '''(experimental) Grants permission to view details about a specified maintenance window.

        Access Level: Read

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_GetMaintenanceWindow.html

        :stability: experimental
        '''
        return typing.cast("Ssm", jsii.invoke(self, "toGetMaintenanceWindow", []))

    @jsii.member(jsii_name="toGetMaintenanceWindowExecution")
    def to_get_maintenance_window_execution(self) -> "Ssm":
        '''(experimental) Grants permission to view details about a specified maintenance window execution.

        Access Level: Read

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_GetMaintenanceWindowExecution.html

        :stability: experimental
        '''
        return typing.cast("Ssm", jsii.invoke(self, "toGetMaintenanceWindowExecution", []))

    @jsii.member(jsii_name="toGetMaintenanceWindowExecutionTask")
    def to_get_maintenance_window_execution_task(self) -> "Ssm":
        '''(experimental) Grants permission to view details about a specified maintenance window execution task.

        Access Level: Read

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_GetMaintenanceWindowExecutionTask.html

        :stability: experimental
        '''
        return typing.cast("Ssm", jsii.invoke(self, "toGetMaintenanceWindowExecutionTask", []))

    @jsii.member(jsii_name="toGetMaintenanceWindowExecutionTaskInvocation")
    def to_get_maintenance_window_execution_task_invocation(self) -> "Ssm":
        '''(experimental) Grants permission to view details about a specific maintenance window task running on a specific target.

        Access Level: Read

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_GetMaintenanceWindowExecutionTaskInvocation.html

        :stability: experimental
        '''
        return typing.cast("Ssm", jsii.invoke(self, "toGetMaintenanceWindowExecutionTaskInvocation", []))

    @jsii.member(jsii_name="toGetMaintenanceWindowTask")
    def to_get_maintenance_window_task(self) -> "Ssm":
        '''(experimental) Grants permission to view details about tasks registered with a specified maintenance window.

        Access Level: Read

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_GetMaintenanceWindowTask.html

        :stability: experimental
        '''
        return typing.cast("Ssm", jsii.invoke(self, "toGetMaintenanceWindowTask", []))

    @jsii.member(jsii_name="toGetManifest")
    def to_get_manifest(self) -> "Ssm":
        '''(experimental) Grants permission to Systems Manager and SSM Agent to determine package installation requirements for an instance (internal Systems Manager call).

        Access Level: Read

        :stability: experimental
        '''
        return typing.cast("Ssm", jsii.invoke(self, "toGetManifest", []))

    @jsii.member(jsii_name="toGetOpsItem")
    def to_get_ops_item(self) -> "Ssm":
        '''(experimental) Grants permission to view information about a specified OpsItem.

        Access Level: Read

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_GetOpsItem.html

        :stability: experimental
        '''
        return typing.cast("Ssm", jsii.invoke(self, "toGetOpsItem", []))

    @jsii.member(jsii_name="toGetOpsMetadata")
    def to_get_ops_metadata(self) -> "Ssm":
        '''(experimental) Grants permission to retrieve an OpsMetadata object.

        Access Level: Read

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_GetOpsMetadata.html

        :stability: experimental
        '''
        return typing.cast("Ssm", jsii.invoke(self, "toGetOpsMetadata", []))

    @jsii.member(jsii_name="toGetOpsSummary")
    def to_get_ops_summary(self) -> "Ssm":
        '''(experimental) Grants permission to view summary information about OpsItems based on specified filters and aggregators.

        Access Level: Read

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_GetOpsSummary.html

        :stability: experimental
        '''
        return typing.cast("Ssm", jsii.invoke(self, "toGetOpsSummary", []))

    @jsii.member(jsii_name="toGetParameter")
    def to_get_parameter(self) -> "Ssm":
        '''(experimental) Grants permission to view information about a specified parameter.

        Access Level: Read

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_GetParameter.html

        :stability: experimental
        '''
        return typing.cast("Ssm", jsii.invoke(self, "toGetParameter", []))

    @jsii.member(jsii_name="toGetParameterHistory")
    def to_get_parameter_history(self) -> "Ssm":
        '''(experimental) Grants permission to view details and changes for a specified parameter.

        Access Level: Read

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_GetParameterHistory.html

        :stability: experimental
        '''
        return typing.cast("Ssm", jsii.invoke(self, "toGetParameterHistory", []))

    @jsii.member(jsii_name="toGetParameters")
    def to_get_parameters(self) -> "Ssm":
        '''(experimental) Grants permission to view information about multiple specified parameters.

        Access Level: Read

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_GetParameters.html

        :stability: experimental
        '''
        return typing.cast("Ssm", jsii.invoke(self, "toGetParameters", []))

    @jsii.member(jsii_name="toGetParametersByPath")
    def to_get_parameters_by_path(self) -> "Ssm":
        '''(experimental) Grants permission to view information about parameters in a specified hierarchy.

        Access Level: Read

        Possible conditions:

        - .ifRecursive()

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_GetParametersByPath.html

        :stability: experimental
        '''
        return typing.cast("Ssm", jsii.invoke(self, "toGetParametersByPath", []))

    @jsii.member(jsii_name="toGetPatchBaseline")
    def to_get_patch_baseline(self) -> "Ssm":
        '''(experimental) Grants permission to view information about a specified patch baseline.

        Access Level: Read

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_GetPatchBaseline.html

        :stability: experimental
        '''
        return typing.cast("Ssm", jsii.invoke(self, "toGetPatchBaseline", []))

    @jsii.member(jsii_name="toGetPatchBaselineForPatchGroup")
    def to_get_patch_baseline_for_patch_group(self) -> "Ssm":
        '''(experimental) Grants permission to view the ID of the current patch baseline for a specified patch group.

        Access Level: Read

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_GetPatchBaselineForPatchGroup.html

        :stability: experimental
        '''
        return typing.cast("Ssm", jsii.invoke(self, "toGetPatchBaselineForPatchGroup", []))

    @jsii.member(jsii_name="toGetServiceSetting")
    def to_get_service_setting(self) -> "Ssm":
        '''(experimental) Grants permission to view the account-level setting for an AWS service.

        Access Level: Read

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_GetServiceSetting.html

        :stability: experimental
        '''
        return typing.cast("Ssm", jsii.invoke(self, "toGetServiceSetting", []))

    @jsii.member(jsii_name="toLabelParameterVersion")
    def to_label_parameter_version(self) -> "Ssm":
        '''(experimental) Grants permission to apply an identifying label to a specified version of a parameter.

        Access Level: Write

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_LabelParameterVersion.html

        :stability: experimental
        '''
        return typing.cast("Ssm", jsii.invoke(self, "toLabelParameterVersion", []))

    @jsii.member(jsii_name="toListAssociations")
    def to_list_associations(self) -> "Ssm":
        '''(experimental) Grants permission to list the associations for a specified SSM document or managed instance.

        Access Level: List

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_ListAssociations.html

        :stability: experimental
        '''
        return typing.cast("Ssm", jsii.invoke(self, "toListAssociations", []))

    @jsii.member(jsii_name="toListAssociationVersions")
    def to_list_association_versions(self) -> "Ssm":
        '''(experimental) Grants permission to list versions of the specified association.

        Access Level: List

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_ListAssociationVersions.html

        :stability: experimental
        '''
        return typing.cast("Ssm", jsii.invoke(self, "toListAssociationVersions", []))

    @jsii.member(jsii_name="toListCommandInvocations")
    def to_list_command_invocations(self) -> "Ssm":
        '''(experimental) Grants permission to list information about command invocations sent to a specified instance.

        Access Level: List

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_ListCommandInvocations.html

        :stability: experimental
        '''
        return typing.cast("Ssm", jsii.invoke(self, "toListCommandInvocations", []))

    @jsii.member(jsii_name="toListCommands")
    def to_list_commands(self) -> "Ssm":
        '''(experimental) Grants permission to list the commands sent to a specified instance.

        Access Level: List

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_ListCommands.html

        :stability: experimental
        '''
        return typing.cast("Ssm", jsii.invoke(self, "toListCommands", []))

    @jsii.member(jsii_name="toListComplianceItems")
    def to_list_compliance_items(self) -> "Ssm":
        '''(experimental) Grants permission to list compliance status for specified resource types on a specified resource.

        Access Level: List

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_ListComplianceItems.html

        :stability: experimental
        '''
        return typing.cast("Ssm", jsii.invoke(self, "toListComplianceItems", []))

    @jsii.member(jsii_name="toListComplianceSummaries")
    def to_list_compliance_summaries(self) -> "Ssm":
        '''(experimental) Grants permission to list a summary count of compliant and noncompliant resources for a specified compliance type.

        Access Level: List

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_ListComplianceSummaries.html

        :stability: experimental
        '''
        return typing.cast("Ssm", jsii.invoke(self, "toListComplianceSummaries", []))

    @jsii.member(jsii_name="toListDocumentMetadataHistory")
    def to_list_document_metadata_history(self) -> "Ssm":
        '''(experimental) Grants permission to view metadata history about a specified SSM document.

        Access Level: List

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_ListDocumentMetadataHistory.html

        :stability: experimental
        '''
        return typing.cast("Ssm", jsii.invoke(self, "toListDocumentMetadataHistory", []))

    @jsii.member(jsii_name="toListDocuments")
    def to_list_documents(self) -> "Ssm":
        '''(experimental) Grants permission to view information about a specified SSM document.

        Access Level: List

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_ListDocuments.html

        :stability: experimental
        '''
        return typing.cast("Ssm", jsii.invoke(self, "toListDocuments", []))

    @jsii.member(jsii_name="toListDocumentVersions")
    def to_list_document_versions(self) -> "Ssm":
        '''(experimental) Grants permission to list all versions of a specified document.

        Access Level: List

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_ListDocumentVersions.html

        :stability: experimental
        '''
        return typing.cast("Ssm", jsii.invoke(self, "toListDocumentVersions", []))

    @jsii.member(jsii_name="toListInstanceAssociations")
    def to_list_instance_associations(self) -> "Ssm":
        '''(experimental) Grants permission to SSM Agent to check for new State Manager associations (internal Systems Manager call).

        Access Level: List

        https://docs.aws.amazon.com/systems-manager/latest/userguide/systems-manager-setting-up-messageAPIs.html

        :stability: experimental
        '''
        return typing.cast("Ssm", jsii.invoke(self, "toListInstanceAssociations", []))

    @jsii.member(jsii_name="toListInventoryEntries")
    def to_list_inventory_entries(self) -> "Ssm":
        '''(experimental) Grants permission to view a list of specified inventory types for a specified instance.

        Access Level: List

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_ListInventoryEntries.html

        :stability: experimental
        '''
        return typing.cast("Ssm", jsii.invoke(self, "toListInventoryEntries", []))

    @jsii.member(jsii_name="toListOpsItemEvents")
    def to_list_ops_item_events(self) -> "Ssm":
        '''(experimental) Grants permission to view details about OpsItemEvents.

        Access Level: List

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_ListOpsItemEvents.html

        :stability: experimental
        '''
        return typing.cast("Ssm", jsii.invoke(self, "toListOpsItemEvents", []))

    @jsii.member(jsii_name="toListOpsItemRelatedItems")
    def to_list_ops_item_related_items(self) -> "Ssm":
        '''(experimental) Grants permission to view details about OpsItem RelatedItems.

        Access Level: List

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_ListOpsItemRelatedItems.html

        :stability: experimental
        '''
        return typing.cast("Ssm", jsii.invoke(self, "toListOpsItemRelatedItems", []))

    @jsii.member(jsii_name="toListOpsMetadata")
    def to_list_ops_metadata(self) -> "Ssm":
        '''(experimental) Grants permission to view a list of OpsMetadata objects.

        Access Level: List

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_ListOpsMetadata.html

        :stability: experimental
        '''
        return typing.cast("Ssm", jsii.invoke(self, "toListOpsMetadata", []))

    @jsii.member(jsii_name="toListResourceComplianceSummaries")
    def to_list_resource_compliance_summaries(self) -> "Ssm":
        '''(experimental) Grants permission to list resource-level summary count.

        Access Level: List

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_ListResourceComplianceSummaries.html

        :stability: experimental
        '''
        return typing.cast("Ssm", jsii.invoke(self, "toListResourceComplianceSummaries", []))

    @jsii.member(jsii_name="toListResourceDataSync")
    def to_list_resource_data_sync(self) -> "Ssm":
        '''(experimental) Grants permission to list information about resource data sync configurations in an account.

        Access Level: List

        Possible conditions:

        - .ifSyncType()

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_ListResourceDataSync.html

        :stability: experimental
        '''
        return typing.cast("Ssm", jsii.invoke(self, "toListResourceDataSync", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Ssm":
        '''(experimental) Grants permission to view a list of resource tags for a specified resource.

        Access Level: List

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("Ssm", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toModifyDocumentPermission")
    def to_modify_document_permission(self) -> "Ssm":
        '''(experimental) Grants permission to share a custom SSM document publicly or privately with specified AWS accounts.

        Access Level: Permissions management

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_ModifyDocumentPermission.html

        :stability: experimental
        '''
        return typing.cast("Ssm", jsii.invoke(self, "toModifyDocumentPermission", []))

    @jsii.member(jsii_name="toPutCalendar")
    def to_put_calendar(self) -> "Ssm":
        '''(experimental) Grants permission to create/edit a specific calendar.

        Access Level: Write

        :stability: experimental
        '''
        return typing.cast("Ssm", jsii.invoke(self, "toPutCalendar", []))

    @jsii.member(jsii_name="toPutComplianceItems")
    def to_put_compliance_items(self) -> "Ssm":
        '''(experimental) Grants permission to register a compliance type and other compliance details on a specified resource.

        Access Level: Write

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_PutComplianceItems.html

        :stability: experimental
        '''
        return typing.cast("Ssm", jsii.invoke(self, "toPutComplianceItems", []))

    @jsii.member(jsii_name="toPutConfigurePackageResult")
    def to_put_configure_package_result(self) -> "Ssm":
        '''(experimental) Grants permission to SSM Agent to generate a report of the results of specific agent requests (internal Systems Manager call).

        Access Level: Read

        :stability: experimental
        '''
        return typing.cast("Ssm", jsii.invoke(self, "toPutConfigurePackageResult", []))

    @jsii.member(jsii_name="toPutInventory")
    def to_put_inventory(self) -> "Ssm":
        '''(experimental) Grants permission to add or update inventory items on multiple specified managed instances.

        Access Level: Write

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_PutInventory.html

        :stability: experimental
        '''
        return typing.cast("Ssm", jsii.invoke(self, "toPutInventory", []))

    @jsii.member(jsii_name="toPutParameter")
    def to_put_parameter(self) -> "Ssm":
        '''(experimental) Grants permission to create an SSM parameter.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifOverwrite()

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_PutParameter.html

        :stability: experimental
        '''
        return typing.cast("Ssm", jsii.invoke(self, "toPutParameter", []))

    @jsii.member(jsii_name="toRegisterDefaultPatchBaseline")
    def to_register_default_patch_baseline(self) -> "Ssm":
        '''(experimental) Grants permission to specify the default patch baseline for an operating system type.

        Access Level: Write

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_RegisterDefaultPatchBaseline.html

        :stability: experimental
        '''
        return typing.cast("Ssm", jsii.invoke(self, "toRegisterDefaultPatchBaseline", []))

    @jsii.member(jsii_name="toRegisterManagedInstance")
    def to_register_managed_instance(self) -> "Ssm":
        '''(experimental) Grants permission to register a Systems Manager Agent.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/systems-manager/latest/userguide/systems-manager-setting-up-messageAPIs.html

        :stability: experimental
        '''
        return typing.cast("Ssm", jsii.invoke(self, "toRegisterManagedInstance", []))

    @jsii.member(jsii_name="toRegisterPatchBaselineForPatchGroup")
    def to_register_patch_baseline_for_patch_group(self) -> "Ssm":
        '''(experimental) Grants permission to specify the default patch baseline for a specified patch group.

        Access Level: Write

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_RegisterPatchBaselineForPatchGroup.html

        :stability: experimental
        '''
        return typing.cast("Ssm", jsii.invoke(self, "toRegisterPatchBaselineForPatchGroup", []))

    @jsii.member(jsii_name="toRegisterTargetWithMaintenanceWindow")
    def to_register_target_with_maintenance_window(self) -> "Ssm":
        '''(experimental) Grants permission to register a target with a specified maintenance window.

        Access Level: Write

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_RegisterTargetWithMaintenanceWindow.html

        :stability: experimental
        '''
        return typing.cast("Ssm", jsii.invoke(self, "toRegisterTargetWithMaintenanceWindow", []))

    @jsii.member(jsii_name="toRegisterTaskWithMaintenanceWindow")
    def to_register_task_with_maintenance_window(self) -> "Ssm":
        '''(experimental) Grants permission to register a task with a specified maintenance window.

        Access Level: Write

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_RegisterTaskWithMaintenanceWindow.html

        :stability: experimental
        '''
        return typing.cast("Ssm", jsii.invoke(self, "toRegisterTaskWithMaintenanceWindow", []))

    @jsii.member(jsii_name="toRemoveTagsFromResource")
    def to_remove_tags_from_resource(self) -> "Ssm":
        '''(experimental) Grants permission to remove a specified tag key from a specified resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_RemoveTagsFromResource.html

        :stability: experimental
        '''
        return typing.cast("Ssm", jsii.invoke(self, "toRemoveTagsFromResource", []))

    @jsii.member(jsii_name="toResetServiceSetting")
    def to_reset_service_setting(self) -> "Ssm":
        '''(experimental) Grants permission to reset the service setting for an AWS account to the default value.

        Access Level: Write

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_ResetServiceSetting.html

        :stability: experimental
        '''
        return typing.cast("Ssm", jsii.invoke(self, "toResetServiceSetting", []))

    @jsii.member(jsii_name="toResumeSession")
    def to_resume_session(self) -> "Ssm":
        '''(experimental) Grants permission to reconnect a Session Manager session to a managed instance.

        Access Level: Write

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_ResumeSession.html

        :stability: experimental
        '''
        return typing.cast("Ssm", jsii.invoke(self, "toResumeSession", []))

    @jsii.member(jsii_name="toSendAutomationSignal")
    def to_send_automation_signal(self) -> "Ssm":
        '''(experimental) Grants permission to send a signal to change the current behavior or status of a specified Automation execution.

        Access Level: Write

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_SendAutomationSignal.html

        :stability: experimental
        '''
        return typing.cast("Ssm", jsii.invoke(self, "toSendAutomationSignal", []))

    @jsii.member(jsii_name="toSendCommand")
    def to_send_command(self) -> "Ssm":
        '''(experimental) Grants permission to run commands on one or more specified managed instances.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()
        - .ifResourceTag()

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_SendCommand.html

        :stability: experimental
        '''
        return typing.cast("Ssm", jsii.invoke(self, "toSendCommand", []))

    @jsii.member(jsii_name="toStartAssociationsOnce")
    def to_start_associations_once(self) -> "Ssm":
        '''(experimental) Grants permission to run a specified association manually.

        Access Level: Write

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_StartAssociationsOnce.html

        :stability: experimental
        '''
        return typing.cast("Ssm", jsii.invoke(self, "toStartAssociationsOnce", []))

    @jsii.member(jsii_name="toStartAutomationExecution")
    def to_start_automation_execution(self) -> "Ssm":
        '''(experimental) Grants permission to initiate the execution of an Automation document.

        Access Level: Write

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_StartAutomationExecution.html

        :stability: experimental
        '''
        return typing.cast("Ssm", jsii.invoke(self, "toStartAutomationExecution", []))

    @jsii.member(jsii_name="toStartChangeRequestExecution")
    def to_start_change_request_execution(self) -> "Ssm":
        '''(experimental) Grants permission to initiate the execution of an Automation Change Template document.

        Access Level: Write

        Possible conditions:

        - .ifAutoApprove()

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_StartChangeRequestExecution.html

        :stability: experimental
        '''
        return typing.cast("Ssm", jsii.invoke(self, "toStartChangeRequestExecution", []))

    @jsii.member(jsii_name="toStartSession")
    def to_start_session(self) -> "Ssm":
        '''(experimental) Grants permission to initiate a connection to a specified target for a Session Manager session.

        Access Level: Write

        Possible conditions:

        - .ifSessionDocumentAccessCheck()
        - .ifResourceTag()
        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_StartSession.html

        :stability: experimental
        '''
        return typing.cast("Ssm", jsii.invoke(self, "toStartSession", []))

    @jsii.member(jsii_name="toStopAutomationExecution")
    def to_stop_automation_execution(self) -> "Ssm":
        '''(experimental) Grants permission to stop a specified Automation execution that is already in progress.

        Access Level: Write

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_StopAutomationExecution.html

        :stability: experimental
        '''
        return typing.cast("Ssm", jsii.invoke(self, "toStopAutomationExecution", []))

    @jsii.member(jsii_name="toTerminateSession")
    def to_terminate_session(self) -> "Ssm":
        '''(experimental) Grants permission to permanently end a Session Manager connection to an instance.

        Access Level: Write

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_TerminateSession.html

        :stability: experimental
        '''
        return typing.cast("Ssm", jsii.invoke(self, "toTerminateSession", []))

    @jsii.member(jsii_name="toUnlabelParameterVersion")
    def to_unlabel_parameter_version(self) -> "Ssm":
        '''(experimental) Grants permission to remove an identifying label from a specified version of a parameter.

        Access Level: Write

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_UnlabelParameterVersion.html

        :stability: experimental
        '''
        return typing.cast("Ssm", jsii.invoke(self, "toUnlabelParameterVersion", []))

    @jsii.member(jsii_name="toUpdateAssociation")
    def to_update_association(self) -> "Ssm":
        '''(experimental) Grants permission to update an association and immediately run the association on the specified targets.

        Access Level: Write

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_UpdateAssociation.html

        :stability: experimental
        '''
        return typing.cast("Ssm", jsii.invoke(self, "toUpdateAssociation", []))

    @jsii.member(jsii_name="toUpdateAssociationStatus")
    def to_update_association_status(self) -> "Ssm":
        '''(experimental) Grants permission to update the status of the SSM document associated with a specified instance.

        Access Level: Write

        Possible conditions:

        - .ifSourceInstanceARN()

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_UpdateAssociationStatus.html

        :stability: experimental
        '''
        return typing.cast("Ssm", jsii.invoke(self, "toUpdateAssociationStatus", []))

    @jsii.member(jsii_name="toUpdateDocument")
    def to_update_document(self) -> "Ssm":
        '''(experimental) Grants permission to update one or more values for an SSM document.

        Access Level: Write

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_UpdateDocument.html

        :stability: experimental
        '''
        return typing.cast("Ssm", jsii.invoke(self, "toUpdateDocument", []))

    @jsii.member(jsii_name="toUpdateDocumentDefaultVersion")
    def to_update_document_default_version(self) -> "Ssm":
        '''(experimental) Grants permission to change the default version of an SSM document.

        Access Level: Write

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_UpdateDocumentDefaultVersion.html

        :stability: experimental
        '''
        return typing.cast("Ssm", jsii.invoke(self, "toUpdateDocumentDefaultVersion", []))

    @jsii.member(jsii_name="toUpdateDocumentMetadata")
    def to_update_document_metadata(self) -> "Ssm":
        '''(experimental) Grants permission to update the metadata of an SSM document.

        Access Level: Write

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_UpdateDocumentMetadata.html

        :stability: experimental
        '''
        return typing.cast("Ssm", jsii.invoke(self, "toUpdateDocumentMetadata", []))

    @jsii.member(jsii_name="toUpdateInstanceAssociationStatus")
    def to_update_instance_association_status(self) -> "Ssm":
        '''(experimental) Grants permission to SSM Agent to update the status of the association that it is currently running (internal Systems Manager call).

        Access Level: Write

        Possible conditions:

        - .ifSourceInstanceARN()

        :stability: experimental
        '''
        return typing.cast("Ssm", jsii.invoke(self, "toUpdateInstanceAssociationStatus", []))

    @jsii.member(jsii_name="toUpdateInstanceInformation")
    def to_update_instance_information(self) -> "Ssm":
        '''(experimental) Grants permission to SSM Agent to send a heartbeat signal to the Systems Manager service in the cloud.

        Access Level: Write

        Possible conditions:

        - .ifSourceInstanceARN()

        https://docs.aws.amazon.com/systems-manager/latest/userguide/systems-manager-setting-up-messageAPIs.html

        :stability: experimental
        '''
        return typing.cast("Ssm", jsii.invoke(self, "toUpdateInstanceInformation", []))

    @jsii.member(jsii_name="toUpdateMaintenanceWindow")
    def to_update_maintenance_window(self) -> "Ssm":
        '''(experimental) Grants permission to update a specified maintenance window.

        Access Level: Write

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_UpdateMaintenanceWindow.html

        :stability: experimental
        '''
        return typing.cast("Ssm", jsii.invoke(self, "toUpdateMaintenanceWindow", []))

    @jsii.member(jsii_name="toUpdateMaintenanceWindowTarget")
    def to_update_maintenance_window_target(self) -> "Ssm":
        '''(experimental) Grants permission to update a specified maintenance window target.

        Access Level: Write

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_UpdateMaintenanceWindowTarget.html

        :stability: experimental
        '''
        return typing.cast("Ssm", jsii.invoke(self, "toUpdateMaintenanceWindowTarget", []))

    @jsii.member(jsii_name="toUpdateMaintenanceWindowTask")
    def to_update_maintenance_window_task(self) -> "Ssm":
        '''(experimental) Grants permission to update a specified maintenance window task.

        Access Level: Write

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_UpdateMaintenanceWindowTask.html

        :stability: experimental
        '''
        return typing.cast("Ssm", jsii.invoke(self, "toUpdateMaintenanceWindowTask", []))

    @jsii.member(jsii_name="toUpdateManagedInstanceRole")
    def to_update_managed_instance_role(self) -> "Ssm":
        '''(experimental) Grants permission to assign or change the IAM role assigned to a specified managed instance.

        Access Level: Write

        Possible conditions:

        - .ifResourceTag()

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_UpdateManagedInstanceRole.html

        :stability: experimental
        '''
        return typing.cast("Ssm", jsii.invoke(self, "toUpdateManagedInstanceRole", []))

    @jsii.member(jsii_name="toUpdateOpsItem")
    def to_update_ops_item(self) -> "Ssm":
        '''(experimental) Grants permission to edit or change an OpsItem.

        Access Level: Write

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_UpdateOpsItem.html

        :stability: experimental
        '''
        return typing.cast("Ssm", jsii.invoke(self, "toUpdateOpsItem", []))

    @jsii.member(jsii_name="toUpdateOpsMetadata")
    def to_update_ops_metadata(self) -> "Ssm":
        '''(experimental) Grants permission to update an OpsMetadata object.

        Access Level: Write

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_UpdateOpsMetadata.html

        :stability: experimental
        '''
        return typing.cast("Ssm", jsii.invoke(self, "toUpdateOpsMetadata", []))

    @jsii.member(jsii_name="toUpdatePatchBaseline")
    def to_update_patch_baseline(self) -> "Ssm":
        '''(experimental) Grants permission to update a specified patch baseline.

        Access Level: Write

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_UpdatePatchBaseline.html

        :stability: experimental
        '''
        return typing.cast("Ssm", jsii.invoke(self, "toUpdatePatchBaseline", []))

    @jsii.member(jsii_name="toUpdateResourceDataSync")
    def to_update_resource_data_sync(self) -> "Ssm":
        '''(experimental) Grants permission to update a resource data sync.

        Access Level: Write

        Possible conditions:

        - .ifSyncType()

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_UpdateResourceDataSync.html

        :stability: experimental
        '''
        return typing.cast("Ssm", jsii.invoke(self, "toUpdateResourceDataSync", []))

    @jsii.member(jsii_name="toUpdateServiceSetting")
    def to_update_service_setting(self) -> "Ssm":
        '''(experimental) Grants permission to update the service setting for an AWS account.

        Access Level: Write

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_UpdateServiceSetting.html

        :stability: experimental
        '''
        return typing.cast("Ssm", jsii.invoke(self, "toUpdateServiceSetting", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__83421e85744b060ab8bed456149ea385890368217b8670be522e3f72f30867cb)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__06312c7329b85d34e7013833ff47570ff02b88739c97cc9a5248b34a6529ba39)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class SsmContacts(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.SsmContacts",
):
    '''(experimental) Statement provider for service `ssm-contacts <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awssystemsmanagerincidentmanagercontacts.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `ssm-contacts <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awssystemsmanagerincidentmanagercontacts.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onContact")
    def on_contact(
        self,
        contact_alias: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "SsmContacts":
        '''(experimental) Adds a resource of type contact to the statement.

        https://docs.aws.amazon.com/incident-manager/latest/userguide/contacts.html

        :param contact_alias: - Identifier for the contactAlias.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bd2802743740474fb76e530e28b76773948261293aff3db2ff60c295689160ef)
            check_type(argname="argument contact_alias", value=contact_alias, expected_type=type_hints["contact_alias"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("SsmContacts", jsii.invoke(self, "onContact", [contact_alias, account, region, partition]))

    @jsii.member(jsii_name="onContactchannel")
    def on_contactchannel(
        self,
        contact_alias: builtins.str,
        contact_channel_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "SsmContacts":
        '''(experimental) Adds a resource of type contactchannel to the statement.

        https://docs.aws.amazon.com/incident-manager/latest/userguide/contacts.html

        :param contact_alias: - Identifier for the contactAlias.
        :param contact_channel_id: - Identifier for the contactChannelId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__19c5731637c76cc73ab88745aed38e6196d7c9b649ba10cc9edeaca904c3f9c8)
            check_type(argname="argument contact_alias", value=contact_alias, expected_type=type_hints["contact_alias"])
            check_type(argname="argument contact_channel_id", value=contact_channel_id, expected_type=type_hints["contact_channel_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("SsmContacts", jsii.invoke(self, "onContactchannel", [contact_alias, contact_channel_id, account, region, partition]))

    @jsii.member(jsii_name="onEngagement")
    def on_engagement(
        self,
        contact_alias: builtins.str,
        engagement_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "SsmContacts":
        '''(experimental) Adds a resource of type engagement to the statement.

        https://docs.aws.amazon.com/incident-manager/latest/userguide/escalation.html

        :param contact_alias: - Identifier for the contactAlias.
        :param engagement_id: - Identifier for the engagementId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8a7f6a55ffe26e86182ea73d3b82a9c79d3b832c15a9f8cdf8f63ac137017480)
            check_type(argname="argument contact_alias", value=contact_alias, expected_type=type_hints["contact_alias"])
            check_type(argname="argument engagement_id", value=engagement_id, expected_type=type_hints["engagement_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("SsmContacts", jsii.invoke(self, "onEngagement", [contact_alias, engagement_id, account, region, partition]))

    @jsii.member(jsii_name="onPage")
    def on_page(
        self,
        contact_alias: builtins.str,
        page_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "SsmContacts":
        '''(experimental) Adds a resource of type page to the statement.

        https://docs.aws.amazon.com/incident-manager/latest/userguide/escalation.html

        :param contact_alias: - Identifier for the contactAlias.
        :param page_id: - Identifier for the pageId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__aeebb11b41fcd9df199886c765cc58722b6bcc7c715c6d1c7ebe073bb4ec8a44)
            check_type(argname="argument contact_alias", value=contact_alias, expected_type=type_hints["contact_alias"])
            check_type(argname="argument page_id", value=page_id, expected_type=type_hints["page_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("SsmContacts", jsii.invoke(self, "onPage", [contact_alias, page_id, account, region, partition]))

    @jsii.member(jsii_name="toAcceptPage")
    def to_accept_page(self) -> "SsmContacts":
        '''(experimental) Grants permission to accept a page.

        Access Level: Write

        https://docs.aws.amazon.com/incident-manager/latest/APIReference/API_SSMContacts_AcceptPage.html

        :stability: experimental
        '''
        return typing.cast("SsmContacts", jsii.invoke(self, "toAcceptPage", []))

    @jsii.member(jsii_name="toActivateContactChannel")
    def to_activate_contact_channel(self) -> "SsmContacts":
        '''(experimental) Grants permission to activate a contact's contact channel.

        Access Level: Write

        https://docs.aws.amazon.com/incident-manager/latest/APIReference/API_SSMContacts_ActivateContactChannel.html

        :stability: experimental
        '''
        return typing.cast("SsmContacts", jsii.invoke(self, "toActivateContactChannel", []))

    @jsii.member(jsii_name="toAssociateContact")
    def to_associate_contact(self) -> "SsmContacts":
        '''(experimental) Grants permission to use a contact in an escalation plan.

        Access Level: Permissions management

        https://docs.aws.amazon.com/incident-manager/latest/APIReference/API_SSMContacts_AssociateContact.html

        :stability: experimental
        '''
        return typing.cast("SsmContacts", jsii.invoke(self, "toAssociateContact", []))

    @jsii.member(jsii_name="toCreateContact")
    def to_create_contact(self) -> "SsmContacts":
        '''(experimental) Grants permission to create a contact.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        Dependent actions:

        - ssm-contacts:AssociateContact

        https://docs.aws.amazon.com/incident-manager/latest/APIReference/API_SSMContacts_CreateContact.html

        :stability: experimental
        '''
        return typing.cast("SsmContacts", jsii.invoke(self, "toCreateContact", []))

    @jsii.member(jsii_name="toCreateContactChannel")
    def to_create_contact_channel(self) -> "SsmContacts":
        '''(experimental) Grants permission to create a contact channel for a contact.

        Access Level: Write

        https://docs.aws.amazon.com/incident-manager/latest/APIReference/API_SSMContacts_CreateContactChannel.html

        :stability: experimental
        '''
        return typing.cast("SsmContacts", jsii.invoke(self, "toCreateContactChannel", []))

    @jsii.member(jsii_name="toDeactivateContactChannel")
    def to_deactivate_contact_channel(self) -> "SsmContacts":
        '''(experimental) Grants permission to deactivate a contact's contact channel.

        Access Level: Write

        https://docs.aws.amazon.com/incident-manager/latest/APIReference/API_SSMContacts_DeactivateContactChannel.html

        :stability: experimental
        '''
        return typing.cast("SsmContacts", jsii.invoke(self, "toDeactivateContactChannel", []))

    @jsii.member(jsii_name="toDeleteContact")
    def to_delete_contact(self) -> "SsmContacts":
        '''(experimental) Grants permission to delete a contact.

        Access Level: Write

        https://docs.aws.amazon.com/incident-manager/latest/APIReference/API_SSMContacts_DeleteContact.html

        :stability: experimental
        '''
        return typing.cast("SsmContacts", jsii.invoke(self, "toDeleteContact", []))

    @jsii.member(jsii_name="toDeleteContactChannel")
    def to_delete_contact_channel(self) -> "SsmContacts":
        '''(experimental) Grants permission to delete a contact's contact channel.

        Access Level: Write

        https://docs.aws.amazon.com/incident-manager/latest/APIReference/API_SSMContacts_DeleteContactChannel.html

        :stability: experimental
        '''
        return typing.cast("SsmContacts", jsii.invoke(self, "toDeleteContactChannel", []))

    @jsii.member(jsii_name="toDescribeEngagement")
    def to_describe_engagement(self) -> "SsmContacts":
        '''(experimental) Grants permission to describe an engagement.

        Access Level: Read

        https://docs.aws.amazon.com/incident-manager/latest/APIReference/API_SSMContacts_DescribeEngagement.html

        :stability: experimental
        '''
        return typing.cast("SsmContacts", jsii.invoke(self, "toDescribeEngagement", []))

    @jsii.member(jsii_name="toDescribePage")
    def to_describe_page(self) -> "SsmContacts":
        '''(experimental) Grants permission to describe a page.

        Access Level: Read

        https://docs.aws.amazon.com/incident-manager/latest/APIReference/API_SSMContacts_DescribePage.html

        :stability: experimental
        '''
        return typing.cast("SsmContacts", jsii.invoke(self, "toDescribePage", []))

    @jsii.member(jsii_name="toGetContact")
    def to_get_contact(self) -> "SsmContacts":
        '''(experimental) Grants permission to get a contact.

        Access Level: Read

        https://docs.aws.amazon.com/incident-manager/latest/APIReference/API_SSMContacts_GetContact.html

        :stability: experimental
        '''
        return typing.cast("SsmContacts", jsii.invoke(self, "toGetContact", []))

    @jsii.member(jsii_name="toGetContactChannel")
    def to_get_contact_channel(self) -> "SsmContacts":
        '''(experimental) Grants permission to get a contact's contact channel.

        Access Level: Read

        https://docs.aws.amazon.com/incident-manager/latest/APIReference/API_SSMContacts_GetContactChannel.html

        :stability: experimental
        '''
        return typing.cast("SsmContacts", jsii.invoke(self, "toGetContactChannel", []))

    @jsii.member(jsii_name="toGetContactPolicy")
    def to_get_contact_policy(self) -> "SsmContacts":
        '''(experimental) Grants permission to get a contact's resource policy.

        Access Level: Read

        https://docs.aws.amazon.com/incident-manager/latest/APIReference/API_SSMContacts_GetContactPolicy.html

        :stability: experimental
        '''
        return typing.cast("SsmContacts", jsii.invoke(self, "toGetContactPolicy", []))

    @jsii.member(jsii_name="toListContactChannels")
    def to_list_contact_channels(self) -> "SsmContacts":
        '''(experimental) Grants permission to list all of a contact's contact channels.

        Access Level: List

        https://docs.aws.amazon.com/incident-manager/latest/APIReference/API_SSMContacts_ListContactChannels.html

        :stability: experimental
        '''
        return typing.cast("SsmContacts", jsii.invoke(self, "toListContactChannels", []))

    @jsii.member(jsii_name="toListContacts")
    def to_list_contacts(self) -> "SsmContacts":
        '''(experimental) Grants permission to list all contacts.

        Access Level: List

        https://docs.aws.amazon.com/incident-manager/latest/APIReference/API_SSMContacts_ListContacts.html

        :stability: experimental
        '''
        return typing.cast("SsmContacts", jsii.invoke(self, "toListContacts", []))

    @jsii.member(jsii_name="toListEngagements")
    def to_list_engagements(self) -> "SsmContacts":
        '''(experimental) Grants permission to list all engagements.

        Access Level: List

        https://docs.aws.amazon.com/incident-manager/latest/APIReference/API_SSMContacts_ListEngagements.html

        :stability: experimental
        '''
        return typing.cast("SsmContacts", jsii.invoke(self, "toListEngagements", []))

    @jsii.member(jsii_name="toListPageReceipts")
    def to_list_page_receipts(self) -> "SsmContacts":
        '''(experimental) Grants permission to list all receipts of a page.

        Access Level: List

        https://docs.aws.amazon.com/incident-manager/latest/APIReference/API_SSMContacts_ListPageReceipts.html

        :stability: experimental
        '''
        return typing.cast("SsmContacts", jsii.invoke(self, "toListPageReceipts", []))

    @jsii.member(jsii_name="toListPagesByContact")
    def to_list_pages_by_contact(self) -> "SsmContacts":
        '''(experimental) Grants permission to list all pages sent to a contact.

        Access Level: List

        https://docs.aws.amazon.com/incident-manager/latest/APIReference/API_SSMContacts_ListPagesByContact.html

        :stability: experimental
        '''
        return typing.cast("SsmContacts", jsii.invoke(self, "toListPagesByContact", []))

    @jsii.member(jsii_name="toListPagesByEngagement")
    def to_list_pages_by_engagement(self) -> "SsmContacts":
        '''(experimental) Grants permission to list all pages created in an engagement.

        Access Level: List

        https://docs.aws.amazon.com/incident-manager/latest/APIReference/API_SSMContacts_ListPagesByEngagement.html

        :stability: experimental
        '''
        return typing.cast("SsmContacts", jsii.invoke(self, "toListPagesByEngagement", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "SsmContacts":
        '''(experimental) Grants permission to view a list of resource tags for a specified resource.

        Access Level: Read

        https://docs.aws.amazon.com/incident-manager/latest/APIReference/API_SSMContacts_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("SsmContacts", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toPutContactPolicy")
    def to_put_contact_policy(self) -> "SsmContacts":
        '''(experimental) Grants permission to add a resource policy to a contact.

        Access Level: Write

        https://docs.aws.amazon.com/incident-manager/latest/APIReference/API_SSMContacts_PutContactPolicy.html

        :stability: experimental
        '''
        return typing.cast("SsmContacts", jsii.invoke(self, "toPutContactPolicy", []))

    @jsii.member(jsii_name="toSendActivationCode")
    def to_send_activation_code(self) -> "SsmContacts":
        '''(experimental) Grants permission to send the activation code of a contact's contact channel.

        Access Level: Write

        https://docs.aws.amazon.com/incident-manager/latest/APIReference/API_SSMContacts_SendActivationCode.html

        :stability: experimental
        '''
        return typing.cast("SsmContacts", jsii.invoke(self, "toSendActivationCode", []))

    @jsii.member(jsii_name="toStartEngagement")
    def to_start_engagement(self) -> "SsmContacts":
        '''(experimental) Grants permission to start an engagement.

        Access Level: Write

        https://docs.aws.amazon.com/incident-manager/latest/APIReference/API_SSMContacts_StartEngagement.html

        :stability: experimental
        '''
        return typing.cast("SsmContacts", jsii.invoke(self, "toStartEngagement", []))

    @jsii.member(jsii_name="toStopEngagement")
    def to_stop_engagement(self) -> "SsmContacts":
        '''(experimental) Grants permission to stop an engagement.

        Access Level: Write

        https://docs.aws.amazon.com/incident-manager/latest/APIReference/API_SSMContacts_StopEngagement.html

        :stability: experimental
        '''
        return typing.cast("SsmContacts", jsii.invoke(self, "toStopEngagement", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "SsmContacts":
        '''(experimental) Grants permission to add tags to a response plan.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/incident-manager/latest/APIReference/API_SSMContacts_TagResource.html

        :stability: experimental
        '''
        return typing.cast("SsmContacts", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "SsmContacts":
        '''(experimental) Grants permission to remove tags from a response plan.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/incident-manager/latest/APIReference/API_SSMContacts_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("SsmContacts", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateContact")
    def to_update_contact(self) -> "SsmContacts":
        '''(experimental) Grants permission to update a contact.

        Access Level: Write

        Dependent actions:

        - ssm-contacts:AssociateContact

        https://docs.aws.amazon.com/incident-manager/latest/APIReference/API_SSMContacts_UpdateContact.html

        :stability: experimental
        '''
        return typing.cast("SsmContacts", jsii.invoke(self, "toUpdateContact", []))

    @jsii.member(jsii_name="toUpdateContactChannel")
    def to_update_contact_channel(self) -> "SsmContacts":
        '''(experimental) Grants permission to update a contact's contact channel.

        Access Level: Write

        https://docs.aws.amazon.com/incident-manager/latest/APIReference/API_SSMContacts_UpdateContactChannel.html

        :stability: experimental
        '''
        return typing.cast("SsmContacts", jsii.invoke(self, "toUpdateContactChannel", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f2873c6ade2c61abf0e648122d2de66101819dd0ee8fd92ce63a254bf6ca71d1)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4fb80cf00c667e83b1b3a1d72eb38b388fb3884c941c838ff9236314836273aa)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class SsmGuiconnect(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.SsmGuiconnect",
):
    '''(experimental) Statement provider for service `ssm-guiconnect <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awssystemsmanagerguiconnect.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `ssm-guiconnect <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awssystemsmanagerguiconnect.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="toCancelConnection")
    def to_cancel_connection(self) -> "SsmGuiconnect":
        '''(experimental) Grants permission to terminate a GUI Connect session.

        Access Level: Write

        https://docs.aws.amazon.com/systems-manager/latest/userguide/fleet-rdp.html

        :stability: experimental
        '''
        return typing.cast("SsmGuiconnect", jsii.invoke(self, "toCancelConnection", []))

    @jsii.member(jsii_name="toGetConnection")
    def to_get_connection(self) -> "SsmGuiconnect":
        '''(experimental) Grants permission to get the metadata for a GUI Connect session.

        Access Level: Read

        https://docs.aws.amazon.com/systems-manager/latest/userguide/fleet-rdp.html

        :stability: experimental
        '''
        return typing.cast("SsmGuiconnect", jsii.invoke(self, "toGetConnection", []))

    @jsii.member(jsii_name="toStartConnection")
    def to_start_connection(self) -> "SsmGuiconnect":
        '''(experimental) Grants permission to start a GUI Connect session.

        Access Level: Write

        https://docs.aws.amazon.com/systems-manager/latest/userguide/fleet-rdp.html

        :stability: experimental
        '''
        return typing.cast("SsmGuiconnect", jsii.invoke(self, "toStartConnection", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4317ae7277acb2ad08b668bec0ee9102106561bfdca1ca3645aa366a5bb5eb38)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8b998051aba785635b700b8d6f014fe82b5ad138d2acb63bf302824224e0e4a1)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class SsmIncidents(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.SsmIncidents",
):
    '''(experimental) Statement provider for service `ssm-incidents <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awssystemsmanagerincidentmanager.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `ssm-incidents <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awssystemsmanagerincidentmanager.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onIncidentRecord")
    def on_incident_record(
        self,
        response_plan: builtins.str,
        incident_record: builtins.str,
        account: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "SsmIncidents":
        '''(experimental) Adds a resource of type incident-record to the statement.

        https://docs.aws.amazon.com/incident-manager/latest/userguide/tracking-details.html

        :param response_plan: - Identifier for the responsePlan.
        :param incident_record: - Identifier for the incidentRecord.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fe39e9dcd3e3d12b46232a2dc0358f47b8c629a9ff1eb1440879eca4bddd8c0a)
            check_type(argname="argument response_plan", value=response_plan, expected_type=type_hints["response_plan"])
            check_type(argname="argument incident_record", value=incident_record, expected_type=type_hints["incident_record"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("SsmIncidents", jsii.invoke(self, "onIncidentRecord", [response_plan, incident_record, account, partition]))

    @jsii.member(jsii_name="onReplicationSet")
    def on_replication_set(
        self,
        replication_set: builtins.str,
        account: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "SsmIncidents":
        '''(experimental) Adds a resource of type replication-set to the statement.

        https://docs.aws.amazon.com/incident-manager/latest/userguide/disaster-recovery-resiliency.html#replication

        :param replication_set: - Identifier for the replicationSet.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3f241253dd8dee01ba72f41a8f5bdbfd65b0887199ce734990a9d3dae65425ef)
            check_type(argname="argument replication_set", value=replication_set, expected_type=type_hints["replication_set"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("SsmIncidents", jsii.invoke(self, "onReplicationSet", [replication_set, account, partition]))

    @jsii.member(jsii_name="onResponsePlan")
    def on_response_plan(
        self,
        response_plan: builtins.str,
        account: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "SsmIncidents":
        '''(experimental) Adds a resource of type response-plan to the statement.

        https://docs.aws.amazon.com/incident-manager/latest/userguide/response-plans.html

        :param response_plan: - Identifier for the responsePlan.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8c7c1357f884f2a2e3da57e2f6ae71f56cc28ec2002604b3dffa2746b02589be)
            check_type(argname="argument response_plan", value=response_plan, expected_type=type_hints["response_plan"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("SsmIncidents", jsii.invoke(self, "onResponsePlan", [response_plan, account, partition]))

    @jsii.member(jsii_name="toCreateReplicationSet")
    def to_create_replication_set(self) -> "SsmIncidents":
        '''(experimental) Grants permission to create a replication set.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        Dependent actions:

        - iam:CreateServiceLinkedRole
        - ssm-incidents:TagResource

        https://docs.aws.amazon.com/incident-manager/latest/APIReference/API_CreateReplicationSet.html

        :stability: experimental
        '''
        return typing.cast("SsmIncidents", jsii.invoke(self, "toCreateReplicationSet", []))

    @jsii.member(jsii_name="toCreateResponsePlan")
    def to_create_response_plan(self) -> "SsmIncidents":
        '''(experimental) Grants permission to create a response plan.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        Dependent actions:

        - iam:PassRole
        - ssm-incidents:TagResource

        https://docs.aws.amazon.com/incident-manager/latest/APIReference/API_CreateResponsePlan.html

        :stability: experimental
        '''
        return typing.cast("SsmIncidents", jsii.invoke(self, "toCreateResponsePlan", []))

    @jsii.member(jsii_name="toCreateTimelineEvent")
    def to_create_timeline_event(self) -> "SsmIncidents":
        '''(experimental) Grants permission to create a timeline event for an incident record.

        Access Level: Write

        https://docs.aws.amazon.com/incident-manager/latest/APIReference/API_CreateTimelineEvent.html

        :stability: experimental
        '''
        return typing.cast("SsmIncidents", jsii.invoke(self, "toCreateTimelineEvent", []))

    @jsii.member(jsii_name="toDeleteIncidentRecord")
    def to_delete_incident_record(self) -> "SsmIncidents":
        '''(experimental) Grants permission to delete an incident record.

        Access Level: Write

        https://docs.aws.amazon.com/incident-manager/latest/APIReference/API_DeleteIncidentRecord.html

        :stability: experimental
        '''
        return typing.cast("SsmIncidents", jsii.invoke(self, "toDeleteIncidentRecord", []))

    @jsii.member(jsii_name="toDeleteReplicationSet")
    def to_delete_replication_set(self) -> "SsmIncidents":
        '''(experimental) Grants permission to delete a replication set.

        Access Level: Write

        https://docs.aws.amazon.com/incident-manager/latest/APIReference/API_DeleteReplicationSet.html

        :stability: experimental
        '''
        return typing.cast("SsmIncidents", jsii.invoke(self, "toDeleteReplicationSet", []))

    @jsii.member(jsii_name="toDeleteResourcePolicy")
    def to_delete_resource_policy(self) -> "SsmIncidents":
        '''(experimental) Grants permission to delete resource policy from a response plan.

        Access Level: Permissions management

        https://docs.aws.amazon.com/incident-manager/latest/APIReference/API_DeleteResourcePolicy.html

        :stability: experimental
        '''
        return typing.cast("SsmIncidents", jsii.invoke(self, "toDeleteResourcePolicy", []))

    @jsii.member(jsii_name="toDeleteResponsePlan")
    def to_delete_response_plan(self) -> "SsmIncidents":
        '''(experimental) Grants permission to delete a response plan.

        Access Level: Write

        https://docs.aws.amazon.com/incident-manager/latest/APIReference/API_DeleteResponsePlan.html

        :stability: experimental
        '''
        return typing.cast("SsmIncidents", jsii.invoke(self, "toDeleteResponsePlan", []))

    @jsii.member(jsii_name="toDeleteTimelineEvent")
    def to_delete_timeline_event(self) -> "SsmIncidents":
        '''(experimental) Grants permission to delete a timeline event.

        Access Level: Write

        https://docs.aws.amazon.com/incident-manager/latest/APIReference/API_DeleteTimelineEvent.html

        :stability: experimental
        '''
        return typing.cast("SsmIncidents", jsii.invoke(self, "toDeleteTimelineEvent", []))

    @jsii.member(jsii_name="toGetIncidentRecord")
    def to_get_incident_record(self) -> "SsmIncidents":
        '''(experimental) Grants permission to view the contents of an incident record.

        Access Level: Read

        https://docs.aws.amazon.com/incident-manager/latest/APIReference/API_GetIncidentRecord.html

        :stability: experimental
        '''
        return typing.cast("SsmIncidents", jsii.invoke(self, "toGetIncidentRecord", []))

    @jsii.member(jsii_name="toGetReplicationSet")
    def to_get_replication_set(self) -> "SsmIncidents":
        '''(experimental) Grants permission to view the replication set.

        Access Level: Read

        https://docs.aws.amazon.com/incident-manager/latest/APIReference/API_GetReplicationSet.html

        :stability: experimental
        '''
        return typing.cast("SsmIncidents", jsii.invoke(self, "toGetReplicationSet", []))

    @jsii.member(jsii_name="toGetResourcePolicies")
    def to_get_resource_policies(self) -> "SsmIncidents":
        '''(experimental) Grants permission to view resource policies of a response plan.

        Access Level: Read

        https://docs.aws.amazon.com/incident-manager/latest/APIReference/API_GetResourcePolicies.html

        :stability: experimental
        '''
        return typing.cast("SsmIncidents", jsii.invoke(self, "toGetResourcePolicies", []))

    @jsii.member(jsii_name="toGetResponsePlan")
    def to_get_response_plan(self) -> "SsmIncidents":
        '''(experimental) Grants permission to view the contents of a specified response plan.

        Access Level: Read

        https://docs.aws.amazon.com/incident-manager/latest/APIReference/API_GetResponsePlan.html

        :stability: experimental
        '''
        return typing.cast("SsmIncidents", jsii.invoke(self, "toGetResponsePlan", []))

    @jsii.member(jsii_name="toGetTimelineEvent")
    def to_get_timeline_event(self) -> "SsmIncidents":
        '''(experimental) Grants permission to view a timeline event.

        Access Level: Read

        https://docs.aws.amazon.com/incident-manager/latest/APIReference/API_GetTimelineEvent.html

        :stability: experimental
        '''
        return typing.cast("SsmIncidents", jsii.invoke(self, "toGetTimelineEvent", []))

    @jsii.member(jsii_name="toListIncidentRecords")
    def to_list_incident_records(self) -> "SsmIncidents":
        '''(experimental) Grants permission to list the contents of all incident records.

        Access Level: List

        https://docs.aws.amazon.com/incident-manager/latest/APIReference/API_ListIncidentRecords.html

        :stability: experimental
        '''
        return typing.cast("SsmIncidents", jsii.invoke(self, "toListIncidentRecords", []))

    @jsii.member(jsii_name="toListRelatedItems")
    def to_list_related_items(self) -> "SsmIncidents":
        '''(experimental) Grants permission to list related items of an incident records.

        Access Level: List

        https://docs.aws.amazon.com/incident-manager/latest/APIReference/API_ListRelatedItems.html

        :stability: experimental
        '''
        return typing.cast("SsmIncidents", jsii.invoke(self, "toListRelatedItems", []))

    @jsii.member(jsii_name="toListReplicationSets")
    def to_list_replication_sets(self) -> "SsmIncidents":
        '''(experimental) Grants permission to list all replication sets.

        Access Level: List

        https://docs.aws.amazon.com/incident-manager/latest/APIReference/API_ListReplicationSets.html

        :stability: experimental
        '''
        return typing.cast("SsmIncidents", jsii.invoke(self, "toListReplicationSets", []))

    @jsii.member(jsii_name="toListResponsePlans")
    def to_list_response_plans(self) -> "SsmIncidents":
        '''(experimental) Grants permission to list all response plans.

        Access Level: List

        https://docs.aws.amazon.com/incident-manager/latest/APIReference/API_ListResponsePlans.html

        :stability: experimental
        '''
        return typing.cast("SsmIncidents", jsii.invoke(self, "toListResponsePlans", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "SsmIncidents":
        '''(experimental) Grants permission to view a list of resource tags for a specified resource.

        Access Level: Read

        https://docs.aws.amazon.com/incident-manager/latest/APIReference/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("SsmIncidents", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toListTimelineEvents")
    def to_list_timeline_events(self) -> "SsmIncidents":
        '''(experimental) Grants permission to list all timeline events for an incident record.

        Access Level: List

        https://docs.aws.amazon.com/incident-manager/latest/APIReference/API_ListTimelineEvents.html

        :stability: experimental
        '''
        return typing.cast("SsmIncidents", jsii.invoke(self, "toListTimelineEvents", []))

    @jsii.member(jsii_name="toPutResourcePolicy")
    def to_put_resource_policy(self) -> "SsmIncidents":
        '''(experimental) Grants permission to put resource policy on a response plan.

        Access Level: Permissions management

        https://docs.aws.amazon.com/incident-manager/latest/APIReference/API_PutResourcePolicy.html

        :stability: experimental
        '''
        return typing.cast("SsmIncidents", jsii.invoke(self, "toPutResourcePolicy", []))

    @jsii.member(jsii_name="toStartIncident")
    def to_start_incident(self) -> "SsmIncidents":
        '''(experimental) Grants permission to start a new incident using a response plan.

        Access Level: Write

        https://docs.aws.amazon.com/incident-manager/latest/APIReference/API_StartIncident.html

        :stability: experimental
        '''
        return typing.cast("SsmIncidents", jsii.invoke(self, "toStartIncident", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "SsmIncidents":
        '''(experimental) Grants permission to add tags to a response plan.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/incident-manager/latest/APIReference/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("SsmIncidents", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "SsmIncidents":
        '''(experimental) Grants permission to remove tags from a response plan.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/incident-manager/latest/APIReference/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("SsmIncidents", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateDeletionProtection")
    def to_update_deletion_protection(self) -> "SsmIncidents":
        '''(experimental) Grants permission to update replication set deletion protection.

        Access Level: Write

        https://docs.aws.amazon.com/incident-manager/latest/APIReference/API_UpdateDeletionProtection.html

        :stability: experimental
        '''
        return typing.cast("SsmIncidents", jsii.invoke(self, "toUpdateDeletionProtection", []))

    @jsii.member(jsii_name="toUpdateIncidentRecord")
    def to_update_incident_record(self) -> "SsmIncidents":
        '''(experimental) Grants permission to update the contents of an incident record.

        Access Level: Write

        https://docs.aws.amazon.com/incident-manager/latest/APIReference/API_UpdateIncidentRecord.html

        :stability: experimental
        '''
        return typing.cast("SsmIncidents", jsii.invoke(self, "toUpdateIncidentRecord", []))

    @jsii.member(jsii_name="toUpdateRelatedItems")
    def to_update_related_items(self) -> "SsmIncidents":
        '''(experimental) Grants permission to update related items of an incident record.

        Access Level: Write

        https://docs.aws.amazon.com/incident-manager/latest/APIReference/API_UpdateRelatedItems.html

        :stability: experimental
        '''
        return typing.cast("SsmIncidents", jsii.invoke(self, "toUpdateRelatedItems", []))

    @jsii.member(jsii_name="toUpdateReplicationSet")
    def to_update_replication_set(self) -> "SsmIncidents":
        '''(experimental) Grants permission to update a replication set.

        Access Level: Write

        https://docs.aws.amazon.com/incident-manager/latest/APIReference/API_UpdateReplicationSet.html

        :stability: experimental
        '''
        return typing.cast("SsmIncidents", jsii.invoke(self, "toUpdateReplicationSet", []))

    @jsii.member(jsii_name="toUpdateResponsePlan")
    def to_update_response_plan(self) -> "SsmIncidents":
        '''(experimental) Grants permission to update the contents of a response plan.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        Dependent actions:

        - iam:PassRole
        - ssm-incidents:TagResource

        https://docs.aws.amazon.com/incident-manager/latest/APIReference/API_UpdateResponsePlan.html

        :stability: experimental
        '''
        return typing.cast("SsmIncidents", jsii.invoke(self, "toUpdateResponsePlan", []))

    @jsii.member(jsii_name="toUpdateTimelineEvent")
    def to_update_timeline_event(self) -> "SsmIncidents":
        '''(experimental) Grants permission to update a timeline event.

        Access Level: Write

        https://docs.aws.amazon.com/incident-manager/latest/APIReference/API_UpdateTimelineEvent.html

        :stability: experimental
        '''
        return typing.cast("SsmIncidents", jsii.invoke(self, "toUpdateTimelineEvent", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fd2137d103bc955eb8909b4720debcb23c7349b8bd0a30157ab532216c95bf32)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f59307be424033966fa85d57196d811c873f021c60fd4c657f148840c6f08d41)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class SsmSap(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.SsmSap",
):
    '''(experimental) Statement provider for service `ssm-sap <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awssystemsmanagerforsap.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `ssm-sap <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awssystemsmanagerforsap.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onApplication")
    def on_application(
        self,
        application_type: builtins.str,
        application_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "SsmSap":
        '''(experimental) Adds a resource of type application to the statement.

        https://docs.aws.amazon.com/systems-manager/index.html

        :param application_type: - Identifier for the applicationType.
        :param application_id: - Identifier for the applicationId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6d327abfa8709efc8395b37a01f81d1a31adb69cf97b851e5d24995a7c3fbdc6)
            check_type(argname="argument application_type", value=application_type, expected_type=type_hints["application_type"])
            check_type(argname="argument application_id", value=application_id, expected_type=type_hints["application_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("SsmSap", jsii.invoke(self, "onApplication", [application_type, application_id, account, region, partition]))

    @jsii.member(jsii_name="onDatabase")
    def on_database(
        self,
        application_type: builtins.str,
        application_id: builtins.str,
        database_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "SsmSap":
        '''(experimental) Adds a resource of type database to the statement.

        https://docs.aws.amazon.com/systems-manager/index.html

        :param application_type: - Identifier for the applicationType.
        :param application_id: - Identifier for the applicationId.
        :param database_id: - Identifier for the databaseId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__31a92d4d321aac370a0b24d3728971aeaf7e98f75b57be48c443d8482531858c)
            check_type(argname="argument application_type", value=application_type, expected_type=type_hints["application_type"])
            check_type(argname="argument application_id", value=application_id, expected_type=type_hints["application_id"])
            check_type(argname="argument database_id", value=database_id, expected_type=type_hints["database_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("SsmSap", jsii.invoke(self, "onDatabase", [application_type, application_id, database_id, account, region, partition]))

    @jsii.member(jsii_name="toBackupDatabase")
    def to_backup_database(self) -> "SsmSap":
        '''(experimental) Grants permission to perform backup operation on a specified database.

        Access Level: Write

        https://docs.aws.amazon.com/systems-manager/index.html

        :stability: experimental
        '''
        return typing.cast("SsmSap", jsii.invoke(self, "toBackupDatabase", []))

    @jsii.member(jsii_name="toDeleteResourcePermission")
    def to_delete_resource_permission(self) -> "SsmSap":
        '''(experimental) Grants permission to delete the SSM for SAP level resource permissions associated with a SSM for SAP database resource.

        Access Level: Write

        https://docs.aws.amazon.com/systems-manager/index.html

        :stability: experimental
        '''
        return typing.cast("SsmSap", jsii.invoke(self, "toDeleteResourcePermission", []))

    @jsii.member(jsii_name="toDeregisterApplication")
    def to_deregister_application(self) -> "SsmSap":
        '''(experimental) Grants permission to deregister an SAP application with SSM for SAP.

        Access Level: Write

        https://docs.aws.amazon.com/systems-manager/index.html

        :stability: experimental
        '''
        return typing.cast("SsmSap", jsii.invoke(self, "toDeregisterApplication", []))

    @jsii.member(jsii_name="toGetApplication")
    def to_get_application(self) -> "SsmSap":
        '''(experimental) Grants permission to access information about an application registered with SSM for SAP by providing the application ID or application ARN.

        Access Level: Read

        https://docs.aws.amazon.com/systems-manager/index.html

        :stability: experimental
        '''
        return typing.cast("SsmSap", jsii.invoke(self, "toGetApplication", []))

    @jsii.member(jsii_name="toGetComponent")
    def to_get_component(self) -> "SsmSap":
        '''(experimental) Grants permission to access information about a component registered with SSM for SAP by providing the application ID and component ID.

        Access Level: Read

        https://docs.aws.amazon.com/systems-manager/index.html

        :stability: experimental
        '''
        return typing.cast("SsmSap", jsii.invoke(self, "toGetComponent", []))

    @jsii.member(jsii_name="toGetDatabase")
    def to_get_database(self) -> "SsmSap":
        '''(experimental) Grants permission to access information about a database registered with SSM for SAP by providing the application ID, component ID, and database ID.

        Access Level: Read

        https://docs.aws.amazon.com/systems-manager/index.html

        :stability: experimental
        '''
        return typing.cast("SsmSap", jsii.invoke(self, "toGetDatabase", []))

    @jsii.member(jsii_name="toGetOperation")
    def to_get_operation(self) -> "SsmSap":
        '''(experimental) Grants permission to access information about an operation by providing its operation ID.

        Access Level: Read

        https://docs.aws.amazon.com/systems-manager/index.html

        :stability: experimental
        '''
        return typing.cast("SsmSap", jsii.invoke(self, "toGetOperation", []))

    @jsii.member(jsii_name="toGetResourcePermission")
    def to_get_resource_permission(self) -> "SsmSap":
        '''(experimental) Grants permission to get the SSM for SAP level resource permissions associated with a SSM for SAP database resource.

        Access Level: Read

        https://docs.aws.amazon.com/systems-manager/index.html

        :stability: experimental
        '''
        return typing.cast("SsmSap", jsii.invoke(self, "toGetResourcePermission", []))

    @jsii.member(jsii_name="toListApplications")
    def to_list_applications(self) -> "SsmSap":
        '''(experimental) Grants permission to retrieve a list of all applications registered with SSM for SAP under the customer AWS account.

        Access Level: List

        https://docs.aws.amazon.com/systems-manager/index.html

        :stability: experimental
        '''
        return typing.cast("SsmSap", jsii.invoke(self, "toListApplications", []))

    @jsii.member(jsii_name="toListComponents")
    def to_list_components(self) -> "SsmSap":
        '''(experimental) Grants permission to retrieve a list of all components in the account of customer, or a specific application.

        Access Level: List

        https://docs.aws.amazon.com/systems-manager/index.html

        :stability: experimental
        '''
        return typing.cast("SsmSap", jsii.invoke(self, "toListComponents", []))

    @jsii.member(jsii_name="toListDatabases")
    def to_list_databases(self) -> "SsmSap":
        '''(experimental) Grants permission to retrieve a list of all databases in the account of customer, or a specific application.

        Access Level: List

        https://docs.aws.amazon.com/systems-manager/index.html

        :stability: experimental
        '''
        return typing.cast("SsmSap", jsii.invoke(self, "toListDatabases", []))

    @jsii.member(jsii_name="toListOperations")
    def to_list_operations(self) -> "SsmSap":
        '''(experimental) Grants permission to retrieve a list of all operations in the account of customer, additional filters can be applied.

        Access Level: List

        https://docs.aws.amazon.com/systems-manager/index.html

        :stability: experimental
        '''
        return typing.cast("SsmSap", jsii.invoke(self, "toListOperations", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "SsmSap":
        '''(experimental) Grants permission to list the tags on a specified resource ARN.

        Access Level: Read

        https://docs.aws.amazon.com/systems-manager/index.html

        :stability: experimental
        '''
        return typing.cast("SsmSap", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toPutResourcePermission")
    def to_put_resource_permission(self) -> "SsmSap":
        '''(experimental) Grants permission to add the SSM for SAP level resource permissions associated with a SSM for SAP database resource.

        Access Level: Write

        https://docs.aws.amazon.com/systems-manager/index.html

        :stability: experimental
        '''
        return typing.cast("SsmSap", jsii.invoke(self, "toPutResourcePermission", []))

    @jsii.member(jsii_name="toRegisterApplication")
    def to_register_application(self) -> "SsmSap":
        '''(experimental) Grants permission to registers an SAP application with SSM for SAP.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/systems-manager/index.html

        :stability: experimental
        '''
        return typing.cast("SsmSap", jsii.invoke(self, "toRegisterApplication", []))

    @jsii.member(jsii_name="toRestoreDatabase")
    def to_restore_database(self) -> "SsmSap":
        '''(experimental) Grants permission to restore a database from another database.

        Access Level: Write

        https://docs.aws.amazon.com/systems-manager/index.html

        :stability: experimental
        '''
        return typing.cast("SsmSap", jsii.invoke(self, "toRestoreDatabase", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "SsmSap":
        '''(experimental) Grants permission to tag a specified resource ARN.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/systems-manager/index.html

        :stability: experimental
        '''
        return typing.cast("SsmSap", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "SsmSap":
        '''(experimental) Grants permission to remove tags from a specified resource ARN.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/systems-manager/index.html

        :stability: experimental
        '''
        return typing.cast("SsmSap", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateApplicationSettings")
    def to_update_application_settings(self) -> "SsmSap":
        '''(experimental) Grants permission to update settings of a registered SSM for SAP application.

        Access Level: Write

        https://docs.aws.amazon.com/systems-manager/index.html

        :stability: experimental
        '''
        return typing.cast("SsmSap", jsii.invoke(self, "toUpdateApplicationSettings", []))

    @jsii.member(jsii_name="toUpdateHANABackupSettings")
    def to_update_hana_backup_settings(self) -> "SsmSap":
        '''(experimental) Grants permission to update the HANA backup settings of a specified database.

        Access Level: Write

        https://docs.aws.amazon.com/systems-manager/index.html

        :stability: experimental
        '''
        return typing.cast("SsmSap", jsii.invoke(self, "toUpdateHANABackupSettings", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d38fb1ecb5165a9ce5246a40957b8d46ab8fecbf6d31d4026da75a0f5b75cb12)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__208d6613cd947b37b66c83c7bbb4dd250d68d7b0eb5239864182dfb418a46494)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Ssmmessages(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Ssmmessages",
):
    '''(experimental) Statement provider for service `ssmmessages <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonsessionmanagermessagegatewayservice.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `ssmmessages <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonsessionmanagermessagegatewayservice.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="ifSsmSourceInstanceARN")
    def if_ssm_source_instance_arn(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Ssmmessages":
        '''(experimental) Filters access by verifying the Amazon Resource Name (ARN) of the AWS Systems Manager's managed instance from which the request is made.

        This key is not present when the request comes from the managed instance authenticated with an IAM role associated with EC2 instance profile

        https://docs.aws.amazon.com/service-authorization/latest/reference/list_awssystemsmanager.html#awssystemsmanager-policy-keys

        Applies to actions:

        - .toCreateControlChannel()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__36bcc948cc631efce07c90c39fd3297cbee20805c5778e25c9454e5623270362)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Ssmmessages", jsii.invoke(self, "ifSsmSourceInstanceARN", [value, operator]))

    @jsii.member(jsii_name="toCreateControlChannel")
    def to_create_control_channel(self) -> "Ssmmessages":
        '''(experimental) Grants permission to register a control channel for an instance to send control messages to Systems Manager service.

        Access Level: Write

        Possible conditions:

        - .ifSsmSourceInstanceARN()

        https://docs.aws.amazon.com/systems-manager/latest/userguide/getting-started-create-iam-instance-profile.html

        :stability: experimental
        '''
        return typing.cast("Ssmmessages", jsii.invoke(self, "toCreateControlChannel", []))

    @jsii.member(jsii_name="toCreateDataChannel")
    def to_create_data_channel(self) -> "Ssmmessages":
        '''(experimental) Grants permission to register a data channel for an instance to send data messages to Systems Manager service.

        Access Level: Write

        https://docs.aws.amazon.com/systems-manager/latest/userguide/getting-started-create-iam-instance-profile.html

        :stability: experimental
        '''
        return typing.cast("Ssmmessages", jsii.invoke(self, "toCreateDataChannel", []))

    @jsii.member(jsii_name="toOpenControlChannel")
    def to_open_control_channel(self) -> "Ssmmessages":
        '''(experimental) Grants permission to open a websocket connection for a registered control channel stream from an instance to Systems Manager service.

        Access Level: Write

        https://docs.aws.amazon.com/systems-manager/latest/userguide/getting-started-create-iam-instance-profile.html

        :stability: experimental
        '''
        return typing.cast("Ssmmessages", jsii.invoke(self, "toOpenControlChannel", []))

    @jsii.member(jsii_name="toOpenDataChannel")
    def to_open_data_channel(self) -> "Ssmmessages":
        '''(experimental) Grants permission to open a websocket connection for a registered data channel stream from an instance to Systems Manager service.

        Access Level: Write

        https://docs.aws.amazon.com/systems-manager/latest/userguide/getting-started-create-iam-instance-profile.html

        :stability: experimental
        '''
        return typing.cast("Ssmmessages", jsii.invoke(self, "toOpenDataChannel", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9c7bb119b02a550f1b56110137ee6931cae32fa24b38fc540ac84896fce94439)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1702d2754e5720ec485210bd006e3ff463833c6b80b405cc2269fd70422bb1bb)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Sso(PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Sso"):
    '''(experimental) Statement provider for service `sso <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiamidentitycentersuccessortoawssinglesign-on.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `sso <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiamidentitycentersuccessortoawssinglesign-on.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onAccount")
    def on_account(
        self,
        account_id: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Sso":
        '''(experimental) Adds a resource of type Account to the statement.

        https://docs.aws.amazon.com/singlesignon/latest/userguide/manage-your-accounts.html

        :param account_id: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a77f0ee5f1935a71160bccd4f8dfe7152202b4145113237c5cbb8035d8154b81)
            check_type(argname="argument account_id", value=account_id, expected_type=type_hints["account_id"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Sso", jsii.invoke(self, "onAccount", [account_id, partition]))

    @jsii.member(jsii_name="onInstance")
    def on_instance(
        self,
        instance_id: builtins.str,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Sso":
        '''(experimental) Adds a resource of type Instance to the statement.

        https://docs.aws.amazon.com/singlesignon/latest/userguide/step1.html

        :param instance_id: - Identifier for the instanceId.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ec5434820943d0c10203eb7aba808e00457ec135b330893e1da80000a9c22e94)
            check_type(argname="argument instance_id", value=instance_id, expected_type=type_hints["instance_id"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Sso", jsii.invoke(self, "onInstance", [instance_id, partition]))

    @jsii.member(jsii_name="onPermissionSet")
    def on_permission_set(
        self,
        instance_id: builtins.str,
        permission_set_id: builtins.str,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Sso":
        '''(experimental) Adds a resource of type PermissionSet to the statement.

        https://docs.aws.amazon.com/singlesignon/latest/userguide/permissionsetsconcept.html

        :param instance_id: - Identifier for the instanceId.
        :param permission_set_id: - Identifier for the permissionSetId.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e85cdffa870429a96d8114bdecf697e3a5cdd88ca647f5a3dbaa1cf3f000bd48)
            check_type(argname="argument instance_id", value=instance_id, expected_type=type_hints["instance_id"])
            check_type(argname="argument permission_set_id", value=permission_set_id, expected_type=type_hints["permission_set_id"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Sso", jsii.invoke(self, "onPermissionSet", [instance_id, permission_set_id, partition]))

    @jsii.member(jsii_name="toAssociateDirectory")
    def to_associate_directory(self) -> "Sso":
        '''(experimental) Grants permission to connect a directory to be used by AWS IAM Identity Center.

        Access Level: Write

        Dependent actions:

        - ds:AuthorizeApplication

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        :stability: experimental
        '''
        return typing.cast("Sso", jsii.invoke(self, "toAssociateDirectory", []))

    @jsii.member(jsii_name="toAssociateProfile")
    def to_associate_profile(self) -> "Sso":
        '''(experimental) Grants permission to create an association between a directory user or group and a profile.

        Access Level: Write

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        :stability: experimental
        '''
        return typing.cast("Sso", jsii.invoke(self, "toAssociateProfile", []))

    @jsii.member(jsii_name="toAttachCustomerManagedPolicyReferenceToPermissionSet")
    def to_attach_customer_managed_policy_reference_to_permission_set(self) -> "Sso":
        '''(experimental) Grants permission to attach a customer managed policy reference to a permission set.

        Access Level: Permissions management

        https://docs.aws.amazon.com/singlesignon/latest/APIReference/API_AttachCustomerManagedPolicyReferenceToPermissionSet.html

        :stability: experimental
        '''
        return typing.cast("Sso", jsii.invoke(self, "toAttachCustomerManagedPolicyReferenceToPermissionSet", []))

    @jsii.member(jsii_name="toAttachManagedPolicyToPermissionSet")
    def to_attach_managed_policy_to_permission_set(self) -> "Sso":
        '''(experimental) Grants permission to attach an AWS managed policy to a permission set.

        Access Level: Permissions management

        https://docs.aws.amazon.com/singlesignon/latest/APIReference/API_AttachManagedPolicyToPermissionSet.html

        :stability: experimental
        '''
        return typing.cast("Sso", jsii.invoke(self, "toAttachManagedPolicyToPermissionSet", []))

    @jsii.member(jsii_name="toCreateAccountAssignment")
    def to_create_account_assignment(self) -> "Sso":
        '''(experimental) Grants permission to assign access to a Principal for a specified AWS account using a specified permission set.

        Access Level: Write

        https://docs.aws.amazon.com/singlesignon/latest/APIReference/API_CreateAccountAssignment.html

        :stability: experimental
        '''
        return typing.cast("Sso", jsii.invoke(self, "toCreateAccountAssignment", []))

    @jsii.member(jsii_name="toCreateApplicationInstance")
    def to_create_application_instance(self) -> "Sso":
        '''(experimental) Grants permission to add an application instance to AWS IAM Identity Center.

        Access Level: Write

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        :stability: experimental
        '''
        return typing.cast("Sso", jsii.invoke(self, "toCreateApplicationInstance", []))

    @jsii.member(jsii_name="toCreateApplicationInstanceCertificate")
    def to_create_application_instance_certificate(self) -> "Sso":
        '''(experimental) Grants permission to add a new certificate for an application instance.

        Access Level: Write

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        :stability: experimental
        '''
        return typing.cast("Sso", jsii.invoke(self, "toCreateApplicationInstanceCertificate", []))

    @jsii.member(jsii_name="toCreateInstanceAccessControlAttributeConfiguration")
    def to_create_instance_access_control_attribute_configuration(self) -> "Sso":
        '''(experimental) Grants permission to enable the instance for ABAC and specify the attributes.

        Access Level: Write

        Dependent actions:

        - iam:AttachRolePolicy
        - iam:CreateRole
        - iam:DeleteRole
        - iam:DeleteRolePolicy
        - iam:DetachRolePolicy
        - iam:GetRole
        - iam:ListAttachedRolePolicies
        - iam:ListRolePolicies
        - iam:PutRolePolicy
        - iam:UpdateAssumeRolePolicy

        https://docs.aws.amazon.com/singlesignon/latest/APIReference/API_CreateInstanceAccessControlAttributeConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Sso", jsii.invoke(self, "toCreateInstanceAccessControlAttributeConfiguration", []))

    @jsii.member(jsii_name="toCreateManagedApplicationInstance")
    def to_create_managed_application_instance(self) -> "Sso":
        '''(experimental) Grants permission to add a managed application instance to AWS IAM Identity Center.

        Access Level: Write

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        :stability: experimental
        '''
        return typing.cast("Sso", jsii.invoke(self, "toCreateManagedApplicationInstance", []))

    @jsii.member(jsii_name="toCreatePermissionSet")
    def to_create_permission_set(self) -> "Sso":
        '''(experimental) Grants permission to create a permission set.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/singlesignon/latest/APIReference/API_CreatePermissionSet.html

        :stability: experimental
        '''
        return typing.cast("Sso", jsii.invoke(self, "toCreatePermissionSet", []))

    @jsii.member(jsii_name="toCreateProfile")
    def to_create_profile(self) -> "Sso":
        '''(experimental) Grants permission to create a profile for an application instance.

        Access Level: Write

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        :stability: experimental
        '''
        return typing.cast("Sso", jsii.invoke(self, "toCreateProfile", []))

    @jsii.member(jsii_name="toCreateTrust")
    def to_create_trust(self) -> "Sso":
        '''(experimental) Grants permission to create a federation trust in a target account.

        Access Level: Write

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        :stability: experimental
        '''
        return typing.cast("Sso", jsii.invoke(self, "toCreateTrust", []))

    @jsii.member(jsii_name="toDeleteAccountAssignment")
    def to_delete_account_assignment(self) -> "Sso":
        '''(experimental) Grants permission to delete a Principal's access from a specified AWS account using a specified permission set.

        Access Level: Write

        https://docs.aws.amazon.com/singlesignon/latest/APIReference/API_DeleteAccountAssignment.html

        :stability: experimental
        '''
        return typing.cast("Sso", jsii.invoke(self, "toDeleteAccountAssignment", []))

    @jsii.member(jsii_name="toDeleteApplicationInstance")
    def to_delete_application_instance(self) -> "Sso":
        '''(experimental) Grants permission to delete the application instance.

        Access Level: Write

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        :stability: experimental
        '''
        return typing.cast("Sso", jsii.invoke(self, "toDeleteApplicationInstance", []))

    @jsii.member(jsii_name="toDeleteApplicationInstanceCertificate")
    def to_delete_application_instance_certificate(self) -> "Sso":
        '''(experimental) Grants permission to delete an inactive or expired certificate from the application instance.

        Access Level: Write

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        :stability: experimental
        '''
        return typing.cast("Sso", jsii.invoke(self, "toDeleteApplicationInstanceCertificate", []))

    @jsii.member(jsii_name="toDeleteInlinePolicyFromPermissionSet")
    def to_delete_inline_policy_from_permission_set(self) -> "Sso":
        '''(experimental) Grants permission to delete the inline policy from a specified permission set.

        Access Level: Write

        https://docs.aws.amazon.com/singlesignon/latest/APIReference/API_DeleteInlinePolicyFromPermissionSet.html

        :stability: experimental
        '''
        return typing.cast("Sso", jsii.invoke(self, "toDeleteInlinePolicyFromPermissionSet", []))

    @jsii.member(jsii_name="toDeleteInstanceAccessControlAttributeConfiguration")
    def to_delete_instance_access_control_attribute_configuration(self) -> "Sso":
        '''(experimental) Grants permission to disable ABAC and remove the attributes list for the instance.

        Access Level: Write

        https://docs.aws.amazon.com/singlesignon/latest/APIReference/API_DeleteInstanceAccessControlAttributeConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Sso", jsii.invoke(self, "toDeleteInstanceAccessControlAttributeConfiguration", []))

    @jsii.member(jsii_name="toDeleteManagedApplicationInstance")
    def to_delete_managed_application_instance(self) -> "Sso":
        '''(experimental) Grants permission to delete the managed application instance.

        Access Level: Write

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        :stability: experimental
        '''
        return typing.cast("Sso", jsii.invoke(self, "toDeleteManagedApplicationInstance", []))

    @jsii.member(jsii_name="toDeletePermissionsBoundaryFromPermissionSet")
    def to_delete_permissions_boundary_from_permission_set(self) -> "Sso":
        '''(experimental) Grants permission to remove permissions boundary from a permission set.

        Access Level: Permissions management

        https://docs.aws.amazon.com/singlesignon/latest/APIReference/API_DeletePermissionsBoundaryFromPermissionSet.html

        :stability: experimental
        '''
        return typing.cast("Sso", jsii.invoke(self, "toDeletePermissionsBoundaryFromPermissionSet", []))

    @jsii.member(jsii_name="toDeletePermissionSet")
    def to_delete_permission_set(self) -> "Sso":
        '''(experimental) Grants permission to delete a permission set.

        Access Level: Write

        :stability: experimental
        '''
        return typing.cast("Sso", jsii.invoke(self, "toDeletePermissionSet", []))

    @jsii.member(jsii_name="toDeletePermissionsPolicy")
    def to_delete_permissions_policy(self) -> "Sso":
        '''(experimental) Grants permission to delete the permission policy associated with a permission set.

        Access Level: Permissions management

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        :stability: experimental
        '''
        return typing.cast("Sso", jsii.invoke(self, "toDeletePermissionsPolicy", []))

    @jsii.member(jsii_name="toDeleteProfile")
    def to_delete_profile(self) -> "Sso":
        '''(experimental) Grants permission to delete the profile for an application instance.

        Access Level: Write

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        :stability: experimental
        '''
        return typing.cast("Sso", jsii.invoke(self, "toDeleteProfile", []))

    @jsii.member(jsii_name="toDescribeAccountAssignmentCreationStatus")
    def to_describe_account_assignment_creation_status(self) -> "Sso":
        '''(experimental) Grants permission to describe the status of the assignment creation request.

        Access Level: Read

        https://docs.aws.amazon.com/singlesignon/latest/APIReference/API_DescribeAccountAssignmentCreationStatus.html

        :stability: experimental
        '''
        return typing.cast("Sso", jsii.invoke(self, "toDescribeAccountAssignmentCreationStatus", []))

    @jsii.member(jsii_name="toDescribeAccountAssignmentDeletionStatus")
    def to_describe_account_assignment_deletion_status(self) -> "Sso":
        '''(experimental) Grants permission to describe the status of an assignment deletion request.

        Access Level: Read

        https://docs.aws.amazon.com/singlesignon/latest/APIReference/API_DescribeAccountAssignmentDeletionStatus.html

        :stability: experimental
        '''
        return typing.cast("Sso", jsii.invoke(self, "toDescribeAccountAssignmentDeletionStatus", []))

    @jsii.member(jsii_name="toDescribeInstanceAccessControlAttributeConfiguration")
    def to_describe_instance_access_control_attribute_configuration(self) -> "Sso":
        '''(experimental) Grants permission to get the list of attributes used by the instance for ABAC.

        Access Level: Read

        https://docs.aws.amazon.com/singlesignon/latest/APIReference/API_DescribeInstanceAccessControlAttributeConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Sso", jsii.invoke(self, "toDescribeInstanceAccessControlAttributeConfiguration", []))

    @jsii.member(jsii_name="toDescribePermissionSet")
    def to_describe_permission_set(self) -> "Sso":
        '''(experimental) Grants permission to describe a permission set.

        Access Level: Read

        https://docs.aws.amazon.com/singlesignon/latest/APIReference/API_DescribePermissionSet.html

        :stability: experimental
        '''
        return typing.cast("Sso", jsii.invoke(self, "toDescribePermissionSet", []))

    @jsii.member(jsii_name="toDescribePermissionSetProvisioningStatus")
    def to_describe_permission_set_provisioning_status(self) -> "Sso":
        '''(experimental) Grants permission to describe the status for the given Permission Set Provisioning request.

        Access Level: Read

        https://docs.aws.amazon.com/singlesignon/latest/APIReference/API_DescribePermissionSetProvisioningStatus.html

        :stability: experimental
        '''
        return typing.cast("Sso", jsii.invoke(self, "toDescribePermissionSetProvisioningStatus", []))

    @jsii.member(jsii_name="toDescribePermissionsPolicies")
    def to_describe_permissions_policies(self) -> "Sso":
        '''(experimental) Grants permission to retrieve all the permissions policies associated with a permission set.

        Access Level: Read

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        :stability: experimental
        '''
        return typing.cast("Sso", jsii.invoke(self, "toDescribePermissionsPolicies", []))

    @jsii.member(jsii_name="toDescribeRegisteredRegions")
    def to_describe_registered_regions(self) -> "Sso":
        '''(experimental) Grants permission to obtain the regions where your organization has enabled AWS IAM Identity Center.

        Access Level: Read

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        :stability: experimental
        '''
        return typing.cast("Sso", jsii.invoke(self, "toDescribeRegisteredRegions", []))

    @jsii.member(jsii_name="toDetachCustomerManagedPolicyReferenceFromPermissionSet")
    def to_detach_customer_managed_policy_reference_from_permission_set(self) -> "Sso":
        '''(experimental) Grants permission to detach a customer managed policy reference from a permission set.

        Access Level: Permissions management

        https://docs.aws.amazon.com/singlesignon/latest/APIReference/API_DetachCustomerManagedPolicyReferenceFromPermissionSet.html

        :stability: experimental
        '''
        return typing.cast("Sso", jsii.invoke(self, "toDetachCustomerManagedPolicyReferenceFromPermissionSet", []))

    @jsii.member(jsii_name="toDetachManagedPolicyFromPermissionSet")
    def to_detach_managed_policy_from_permission_set(self) -> "Sso":
        '''(experimental) Grants permission to detach the attached AWS managed policy from the specified permission set.

        Access Level: Permissions management

        https://docs.aws.amazon.com/singlesignon/latest/APIReference/API_DetachManagedPolicyFromPermissionSet.html

        :stability: experimental
        '''
        return typing.cast("Sso", jsii.invoke(self, "toDetachManagedPolicyFromPermissionSet", []))

    @jsii.member(jsii_name="toDisassociateDirectory")
    def to_disassociate_directory(self) -> "Sso":
        '''(experimental) Grants permission to disassociate a directory to be used by AWS IAM Identity Center.

        Access Level: Write

        Dependent actions:

        - ds:UnauthorizeApplication

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        :stability: experimental
        '''
        return typing.cast("Sso", jsii.invoke(self, "toDisassociateDirectory", []))

    @jsii.member(jsii_name="toDisassociateProfile")
    def to_disassociate_profile(self) -> "Sso":
        '''(experimental) Grants permission to disassociate a directory user or group from a profile.

        Access Level: Write

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        :stability: experimental
        '''
        return typing.cast("Sso", jsii.invoke(self, "toDisassociateProfile", []))

    @jsii.member(jsii_name="toGetApplicationInstance")
    def to_get_application_instance(self) -> "Sso":
        '''(experimental) Grants permission to retrieve details for an application instance.

        Access Level: Read

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        :stability: experimental
        '''
        return typing.cast("Sso", jsii.invoke(self, "toGetApplicationInstance", []))

    @jsii.member(jsii_name="toGetApplicationTemplate")
    def to_get_application_template(self) -> "Sso":
        '''(experimental) Grants permission to retrieve application template details.

        Access Level: Read

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        :stability: experimental
        '''
        return typing.cast("Sso", jsii.invoke(self, "toGetApplicationTemplate", []))

    @jsii.member(jsii_name="toGetInlinePolicyForPermissionSet")
    def to_get_inline_policy_for_permission_set(self) -> "Sso":
        '''(experimental) Grants permission to obtain the inline policy assigned to the permission set.

        Access Level: Read

        https://docs.aws.amazon.com/singlesignon/latest/APIReference/API_GetInlinePolicyForPermissionSet.html

        :stability: experimental
        '''
        return typing.cast("Sso", jsii.invoke(self, "toGetInlinePolicyForPermissionSet", []))

    @jsii.member(jsii_name="toGetManagedApplicationInstance")
    def to_get_managed_application_instance(self) -> "Sso":
        '''(experimental) Grants permission to retrieve details for an application instance.

        Access Level: Read

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        :stability: experimental
        '''
        return typing.cast("Sso", jsii.invoke(self, "toGetManagedApplicationInstance", []))

    @jsii.member(jsii_name="toGetMfaDeviceManagementForDirectory")
    def to_get_mfa_device_management_for_directory(self) -> "Sso":
        '''(experimental) Grants permission to retrieve Mfa Device Management settings for the directory.

        Access Level: Read

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        :stability: experimental
        '''
        return typing.cast("Sso", jsii.invoke(self, "toGetMfaDeviceManagementForDirectory", []))

    @jsii.member(jsii_name="toGetPermissionsBoundaryForPermissionSet")
    def to_get_permissions_boundary_for_permission_set(self) -> "Sso":
        '''(experimental) Grants permission to get permissions boundary for a permission set.

        Access Level: Read

        https://docs.aws.amazon.com/singlesignon/latest/APIReference/API_GetPermissionsBoundaryForPermissionSet.html

        :stability: experimental
        '''
        return typing.cast("Sso", jsii.invoke(self, "toGetPermissionsBoundaryForPermissionSet", []))

    @jsii.member(jsii_name="toGetPermissionSet")
    def to_get_permission_set(self) -> "Sso":
        '''(experimental) Grants permission to retrieve details of a permission set.

        Access Level: Read

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        :stability: experimental
        '''
        return typing.cast("Sso", jsii.invoke(self, "toGetPermissionSet", []))

    @jsii.member(jsii_name="toGetPermissionsPolicy")
    def to_get_permissions_policy(self) -> "Sso":
        '''(experimental) Grants permission to retrieve all permission policies associated with a permission set.

        Access Level: Read

        Dependent actions:

        - sso:DescribePermissionsPolicies

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        :stability: experimental
        '''
        return typing.cast("Sso", jsii.invoke(self, "toGetPermissionsPolicy", []))

    @jsii.member(jsii_name="toGetProfile")
    def to_get_profile(self) -> "Sso":
        '''(experimental) Grants permission to retrieve a profile for an application instance.

        Access Level: Read

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        :stability: experimental
        '''
        return typing.cast("Sso", jsii.invoke(self, "toGetProfile", []))

    @jsii.member(jsii_name="toGetSharedSsoConfiguration")
    def to_get_shared_sso_configuration(self) -> "Sso":
        '''(experimental) Grants permission to retrieve shared configuration for the current SSO instance.

        Access Level: Read

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        :stability: experimental
        '''
        return typing.cast("Sso", jsii.invoke(self, "toGetSharedSsoConfiguration", []))

    @jsii.member(jsii_name="toGetSsoConfiguration")
    def to_get_sso_configuration(self) -> "Sso":
        '''(experimental) Grants permission to retrieve configuration for the current SSO instance.

        Access Level: Read

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        :stability: experimental
        '''
        return typing.cast("Sso", jsii.invoke(self, "toGetSsoConfiguration", []))

    @jsii.member(jsii_name="toGetSSOStatus")
    def to_get_sso_status(self) -> "Sso":
        '''(experimental) Grants permission to check if AWS IAM Identity Center is enabled.

        Access Level: Read

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        :stability: experimental
        '''
        return typing.cast("Sso", jsii.invoke(self, "toGetSSOStatus", []))

    @jsii.member(jsii_name="toGetTrust")
    def to_get_trust(self) -> "Sso":
        '''(experimental) Grants permission to retrieve the federation trust in a target account.

        Access Level: Read

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        :stability: experimental
        '''
        return typing.cast("Sso", jsii.invoke(self, "toGetTrust", []))

    @jsii.member(jsii_name="toImportApplicationInstanceServiceProviderMetadata")
    def to_import_application_instance_service_provider_metadata(self) -> "Sso":
        '''(experimental) Grants permission to update the application instance by uploading an application SAML metadata file provided by the service provider.

        Access Level: Write

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        :stability: experimental
        '''
        return typing.cast("Sso", jsii.invoke(self, "toImportApplicationInstanceServiceProviderMetadata", []))

    @jsii.member(jsii_name="toListAccountAssignmentCreationStatus")
    def to_list_account_assignment_creation_status(self) -> "Sso":
        '''(experimental) Grants permission to list the status of the AWS account assignment creation requests for a specified SSO instance.

        Access Level: List

        https://docs.aws.amazon.com/singlesignon/latest/APIReference/API_ListAccountAssignmentCreationStatus.html

        :stability: experimental
        '''
        return typing.cast("Sso", jsii.invoke(self, "toListAccountAssignmentCreationStatus", []))

    @jsii.member(jsii_name="toListAccountAssignmentDeletionStatus")
    def to_list_account_assignment_deletion_status(self) -> "Sso":
        '''(experimental) Grants permission to list the status of the AWS account assignment deletion requests for a specified SSO instance.

        Access Level: List

        https://docs.aws.amazon.com/singlesignon/latest/APIReference/API_ListAccountAssignmentDeletionStatus.html

        :stability: experimental
        '''
        return typing.cast("Sso", jsii.invoke(self, "toListAccountAssignmentDeletionStatus", []))

    @jsii.member(jsii_name="toListAccountAssignments")
    def to_list_account_assignments(self) -> "Sso":
        '''(experimental) Grants permission to list the assignee of the specified AWS account with the specified permission set.

        Access Level: List

        https://docs.aws.amazon.com/singlesignon/latest/APIReference/API_ListAccountAssignments.html

        :stability: experimental
        '''
        return typing.cast("Sso", jsii.invoke(self, "toListAccountAssignments", []))

    @jsii.member(jsii_name="toListAccountsForProvisionedPermissionSet")
    def to_list_accounts_for_provisioned_permission_set(self) -> "Sso":
        '''(experimental) Grants permission to list all the AWS accounts where the specified permission set is provisioned.

        Access Level: List

        https://docs.aws.amazon.com/singlesignon/latest/APIReference/API_ListAccountsForProvisionedPermissionSet.html

        :stability: experimental
        '''
        return typing.cast("Sso", jsii.invoke(self, "toListAccountsForProvisionedPermissionSet", []))

    @jsii.member(jsii_name="toListApplicationInstanceCertificates")
    def to_list_application_instance_certificates(self) -> "Sso":
        '''(experimental) Grants permission to retrieve all of the certificates for a given application instance.

        Access Level: Read

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        :stability: experimental
        '''
        return typing.cast("Sso", jsii.invoke(self, "toListApplicationInstanceCertificates", []))

    @jsii.member(jsii_name="toListApplicationInstances")
    def to_list_application_instances(self) -> "Sso":
        '''(experimental) Grants permission to retrieve all application instances.

        Access Level: List

        Dependent actions:

        - sso:GetApplicationInstance

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        :stability: experimental
        '''
        return typing.cast("Sso", jsii.invoke(self, "toListApplicationInstances", []))

    @jsii.member(jsii_name="toListApplications")
    def to_list_applications(self) -> "Sso":
        '''(experimental) Grants permission to retrieve all supported applications.

        Access Level: List

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        :stability: experimental
        '''
        return typing.cast("Sso", jsii.invoke(self, "toListApplications", []))

    @jsii.member(jsii_name="toListApplicationTemplates")
    def to_list_application_templates(self) -> "Sso":
        '''(experimental) Grants permission to retrieve all supported application templates.

        Access Level: List

        Dependent actions:

        - sso:GetApplicationTemplate

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        :stability: experimental
        '''
        return typing.cast("Sso", jsii.invoke(self, "toListApplicationTemplates", []))

    @jsii.member(jsii_name="toListCustomerManagedPolicyReferencesInPermissionSet")
    def to_list_customer_managed_policy_references_in_permission_set(self) -> "Sso":
        '''(experimental) Grants permission to list the customer managed policy references that are attached to a permission set.

        Access Level: List

        https://docs.aws.amazon.com/singlesignon/latest/APIReference/API_ListCustomerManagedPolicyReferencesInPermissionSet.html

        :stability: experimental
        '''
        return typing.cast("Sso", jsii.invoke(self, "toListCustomerManagedPolicyReferencesInPermissionSet", []))

    @jsii.member(jsii_name="toListDirectoryAssociations")
    def to_list_directory_associations(self) -> "Sso":
        '''(experimental) Grants permission to retrieve details about the directory connected to AWS IAM Identity Center.

        Access Level: Read

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        :stability: experimental
        '''
        return typing.cast("Sso", jsii.invoke(self, "toListDirectoryAssociations", []))

    @jsii.member(jsii_name="toListInstances")
    def to_list_instances(self) -> "Sso":
        '''(experimental) Grants permission to list the SSO Instances that the caller has access to.

        Access Level: List

        https://docs.aws.amazon.com/singlesignon/latest/APIReference/API_ListInstances.html

        :stability: experimental
        '''
        return typing.cast("Sso", jsii.invoke(self, "toListInstances", []))

    @jsii.member(jsii_name="toListManagedPoliciesInPermissionSet")
    def to_list_managed_policies_in_permission_set(self) -> "Sso":
        '''(experimental) Grants permission to list the AWS managed policies that are attached to a specified permission set.

        Access Level: List

        https://docs.aws.amazon.com/singlesignon/latest/APIReference/API_ListManagedPoliciesInPermissionSet.html

        :stability: experimental
        '''
        return typing.cast("Sso", jsii.invoke(self, "toListManagedPoliciesInPermissionSet", []))

    @jsii.member(jsii_name="toListPermissionSetProvisioningStatus")
    def to_list_permission_set_provisioning_status(self) -> "Sso":
        '''(experimental) Grants permission to list the status of the Permission Set Provisioning requests for a specified SSO instance.

        Access Level: List

        https://docs.aws.amazon.com/singlesignon/latest/APIReference/API_ListPermissionSetProvisioningStatus.html

        :stability: experimental
        '''
        return typing.cast("Sso", jsii.invoke(self, "toListPermissionSetProvisioningStatus", []))

    @jsii.member(jsii_name="toListPermissionSets")
    def to_list_permission_sets(self) -> "Sso":
        '''(experimental) Grants permission to retrieve all permission sets.

        Access Level: List

        :stability: experimental
        '''
        return typing.cast("Sso", jsii.invoke(self, "toListPermissionSets", []))

    @jsii.member(jsii_name="toListPermissionSetsProvisionedToAccount")
    def to_list_permission_sets_provisioned_to_account(self) -> "Sso":
        '''(experimental) Grants permission to list all the permission sets that are provisioned to a specified AWS account.

        Access Level: List

        https://docs.aws.amazon.com/singlesignon/latest/APIReference/API_ListPermissionSetsProvisionedToAccount.html

        :stability: experimental
        '''
        return typing.cast("Sso", jsii.invoke(self, "toListPermissionSetsProvisionedToAccount", []))

    @jsii.member(jsii_name="toListProfileAssociations")
    def to_list_profile_associations(self) -> "Sso":
        '''(experimental) Grants permission to retrieve the directory user or group associated with the profile.

        Access Level: Read

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        :stability: experimental
        '''
        return typing.cast("Sso", jsii.invoke(self, "toListProfileAssociations", []))

    @jsii.member(jsii_name="toListProfiles")
    def to_list_profiles(self) -> "Sso":
        '''(experimental) Grants permission to retrieve all profiles for an application instance.

        Access Level: List

        Dependent actions:

        - sso:GetProfile

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        :stability: experimental
        '''
        return typing.cast("Sso", jsii.invoke(self, "toListProfiles", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Sso":
        '''(experimental) Grants permission to list the tags that are attached to a specified resource.

        Access Level: Read

        https://docs.aws.amazon.com/singlesignon/latest/APIReference/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("Sso", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toProvisionPermissionSet")
    def to_provision_permission_set(self) -> "Sso":
        '''(experimental) Grants permission to provision a specified permission set to the specified target.

        Access Level: Write

        https://docs.aws.amazon.com/singlesignon/latest/APIReference/API_ProvisionPermissionSet.html

        :stability: experimental
        '''
        return typing.cast("Sso", jsii.invoke(self, "toProvisionPermissionSet", []))

    @jsii.member(jsii_name="toPutInlinePolicyToPermissionSet")
    def to_put_inline_policy_to_permission_set(self) -> "Sso":
        '''(experimental) Grants permission to attach an IAM inline policy to a permission set.

        Access Level: Write

        https://docs.aws.amazon.com/singlesignon/latest/APIReference/API_PutInlinePolicyToPermissionSet.html

        :stability: experimental
        '''
        return typing.cast("Sso", jsii.invoke(self, "toPutInlinePolicyToPermissionSet", []))

    @jsii.member(jsii_name="toPutMfaDeviceManagementForDirectory")
    def to_put_mfa_device_management_for_directory(self) -> "Sso":
        '''(experimental) Grants permission to put Mfa Device Management settings for the directory.

        Access Level: Write

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        :stability: experimental
        '''
        return typing.cast("Sso", jsii.invoke(self, "toPutMfaDeviceManagementForDirectory", []))

    @jsii.member(jsii_name="toPutPermissionsBoundaryToPermissionSet")
    def to_put_permissions_boundary_to_permission_set(self) -> "Sso":
        '''(experimental) Grants permission to add permissions boundary to a permission set.

        Access Level: Permissions management

        https://docs.aws.amazon.com/singlesignon/latest/APIReference/API_PutPermissionsBoundaryToPermissionSet.html

        :stability: experimental
        '''
        return typing.cast("Sso", jsii.invoke(self, "toPutPermissionsBoundaryToPermissionSet", []))

    @jsii.member(jsii_name="toPutPermissionsPolicy")
    def to_put_permissions_policy(self) -> "Sso":
        '''(experimental) Grants permission to add a policy to a permission set.

        Access Level: Permissions management

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        :stability: experimental
        '''
        return typing.cast("Sso", jsii.invoke(self, "toPutPermissionsPolicy", []))

    @jsii.member(jsii_name="toSearchGroups")
    def to_search_groups(self) -> "Sso":
        '''(experimental) Grants permission to search for groups within the associated directory.

        Access Level: Read

        Dependent actions:

        - ds:DescribeDirectories

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        :stability: experimental
        '''
        return typing.cast("Sso", jsii.invoke(self, "toSearchGroups", []))

    @jsii.member(jsii_name="toSearchUsers")
    def to_search_users(self) -> "Sso":
        '''(experimental) Grants permission to search for users within the associated directory.

        Access Level: Read

        Dependent actions:

        - ds:DescribeDirectories

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        :stability: experimental
        '''
        return typing.cast("Sso", jsii.invoke(self, "toSearchUsers", []))

    @jsii.member(jsii_name="toStartSSO")
    def to_start_sso(self) -> "Sso":
        '''(experimental) Grants permission to initialize AWS IAM Identity Center.

        Access Level: Write

        Dependent actions:

        - organizations:DescribeOrganization
        - organizations:EnableAWSServiceAccess

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        :stability: experimental
        '''
        return typing.cast("Sso", jsii.invoke(self, "toStartSSO", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Sso":
        '''(experimental) Grants permission to associate a set of tags with a specified resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/singlesignon/latest/APIReference/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("Sso", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Sso":
        '''(experimental) Grants permission to disassociate a set of tags from a specified resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/singlesignon/latest/APIReference/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("Sso", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateApplicationInstanceActiveCertificate")
    def to_update_application_instance_active_certificate(self) -> "Sso":
        '''(experimental) Grants permission to set a certificate as the active one for this application instance.

        Access Level: Write

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        :stability: experimental
        '''
        return typing.cast("Sso", jsii.invoke(self, "toUpdateApplicationInstanceActiveCertificate", []))

    @jsii.member(jsii_name="toUpdateApplicationInstanceDisplayData")
    def to_update_application_instance_display_data(self) -> "Sso":
        '''(experimental) Grants permission to update display data of an application instance.

        Access Level: Write

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        :stability: experimental
        '''
        return typing.cast("Sso", jsii.invoke(self, "toUpdateApplicationInstanceDisplayData", []))

    @jsii.member(jsii_name="toUpdateApplicationInstanceResponseConfiguration")
    def to_update_application_instance_response_configuration(self) -> "Sso":
        '''(experimental) Grants permission to update federation response configuration for the application instance.

        Access Level: Write

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        :stability: experimental
        '''
        return typing.cast("Sso", jsii.invoke(self, "toUpdateApplicationInstanceResponseConfiguration", []))

    @jsii.member(jsii_name="toUpdateApplicationInstanceResponseSchemaConfiguration")
    def to_update_application_instance_response_schema_configuration(self) -> "Sso":
        '''(experimental) Grants permission to update federation response schema configuration for the application instance.

        Access Level: Write

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        :stability: experimental
        '''
        return typing.cast("Sso", jsii.invoke(self, "toUpdateApplicationInstanceResponseSchemaConfiguration", []))

    @jsii.member(jsii_name="toUpdateApplicationInstanceSecurityConfiguration")
    def to_update_application_instance_security_configuration(self) -> "Sso":
        '''(experimental) Grants permission to update security details for the application instance.

        Access Level: Write

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        :stability: experimental
        '''
        return typing.cast("Sso", jsii.invoke(self, "toUpdateApplicationInstanceSecurityConfiguration", []))

    @jsii.member(jsii_name="toUpdateApplicationInstanceServiceProviderConfiguration")
    def to_update_application_instance_service_provider_configuration(self) -> "Sso":
        '''(experimental) Grants permission to update service provider related configuration for the application instance.

        Access Level: Write

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        :stability: experimental
        '''
        return typing.cast("Sso", jsii.invoke(self, "toUpdateApplicationInstanceServiceProviderConfiguration", []))

    @jsii.member(jsii_name="toUpdateApplicationInstanceStatus")
    def to_update_application_instance_status(self) -> "Sso":
        '''(experimental) Grants permission to update the status of an application instance.

        Access Level: Write

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        :stability: experimental
        '''
        return typing.cast("Sso", jsii.invoke(self, "toUpdateApplicationInstanceStatus", []))

    @jsii.member(jsii_name="toUpdateDirectoryAssociation")
    def to_update_directory_association(self) -> "Sso":
        '''(experimental) Grants permission to update the user attribute mappings for your connected directory.

        Access Level: Write

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        :stability: experimental
        '''
        return typing.cast("Sso", jsii.invoke(self, "toUpdateDirectoryAssociation", []))

    @jsii.member(jsii_name="toUpdateInstanceAccessControlAttributeConfiguration")
    def to_update_instance_access_control_attribute_configuration(self) -> "Sso":
        '''(experimental) Grants permission to update the attributes to use with the instance for ABAC.

        Access Level: Write

        https://docs.aws.amazon.com/singlesignon/latest/APIReference/API_UpdateInstanceAccessControlAttributeConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Sso", jsii.invoke(self, "toUpdateInstanceAccessControlAttributeConfiguration", []))

    @jsii.member(jsii_name="toUpdateManagedApplicationInstanceStatus")
    def to_update_managed_application_instance_status(self) -> "Sso":
        '''(experimental) Grants permission to update the status of a managed application instance.

        Access Level: Write

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        :stability: experimental
        '''
        return typing.cast("Sso", jsii.invoke(self, "toUpdateManagedApplicationInstanceStatus", []))

    @jsii.member(jsii_name="toUpdatePermissionSet")
    def to_update_permission_set(self) -> "Sso":
        '''(experimental) Grants permission to update the permission set.

        Access Level: Permissions management

        :stability: experimental
        '''
        return typing.cast("Sso", jsii.invoke(self, "toUpdatePermissionSet", []))

    @jsii.member(jsii_name="toUpdateProfile")
    def to_update_profile(self) -> "Sso":
        '''(experimental) Grants permission to update the profile for an application instance.

        Access Level: Write

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        :stability: experimental
        '''
        return typing.cast("Sso", jsii.invoke(self, "toUpdateProfile", []))

    @jsii.member(jsii_name="toUpdateSSOConfiguration")
    def to_update_sso_configuration(self) -> "Sso":
        '''(experimental) Grants permission to update the configuration for the current SSO instance.

        Access Level: Write

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        :stability: experimental
        '''
        return typing.cast("Sso", jsii.invoke(self, "toUpdateSSOConfiguration", []))

    @jsii.member(jsii_name="toUpdateTrust")
    def to_update_trust(self) -> "Sso":
        '''(experimental) Grants permission to update the federation trust in a target account.

        Access Level: Write

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        :stability: experimental
        '''
        return typing.cast("Sso", jsii.invoke(self, "toUpdateTrust", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__807830123c5f8135f1ed4edd98f8aa80c854f534ef4aab7162bdc9b2038a5a07)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ecad6b02c3dc93ab8f1c1a2f97b8282fc434bca64ea4b0b20517bded46579045)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class SsoDirectory(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.SsoDirectory",
):
    '''(experimental) Statement provider for service `sso-directory <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiamidentitycentersuccessortoawssinglesign-ondirectory.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `sso-directory <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiamidentitycentersuccessortoawssinglesign-ondirectory.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="toAddMemberToGroup")
    def to_add_member_to_group(self) -> "SsoDirectory":
        '''(experimental) Grants permission to add a member to a group in the directory that AWS IAM Identity Center provides by default.

        Access Level: Write

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        :stability: experimental
        '''
        return typing.cast("SsoDirectory", jsii.invoke(self, "toAddMemberToGroup", []))

    @jsii.member(jsii_name="toCompleteVirtualMfaDeviceRegistration")
    def to_complete_virtual_mfa_device_registration(self) -> "SsoDirectory":
        '''(experimental) Grants permission to complete the creation process of a virtual MFA device.

        Access Level: Write

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        :stability: experimental
        '''
        return typing.cast("SsoDirectory", jsii.invoke(self, "toCompleteVirtualMfaDeviceRegistration", []))

    @jsii.member(jsii_name="toCompleteWebAuthnDeviceRegistration")
    def to_complete_web_authn_device_registration(self) -> "SsoDirectory":
        '''(experimental) Grants permission to complete the registration process of a WebAuthn device.

        Access Level: Write

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        :stability: experimental
        '''
        return typing.cast("SsoDirectory", jsii.invoke(self, "toCompleteWebAuthnDeviceRegistration", []))

    @jsii.member(jsii_name="toCreateAlias")
    def to_create_alias(self) -> "SsoDirectory":
        '''(experimental) Grants permission to create an alias for the directory that AWS IAM Identity Center provides by default.

        Access Level: Write

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        :stability: experimental
        '''
        return typing.cast("SsoDirectory", jsii.invoke(self, "toCreateAlias", []))

    @jsii.member(jsii_name="toCreateBearerToken")
    def to_create_bearer_token(self) -> "SsoDirectory":
        '''(experimental) Grants permission to create a bearer token for a given provisioning tenant.

        Access Level: Write

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        :stability: experimental
        '''
        return typing.cast("SsoDirectory", jsii.invoke(self, "toCreateBearerToken", []))

    @jsii.member(jsii_name="toCreateExternalIdPConfigurationForDirectory")
    def to_create_external_id_p_configuration_for_directory(self) -> "SsoDirectory":
        '''(experimental) Grants permission to create an External Identity Provider configuration for the directory.

        Access Level: Write

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        :stability: experimental
        '''
        return typing.cast("SsoDirectory", jsii.invoke(self, "toCreateExternalIdPConfigurationForDirectory", []))

    @jsii.member(jsii_name="toCreateGroup")
    def to_create_group(self) -> "SsoDirectory":
        '''(experimental) Grants permission to create a group in the directory that AWS IAM Identity Center provides by default.

        Access Level: Write

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        :stability: experimental
        '''
        return typing.cast("SsoDirectory", jsii.invoke(self, "toCreateGroup", []))

    @jsii.member(jsii_name="toCreateProvisioningTenant")
    def to_create_provisioning_tenant(self) -> "SsoDirectory":
        '''(experimental) Grants permission to create a provisioning tenant for a given directory.

        Access Level: Write

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        :stability: experimental
        '''
        return typing.cast("SsoDirectory", jsii.invoke(self, "toCreateProvisioningTenant", []))

    @jsii.member(jsii_name="toCreateUser")
    def to_create_user(self) -> "SsoDirectory":
        '''(experimental) Grants permission to create a user in the directory that AWS IAM Identity Center provides by default.

        Access Level: Write

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        :stability: experimental
        '''
        return typing.cast("SsoDirectory", jsii.invoke(self, "toCreateUser", []))

    @jsii.member(jsii_name="toDeleteBearerToken")
    def to_delete_bearer_token(self) -> "SsoDirectory":
        '''(experimental) Grants permission to delete a bearer token.

        Access Level: Write

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        :stability: experimental
        '''
        return typing.cast("SsoDirectory", jsii.invoke(self, "toDeleteBearerToken", []))

    @jsii.member(jsii_name="toDeleteExternalIdPCertificate")
    def to_delete_external_id_p_certificate(self) -> "SsoDirectory":
        '''(experimental) Grants permission to delete the given external IdP certificate.

        Access Level: Write

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        :stability: experimental
        '''
        return typing.cast("SsoDirectory", jsii.invoke(self, "toDeleteExternalIdPCertificate", []))

    @jsii.member(jsii_name="toDeleteExternalIdPConfigurationForDirectory")
    def to_delete_external_id_p_configuration_for_directory(self) -> "SsoDirectory":
        '''(experimental) Grants permission to delete an External Identity Provider configuration associated with the directory.

        Access Level: Write

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        :stability: experimental
        '''
        return typing.cast("SsoDirectory", jsii.invoke(self, "toDeleteExternalIdPConfigurationForDirectory", []))

    @jsii.member(jsii_name="toDeleteGroup")
    def to_delete_group(self) -> "SsoDirectory":
        '''(experimental) Grants permission to delete a group from the directory that AWS IAM Identity Center provides by default.

        Access Level: Write

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        :stability: experimental
        '''
        return typing.cast("SsoDirectory", jsii.invoke(self, "toDeleteGroup", []))

    @jsii.member(jsii_name="toDeleteMfaDeviceForUser")
    def to_delete_mfa_device_for_user(self) -> "SsoDirectory":
        '''(experimental) Grants permission to delete a MFA device by device name for a given user.

        Access Level: Write

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        :stability: experimental
        '''
        return typing.cast("SsoDirectory", jsii.invoke(self, "toDeleteMfaDeviceForUser", []))

    @jsii.member(jsii_name="toDeleteProvisioningTenant")
    def to_delete_provisioning_tenant(self) -> "SsoDirectory":
        '''(experimental) Grants permission to delete the provisioning tenant.

        Access Level: Write

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        :stability: experimental
        '''
        return typing.cast("SsoDirectory", jsii.invoke(self, "toDeleteProvisioningTenant", []))

    @jsii.member(jsii_name="toDeleteUser")
    def to_delete_user(self) -> "SsoDirectory":
        '''(experimental) Grants permission to delete a user from the directory that AWS IAM Identity Center provides by default.

        Access Level: Write

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        :stability: experimental
        '''
        return typing.cast("SsoDirectory", jsii.invoke(self, "toDeleteUser", []))

    @jsii.member(jsii_name="toDescribeDirectory")
    def to_describe_directory(self) -> "SsoDirectory":
        '''(experimental) Grants permission to retrieve information about the directory that AWS IAM Identity Center provides by default.

        Access Level: Read

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        :stability: experimental
        '''
        return typing.cast("SsoDirectory", jsii.invoke(self, "toDescribeDirectory", []))

    @jsii.member(jsii_name="toDescribeGroup")
    def to_describe_group(self) -> "SsoDirectory":
        '''(experimental) Grants permission to query the group data, not including user and group members.

        Access Level: Read

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        :stability: experimental
        '''
        return typing.cast("SsoDirectory", jsii.invoke(self, "toDescribeGroup", []))

    @jsii.member(jsii_name="toDescribeGroups")
    def to_describe_groups(self) -> "SsoDirectory":
        '''(experimental) Grants permission to retrieve information about groups from the directory that AWS IAM Identity Center provides by default.

        Access Level: Read

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        :stability: experimental
        '''
        return typing.cast("SsoDirectory", jsii.invoke(self, "toDescribeGroups", []))

    @jsii.member(jsii_name="toDescribeProvisioningTenant")
    def to_describe_provisioning_tenant(self) -> "SsoDirectory":
        '''(experimental) Grants permission to describes the provisioning tenant.

        Access Level: Read

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        :stability: experimental
        '''
        return typing.cast("SsoDirectory", jsii.invoke(self, "toDescribeProvisioningTenant", []))

    @jsii.member(jsii_name="toDescribeUser")
    def to_describe_user(self) -> "SsoDirectory":
        '''(experimental) Grants permission to retrieve information about a user from the directory that AWS IAM Identity Center provides by default.

        Access Level: Read

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        :stability: experimental
        '''
        return typing.cast("SsoDirectory", jsii.invoke(self, "toDescribeUser", []))

    @jsii.member(jsii_name="toDescribeUserByUniqueAttribute")
    def to_describe_user_by_unique_attribute(self) -> "SsoDirectory":
        '''(experimental) Grants permission to describe user with a valid unique attribute represented for the user.

        Access Level: Read

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        :stability: experimental
        '''
        return typing.cast("SsoDirectory", jsii.invoke(self, "toDescribeUserByUniqueAttribute", []))

    @jsii.member(jsii_name="toDescribeUsers")
    def to_describe_users(self) -> "SsoDirectory":
        '''(experimental) Grants permission to retrieve information about user from the directory that AWS IAM Identity Center provides by default.

        Access Level: Read

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        :stability: experimental
        '''
        return typing.cast("SsoDirectory", jsii.invoke(self, "toDescribeUsers", []))

    @jsii.member(jsii_name="toDisableExternalIdPConfigurationForDirectory")
    def to_disable_external_id_p_configuration_for_directory(self) -> "SsoDirectory":
        '''(experimental) Grants permission to disable authentication of end users with an External Identity Provider.

        Access Level: Write

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        :stability: experimental
        '''
        return typing.cast("SsoDirectory", jsii.invoke(self, "toDisableExternalIdPConfigurationForDirectory", []))

    @jsii.member(jsii_name="toDisableUser")
    def to_disable_user(self) -> "SsoDirectory":
        '''(experimental) Grants permission to deactivate a user in the directory that AWS IAM Identity Center provides by default.

        Access Level: Write

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        :stability: experimental
        '''
        return typing.cast("SsoDirectory", jsii.invoke(self, "toDisableUser", []))

    @jsii.member(jsii_name="toEnableExternalIdPConfigurationForDirectory")
    def to_enable_external_id_p_configuration_for_directory(self) -> "SsoDirectory":
        '''(experimental) Grants permission to enable authentication of end users with an External Identity Provider.

        Access Level: Write

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        :stability: experimental
        '''
        return typing.cast("SsoDirectory", jsii.invoke(self, "toEnableExternalIdPConfigurationForDirectory", []))

    @jsii.member(jsii_name="toEnableUser")
    def to_enable_user(self) -> "SsoDirectory":
        '''(experimental) Grants permission to activate user in the directory that AWS IAM Identity Center provides by default.

        Access Level: Write

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        :stability: experimental
        '''
        return typing.cast("SsoDirectory", jsii.invoke(self, "toEnableUser", []))

    @jsii.member(jsii_name="toGetAWSSPConfigurationForDirectory")
    def to_get_awssp_configuration_for_directory(self) -> "SsoDirectory":
        '''(experimental) Grants permission to retrieve the AWS IAM Identity Center Service Provider configurations for the directory.

        Access Level: Read

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        :stability: experimental
        '''
        return typing.cast("SsoDirectory", jsii.invoke(self, "toGetAWSSPConfigurationForDirectory", []))

    @jsii.member(jsii_name="toGetUserPoolInfo")
    def to_get_user_pool_info(self) -> "SsoDirectory":
        '''(experimental) (Deprecated) Grants permission to get UserPool Info.

        Access Level: Read

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        :stability: experimental
        '''
        return typing.cast("SsoDirectory", jsii.invoke(self, "toGetUserPoolInfo", []))

    @jsii.member(jsii_name="toImportExternalIdPCertificate")
    def to_import_external_id_p_certificate(self) -> "SsoDirectory":
        '''(experimental) Grants permission to import the IdP certificate used for verifying external IdP responses.

        Access Level: Write

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        :stability: experimental
        '''
        return typing.cast("SsoDirectory", jsii.invoke(self, "toImportExternalIdPCertificate", []))

    @jsii.member(jsii_name="toIsMemberInGroup")
    def to_is_member_in_group(self) -> "SsoDirectory":
        '''(experimental) Grants permission to check if a member is a part of the group in the directory that AWS IAM Identity Center provides by default.

        Access Level: Read

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        :stability: experimental
        '''
        return typing.cast("SsoDirectory", jsii.invoke(self, "toIsMemberInGroup", []))

    @jsii.member(jsii_name="toListBearerTokens")
    def to_list_bearer_tokens(self) -> "SsoDirectory":
        '''(experimental) Grants permission to list bearer tokens for a given provisioning tenant.

        Access Level: Read

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        :stability: experimental
        '''
        return typing.cast("SsoDirectory", jsii.invoke(self, "toListBearerTokens", []))

    @jsii.member(jsii_name="toListExternalIdPCertificates")
    def to_list_external_id_p_certificates(self) -> "SsoDirectory":
        '''(experimental) Grants permission to list the external IdP certificates of a given directory and IdP.

        Access Level: Read

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        :stability: experimental
        '''
        return typing.cast("SsoDirectory", jsii.invoke(self, "toListExternalIdPCertificates", []))

    @jsii.member(jsii_name="toListExternalIdPConfigurationsForDirectory")
    def to_list_external_id_p_configurations_for_directory(self) -> "SsoDirectory":
        '''(experimental) Grants permission to list all the External Identity Provider configurations created for the directory.

        Access Level: Read

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        :stability: experimental
        '''
        return typing.cast("SsoDirectory", jsii.invoke(self, "toListExternalIdPConfigurationsForDirectory", []))

    @jsii.member(jsii_name="toListGroupsForMember")
    def to_list_groups_for_member(self) -> "SsoDirectory":
        '''(experimental) Grants permission to list groups of the target member.

        Access Level: Read

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        :stability: experimental
        '''
        return typing.cast("SsoDirectory", jsii.invoke(self, "toListGroupsForMember", []))

    @jsii.member(jsii_name="toListGroupsForUser")
    def to_list_groups_for_user(self) -> "SsoDirectory":
        '''(experimental) Grants permission to list groups for a user from the directory that AWS IAM Identity Center provides by default.

        Access Level: Read

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        :stability: experimental
        '''
        return typing.cast("SsoDirectory", jsii.invoke(self, "toListGroupsForUser", []))

    @jsii.member(jsii_name="toListMembersInGroup")
    def to_list_members_in_group(self) -> "SsoDirectory":
        '''(experimental) Grants permission to retrieve all members that are part of a group in the directory that AWS IAM Identity Center provides by default.

        Access Level: Read

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        :stability: experimental
        '''
        return typing.cast("SsoDirectory", jsii.invoke(self, "toListMembersInGroup", []))

    @jsii.member(jsii_name="toListMfaDevicesForUser")
    def to_list_mfa_devices_for_user(self) -> "SsoDirectory":
        '''(experimental) Grants permission to list all active MFA devices and their MFA device metadata for a user.

        Access Level: Read

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        :stability: experimental
        '''
        return typing.cast("SsoDirectory", jsii.invoke(self, "toListMfaDevicesForUser", []))

    @jsii.member(jsii_name="toListProvisioningTenants")
    def to_list_provisioning_tenants(self) -> "SsoDirectory":
        '''(experimental) Grants permission to list provisioning tenants for a given directory.

        Access Level: Read

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        :stability: experimental
        '''
        return typing.cast("SsoDirectory", jsii.invoke(self, "toListProvisioningTenants", []))

    @jsii.member(jsii_name="toRemoveMemberFromGroup")
    def to_remove_member_from_group(self) -> "SsoDirectory":
        '''(experimental) Grants permission to remove a member that is part of a group in the directory that AWS IAM Identity Center provides by default.

        Access Level: Write

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        :stability: experimental
        '''
        return typing.cast("SsoDirectory", jsii.invoke(self, "toRemoveMemberFromGroup", []))

    @jsii.member(jsii_name="toSearchGroups")
    def to_search_groups(self) -> "SsoDirectory":
        '''(experimental) Grants permission to search for groups within the associated directory.

        Access Level: Read

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        :stability: experimental
        '''
        return typing.cast("SsoDirectory", jsii.invoke(self, "toSearchGroups", []))

    @jsii.member(jsii_name="toSearchUsers")
    def to_search_users(self) -> "SsoDirectory":
        '''(experimental) Grants permission to search for users within the associated directory.

        Access Level: Read

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        :stability: experimental
        '''
        return typing.cast("SsoDirectory", jsii.invoke(self, "toSearchUsers", []))

    @jsii.member(jsii_name="toStartVirtualMfaDeviceRegistration")
    def to_start_virtual_mfa_device_registration(self) -> "SsoDirectory":
        '''(experimental) Grants permission to begin the creation process of virtual mfa device.

        Access Level: Write

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        :stability: experimental
        '''
        return typing.cast("SsoDirectory", jsii.invoke(self, "toStartVirtualMfaDeviceRegistration", []))

    @jsii.member(jsii_name="toStartWebAuthnDeviceRegistration")
    def to_start_web_authn_device_registration(self) -> "SsoDirectory":
        '''(experimental) Grants permission to begin the registration process of a WebAuthn device.

        Access Level: Write

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        :stability: experimental
        '''
        return typing.cast("SsoDirectory", jsii.invoke(self, "toStartWebAuthnDeviceRegistration", []))

    @jsii.member(jsii_name="toUpdateExternalIdPConfigurationForDirectory")
    def to_update_external_id_p_configuration_for_directory(self) -> "SsoDirectory":
        '''(experimental) Grants permission to update an External Identity Provider configuration associated with the directory.

        Access Level: Write

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        :stability: experimental
        '''
        return typing.cast("SsoDirectory", jsii.invoke(self, "toUpdateExternalIdPConfigurationForDirectory", []))

    @jsii.member(jsii_name="toUpdateGroup")
    def to_update_group(self) -> "SsoDirectory":
        '''(experimental) Grants permission to update information about a group in the directory that AWS IAM Identity Center provides by default.

        Access Level: Write

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        :stability: experimental
        '''
        return typing.cast("SsoDirectory", jsii.invoke(self, "toUpdateGroup", []))

    @jsii.member(jsii_name="toUpdateGroupDisplayName")
    def to_update_group_display_name(self) -> "SsoDirectory":
        '''(experimental) Grants permission to update group display name update group display name response.

        Access Level: Write

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        :stability: experimental
        '''
        return typing.cast("SsoDirectory", jsii.invoke(self, "toUpdateGroupDisplayName", []))

    @jsii.member(jsii_name="toUpdateMfaDeviceForUser")
    def to_update_mfa_device_for_user(self) -> "SsoDirectory":
        '''(experimental) Grants permission to update MFA device information.

        Access Level: Write

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        :stability: experimental
        '''
        return typing.cast("SsoDirectory", jsii.invoke(self, "toUpdateMfaDeviceForUser", []))

    @jsii.member(jsii_name="toUpdatePassword")
    def to_update_password(self) -> "SsoDirectory":
        '''(experimental) Grants permission to update a password by sending password reset link via email or generating one time password for a user in the directory that AWS IAM Identity Center provides by default.

        Access Level: Write

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        :stability: experimental
        '''
        return typing.cast("SsoDirectory", jsii.invoke(self, "toUpdatePassword", []))

    @jsii.member(jsii_name="toUpdateUser")
    def to_update_user(self) -> "SsoDirectory":
        '''(experimental) Grants permission to update user information in the directory that AWS IAM Identity Center provides by default.

        Access Level: Write

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        :stability: experimental
        '''
        return typing.cast("SsoDirectory", jsii.invoke(self, "toUpdateUser", []))

    @jsii.member(jsii_name="toUpdateUserName")
    def to_update_user_name(self) -> "SsoDirectory":
        '''(experimental) Grants permission to update user name update user name response.

        Access Level: Write

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        :stability: experimental
        '''
        return typing.cast("SsoDirectory", jsii.invoke(self, "toUpdateUserName", []))

    @jsii.member(jsii_name="toVerifyEmail")
    def to_verify_email(self) -> "SsoDirectory":
        '''(experimental) Grants permission to verify an email address of an User.

        Access Level: Write

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        :stability: experimental
        '''
        return typing.cast("SsoDirectory", jsii.invoke(self, "toVerifyEmail", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f64a7a006d765c18949b5f7a79044e57cef0e6ed79463989427f08321374be2c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__787c5d11a86646b6b27970042356df605cc6fe5c8f70541d00377a6aae80ab97)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class States(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.States",
):
    '''(experimental) Statement provider for service `states <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsstepfunctions.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `states <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsstepfunctions.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onActivity")
    def on_activity(
        self,
        activity_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "States":
        '''(experimental) Adds a resource of type activity to the statement.

        https://docs.aws.amazon.com/step-functions/latest/dg/concepts-activities.html

        :param activity_name: - Identifier for the activityName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__558ba3042ff4b7351291ebd20a1b767e9f199d6b57d15473ecee13ab80a93d00)
            check_type(argname="argument activity_name", value=activity_name, expected_type=type_hints["activity_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("States", jsii.invoke(self, "onActivity", [activity_name, account, region, partition]))

    @jsii.member(jsii_name="onExecution")
    def on_execution(
        self,
        state_machine_name: builtins.str,
        execution_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "States":
        '''(experimental) Adds a resource of type execution to the statement.

        https://docs.aws.amazon.com/step-functions/latest/dg/concepts-state-machine-executions.html

        :param state_machine_name: - Identifier for the stateMachineName.
        :param execution_id: - Identifier for the executionId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__dcc5706baa3ec6bbc34ee8287099c5d058630ea300a8199d30663733b0bfbd06)
            check_type(argname="argument state_machine_name", value=state_machine_name, expected_type=type_hints["state_machine_name"])
            check_type(argname="argument execution_id", value=execution_id, expected_type=type_hints["execution_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("States", jsii.invoke(self, "onExecution", [state_machine_name, execution_id, account, region, partition]))

    @jsii.member(jsii_name="onExpress")
    def on_express(
        self,
        state_machine_name: builtins.str,
        execution_id: builtins.str,
        express_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "States":
        '''(experimental) Adds a resource of type express to the statement.

        https://docs.aws.amazon.com/step-functions/latest/dg/concepts-state-machine-executions.html

        :param state_machine_name: - Identifier for the stateMachineName.
        :param execution_id: - Identifier for the executionId.
        :param express_id: - Identifier for the expressId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0d08cf01154de0c11537593158b6927755ab95989e86807f2b7de4c5641877c8)
            check_type(argname="argument state_machine_name", value=state_machine_name, expected_type=type_hints["state_machine_name"])
            check_type(argname="argument execution_id", value=execution_id, expected_type=type_hints["execution_id"])
            check_type(argname="argument express_id", value=express_id, expected_type=type_hints["express_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("States", jsii.invoke(self, "onExpress", [state_machine_name, execution_id, express_id, account, region, partition]))

    @jsii.member(jsii_name="onMaprun")
    def on_maprun(
        self,
        state_machine_name: builtins.str,
        map_run_label: builtins.str,
        map_run_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "States":
        '''(experimental) Adds a resource of type maprun to the statement.

        https://docs.aws.amazon.com/step-functions/latest/dg/concepts-examine-map-run.html

        :param state_machine_name: - Identifier for the stateMachineName.
        :param map_run_label: - Identifier for the mapRunLabel.
        :param map_run_id: - Identifier for the mapRunId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0b8604faaed45dad40dec1c686583ffcb385b125f321f0a7f5de732bc9f00070)
            check_type(argname="argument state_machine_name", value=state_machine_name, expected_type=type_hints["state_machine_name"])
            check_type(argname="argument map_run_label", value=map_run_label, expected_type=type_hints["map_run_label"])
            check_type(argname="argument map_run_id", value=map_run_id, expected_type=type_hints["map_run_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("States", jsii.invoke(self, "onMaprun", [state_machine_name, map_run_label, map_run_id, account, region, partition]))

    @jsii.member(jsii_name="onStatemachine")
    def on_statemachine(
        self,
        state_machine_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "States":
        '''(experimental) Adds a resource of type statemachine to the statement.

        https://docs.aws.amazon.com/step-functions/latest/dg/concepts-amazon-states-language.html

        :param state_machine_name: - Identifier for the stateMachineName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__371cdc5cf9d6feae5473d04659722a31f0bc75847446c19f06b25685c5d98239)
            check_type(argname="argument state_machine_name", value=state_machine_name, expected_type=type_hints["state_machine_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("States", jsii.invoke(self, "onStatemachine", [state_machine_name, account, region, partition]))

    @jsii.member(jsii_name="toCreateActivity")
    def to_create_activity(self) -> "States":
        '''(experimental) Grants permission to create an activity.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/step-functions/latest/apireference/API_CreateActivity.html

        :stability: experimental
        '''
        return typing.cast("States", jsii.invoke(self, "toCreateActivity", []))

    @jsii.member(jsii_name="toCreateStateMachine")
    def to_create_state_machine(self) -> "States":
        '''(experimental) Grants permission to create a state machine.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/step-functions/latest/apireference/API_CreateStateMachine.html

        :stability: experimental
        '''
        return typing.cast("States", jsii.invoke(self, "toCreateStateMachine", []))

    @jsii.member(jsii_name="toDeleteActivity")
    def to_delete_activity(self) -> "States":
        '''(experimental) Grants permission to delete an activity.

        Access Level: Write

        https://docs.aws.amazon.com/step-functions/latest/apireference/API_DeleteActivity.html

        :stability: experimental
        '''
        return typing.cast("States", jsii.invoke(self, "toDeleteActivity", []))

    @jsii.member(jsii_name="toDeleteStateMachine")
    def to_delete_state_machine(self) -> "States":
        '''(experimental) Grants permission to delete a state machine.

        Access Level: Write

        https://docs.aws.amazon.com/step-functions/latest/apireference/API_DeleteStateMachine.html

        :stability: experimental
        '''
        return typing.cast("States", jsii.invoke(self, "toDeleteStateMachine", []))

    @jsii.member(jsii_name="toDescribeActivity")
    def to_describe_activity(self) -> "States":
        '''(experimental) Grants permission to describe an activity.

        Access Level: Read

        https://docs.aws.amazon.com/step-functions/latest/apireference/API_DescribeActivity.html

        :stability: experimental
        '''
        return typing.cast("States", jsii.invoke(self, "toDescribeActivity", []))

    @jsii.member(jsii_name="toDescribeExecution")
    def to_describe_execution(self) -> "States":
        '''(experimental) Grants permission to describe an execution.

        Access Level: Read

        https://docs.aws.amazon.com/step-functions/latest/apireference/API_DescribeExecution.html

        :stability: experimental
        '''
        return typing.cast("States", jsii.invoke(self, "toDescribeExecution", []))

    @jsii.member(jsii_name="toDescribeMapRun")
    def to_describe_map_run(self) -> "States":
        '''(experimental) Grants permission to describe a map run.

        Access Level: Read

        https://docs.aws.amazon.com/step-functions/latest/apireference/API_DescribeMapRun.html

        :stability: experimental
        '''
        return typing.cast("States", jsii.invoke(self, "toDescribeMapRun", []))

    @jsii.member(jsii_name="toDescribeStateMachine")
    def to_describe_state_machine(self) -> "States":
        '''(experimental) Grants permission to describe a state machine.

        Access Level: Read

        https://docs.aws.amazon.com/step-functions/latest/apireference/API_DescribeStateMachine.html

        :stability: experimental
        '''
        return typing.cast("States", jsii.invoke(self, "toDescribeStateMachine", []))

    @jsii.member(jsii_name="toDescribeStateMachineForExecution")
    def to_describe_state_machine_for_execution(self) -> "States":
        '''(experimental) Grants permission to describe the state machine for an execution.

        Access Level: Read

        https://docs.aws.amazon.com/step-functions/latest/apireference/API_DescribeStateMachineForExecution.html

        :stability: experimental
        '''
        return typing.cast("States", jsii.invoke(self, "toDescribeStateMachineForExecution", []))

    @jsii.member(jsii_name="toGetActivityTask")
    def to_get_activity_task(self) -> "States":
        '''(experimental) Grants permission to be used by workers to retrieve a task (with the specified activity ARN) which has been scheduled for execution by a running state machine.

        Access Level: Write

        https://docs.aws.amazon.com/step-functions/latest/apireference/API_GetActivityTask.html

        :stability: experimental
        '''
        return typing.cast("States", jsii.invoke(self, "toGetActivityTask", []))

    @jsii.member(jsii_name="toGetExecutionHistory")
    def to_get_execution_history(self) -> "States":
        '''(experimental) Grants permission to return the history of the specified execution as a list of events.

        Access Level: Read

        https://docs.aws.amazon.com/step-functions/latest/apireference/API_GetExecutionHistory.html

        :stability: experimental
        '''
        return typing.cast("States", jsii.invoke(self, "toGetExecutionHistory", []))

    @jsii.member(jsii_name="toListActivities")
    def to_list_activities(self) -> "States":
        '''(experimental) Grants permission to list the existing activities.

        Access Level: List

        https://docs.aws.amazon.com/step-functions/latest/apireference/API_ListActivities.html

        :stability: experimental
        '''
        return typing.cast("States", jsii.invoke(self, "toListActivities", []))

    @jsii.member(jsii_name="toListExecutions")
    def to_list_executions(self) -> "States":
        '''(experimental) Grants permission to list the executions of a state machine.

        Access Level: Read

        https://docs.aws.amazon.com/step-functions/latest/apireference/API_ListExecutions.html

        :stability: experimental
        '''
        return typing.cast("States", jsii.invoke(self, "toListExecutions", []))

    @jsii.member(jsii_name="toListMapRuns")
    def to_list_map_runs(self) -> "States":
        '''(experimental) Grants permission to list the map runs of an execution.

        Access Level: List

        https://docs.aws.amazon.com/step-functions/latest/apireference/API_ListMapRuns.html

        :stability: experimental
        '''
        return typing.cast("States", jsii.invoke(self, "toListMapRuns", []))

    @jsii.member(jsii_name="toListStateMachines")
    def to_list_state_machines(self) -> "States":
        '''(experimental) Grants permission to lists the existing state machines.

        Access Level: List

        https://docs.aws.amazon.com/step-functions/latest/apireference/API_ListStateMachines.html

        :stability: experimental
        '''
        return typing.cast("States", jsii.invoke(self, "toListStateMachines", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "States":
        '''(experimental) Grants permission to list tags for an AWS Step Functions resource.

        Access Level: Read

        https://docs.aws.amazon.com/step-functions/latest/apireference/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("States", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toSendTaskFailure")
    def to_send_task_failure(self) -> "States":
        '''(experimental) Grants permission to report that the task identified by the taskToken failed.

        Access Level: Write

        https://docs.aws.amazon.com/step-functions/latest/apireference/API_SendTaskFailure.html

        :stability: experimental
        '''
        return typing.cast("States", jsii.invoke(self, "toSendTaskFailure", []))

    @jsii.member(jsii_name="toSendTaskHeartbeat")
    def to_send_task_heartbeat(self) -> "States":
        '''(experimental) Grants permission to report to the service that the task represented by the specified taskToken is still making progress.

        Access Level: Write

        https://docs.aws.amazon.com/step-functions/latest/apireference/API_SendTaskHeartbeat.html

        :stability: experimental
        '''
        return typing.cast("States", jsii.invoke(self, "toSendTaskHeartbeat", []))

    @jsii.member(jsii_name="toSendTaskSuccess")
    def to_send_task_success(self) -> "States":
        '''(experimental) Grants permission to report that the task identified by the taskToken completed successfully.

        Access Level: Write

        https://docs.aws.amazon.com/step-functions/latest/apireference/API_SendTaskSuccess.html

        :stability: experimental
        '''
        return typing.cast("States", jsii.invoke(self, "toSendTaskSuccess", []))

    @jsii.member(jsii_name="toStartExecution")
    def to_start_execution(self) -> "States":
        '''(experimental) Grants permission to start a state machine execution.

        Access Level: Write

        https://docs.aws.amazon.com/step-functions/latest/apireference/API_StartExecution.html

        :stability: experimental
        '''
        return typing.cast("States", jsii.invoke(self, "toStartExecution", []))

    @jsii.member(jsii_name="toStartSyncExecution")
    def to_start_sync_execution(self) -> "States":
        '''(experimental) Grants permission to start a Synchronous Express state machine execution.

        Access Level: Write

        https://docs.aws.amazon.com/step-functions/latest/apireference/API_StartSyncExecution.html

        :stability: experimental
        '''
        return typing.cast("States", jsii.invoke(self, "toStartSyncExecution", []))

    @jsii.member(jsii_name="toStopExecution")
    def to_stop_execution(self) -> "States":
        '''(experimental) Grants permission to stop an execution.

        Access Level: Write

        https://docs.aws.amazon.com/step-functions/latest/apireference/API_StopExecution.html

        :stability: experimental
        '''
        return typing.cast("States", jsii.invoke(self, "toStopExecution", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "States":
        '''(experimental) Grants permission to tag an AWS Step Functions resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/step-functions/latest/apireference/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("States", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "States":
        '''(experimental) Grants permission to remove a tag from an AWS Step Functions resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/step-functions/latest/apireference/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("States", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateMapRun")
    def to_update_map_run(self) -> "States":
        '''(experimental) Grants permission to update a map run.

        Access Level: Write

        https://docs.aws.amazon.com/step-functions/latest/apireference/API_UpdateMapRun.html

        :stability: experimental
        '''
        return typing.cast("States", jsii.invoke(self, "toUpdateMapRun", []))

    @jsii.member(jsii_name="toUpdateStateMachine")
    def to_update_state_machine(self) -> "States":
        '''(experimental) Grants permission to update a state machine.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/step-functions/latest/apireference/API_UpdateStateMachine.html

        :stability: experimental
        '''
        return typing.cast("States", jsii.invoke(self, "toUpdateStateMachine", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5e1117abb17bbbcde1b74f5e12995845b21c4adbe94a606d8ebe0d1f023e67d8)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__18ba367d14016da9f9c8368572c4f06c230189fd9db5659134123d92c9a28793)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Storagegateway(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Storagegateway",
):
    '''(experimental) Statement provider for service `storagegateway <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsstoragegateway.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `storagegateway <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsstoragegateway.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onDevice")
    def on_device(
        self,
        gateway_id: builtins.str,
        vtldevice: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Storagegateway":
        '''(experimental) Adds a resource of type device to the statement.

        https://docs.aws.amazon.com/storagegateway/latest/userguide/resource_vtl-devices.html

        :param gateway_id: - Identifier for the gatewayId.
        :param vtldevice: - Identifier for the vtldevice.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4fb192b6785fa11b7d9e641be419a29f7a6f39cc9ba47d66e037918983039438)
            check_type(argname="argument gateway_id", value=gateway_id, expected_type=type_hints["gateway_id"])
            check_type(argname="argument vtldevice", value=vtldevice, expected_type=type_hints["vtldevice"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Storagegateway", jsii.invoke(self, "onDevice", [gateway_id, vtldevice, account, region, partition]))

    @jsii.member(jsii_name="onFsAssociation")
    def on_fs_association(
        self,
        fsa_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Storagegateway":
        '''(experimental) Adds a resource of type fs-association to the statement.

        https://docs.aws.amazon.com/storagegateway/latest/userguide/API_AssociateFileSystem.html

        :param fsa_id: - Identifier for the fsaId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a077a391756bb466ce8bdb6e922f29c9145e7422b6a5ecfaeef1d6a23e710176)
            check_type(argname="argument fsa_id", value=fsa_id, expected_type=type_hints["fsa_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Storagegateway", jsii.invoke(self, "onFsAssociation", [fsa_id, account, region, partition]))

    @jsii.member(jsii_name="onGateway")
    def on_gateway(
        self,
        gateway_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Storagegateway":
        '''(experimental) Adds a resource of type gateway to the statement.

        https://docs.aws.amazon.com/storagegateway/latest/userguide/StorageGatewayConcepts.html

        :param gateway_id: - Identifier for the gatewayId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__af6d28bfee531ff5c157dae0e63e6ee8e2e421f080ce1fdc9325c4b0340bc617)
            check_type(argname="argument gateway_id", value=gateway_id, expected_type=type_hints["gateway_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Storagegateway", jsii.invoke(self, "onGateway", [gateway_id, account, region, partition]))

    @jsii.member(jsii_name="onShare")
    def on_share(
        self,
        share_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Storagegateway":
        '''(experimental) Adds a resource of type share to the statement.

        https://docs.aws.amazon.com/storagegateway/latest/userguide/GettingStartedCreateFileShare.html

        :param share_id: - Identifier for the shareId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__754341200f2aa040d02b5786e71846d9e73e45015da100ad54a24e375bc35306)
            check_type(argname="argument share_id", value=share_id, expected_type=type_hints["share_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Storagegateway", jsii.invoke(self, "onShare", [share_id, account, region, partition]))

    @jsii.member(jsii_name="onTape")
    def on_tape(
        self,
        tape_barcode: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Storagegateway":
        '''(experimental) Adds a resource of type tape to the statement.

        https://docs.aws.amazon.com/storagegateway/latest/userguide/StorageGatewayConcepts.html#storage-gateway-vtl-concepts

        :param tape_barcode: - Identifier for the tapeBarcode.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__90706ff6e78cb2419b55d1f33749338586611630676fa6f58e363dcc2c10cebb)
            check_type(argname="argument tape_barcode", value=tape_barcode, expected_type=type_hints["tape_barcode"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Storagegateway", jsii.invoke(self, "onTape", [tape_barcode, account, region, partition]))

    @jsii.member(jsii_name="onTapepool")
    def on_tapepool(
        self,
        pool_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Storagegateway":
        '''(experimental) Adds a resource of type tapepool to the statement.

        https://docs.aws.amazon.com/storagegateway/latest/userguide/CreatingCustomTapePool.html

        :param pool_id: - Identifier for the poolId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__cc253ecd33a0941efee24c35c9f89306c75108027568e7c78f5e53510fb972a1)
            check_type(argname="argument pool_id", value=pool_id, expected_type=type_hints["pool_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Storagegateway", jsii.invoke(self, "onTapepool", [pool_id, account, region, partition]))

    @jsii.member(jsii_name="onTarget")
    def on_target(
        self,
        gateway_id: builtins.str,
        iscsi_target: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Storagegateway":
        '''(experimental) Adds a resource of type target to the statement.

        https://docs.aws.amazon.com/storagegateway/latest/userguide/GettingStartedCreateVolumes.html

        :param gateway_id: - Identifier for the gatewayId.
        :param iscsi_target: - Identifier for the iscsiTarget.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f9373ae1594af2143e0ed9397758480e68c2eab5f307b257e0b881d4f499f92f)
            check_type(argname="argument gateway_id", value=gateway_id, expected_type=type_hints["gateway_id"])
            check_type(argname="argument iscsi_target", value=iscsi_target, expected_type=type_hints["iscsi_target"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Storagegateway", jsii.invoke(self, "onTarget", [gateway_id, iscsi_target, account, region, partition]))

    @jsii.member(jsii_name="onVolume")
    def on_volume(
        self,
        gateway_id: builtins.str,
        volume_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Storagegateway":
        '''(experimental) Adds a resource of type volume to the statement.

        https://docs.aws.amazon.com/storagegateway/latest/userguide/StorageGatewayConcepts.html#volume-gateway-concepts

        :param gateway_id: - Identifier for the gatewayId.
        :param volume_id: - Identifier for the volumeId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e7df4aae276d6f8fa82ea0d8ba45035d48913bcac8c185595fca043f0f37318e)
            check_type(argname="argument gateway_id", value=gateway_id, expected_type=type_hints["gateway_id"])
            check_type(argname="argument volume_id", value=volume_id, expected_type=type_hints["volume_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Storagegateway", jsii.invoke(self, "onVolume", [gateway_id, volume_id, account, region, partition]))

    @jsii.member(jsii_name="toActivateGateway")
    def to_activate_gateway(self) -> "Storagegateway":
        '''(experimental) Grants permission to activate the gateway you previously deployed on your host.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_ActivateGateway.html

        :stability: experimental
        '''
        return typing.cast("Storagegateway", jsii.invoke(self, "toActivateGateway", []))

    @jsii.member(jsii_name="toAddCache")
    def to_add_cache(self) -> "Storagegateway":
        '''(experimental) Grants permission to configure one or more gateway local disks as cache for a cached-volume gateway.

        Access Level: Write

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_AddCache.html

        :stability: experimental
        '''
        return typing.cast("Storagegateway", jsii.invoke(self, "toAddCache", []))

    @jsii.member(jsii_name="toAddTagsToResource")
    def to_add_tags_to_resource(self) -> "Storagegateway":
        '''(experimental) Grants permission to add one or more tags to the specified resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_AddTagsToResource.html

        :stability: experimental
        '''
        return typing.cast("Storagegateway", jsii.invoke(self, "toAddTagsToResource", []))

    @jsii.member(jsii_name="toAddUploadBuffer")
    def to_add_upload_buffer(self) -> "Storagegateway":
        '''(experimental) Grants permission to configure one or more gateway local disks as upload buffer for a specified gateway.

        Access Level: Write

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_AddUploadBuffer.html

        :stability: experimental
        '''
        return typing.cast("Storagegateway", jsii.invoke(self, "toAddUploadBuffer", []))

    @jsii.member(jsii_name="toAddWorkingStorage")
    def to_add_working_storage(self) -> "Storagegateway":
        '''(experimental) Grants permission to configure one or more gateway local disks as working storage for a gateway.

        Access Level: Write

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_AddWorkingStorage.html

        :stability: experimental
        '''
        return typing.cast("Storagegateway", jsii.invoke(self, "toAddWorkingStorage", []))

    @jsii.member(jsii_name="toAssignTapePool")
    def to_assign_tape_pool(self) -> "Storagegateway":
        '''(experimental) Grants permission to move a tape to the target pool specified.

        Access Level: Write

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_AssignTapePool.html

        :stability: experimental
        '''
        return typing.cast("Storagegateway", jsii.invoke(self, "toAssignTapePool", []))

    @jsii.member(jsii_name="toAssociateFileSystem")
    def to_associate_file_system(self) -> "Storagegateway":
        '''(experimental) Grants permission to associate an Amazon FSx file system with the Amazon FSx file gateway.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - ds:DescribeDirectories
        - ec2:DescribeNetworkInterfaces
        - fsx:DescribeFileSystems
        - iam:CreateServiceLinkedRole
        - logs:CreateLogDelivery
        - logs:GetLogDelivery
        - logs:ListLogDeliveries
        - logs:UpdateLogDelivery

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_AssociateFileSystem.html

        :stability: experimental
        '''
        return typing.cast("Storagegateway", jsii.invoke(self, "toAssociateFileSystem", []))

    @jsii.member(jsii_name="toAttachVolume")
    def to_attach_volume(self) -> "Storagegateway":
        '''(experimental) Grants permission to connect a volume to an iSCSI connection and then attaches the volume to the specified gateway.

        Access Level: Write

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_AttachVolume.html

        :stability: experimental
        '''
        return typing.cast("Storagegateway", jsii.invoke(self, "toAttachVolume", []))

    @jsii.member(jsii_name="toBypassGovernanceRetention")
    def to_bypass_governance_retention(self) -> "Storagegateway":
        '''(experimental) Grants permission to allow the governance retention lock on a pool to be bypassed.

        Access Level: Write

        https://docs.aws.amazon.com/storagegateway/latest/userguide/CreatingCustomTapePool.html#TapeRetentionLock

        :stability: experimental
        '''
        return typing.cast("Storagegateway", jsii.invoke(self, "toBypassGovernanceRetention", []))

    @jsii.member(jsii_name="toCancelArchival")
    def to_cancel_archival(self) -> "Storagegateway":
        '''(experimental) Grants permission to cancel archiving of a virtual tape to the virtual tape shelf (VTS) after the archiving process is initiated.

        Access Level: Write

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_CancelArchival.html

        :stability: experimental
        '''
        return typing.cast("Storagegateway", jsii.invoke(self, "toCancelArchival", []))

    @jsii.member(jsii_name="toCancelRetrieval")
    def to_cancel_retrieval(self) -> "Storagegateway":
        '''(experimental) Grants permission to cancel retrieval of a virtual tape from the virtual tape shelf (VTS) to a gateway after the retrieval process is initiated.

        Access Level: Write

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_CancelRetrieval.html

        :stability: experimental
        '''
        return typing.cast("Storagegateway", jsii.invoke(self, "toCancelRetrieval", []))

    @jsii.member(jsii_name="toCreateCachediSCSIVolume")
    def to_create_cachedi_scsi_volume(self) -> "Storagegateway":
        '''(experimental) Grants permission to create a cached volume on a specified cached gateway.

        This operation is supported only for the gateway-cached volume architecture

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_CreateCachediSCSIVolume.html

        :stability: experimental
        '''
        return typing.cast("Storagegateway", jsii.invoke(self, "toCreateCachediSCSIVolume", []))

    @jsii.member(jsii_name="toCreateNFSFileShare")
    def to_create_nfs_file_share(self) -> "Storagegateway":
        '''(experimental) Grants permission to create a NFS file share on an existing file gateway.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_CreateNFSFileShare.html

        :stability: experimental
        '''
        return typing.cast("Storagegateway", jsii.invoke(self, "toCreateNFSFileShare", []))

    @jsii.member(jsii_name="toCreateSMBFileShare")
    def to_create_smb_file_share(self) -> "Storagegateway":
        '''(experimental) Grants permission to create a SMB file share on an existing file gateway.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_CreateSMBFileShare.html

        :stability: experimental
        '''
        return typing.cast("Storagegateway", jsii.invoke(self, "toCreateSMBFileShare", []))

    @jsii.member(jsii_name="toCreateSnapshot")
    def to_create_snapshot(self) -> "Storagegateway":
        '''(experimental) Grants permission to initiate a snapshot of a volume.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_CreateSnapshot.html

        :stability: experimental
        '''
        return typing.cast("Storagegateway", jsii.invoke(self, "toCreateSnapshot", []))

    @jsii.member(jsii_name="toCreateSnapshotFromVolumeRecoveryPoint")
    def to_create_snapshot_from_volume_recovery_point(self) -> "Storagegateway":
        '''(experimental) Grants permission to initiate a snapshot of a gateway from a volume recovery point.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_CreateSnapshotFromVolumeRecoveryPoint.html

        :stability: experimental
        '''
        return typing.cast("Storagegateway", jsii.invoke(self, "toCreateSnapshotFromVolumeRecoveryPoint", []))

    @jsii.member(jsii_name="toCreateStorediSCSIVolume")
    def to_create_storedi_scsi_volume(self) -> "Storagegateway":
        '''(experimental) Grants permission to create a volume on a specified gateway.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_CreateStorediSCSIVolume.html

        :stability: experimental
        '''
        return typing.cast("Storagegateway", jsii.invoke(self, "toCreateStorediSCSIVolume", []))

    @jsii.member(jsii_name="toCreateTapePool")
    def to_create_tape_pool(self) -> "Storagegateway":
        '''(experimental) Grants permission to create a tape pool.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_CreateTapePool.html

        :stability: experimental
        '''
        return typing.cast("Storagegateway", jsii.invoke(self, "toCreateTapePool", []))

    @jsii.member(jsii_name="toCreateTapes")
    def to_create_tapes(self) -> "Storagegateway":
        '''(experimental) Grants permission to create one or more virtual tapes.

        You write data to the virtual tapes and then archive the tapes

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_CreateTapes.html

        :stability: experimental
        '''
        return typing.cast("Storagegateway", jsii.invoke(self, "toCreateTapes", []))

    @jsii.member(jsii_name="toCreateTapeWithBarcode")
    def to_create_tape_with_barcode(self) -> "Storagegateway":
        '''(experimental) Grants permission to create a virtual tape by using your own barcode.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_CreateTapeWithBarcode.html

        :stability: experimental
        '''
        return typing.cast("Storagegateway", jsii.invoke(self, "toCreateTapeWithBarcode", []))

    @jsii.member(jsii_name="toDeleteAutomaticTapeCreationPolicy")
    def to_delete_automatic_tape_creation_policy(self) -> "Storagegateway":
        '''(experimental) Grants permission to delete the automatic tape creation policy configured on a gateway-VTL.

        Access Level: Write

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_DeleteAutomaticTapeCreationPolicy.html

        :stability: experimental
        '''
        return typing.cast("Storagegateway", jsii.invoke(self, "toDeleteAutomaticTapeCreationPolicy", []))

    @jsii.member(jsii_name="toDeleteBandwidthRateLimit")
    def to_delete_bandwidth_rate_limit(self) -> "Storagegateway":
        '''(experimental) Grants permission to delete the bandwidth rate limits of a gateway.

        Access Level: Write

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_DeleteBandwidthRateLimit.html

        :stability: experimental
        '''
        return typing.cast("Storagegateway", jsii.invoke(self, "toDeleteBandwidthRateLimit", []))

    @jsii.member(jsii_name="toDeleteChapCredentials")
    def to_delete_chap_credentials(self) -> "Storagegateway":
        '''(experimental) Grants permission to delete Challenge-Handshake Authentication Protocol (CHAP) credentials for a specified iSCSI target and initiator pair.

        Access Level: Write

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_DeleteChapCredentials.html

        :stability: experimental
        '''
        return typing.cast("Storagegateway", jsii.invoke(self, "toDeleteChapCredentials", []))

    @jsii.member(jsii_name="toDeleteFileShare")
    def to_delete_file_share(self) -> "Storagegateway":
        '''(experimental) Grants permission to delete a file share from a file gateway.

        Access Level: Write

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_DeleteFileShare.html

        :stability: experimental
        '''
        return typing.cast("Storagegateway", jsii.invoke(self, "toDeleteFileShare", []))

    @jsii.member(jsii_name="toDeleteGateway")
    def to_delete_gateway(self) -> "Storagegateway":
        '''(experimental) Grants permission to delete a gateway.

        Access Level: Write

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_DeleteGateway.html

        :stability: experimental
        '''
        return typing.cast("Storagegateway", jsii.invoke(self, "toDeleteGateway", []))

    @jsii.member(jsii_name="toDeleteSnapshotSchedule")
    def to_delete_snapshot_schedule(self) -> "Storagegateway":
        '''(experimental) Grants permission to delete a snapshot of a volume.

        Access Level: Write

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_DeleteSnapshotSchedule.html

        :stability: experimental
        '''
        return typing.cast("Storagegateway", jsii.invoke(self, "toDeleteSnapshotSchedule", []))

    @jsii.member(jsii_name="toDeleteTape")
    def to_delete_tape(self) -> "Storagegateway":
        '''(experimental) Grants permission to delete the specified virtual tape.

        Access Level: Write

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_DeleteTape.html

        :stability: experimental
        '''
        return typing.cast("Storagegateway", jsii.invoke(self, "toDeleteTape", []))

    @jsii.member(jsii_name="toDeleteTapeArchive")
    def to_delete_tape_archive(self) -> "Storagegateway":
        '''(experimental) Grants permission to delete the specified virtual tape from the virtual tape shelf (VTS).

        Access Level: Write

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_DeleteTapeArchive.html

        :stability: experimental
        '''
        return typing.cast("Storagegateway", jsii.invoke(self, "toDeleteTapeArchive", []))

    @jsii.member(jsii_name="toDeleteTapePool")
    def to_delete_tape_pool(self) -> "Storagegateway":
        '''(experimental) Grants permission to delete the specified tape pool.

        Access Level: Write

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_DeleteTapePool.html

        :stability: experimental
        '''
        return typing.cast("Storagegateway", jsii.invoke(self, "toDeleteTapePool", []))

    @jsii.member(jsii_name="toDeleteVolume")
    def to_delete_volume(self) -> "Storagegateway":
        '''(experimental) Grants permission to delete the specified gateway volume that you previously created using the CreateCachediSCSIVolume or CreateStorediSCSIVolume API.

        Access Level: Write

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_DeleteVolume.html

        :stability: experimental
        '''
        return typing.cast("Storagegateway", jsii.invoke(self, "toDeleteVolume", []))

    @jsii.member(jsii_name="toDescribeAvailabilityMonitorTest")
    def to_describe_availability_monitor_test(self) -> "Storagegateway":
        '''(experimental) Grants permission to get the information about the most recent high availability monitoring test that was performed on the gateway.

        Access Level: Read

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_DescribeAvailabilityMonitorTest.html

        :stability: experimental
        '''
        return typing.cast("Storagegateway", jsii.invoke(self, "toDescribeAvailabilityMonitorTest", []))

    @jsii.member(jsii_name="toDescribeBandwidthRateLimit")
    def to_describe_bandwidth_rate_limit(self) -> "Storagegateway":
        '''(experimental) Grants permission to get the bandwidth rate limits of a gateway.

        Access Level: Read

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_DescribeBandwidthRateLimit.html

        :stability: experimental
        '''
        return typing.cast("Storagegateway", jsii.invoke(self, "toDescribeBandwidthRateLimit", []))

    @jsii.member(jsii_name="toDescribeBandwidthRateLimitSchedule")
    def to_describe_bandwidth_rate_limit_schedule(self) -> "Storagegateway":
        '''(experimental) Grants permission to get the bandwidth rate limit schedule of a gateway.

        Access Level: Read

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_DescribeBandwidthRateLimitSchedule.html

        :stability: experimental
        '''
        return typing.cast("Storagegateway", jsii.invoke(self, "toDescribeBandwidthRateLimitSchedule", []))

    @jsii.member(jsii_name="toDescribeCache")
    def to_describe_cache(self) -> "Storagegateway":
        '''(experimental) Grants permission to get information about the cache of a gateway.

        This operation is supported only for the gateway-cached volume architecture

        Access Level: Read

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_DescribeCache.html

        :stability: experimental
        '''
        return typing.cast("Storagegateway", jsii.invoke(self, "toDescribeCache", []))

    @jsii.member(jsii_name="toDescribeCachediSCSIVolumes")
    def to_describe_cachedi_scsi_volumes(self) -> "Storagegateway":
        '''(experimental) Grants permission to get a description of the gateway volumes specified in the request.

        This operation is supported only for the gateway-cached volume architecture

        Access Level: Read

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_DescribeCachediSCSIVolumes.html

        :stability: experimental
        '''
        return typing.cast("Storagegateway", jsii.invoke(self, "toDescribeCachediSCSIVolumes", []))

    @jsii.member(jsii_name="toDescribeChapCredentials")
    def to_describe_chap_credentials(self) -> "Storagegateway":
        '''(experimental) Grants permission to get an array of Challenge-Handshake Authentication Protocol (CHAP) credentials information for a specified iSCSI target, one for each target-initiator pair.

        Access Level: Read

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_DescribeChapCredentials.html

        :stability: experimental
        '''
        return typing.cast("Storagegateway", jsii.invoke(self, "toDescribeChapCredentials", []))

    @jsii.member(jsii_name="toDescribeFileSystemAssociations")
    def to_describe_file_system_associations(self) -> "Storagegateway":
        '''(experimental) Grants permission to get a description for one or more file system associations.

        Access Level: Read

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_DescribeFileSystemAssociations.html

        :stability: experimental
        '''
        return typing.cast("Storagegateway", jsii.invoke(self, "toDescribeFileSystemAssociations", []))

    @jsii.member(jsii_name="toDescribeGatewayInformation")
    def to_describe_gateway_information(self) -> "Storagegateway":
        '''(experimental) Grants permission to get metadata about a gateway such as its name, network interfaces, configured time zone, and the state (whether the gateway is running or not).

        Access Level: Read

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_DescribeGatewayInformation.html

        :stability: experimental
        '''
        return typing.cast("Storagegateway", jsii.invoke(self, "toDescribeGatewayInformation", []))

    @jsii.member(jsii_name="toDescribeMaintenanceStartTime")
    def to_describe_maintenance_start_time(self) -> "Storagegateway":
        '''(experimental) Grants permission to get your gateway's weekly maintenance start time including the day and time of the week.

        Access Level: Read

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_DescribeMaintenanceStartTime.html

        :stability: experimental
        '''
        return typing.cast("Storagegateway", jsii.invoke(self, "toDescribeMaintenanceStartTime", []))

    @jsii.member(jsii_name="toDescribeNFSFileShares")
    def to_describe_nfs_file_shares(self) -> "Storagegateway":
        '''(experimental) Grants permission to get a description for one or more file shares from a file gateway.

        Access Level: Read

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_DescribeNFSFileShares.html

        :stability: experimental
        '''
        return typing.cast("Storagegateway", jsii.invoke(self, "toDescribeNFSFileShares", []))

    @jsii.member(jsii_name="toDescribeSMBFileShares")
    def to_describe_smb_file_shares(self) -> "Storagegateway":
        '''(experimental) Grants permission to get a description for one or more file shares from a file gateway.

        Access Level: Read

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_DescribeSMBFileShares.html

        :stability: experimental
        '''
        return typing.cast("Storagegateway", jsii.invoke(self, "toDescribeSMBFileShares", []))

    @jsii.member(jsii_name="toDescribeSMBSettings")
    def to_describe_smb_settings(self) -> "Storagegateway":
        '''(experimental) Grants permission to get a description of a Server Message Block (SMB) file share settings from a file gateway.

        Access Level: Read

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_DescribeSMBSettings.html

        :stability: experimental
        '''
        return typing.cast("Storagegateway", jsii.invoke(self, "toDescribeSMBSettings", []))

    @jsii.member(jsii_name="toDescribeSnapshotSchedule")
    def to_describe_snapshot_schedule(self) -> "Storagegateway":
        '''(experimental) Grants permission to describe the snapshot schedule for the specified gateway volume.

        Access Level: Read

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_DescribeSnapshotSchedule.html

        :stability: experimental
        '''
        return typing.cast("Storagegateway", jsii.invoke(self, "toDescribeSnapshotSchedule", []))

    @jsii.member(jsii_name="toDescribeStorediSCSIVolumes")
    def to_describe_storedi_scsi_volumes(self) -> "Storagegateway":
        '''(experimental) Grants permission to get the description of the gateway volumes specified in the request.

        Access Level: Read

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_DescribeStorediSCSIVolumes.html

        :stability: experimental
        '''
        return typing.cast("Storagegateway", jsii.invoke(self, "toDescribeStorediSCSIVolumes", []))

    @jsii.member(jsii_name="toDescribeTapeArchives")
    def to_describe_tape_archives(self) -> "Storagegateway":
        '''(experimental) Grants permission to get a description of specified virtual tapes in the virtual tape shelf (VTS).

        Access Level: Read

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_DescribeTapeArchives.html

        :stability: experimental
        '''
        return typing.cast("Storagegateway", jsii.invoke(self, "toDescribeTapeArchives", []))

    @jsii.member(jsii_name="toDescribeTapeRecoveryPoints")
    def to_describe_tape_recovery_points(self) -> "Storagegateway":
        '''(experimental) Grants permission to get a list of virtual tape recovery points that are available for the specified gateway-VTL.

        Access Level: Read

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_DescribeTapeRecoveryPoints.html

        :stability: experimental
        '''
        return typing.cast("Storagegateway", jsii.invoke(self, "toDescribeTapeRecoveryPoints", []))

    @jsii.member(jsii_name="toDescribeTapes")
    def to_describe_tapes(self) -> "Storagegateway":
        '''(experimental) Grants permission to get a description of the specified Amazon Resource Name (ARN) of virtual tapes.

        Access Level: Read

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_DescribeTapes.html

        :stability: experimental
        '''
        return typing.cast("Storagegateway", jsii.invoke(self, "toDescribeTapes", []))

    @jsii.member(jsii_name="toDescribeUploadBuffer")
    def to_describe_upload_buffer(self) -> "Storagegateway":
        '''(experimental) Grants permission to get information about the upload buffer of a gateway.

        Access Level: Read

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_DescribeUploadBuffer.html

        :stability: experimental
        '''
        return typing.cast("Storagegateway", jsii.invoke(self, "toDescribeUploadBuffer", []))

    @jsii.member(jsii_name="toDescribeVTLDevices")
    def to_describe_vtl_devices(self) -> "Storagegateway":
        '''(experimental) Grants permission to get a description of virtual tape library (VTL) devices for the specified gateway.

        Access Level: Read

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_DescribeVTLDevices.html

        :stability: experimental
        '''
        return typing.cast("Storagegateway", jsii.invoke(self, "toDescribeVTLDevices", []))

    @jsii.member(jsii_name="toDescribeWorkingStorage")
    def to_describe_working_storage(self) -> "Storagegateway":
        '''(experimental) Grants permission to get information about the working storage of a gateway.

        Access Level: Read

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_DescribeWorkingStorage.html

        :stability: experimental
        '''
        return typing.cast("Storagegateway", jsii.invoke(self, "toDescribeWorkingStorage", []))

    @jsii.member(jsii_name="toDetachVolume")
    def to_detach_volume(self) -> "Storagegateway":
        '''(experimental) Grants permission to disconnect a volume from an iSCSI connection and then detaches the volume from the specified gateway.

        Access Level: Write

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_DetachVolume.html

        :stability: experimental
        '''
        return typing.cast("Storagegateway", jsii.invoke(self, "toDetachVolume", []))

    @jsii.member(jsii_name="toDisableGateway")
    def to_disable_gateway(self) -> "Storagegateway":
        '''(experimental) Grants permission to disable a gateway when the gateway is no longer functioning.

        Access Level: Write

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_DisableGateway.html

        :stability: experimental
        '''
        return typing.cast("Storagegateway", jsii.invoke(self, "toDisableGateway", []))

    @jsii.member(jsii_name="toDisassociateFileSystem")
    def to_disassociate_file_system(self) -> "Storagegateway":
        '''(experimental) Grants permission to disassociate an Amazon FSx file system from an Amazon FSx file gateway.

        Access Level: Write

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_DisassociateFileSystem.html

        :stability: experimental
        '''
        return typing.cast("Storagegateway", jsii.invoke(self, "toDisassociateFileSystem", []))

    @jsii.member(jsii_name="toJoinDomain")
    def to_join_domain(self) -> "Storagegateway":
        '''(experimental) Grants permission to enable you to join an Active Directory Domain.

        Access Level: Write

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_JoinDomain.html

        :stability: experimental
        '''
        return typing.cast("Storagegateway", jsii.invoke(self, "toJoinDomain", []))

    @jsii.member(jsii_name="toListAutomaticTapeCreationPolicies")
    def to_list_automatic_tape_creation_policies(self) -> "Storagegateway":
        '''(experimental) Grants permission to list the automatic tape creation policies configured on the specified gateway-VTL or all gateway-VTLs owned by your account.

        Access Level: List

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_ListAutomaticTapeCreationPolicies.html

        :stability: experimental
        '''
        return typing.cast("Storagegateway", jsii.invoke(self, "toListAutomaticTapeCreationPolicies", []))

    @jsii.member(jsii_name="toListFileShares")
    def to_list_file_shares(self) -> "Storagegateway":
        '''(experimental) Grants permission to get a list of the file shares for a specific file gateway, or the list of file shares that belong to the calling user account.

        Access Level: List

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_ListFileShares.html

        :stability: experimental
        '''
        return typing.cast("Storagegateway", jsii.invoke(self, "toListFileShares", []))

    @jsii.member(jsii_name="toListFileSystemAssociations")
    def to_list_file_system_associations(self) -> "Storagegateway":
        '''(experimental) Grants permission to get a list of the file system associations for the specified gateway.

        Access Level: List

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_ListFileSystemAssociations.html

        :stability: experimental
        '''
        return typing.cast("Storagegateway", jsii.invoke(self, "toListFileSystemAssociations", []))

    @jsii.member(jsii_name="toListGateways")
    def to_list_gateways(self) -> "Storagegateway":
        '''(experimental) Grants permission to list gateways owned by an AWS account in a region specified in the request.

        The returned list is ordered by gateway Amazon Resource Name (ARN)

        Access Level: List

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_ListGateways.html

        :stability: experimental
        '''
        return typing.cast("Storagegateway", jsii.invoke(self, "toListGateways", []))

    @jsii.member(jsii_name="toListLocalDisks")
    def to_list_local_disks(self) -> "Storagegateway":
        '''(experimental) Grants permission to get a list of the gateway's local disks.

        Access Level: List

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_ListLocalDisks.html

        :stability: experimental
        '''
        return typing.cast("Storagegateway", jsii.invoke(self, "toListLocalDisks", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Storagegateway":
        '''(experimental) Grants permission to get the tags that have been added to the specified resource.

        Access Level: List

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("Storagegateway", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toListTapePools")
    def to_list_tape_pools(self) -> "Storagegateway":
        '''(experimental) Grants permission to list tape pools owned by your AWS account.

        Access Level: List

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_ListTapePools.html

        :stability: experimental
        '''
        return typing.cast("Storagegateway", jsii.invoke(self, "toListTapePools", []))

    @jsii.member(jsii_name="toListTapes")
    def to_list_tapes(self) -> "Storagegateway":
        '''(experimental) Grants permission to list virtual tapes in your virtual tape library (VTL) and your virtual tape shelf (VTS).

        Access Level: List

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_ListTapes.html

        :stability: experimental
        '''
        return typing.cast("Storagegateway", jsii.invoke(self, "toListTapes", []))

    @jsii.member(jsii_name="toListVolumeInitiators")
    def to_list_volume_initiators(self) -> "Storagegateway":
        '''(experimental) Grants permission to list iSCSI initiators that are connected to a volume.

        Access Level: List

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_ListVolumeInitiators.html

        :stability: experimental
        '''
        return typing.cast("Storagegateway", jsii.invoke(self, "toListVolumeInitiators", []))

    @jsii.member(jsii_name="toListVolumeRecoveryPoints")
    def to_list_volume_recovery_points(self) -> "Storagegateway":
        '''(experimental) Grants permission to list the recovery points for a specified gateway.

        Access Level: List

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_ListVolumeRecoveryPoints.html

        :stability: experimental
        '''
        return typing.cast("Storagegateway", jsii.invoke(self, "toListVolumeRecoveryPoints", []))

    @jsii.member(jsii_name="toListVolumes")
    def to_list_volumes(self) -> "Storagegateway":
        '''(experimental) Grants permission to list the iSCSI stored volumes of a gateway.

        Access Level: List

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_ListVolumes.html

        :stability: experimental
        '''
        return typing.cast("Storagegateway", jsii.invoke(self, "toListVolumes", []))

    @jsii.member(jsii_name="toNotifyWhenUploaded")
    def to_notify_when_uploaded(self) -> "Storagegateway":
        '''(experimental) Grants permission to send you a notification through CloudWatch Events when all files written to your NFS file share have been uploaded to Amazon S3.

        Access Level: Write

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_NotifyWhenUploaded.html

        :stability: experimental
        '''
        return typing.cast("Storagegateway", jsii.invoke(self, "toNotifyWhenUploaded", []))

    @jsii.member(jsii_name="toRefreshCache")
    def to_refresh_cache(self) -> "Storagegateway":
        '''(experimental) Grants permission to refresh the cache for the specified file share.

        Access Level: Write

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_RefreshCache.html

        :stability: experimental
        '''
        return typing.cast("Storagegateway", jsii.invoke(self, "toRefreshCache", []))

    @jsii.member(jsii_name="toRemoveTagsFromResource")
    def to_remove_tags_from_resource(self) -> "Storagegateway":
        '''(experimental) Grants permission to remove one or more tags from the specified resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_RemoveTagsFromResource.html

        :stability: experimental
        '''
        return typing.cast("Storagegateway", jsii.invoke(self, "toRemoveTagsFromResource", []))

    @jsii.member(jsii_name="toResetCache")
    def to_reset_cache(self) -> "Storagegateway":
        '''(experimental) Grants permission to reset all cache disks that have encountered a error and makes the disks available for reconfiguration as cache storage.

        Access Level: Write

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_ResetCache.html

        :stability: experimental
        '''
        return typing.cast("Storagegateway", jsii.invoke(self, "toResetCache", []))

    @jsii.member(jsii_name="toRetrieveTapeArchive")
    def to_retrieve_tape_archive(self) -> "Storagegateway":
        '''(experimental) Grants permission to retrieve an archived virtual tape from the virtual tape shelf (VTS) to a gateway-VTL.

        Access Level: Write

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_RetrieveTapeArchive.html

        :stability: experimental
        '''
        return typing.cast("Storagegateway", jsii.invoke(self, "toRetrieveTapeArchive", []))

    @jsii.member(jsii_name="toRetrieveTapeRecoveryPoint")
    def to_retrieve_tape_recovery_point(self) -> "Storagegateway":
        '''(experimental) Grants permission to retrieve the recovery point for the specified virtual tape.

        Access Level: Write

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_RetrieveTapeRecoveryPoint.html

        :stability: experimental
        '''
        return typing.cast("Storagegateway", jsii.invoke(self, "toRetrieveTapeRecoveryPoint", []))

    @jsii.member(jsii_name="toSetLocalConsolePassword")
    def to_set_local_console_password(self) -> "Storagegateway":
        '''(experimental) Grants permission to set the password for your VM local console.

        Access Level: Write

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_SetLocalConsolePassword.html

        :stability: experimental
        '''
        return typing.cast("Storagegateway", jsii.invoke(self, "toSetLocalConsolePassword", []))

    @jsii.member(jsii_name="toSetSMBGuestPassword")
    def to_set_smb_guest_password(self) -> "Storagegateway":
        '''(experimental) Grants permission to set the password for SMB Guest user.

        Access Level: Write

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_SetSMBGuestPassword.html

        :stability: experimental
        '''
        return typing.cast("Storagegateway", jsii.invoke(self, "toSetSMBGuestPassword", []))

    @jsii.member(jsii_name="toShutdownGateway")
    def to_shutdown_gateway(self) -> "Storagegateway":
        '''(experimental) Grants permission to shut down a gateway.

        Access Level: Write

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_ShutdownGateway.html

        :stability: experimental
        '''
        return typing.cast("Storagegateway", jsii.invoke(self, "toShutdownGateway", []))

    @jsii.member(jsii_name="toStartAvailabilityMonitorTest")
    def to_start_availability_monitor_test(self) -> "Storagegateway":
        '''(experimental) Grants permission to start a test that verifies that the specified gateway is configured for High Availability monitoring in your host environment.

        Access Level: Write

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_StartAvailabilityMonitorTest.html

        :stability: experimental
        '''
        return typing.cast("Storagegateway", jsii.invoke(self, "toStartAvailabilityMonitorTest", []))

    @jsii.member(jsii_name="toStartGateway")
    def to_start_gateway(self) -> "Storagegateway":
        '''(experimental) Grants permission to start a gateway that you previously shut down.

        Access Level: Write

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_StartGateway.html

        :stability: experimental
        '''
        return typing.cast("Storagegateway", jsii.invoke(self, "toStartGateway", []))

    @jsii.member(jsii_name="toUpdateAutomaticTapeCreationPolicy")
    def to_update_automatic_tape_creation_policy(self) -> "Storagegateway":
        '''(experimental) Grants permission to update the automatic tape creation policy configured on a gateway-VTL.

        Access Level: Write

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_UpdateAutomaticTapeCreationPolicy.html

        :stability: experimental
        '''
        return typing.cast("Storagegateway", jsii.invoke(self, "toUpdateAutomaticTapeCreationPolicy", []))

    @jsii.member(jsii_name="toUpdateBandwidthRateLimit")
    def to_update_bandwidth_rate_limit(self) -> "Storagegateway":
        '''(experimental) Grants permission to update the bandwidth rate limits of a gateway.

        Access Level: Write

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_UpdateBandwidthRateLimit.html

        :stability: experimental
        '''
        return typing.cast("Storagegateway", jsii.invoke(self, "toUpdateBandwidthRateLimit", []))

    @jsii.member(jsii_name="toUpdateBandwidthRateLimitSchedule")
    def to_update_bandwidth_rate_limit_schedule(self) -> "Storagegateway":
        '''(experimental) Grants permission to update the bandwidth rate limit schedule of a gateway.

        Access Level: Write

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_UpdateBandwidthRateLimitSchedule.html

        :stability: experimental
        '''
        return typing.cast("Storagegateway", jsii.invoke(self, "toUpdateBandwidthRateLimitSchedule", []))

    @jsii.member(jsii_name="toUpdateChapCredentials")
    def to_update_chap_credentials(self) -> "Storagegateway":
        '''(experimental) Grants permission to update the Challenge-Handshake Authentication Protocol (CHAP) credentials for a specified iSCSI target.

        Access Level: Write

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_UpdateChapCredentials.html

        :stability: experimental
        '''
        return typing.cast("Storagegateway", jsii.invoke(self, "toUpdateChapCredentials", []))

    @jsii.member(jsii_name="toUpdateFileSystemAssociation")
    def to_update_file_system_association(self) -> "Storagegateway":
        '''(experimental) Grants permission to update a file system association.

        Access Level: Write

        Dependent actions:

        - logs:CreateLogDelivery
        - logs:DeleteLogDelivery
        - logs:GetLogDelivery
        - logs:ListLogDeliveries
        - logs:UpdateLogDelivery

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_UpdateFileSystemAssociation.html

        :stability: experimental
        '''
        return typing.cast("Storagegateway", jsii.invoke(self, "toUpdateFileSystemAssociation", []))

    @jsii.member(jsii_name="toUpdateGatewayInformation")
    def to_update_gateway_information(self) -> "Storagegateway":
        '''(experimental) Grants permission to update a gateway's metadata, which includes the gateway's name and time zone.

        Access Level: Write

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_UpdateGatewayInformation.html

        :stability: experimental
        '''
        return typing.cast("Storagegateway", jsii.invoke(self, "toUpdateGatewayInformation", []))

    @jsii.member(jsii_name="toUpdateGatewaySoftwareNow")
    def to_update_gateway_software_now(self) -> "Storagegateway":
        '''(experimental) Grants permission to update the gateway virtual machine (VM) software.

        Access Level: Write

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_UpdateGatewaySoftwareNow.html

        :stability: experimental
        '''
        return typing.cast("Storagegateway", jsii.invoke(self, "toUpdateGatewaySoftwareNow", []))

    @jsii.member(jsii_name="toUpdateMaintenanceStartTime")
    def to_update_maintenance_start_time(self) -> "Storagegateway":
        '''(experimental) Grants permission to update a gateway's weekly maintenance start time information, including day and time of the week.

        The maintenance time is the time in your gateway's time zone

        Access Level: Write

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_UpdateMaintenanceStartTime.html

        :stability: experimental
        '''
        return typing.cast("Storagegateway", jsii.invoke(self, "toUpdateMaintenanceStartTime", []))

    @jsii.member(jsii_name="toUpdateNFSFileShare")
    def to_update_nfs_file_share(self) -> "Storagegateway":
        '''(experimental) Grants permission to update a NFS file share.

        Access Level: Write

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_UpdateNFSFileShare.html

        :stability: experimental
        '''
        return typing.cast("Storagegateway", jsii.invoke(self, "toUpdateNFSFileShare", []))

    @jsii.member(jsii_name="toUpdateSMBFileShare")
    def to_update_smb_file_share(self) -> "Storagegateway":
        '''(experimental) Grants permission to update a SMB file share.

        Access Level: Write

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_UpdateSMBFileShare.html

        :stability: experimental
        '''
        return typing.cast("Storagegateway", jsii.invoke(self, "toUpdateSMBFileShare", []))

    @jsii.member(jsii_name="toUpdateSMBFileShareVisibility")
    def to_update_smb_file_share_visibility(self) -> "Storagegateway":
        '''(experimental) Grants permission to update whether the shares on a gateway are visible in a net view or browse list.

        Access Level: Write

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_UpdateSMBFileShareVisibility.html

        :stability: experimental
        '''
        return typing.cast("Storagegateway", jsii.invoke(self, "toUpdateSMBFileShareVisibility", []))

    @jsii.member(jsii_name="toUpdateSMBLocalGroups")
    def to_update_smb_local_groups(self) -> "Storagegateway":
        '''(experimental) Grants permission to update the list of Active Directory users and groups that have special permissions for SMB file shares on the gateway.

        Access Level: Write

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_UpdateSMBLocalGroups.html

        :stability: experimental
        '''
        return typing.cast("Storagegateway", jsii.invoke(self, "toUpdateSMBLocalGroups", []))

    @jsii.member(jsii_name="toUpdateSMBSecurityStrategy")
    def to_update_smb_security_strategy(self) -> "Storagegateway":
        '''(experimental) Grants permission to update the SMB security strategy on a file gateway.

        Access Level: Write

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_UpdateSMBSecurityStrategy.html

        :stability: experimental
        '''
        return typing.cast("Storagegateway", jsii.invoke(self, "toUpdateSMBSecurityStrategy", []))

    @jsii.member(jsii_name="toUpdateSnapshotSchedule")
    def to_update_snapshot_schedule(self) -> "Storagegateway":
        '''(experimental) Grants permission to update a snapshot schedule configured for a gateway volume.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_UpdateSnapshotSchedule.html

        :stability: experimental
        '''
        return typing.cast("Storagegateway", jsii.invoke(self, "toUpdateSnapshotSchedule", []))

    @jsii.member(jsii_name="toUpdateVTLDeviceType")
    def to_update_vtl_device_type(self) -> "Storagegateway":
        '''(experimental) Grants permission to update the type of medium changer in a gateway-VTL.

        Access Level: Write

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_UpdateVTLDeviceType.html

        :stability: experimental
        '''
        return typing.cast("Storagegateway", jsii.invoke(self, "toUpdateVTLDeviceType", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__747483c0586efaa80b3694c0ceff65a12eb42d7cbc7ea75e061082899522fb52)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5477a0cf3c58a98765b4b40e4250451f457b6b4df6abd5e006def792744b7fe8)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Sts(PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Sts"):
    '''(experimental) Statement provider for service `sts <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awssecuritytokenservice.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `sts <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awssecuritytokenservice.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="ifAmazonAppId")
    def if_amazon_app_id(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Sts":
        '''(experimental) Filters access by the Login with Amazon application ID.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_iam-condition-keys.html#ck_id

        Applies to actions:

        - .toAssumeRoleWithWebIdentity()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a2c759614d4b8558b83546afc917963ac19bfc78c4e9447804e544079855e928)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Sts", jsii.invoke(self, "ifAmazonAppId", [value, operator]))

    @jsii.member(jsii_name="ifAmazonUserId")
    def if_amazon_user_id(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Sts":
        '''(experimental) Filters access by the Login with Amazon user ID.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_iam-condition-keys.html#ck_id

        Applies to actions:

        - .toAssumeRoleWithWebIdentity()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d6b6f0853e6b91f7fc9e02a4a655c45ee8bf3205be180fcff36a79be715569b3)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Sts", jsii.invoke(self, "ifAmazonUserId", [value, operator]))

    @jsii.member(jsii_name="ifAWSServiceName")
    def if_aws_service_name(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Sts":
        '''(experimental) Filters access by the service that is obtaining a bearer token.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_iam-condition-keys.html#ck_awsservicename

        Applies to actions:

        - .toGetServiceBearerToken()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b4aec1e3c4663aa6a614b9300304c2776d349b05b5ae8efc8cfa83f448f329ad)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Sts", jsii.invoke(self, "ifAWSServiceName", [value, operator]))

    @jsii.member(jsii_name="ifCognitoAmr")
    def if_cognito_amr(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Sts":
        '''(experimental) Filters access by the login information for Amazon Cognito.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_iam-condition-keys.html#ck_amr

        Applies to actions:

        - .toAssumeRoleWithWebIdentity()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__853ecce3f5e6fab97ca602c2c4e99d6f16a45dc522bf15cab7b68ec0e5a94636)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Sts", jsii.invoke(self, "ifCognitoAmr", [value, operator]))

    @jsii.member(jsii_name="ifCognitoAud")
    def if_cognito_aud(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Sts":
        '''(experimental) Filters access by the Amazon Cognito identity pool ID.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_iam-condition-keys.html#ck_aud

        Applies to actions:

        - .toAssumeRoleWithWebIdentity()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__17d8e6c76055631872289c3e8d24ee38c76de1bea57a410d4e63ea09b177523b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Sts", jsii.invoke(self, "ifCognitoAud", [value, operator]))

    @jsii.member(jsii_name="ifCognitoSub")
    def if_cognito_sub(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Sts":
        '''(experimental) Filters access by the subject of the claim (the Amazon Cognito user ID).

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_iam-condition-keys.html#ck_sub

        Applies to actions:

        - .toAssumeRoleWithWebIdentity()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4680cd004bbd979042cb5b1a7873a0490fd808b2df4b4930a5cd1490de11d04f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Sts", jsii.invoke(self, "ifCognitoSub", [value, operator]))

    @jsii.member(jsii_name="ifExternalId")
    def if_external_id(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Sts":
        '''(experimental) Filters access by the unique identifier required when you assume a role in another account.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_iam-condition-keys.html#ck_externalid

        Applies to actions:

        - .toAssumeRole()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a6de4f465dcd0a738efddef4345c614a6649b56ff4008aa4765c9ebb252d1bcf)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Sts", jsii.invoke(self, "ifExternalId", [value, operator]))

    @jsii.member(jsii_name="ifFacebookAppId")
    def if_facebook_app_id(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Sts":
        '''(experimental) Filters access by the Facebook application ID.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_iam-condition-keys.html#ck_id

        Applies to actions:

        - .toAssumeRoleWithWebIdentity()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0e9fb7b7a13eb830676b0fa1b406edb452b1484483304760ac97cb7bcb4731af)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Sts", jsii.invoke(self, "ifFacebookAppId", [value, operator]))

    @jsii.member(jsii_name="ifFacebookId")
    def if_facebook_id(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Sts":
        '''(experimental) Filters access by the Facebook user ID.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_iam-condition-keys.html#ck_id

        Applies to actions:

        - .toAssumeRoleWithWebIdentity()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2adfb871892ec25568d5b621486e89858e6e62ce22496918bfd17c71cd83f675)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Sts", jsii.invoke(self, "ifFacebookId", [value, operator]))

    @jsii.member(jsii_name="ifGoogleAud")
    def if_google_aud(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Sts":
        '''(experimental) Filters access by the Google application ID.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_iam-condition-keys.html#ck_aud

        Applies to actions:

        - .toAssumeRoleWithWebIdentity()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__22a4bbff581ecbd94281f7b424c1126c5a25ad71b44a5e7b40bd17c55aacbc91)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Sts", jsii.invoke(self, "ifGoogleAud", [value, operator]))

    @jsii.member(jsii_name="ifGoogleOaud")
    def if_google_oaud(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Sts":
        '''(experimental) Filters access by the Google audience.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_iam-condition-keys.html#ck_oaud

        Applies to actions:

        - .toAssumeRoleWithWebIdentity()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__37f450a86b7620e753b650379122b9f79cdc27a5f98706e9044df75bf99a0ded)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Sts", jsii.invoke(self, "ifGoogleOaud", [value, operator]))

    @jsii.member(jsii_name="ifGoogleSub")
    def if_google_sub(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Sts":
        '''(experimental) Filters access by the subject of the claim (the Google user ID).

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_iam-condition-keys.html#ck_sub

        Applies to actions:

        - .toAssumeRoleWithWebIdentity()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__31619025761030601899ebf15e6a13ccb0e6dff972f7ad5830e43945651185c5)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Sts", jsii.invoke(self, "ifGoogleSub", [value, operator]))

    @jsii.member(jsii_name="ifIamResourceTag")
    def if_iam_resource_tag(
        self,
        tag_key: builtins.str,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Sts":
        '''(experimental) Filters access by the tags that are attached to the role that is being assumed.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_iam-condition-keys.html#ck_ResourceTag

        Applies to actions:

        - .toAssumeRole()

        :param tag_key: The tag key to check.
        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8e63fdd93df0f3041b3eb73b3fa8df52304766b7e66271235141c5364d31da18)
            check_type(argname="argument tag_key", value=tag_key, expected_type=type_hints["tag_key"])
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Sts", jsii.invoke(self, "ifIamResourceTag", [tag_key, value, operator]))

    @jsii.member(jsii_name="ifRoleSessionName")
    def if_role_session_name(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Sts":
        '''(experimental) Filters access by the role session name required when you assume a role.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_iam-condition-keys.html#ck_rolesessionname

        Applies to actions:

        - .toAssumeRole()
        - .toAssumeRoleWithSAML()
        - .toAssumeRoleWithWebIdentity()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__13ddd99b0b5fb19ad0cce179867ca83dfa14ef04cdb02ceb3bc45daa370e398e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Sts", jsii.invoke(self, "ifRoleSessionName", [value, operator]))

    @jsii.member(jsii_name="ifSamlAud")
    def if_saml_aud(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Sts":
        '''(experimental) Filters access by the endpoint URL to which SAML assertions are presented.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_iam-condition-keys.html#ck_aud

        Applies to actions:

        - .toAssumeRoleWithSAML()
        - .toTagSession()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1c22c1e619c27f5ca8a285af071766a4376fc7d6ed5765d3bb096afdb3249c1f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Sts", jsii.invoke(self, "ifSamlAud", [value, operator]))

    @jsii.member(jsii_name="ifSamlCn")
    def if_saml_cn(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Sts":
        '''(experimental) Filters access by the eduOrg attribute.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_iam-condition-keys.html#ck_cn

        Applies to actions:

        - .toAssumeRoleWithSAML()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__38ace441d93b8f9675cc5d145fd8f49953736c17356c7955e43a9777e7bbb499)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Sts", jsii.invoke(self, "ifSamlCn", [value, operator]))

    @jsii.member(jsii_name="ifSamlCommonName")
    def if_saml_common_name(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Sts":
        '''(experimental) Filters access by the commonName attribute.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_iam-condition-keys.html#ck_commonname

        Applies to actions:

        - .toAssumeRoleWithSAML()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f6d5f0eca6e2e795dd32d996ecf0f565a41da6eb4f54ebd59acd741ac0a22d37)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Sts", jsii.invoke(self, "ifSamlCommonName", [value, operator]))

    @jsii.member(jsii_name="ifSamlDoc")
    def if_saml_doc(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Sts":
        '''(experimental) Filters access by on the principal that was used to assume the role.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_iam-condition-keys.html#ck_doc

        Applies to actions:

        - .toAssumeRoleWithSAML()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b0bc5716e60092c110295a67ee61c6421c3bc47069be90eda527fab94f3419cd)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Sts", jsii.invoke(self, "ifSamlDoc", [value, operator]))

    @jsii.member(jsii_name="ifSamlEduorghomepageuri")
    def if_saml_eduorghomepageuri(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Sts":
        '''(experimental) Filters access by the eduOrg attribute.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_iam-condition-keys.html#ck_eduorghomepageuri

        Applies to actions:

        - .toAssumeRoleWithSAML()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8ab353333c06e64c212b62f95ab2479c5e7b411b8fe8e4484df68aec3cf35ee7)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Sts", jsii.invoke(self, "ifSamlEduorghomepageuri", [value, operator]))

    @jsii.member(jsii_name="ifSamlEduorgidentityauthnpolicyuri")
    def if_saml_eduorgidentityauthnpolicyuri(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Sts":
        '''(experimental) Filters access by the eduOrg attribute.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_iam-condition-keys.html#ck_aud

        Applies to actions:

        - .toAssumeRoleWithSAML()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__dbd69e3fe3bef0b207655dadc1800e9e1a81636f8f29df9babb8a72d2295fd07)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Sts", jsii.invoke(self, "ifSamlEduorgidentityauthnpolicyuri", [value, operator]))

    @jsii.member(jsii_name="ifSamlEduorglegalname")
    def if_saml_eduorglegalname(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Sts":
        '''(experimental) Filters access by the eduOrg attribute.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_iam-condition-keys.html#ck_eduorglegalname

        Applies to actions:

        - .toAssumeRoleWithSAML()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0cb95cea91f1d8e4323fd1f047bda86ac7aeaf3b991f69854d2833f8b2d4960f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Sts", jsii.invoke(self, "ifSamlEduorglegalname", [value, operator]))

    @jsii.member(jsii_name="ifSamlEduorgsuperioruri")
    def if_saml_eduorgsuperioruri(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Sts":
        '''(experimental) Filters access by the eduOrg attribute.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_iam-condition-keys.html#ck_eduorgsuperioruri

        Applies to actions:

        - .toAssumeRoleWithSAML()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4c9fa3c199fc49e13c7ad97d846a16862cfdd76f5e47f2d6a32a599313235ba8)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Sts", jsii.invoke(self, "ifSamlEduorgsuperioruri", [value, operator]))

    @jsii.member(jsii_name="ifSamlEduorgwhitepagesuri")
    def if_saml_eduorgwhitepagesuri(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Sts":
        '''(experimental) Filters access by the eduOrg attribute.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_iam-condition-keys.html#ck_eduorgwhitepagesuri

        Applies to actions:

        - .toAssumeRoleWithSAML()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e8c7d21cc9aadfd734a05b50430aa0ba7ea696e2332e28c98a735dfd8153c322)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Sts", jsii.invoke(self, "ifSamlEduorgwhitepagesuri", [value, operator]))

    @jsii.member(jsii_name="ifSamlEdupersonaffiliation")
    def if_saml_edupersonaffiliation(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Sts":
        '''(experimental) Filters access by the eduPerson attribute.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_iam-condition-keys.html#ck_edupersonaffiliation

        Applies to actions:

        - .toAssumeRoleWithSAML()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__28f5cb644596480ee0d1a7a132053e5c38b85335ac8eef0ca32b78b30b5206b5)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Sts", jsii.invoke(self, "ifSamlEdupersonaffiliation", [value, operator]))

    @jsii.member(jsii_name="ifSamlEdupersonassurance")
    def if_saml_edupersonassurance(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Sts":
        '''(experimental) Filters access by the eduPerson attribute.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_iam-condition-keys.html#ck_edupersonassurance

        Applies to actions:

        - .toAssumeRoleWithSAML()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c1ec37f70d5a2f89ff45e6a41d7a41450bd399913dd713705437feb621920846)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Sts", jsii.invoke(self, "ifSamlEdupersonassurance", [value, operator]))

    @jsii.member(jsii_name="ifSamlEdupersonentitlement")
    def if_saml_edupersonentitlement(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Sts":
        '''(experimental) Filters access by the eduPerson attribute.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_iam-condition-keys.html#ck_edupersonentitlement

        Applies to actions:

        - .toAssumeRoleWithSAML()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ca0b120523c02c29f32bfaf5b0efc41c3b5a78f28efb6255e97669c58f3e0f1f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Sts", jsii.invoke(self, "ifSamlEdupersonentitlement", [value, operator]))

    @jsii.member(jsii_name="ifSamlEdupersonnickname")
    def if_saml_edupersonnickname(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Sts":
        '''(experimental) Filters access by the eduPerson attribute.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_iam-condition-keys.html#ck_edupersonnickname

        Applies to actions:

        - .toAssumeRoleWithSAML()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9fac7695ab648f98d096b20905a91ff604219d1d216fc0832c664939d14a2dc4)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Sts", jsii.invoke(self, "ifSamlEdupersonnickname", [value, operator]))

    @jsii.member(jsii_name="ifSamlEdupersonorgdn")
    def if_saml_edupersonorgdn(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Sts":
        '''(experimental) Filters access by the eduPerson attribute.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_iam-condition-keys.html#ck_edupersonorgdn

        Applies to actions:

        - .toAssumeRoleWithSAML()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bff1f2ab4c405d8b56e32aa50e2a7a36bc591aee6ec013e0d6926b36d55c1010)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Sts", jsii.invoke(self, "ifSamlEdupersonorgdn", [value, operator]))

    @jsii.member(jsii_name="ifSamlEdupersonorgunitdn")
    def if_saml_edupersonorgunitdn(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Sts":
        '''(experimental) Filters access by the eduPerson attribute.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_iam-condition-keys.html#ck_edupersonorgunitdn

        Applies to actions:

        - .toAssumeRoleWithSAML()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1eb2fa344123238c8d768035f77a5509bfebea97901df258b6427a77604ae767)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Sts", jsii.invoke(self, "ifSamlEdupersonorgunitdn", [value, operator]))

    @jsii.member(jsii_name="ifSamlEdupersonprimaryaffiliation")
    def if_saml_edupersonprimaryaffiliation(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Sts":
        '''(experimental) Filters access by the eduPerson attribute.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_iam-condition-keys.html#ck_edupersonprimaryaffiliation

        Applies to actions:

        - .toAssumeRoleWithSAML()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__31ab88dc3f3558239214e9f09f7a1ea9846cfcb8eef36df9e63e239013d4bb80)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Sts", jsii.invoke(self, "ifSamlEdupersonprimaryaffiliation", [value, operator]))

    @jsii.member(jsii_name="ifSamlEdupersonprimaryorgunitdn")
    def if_saml_edupersonprimaryorgunitdn(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Sts":
        '''(experimental) Filters access by the eduPerson attribute.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_iam-condition-keys.html#ck_edupersonprimaryorgunitdn

        Applies to actions:

        - .toAssumeRoleWithSAML()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0582edd00d3146615474a71987788e6108be2724a658cd232435502aa491bfdc)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Sts", jsii.invoke(self, "ifSamlEdupersonprimaryorgunitdn", [value, operator]))

    @jsii.member(jsii_name="ifSamlEdupersonprincipalname")
    def if_saml_edupersonprincipalname(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Sts":
        '''(experimental) Filters access by the eduPerson attribute.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_iam-condition-keys.html#ck_edupersonprincipalname

        Applies to actions:

        - .toAssumeRoleWithSAML()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__980458e9cc0c922a14ca3acd39a5576a2b38aa066358ea5e88b8255085ff4773)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Sts", jsii.invoke(self, "ifSamlEdupersonprincipalname", [value, operator]))

    @jsii.member(jsii_name="ifSamlEdupersonscopedaffiliation")
    def if_saml_edupersonscopedaffiliation(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Sts":
        '''(experimental) Filters access by the eduPerson attribute.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_iam-condition-keys.html#ck_edupersonscopedaffiliation

        Applies to actions:

        - .toAssumeRoleWithSAML()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0d66e72a60981a320f631af33471bd7bc660203ae27f62b9bff8d2465056cbb8)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Sts", jsii.invoke(self, "ifSamlEdupersonscopedaffiliation", [value, operator]))

    @jsii.member(jsii_name="ifSamlEdupersontargetedid")
    def if_saml_edupersontargetedid(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Sts":
        '''(experimental) Filters access by the eduPerson attribute.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_iam-condition-keys.html#ck_edupersontargetedid

        Applies to actions:

        - .toAssumeRoleWithSAML()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a6b2ddd7c77cf94437187b3c51aac6a406834e15163d08920e3b8e8947d8319a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Sts", jsii.invoke(self, "ifSamlEdupersontargetedid", [value, operator]))

    @jsii.member(jsii_name="ifSamlGivenName")
    def if_saml_given_name(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Sts":
        '''(experimental) Filters access by the givenName attribute.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_iam-condition-keys.html#ck_givenname

        Applies to actions:

        - .toAssumeRoleWithSAML()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1ac44d3a357285e61cb7134822787cfeb8c227aa7a0aef525ecefb3c92259e74)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Sts", jsii.invoke(self, "ifSamlGivenName", [value, operator]))

    @jsii.member(jsii_name="ifSamlIss")
    def if_saml_iss(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Sts":
        '''(experimental) Filters access by on the issuer, which is represented by a URN.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_iam-condition-keys.html#ck_iss

        Applies to actions:

        - .toAssumeRoleWithSAML()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9ea542fd9dba04c3af6c2a0fb22faa22ec72c4ca712ccecf17ab5a1af13760b9)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Sts", jsii.invoke(self, "ifSamlIss", [value, operator]))

    @jsii.member(jsii_name="ifSamlMail")
    def if_saml_mail(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Sts":
        '''(experimental) Filters access by the mail attribute.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_iam-condition-keys.html#ck_mail

        Applies to actions:

        - .toAssumeRoleWithSAML()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__349ed7060f7c2a2adf5ff1780c88fd8304013f13ec8333ed86d5a1c3964a4ad9)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Sts", jsii.invoke(self, "ifSamlMail", [value, operator]))

    @jsii.member(jsii_name="ifSamlName")
    def if_saml_name(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Sts":
        '''(experimental) Filters access by the name attribute.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_iam-condition-keys.html#ck_name

        Applies to actions:

        - .toAssumeRoleWithSAML()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4c92a122166c8bfd0c3b5436860fde46f6c97cc5775e60de8b9e89e2d2129a40)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Sts", jsii.invoke(self, "ifSamlName", [value, operator]))

    @jsii.member(jsii_name="ifSamlNamequalifier")
    def if_saml_namequalifier(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Sts":
        '''(experimental) Filters access by the hash value of the issuer, account ID, and friendly name.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_iam-condition-keys.html#ck_namequalifier

        Applies to actions:

        - .toAssumeRoleWithSAML()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__23cabc67567b28be9a78e0e4a97c110f03acb4fd482ee4ab2d7eef94c5e26e34)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Sts", jsii.invoke(self, "ifSamlNamequalifier", [value, operator]))

    @jsii.member(jsii_name="ifSamlOrganizationStatus")
    def if_saml_organization_status(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Sts":
        '''(experimental) Filters access by the organizationStatus attribute.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_iam-condition-keys.html#ck_organizationstatus

        Applies to actions:

        - .toAssumeRoleWithSAML()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d1963e4b6c07c81c8d7430592ce068fc9aa292a4dbb15b4ed0bdabdf64ad911f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Sts", jsii.invoke(self, "ifSamlOrganizationStatus", [value, operator]))

    @jsii.member(jsii_name="ifSamlPrimaryGroupSID")
    def if_saml_primary_group_sid(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Sts":
        '''(experimental) Filters access by the primaryGroupSID attribute.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_iam-condition-keys.html#ck_primarygroupsid

        Applies to actions:

        - .toAssumeRoleWithSAML()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3ebbeed7d33f67ea228122d7e1e1404ae1d70275acf5d49c25583d7dc7cc262b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Sts", jsii.invoke(self, "ifSamlPrimaryGroupSID", [value, operator]))

    @jsii.member(jsii_name="ifSamlSub")
    def if_saml_sub(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Sts":
        '''(experimental) Filters access by the subject of the claim (the SAML user ID).

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_iam-condition-keys.html#ck_sub

        Applies to actions:

        - .toAssumeRoleWithSAML()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bcc34ee9092bbc3bbf003bfa5c9714221cafdd9f1e360f8da353a165fecc6ea3)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Sts", jsii.invoke(self, "ifSamlSub", [value, operator]))

    @jsii.member(jsii_name="ifSamlSubType")
    def if_saml_sub_type(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Sts":
        '''(experimental) Filters access by the value persistent, transient, or the full Format URI.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_iam-condition-keys.html#ck_subtype

        Applies to actions:

        - .toAssumeRoleWithSAML()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ebc82d1f1d091f6d14b50f4e447c1f1b8be7220f25920abf894577e54d9e392b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Sts", jsii.invoke(self, "ifSamlSubType", [value, operator]))

    @jsii.member(jsii_name="ifSamlSurname")
    def if_saml_surname(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Sts":
        '''(experimental) Filters access by the surname attribute.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_iam-condition-keys.html#ck_surname

        Applies to actions:

        - .toAssumeRoleWithSAML()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c4b5c80181d99df02d745cc02250e5bbcbffbb47a4fae221566371e09c894535)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Sts", jsii.invoke(self, "ifSamlSurname", [value, operator]))

    @jsii.member(jsii_name="ifSamlUid")
    def if_saml_uid(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Sts":
        '''(experimental) Filters access by the uid attribute.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_iam-condition-keys.html#ck_uid

        Applies to actions:

        - .toAssumeRoleWithSAML()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d95fe063b18cd7832e24c3572cf4c55a0dc574112a62e96dcc2bafcccac6897c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Sts", jsii.invoke(self, "ifSamlUid", [value, operator]))

    @jsii.member(jsii_name="ifSamlX500UniqueIdentifier")
    def if_saml_x500_unique_identifier(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Sts":
        '''(experimental) Filters access by the uid attribute.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_iam-condition-keys.html#ck_x500uniqueidentifier

        Applies to actions:

        - .toAssumeRoleWithSAML()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c842a861611e7cb50c42c24a59ac8d51c767b2fb754b09be15fb8268e6c7cf2f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Sts", jsii.invoke(self, "ifSamlX500UniqueIdentifier", [value, operator]))

    @jsii.member(jsii_name="ifSourceIdentity")
    def if_source_identity(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Sts":
        '''(experimental) Filters access by the source identity that is passed in the request.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_iam-condition-keys.html#ck_sourceidentity

        Applies to actions:

        - .toAssumeRole()
        - .toAssumeRoleWithSAML()
        - .toAssumeRoleWithWebIdentity()
        - .toSetSourceIdentity()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f8ad5b561e7121f6125c2ad3c6ac38c7397fa0a1f53cd89838fc4cb087274285)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Sts", jsii.invoke(self, "ifSourceIdentity", [value, operator]))

    @jsii.member(jsii_name="ifTransitiveTagKeys")
    def if_transitive_tag_keys(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Sts":
        '''(experimental) Filters access by the transitive tag keys that are passed in the request.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_iam-condition-keys.html#ck_TransitiveTagKeys

        Applies to actions:

        - .toAssumeRole()
        - .toAssumeRoleWithSAML()
        - .toAssumeRoleWithWebIdentity()
        - .toTagSession()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e2b9a791c100a13f4c152bf25037aca8ed60327a16a918fe83e417ff161ded30)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Sts", jsii.invoke(self, "ifTransitiveTagKeys", [value, operator]))

    @jsii.member(jsii_name="onRole")
    def on_role(
        self,
        role_name_with_path: builtins.str,
        account: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Sts":
        '''(experimental) Adds a resource of type role to the statement.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/id_roles.html

        :param role_name_with_path: - Identifier for the roleNameWithPath.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__255588f314993aa0395ed9cc4dff555c9bb105c2c7609fb9bbda37b3ad9de942)
            check_type(argname="argument role_name_with_path", value=role_name_with_path, expected_type=type_hints["role_name_with_path"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Sts", jsii.invoke(self, "onRole", [role_name_with_path, account, partition]))

    @jsii.member(jsii_name="onUser")
    def on_user(
        self,
        user_name_with_path: builtins.str,
        account: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Sts":
        '''(experimental) Adds a resource of type user to the statement.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/id_users.html

        :param user_name_with_path: - Identifier for the userNameWithPath.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__87e8a81a902fa204ac69e7302cad47a6591b537684963fa42682125dccca7418)
            check_type(argname="argument user_name_with_path", value=user_name_with_path, expected_type=type_hints["user_name_with_path"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Sts", jsii.invoke(self, "onUser", [user_name_with_path, account, partition]))

    @jsii.member(jsii_name="toAssumeRole")
    def to_assume_role(self) -> "Sts":
        '''(experimental) Grants permission to obtain a set of temporary security credentials that you can use to access AWS resources that you might not normally have access to.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()
        - .ifTransitiveTagKeys()
        - .ifExternalId()
        - .ifRoleSessionName()
        - .ifIamResourceTag()
        - .ifSourceIdentity()

        https://docs.aws.amazon.com/STS/latest/APIReference/API_AssumeRole.html

        :stability: experimental
        '''
        return typing.cast("Sts", jsii.invoke(self, "toAssumeRole", []))

    @jsii.member(jsii_name="toAssumeRoleWithSAML")
    def to_assume_role_with_saml(self) -> "Sts":
        '''(experimental) Grants permission to obtain a set of temporary security credentials for users who have been authenticated via a SAML authentication response.

        Access Level: Write

        Possible conditions:

        - .ifSamlNamequalifier()
        - .ifSamlSub()
        - .ifSamlSubType()
        - .ifSamlAud()
        - .ifSamlIss()
        - .ifSamlDoc()
        - .ifSamlCn()
        - .ifSamlCommonName()
        - .ifSamlEduorghomepageuri()
        - .ifSamlEduorgidentityauthnpolicyuri()
        - .ifSamlEduorglegalname()
        - .ifSamlEduorgsuperioruri()
        - .ifSamlEduorgwhitepagesuri()
        - .ifSamlEdupersonaffiliation()
        - .ifSamlEdupersonassurance()
        - .ifSamlEdupersonentitlement()
        - .ifSamlEdupersonnickname()
        - .ifSamlEdupersonorgdn()
        - .ifSamlEdupersonorgunitdn()
        - .ifSamlEdupersonprimaryaffiliation()
        - .ifSamlEdupersonprimaryorgunitdn()
        - .ifSamlEdupersonprincipalname()
        - .ifSamlEdupersonscopedaffiliation()
        - .ifSamlEdupersontargetedid()
        - .ifSamlGivenName()
        - .ifSamlMail()
        - .ifSamlName()
        - .ifSamlOrganizationStatus()
        - .ifSamlPrimaryGroupSID()
        - .ifSamlSurname()
        - .ifSamlUid()
        - .ifSamlX500UniqueIdentifier()
        - .ifAwsTagKeys()
        - .ifAwsRequestTag()
        - .ifTransitiveTagKeys()
        - .ifSourceIdentity()
        - .ifRoleSessionName()

        https://docs.aws.amazon.com/STS/latest/APIReference/API_AssumeRoleWithSAML.html

        :stability: experimental
        '''
        return typing.cast("Sts", jsii.invoke(self, "toAssumeRoleWithSAML", []))

    @jsii.member(jsii_name="toAssumeRoleWithWebIdentity")
    def to_assume_role_with_web_identity(self) -> "Sts":
        '''(experimental) Grants permission to obtain a set of temporary security credentials for users who have been authenticated in a mobile or web application with a web identity provider.

        Access Level: Write

        Possible conditions:

        - .ifCognitoAmr()
        - .ifCognitoAud()
        - .ifCognitoSub()
        - .ifAmazonAppId()
        - .ifAmazonUserId()
        - .ifFacebookAppId()
        - .ifFacebookId()
        - .ifGoogleAud()
        - .ifGoogleOaud()
        - .ifGoogleSub()
        - .ifAwsTagKeys()
        - .ifAwsRequestTag()
        - .ifTransitiveTagKeys()
        - .ifSourceIdentity()
        - .ifRoleSessionName()

        https://docs.aws.amazon.com/STS/latest/APIReference/API_AssumeRoleWithWebIdentity.html

        :stability: experimental
        '''
        return typing.cast("Sts", jsii.invoke(self, "toAssumeRoleWithWebIdentity", []))

    @jsii.member(jsii_name="toDecodeAuthorizationMessage")
    def to_decode_authorization_message(self) -> "Sts":
        '''(experimental) Grants permission to decode additional information about the authorization status of a request from an encoded message returned in response to an AWS request.

        Access Level: Write

        https://docs.aws.amazon.com/STS/latest/APIReference/API_DecodeAuthorizationMessage.html

        :stability: experimental
        '''
        return typing.cast("Sts", jsii.invoke(self, "toDecodeAuthorizationMessage", []))

    @jsii.member(jsii_name="toGetAccessKeyInfo")
    def to_get_access_key_info(self) -> "Sts":
        '''(experimental) Grants permission to obtain details about the access key id passed as a parameter to the request.

        Access Level: Read

        https://docs.aws.amazon.com/STS/latest/APIReference/API_GetAccessKeyInfo.html

        :stability: experimental
        '''
        return typing.cast("Sts", jsii.invoke(self, "toGetAccessKeyInfo", []))

    @jsii.member(jsii_name="toGetCallerIdentity")
    def to_get_caller_identity(self) -> "Sts":
        '''(experimental) Grants permission to obtain details about the IAM identity whose credentials are used to call the API.

        Access Level: Read

        https://docs.aws.amazon.com/STS/latest/APIReference/API_GetCallerIdentity.html

        :stability: experimental
        '''
        return typing.cast("Sts", jsii.invoke(self, "toGetCallerIdentity", []))

    @jsii.member(jsii_name="toGetFederationToken")
    def to_get_federation_token(self) -> "Sts":
        '''(experimental) Grants permission to obtain a set of temporary security credentials (consisting of an access key ID, a secret access key, and a security token) for a federated user.

        Access Level: Read

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/STS/latest/APIReference/API_GetFederationToken.html

        :stability: experimental
        '''
        return typing.cast("Sts", jsii.invoke(self, "toGetFederationToken", []))

    @jsii.member(jsii_name="toGetServiceBearerToken")
    def to_get_service_bearer_token(self) -> "Sts":
        '''(experimental) Grants permission to obtain a STS bearer token for an AWS root user, IAM role, or an IAM user.

        Access Level: Read

        Possible conditions:

        - .ifAWSServiceName()

        https://docs.aws.amazon.com/IAM/latest/UserGuide/id_credentials_bearer.html

        :stability: experimental
        '''
        return typing.cast("Sts", jsii.invoke(self, "toGetServiceBearerToken", []))

    @jsii.member(jsii_name="toGetSessionToken")
    def to_get_session_token(self) -> "Sts":
        '''(experimental) Grants permission to obtain a set of temporary security credentials (consisting of an access key ID, a secret access key, and a security token) for an AWS account or IAM user.

        Access Level: Read

        https://docs.aws.amazon.com/STS/latest/APIReference/API_GetSessionToken.html

        :stability: experimental
        '''
        return typing.cast("Sts", jsii.invoke(self, "toGetSessionToken", []))

    @jsii.member(jsii_name="toSetSourceIdentity")
    def to_set_source_identity(self) -> "Sts":
        '''(experimental) Grants permission to set a source identity on a STS session.

        Access Level: Write

        Possible conditions:

        - .ifSourceIdentity()

        https://docs.aws.amazon.com/IAM/latest/UserGuide/id_credentials_temp_control-access_monitor.html#id_credentials_temp_control-access_monitor-perms

        :stability: experimental
        '''
        return typing.cast("Sts", jsii.invoke(self, "toSetSourceIdentity", []))

    @jsii.member(jsii_name="toTagSession")
    def to_tag_session(self) -> "Sts":
        '''(experimental) Grants permission to add tags to a STS session.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()
        - .ifTransitiveTagKeys()
        - .ifSamlAud()

        https://docs.aws.amazon.com/IAM/latest/UserGuide/id_session-tags.html

        :stability: experimental
        '''
        return typing.cast("Sts", jsii.invoke(self, "toTagSession", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4b6c6eec28c374d8e0b586dd75317d97345bd1bf6c4843cb305cd8534cecb9f4)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__76089d1a7ba35752ae871b0ddc92f97a675b232e62c38e94c24ccf410b5e021f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Sumerian(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Sumerian",
):
    '''(experimental) Statement provider for service `sumerian <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonsumerian.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `sumerian <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonsumerian.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onProject")
    def on_project(
        self,
        project_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Sumerian":
        '''(experimental) Adds a resource of type project to the statement.

        https://docs.aws.amazon.com/sumerian/latest/userguide/sumerian-concepts.html

        :param project_name: - Identifier for the projectName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b48f8362b3fdfc10981b0d9353fd4d7d8813b1be32444b04010cb73be0579fb1)
            check_type(argname="argument project_name", value=project_name, expected_type=type_hints["project_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Sumerian", jsii.invoke(self, "onProject", [project_name, account, region, partition]))

    @jsii.member(jsii_name="toLogin")
    def to_login(self) -> "Sumerian":
        '''(experimental) Grants permission to log into the Sumerian console.

        Access Level: Write

        https://docs.aws.amazon.com/sumerian/latest/userguide/sumerian-permissions.html

        :stability: experimental
        '''
        return typing.cast("Sumerian", jsii.invoke(self, "toLogin", []))

    @jsii.member(jsii_name="toViewRelease")
    def to_view_release(self) -> "Sumerian":
        '''(experimental) Grants permission to view a project release.

        Access Level: Read

        https://docs.aws.amazon.com/sumerian/latest/userguide/sumerian-permissions.html

        :stability: experimental
        '''
        return typing.cast("Sumerian", jsii.invoke(self, "toViewRelease", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5d87dd2d37b900f7e37c6168d484d40acaa3d87cdb1cfd0a2259479e40a3ed17)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9ac7636a6ba72a4c6be1a0e49735c522fec46f34921a32fc445110314eeb33a1)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Support(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Support",
):
    '''(experimental) Statement provider for service `support <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awssupport.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `support <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awssupport.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="toAddAttachmentsToSet")
    def to_add_attachments_to_set(self) -> "Support":
        '''(experimental) Adds one or more attachments to an AWS Support case.

        Access Level: Write

        https://docs.aws.amazon.com/awssupport/latest/APIReference/API_AddAttachmentsToSet.html

        :stability: experimental
        '''
        return typing.cast("Support", jsii.invoke(self, "toAddAttachmentsToSet", []))

    @jsii.member(jsii_name="toAddCommunicationToCase")
    def to_add_communication_to_case(self) -> "Support":
        '''(experimental) Adds a customer communication to an AWS Support case.

        Access Level: Write

        https://docs.aws.amazon.com/awssupport/latest/APIReference/API_AddCommunicationToCase.html

        :stability: experimental
        '''
        return typing.cast("Support", jsii.invoke(self, "toAddCommunicationToCase", []))

    @jsii.member(jsii_name="toCreateCase")
    def to_create_case(self) -> "Support":
        '''(experimental) Creates a new AWS Support case.

        Access Level: Write

        https://docs.aws.amazon.com/awssupport/latest/APIReference/API_CreateCase.html

        :stability: experimental
        '''
        return typing.cast("Support", jsii.invoke(self, "toCreateCase", []))

    @jsii.member(jsii_name="toDescribeAttachment")
    def to_describe_attachment(self) -> "Support":
        '''(experimental) Returns the description for an attachment.

        Access Level: Read

        https://docs.aws.amazon.com/awssupport/latest/APIReference/API_DescribeAttachment.html

        :stability: experimental
        '''
        return typing.cast("Support", jsii.invoke(self, "toDescribeAttachment", []))

    @jsii.member(jsii_name="toDescribeCaseAttributes")
    def to_describe_case_attributes(self) -> "Support":
        '''(experimental) This is an internally managed function which allows secondary services to read AWS Support case attributes.

        Access Level: Read

        :stability: experimental
        '''
        return typing.cast("Support", jsii.invoke(self, "toDescribeCaseAttributes", []))

    @jsii.member(jsii_name="toDescribeCases")
    def to_describe_cases(self) -> "Support":
        '''(experimental) Returns a list of AWS Support cases that matches the given inputs.

        Access Level: Read

        https://docs.aws.amazon.com/awssupport/latest/APIReference/API_DescribeCases.html

        :stability: experimental
        '''
        return typing.cast("Support", jsii.invoke(self, "toDescribeCases", []))

    @jsii.member(jsii_name="toDescribeCommunications")
    def to_describe_communications(self) -> "Support":
        '''(experimental) Returns the communications and attachments for one or more AWS Support cases.

        Access Level: Read

        https://docs.aws.amazon.com/awssupport/latest/APIReference/API_DescribeCommunications.html

        :stability: experimental
        '''
        return typing.cast("Support", jsii.invoke(self, "toDescribeCommunications", []))

    @jsii.member(jsii_name="toDescribeIssueTypes")
    def to_describe_issue_types(self) -> "Support":
        '''(experimental) Returns issue types for AWS Support cases.

        Access Level: Read

        :stability: experimental
        '''
        return typing.cast("Support", jsii.invoke(self, "toDescribeIssueTypes", []))

    @jsii.member(jsii_name="toDescribeServices")
    def to_describe_services(self) -> "Support":
        '''(experimental) Returns the current list of AWS services and categories that applies to each service.

        Access Level: Read

        https://docs.aws.amazon.com/awssupport/latest/APIReference/API_DescribeServices.html

        :stability: experimental
        '''
        return typing.cast("Support", jsii.invoke(self, "toDescribeServices", []))

    @jsii.member(jsii_name="toDescribeSeverityLevels")
    def to_describe_severity_levels(self) -> "Support":
        '''(experimental) Returns the list of severity levels that can be assigned to an AWS Support case.

        Access Level: Read

        https://docs.aws.amazon.com/awssupport/latest/APIReference/API_DescribeSeverityLevels.html

        :stability: experimental
        '''
        return typing.cast("Support", jsii.invoke(self, "toDescribeSeverityLevels", []))

    @jsii.member(jsii_name="toDescribeSupportLevel")
    def to_describe_support_level(self) -> "Support":
        '''(experimental) Returns the support level for an AWS Account identifier.

        Access Level: Read

        :stability: experimental
        '''
        return typing.cast("Support", jsii.invoke(self, "toDescribeSupportLevel", []))

    @jsii.member(jsii_name="toDescribeTrustedAdvisorCheckRefreshStatuses")
    def to_describe_trusted_advisor_check_refresh_statuses(self) -> "Support":
        '''(experimental) Returns the status of a Trusted Advisor refresh check based on a list of check identifiers.

        Access Level: Read

        https://docs.aws.amazon.com/awssupport/latest/APIReference/API_DescribeTrustedAdvisorCheckRefreshStatuses.html

        :stability: experimental
        '''
        return typing.cast("Support", jsii.invoke(self, "toDescribeTrustedAdvisorCheckRefreshStatuses", []))

    @jsii.member(jsii_name="toDescribeTrustedAdvisorCheckResult")
    def to_describe_trusted_advisor_check_result(self) -> "Support":
        '''(experimental) Returns the results of the Trusted Advisor check that has the specified check identifier.

        Access Level: Read

        https://docs.aws.amazon.com/awssupport/latest/APIReference/API_DescribeTrustedAdvisorCheckResult.html

        :stability: experimental
        '''
        return typing.cast("Support", jsii.invoke(self, "toDescribeTrustedAdvisorCheckResult", []))

    @jsii.member(jsii_name="toDescribeTrustedAdvisorChecks")
    def to_describe_trusted_advisor_checks(self) -> "Support":
        '''(experimental) Returns a list of all available Trusted Advisor checks, including name, identifier, category and description.

        Access Level: Read

        https://docs.aws.amazon.com/awssupport/latest/APIReference/API_DescribeTrustedAdvisorChecks.html

        :stability: experimental
        '''
        return typing.cast("Support", jsii.invoke(self, "toDescribeTrustedAdvisorChecks", []))

    @jsii.member(jsii_name="toDescribeTrustedAdvisorCheckSummaries")
    def to_describe_trusted_advisor_check_summaries(self) -> "Support":
        '''(experimental) Returns the summaries of the results of the Trusted Advisor checks that have the specified check identifiers.

        Access Level: Read

        https://docs.aws.amazon.com/awssupport/latest/APIReference/API_DescribeTrustedAdvisorCheckSummaries.html

        :stability: experimental
        '''
        return typing.cast("Support", jsii.invoke(self, "toDescribeTrustedAdvisorCheckSummaries", []))

    @jsii.member(jsii_name="toInitiateCallForCase")
    def to_initiate_call_for_case(self) -> "Support":
        '''(experimental) This is an internally managed function to initiate a call on AWS Support Center.

        Access Level: Write

        :stability: experimental
        '''
        return typing.cast("Support", jsii.invoke(self, "toInitiateCallForCase", []))

    @jsii.member(jsii_name="toInitiateChatForCase")
    def to_initiate_chat_for_case(self) -> "Support":
        '''(experimental) This is an internally managed function to initiate a chat on AWS Support Center.

        Access Level: Write

        :stability: experimental
        '''
        return typing.cast("Support", jsii.invoke(self, "toInitiateChatForCase", []))

    @jsii.member(jsii_name="toPutCaseAttributes")
    def to_put_case_attributes(self) -> "Support":
        '''(experimental) This is an internally managed function which allows secondary services to attach attributes to AWS Support cases.

        Access Level: Write

        :stability: experimental
        '''
        return typing.cast("Support", jsii.invoke(self, "toPutCaseAttributes", []))

    @jsii.member(jsii_name="toRateCaseCommunication")
    def to_rate_case_communication(self) -> "Support":
        '''(experimental) Rate an AWS Support case communication.

        Access Level: Write

        :stability: experimental
        '''
        return typing.cast("Support", jsii.invoke(self, "toRateCaseCommunication", []))

    @jsii.member(jsii_name="toRefreshTrustedAdvisorCheck")
    def to_refresh_trusted_advisor_check(self) -> "Support":
        '''(experimental) Requests a refresh of the Trusted Advisor check that has the specified check identifier.

        Access Level: Write

        https://docs.aws.amazon.com/awssupport/latest/APIReference/API_RefreshTrustedAdvisorCheck.html

        :stability: experimental
        '''
        return typing.cast("Support", jsii.invoke(self, "toRefreshTrustedAdvisorCheck", []))

    @jsii.member(jsii_name="toResolveCase")
    def to_resolve_case(self) -> "Support":
        '''(experimental) Resolves an AWS Support case.

        Access Level: Write

        https://docs.aws.amazon.com/awssupport/latest/APIReference/API_ResolveCase.html

        :stability: experimental
        '''
        return typing.cast("Support", jsii.invoke(self, "toResolveCase", []))

    @jsii.member(jsii_name="toSearchForCases")
    def to_search_for_cases(self) -> "Support":
        '''(experimental) Returns a list of AWS Support cases that matches the given inputs.

        Access Level: Read

        :stability: experimental
        '''
        return typing.cast("Support", jsii.invoke(self, "toSearchForCases", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a8b7b0facb832175244fdf7f51b86efd18b15d27ca3a4df3cfe2f519821fe5ed)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e316dd5144c78a5ab4f8c8765c8f0964d7be1e4596d1e76b0a11ffb6766f3152)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Supportapp(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Supportapp",
):
    '''(experimental) Statement provider for service `supportapp <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awssupportappinslack.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `supportapp <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awssupportappinslack.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="toCreateSlackChannelConfiguration")
    def to_create_slack_channel_configuration(self) -> "Supportapp":
        '''(experimental) Grants permission to create a Slack channel configuration for your account.

        Access Level: Write

        https://docs.aws.amazon.com/supportapp/latest/APIReference/API_CreateSlackChannelConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Supportapp", jsii.invoke(self, "toCreateSlackChannelConfiguration", []))

    @jsii.member(jsii_name="toDeleteAccountAlias")
    def to_delete_account_alias(self) -> "Supportapp":
        '''(experimental) Grants permission to delete an alias from your account.

        Access Level: Write

        https://docs.aws.amazon.com/supportapp/latest/APIReference/API_DeleteAccountAlias.html

        :stability: experimental
        '''
        return typing.cast("Supportapp", jsii.invoke(self, "toDeleteAccountAlias", []))

    @jsii.member(jsii_name="toDeleteSlackChannelConfiguration")
    def to_delete_slack_channel_configuration(self) -> "Supportapp":
        '''(experimental) Grants permission to delete a Slack channel configuration from your account.

        Access Level: Write

        https://docs.aws.amazon.com/supportapp/latest/APIReference/API_DeleteSlackChannelConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Supportapp", jsii.invoke(self, "toDeleteSlackChannelConfiguration", []))

    @jsii.member(jsii_name="toDeleteSlackWorkspaceConfiguration")
    def to_delete_slack_workspace_configuration(self) -> "Supportapp":
        '''(experimental) Grants permission to delete a Slack workspace configuration from your account.

        Access Level: Write

        https://docs.aws.amazon.com/supportapp/latest/APIReference/API_DeleteSlackWorkspaceConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Supportapp", jsii.invoke(self, "toDeleteSlackWorkspaceConfiguration", []))

    @jsii.member(jsii_name="toDescribeSlackChannels")
    def to_describe_slack_channels(self) -> "Supportapp":
        '''(experimental) Grants permission to list all public Slack channels in a workspace that have invited the AWS Support App.

        Access Level: Read

        https://docs.aws.amazon.com/awssupport/latest/user/slack-authorization-permissions.html

        :stability: experimental
        '''
        return typing.cast("Supportapp", jsii.invoke(self, "toDescribeSlackChannels", []))

    @jsii.member(jsii_name="toGetAccountAlias")
    def to_get_account_alias(self) -> "Supportapp":
        '''(experimental) Grants permission to get the alias for your account.

        Access Level: Read

        https://docs.aws.amazon.com/supportapp/latest/APIReference/API_GetAccountAlias.html

        :stability: experimental
        '''
        return typing.cast("Supportapp", jsii.invoke(self, "toGetAccountAlias", []))

    @jsii.member(jsii_name="toGetSlackOauthParameters")
    def to_get_slack_oauth_parameters(self) -> "Supportapp":
        '''(experimental) Grants permission to get parameters for the Slack OAuth code, which the AWS Support App uses to authorize the workspace.

        Access Level: Read

        https://docs.aws.amazon.com/awssupport/latest/user/slack-authorization-permissions.html

        :stability: experimental
        '''
        return typing.cast("Supportapp", jsii.invoke(self, "toGetSlackOauthParameters", []))

    @jsii.member(jsii_name="toListSlackChannelConfigurations")
    def to_list_slack_channel_configurations(self) -> "Supportapp":
        '''(experimental) Grants permission to list all Slack channel configurations for your account.

        Access Level: Read

        https://docs.aws.amazon.com/supportapp/latest/APIReference/API_ListSlackChannelConfigurations.html

        :stability: experimental
        '''
        return typing.cast("Supportapp", jsii.invoke(self, "toListSlackChannelConfigurations", []))

    @jsii.member(jsii_name="toListSlackWorkspaceConfigurations")
    def to_list_slack_workspace_configurations(self) -> "Supportapp":
        '''(experimental) Grants permission to list all Slack workspace configurations for your account.

        Access Level: Read

        https://docs.aws.amazon.com/supportapp/latest/APIReference/API_ListSlackWorkspaceConfigurations.html

        :stability: experimental
        '''
        return typing.cast("Supportapp", jsii.invoke(self, "toListSlackWorkspaceConfigurations", []))

    @jsii.member(jsii_name="toPutAccountAlias")
    def to_put_account_alias(self) -> "Supportapp":
        '''(experimental) Grants permission to create or update an alias for your account.

        Access Level: Write

        https://docs.aws.amazon.com/supportapp/latest/APIReference/API_PutAccountAlias.html

        :stability: experimental
        '''
        return typing.cast("Supportapp", jsii.invoke(self, "toPutAccountAlias", []))

    @jsii.member(jsii_name="toRedeemSlackOauthCode")
    def to_redeem_slack_oauth_code(self) -> "Supportapp":
        '''(experimental) Grants permission to redeem the Slack OAuth code, which the AWS Support App uses to authorize the workspace.

        Access Level: Write

        https://docs.aws.amazon.com/awssupport/latest/user/slack-authorization-permissions.html

        :stability: experimental
        '''
        return typing.cast("Supportapp", jsii.invoke(self, "toRedeemSlackOauthCode", []))

    @jsii.member(jsii_name="toRegisterSlackWorkspaceForOrganization")
    def to_register_slack_workspace_for_organization(self) -> "Supportapp":
        '''(experimental) Grants permission to register a Slack workspace for an AWS account that is part of an organization.

        Access Level: Write

        https://docs.aws.amazon.com/supportapp/latest/APIReference/API_RegisterSlackWorkspaceForOrganization.html

        :stability: experimental
        '''
        return typing.cast("Supportapp", jsii.invoke(self, "toRegisterSlackWorkspaceForOrganization", []))

    @jsii.member(jsii_name="toUpdateSlackChannelConfiguration")
    def to_update_slack_channel_configuration(self) -> "Supportapp":
        '''(experimental) Grants permission to update a Slack channel configuration for your account.

        Access Level: Write

        https://docs.aws.amazon.com/supportapp/latest/APIReference/API_UpdateSlackChannelConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Supportapp", jsii.invoke(self, "toUpdateSlackChannelConfiguration", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ed2e3949482eb35a32d1f371184808468884f390d9e47af7efdfcd7a9b2b1809)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__cd0dd774facf188b1879cdf6e3447d16099bb77d04999b97ed8a097e05638fff)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Supportplans(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Supportplans",
):
    '''(experimental) Statement provider for service `supportplans <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awssupportplans.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `supportplans <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awssupportplans.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="toGetSupportPlan")
    def to_get_support_plan(self) -> "Supportplans":
        '''(experimental) Grants permission to view details about the current support plan for this AWS account.

        Access Level: Read

        https://docs.aws.amazon.com/awssupport/latest/user/security-support-plans.html

        :stability: experimental
        '''
        return typing.cast("Supportplans", jsii.invoke(self, "toGetSupportPlan", []))

    @jsii.member(jsii_name="toGetSupportPlanUpdateStatus")
    def to_get_support_plan_update_status(self) -> "Supportplans":
        '''(experimental) Grants permission to view details about the status for a request to update a support plan.

        Access Level: Read

        https://docs.aws.amazon.com/awssupport/latest/user/security-support-plans.html

        :stability: experimental
        '''
        return typing.cast("Supportplans", jsii.invoke(self, "toGetSupportPlanUpdateStatus", []))

    @jsii.member(jsii_name="toStartSupportPlanUpdate")
    def to_start_support_plan_update(self) -> "Supportplans":
        '''(experimental) Grants permission to update the support plan for this AWS account.

        Access Level: Write

        https://docs.aws.amazon.com/awssupport/latest/user/security-support-plans.html

        :stability: experimental
        '''
        return typing.cast("Supportplans", jsii.invoke(self, "toStartSupportPlanUpdate", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f22475b090ba78776837ac81457caf95deb3a2e7a61746131ff0035bc95836bd)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__db2c88ccfdff90c496368fc990e48e68d9ea86e557ec23954a124d0127b6f3f1)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Sustainability(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Sustainability",
):
    '''(experimental) Statement provider for service `sustainability <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awssustainability.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `sustainability <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awssustainability.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="toGetCarbonFootprintSummary")
    def to_get_carbon_footprint_summary(self) -> "Sustainability":
        '''(experimental) Grants permission to view the carbon footprint tool.

        Access Level: Read

        https://docs.aws.amazon.com/awsaccountbilling/latest/aboutv2/billing-permissions-ref.html

        :stability: experimental
        '''
        return typing.cast("Sustainability", jsii.invoke(self, "toGetCarbonFootprintSummary", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f3c99cbeb61fd1b21060fd022c83316ebbb3cf1eec25d41e53322192b543b3de)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__08ce2c16b36699c5ca34e20771a88bfe4f4565741076aefd08c1fed1c7cb8857)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Swf(PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Swf"):
    '''(experimental) Statement provider for service `swf <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonsimpleworkflowservice.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `swf <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonsimpleworkflowservice.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="ifActivityTypeName")
    def if_activity_type_name(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Swf":
        '''(experimental) Filters access by the name of the activity type.

        https://docs.aws.amazon.com/amazonswf/latest/developerguide/swf-dev-iam.html##swf-dev-iam.api

        Applies to actions:

        - .toDeprecateActivityType()
        - .toDescribeActivityType()
        - .toRespondActivityTaskCompleted()
        - .toUndeprecateActivityType()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__78b14464800348270c89eed751af8ba77e3f6dfddde7b590cb609b0bc7aa25a8)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Swf", jsii.invoke(self, "ifActivityTypeName", [value, operator]))

    @jsii.member(jsii_name="ifActivityTypeVersion")
    def if_activity_type_version(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Swf":
        '''(experimental) Filters access by the version of the activity type.

        https://docs.aws.amazon.com/amazonswf/latest/developerguide/swf-dev-iam.html##swf-dev-iam.api

        Applies to actions:

        - .toDeprecateActivityType()
        - .toDescribeActivityType()
        - .toRespondActivityTaskCompleted()
        - .toUndeprecateActivityType()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fbf8bdddfa348fc627795a4eb23d47f4b7669b8c17af1078948f3f4ec6c62937)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Swf", jsii.invoke(self, "ifActivityTypeVersion", [value, operator]))

    @jsii.member(jsii_name="ifDefaultTaskListName")
    def if_default_task_list_name(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Swf":
        '''(experimental) Filters access by the name of the default task list.

        https://docs.aws.amazon.com/amazonswf/latest/developerguide/swf-dev-iam.html##swf-dev-iam.api

        Applies to actions:

        - .toRegisterActivityType()
        - .toRegisterWorkflowType()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__807d6841bee2f334aee465ec147717c78a5e767154f480ac77cb30c2be412a0a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Swf", jsii.invoke(self, "ifDefaultTaskListName", [value, operator]))

    @jsii.member(jsii_name="ifName")
    def if_name(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Swf":
        '''(experimental) Filters access by the name of activities or workflows.

        https://docs.aws.amazon.com/amazonswf/latest/developerguide/swf-dev-iam.html##swf-dev-iam.api

        Applies to actions:

        - .toRegisterActivityType()
        - .toRegisterWorkflowType()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ef9323f7cdeec14af84ab064a797f71d767b42df4255865b33c38709ad06da22)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Swf", jsii.invoke(self, "ifName", [value, operator]))

    @jsii.member(jsii_name="ifTagFilterTag")
    def if_tag_filter_tag(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Swf":
        '''(experimental) Filters access by the value of tagFilter.tag.

        https://docs.aws.amazon.com/amazonswf/latest/developerguide/swf-dev-iam.html##swf-dev-iam.api

        Applies to actions:

        - .toCountClosedWorkflowExecutions()
        - .toCountOpenWorkflowExecutions()
        - .toListClosedWorkflowExecutions()
        - .toListOpenWorkflowExecutions()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e44fe08b340b977d1855e3db942ddeae2ff78b379545463a9654be82d39a89d1)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Swf", jsii.invoke(self, "ifTagFilterTag", [value, operator]))

    @jsii.member(jsii_name="ifTagListMember0")
    def if_tag_list_member0(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Swf":
        '''(experimental) Filters access by the specified tag.

        https://docs.aws.amazon.com/amazonswf/latest/developerguide/swf-dev-iam.html##swf-dev-iam.api

        Applies to actions:

        - .toRespondActivityTaskCompleted()
        - .toStartWorkflowExecution()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8421840701470efe4795b9284cbf7031f94f74aafc60e6da9d26110107d870ff)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Swf", jsii.invoke(self, "ifTagListMember0", [value, operator]))

    @jsii.member(jsii_name="ifTagListMember1")
    def if_tag_list_member1(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Swf":
        '''(experimental) Filters access by the specified tag.

        https://docs.aws.amazon.com/amazonswf/latest/developerguide/swf-dev-iam.html##swf-dev-iam.api

        Applies to actions:

        - .toRespondActivityTaskCompleted()
        - .toStartWorkflowExecution()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5bdf0f8ba5be833636f4ea8c09dc45891382f09da6d32c04d0b56b823eab4de5)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Swf", jsii.invoke(self, "ifTagListMember1", [value, operator]))

    @jsii.member(jsii_name="ifTagListMember2")
    def if_tag_list_member2(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Swf":
        '''(experimental) Filters access by the specified tag.

        https://docs.aws.amazon.com/amazonswf/latest/developerguide/swf-dev-iam.html##swf-dev-iam.api

        Applies to actions:

        - .toRespondActivityTaskCompleted()
        - .toStartWorkflowExecution()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d0c9b2543b617e07bc386b6e63aba860650d8d4d30824305ae49e04a7b3f83f0)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Swf", jsii.invoke(self, "ifTagListMember2", [value, operator]))

    @jsii.member(jsii_name="ifTagListMember3")
    def if_tag_list_member3(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Swf":
        '''(experimental) Filters access by the specified tag.

        https://docs.aws.amazon.com/amazonswf/latest/developerguide/swf-dev-iam.html##swf-dev-iam.api

        Applies to actions:

        - .toRespondActivityTaskCompleted()
        - .toStartWorkflowExecution()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5ca3c9b2424fbae567168f702aef0e9b8640969104252bb907e2e3a861a695a7)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Swf", jsii.invoke(self, "ifTagListMember3", [value, operator]))

    @jsii.member(jsii_name="ifTagListMember4")
    def if_tag_list_member4(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Swf":
        '''(experimental) Filters access by the specified tag.

        https://docs.aws.amazon.com/amazonswf/latest/developerguide/swf-dev-iam.html##swf-dev-iam.api

        Applies to actions:

        - .toRespondActivityTaskCompleted()
        - .toStartWorkflowExecution()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1324643c42370ca7ff06848bf02b212d311d5ccc24a108eb99e406c6a3b3afd2)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Swf", jsii.invoke(self, "ifTagListMember4", [value, operator]))

    @jsii.member(jsii_name="ifTaskListName")
    def if_task_list_name(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Swf":
        '''(experimental) Filters access by the name of the tasklist.

        https://docs.aws.amazon.com/amazonswf/latest/developerguide/swf-dev-iam.html##swf-dev-iam.api

        Applies to actions:

        - .toCountPendingActivityTasks()
        - .toCountPendingDecisionTasks()
        - .toPollForActivityTask()
        - .toPollForDecisionTask()
        - .toRespondActivityTaskCompleted()
        - .toStartWorkflowExecution()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0441306ade2662caa1d5574c896a7af1d458f33eb6961173b824824cd3a666a0)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Swf", jsii.invoke(self, "ifTaskListName", [value, operator]))

    @jsii.member(jsii_name="ifTypeFilterName")
    def if_type_filter_name(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Swf":
        '''(experimental) Filters access by the name of the type filter.

        https://docs.aws.amazon.com/amazonswf/latest/developerguide/swf-dev-iam.html##swf-dev-iam.api

        Applies to actions:

        - .toCountClosedWorkflowExecutions()
        - .toCountOpenWorkflowExecutions()
        - .toListClosedWorkflowExecutions()
        - .toListOpenWorkflowExecutions()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8842c5b9360baafcb9cc0c2f2a04c5a79fba20fa68e23efe9c3c672241adf456)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Swf", jsii.invoke(self, "ifTypeFilterName", [value, operator]))

    @jsii.member(jsii_name="ifTypeFilterVersion")
    def if_type_filter_version(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Swf":
        '''(experimental) Filters access by the version of the type filter.

        https://docs.aws.amazon.com/amazonswf/latest/developerguide/swf-dev-iam.html##swf-dev-iam.api

        Applies to actions:

        - .toCountClosedWorkflowExecutions()
        - .toCountOpenWorkflowExecutions()
        - .toListClosedWorkflowExecutions()
        - .toListOpenWorkflowExecutions()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__30cddb9a39dd3ea007166d1cb541ec81b4cd961e3018ffdf7b317c64f5909588)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Swf", jsii.invoke(self, "ifTypeFilterVersion", [value, operator]))

    @jsii.member(jsii_name="ifVersion")
    def if_version(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Swf":
        '''(experimental) Filters access by the version of activities or workflows.

        https://docs.aws.amazon.com/amazonswf/latest/developerguide/swf-dev-iam.html##swf-dev-iam.api

        Applies to actions:

        - .toRegisterActivityType()
        - .toRegisterWorkflowType()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8cf5bec312273a2937868ff3fd8b3a17a2f64285cddcb7dbdb7fd42de26296c9)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Swf", jsii.invoke(self, "ifVersion", [value, operator]))

    @jsii.member(jsii_name="ifWorkflowTypeName")
    def if_workflow_type_name(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Swf":
        '''(experimental) Filters access by the name of the workflow type.

        https://docs.aws.amazon.com/amazonswf/latest/developerguide/swf-dev-iam.html##swf-dev-iam.api

        Applies to actions:

        - .toDeprecateWorkflowType()
        - .toDescribeWorkflowType()
        - .toRespondActivityTaskCompleted()
        - .toStartWorkflowExecution()
        - .toUndeprecateWorkflowType()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b451b965b43cdd7273fa4ad1bafa39327bafdc7b5614be9fb483ba3d64faec3e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Swf", jsii.invoke(self, "ifWorkflowTypeName", [value, operator]))

    @jsii.member(jsii_name="ifWorkflowTypeVersion")
    def if_workflow_type_version(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Swf":
        '''(experimental) Filters access by the version of the workflow type.

        https://docs.aws.amazon.com/amazonswf/latest/developerguide/swf-dev-iam.html##swf-dev-iam.api

        Applies to actions:

        - .toDeprecateWorkflowType()
        - .toDescribeWorkflowType()
        - .toRespondActivityTaskCompleted()
        - .toStartWorkflowExecution()
        - .toUndeprecateWorkflowType()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a2d908aa5bba9c6d72f72b9740638391ca2ef94e814093383b857b2691d43633)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Swf", jsii.invoke(self, "ifWorkflowTypeVersion", [value, operator]))

    @jsii.member(jsii_name="onDomain")
    def on_domain(
        self,
        domain_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Swf":
        '''(experimental) Adds a resource of type domain to the statement.

        https://docs.aws.amazon.com/amazonswf/latest/developerguide/swf-dev-domains.html

        :param domain_name: - Identifier for the domainName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__df6d984885c4061a58d1e242ed0a1aabe7f592ee839a6d95920492f8baf50530)
            check_type(argname="argument domain_name", value=domain_name, expected_type=type_hints["domain_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Swf", jsii.invoke(self, "onDomain", [domain_name, account, partition]))

    @jsii.member(jsii_name="toCancelTimer")
    def to_cancel_timer(self) -> "Swf":
        '''(experimental) Grants permission to cancel a previously started timer and record a TimerCanceled event in the history.

        Access Level: Write

        https://docs.aws.amazon.com/amazonswf/latest/apireference/API_Decision.html

        :stability: experimental
        '''
        return typing.cast("Swf", jsii.invoke(self, "toCancelTimer", []))

    @jsii.member(jsii_name="toCancelWorkflowExecution")
    def to_cancel_workflow_execution(self) -> "Swf":
        '''(experimental) Grants permission to close the workflow execution and record a WorkflowExecutionCanceled event in the history.

        Access Level: Write

        https://docs.aws.amazon.com/amazonswf/latest/apireference/API_Decision.html

        :stability: experimental
        '''
        return typing.cast("Swf", jsii.invoke(self, "toCancelWorkflowExecution", []))

    @jsii.member(jsii_name="toCompleteWorkflowExecution")
    def to_complete_workflow_execution(self) -> "Swf":
        '''(experimental) Grants permission to close the workflow execution and record a WorkflowExecutionCompleted event in the history.

        Access Level: Write

        https://docs.aws.amazon.com/amazonswf/latest/apireference/API_Decision.html

        :stability: experimental
        '''
        return typing.cast("Swf", jsii.invoke(self, "toCompleteWorkflowExecution", []))

    @jsii.member(jsii_name="toContinueAsNewWorkflowExecution")
    def to_continue_as_new_workflow_execution(self) -> "Swf":
        '''(experimental) Grants permission to close the workflow execution and start a new workflow execution of the same type using the same workflow ID and a unique run Id.

        Access Level: Write

        https://docs.aws.amazon.com/amazonswf/latest/apireference/API_Decision.html

        :stability: experimental
        '''
        return typing.cast("Swf", jsii.invoke(self, "toContinueAsNewWorkflowExecution", []))

    @jsii.member(jsii_name="toCountClosedWorkflowExecutions")
    def to_count_closed_workflow_executions(self) -> "Swf":
        '''(experimental) Grants permission to return the number of closed workflow executions within the given domain that meet the specified filtering criteria.

        Access Level: Read

        Possible conditions:

        - .ifTagFilterTag()
        - .ifTypeFilterName()
        - .ifTypeFilterVersion()

        https://docs.aws.amazon.com/amazonswf/latest/apireference/API_CountClosedWorkflowExecutions.html

        :stability: experimental
        '''
        return typing.cast("Swf", jsii.invoke(self, "toCountClosedWorkflowExecutions", []))

    @jsii.member(jsii_name="toCountOpenWorkflowExecutions")
    def to_count_open_workflow_executions(self) -> "Swf":
        '''(experimental) Grants permission to return the number of open workflow executions within the given domain that meet the specified filtering criteria.

        Access Level: Read

        Possible conditions:

        - .ifTagFilterTag()
        - .ifTypeFilterName()
        - .ifTypeFilterVersion()

        https://docs.aws.amazon.com/amazonswf/latest/apireference/API_CountOpenWorkflowExecutions.html

        :stability: experimental
        '''
        return typing.cast("Swf", jsii.invoke(self, "toCountOpenWorkflowExecutions", []))

    @jsii.member(jsii_name="toCountPendingActivityTasks")
    def to_count_pending_activity_tasks(self) -> "Swf":
        '''(experimental) Grants permission to return the estimated number of activity tasks in the specified task list.

        Access Level: Read

        Possible conditions:

        - .ifTaskListName()

        https://docs.aws.amazon.com/amazonswf/latest/apireference/API_CountPendingActivityTasks.html

        :stability: experimental
        '''
        return typing.cast("Swf", jsii.invoke(self, "toCountPendingActivityTasks", []))

    @jsii.member(jsii_name="toCountPendingDecisionTasks")
    def to_count_pending_decision_tasks(self) -> "Swf":
        '''(experimental) Grants permission to return the estimated number of decision tasks in the specified task list.

        Access Level: Read

        Possible conditions:

        - .ifTaskListName()

        https://docs.aws.amazon.com/amazonswf/latest/apireference/API_CountPendingDecisionTasks.html

        :stability: experimental
        '''
        return typing.cast("Swf", jsii.invoke(self, "toCountPendingDecisionTasks", []))

    @jsii.member(jsii_name="toDeprecateActivityType")
    def to_deprecate_activity_type(self) -> "Swf":
        '''(experimental) Grants permission to deprecate the specified activity type.

        Access Level: Write

        Possible conditions:

        - .ifActivityTypeName()
        - .ifActivityTypeVersion()

        https://docs.aws.amazon.com/amazonswf/latest/apireference/API_DeprecateActivityType.html

        :stability: experimental
        '''
        return typing.cast("Swf", jsii.invoke(self, "toDeprecateActivityType", []))

    @jsii.member(jsii_name="toDeprecateDomain")
    def to_deprecate_domain(self) -> "Swf":
        '''(experimental) Grants permission to deprecate the specified domain.

        Access Level: Write

        https://docs.aws.amazon.com/amazonswf/latest/apireference/API_DeprecateDomain.html

        :stability: experimental
        '''
        return typing.cast("Swf", jsii.invoke(self, "toDeprecateDomain", []))

    @jsii.member(jsii_name="toDeprecateWorkflowType")
    def to_deprecate_workflow_type(self) -> "Swf":
        '''(experimental) Grants permission to deprecate the specified workflow type.

        Access Level: Write

        Possible conditions:

        - .ifWorkflowTypeName()
        - .ifWorkflowTypeVersion()

        https://docs.aws.amazon.com/amazonswf/latest/apireference/API_DeprecateWorkflowType.html

        :stability: experimental
        '''
        return typing.cast("Swf", jsii.invoke(self, "toDeprecateWorkflowType", []))

    @jsii.member(jsii_name="toDescribeActivityType")
    def to_describe_activity_type(self) -> "Swf":
        '''(experimental) Grants permission to return information about the specified activity type.

        Access Level: Read

        Possible conditions:

        - .ifActivityTypeName()
        - .ifActivityTypeVersion()

        https://docs.aws.amazon.com/amazonswf/latest/apireference/API_DescribeActivityType.html

        :stability: experimental
        '''
        return typing.cast("Swf", jsii.invoke(self, "toDescribeActivityType", []))

    @jsii.member(jsii_name="toDescribeDomain")
    def to_describe_domain(self) -> "Swf":
        '''(experimental) Grants permission to return information about the specified domain, including its description and status.

        Access Level: Read

        https://docs.aws.amazon.com/amazonswf/latest/apireference/API_DescribeDomain.html

        :stability: experimental
        '''
        return typing.cast("Swf", jsii.invoke(self, "toDescribeDomain", []))

    @jsii.member(jsii_name="toDescribeWorkflowExecution")
    def to_describe_workflow_execution(self) -> "Swf":
        '''(experimental) Grants permission to return information about the specified workflow execution including its type and some statistics.

        Access Level: Read

        https://docs.aws.amazon.com/amazonswf/latest/apireference/API_DescribeWorkflowExecution.html

        :stability: experimental
        '''
        return typing.cast("Swf", jsii.invoke(self, "toDescribeWorkflowExecution", []))

    @jsii.member(jsii_name="toDescribeWorkflowType")
    def to_describe_workflow_type(self) -> "Swf":
        '''(experimental) Grants permission to return information about the specified workflow type.

        Access Level: Read

        Possible conditions:

        - .ifWorkflowTypeName()
        - .ifWorkflowTypeVersion()

        https://docs.aws.amazon.com/amazonswf/latest/apireference/API_DescribeWorkflowType.html

        :stability: experimental
        '''
        return typing.cast("Swf", jsii.invoke(self, "toDescribeWorkflowType", []))

    @jsii.member(jsii_name="toFailWorkflowExecution")
    def to_fail_workflow_execution(self) -> "Swf":
        '''(experimental) Grants permission to close the workflow execution and record a WorkflowExecutionFailed event in the history.

        Access Level: Write

        https://docs.aws.amazon.com/amazonswf/latest/apireference/API_Decision.html

        :stability: experimental
        '''
        return typing.cast("Swf", jsii.invoke(self, "toFailWorkflowExecution", []))

    @jsii.member(jsii_name="toGetWorkflowExecutionHistory")
    def to_get_workflow_execution_history(self) -> "Swf":
        '''(experimental) Grants permission to return the history of the specified workflow execution.

        Access Level: Read

        https://docs.aws.amazon.com/amazonswf/latest/apireference/API_GetWorkflowExecutionHistory.html

        :stability: experimental
        '''
        return typing.cast("Swf", jsii.invoke(self, "toGetWorkflowExecutionHistory", []))

    @jsii.member(jsii_name="toListActivityTypes")
    def to_list_activity_types(self) -> "Swf":
        '''(experimental) Grants permission to return information about all activities registered in the specified domain that match the specified name and registration status.

        Access Level: List

        https://docs.aws.amazon.com/amazonswf/latest/apireference/API_ListActivityTypes.html

        :stability: experimental
        '''
        return typing.cast("Swf", jsii.invoke(self, "toListActivityTypes", []))

    @jsii.member(jsii_name="toListClosedWorkflowExecutions")
    def to_list_closed_workflow_executions(self) -> "Swf":
        '''(experimental) Grants permission to return a list of closed workflow executions in the specified domain that meet the filtering criteria.

        Access Level: List

        Possible conditions:

        - .ifTagFilterTag()
        - .ifTypeFilterName()
        - .ifTypeFilterVersion()

        https://docs.aws.amazon.com/amazonswf/latest/apireference/API_ListClosedWorkflowExecutions.html

        :stability: experimental
        '''
        return typing.cast("Swf", jsii.invoke(self, "toListClosedWorkflowExecutions", []))

    @jsii.member(jsii_name="toListDomains")
    def to_list_domains(self) -> "Swf":
        '''(experimental) Grants permission to return the list of domains registered in the account.

        Access Level: List

        https://docs.aws.amazon.com/amazonswf/latest/apireference/API_ListDomains.html

        :stability: experimental
        '''
        return typing.cast("Swf", jsii.invoke(self, "toListDomains", []))

    @jsii.member(jsii_name="toListOpenWorkflowExecutions")
    def to_list_open_workflow_executions(self) -> "Swf":
        '''(experimental) Grants permission to return a list of open workflow executions in the specified domain that meet the filtering criteria.

        Access Level: List

        Possible conditions:

        - .ifTagFilterTag()
        - .ifTypeFilterName()
        - .ifTypeFilterVersion()

        https://docs.aws.amazon.com/amazonswf/latest/apireference/API_ListOpenWorkflowExecutions.html

        :stability: experimental
        '''
        return typing.cast("Swf", jsii.invoke(self, "toListOpenWorkflowExecutions", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Swf":
        '''(experimental) Grants permission to list tags for an AWS SWF resource.

        Access Level: List

        https://docs.aws.amazon.com/amazonswf/latest/apireference/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("Swf", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toListWorkflowTypes")
    def to_list_workflow_types(self) -> "Swf":
        '''(experimental) Grants permission to return information about workflow types in the specified domain.

        Access Level: List

        https://docs.aws.amazon.com/amazonswf/latest/apireference/API_ListWorkflowTypes.html

        :stability: experimental
        '''
        return typing.cast("Swf", jsii.invoke(self, "toListWorkflowTypes", []))

    @jsii.member(jsii_name="toPollForActivityTask")
    def to_poll_for_activity_task(self) -> "Swf":
        '''(experimental) Grants permission to workers to get an ActivityTask from the specified activity taskList.

        Access Level: Write

        Possible conditions:

        - .ifTaskListName()

        https://docs.aws.amazon.com/amazonswf/latest/apireference/API_PollForActivityTask.html

        :stability: experimental
        '''
        return typing.cast("Swf", jsii.invoke(self, "toPollForActivityTask", []))

    @jsii.member(jsii_name="toPollForDecisionTask")
    def to_poll_for_decision_task(self) -> "Swf":
        '''(experimental) Grants permission to deciders to get a DecisionTask from the specified decision taskList.

        Access Level: Write

        Possible conditions:

        - .ifTaskListName()

        https://docs.aws.amazon.com/amazonswf/latest/apireference/API_PollForDecisionTask.html

        :stability: experimental
        '''
        return typing.cast("Swf", jsii.invoke(self, "toPollForDecisionTask", []))

    @jsii.member(jsii_name="toRecordActivityTaskHeartbeat")
    def to_record_activity_task_heartbeat(self) -> "Swf":
        '''(experimental) Grants permission to workers to report to the service that the ActivityTask represented by the specified taskToken is still making progress.

        Access Level: Write

        https://docs.aws.amazon.com/amazonswf/latest/apireference/API_RecordActivityTaskHeartbeat.html

        :stability: experimental
        '''
        return typing.cast("Swf", jsii.invoke(self, "toRecordActivityTaskHeartbeat", []))

    @jsii.member(jsii_name="toRecordMarker")
    def to_record_marker(self) -> "Swf":
        '''(experimental) Grants permission to record a MarkerRecorded event in the history.

        Access Level: Write

        https://docs.aws.amazon.com/amazonswf/latest/apireference/API_Decision.html

        :stability: experimental
        '''
        return typing.cast("Swf", jsii.invoke(self, "toRecordMarker", []))

    @jsii.member(jsii_name="toRegisterActivityType")
    def to_register_activity_type(self) -> "Swf":
        '''(experimental) Grants permission to register a new activity type along with its configuration settings in the specified domain.

        Access Level: Write

        Possible conditions:

        - .ifDefaultTaskListName()
        - .ifName()
        - .ifVersion()

        https://docs.aws.amazon.com/amazonswf/latest/apireference/API_RegisterActivityType.html

        :stability: experimental
        '''
        return typing.cast("Swf", jsii.invoke(self, "toRegisterActivityType", []))

    @jsii.member(jsii_name="toRegisterDomain")
    def to_register_domain(self) -> "Swf":
        '''(experimental) Grants permission to register a new domain.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/amazonswf/latest/apireference/API_RegisterDomain.html

        :stability: experimental
        '''
        return typing.cast("Swf", jsii.invoke(self, "toRegisterDomain", []))

    @jsii.member(jsii_name="toRegisterWorkflowType")
    def to_register_workflow_type(self) -> "Swf":
        '''(experimental) Grants permission to register a new workflow type and its configuration settings in the specified domain.

        Access Level: Write

        Possible conditions:

        - .ifDefaultTaskListName()
        - .ifName()
        - .ifVersion()

        https://docs.aws.amazon.com/amazonswf/latest/apireference/API_RegisterWorkflowType.html

        :stability: experimental
        '''
        return typing.cast("Swf", jsii.invoke(self, "toRegisterWorkflowType", []))

    @jsii.member(jsii_name="toRequestCancelActivityTask")
    def to_request_cancel_activity_task(self) -> "Swf":
        '''(experimental) Grants permission to attempt to cancel a previously scheduled activity task.

        Access Level: Write

        https://docs.aws.amazon.com/amazonswf/latest/apireference/API_Decision.html

        :stability: experimental
        '''
        return typing.cast("Swf", jsii.invoke(self, "toRequestCancelActivityTask", []))

    @jsii.member(jsii_name="toRequestCancelExternalWorkflowExecution")
    def to_request_cancel_external_workflow_execution(self) -> "Swf":
        '''(experimental) Grants permission to request that a request be made to cancel the specified external workflow execution.

        Access Level: Write

        https://docs.aws.amazon.com/amazonswf/latest/apireference/API_Decision.html

        :stability: experimental
        '''
        return typing.cast("Swf", jsii.invoke(self, "toRequestCancelExternalWorkflowExecution", []))

    @jsii.member(jsii_name="toRequestCancelWorkflowExecution")
    def to_request_cancel_workflow_execution(self) -> "Swf":
        '''(experimental) Grants permission to record a WorkflowExecutionCancelRequested event in the currently running workflow execution identified by the given domain, workflowId, and runId.

        Access Level: Write

        https://docs.aws.amazon.com/amazonswf/latest/apireference/API_RequestCancelWorkflowExecution.html

        :stability: experimental
        '''
        return typing.cast("Swf", jsii.invoke(self, "toRequestCancelWorkflowExecution", []))

    @jsii.member(jsii_name="toRespondActivityTaskCanceled")
    def to_respond_activity_task_canceled(self) -> "Swf":
        '''(experimental) Grants permission to workers to tell the service that the ActivityTask identified by the taskToken was successfully canceled.

        Access Level: Write

        https://docs.aws.amazon.com/amazonswf/latest/apireference/API_RespondActivityTaskCanceled.html

        :stability: experimental
        '''
        return typing.cast("Swf", jsii.invoke(self, "toRespondActivityTaskCanceled", []))

    @jsii.member(jsii_name="toRespondActivityTaskCompleted")
    def to_respond_activity_task_completed(self) -> "Swf":
        '''(experimental) Grants permission to workers to tell the service that the ActivityTask identified by the taskToken completed successfully with a result (if provided).

        Access Level: Write

        Possible conditions:

        - .ifActivityTypeName()
        - .ifActivityTypeVersion()
        - .ifTagListMember0()
        - .ifTagListMember1()
        - .ifTagListMember2()
        - .ifTagListMember3()
        - .ifTagListMember4()
        - .ifTaskListName()
        - .ifWorkflowTypeName()
        - .ifWorkflowTypeVersion()

        https://docs.aws.amazon.com/amazonswf/latest/apireference/API_RespondActivityTaskCompleted.html

        :stability: experimental
        '''
        return typing.cast("Swf", jsii.invoke(self, "toRespondActivityTaskCompleted", []))

    @jsii.member(jsii_name="toRespondActivityTaskFailed")
    def to_respond_activity_task_failed(self) -> "Swf":
        '''(experimental) Grants permission to workers to tell the service that the ActivityTask identified by the taskToken has failed with reason (if specified).

        Access Level: Write

        https://docs.aws.amazon.com/amazonswf/latest/apireference/API_RespondActivityTaskFailed.html

        :stability: experimental
        '''
        return typing.cast("Swf", jsii.invoke(self, "toRespondActivityTaskFailed", []))

    @jsii.member(jsii_name="toRespondDecisionTaskCompleted")
    def to_respond_decision_task_completed(self) -> "Swf":
        '''(experimental) Grants permission to deciders to tell the service that the DecisionTask identified by the taskToken has successfully completed.

        Access Level: Write

        https://docs.aws.amazon.com/amazonswf/latest/apireference/API_RespondDecisionTaskCompleted.html

        :stability: experimental
        '''
        return typing.cast("Swf", jsii.invoke(self, "toRespondDecisionTaskCompleted", []))

    @jsii.member(jsii_name="toScheduleActivityTask")
    def to_schedule_activity_task(self) -> "Swf":
        '''(experimental) Grants permission to schedule an activity task.

        Access Level: Write

        https://docs.aws.amazon.com/amazonswf/latest/apireference/API_Decision.html

        :stability: experimental
        '''
        return typing.cast("Swf", jsii.invoke(self, "toScheduleActivityTask", []))

    @jsii.member(jsii_name="toSignalExternalWorkflowExecution")
    def to_signal_external_workflow_execution(self) -> "Swf":
        '''(experimental) Grants permission to request a signal to be delivered to the specified external workflow execution and records.

        Access Level: Write

        https://docs.aws.amazon.com/amazonswf/latest/apireference/API_Decision.html

        :stability: experimental
        '''
        return typing.cast("Swf", jsii.invoke(self, "toSignalExternalWorkflowExecution", []))

    @jsii.member(jsii_name="toSignalWorkflowExecution")
    def to_signal_workflow_execution(self) -> "Swf":
        '''(experimental) Grants permission to record a WorkflowExecutionSignaled event in the workflow execution history and create a decision task for the workflow execution identified by the given domain, workflowId and runId.

        Access Level: Write

        https://docs.aws.amazon.com/amazonswf/latest/apireference/API_SignalWorkflowExecution.html

        :stability: experimental
        '''
        return typing.cast("Swf", jsii.invoke(self, "toSignalWorkflowExecution", []))

    @jsii.member(jsii_name="toStartChildWorkflowExecution")
    def to_start_child_workflow_execution(self) -> "Swf":
        '''(experimental) Grants permission to request that a child workflow execution be started.

        Access Level: Write

        https://docs.aws.amazon.com/amazonswf/latest/apireference/API_Decision.html

        :stability: experimental
        '''
        return typing.cast("Swf", jsii.invoke(self, "toStartChildWorkflowExecution", []))

    @jsii.member(jsii_name="toStartTimer")
    def to_start_timer(self) -> "Swf":
        '''(experimental) Grants permission to start a timer for a workflow execution.

        Access Level: Write

        https://docs.aws.amazon.com/amazonswf/latest/apireference/API_Decision.html

        :stability: experimental
        '''
        return typing.cast("Swf", jsii.invoke(self, "toStartTimer", []))

    @jsii.member(jsii_name="toStartWorkflowExecution")
    def to_start_workflow_execution(self) -> "Swf":
        '''(experimental) Grants permission to start an execution of the workflow type in the specified domain using the provided workflowId and input data.

        Access Level: Write

        Possible conditions:

        - .ifTagListMember0()
        - .ifTagListMember1()
        - .ifTagListMember2()
        - .ifTagListMember3()
        - .ifTagListMember4()
        - .ifTaskListName()
        - .ifWorkflowTypeName()
        - .ifWorkflowTypeVersion()

        https://docs.aws.amazon.com/amazonswf/latest/apireference/API_StartWorkflowExecution.html

        :stability: experimental
        '''
        return typing.cast("Swf", jsii.invoke(self, "toStartWorkflowExecution", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Swf":
        '''(experimental) Grants permission to tag an AWS SWF resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/amazonswf/latest/apireference/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("Swf", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toTerminateWorkflowExecution")
    def to_terminate_workflow_execution(self) -> "Swf":
        '''(experimental) Grants permission to record a WorkflowExecutionTerminated event and force closure of the workflow execution identified by the given domain, runId, and workflowId.

        Access Level: Write

        https://docs.aws.amazon.com/amazonswf/latest/apireference/API_TerminateWorkflowExecution.html

        :stability: experimental
        '''
        return typing.cast("Swf", jsii.invoke(self, "toTerminateWorkflowExecution", []))

    @jsii.member(jsii_name="toUndeprecateActivityType")
    def to_undeprecate_activity_type(self) -> "Swf":
        '''(experimental) Grants permission to undeprecate a previously deprecated activity type.

        Access Level: Write

        Possible conditions:

        - .ifActivityTypeName()
        - .ifActivityTypeVersion()

        https://docs.aws.amazon.com/amazonswf/latest/apireference/API_UndeprecateActivityType.html

        :stability: experimental
        '''
        return typing.cast("Swf", jsii.invoke(self, "toUndeprecateActivityType", []))

    @jsii.member(jsii_name="toUndeprecateDomain")
    def to_undeprecate_domain(self) -> "Swf":
        '''(experimental) Grants permission to undeprecate a previously deprecated domain.

        Access Level: Write

        https://docs.aws.amazon.com/amazonswf/latest/apireference/API_UndeprecateDomain.html

        :stability: experimental
        '''
        return typing.cast("Swf", jsii.invoke(self, "toUndeprecateDomain", []))

    @jsii.member(jsii_name="toUndeprecateWorkflowType")
    def to_undeprecate_workflow_type(self) -> "Swf":
        '''(experimental) Grants permission to undeprecate a previously deprecated workflow type.

        Access Level: Write

        Possible conditions:

        - .ifWorkflowTypeName()
        - .ifWorkflowTypeVersion()

        https://docs.aws.amazon.com/amazonswf/latest/apireference/API_UndeprecateWorkflowType.html

        :stability: experimental
        '''
        return typing.cast("Swf", jsii.invoke(self, "toUndeprecateWorkflowType", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Swf":
        '''(experimental) Grants permission to remove a tag from an AWS SWF resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/amazonswf/latest/apireference/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("Swf", jsii.invoke(self, "toUntagResource", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fac13df42dd78b67a2ac1ef0cf8e1c6cbeb0422ff05bc1405d636aacce2fca0a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6f797cb9c81efead3438322b3513ee4158bb5d7dcf867561007c2f713185ddb6)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Synthetics(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Synthetics",
):
    '''(experimental) Statement provider for service `synthetics <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazoncloudwatchsynthetics.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `synthetics <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazoncloudwatchsynthetics.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="ifNames")
    def if_names(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Synthetics":
        '''(experimental) Filters access based on the name of the canary.

        https://docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/CloudWatch_Synthetics_Canaries_Restricted.html

        Applies to actions:

        - .toDescribeCanaries()
        - .toDescribeCanariesLastRun()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e6bed424e387b92d6d6f2ecabb8e8636d8dfb1c377535c163db13bbcd5b8ceaa)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Synthetics", jsii.invoke(self, "ifNames", [value, operator]))

    @jsii.member(jsii_name="onCanary")
    def on_canary(
        self,
        canary_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Synthetics":
        '''(experimental) Adds a resource of type canary to the statement.

        https://docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/CloudWatch_Synthetics_Canaries.html

        :param canary_name: - Identifier for the canaryName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7c5efb03621519fa048cec5b0f49f3cc7672ee831ce20e9c6286784cada6d05a)
            check_type(argname="argument canary_name", value=canary_name, expected_type=type_hints["canary_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Synthetics", jsii.invoke(self, "onCanary", [canary_name, account, region, partition]))

    @jsii.member(jsii_name="onGroup")
    def on_group(
        self,
        group_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Synthetics":
        '''(experimental) Adds a resource of type group to the statement.

        https://docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/CloudWatch_Synthetics_Groups.html

        :param group_id: - Identifier for the groupId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c95bf38e90991f47bda738e728b5781a6882e904de5f7bf416ad62269dbaad4b)
            check_type(argname="argument group_id", value=group_id, expected_type=type_hints["group_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Synthetics", jsii.invoke(self, "onGroup", [group_id, account, region, partition]))

    @jsii.member(jsii_name="toAssociateResource")
    def to_associate_resource(self) -> "Synthetics":
        '''(experimental) Grants permission to associate a resource with a group.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/AmazonSynthetics/latest/APIReference/API_AssociateResource.html

        :stability: experimental
        '''
        return typing.cast("Synthetics", jsii.invoke(self, "toAssociateResource", []))

    @jsii.member(jsii_name="toCreateCanary")
    def to_create_canary(self) -> "Synthetics":
        '''(experimental) Grants permission to create a canary.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/AmazonSynthetics/latest/APIReference/API_CreateCanary.html

        :stability: experimental
        '''
        return typing.cast("Synthetics", jsii.invoke(self, "toCreateCanary", []))

    @jsii.member(jsii_name="toCreateGroup")
    def to_create_group(self) -> "Synthetics":
        '''(experimental) Grants permission to create a group.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/AmazonSynthetics/latest/APIReference/API_CreateGroup.html

        :stability: experimental
        '''
        return typing.cast("Synthetics", jsii.invoke(self, "toCreateGroup", []))

    @jsii.member(jsii_name="toDeleteCanary")
    def to_delete_canary(self) -> "Synthetics":
        '''(experimental) Grants permission to delete a canary.

        Amazon Synthetics deletes all the resources except for the Lambda function and the CloudWatch Alarms if you created one

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/AmazonSynthetics/latest/APIReference/API_DeleteCanary.html

        :stability: experimental
        '''
        return typing.cast("Synthetics", jsii.invoke(self, "toDeleteCanary", []))

    @jsii.member(jsii_name="toDeleteGroup")
    def to_delete_group(self) -> "Synthetics":
        '''(experimental) Grants permission to delete a group.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/AmazonSynthetics/latest/APIReference/API_DeleteGroup.html

        :stability: experimental
        '''
        return typing.cast("Synthetics", jsii.invoke(self, "toDeleteGroup", []))

    @jsii.member(jsii_name="toDescribeCanaries")
    def to_describe_canaries(self) -> "Synthetics":
        '''(experimental) Grants permission to list information of all canaries.

        Access Level: Read

        Possible conditions:

        - .ifNames()

        https://docs.aws.amazon.com/AmazonSynthetics/latest/APIReference/API_DescribeCanaries.html

        :stability: experimental
        '''
        return typing.cast("Synthetics", jsii.invoke(self, "toDescribeCanaries", []))

    @jsii.member(jsii_name="toDescribeCanariesLastRun")
    def to_describe_canaries_last_run(self) -> "Synthetics":
        '''(experimental) Grants permission to list information about the last test run associated with all canaries.

        Access Level: Read

        Possible conditions:

        - .ifNames()

        https://docs.aws.amazon.com/AmazonSynthetics/latest/APIReference/API_DescribeCanariesLastRun.html

        :stability: experimental
        '''
        return typing.cast("Synthetics", jsii.invoke(self, "toDescribeCanariesLastRun", []))

    @jsii.member(jsii_name="toDescribeRuntimeVersions")
    def to_describe_runtime_versions(self) -> "Synthetics":
        '''(experimental) Grants permission to list information about Synthetics canary runtime versions.

        Access Level: Read

        https://docs.aws.amazon.com/AmazonSynthetics/latest/APIReference/API_DescribeRuntimeVersions.html

        :stability: experimental
        '''
        return typing.cast("Synthetics", jsii.invoke(self, "toDescribeRuntimeVersions", []))

    @jsii.member(jsii_name="toDisassociateResource")
    def to_disassociate_resource(self) -> "Synthetics":
        '''(experimental) Grants permission to disassociate a resource from a group.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/AmazonSynthetics/latest/APIReference/API_DisassociateResource.html

        :stability: experimental
        '''
        return typing.cast("Synthetics", jsii.invoke(self, "toDisassociateResource", []))

    @jsii.member(jsii_name="toGetCanary")
    def to_get_canary(self) -> "Synthetics":
        '''(experimental) Grants permission to view the details of a canary.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/AmazonSynthetics/latest/APIReference/API_GetCanary.html

        :stability: experimental
        '''
        return typing.cast("Synthetics", jsii.invoke(self, "toGetCanary", []))

    @jsii.member(jsii_name="toGetCanaryRuns")
    def to_get_canary_runs(self) -> "Synthetics":
        '''(experimental) Grants permission to list information about all the test runs associated with a canary.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/AmazonSynthetics/latest/APIReference/API_GetCanaryRuns.html

        :stability: experimental
        '''
        return typing.cast("Synthetics", jsii.invoke(self, "toGetCanaryRuns", []))

    @jsii.member(jsii_name="toGetGroup")
    def to_get_group(self) -> "Synthetics":
        '''(experimental) Grants permission to view the details of a group.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/AmazonSynthetics/latest/APIReference/API_GetGroup.html

        :stability: experimental
        '''
        return typing.cast("Synthetics", jsii.invoke(self, "toGetGroup", []))

    @jsii.member(jsii_name="toListAssociatedGroups")
    def to_list_associated_groups(self) -> "Synthetics":
        '''(experimental) Grants permission to list information about the associated groups of a canary.

        Access Level: List

        Possible conditions:

        - .ifAwsResourceTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/AmazonSynthetics/latest/APIReference/API_ListAssociatedGroups.html

        :stability: experimental
        '''
        return typing.cast("Synthetics", jsii.invoke(self, "toListAssociatedGroups", []))

    @jsii.member(jsii_name="toListGroupResources")
    def to_list_group_resources(self) -> "Synthetics":
        '''(experimental) Grants permission to list information about canaries in a group.

        Access Level: List

        Possible conditions:

        - .ifAwsResourceTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/AmazonSynthetics/latest/APIReference/API_ListGroupResources.html

        :stability: experimental
        '''
        return typing.cast("Synthetics", jsii.invoke(self, "toListGroupResources", []))

    @jsii.member(jsii_name="toListGroups")
    def to_list_groups(self) -> "Synthetics":
        '''(experimental) Grants permission to list information of all groups.

        Access Level: List

        https://docs.aws.amazon.com/AmazonSynthetics/latest/APIReference/API_ListGroups.html

        :stability: experimental
        '''
        return typing.cast("Synthetics", jsii.invoke(self, "toListGroups", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Synthetics":
        '''(experimental) Grants permission to list all tags and values associated with a resource.

        Access Level: Read

        https://docs.aws.amazon.com/AmazonSynthetics/latest/APIReference/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("Synthetics", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toStartCanary")
    def to_start_canary(self) -> "Synthetics":
        '''(experimental) Grants permission to start a canary, so that Amazon CloudWatch Synthetics starts monitoring a website.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/AmazonSynthetics/latest/APIReference/API_StartCanary.html

        :stability: experimental
        '''
        return typing.cast("Synthetics", jsii.invoke(self, "toStartCanary", []))

    @jsii.member(jsii_name="toStopCanary")
    def to_stop_canary(self) -> "Synthetics":
        '''(experimental) Grants permission to stop a canary.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/AmazonSynthetics/latest/APIReference/API_StopCanary.html

        :stability: experimental
        '''
        return typing.cast("Synthetics", jsii.invoke(self, "toStopCanary", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Synthetics":
        '''(experimental) Grants permission to add one or more tags to a resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/AmazonSynthetics/latest/APIReference/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("Synthetics", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Synthetics":
        '''(experimental) Grants permission to remove one or more tags from a resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsResourceTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/AmazonSynthetics/latest/APIReference/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("Synthetics", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateCanary")
    def to_update_canary(self) -> "Synthetics":
        '''(experimental) Grants permission to update a canary.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/AmazonSynthetics/latest/APIReference/API_UpdateCanary.html

        :stability: experimental
        '''
        return typing.cast("Synthetics", jsii.invoke(self, "toUpdateCanary", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5f90d6ace9854dc9266a7df7d59bd90c932ca2875c6d7c3556a0fa28fe6edf55)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0d52604abca1c9bf404fec2f3d4ef66ab8f89e9e94b26fe1c8512fd6641333f0)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Tag(PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Tag"):
    '''(experimental) Statement provider for service `tag <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonresourcegrouptaggingapi.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `tag <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonresourcegrouptaggingapi.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="toDescribeReportCreation")
    def to_describe_report_creation(self) -> "Tag":
        '''(experimental) Grants permission to describe the status of the StartReportCreation operation.

        Access Level: Read

        https://docs.aws.amazon.com/resourcegroupstagging/latest/APIReference/API_DescribeReportCreation.html

        :stability: experimental
        '''
        return typing.cast("Tag", jsii.invoke(self, "toDescribeReportCreation", []))

    @jsii.member(jsii_name="toGetComplianceSummary")
    def to_get_compliance_summary(self) -> "Tag":
        '''(experimental) Grants permission to retrieve a summary of how many resources are noncompliant with their effective tag policies.

        Access Level: Read

        https://docs.aws.amazon.com/resourcegroupstagging/latest/APIReference/API_GetComplianceSummary.html

        :stability: experimental
        '''
        return typing.cast("Tag", jsii.invoke(self, "toGetComplianceSummary", []))

    @jsii.member(jsii_name="toGetResources")
    def to_get_resources(self) -> "Tag":
        '''(experimental) Grants permission to return tagged or previously tagged resources in the specified AWS Region for the calling account.

        Access Level: Read

        https://docs.aws.amazon.com/resourcegroupstagging/latest/APIReference/API_GetResources.html

        :stability: experimental
        '''
        return typing.cast("Tag", jsii.invoke(self, "toGetResources", []))

    @jsii.member(jsii_name="toGetTagKeys")
    def to_get_tag_keys(self) -> "Tag":
        '''(experimental) Grants permission to returns tag keys currently in use in the specified AWS Region for the calling account.

        Access Level: Read

        https://docs.aws.amazon.com/resourcegroupstagging/latest/APIReference/API_GetTagKeys.html

        :stability: experimental
        '''
        return typing.cast("Tag", jsii.invoke(self, "toGetTagKeys", []))

    @jsii.member(jsii_name="toGetTagValues")
    def to_get_tag_values(self) -> "Tag":
        '''(experimental) Grants permission to return tag values for the specified key that are used in the specified AWS Region for the calling account.

        Access Level: Read

        https://docs.aws.amazon.com/resourcegroupstagging/latest/APIReference/API_GetTagValues.html

        :stability: experimental
        '''
        return typing.cast("Tag", jsii.invoke(self, "toGetTagValues", []))

    @jsii.member(jsii_name="toStartReportCreation")
    def to_start_report_creation(self) -> "Tag":
        '''(experimental) Grants permission to start generating a report listing all tagged resources in accounts across your organization, and whether each resource is compliant with the effective tag policy.

        Access Level: Write

        https://docs.aws.amazon.com/resourcegroupstagging/latest/APIReference/API_StartReportCreation.html

        :stability: experimental
        '''
        return typing.cast("Tag", jsii.invoke(self, "toStartReportCreation", []))

    @jsii.member(jsii_name="toTagResources")
    def to_tag_resources(self) -> "Tag":
        '''(experimental) Grants permission to apply one or more tags to the specified resources.

        Access Level: Tagging

        https://docs.aws.amazon.com/resourcegroupstagging/latest/APIReference/API_TagResources.html

        :stability: experimental
        '''
        return typing.cast("Tag", jsii.invoke(self, "toTagResources", []))

    @jsii.member(jsii_name="toUntagResources")
    def to_untag_resources(self) -> "Tag":
        '''(experimental) Grants permission to remove the specified tags from the specified resources.

        Access Level: Tagging

        https://docs.aws.amazon.com/resourcegroupstagging/latest/APIReference/API_UntagResources.html

        :stability: experimental
        '''
        return typing.cast("Tag", jsii.invoke(self, "toUntagResources", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__097310013a9d4c32e004950302c7cc8c0f03c7d901ea568f21b9cd570b4104e0)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8188cff1ad06909687b3171519c3d7d600dc270836a541bfd07125cedb023e90)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Tax(PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Tax"):
    '''(experimental) Statement provider for service `tax <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awstaxsettings.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `tax <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awstaxsettings.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="toGetExemptions")
    def to_get_exemptions(self) -> "Tax":
        '''(experimental) Grants permission to view tax exemptions data.

        Access Level: Read

        https://docs.aws.amazon.com/awsaccountbilling/latest/aboutv2/billing-permissions-ref.html#user-permissions

        :stability: experimental
        '''
        return typing.cast("Tax", jsii.invoke(self, "toGetExemptions", []))

    @jsii.member(jsii_name="toGetTaxInterview")
    def to_get_tax_interview(self) -> "Tax":
        '''(experimental) Grants permission to retrieve tax interview data.

        Access Level: Read

        :stability: experimental
        '''
        return typing.cast("Tax", jsii.invoke(self, "toGetTaxInterview", []))

    @jsii.member(jsii_name="toGetTaxRegistration")
    def to_get_tax_registration(self) -> "Tax":
        '''(experimental) Grants permission to view tax registrations data.

        Access Level: Read

        :stability: experimental
        '''
        return typing.cast("Tax", jsii.invoke(self, "toGetTaxRegistration", []))

    @jsii.member(jsii_name="toPutTaxInterview")
    def to_put_tax_interview(self) -> "Tax":
        '''(experimental) Grants permission to update tax interview data.

        Access Level: Write

        :stability: experimental
        '''
        return typing.cast("Tax", jsii.invoke(self, "toPutTaxInterview", []))

    @jsii.member(jsii_name="toPutTaxRegistration")
    def to_put_tax_registration(self) -> "Tax":
        '''(experimental) Grants permission to update tax registrations data.

        Access Level: Write

        :stability: experimental
        '''
        return typing.cast("Tax", jsii.invoke(self, "toPutTaxRegistration", []))

    @jsii.member(jsii_name="toUpdateExemptions")
    def to_update_exemptions(self) -> "Tax":
        '''(experimental) Grants permission to update tax exemptions data.

        Access Level: Write

        https://docs.aws.amazon.com/awsaccountbilling/latest/aboutv2/billing-permissions-ref.html#user-permissions

        :stability: experimental
        '''
        return typing.cast("Tax", jsii.invoke(self, "toUpdateExemptions", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4a8794039d9f5cbd3ecbc991bd258909d243c498c66e050c916cb50ed993da8c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5c1145fbbf21b9258d486c7ef6945cc77602d36464f702f1ff343d171685ed63)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Textract(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Textract",
):
    '''(experimental) Statement provider for service `textract <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazontextract.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `textract <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazontextract.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="toAnalyzeDocument")
    def to_analyze_document(self) -> "Textract":
        '''(experimental) Grants permission to detect instances of real-world document entities within an image provided as input.

        Access Level: Read

        Dependent actions:

        - s3:GetObject

        https://docs.aws.amazon.com/textract/latest/dg/API_AnalyzeDocument.html

        :stability: experimental
        '''
        return typing.cast("Textract", jsii.invoke(self, "toAnalyzeDocument", []))

    @jsii.member(jsii_name="toAnalyzeExpense")
    def to_analyze_expense(self) -> "Textract":
        '''(experimental) Grants permission to detect instances of real-world document entities within an image provided as input.

        Access Level: Read

        Dependent actions:

        - s3:GetObject

        https://docs.aws.amazon.com/textract/latest/dg/API_AnalyzeExpense.html

        :stability: experimental
        '''
        return typing.cast("Textract", jsii.invoke(self, "toAnalyzeExpense", []))

    @jsii.member(jsii_name="toAnalyzeID")
    def to_analyze_id(self) -> "Textract":
        '''(experimental) Grants permission to detect relevant information from identity documents provided as input.

        Access Level: Read

        Dependent actions:

        - s3:GetObject

        https://docs.aws.amazon.com/textract/latest/dg/API_AnalyzeID.html

        :stability: experimental
        '''
        return typing.cast("Textract", jsii.invoke(self, "toAnalyzeID", []))

    @jsii.member(jsii_name="toDetectDocumentText")
    def to_detect_document_text(self) -> "Textract":
        '''(experimental) Grants permission to detect text in document images.

        Access Level: Read

        Dependent actions:

        - s3:GetObject

        https://docs.aws.amazon.com/textract/latest/dg/API_DetectDocumentText.html

        :stability: experimental
        '''
        return typing.cast("Textract", jsii.invoke(self, "toDetectDocumentText", []))

    @jsii.member(jsii_name="toGetDocumentAnalysis")
    def to_get_document_analysis(self) -> "Textract":
        '''(experimental) Grants permission to return information about a document analysis job.

        Access Level: Read

        https://docs.aws.amazon.com/textract/latest/dg/API_GetDocumentAnalysis.html

        :stability: experimental
        '''
        return typing.cast("Textract", jsii.invoke(self, "toGetDocumentAnalysis", []))

    @jsii.member(jsii_name="toGetDocumentTextDetection")
    def to_get_document_text_detection(self) -> "Textract":
        '''(experimental) Grants permission to return information about a document text detection job.

        Access Level: Read

        https://docs.aws.amazon.com/textract/latest/dg/API_GetDocumentTextDetection.html

        :stability: experimental
        '''
        return typing.cast("Textract", jsii.invoke(self, "toGetDocumentTextDetection", []))

    @jsii.member(jsii_name="toGetExpenseAnalysis")
    def to_get_expense_analysis(self) -> "Textract":
        '''(experimental) Grants permission to return information about an expense analysis job.

        Access Level: Read

        https://docs.aws.amazon.com/textract/latest/dg/API_GetExpenseAnalysis.html

        :stability: experimental
        '''
        return typing.cast("Textract", jsii.invoke(self, "toGetExpenseAnalysis", []))

    @jsii.member(jsii_name="toGetLendingAnalysis")
    def to_get_lending_analysis(self) -> "Textract":
        '''(experimental) Grants permission to retrieve page-level information regarding a lending analysis job.

        Access Level: Read

        https://docs.aws.amazon.com/textract/latest/dg/API_GetLendingAnalysis.html

        :stability: experimental
        '''
        return typing.cast("Textract", jsii.invoke(self, "toGetLendingAnalysis", []))

    @jsii.member(jsii_name="toGetLendingAnalysisSummary")
    def to_get_lending_analysis_summary(self) -> "Textract":
        '''(experimental) Grants permission to retrieve summarized information regarding a lending analysis job.

        Access Level: Read

        https://docs.aws.amazon.com/textract/latest/dg/API_GetLendingAnalysisSummary.html

        :stability: experimental
        '''
        return typing.cast("Textract", jsii.invoke(self, "toGetLendingAnalysisSummary", []))

    @jsii.member(jsii_name="toStartDocumentAnalysis")
    def to_start_document_analysis(self) -> "Textract":
        '''(experimental) Grants permission to start an asynchronous job to detect instances of real-world document entities within an image or pdf provided as input.

        Access Level: Write

        Dependent actions:

        - s3:GetObject

        https://docs.aws.amazon.com/textract/latest/dg/API_StartDocumentAnalysis.html

        :stability: experimental
        '''
        return typing.cast("Textract", jsii.invoke(self, "toStartDocumentAnalysis", []))

    @jsii.member(jsii_name="toStartDocumentTextDetection")
    def to_start_document_text_detection(self) -> "Textract":
        '''(experimental) Grants permission to start an asynchronous job to detect text in document images or pdfs.

        Access Level: Write

        Dependent actions:

        - s3:GetObject

        https://docs.aws.amazon.com/textract/latest/dg/API_StartDocumentTextDetection.html

        :stability: experimental
        '''
        return typing.cast("Textract", jsii.invoke(self, "toStartDocumentTextDetection", []))

    @jsii.member(jsii_name="toStartExpenseAnalysis")
    def to_start_expense_analysis(self) -> "Textract":
        '''(experimental) Grants permission to start an asynchronous job to detect instances of invoices or receipts within an image or pdf provided as input.

        Access Level: Write

        Dependent actions:

        - s3:GetObject

        https://docs.aws.amazon.com/textract/latest/dg/API_StartExpenseAnalysis.html

        :stability: experimental
        '''
        return typing.cast("Textract", jsii.invoke(self, "toStartExpenseAnalysis", []))

    @jsii.member(jsii_name="toStartLendingAnalysis")
    def to_start_lending_analysis(self) -> "Textract":
        '''(experimental) Grants permission to start an asynchronous job for detection of entities in a lending document, takes a provided image or PDF as input.

        Access Level: Write

        Dependent actions:

        - s3:GetObject

        https://docs.aws.amazon.com/textract/latest/dg/API_StartLendingAnalysis.html

        :stability: experimental
        '''
        return typing.cast("Textract", jsii.invoke(self, "toStartLendingAnalysis", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__281226ca7d3eedb9fb426148f0e404c2f64d7e16ff1211106ec4e03bfc130ec2)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1e463d01b2abbf6df4415827351569054d191c22fd771d42d44016d3ccac1d12)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Timestream(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Timestream",
):
    '''(experimental) Statement provider for service `timestream <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazontimestream.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `timestream <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazontimestream.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onDatabase")
    def on_database(
        self,
        database_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Timestream":
        '''(experimental) Adds a resource of type database to the statement.

        https://docs.aws.amazon.com/timestream/latest/developerguide/API_Database.html

        :param database_name: - Identifier for the databaseName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bd6de4b01f2f405e38564c05eb2cf3fbbda04ee654cde1c51a3d1f7210e59983)
            check_type(argname="argument database_name", value=database_name, expected_type=type_hints["database_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Timestream", jsii.invoke(self, "onDatabase", [database_name, account, region, partition]))

    @jsii.member(jsii_name="onScheduledQuery")
    def on_scheduled_query(
        self,
        scheduled_query_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Timestream":
        '''(experimental) Adds a resource of type scheduled-query to the statement.

        https://docs.aws.amazon.com/timestream/latest/developerguide/API_ScheduledQuery.html

        :param scheduled_query_name: - Identifier for the scheduledQueryName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__08cd2bf44308e100381ec3d1d48f803278f18f60eda7a28f027b351fc05fa76f)
            check_type(argname="argument scheduled_query_name", value=scheduled_query_name, expected_type=type_hints["scheduled_query_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Timestream", jsii.invoke(self, "onScheduledQuery", [scheduled_query_name, account, region, partition]))

    @jsii.member(jsii_name="onTable")
    def on_table(
        self,
        database_name: builtins.str,
        table_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Timestream":
        '''(experimental) Adds a resource of type table to the statement.

        https://docs.aws.amazon.com/timestream/latest/developerguide/API_Table.html

        :param database_name: - Identifier for the databaseName.
        :param table_name: - Identifier for the tableName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__88e67abef72635298aa107de332c404aa4e0f45bf750e4b3ff5b24b3be454f29)
            check_type(argname="argument database_name", value=database_name, expected_type=type_hints["database_name"])
            check_type(argname="argument table_name", value=table_name, expected_type=type_hints["table_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Timestream", jsii.invoke(self, "onTable", [database_name, table_name, account, region, partition]))

    @jsii.member(jsii_name="toCancelQuery")
    def to_cancel_query(self) -> "Timestream":
        '''(experimental) Grants permission to cancel queries in your account.

        Access Level: Write

        Dependent actions:

        - timestream:DescribeEndpoints

        https://docs.aws.amazon.com/timestream/latest/developerguide/API_query_CancelQuery.html

        :stability: experimental
        '''
        return typing.cast("Timestream", jsii.invoke(self, "toCancelQuery", []))

    @jsii.member(jsii_name="toCreateDatabase")
    def to_create_database(self) -> "Timestream":
        '''(experimental) Grants permission to create a database in your account.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - timestream:DescribeEndpoints

        https://docs.aws.amazon.com/timestream/latest/developerguide/API_CreateDatabase.html

        :stability: experimental
        '''
        return typing.cast("Timestream", jsii.invoke(self, "toCreateDatabase", []))

    @jsii.member(jsii_name="toCreateScheduledQuery")
    def to_create_scheduled_query(self) -> "Timestream":
        '''(experimental) Grants permission to create a scheduled query in your account.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - iam:PassRole
        - timestream:DescribeEndpoints

        https://docs.aws.amazon.com/timestream/latest/developerguide/API_CreateScheduledQuery.html

        :stability: experimental
        '''
        return typing.cast("Timestream", jsii.invoke(self, "toCreateScheduledQuery", []))

    @jsii.member(jsii_name="toCreateTable")
    def to_create_table(self) -> "Timestream":
        '''(experimental) Grants permission to create a table in your account.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - timestream:DescribeEndpoints

        https://docs.aws.amazon.com/timestream/latest/developerguide/API_CreateTable.html

        :stability: experimental
        '''
        return typing.cast("Timestream", jsii.invoke(self, "toCreateTable", []))

    @jsii.member(jsii_name="toDeleteDatabase")
    def to_delete_database(self) -> "Timestream":
        '''(experimental) Grants permission to delete a database in your account.

        Access Level: Write

        Dependent actions:

        - timestream:DescribeEndpoints

        https://docs.aws.amazon.com/timestream/latest/developerguide/API_DeleteDatabase.html

        :stability: experimental
        '''
        return typing.cast("Timestream", jsii.invoke(self, "toDeleteDatabase", []))

    @jsii.member(jsii_name="toDeleteScheduledQuery")
    def to_delete_scheduled_query(self) -> "Timestream":
        '''(experimental) Grants permission to delete a scheduled query in your account.

        Access Level: Write

        Dependent actions:

        - timestream:DescribeEndpoints

        https://docs.aws.amazon.com/timestream/latest/developerguide/API_DeleteScheduledQuery.html

        :stability: experimental
        '''
        return typing.cast("Timestream", jsii.invoke(self, "toDeleteScheduledQuery", []))

    @jsii.member(jsii_name="toDeleteTable")
    def to_delete_table(self) -> "Timestream":
        '''(experimental) Grants permission to delete a table in your account.

        Access Level: Write

        Dependent actions:

        - timestream:DescribeEndpoints

        https://docs.aws.amazon.com/timestream/latest/developerguide/API_DeleteTable.html

        :stability: experimental
        '''
        return typing.cast("Timestream", jsii.invoke(self, "toDeleteTable", []))

    @jsii.member(jsii_name="toDescribeDatabase")
    def to_describe_database(self) -> "Timestream":
        '''(experimental) Grants permission to describe a database in your account.

        Access Level: Read

        Dependent actions:

        - timestream:DescribeEndpoints

        https://docs.aws.amazon.com/timestream/latest/developerguide/API_DescribeDatabase.html

        :stability: experimental
        '''
        return typing.cast("Timestream", jsii.invoke(self, "toDescribeDatabase", []))

    @jsii.member(jsii_name="toDescribeEndpoints")
    def to_describe_endpoints(self) -> "Timestream":
        '''(experimental) Grants permission to describe timestream endpoints.

        Access Level: List

        https://docs.aws.amazon.com/timestream/latest/developerguide/API_DescribeEndpoints.html

        :stability: experimental
        '''
        return typing.cast("Timestream", jsii.invoke(self, "toDescribeEndpoints", []))

    @jsii.member(jsii_name="toDescribeScheduledQuery")
    def to_describe_scheduled_query(self) -> "Timestream":
        '''(experimental) Grants permission to describe a scheduled query in your account.

        Access Level: Read

        Dependent actions:

        - timestream:DescribeEndpoints

        https://docs.aws.amazon.com/timestream/latest/developerguide/API_DescribeScheduledQuery.html

        :stability: experimental
        '''
        return typing.cast("Timestream", jsii.invoke(self, "toDescribeScheduledQuery", []))

    @jsii.member(jsii_name="toDescribeTable")
    def to_describe_table(self) -> "Timestream":
        '''(experimental) Grants permission to describe a table in your account.

        Access Level: Read

        Dependent actions:

        - timestream:DescribeEndpoints

        https://docs.aws.amazon.com/timestream/latest/developerguide/API_DescribeTable.html

        :stability: experimental
        '''
        return typing.cast("Timestream", jsii.invoke(self, "toDescribeTable", []))

    @jsii.member(jsii_name="toExecuteScheduledQuery")
    def to_execute_scheduled_query(self) -> "Timestream":
        '''(experimental) Grants permission to execute a scheduled query in your account.

        Access Level: Write

        Dependent actions:

        - timestream:DescribeEndpoints

        https://docs.aws.amazon.com/timestream/latest/developerguide/API_ExecuteScheduledQuery.html

        :stability: experimental
        '''
        return typing.cast("Timestream", jsii.invoke(self, "toExecuteScheduledQuery", []))

    @jsii.member(jsii_name="toGetAwsBackupStatus")
    def to_get_aws_backup_status(self) -> "Timestream":
        '''(experimental) Grants permission to get Status of a Timestream Table Backup.

        Access Level: Read

        Dependent actions:

        - timestream:DescribeEndpoints

        https://docs.aws.amazon.com/timestream/latest/developerguide/backups.html

        :stability: experimental
        '''
        return typing.cast("Timestream", jsii.invoke(self, "toGetAwsBackupStatus", []))

    @jsii.member(jsii_name="toGetAwsRestoreStatus")
    def to_get_aws_restore_status(self) -> "Timestream":
        '''(experimental) Grants permission to get Status of a Timestream Table Restore.

        Access Level: Read

        Dependent actions:

        - timestream:DescribeEndpoints

        https://docs.aws.amazon.com/timestream/latest/developerguide/backups.html

        :stability: experimental
        '''
        return typing.cast("Timestream", jsii.invoke(self, "toGetAwsRestoreStatus", []))

    @jsii.member(jsii_name="toListDatabases")
    def to_list_databases(self) -> "Timestream":
        '''(experimental) Grants permission to list databases in your account.

        Access Level: List

        Dependent actions:

        - timestream:DescribeEndpoints

        https://docs.aws.amazon.com/timestream/latest/developerguide/API_ListDatabases.html

        :stability: experimental
        '''
        return typing.cast("Timestream", jsii.invoke(self, "toListDatabases", []))

    @jsii.member(jsii_name="toListMeasures")
    def to_list_measures(self) -> "Timestream":
        '''(experimental) Grants permission to list measures of a table in your account.

        Access Level: List

        Dependent actions:

        - timestream:DescribeEndpoints

        https://docs.aws.amazon.com/timestream/latest/developerguide/API_query_Query.html

        :stability: experimental
        '''
        return typing.cast("Timestream", jsii.invoke(self, "toListMeasures", []))

    @jsii.member(jsii_name="toListScheduledQueries")
    def to_list_scheduled_queries(self) -> "Timestream":
        '''(experimental) Grants permission to list scheduled queries in your account.

        Access Level: List

        Dependent actions:

        - timestream:DescribeEndpoints

        https://docs.aws.amazon.com/timestream/latest/developerguide/API_ListScheduledQueries.html

        :stability: experimental
        '''
        return typing.cast("Timestream", jsii.invoke(self, "toListScheduledQueries", []))

    @jsii.member(jsii_name="toListTables")
    def to_list_tables(self) -> "Timestream":
        '''(experimental) Grants permission to list tables in your account.

        Access Level: List

        Dependent actions:

        - timestream:DescribeEndpoints

        https://docs.aws.amazon.com/timestream/latest/developerguide/API_ListTables.html

        :stability: experimental
        '''
        return typing.cast("Timestream", jsii.invoke(self, "toListTables", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Timestream":
        '''(experimental) Grants permission to list tags of a resource in your account.

        Access Level: Read

        Dependent actions:

        - timestream:DescribeEndpoints

        https://docs.aws.amazon.com/timestream/latest/developerguide/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("Timestream", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toPrepareQuery")
    def to_prepare_query(self) -> "Timestream":
        '''(experimental) Grants permission to issue prepare queries.

        Access Level: Read

        Dependent actions:

        - timestream:DescribeEndpoints
        - timestream:Select

        https://docs.aws.amazon.com/timestream/latest/developerguide/API_query_PrepareQuery.html

        :stability: experimental
        '''
        return typing.cast("Timestream", jsii.invoke(self, "toPrepareQuery", []))

    @jsii.member(jsii_name="toSelect")
    def to_select(self) -> "Timestream":
        '''(experimental) Grants permission to issue 'select from table' queries.

        Access Level: Read

        Dependent actions:

        - timestream:DescribeEndpoints

        https://docs.aws.amazon.com/timestream/latest/developerguide/API_query_Query.html

        :stability: experimental
        '''
        return typing.cast("Timestream", jsii.invoke(self, "toSelect", []))

    @jsii.member(jsii_name="toSelectValues")
    def to_select_values(self) -> "Timestream":
        '''(experimental) Grants permission to issue 'select 1' queries.

        Access Level: Read

        Dependent actions:

        - timestream:DescribeEndpoints

        https://docs.aws.amazon.com/timestream/latest/developerguide/API_query_Query.html

        :stability: experimental
        '''
        return typing.cast("Timestream", jsii.invoke(self, "toSelectValues", []))

    @jsii.member(jsii_name="toStartAwsBackupJob")
    def to_start_aws_backup_job(self) -> "Timestream":
        '''(experimental) Grants permission to start a Backup Job for a Timestream Table.

        Access Level: Write

        Dependent actions:

        - timestream:DescribeEndpoints

        https://docs.aws.amazon.com/timestream/latest/developerguide/backups.html

        :stability: experimental
        '''
        return typing.cast("Timestream", jsii.invoke(self, "toStartAwsBackupJob", []))

    @jsii.member(jsii_name="toStartAwsRestoreJob")
    def to_start_aws_restore_job(self) -> "Timestream":
        '''(experimental) Grants permission to start Restore Job for a Backup of Timestream Table.

        Access Level: Write

        Dependent actions:

        - timestream:DescribeEndpoints

        https://docs.aws.amazon.com/timestream/latest/developerguide/backups.html

        :stability: experimental
        '''
        return typing.cast("Timestream", jsii.invoke(self, "toStartAwsRestoreJob", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Timestream":
        '''(experimental) Grants permission to add tags to a resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - timestream:DescribeEndpoints

        https://docs.aws.amazon.com/timestream/latest/developerguide/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("Timestream", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Timestream":
        '''(experimental) Grants permission to remove a tag from a resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        Dependent actions:

        - timestream:DescribeEndpoints

        https://docs.aws.amazon.com/timestream/latest/developerguide/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("Timestream", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateDatabase")
    def to_update_database(self) -> "Timestream":
        '''(experimental) Grants permission to update a database in your account.

        Access Level: Write

        Dependent actions:

        - timestream:DescribeEndpoints

        https://docs.aws.amazon.com/timestream/latest/developerguide/API_UpdateDatabase.html

        :stability: experimental
        '''
        return typing.cast("Timestream", jsii.invoke(self, "toUpdateDatabase", []))

    @jsii.member(jsii_name="toUpdateScheduledQuery")
    def to_update_scheduled_query(self) -> "Timestream":
        '''(experimental) Grants permission to update a scheduled query in your account.

        Access Level: Write

        Dependent actions:

        - timestream:DescribeEndpoints

        https://docs.aws.amazon.com/timestream/latest/developerguide/API_UpdateScheduledQuery.html

        :stability: experimental
        '''
        return typing.cast("Timestream", jsii.invoke(self, "toUpdateScheduledQuery", []))

    @jsii.member(jsii_name="toUpdateTable")
    def to_update_table(self) -> "Timestream":
        '''(experimental) Grants permission to update a table in your account.

        Access Level: Write

        Dependent actions:

        - timestream:DescribeEndpoints

        https://docs.aws.amazon.com/timestream/latest/developerguide/API_UpdateTable.html

        :stability: experimental
        '''
        return typing.cast("Timestream", jsii.invoke(self, "toUpdateTable", []))

    @jsii.member(jsii_name="toWriteRecords")
    def to_write_records(self) -> "Timestream":
        '''(experimental) Grants permission to ingest data to a table in your account.

        Access Level: Write

        Dependent actions:

        - timestream:DescribeEndpoints

        https://docs.aws.amazon.com/timestream/latest/developerguide/API_WriteRecords.html

        :stability: experimental
        '''
        return typing.cast("Timestream", jsii.invoke(self, "toWriteRecords", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7cd784726e2e4bee6ddb98b9c640ac0ef8a1a10a95e3fbd48b7d1407661c1a1a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fb967273513b19347b3b9038a5d9787f818d66067e319b59fc887b90a6c0b7e4)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Tiros(PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Tiros"):
    '''(experimental) Statement provider for service `tiros <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awstiros.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `tiros <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awstiros.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="toCreateQuery")
    def to_create_query(self) -> "Tiros":
        '''(experimental) Grants permission to create a VPC reachability query.

        Access Level: Write

        https://docs.aws.amazon.com/vpc/latest/reachability/security_iam_required-API-permissions.html

        :stability: experimental
        '''
        return typing.cast("Tiros", jsii.invoke(self, "toCreateQuery", []))

    @jsii.member(jsii_name="toExtendQuery")
    def to_extend_query(self) -> "Tiros":
        '''(experimental) Grants permission to extend a VPC reachability query to include the calling principals account.

        Access Level: Write

        https://docs.aws.amazon.com/vpc/latest/reachability/security_iam_required-API-permissions.html

        :stability: experimental
        '''
        return typing.cast("Tiros", jsii.invoke(self, "toExtendQuery", []))

    @jsii.member(jsii_name="toGetQueryAnswer")
    def to_get_query_answer(self) -> "Tiros":
        '''(experimental) Grants permission to get VPC reachability query answers.

        Access Level: Read

        https://docs.aws.amazon.com/vpc/latest/reachability/security_iam_required-API-permissions.html

        :stability: experimental
        '''
        return typing.cast("Tiros", jsii.invoke(self, "toGetQueryAnswer", []))

    @jsii.member(jsii_name="toGetQueryExplanation")
    def to_get_query_explanation(self) -> "Tiros":
        '''(experimental) Grants permission to get VPC reachability query explanations.

        Access Level: Read

        https://docs.aws.amazon.com/vpc/latest/reachability/security_iam_required-API-permissions.html

        :stability: experimental
        '''
        return typing.cast("Tiros", jsii.invoke(self, "toGetQueryExplanation", []))

    @jsii.member(jsii_name="toGetQueryExtensionAccounts")
    def to_get_query_extension_accounts(self) -> "Tiros":
        '''(experimental) Grants permission to list accounts that might be useful in a new query.

        Access Level: Read

        https://docs.aws.amazon.com/vpc/latest/reachability/security_iam_required-API-permissions.html

        :stability: experimental
        '''
        return typing.cast("Tiros", jsii.invoke(self, "toGetQueryExtensionAccounts", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__526d91622ccaa78ffd22e10d149f43b781918e61b02e94a8fd1a50e3268a13dc)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__cb99ea2b44d37b314d7038aa201e2c078ef7ce25781358208cf162b1174c6a70)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Transcribe(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Transcribe",
):
    '''(experimental) Statement provider for service `transcribe <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazontranscribe.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `transcribe <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazontranscribe.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="ifOutputBucketName")
    def if_output_bucket_name(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Transcribe":
        '''(experimental) Filters access based on the output bucket name included in the request.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazontranscribe.html#amazontranscribe-policy-keys

        Applies to actions:

        - .toStartMedicalTranscriptionJob()
        - .toStartTranscriptionJob()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3fc61e29a026e3641c460043d79e8ca9621f5e59aa4cba6823f629d68b74a810)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Transcribe", jsii.invoke(self, "ifOutputBucketName", [value, operator]))

    @jsii.member(jsii_name="ifOutputEncryptionKMSKeyId")
    def if_output_encryption_kms_key_id(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Transcribe":
        '''(experimental) Filters access based on the KMS key id included in the request.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazontranscribe.html#amazontranscribe-policy-keys

        Applies to actions:

        - .toStartCallAnalyticsJob()
        - .toStartMedicalTranscriptionJob()
        - .toStartTranscriptionJob()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__283d530f340124ace9020096f553f3d66c3524de24112d74a5174dc9d6ddd2d7)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Transcribe", jsii.invoke(self, "ifOutputEncryptionKMSKeyId", [value, operator]))

    @jsii.member(jsii_name="ifOutputKey")
    def if_output_key(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Transcribe":
        '''(experimental) Filters access based on the output key included in the request.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazontranscribe.html#amazontranscribe-policy-keys

        Applies to actions:

        - .toStartMedicalTranscriptionJob()
        - .toStartTranscriptionJob()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__97b238bfa538feb503808c891ae95ae690c44ba8eee239f002ac705694b4a415)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Transcribe", jsii.invoke(self, "ifOutputKey", [value, operator]))

    @jsii.member(jsii_name="ifOutputLocation")
    def if_output_location(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Transcribe":
        '''(experimental) Filters access based on the output location included in the request.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazontranscribe.html#amazontranscribe-policy-keys

        Applies to actions:

        - .toStartCallAnalyticsJob()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__372d9c16a061517a537b0017740c5397824c639166d71f9424ca4a93629e864b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Transcribe", jsii.invoke(self, "ifOutputLocation", [value, operator]))

    @jsii.member(jsii_name="onCallanalyticscategory")
    def on_callanalyticscategory(
        self,
        category_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Transcribe":
        '''(experimental) Adds a resource of type callanalyticscategory to the statement.

        https://docs.aws.amazon.com/transcribe/latest/dg/API_CreateCallAnalyticsCategory.html

        :param category_name: - Identifier for the categoryName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fd65af44c4ac29bd3d663c01c2273bb2ea0894bb46ff020f2152d53c1e209e9a)
            check_type(argname="argument category_name", value=category_name, expected_type=type_hints["category_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Transcribe", jsii.invoke(self, "onCallanalyticscategory", [category_name, account, region, partition]))

    @jsii.member(jsii_name="onCallanalyticsjob")
    def on_callanalyticsjob(
        self,
        job_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Transcribe":
        '''(experimental) Adds a resource of type callanalyticsjob to the statement.

        https://docs.aws.amazon.com/transcribe/latest/dg/API_CallAnalyticsJob.html

        :param job_name: - Identifier for the jobName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__10879745cb2d4050d8b79f544bc3538071e4e7f30bfdb477bee39920769d16df)
            check_type(argname="argument job_name", value=job_name, expected_type=type_hints["job_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Transcribe", jsii.invoke(self, "onCallanalyticsjob", [job_name, account, region, partition]))

    @jsii.member(jsii_name="onLanguagemodel")
    def on_languagemodel(
        self,
        model_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Transcribe":
        '''(experimental) Adds a resource of type languagemodel to the statement.

        https://docs.aws.amazon.com/transcribe/latest/dg/API_LanguageModel.html

        :param model_name: - Identifier for the modelName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5c500bbb3d7b4186eeb032c344fd463a0ffbeddbbf6eeda2d8a6bc46269374c5)
            check_type(argname="argument model_name", value=model_name, expected_type=type_hints["model_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Transcribe", jsii.invoke(self, "onLanguagemodel", [model_name, account, region, partition]))

    @jsii.member(jsii_name="onMedicaltranscriptionjob")
    def on_medicaltranscriptionjob(
        self,
        job_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Transcribe":
        '''(experimental) Adds a resource of type medicaltranscriptionjob to the statement.

        https://docs.aws.amazon.com/transcribe/latest/dg/API_MedicalTranscriptionJob.html

        :param job_name: - Identifier for the jobName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fe9db20a4cc2cd5b23eb2559e16f1b5272009c598af0b09b643073b847085135)
            check_type(argname="argument job_name", value=job_name, expected_type=type_hints["job_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Transcribe", jsii.invoke(self, "onMedicaltranscriptionjob", [job_name, account, region, partition]))

    @jsii.member(jsii_name="onMedicalvocabulary")
    def on_medicalvocabulary(
        self,
        vocabulary_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Transcribe":
        '''(experimental) Adds a resource of type medicalvocabulary to the statement.

        https://docs.aws.amazon.com/transcribe/latest/dg/API_CreateMedicalVocabulary.html

        :param vocabulary_name: - Identifier for the vocabularyName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0b30fec53aaee1fb040b5684caeb65126c8089f67807ad64274ef1855e1f94bd)
            check_type(argname="argument vocabulary_name", value=vocabulary_name, expected_type=type_hints["vocabulary_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Transcribe", jsii.invoke(self, "onMedicalvocabulary", [vocabulary_name, account, region, partition]))

    @jsii.member(jsii_name="onTranscriptionjob")
    def on_transcriptionjob(
        self,
        job_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Transcribe":
        '''(experimental) Adds a resource of type transcriptionjob to the statement.

        https://docs.aws.amazon.com/transcribe/latest/dg/API_TranscriptionJob.html

        :param job_name: - Identifier for the jobName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4084182fb6e01dd19be61cea182c62137dfed2d63cc8e23f5f4e05124c846828)
            check_type(argname="argument job_name", value=job_name, expected_type=type_hints["job_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Transcribe", jsii.invoke(self, "onTranscriptionjob", [job_name, account, region, partition]))

    @jsii.member(jsii_name="onVocabulary")
    def on_vocabulary(
        self,
        vocabulary_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Transcribe":
        '''(experimental) Adds a resource of type vocabulary to the statement.

        https://docs.aws.amazon.com/transcribe/latest/dg/API_CreateVocabulary.html

        :param vocabulary_name: - Identifier for the vocabularyName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__463d7297a037423180e4da381cd677a6ec337d93a13e93e8afb4b5e4ebfe089e)
            check_type(argname="argument vocabulary_name", value=vocabulary_name, expected_type=type_hints["vocabulary_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Transcribe", jsii.invoke(self, "onVocabulary", [vocabulary_name, account, region, partition]))

    @jsii.member(jsii_name="onVocabularyfilter")
    def on_vocabularyfilter(
        self,
        vocabulary_filter_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Transcribe":
        '''(experimental) Adds a resource of type vocabularyfilter to the statement.

        https://docs.aws.amazon.com/transcribe/latest/dg/API_CreateVocabularyFilter.html

        :param vocabulary_filter_name: - Identifier for the vocabularyFilterName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7426913f354b5fd3aab9b67fb03b80fda07def73c97480e51ccc56eebce2af61)
            check_type(argname="argument vocabulary_filter_name", value=vocabulary_filter_name, expected_type=type_hints["vocabulary_filter_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Transcribe", jsii.invoke(self, "onVocabularyfilter", [vocabulary_filter_name, account, region, partition]))

    @jsii.member(jsii_name="toCreateCallAnalyticsCategory")
    def to_create_call_analytics_category(self) -> "Transcribe":
        '''(experimental) Grants permission to create an analytics category.

        Amazon Transcribe applies the conditions specified by your analytics categories to your call analytics jobs

        Access Level: Write

        https://docs.aws.amazon.com/transcribe/latest/dg/API_CreateCallAnalyticsCategory.html

        :stability: experimental
        '''
        return typing.cast("Transcribe", jsii.invoke(self, "toCreateCallAnalyticsCategory", []))

    @jsii.member(jsii_name="toCreateLanguageModel")
    def to_create_language_model(self) -> "Transcribe":
        '''(experimental) Grants permission to create a new custom language model.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - s3:GetObject
        - s3:ListBucket

        https://docs.aws.amazon.com/transcribe/latest/dg/API_CreateLanguageModel.html

        :stability: experimental
        '''
        return typing.cast("Transcribe", jsii.invoke(self, "toCreateLanguageModel", []))

    @jsii.member(jsii_name="toCreateMedicalVocabulary")
    def to_create_medical_vocabulary(self) -> "Transcribe":
        '''(experimental) Grants permission to create a new custom vocabulary that you can use to change the way Amazon Transcribe Medical handles transcription of an audio file.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - s3:GetObject

        https://docs.aws.amazon.com/transcribe/latest/dg/API_CreateMedicalVocabulary.html

        :stability: experimental
        '''
        return typing.cast("Transcribe", jsii.invoke(self, "toCreateMedicalVocabulary", []))

    @jsii.member(jsii_name="toCreateVocabulary")
    def to_create_vocabulary(self) -> "Transcribe":
        '''(experimental) Grants permission to create a new custom vocabulary that you can use to change the way Amazon Transcribe handles transcription of an audio file.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - s3:GetObject

        https://docs.aws.amazon.com/transcribe/latest/dg/API_CreateVocabulary.html

        :stability: experimental
        '''
        return typing.cast("Transcribe", jsii.invoke(self, "toCreateVocabulary", []))

    @jsii.member(jsii_name="toCreateVocabularyFilter")
    def to_create_vocabulary_filter(self) -> "Transcribe":
        '''(experimental) Grants permission to create a new vocabulary filter that you can use to filter out words from the transcription of an audio file generated by Amazon Transcribe.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - s3:GetObject

        https://docs.aws.amazon.com/transcribe/latest/dg/API_CreateVocabularyFilter.html

        :stability: experimental
        '''
        return typing.cast("Transcribe", jsii.invoke(self, "toCreateVocabularyFilter", []))

    @jsii.member(jsii_name="toDeleteCallAnalyticsCategory")
    def to_delete_call_analytics_category(self) -> "Transcribe":
        '''(experimental) Grants permission to delete a call analytics category using its name from Amazon Transcribe.

        Access Level: Write

        https://docs.aws.amazon.com/transcribe/latest/dg/API_DeleteCallAnalyticsCategory.html

        :stability: experimental
        '''
        return typing.cast("Transcribe", jsii.invoke(self, "toDeleteCallAnalyticsCategory", []))

    @jsii.member(jsii_name="toDeleteCallAnalyticsJob")
    def to_delete_call_analytics_job(self) -> "Transcribe":
        '''(experimental) Grants permission to delete a previously submitted call analytics job along with any other generated results such as the transcription, models, and so on.

        Access Level: Write

        https://docs.aws.amazon.com/transcribe/latest/dg/API_DeleteCallAnalyticsJob.html

        :stability: experimental
        '''
        return typing.cast("Transcribe", jsii.invoke(self, "toDeleteCallAnalyticsJob", []))

    @jsii.member(jsii_name="toDeleteLanguageModel")
    def to_delete_language_model(self) -> "Transcribe":
        '''(experimental) Grants permission to delete a previously created custom language model.

        Access Level: Write

        https://docs.aws.amazon.com/transcribe/latest/dg/API_DeleteLanguageModel.html

        :stability: experimental
        '''
        return typing.cast("Transcribe", jsii.invoke(self, "toDeleteLanguageModel", []))

    @jsii.member(jsii_name="toDeleteMedicalTranscriptionJob")
    def to_delete_medical_transcription_job(self) -> "Transcribe":
        '''(experimental) Grants permission to delete a previously submitted medical transcription job.

        Access Level: Write

        https://docs.aws.amazon.com/transcribe/latest/dg/API_DeleteMedicalTranscriptionJob.html

        :stability: experimental
        '''
        return typing.cast("Transcribe", jsii.invoke(self, "toDeleteMedicalTranscriptionJob", []))

    @jsii.member(jsii_name="toDeleteMedicalVocabulary")
    def to_delete_medical_vocabulary(self) -> "Transcribe":
        '''(experimental) Grants permission to delete a medical vocabulary from Amazon Transcribe.

        Access Level: Write

        https://docs.aws.amazon.com/transcribe/latest/dg/API_DeleteMedicalVocabulary.html

        :stability: experimental
        '''
        return typing.cast("Transcribe", jsii.invoke(self, "toDeleteMedicalVocabulary", []))

    @jsii.member(jsii_name="toDeleteTranscriptionJob")
    def to_delete_transcription_job(self) -> "Transcribe":
        '''(experimental) Grants permission to delete a previously submitted transcription job along with any other generated results such as the transcription, models, and so on.

        Access Level: Write

        https://docs.aws.amazon.com/transcribe/latest/dg/API_DeleteTranscriptionJob.html

        :stability: experimental
        '''
        return typing.cast("Transcribe", jsii.invoke(self, "toDeleteTranscriptionJob", []))

    @jsii.member(jsii_name="toDeleteVocabulary")
    def to_delete_vocabulary(self) -> "Transcribe":
        '''(experimental) Grants permission to delete a vocabulary from Amazon Transcribe.

        Access Level: Write

        https://docs.aws.amazon.com/transcribe/latest/dg/API_DeleteVocabulary.html

        :stability: experimental
        '''
        return typing.cast("Transcribe", jsii.invoke(self, "toDeleteVocabulary", []))

    @jsii.member(jsii_name="toDeleteVocabularyFilter")
    def to_delete_vocabulary_filter(self) -> "Transcribe":
        '''(experimental) Grants permission to delete a vocabulary filter from Amazon Transcribe.

        Access Level: Write

        https://docs.aws.amazon.com/transcribe/latest/dg/API_DeleteVocabularyFilter.html

        :stability: experimental
        '''
        return typing.cast("Transcribe", jsii.invoke(self, "toDeleteVocabularyFilter", []))

    @jsii.member(jsii_name="toDescribeLanguageModel")
    def to_describe_language_model(self) -> "Transcribe":
        '''(experimental) Grants permission to return information about a custom language model.

        Access Level: Read

        https://docs.aws.amazon.com/transcribe/latest/dg/API_DescribeLanguageModel.html

        :stability: experimental
        '''
        return typing.cast("Transcribe", jsii.invoke(self, "toDescribeLanguageModel", []))

    @jsii.member(jsii_name="toGetCallAnalyticsCategory")
    def to_get_call_analytics_category(self) -> "Transcribe":
        '''(experimental) Grants permission to retrieve information about a call analytics category.

        Access Level: Read

        https://docs.aws.amazon.com/transcribe/latest/dg/API_GetCallAnalyticsCategory.html

        :stability: experimental
        '''
        return typing.cast("Transcribe", jsii.invoke(self, "toGetCallAnalyticsCategory", []))

    @jsii.member(jsii_name="toGetCallAnalyticsJob")
    def to_get_call_analytics_job(self) -> "Transcribe":
        '''(experimental) Grants permission to return information about a call analytics job.

        Access Level: Read

        https://docs.aws.amazon.com/transcribe/latest/dg/API_GetCallAnalyticsJob.html

        :stability: experimental
        '''
        return typing.cast("Transcribe", jsii.invoke(self, "toGetCallAnalyticsJob", []))

    @jsii.member(jsii_name="toGetMedicalTranscriptionJob")
    def to_get_medical_transcription_job(self) -> "Transcribe":
        '''(experimental) Grants permission to return information about a medical transcription job.

        Access Level: Read

        https://docs.aws.amazon.com/transcribe/latest/dg/API_GetMedicalTranscriptionJob.html

        :stability: experimental
        '''
        return typing.cast("Transcribe", jsii.invoke(self, "toGetMedicalTranscriptionJob", []))

    @jsii.member(jsii_name="toGetMedicalVocabulary")
    def to_get_medical_vocabulary(self) -> "Transcribe":
        '''(experimental) Grants permission to get information about a medical vocabulary.

        Access Level: Read

        https://docs.aws.amazon.com/transcribe/latest/dg/API_GetMedicalVocabulary.html

        :stability: experimental
        '''
        return typing.cast("Transcribe", jsii.invoke(self, "toGetMedicalVocabulary", []))

    @jsii.member(jsii_name="toGetTranscriptionJob")
    def to_get_transcription_job(self) -> "Transcribe":
        '''(experimental) Grants permission to return information about a transcription job.

        Access Level: Read

        https://docs.aws.amazon.com/transcribe/latest/dg/API_GetTranscriptionJob.html

        :stability: experimental
        '''
        return typing.cast("Transcribe", jsii.invoke(self, "toGetTranscriptionJob", []))

    @jsii.member(jsii_name="toGetVocabulary")
    def to_get_vocabulary(self) -> "Transcribe":
        '''(experimental) Grants permission to to get information about a vocabulary.

        Access Level: Read

        https://docs.aws.amazon.com/transcribe/latest/dg/API_GetVocabulary.html

        :stability: experimental
        '''
        return typing.cast("Transcribe", jsii.invoke(self, "toGetVocabulary", []))

    @jsii.member(jsii_name="toGetVocabularyFilter")
    def to_get_vocabulary_filter(self) -> "Transcribe":
        '''(experimental) Grants permission to get information about a vocabulary filter.

        Access Level: Read

        https://docs.aws.amazon.com/transcribe/latest/dg/API_GetVocabularyFilter.html

        :stability: experimental
        '''
        return typing.cast("Transcribe", jsii.invoke(self, "toGetVocabularyFilter", []))

    @jsii.member(jsii_name="toListCallAnalyticsCategories")
    def to_list_call_analytics_categories(self) -> "Transcribe":
        '''(experimental) Grants permission to list call analytics categories that has been created.

        Access Level: List

        https://docs.aws.amazon.com/transcribe/latest/dg/API_ListCallAnalyticsCategories.html

        :stability: experimental
        '''
        return typing.cast("Transcribe", jsii.invoke(self, "toListCallAnalyticsCategories", []))

    @jsii.member(jsii_name="toListCallAnalyticsJobs")
    def to_list_call_analytics_jobs(self) -> "Transcribe":
        '''(experimental) Grants permission to list call analytics jobs with the specified status.

        Access Level: List

        https://docs.aws.amazon.com/transcribe/latest/dg/API_ListCallAnalyticsJobs.html

        :stability: experimental
        '''
        return typing.cast("Transcribe", jsii.invoke(self, "toListCallAnalyticsJobs", []))

    @jsii.member(jsii_name="toListLanguageModels")
    def to_list_language_models(self) -> "Transcribe":
        '''(experimental) Grants permission to list custom language models.

        Access Level: List

        https://docs.aws.amazon.com/transcribe/latest/dg/API_ListLanguageModels.html

        :stability: experimental
        '''
        return typing.cast("Transcribe", jsii.invoke(self, "toListLanguageModels", []))

    @jsii.member(jsii_name="toListMedicalTranscriptionJobs")
    def to_list_medical_transcription_jobs(self) -> "Transcribe":
        '''(experimental) Grants permission to list medical transcription jobs with the specified status.

        Access Level: List

        https://docs.aws.amazon.com/transcribe/latest/dg/API_ListMedicalTranscriptionJobs.html

        :stability: experimental
        '''
        return typing.cast("Transcribe", jsii.invoke(self, "toListMedicalTranscriptionJobs", []))

    @jsii.member(jsii_name="toListMedicalVocabularies")
    def to_list_medical_vocabularies(self) -> "Transcribe":
        '''(experimental) Grants permission to return a list of medical vocabularies that match the specified criteria.

        If no criteria are specified, returns the entire list of vocabularies

        Access Level: List

        https://docs.aws.amazon.com/transcribe/latest/dg/API_ListMedicalVocabularies.html

        :stability: experimental
        '''
        return typing.cast("Transcribe", jsii.invoke(self, "toListMedicalVocabularies", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Transcribe":
        '''(experimental) Grants permission to list tags for a resource.

        Access Level: Read

        https://docs.aws.amazon.com/transcribe/latest/dg/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("Transcribe", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toListTranscriptionJobs")
    def to_list_transcription_jobs(self) -> "Transcribe":
        '''(experimental) Grants permission to list transcription jobs with the specified status.

        Access Level: List

        https://docs.aws.amazon.com/transcribe/latest/dg/API_ListTranscriptionJobs.html

        :stability: experimental
        '''
        return typing.cast("Transcribe", jsii.invoke(self, "toListTranscriptionJobs", []))

    @jsii.member(jsii_name="toListVocabularies")
    def to_list_vocabularies(self) -> "Transcribe":
        '''(experimental) Grants permission to return a list of vocabularies that match the specified criteria.

        If no criteria are specified, returns the entire list of vocabularies

        Access Level: List

        https://docs.aws.amazon.com/transcribe/latest/dg/API_ListVocabularies.html

        :stability: experimental
        '''
        return typing.cast("Transcribe", jsii.invoke(self, "toListVocabularies", []))

    @jsii.member(jsii_name="toListVocabularyFilters")
    def to_list_vocabulary_filters(self) -> "Transcribe":
        '''(experimental) Grants permission to return a list of vocabulary filters that match the specified criteria.

        If no criteria are specified, returns the at most 5 vocabulary filters

        Access Level: List

        https://docs.aws.amazon.com/transcribe/latest/dg/API_ListVocabularyFilters.html

        :stability: experimental
        '''
        return typing.cast("Transcribe", jsii.invoke(self, "toListVocabularyFilters", []))

    @jsii.member(jsii_name="toStartCallAnalyticsJob")
    def to_start_call_analytics_job(self) -> "Transcribe":
        '''(experimental) Grants permission to start an asynchronous analytics job that not only transcribes the audio recording of a caller and agent, but also returns additional insights.

        Access Level: Write

        Possible conditions:

        - .ifOutputEncryptionKMSKeyId()
        - .ifOutputLocation()

        Dependent actions:

        - s3:GetObject

        https://docs.aws.amazon.com/transcribe/latest/dg/API_StartCallAnalyticsJob.html

        :stability: experimental
        '''
        return typing.cast("Transcribe", jsii.invoke(self, "toStartCallAnalyticsJob", []))

    @jsii.member(jsii_name="toStartCallAnalyticsStreamTranscription")
    def to_start_call_analytics_stream_transcription(self) -> "Transcribe":
        '''(experimental) Grants permission to start a protocol where audio is streamed to Transcribe Call Analytics and the transcription results are streamed to your application.

        Access Level: Write

        https://docs.aws.amazon.com/transcribe/latest/dg/API_streaming_StartCallAnalyticsStreamTranscription.html

        :stability: experimental
        '''
        return typing.cast("Transcribe", jsii.invoke(self, "toStartCallAnalyticsStreamTranscription", []))

    @jsii.member(jsii_name="toStartCallAnalyticsStreamTranscriptionWebSocket")
    def to_start_call_analytics_stream_transcription_web_socket(self) -> "Transcribe":
        '''(experimental) Grants permission to start a WebSocket where audio is streamed to Transcribe Call Analytics and the transcription results are streamed to your application.

        Access Level: Write

        https://docs.aws.amazon.com/transcribe/latest/dg/API_streaming_StartCallAnalyticsStreamTranscriptionWebSocket.html

        :stability: experimental
        '''
        return typing.cast("Transcribe", jsii.invoke(self, "toStartCallAnalyticsStreamTranscriptionWebSocket", []))

    @jsii.member(jsii_name="toStartMedicalStreamTranscription")
    def to_start_medical_stream_transcription(self) -> "Transcribe":
        '''(experimental) Grants permission to start a protocol where audio is streamed to Transcribe Medical and the transcription results are streamed to your application.

        Access Level: Write

        https://docs.aws.amazon.com/transcribe/latest/dg/API_streaming_StartMedicalStreamTranscription.html

        :stability: experimental
        '''
        return typing.cast("Transcribe", jsii.invoke(self, "toStartMedicalStreamTranscription", []))

    @jsii.member(jsii_name="toStartMedicalStreamTranscriptionWebSocket")
    def to_start_medical_stream_transcription_web_socket(self) -> "Transcribe":
        '''(experimental) Grants permission to start a WebSocket where audio is streamed to Transcribe Medical and the transcription results are streamed to your application.

        Access Level: Write

        https://docs.aws.amazon.com/transcribe/latest/dg/API_streaming_StartMedicalStreamTranscriptionWebSocket.html

        :stability: experimental
        '''
        return typing.cast("Transcribe", jsii.invoke(self, "toStartMedicalStreamTranscriptionWebSocket", []))

    @jsii.member(jsii_name="toStartMedicalTranscriptionJob")
    def to_start_medical_transcription_job(self) -> "Transcribe":
        '''(experimental) Grants permission to start an asynchronous job to transcribe medical speech to text.

        Access Level: Write

        Possible conditions:

        - .ifOutputBucketName()
        - .ifOutputEncryptionKMSKeyId()
        - .ifOutputKey()
        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - s3:GetObject

        https://docs.aws.amazon.com/transcribe/latest/dg/API_StartMedicalTranscriptionJob.html

        :stability: experimental
        '''
        return typing.cast("Transcribe", jsii.invoke(self, "toStartMedicalTranscriptionJob", []))

    @jsii.member(jsii_name="toStartStreamTranscription")
    def to_start_stream_transcription(self) -> "Transcribe":
        '''(experimental) Grants permission to start a bidirectional HTTP2 stream to transcribe speech to text in real time.

        Access Level: Write

        https://docs.aws.amazon.com/transcribe/latest/dg/API_streaming_StartStreamTranscription.html

        :stability: experimental
        '''
        return typing.cast("Transcribe", jsii.invoke(self, "toStartStreamTranscription", []))

    @jsii.member(jsii_name="toStartStreamTranscriptionWebSocket")
    def to_start_stream_transcription_web_socket(self) -> "Transcribe":
        '''(experimental) Grants permission to start a websocket stream to transcribe speech to text in real time.

        Access Level: Write

        https://docs.aws.amazon.com/transcribe/latest/dg/API_streaming_StartStreamTranscriptionWebSocket.html

        :stability: experimental
        '''
        return typing.cast("Transcribe", jsii.invoke(self, "toStartStreamTranscriptionWebSocket", []))

    @jsii.member(jsii_name="toStartTranscriptionJob")
    def to_start_transcription_job(self) -> "Transcribe":
        '''(experimental) Grants permission to start an asynchronous job to transcribe speech to text.

        Access Level: Write

        Possible conditions:

        - .ifOutputBucketName()
        - .ifOutputEncryptionKMSKeyId()
        - .ifOutputKey()
        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - s3:GetObject

        https://docs.aws.amazon.com/transcribe/latest/dg/API_StartTranscriptionJob.html

        :stability: experimental
        '''
        return typing.cast("Transcribe", jsii.invoke(self, "toStartTranscriptionJob", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Transcribe":
        '''(experimental) Grants permission to tag a resource with given key value pairs.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/transcribe/latest/dg/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("Transcribe", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Transcribe":
        '''(experimental) Grants permission to untag a resource with given key.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/transcribe/latest/dg/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("Transcribe", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateCallAnalyticsCategory")
    def to_update_call_analytics_category(self) -> "Transcribe":
        '''(experimental) Grants permission to update the call analytics category with new values.

        The UpdateCallAnalyticsCategory operation overwrites all of the existing information with the values that you provide in the request

        Access Level: Write

        https://docs.aws.amazon.com/transcribe/latest/dg/API_UpdateCallAnalyticsCategory.html

        :stability: experimental
        '''
        return typing.cast("Transcribe", jsii.invoke(self, "toUpdateCallAnalyticsCategory", []))

    @jsii.member(jsii_name="toUpdateMedicalVocabulary")
    def to_update_medical_vocabulary(self) -> "Transcribe":
        '''(experimental) Grants permission to update an existing medical vocabulary with new values.

        The UpdateMedicalVocabulary operation overwrites all of the existing information with the values that you provide in the request

        Access Level: Write

        Dependent actions:

        - s3:GetObject

        https://docs.aws.amazon.com/transcribe/latest/dg/API_UpdateMedicalVocabulary.html

        :stability: experimental
        '''
        return typing.cast("Transcribe", jsii.invoke(self, "toUpdateMedicalVocabulary", []))

    @jsii.member(jsii_name="toUpdateVocabulary")
    def to_update_vocabulary(self) -> "Transcribe":
        '''(experimental) Grants permission to update an existing vocabulary with new values.

        The UpdateVocabulary operation overwrites all of the existing information with the values that you provide in the request

        Access Level: Write

        Dependent actions:

        - s3:GetObject

        https://docs.aws.amazon.com/transcribe/latest/dg/API_UpdateVocabulary.html

        :stability: experimental
        '''
        return typing.cast("Transcribe", jsii.invoke(self, "toUpdateVocabulary", []))

    @jsii.member(jsii_name="toUpdateVocabularyFilter")
    def to_update_vocabulary_filter(self) -> "Transcribe":
        '''(experimental) Grants permission to update an existing vocabulary filter with new values.

        The UpdateVocabularyFilter operation overwrites all of the existing information with the values that you provide in the request

        Access Level: Write

        Dependent actions:

        - s3:GetObject

        https://docs.aws.amazon.com/transcribe/latest/dg/API_UpdateVocabularyFilter.html

        :stability: experimental
        '''
        return typing.cast("Transcribe", jsii.invoke(self, "toUpdateVocabularyFilter", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__84eb638ee40cde49671575ccbcc91a9e64362ac21d04d541f117f1e17d2a1ec7)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__709db907f71c80ac562e129fb5704d33518e395e0b8427682bba4fa2ac61cb3c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Transfer(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Transfer",
):
    '''(experimental) Statement provider for service `transfer <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awstransferfamily.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `transfer <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awstransferfamily.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onAgreement")
    def on_agreement(
        self,
        agreement_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Transfer":
        '''(experimental) Adds a resource of type agreement to the statement.

        https://docs.aws.amazon.com/transfer/latest/userguide/create-b2b-server.html

        :param agreement_id: - Identifier for the agreementId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__96a9d7fd11f2dee7e8ea1618e2df515f8d017637d79e132db55a9651c8433f67)
            check_type(argname="argument agreement_id", value=agreement_id, expected_type=type_hints["agreement_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Transfer", jsii.invoke(self, "onAgreement", [agreement_id, account, region, partition]))

    @jsii.member(jsii_name="onCertificate")
    def on_certificate(
        self,
        certificate_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Transfer":
        '''(experimental) Adds a resource of type certificate to the statement.

        https://docs.aws.amazon.com/transfer/latest/userguide/create-b2b-server.html

        :param certificate_id: - Identifier for the certificateId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__eb11aff7be7b7ec558c563265af8990d3855b050e2ee660bd94fed2d12bde152)
            check_type(argname="argument certificate_id", value=certificate_id, expected_type=type_hints["certificate_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Transfer", jsii.invoke(self, "onCertificate", [certificate_id, account, region, partition]))

    @jsii.member(jsii_name="onConnector")
    def on_connector(
        self,
        connector_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Transfer":
        '''(experimental) Adds a resource of type connector to the statement.

        https://docs.aws.amazon.com/transfer/latest/userguide/create-b2b-server.html

        :param connector_id: - Identifier for the connectorId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__99c3ced0774a6875f445ba98338f7d52b9e661904bf31844a80dc35bfb3342ad)
            check_type(argname="argument connector_id", value=connector_id, expected_type=type_hints["connector_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Transfer", jsii.invoke(self, "onConnector", [connector_id, account, region, partition]))

    @jsii.member(jsii_name="onHostKey")
    def on_host_key(
        self,
        server_id: builtins.str,
        host_key_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Transfer":
        '''(experimental) Adds a resource of type host-key to the statement.

        https://docs.aws.amazon.com/transfer/latest/userguide/edit-server-config.html

        :param server_id: - Identifier for the serverId.
        :param host_key_id: - Identifier for the hostKeyId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ed443b0e45e9ce61e0762a7a0710ae04a3b7915b7d8ec6a0d7f7910c6f7599f5)
            check_type(argname="argument server_id", value=server_id, expected_type=type_hints["server_id"])
            check_type(argname="argument host_key_id", value=host_key_id, expected_type=type_hints["host_key_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Transfer", jsii.invoke(self, "onHostKey", [server_id, host_key_id, account, region, partition]))

    @jsii.member(jsii_name="onProfile")
    def on_profile(
        self,
        profile_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Transfer":
        '''(experimental) Adds a resource of type profile to the statement.

        https://docs.aws.amazon.com/transfer/latest/userguide/create-b2b-server.html

        :param profile_id: - Identifier for the profileId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__31cdd5cc17e6057239bb020ad87fb87610385a365f920da117d50b79dedb5d3b)
            check_type(argname="argument profile_id", value=profile_id, expected_type=type_hints["profile_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Transfer", jsii.invoke(self, "onProfile", [profile_id, account, region, partition]))

    @jsii.member(jsii_name="onServer")
    def on_server(
        self,
        server_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Transfer":
        '''(experimental) Adds a resource of type server to the statement.

        https://docs.aws.amazon.com/transfer/latest/userguide/configuring-servers.html

        :param server_id: - Identifier for the serverId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e2635540b3dad95ab39a8b879bdb89b2656156fe2dd53af81e22f6b5d3e1cb90)
            check_type(argname="argument server_id", value=server_id, expected_type=type_hints["server_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Transfer", jsii.invoke(self, "onServer", [server_id, account, region, partition]))

    @jsii.member(jsii_name="onUser")
    def on_user(
        self,
        server_id: builtins.str,
        user_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Transfer":
        '''(experimental) Adds a resource of type user to the statement.

        https://docs.aws.amazon.com/transfer/latest/userguide/create-user.html

        :param server_id: - Identifier for the serverId.
        :param user_name: - Identifier for the userName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9312edb8ea9468ac5eb32784664cad6277b223596dd800a2dba55b714f61b30c)
            check_type(argname="argument server_id", value=server_id, expected_type=type_hints["server_id"])
            check_type(argname="argument user_name", value=user_name, expected_type=type_hints["user_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Transfer", jsii.invoke(self, "onUser", [server_id, user_name, account, region, partition]))

    @jsii.member(jsii_name="onWorkflow")
    def on_workflow(
        self,
        workflow_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Transfer":
        '''(experimental) Adds a resource of type workflow to the statement.

        https://docs.aws.amazon.com/transfer/latest/userguide/transfer-workflows.html

        :param workflow_id: - Identifier for the workflowId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__458e6e915d489fb8842c99b696b67ae1dfe0b6c57fb0a890a77415bfc18cc6a8)
            check_type(argname="argument workflow_id", value=workflow_id, expected_type=type_hints["workflow_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Transfer", jsii.invoke(self, "onWorkflow", [workflow_id, account, region, partition]))

    @jsii.member(jsii_name="toCreateAccess")
    def to_create_access(self) -> "Transfer":
        '''(experimental) Grants permission to add an access associated with a server.

        Access Level: Write

        Dependent actions:

        - iam:PassRole

        https://docs.aws.amazon.com/transfer/latest/userguide/API_CreateAccess.html

        :stability: experimental
        '''
        return typing.cast("Transfer", jsii.invoke(self, "toCreateAccess", []))

    @jsii.member(jsii_name="toCreateAgreement")
    def to_create_agreement(self) -> "Transfer":
        '''(experimental) Grants permission to add an agreement associated with a server.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        Dependent actions:

        - iam:PassRole

        https://docs.aws.amazon.com/transfer/latest/userguide/API_CreateAgreement.html

        :stability: experimental
        '''
        return typing.cast("Transfer", jsii.invoke(self, "toCreateAgreement", []))

    @jsii.member(jsii_name="toCreateConnector")
    def to_create_connector(self) -> "Transfer":
        '''(experimental) Grants permission to create a connector.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        Dependent actions:

        - iam:PassRole

        https://docs.aws.amazon.com/transfer/latest/userguide/API_CreateConnector.html

        :stability: experimental
        '''
        return typing.cast("Transfer", jsii.invoke(self, "toCreateConnector", []))

    @jsii.member(jsii_name="toCreateProfile")
    def to_create_profile(self) -> "Transfer":
        '''(experimental) Grants permission to create a profile.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/transfer/latest/userguide/API_CreateProfile.html

        :stability: experimental
        '''
        return typing.cast("Transfer", jsii.invoke(self, "toCreateProfile", []))

    @jsii.member(jsii_name="toCreateServer")
    def to_create_server(self) -> "Transfer":
        '''(experimental) Grants permission to create a server.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        Dependent actions:

        - iam:PassRole

        https://docs.aws.amazon.com/transfer/latest/userguide/API_CreateServer.html

        :stability: experimental
        '''
        return typing.cast("Transfer", jsii.invoke(self, "toCreateServer", []))

    @jsii.member(jsii_name="toCreateUser")
    def to_create_user(self) -> "Transfer":
        '''(experimental) Grants permission to add a user associated with a server.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        Dependent actions:

        - iam:PassRole

        https://docs.aws.amazon.com/transfer/latest/userguide/API_CreateUser.html

        :stability: experimental
        '''
        return typing.cast("Transfer", jsii.invoke(self, "toCreateUser", []))

    @jsii.member(jsii_name="toCreateWorkflow")
    def to_create_workflow(self) -> "Transfer":
        '''(experimental) Grants permission to create a workflow.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/transfer/latest/userguide/API_CreateWorkflow.html

        :stability: experimental
        '''
        return typing.cast("Transfer", jsii.invoke(self, "toCreateWorkflow", []))

    @jsii.member(jsii_name="toDeleteAccess")
    def to_delete_access(self) -> "Transfer":
        '''(experimental) Grants permission to delete access.

        Access Level: Write

        https://docs.aws.amazon.com/transfer/latest/userguide/API_DeleteAccess.html

        :stability: experimental
        '''
        return typing.cast("Transfer", jsii.invoke(self, "toDeleteAccess", []))

    @jsii.member(jsii_name="toDeleteAgreement")
    def to_delete_agreement(self) -> "Transfer":
        '''(experimental) Grants permission to delete agreement.

        Access Level: Write

        https://docs.aws.amazon.com/transfer/latest/userguide/API_DeleteAgreement.html

        :stability: experimental
        '''
        return typing.cast("Transfer", jsii.invoke(self, "toDeleteAgreement", []))

    @jsii.member(jsii_name="toDeleteCertificate")
    def to_delete_certificate(self) -> "Transfer":
        '''(experimental) Grants permission to delete certificate.

        Access Level: Write

        https://docs.aws.amazon.com/transfer/latest/userguide/API_DeleteCertificate.html

        :stability: experimental
        '''
        return typing.cast("Transfer", jsii.invoke(self, "toDeleteCertificate", []))

    @jsii.member(jsii_name="toDeleteConnector")
    def to_delete_connector(self) -> "Transfer":
        '''(experimental) Grants permission to delete connector.

        Access Level: Write

        https://docs.aws.amazon.com/transfer/latest/userguide/API_DeleteConnector.html

        :stability: experimental
        '''
        return typing.cast("Transfer", jsii.invoke(self, "toDeleteConnector", []))

    @jsii.member(jsii_name="toDeleteHostKey")
    def to_delete_host_key(self) -> "Transfer":
        '''(experimental) Grants permission to delete a host key associated with a server.

        Access Level: Write

        https://docs.aws.amazon.com/transfer/latest/userguide/API_DeleteHostKey.html

        :stability: experimental
        '''
        return typing.cast("Transfer", jsii.invoke(self, "toDeleteHostKey", []))

    @jsii.member(jsii_name="toDeleteProfile")
    def to_delete_profile(self) -> "Transfer":
        '''(experimental) Grants permission to delete profile.

        Access Level: Write

        https://docs.aws.amazon.com/transfer/latest/userguide/API_DeleteProfile.html

        :stability: experimental
        '''
        return typing.cast("Transfer", jsii.invoke(self, "toDeleteProfile", []))

    @jsii.member(jsii_name="toDeleteServer")
    def to_delete_server(self) -> "Transfer":
        '''(experimental) Grants permission to delete a server.

        Access Level: Write

        https://docs.aws.amazon.com/transfer/latest/userguide/API_DeleteServer.html

        :stability: experimental
        '''
        return typing.cast("Transfer", jsii.invoke(self, "toDeleteServer", []))

    @jsii.member(jsii_name="toDeleteSshPublicKey")
    def to_delete_ssh_public_key(self) -> "Transfer":
        '''(experimental) Grants permission to delete an SSH public key from a user.

        Access Level: Write

        https://docs.aws.amazon.com/transfer/latest/userguide/API_DeleteSshPublicKey.html

        :stability: experimental
        '''
        return typing.cast("Transfer", jsii.invoke(self, "toDeleteSshPublicKey", []))

    @jsii.member(jsii_name="toDeleteUser")
    def to_delete_user(self) -> "Transfer":
        '''(experimental) Grants permission to delete a user associated with a server.

        Access Level: Write

        https://docs.aws.amazon.com/transfer/latest/userguide/API_DeleteUser.html

        :stability: experimental
        '''
        return typing.cast("Transfer", jsii.invoke(self, "toDeleteUser", []))

    @jsii.member(jsii_name="toDeleteWorkflow")
    def to_delete_workflow(self) -> "Transfer":
        '''(experimental) Grants permission to delete a workflow.

        Access Level: Write

        https://docs.aws.amazon.com/transfer/latest/userguide/API_DeleteWorkflow.html

        :stability: experimental
        '''
        return typing.cast("Transfer", jsii.invoke(self, "toDeleteWorkflow", []))

    @jsii.member(jsii_name="toDescribeAccess")
    def to_describe_access(self) -> "Transfer":
        '''(experimental) Grants permission to describe an access assigned to a server.

        Access Level: Read

        https://docs.aws.amazon.com/transfer/latest/userguide/API_DescribeAccess.html

        :stability: experimental
        '''
        return typing.cast("Transfer", jsii.invoke(self, "toDescribeAccess", []))

    @jsii.member(jsii_name="toDescribeAgreement")
    def to_describe_agreement(self) -> "Transfer":
        '''(experimental) Grants permission to describe an agreement assigned to a server.

        Access Level: Read

        https://docs.aws.amazon.com/transfer/latest/userguide/API_DescribeAgreement.html

        :stability: experimental
        '''
        return typing.cast("Transfer", jsii.invoke(self, "toDescribeAgreement", []))

    @jsii.member(jsii_name="toDescribeCertificate")
    def to_describe_certificate(self) -> "Transfer":
        '''(experimental) Grants permission to describe a certificate.

        Access Level: Read

        https://docs.aws.amazon.com/transfer/latest/userguide/API_DescribeCertificate.html

        :stability: experimental
        '''
        return typing.cast("Transfer", jsii.invoke(self, "toDescribeCertificate", []))

    @jsii.member(jsii_name="toDescribeConnector")
    def to_describe_connector(self) -> "Transfer":
        '''(experimental) Grants permission to describe a connector.

        Access Level: Read

        https://docs.aws.amazon.com/transfer/latest/userguide/API_DescribeConnector.html

        :stability: experimental
        '''
        return typing.cast("Transfer", jsii.invoke(self, "toDescribeConnector", []))

    @jsii.member(jsii_name="toDescribeExecution")
    def to_describe_execution(self) -> "Transfer":
        '''(experimental) Grants permission to describe an execution associated with a workflow.

        Access Level: Read

        https://docs.aws.amazon.com/transfer/latest/userguide/API_DescribeExecution.html

        :stability: experimental
        '''
        return typing.cast("Transfer", jsii.invoke(self, "toDescribeExecution", []))

    @jsii.member(jsii_name="toDescribeHostKey")
    def to_describe_host_key(self) -> "Transfer":
        '''(experimental) Grants permission to describe a host key associated with a server.

        Access Level: Read

        https://docs.aws.amazon.com/transfer/latest/userguide/API_DescribeHostKey.html

        :stability: experimental
        '''
        return typing.cast("Transfer", jsii.invoke(self, "toDescribeHostKey", []))

    @jsii.member(jsii_name="toDescribeProfile")
    def to_describe_profile(self) -> "Transfer":
        '''(experimental) Grants permission to describe a profile.

        Access Level: Read

        https://docs.aws.amazon.com/transfer/latest/userguide/API_DescribeProfile.html

        :stability: experimental
        '''
        return typing.cast("Transfer", jsii.invoke(self, "toDescribeProfile", []))

    @jsii.member(jsii_name="toDescribeSecurityPolicy")
    def to_describe_security_policy(self) -> "Transfer":
        '''(experimental) Grants permission to describe a security policy.

        Access Level: Read

        https://docs.aws.amazon.com/transfer/latest/userguide/API_DescribeSecurityPolicy.html

        :stability: experimental
        '''
        return typing.cast("Transfer", jsii.invoke(self, "toDescribeSecurityPolicy", []))

    @jsii.member(jsii_name="toDescribeServer")
    def to_describe_server(self) -> "Transfer":
        '''(experimental) Grants permission to describe a server.

        Access Level: Read

        https://docs.aws.amazon.com/transfer/latest/userguide/API_DescribeServer.html

        :stability: experimental
        '''
        return typing.cast("Transfer", jsii.invoke(self, "toDescribeServer", []))

    @jsii.member(jsii_name="toDescribeUser")
    def to_describe_user(self) -> "Transfer":
        '''(experimental) Grants permission to describe a user associated with a server.

        Access Level: Read

        https://docs.aws.amazon.com/transfer/latest/userguide/API_DescribeUser.html

        :stability: experimental
        '''
        return typing.cast("Transfer", jsii.invoke(self, "toDescribeUser", []))

    @jsii.member(jsii_name="toDescribeWorkflow")
    def to_describe_workflow(self) -> "Transfer":
        '''(experimental) Grants permission to describe a workflow.

        Access Level: Read

        https://docs.aws.amazon.com/transfer/latest/userguide/API_DescribeWorkflow.html

        :stability: experimental
        '''
        return typing.cast("Transfer", jsii.invoke(self, "toDescribeWorkflow", []))

    @jsii.member(jsii_name="toImportCertificate")
    def to_import_certificate(self) -> "Transfer":
        '''(experimental) Grants permission to add a certificate.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/transfer/latest/userguide/API_ImportCertificate.html

        :stability: experimental
        '''
        return typing.cast("Transfer", jsii.invoke(self, "toImportCertificate", []))

    @jsii.member(jsii_name="toImportHostKey")
    def to_import_host_key(self) -> "Transfer":
        '''(experimental) Grants permission to add a host key to a server.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/transfer/latest/userguide/API_ImportHostKey.html

        :stability: experimental
        '''
        return typing.cast("Transfer", jsii.invoke(self, "toImportHostKey", []))

    @jsii.member(jsii_name="toImportSshPublicKey")
    def to_import_ssh_public_key(self) -> "Transfer":
        '''(experimental) Grants permission to add an SSH public key to a user.

        Access Level: Write

        https://docs.aws.amazon.com/transfer/latest/userguide/API_ImportSshPublicKey.html

        :stability: experimental
        '''
        return typing.cast("Transfer", jsii.invoke(self, "toImportSshPublicKey", []))

    @jsii.member(jsii_name="toListAccesses")
    def to_list_accesses(self) -> "Transfer":
        '''(experimental) Grants permission to list accesses.

        Access Level: Read

        https://docs.aws.amazon.com/transfer/latest/userguide/API_ListAccesses.html

        :stability: experimental
        '''
        return typing.cast("Transfer", jsii.invoke(self, "toListAccesses", []))

    @jsii.member(jsii_name="toListAgreements")
    def to_list_agreements(self) -> "Transfer":
        '''(experimental) Grants permission to list agreements.

        Access Level: Read

        https://docs.aws.amazon.com/transfer/latest/userguide/API_ListAgreements.html

        :stability: experimental
        '''
        return typing.cast("Transfer", jsii.invoke(self, "toListAgreements", []))

    @jsii.member(jsii_name="toListCertificates")
    def to_list_certificates(self) -> "Transfer":
        '''(experimental) Grants permission to list certificates.

        Access Level: Read

        https://docs.aws.amazon.com/transfer/latest/userguide/API_ListCertificates.html

        :stability: experimental
        '''
        return typing.cast("Transfer", jsii.invoke(self, "toListCertificates", []))

    @jsii.member(jsii_name="toListConnectors")
    def to_list_connectors(self) -> "Transfer":
        '''(experimental) Grants permission to list connectors.

        Access Level: Read

        https://docs.aws.amazon.com/transfer/latest/userguide/API_ListConnectors.html

        :stability: experimental
        '''
        return typing.cast("Transfer", jsii.invoke(self, "toListConnectors", []))

    @jsii.member(jsii_name="toListExecutions")
    def to_list_executions(self) -> "Transfer":
        '''(experimental) Grants permission to list executions associated with a workflow.

        Access Level: Read

        https://docs.aws.amazon.com/transfer/latest/userguide/API_ListExecutions.html

        :stability: experimental
        '''
        return typing.cast("Transfer", jsii.invoke(self, "toListExecutions", []))

    @jsii.member(jsii_name="toListHostKeys")
    def to_list_host_keys(self) -> "Transfer":
        '''(experimental) Grants permission to list host keys associated with a server.

        Access Level: Read

        https://docs.aws.amazon.com/transfer/latest/userguide/API_ListHostKeys.html

        :stability: experimental
        '''
        return typing.cast("Transfer", jsii.invoke(self, "toListHostKeys", []))

    @jsii.member(jsii_name="toListProfiles")
    def to_list_profiles(self) -> "Transfer":
        '''(experimental) Grants permission to list profiles.

        Access Level: Read

        https://docs.aws.amazon.com/transfer/latest/userguide/API_ListProfiles.html

        :stability: experimental
        '''
        return typing.cast("Transfer", jsii.invoke(self, "toListProfiles", []))

    @jsii.member(jsii_name="toListSecurityPolicies")
    def to_list_security_policies(self) -> "Transfer":
        '''(experimental) Grants permission to list security policies.

        Access Level: List

        https://docs.aws.amazon.com/transfer/latest/userguide/API_ListSecurityPolicies.html

        :stability: experimental
        '''
        return typing.cast("Transfer", jsii.invoke(self, "toListSecurityPolicies", []))

    @jsii.member(jsii_name="toListServers")
    def to_list_servers(self) -> "Transfer":
        '''(experimental) Grants permission to list servers.

        Access Level: List

        https://docs.aws.amazon.com/transfer/latest/userguide/API_ListServers.html

        :stability: experimental
        '''
        return typing.cast("Transfer", jsii.invoke(self, "toListServers", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Transfer":
        '''(experimental) Grants permission to list tags for an AWS Transfer Family resource.

        Access Level: Read

        https://docs.aws.amazon.com/transfer/latest/userguide/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("Transfer", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toListUsers")
    def to_list_users(self) -> "Transfer":
        '''(experimental) Grants permission to list users associated with a server.

        Access Level: List

        https://docs.aws.amazon.com/transfer/latest/userguide/API_ListUsers.html

        :stability: experimental
        '''
        return typing.cast("Transfer", jsii.invoke(self, "toListUsers", []))

    @jsii.member(jsii_name="toListWorkflows")
    def to_list_workflows(self) -> "Transfer":
        '''(experimental) Grants permission to list workflows.

        Access Level: List

        https://docs.aws.amazon.com/transfer/latest/userguide/API_ListWorkflows.html

        :stability: experimental
        '''
        return typing.cast("Transfer", jsii.invoke(self, "toListWorkflows", []))

    @jsii.member(jsii_name="toSendWorkflowStepState")
    def to_send_workflow_step_state(self) -> "Transfer":
        '''(experimental) Grants permission to send a callback for asynchronous custom steps.

        Access Level: Write

        https://docs.aws.amazon.com/transfer/latest/userguide/API_SendWorkflowStepState.html

        :stability: experimental
        '''
        return typing.cast("Transfer", jsii.invoke(self, "toSendWorkflowStepState", []))

    @jsii.member(jsii_name="toStartFileTransfer")
    def to_start_file_transfer(self) -> "Transfer":
        '''(experimental) Grants permission to initiate a connector file transfer.

        Access Level: Write

        https://docs.aws.amazon.com/transfer/latest/userguide/API_StartFileTransfer.html

        :stability: experimental
        '''
        return typing.cast("Transfer", jsii.invoke(self, "toStartFileTransfer", []))

    @jsii.member(jsii_name="toStartServer")
    def to_start_server(self) -> "Transfer":
        '''(experimental) Grants permission to start a server.

        Access Level: Write

        https://docs.aws.amazon.com/transfer/latest/userguide/API_StartServer.html

        :stability: experimental
        '''
        return typing.cast("Transfer", jsii.invoke(self, "toStartServer", []))

    @jsii.member(jsii_name="toStopServer")
    def to_stop_server(self) -> "Transfer":
        '''(experimental) Grants permission to stop a server.

        Access Level: Write

        https://docs.aws.amazon.com/transfer/latest/userguide/API_StopServer.html

        :stability: experimental
        '''
        return typing.cast("Transfer", jsii.invoke(self, "toStopServer", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Transfer":
        '''(experimental) Grants permission to tag an AWS Transfer Family resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/transfer/latest/userguide/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("Transfer", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toTestIdentityProvider")
    def to_test_identity_provider(self) -> "Transfer":
        '''(experimental) Grants permission to test a server's custom identity provider.

        Access Level: Read

        https://docs.aws.amazon.com/transfer/latest/userguide/API_TestIdentityProvider.html

        :stability: experimental
        '''
        return typing.cast("Transfer", jsii.invoke(self, "toTestIdentityProvider", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Transfer":
        '''(experimental) Grants permission to untag an AWS Transfer Family resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/transfer/latest/userguide/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("Transfer", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateAccess")
    def to_update_access(self) -> "Transfer":
        '''(experimental) Grants permission to update access.

        Access Level: Write

        Dependent actions:

        - iam:PassRole

        https://docs.aws.amazon.com/transfer/latest/userguide/API_UpdateAccess.html

        :stability: experimental
        '''
        return typing.cast("Transfer", jsii.invoke(self, "toUpdateAccess", []))

    @jsii.member(jsii_name="toUpdateAgreement")
    def to_update_agreement(self) -> "Transfer":
        '''(experimental) Grants permission to update an agreement.

        Access Level: Write

        Dependent actions:

        - iam:PassRole

        https://docs.aws.amazon.com/transfer/latest/userguide/API_UpdateAgreement.html

        :stability: experimental
        '''
        return typing.cast("Transfer", jsii.invoke(self, "toUpdateAgreement", []))

    @jsii.member(jsii_name="toUpdateCertificate")
    def to_update_certificate(self) -> "Transfer":
        '''(experimental) Grants permission to update a certificate.

        Access Level: Write

        https://docs.aws.amazon.com/transfer/latest/userguide/API_UpdateCertificate.html

        :stability: experimental
        '''
        return typing.cast("Transfer", jsii.invoke(self, "toUpdateCertificate", []))

    @jsii.member(jsii_name="toUpdateConnector")
    def to_update_connector(self) -> "Transfer":
        '''(experimental) Grants permission to update a connector.

        Access Level: Write

        Dependent actions:

        - iam:PassRole

        https://docs.aws.amazon.com/transfer/latest/userguide/API_UpdateConnector.html

        :stability: experimental
        '''
        return typing.cast("Transfer", jsii.invoke(self, "toUpdateConnector", []))

    @jsii.member(jsii_name="toUpdateHostKey")
    def to_update_host_key(self) -> "Transfer":
        '''(experimental) Grants permission to update a host key.

        Access Level: Write

        https://docs.aws.amazon.com/transfer/latest/userguide/API_UpdateHostKey.html

        :stability: experimental
        '''
        return typing.cast("Transfer", jsii.invoke(self, "toUpdateHostKey", []))

    @jsii.member(jsii_name="toUpdateProfile")
    def to_update_profile(self) -> "Transfer":
        '''(experimental) Grants permission to update a profile.

        Access Level: Write

        https://docs.aws.amazon.com/transfer/latest/userguide/API_UpdateProfile.html

        :stability: experimental
        '''
        return typing.cast("Transfer", jsii.invoke(self, "toUpdateProfile", []))

    @jsii.member(jsii_name="toUpdateServer")
    def to_update_server(self) -> "Transfer":
        '''(experimental) Grants permission to update the configuration of a server.

        Access Level: Write

        Dependent actions:

        - iam:PassRole

        https://docs.aws.amazon.com/transfer/latest/userguide/API_UpdateServer.html

        :stability: experimental
        '''
        return typing.cast("Transfer", jsii.invoke(self, "toUpdateServer", []))

    @jsii.member(jsii_name="toUpdateUser")
    def to_update_user(self) -> "Transfer":
        '''(experimental) Grants permission to update the configuration of a user.

        Access Level: Write

        Dependent actions:

        - iam:PassRole

        https://docs.aws.amazon.com/transfer/latest/userguide/API_UpdateUser.html

        :stability: experimental
        '''
        return typing.cast("Transfer", jsii.invoke(self, "toUpdateUser", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__256b17bedf4ba63110c6b554496d16e89c6edc47da10bff85e730d2dc424ff30)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c336443460b9597a021bf56f3383d44c3069449a33ccc3fe38bd67f416556245)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Translate(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Translate",
):
    '''(experimental) Statement provider for service `translate <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazontranslate.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `translate <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazontranslate.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onParallelData")
    def on_parallel_data(
        self,
        resource_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Translate":
        '''(experimental) Adds a resource of type parallel-data to the statement.

        https://docs.aws.amazon.com/translate/latest/dg/customizing-translations-parallel-data.html

        :param resource_name: - Identifier for the resourceName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__748f0ab86af4b1bc8e0746b5befd1437a9ed6172d319137877bf3bb5ef8ba4ae)
            check_type(argname="argument resource_name", value=resource_name, expected_type=type_hints["resource_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Translate", jsii.invoke(self, "onParallelData", [resource_name, account, region, partition]))

    @jsii.member(jsii_name="onTerminology")
    def on_terminology(
        self,
        resource_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Translate":
        '''(experimental) Adds a resource of type terminology to the statement.

        https://docs.aws.amazon.com/translate/latest/dg/how-custom-terminology.html

        :param resource_name: - Identifier for the resourceName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f1853b33f97957a242a1e8499fd88a9e200f6ad2417c3ee26ce57b356d2b6200)
            check_type(argname="argument resource_name", value=resource_name, expected_type=type_hints["resource_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Translate", jsii.invoke(self, "onTerminology", [resource_name, account, region, partition]))

    @jsii.member(jsii_name="toCreateParallelData")
    def to_create_parallel_data(self) -> "Translate":
        '''(experimental) Grants permission to create a Parallel Data.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/translate/latest/APIReference/API_CreateParallelData.html

        :stability: experimental
        '''
        return typing.cast("Translate", jsii.invoke(self, "toCreateParallelData", []))

    @jsii.member(jsii_name="toDeleteParallelData")
    def to_delete_parallel_data(self) -> "Translate":
        '''(experimental) Grants permission to delete a Parallel Data.

        Access Level: Write

        https://docs.aws.amazon.com/translate/latest/APIReference/API_DeleteParallelData.html

        :stability: experimental
        '''
        return typing.cast("Translate", jsii.invoke(self, "toDeleteParallelData", []))

    @jsii.member(jsii_name="toDeleteTerminology")
    def to_delete_terminology(self) -> "Translate":
        '''(experimental) Grants permission to delete a terminology.

        Access Level: Write

        https://docs.aws.amazon.com/translate/latest/APIReference/API_DeleteTerminology.html

        :stability: experimental
        '''
        return typing.cast("Translate", jsii.invoke(self, "toDeleteTerminology", []))

    @jsii.member(jsii_name="toDescribeTextTranslationJob")
    def to_describe_text_translation_job(self) -> "Translate":
        '''(experimental) Grants permission to get the properties associated with an asynchronous batch translation job.

        Access Level: Read

        https://docs.aws.amazon.com/translate/latest/APIReference/API_DescribeTextTranslationJob.html

        :stability: experimental
        '''
        return typing.cast("Translate", jsii.invoke(self, "toDescribeTextTranslationJob", []))

    @jsii.member(jsii_name="toGetParallelData")
    def to_get_parallel_data(self) -> "Translate":
        '''(experimental) Grants permission to get a Parallel Data.

        Access Level: Read

        https://docs.aws.amazon.com/translate/latest/APIReference/API_GetParallelData.html

        :stability: experimental
        '''
        return typing.cast("Translate", jsii.invoke(self, "toGetParallelData", []))

    @jsii.member(jsii_name="toGetTerminology")
    def to_get_terminology(self) -> "Translate":
        '''(experimental) Grants permission to retrieve a terminology.

        Access Level: Read

        https://docs.aws.amazon.com/translate/latest/APIReference/API_GetTerminology.html

        :stability: experimental
        '''
        return typing.cast("Translate", jsii.invoke(self, "toGetTerminology", []))

    @jsii.member(jsii_name="toImportTerminology")
    def to_import_terminology(self) -> "Translate":
        '''(experimental) Grants permission to create or update a terminology, depending on whether or not one already exists for the given terminology name.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/translate/latest/APIReference/API_ImportTerminology.html

        :stability: experimental
        '''
        return typing.cast("Translate", jsii.invoke(self, "toImportTerminology", []))

    @jsii.member(jsii_name="toListLanguages")
    def to_list_languages(self) -> "Translate":
        '''(experimental) Grants permission to list supported languages.

        Access Level: List

        https://docs.aws.amazon.com/translate/latest/APIReference/API_ListLanguages.html

        :stability: experimental
        '''
        return typing.cast("Translate", jsii.invoke(self, "toListLanguages", []))

    @jsii.member(jsii_name="toListParallelData")
    def to_list_parallel_data(self) -> "Translate":
        '''(experimental) Grants permission to list Parallel Data associated with your account.

        Access Level: List

        https://docs.aws.amazon.com/translate/latest/APIReference/API_ListParallelData.html

        :stability: experimental
        '''
        return typing.cast("Translate", jsii.invoke(self, "toListParallelData", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Translate":
        '''(experimental) Grants permission to list tags for a resource.

        Access Level: Read

        https://docs.aws.amazon.com/translate/latest/APIReference/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("Translate", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toListTerminologies")
    def to_list_terminologies(self) -> "Translate":
        '''(experimental) Grants permission to list terminologies associated with your account.

        Access Level: List

        https://docs.aws.amazon.com/translate/latest/APIReference/API_ListTerminologies.html

        :stability: experimental
        '''
        return typing.cast("Translate", jsii.invoke(self, "toListTerminologies", []))

    @jsii.member(jsii_name="toListTextTranslationJobs")
    def to_list_text_translation_jobs(self) -> "Translate":
        '''(experimental) Grants permission to list batch translation jobs that you have submitted.

        Access Level: List

        https://docs.aws.amazon.com/translate/latest/APIReference/API_ListTextTranslationJobs.html

        :stability: experimental
        '''
        return typing.cast("Translate", jsii.invoke(self, "toListTextTranslationJobs", []))

    @jsii.member(jsii_name="toStartTextTranslationJob")
    def to_start_text_translation_job(self) -> "Translate":
        '''(experimental) Grants permission to start an asynchronous batch translation job.

        Batch translation jobs can be used to translate large volumes of text across multiple documents at once

        Access Level: Write

        https://docs.aws.amazon.com/translate/latest/APIReference/API_StartTextTranslationJob.html

        :stability: experimental
        '''
        return typing.cast("Translate", jsii.invoke(self, "toStartTextTranslationJob", []))

    @jsii.member(jsii_name="toStopTextTranslationJob")
    def to_stop_text_translation_job(self) -> "Translate":
        '''(experimental) Grants permission to stop an asynchronous batch translation job that is in progress.

        Access Level: Write

        https://docs.aws.amazon.com/translate/latest/APIReference/API_StopTextTranslationJob.html

        :stability: experimental
        '''
        return typing.cast("Translate", jsii.invoke(self, "toStopTextTranslationJob", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Translate":
        '''(experimental) Grants permission to tag a resource with given key value pairs.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/translate/latest/APIReference/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("Translate", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toTranslateText")
    def to_translate_text(self) -> "Translate":
        '''(experimental) Grants permission to translate text from a source language to a target language.

        Access Level: Read

        https://docs.aws.amazon.com/translate/latest/APIReference/API_TranslateText.html

        :stability: experimental
        '''
        return typing.cast("Translate", jsii.invoke(self, "toTranslateText", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Translate":
        '''(experimental) Grants permission to untag a resource with given key.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/translate/latest/APIReference/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("Translate", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateParallelData")
    def to_update_parallel_data(self) -> "Translate":
        '''(experimental) Grants permission to update an existing Parallel Data.

        Access Level: Write

        https://docs.aws.amazon.com/translate/latest/APIReference/API_UpdateParallelData.html

        :stability: experimental
        '''
        return typing.cast("Translate", jsii.invoke(self, "toUpdateParallelData", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__00eda8adb2172f26899164662c772299818c0a27e70848866f8fe286979fe137)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0b8c31fff7b6e2541c1562ca6bba79af2bbb98bedd72e4b47647dd1a6d3c584d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Trustedadvisor(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Trustedadvisor",
):
    '''(experimental) Statement provider for service `trustedadvisor <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awstrustedadvisor.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `trustedadvisor <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awstrustedadvisor.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onChecks")
    def on_checks(
        self,
        category_code: builtins.str,
        check_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Trustedadvisor":
        '''(experimental) Adds a resource of type checks to the statement.

        https://docs.aws.amazon.com/awssupport/latest/APIReference/API_TrustedAdvisorCheckDescription.html

        :param category_code: - Identifier for the categoryCode.
        :param check_id: - Identifier for the checkId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1128f062d3b22c35c367c1c2c1a640fdd6dbd7a690615ddca297afcdfc7eab19)
            check_type(argname="argument category_code", value=category_code, expected_type=type_hints["category_code"])
            check_type(argname="argument check_id", value=check_id, expected_type=type_hints["check_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Trustedadvisor", jsii.invoke(self, "onChecks", [category_code, check_id, account, region, partition]))

    @jsii.member(jsii_name="toDeleteNotificationConfigurationForDelegatedAdmin")
    def to_delete_notification_configuration_for_delegated_admin(
        self,
    ) -> "Trustedadvisor":
        '''(experimental) Grants permission to the organization management account to delete email notification preferences from a delegated administrator account for Trusted Advisor Priority.

        Access Level: Write

        https://docs.aws.amazon.com/awssupport/latest/user/security-trusted-advisor.html#trusted-advisor-operations

        :stability: experimental
        '''
        return typing.cast("Trustedadvisor", jsii.invoke(self, "toDeleteNotificationConfigurationForDelegatedAdmin", []))

    @jsii.member(jsii_name="toDescribeAccount")
    def to_describe_account(self) -> "Trustedadvisor":
        '''(experimental) Grants permission to view the AWS Support plan and various AWS Trusted Advisor preferences.

        Access Level: Read

        https://docs.aws.amazon.com/awssupport/latest/user/security-trusted-advisor.html#trusted-advisor-operations

        :stability: experimental
        '''
        return typing.cast("Trustedadvisor", jsii.invoke(self, "toDescribeAccount", []))

    @jsii.member(jsii_name="toDescribeAccountAccess")
    def to_describe_account_access(self) -> "Trustedadvisor":
        '''(experimental) Grants permission to view if the AWS account has enabled or disabled AWS Trusted Advisor.

        Access Level: Read

        https://docs.aws.amazon.com/awssupport/latest/user/security-trusted-advisor.html#trusted-advisor-operations

        :stability: experimental
        '''
        return typing.cast("Trustedadvisor", jsii.invoke(self, "toDescribeAccountAccess", []))

    @jsii.member(jsii_name="toDescribeCheckItems")
    def to_describe_check_items(self) -> "Trustedadvisor":
        '''(experimental) Grants permission to view details for the check items.

        Access Level: Read

        https://docs.aws.amazon.com/awssupport/latest/user/security-trusted-advisor.html#trusted-advisor-operations

        :stability: experimental
        '''
        return typing.cast("Trustedadvisor", jsii.invoke(self, "toDescribeCheckItems", []))

    @jsii.member(jsii_name="toDescribeCheckRefreshStatuses")
    def to_describe_check_refresh_statuses(self) -> "Trustedadvisor":
        '''(experimental) Grants permission to view the refresh statuses for AWS Trusted Advisor checks.

        Access Level: Read

        https://docs.aws.amazon.com/awssupport/latest/user/security-trusted-advisor.html#trusted-advisor-operations

        :stability: experimental
        '''
        return typing.cast("Trustedadvisor", jsii.invoke(self, "toDescribeCheckRefreshStatuses", []))

    @jsii.member(jsii_name="toDescribeChecks")
    def to_describe_checks(self) -> "Trustedadvisor":
        '''(experimental) Grants permission to view details for AWS Trusted Advisor checks.

        Access Level: Read

        https://docs.aws.amazon.com/awssupport/latest/user/security-trusted-advisor.html#trusted-advisor-operations

        :stability: experimental
        '''
        return typing.cast("Trustedadvisor", jsii.invoke(self, "toDescribeChecks", []))

    @jsii.member(jsii_name="toDescribeCheckSummaries")
    def to_describe_check_summaries(self) -> "Trustedadvisor":
        '''(experimental) Grants permission to view AWS Trusted Advisor check summaries.

        Access Level: Read

        https://docs.aws.amazon.com/awssupport/latest/user/security-trusted-advisor.html#trusted-advisor-operations

        :stability: experimental
        '''
        return typing.cast("Trustedadvisor", jsii.invoke(self, "toDescribeCheckSummaries", []))

    @jsii.member(jsii_name="toDescribeNotificationConfigurations")
    def to_describe_notification_configurations(self) -> "Trustedadvisor":
        '''(experimental) Grants permission to get your email notification preferences for Trusted Advisor Priority.

        Access Level: Read

        https://docs.aws.amazon.com/awssupport/latest/user/security-trusted-advisor.html#trusted-advisor-operations

        :stability: experimental
        '''
        return typing.cast("Trustedadvisor", jsii.invoke(self, "toDescribeNotificationConfigurations", []))

    @jsii.member(jsii_name="toDescribeNotificationPreferences")
    def to_describe_notification_preferences(self) -> "Trustedadvisor":
        '''(experimental) Grants permission to view the notification preferences for the AWS account.

        Access Level: Read

        https://docs.aws.amazon.com/awssupport/latest/user/security-trusted-advisor.html#trusted-advisor-operations

        :stability: experimental
        '''
        return typing.cast("Trustedadvisor", jsii.invoke(self, "toDescribeNotificationPreferences", []))

    @jsii.member(jsii_name="toDescribeOrganization")
    def to_describe_organization(self) -> "Trustedadvisor":
        '''(experimental) Grants permission to view if the AWS account meets the requirements to enable the organizational view feature.

        Access Level: Read

        https://docs.aws.amazon.com/awssupport/latest/user/security-trusted-advisor.html#trusted-advisor-operations

        :stability: experimental
        '''
        return typing.cast("Trustedadvisor", jsii.invoke(self, "toDescribeOrganization", []))

    @jsii.member(jsii_name="toDescribeOrganizationAccounts")
    def to_describe_organization_accounts(self) -> "Trustedadvisor":
        '''(experimental) Grants permission to view the linked AWS accounts that are in the organization.

        Access Level: Read

        https://docs.aws.amazon.com/awssupport/latest/user/security-trusted-advisor.html#trusted-advisor-operations

        :stability: experimental
        '''
        return typing.cast("Trustedadvisor", jsii.invoke(self, "toDescribeOrganizationAccounts", []))

    @jsii.member(jsii_name="toDescribeReports")
    def to_describe_reports(self) -> "Trustedadvisor":
        '''(experimental) Grants permission to view details for organizational view reports, such as the report name, runtime, date created, status, and format.

        Access Level: Read

        https://docs.aws.amazon.com/awssupport/latest/user/security-trusted-advisor.html#trusted-advisor-operations

        :stability: experimental
        '''
        return typing.cast("Trustedadvisor", jsii.invoke(self, "toDescribeReports", []))

    @jsii.member(jsii_name="toDescribeRisk")
    def to_describe_risk(self) -> "Trustedadvisor":
        '''(experimental) Grants permission to view risk details in AWS Trusted Advisor Priority.

        Access Level: Read

        https://docs.aws.amazon.com/awssupport/latest/user/security-trusted-advisor.html#trusted-advisor-operations

        :stability: experimental
        '''
        return typing.cast("Trustedadvisor", jsii.invoke(self, "toDescribeRisk", []))

    @jsii.member(jsii_name="toDescribeRiskResources")
    def to_describe_risk_resources(self) -> "Trustedadvisor":
        '''(experimental) Grants permission to view affected resources for a risk in AWS Trusted Advisor Priority.

        Access Level: Read

        https://docs.aws.amazon.com/awssupport/latest/user/security-trusted-advisor.html#trusted-advisor-operations

        :stability: experimental
        '''
        return typing.cast("Trustedadvisor", jsii.invoke(self, "toDescribeRiskResources", []))

    @jsii.member(jsii_name="toDescribeRisks")
    def to_describe_risks(self) -> "Trustedadvisor":
        '''(experimental) Grants permission to view risks in AWS Trusted Advisor Priority.

        Access Level: Read

        https://docs.aws.amazon.com/awssupport/latest/user/security-trusted-advisor.html#trusted-advisor-operations

        :stability: experimental
        '''
        return typing.cast("Trustedadvisor", jsii.invoke(self, "toDescribeRisks", []))

    @jsii.member(jsii_name="toDescribeServiceMetadata")
    def to_describe_service_metadata(self) -> "Trustedadvisor":
        '''(experimental) Grants permission to view information about organizational view reports, such as the AWS Regions, check categories, check names, and resource statuses.

        Access Level: Read

        https://docs.aws.amazon.com/awssupport/latest/user/security-trusted-advisor.html#trusted-advisor-operations

        :stability: experimental
        '''
        return typing.cast("Trustedadvisor", jsii.invoke(self, "toDescribeServiceMetadata", []))

    @jsii.member(jsii_name="toDownloadRisk")
    def to_download_risk(self) -> "Trustedadvisor":
        '''(experimental) Grants permission to download a file that contains details about the risk in AWS Trusted Advisor Priority.

        Access Level: Read

        https://docs.aws.amazon.com/awssupport/latest/user/security-trusted-advisor.html#trusted-advisor-operations

        :stability: experimental
        '''
        return typing.cast("Trustedadvisor", jsii.invoke(self, "toDownloadRisk", []))

    @jsii.member(jsii_name="toExcludeCheckItems")
    def to_exclude_check_items(self) -> "Trustedadvisor":
        '''(experimental) Grants permission to exclude recommendations for AWS Trusted Advisor checks.

        Access Level: Write

        https://docs.aws.amazon.com/awssupport/latest/user/security-trusted-advisor.html#trusted-advisor-operations

        :stability: experimental
        '''
        return typing.cast("Trustedadvisor", jsii.invoke(self, "toExcludeCheckItems", []))

    @jsii.member(jsii_name="toGenerateReport")
    def to_generate_report(self) -> "Trustedadvisor":
        '''(experimental) Grants permission to create a report for AWS Trusted Advisor checks in your organization.

        Access Level: Write

        https://docs.aws.amazon.com/awssupport/latest/user/security-trusted-advisor.html#trusted-advisor-operations

        :stability: experimental
        '''
        return typing.cast("Trustedadvisor", jsii.invoke(self, "toGenerateReport", []))

    @jsii.member(jsii_name="toIncludeCheckItems")
    def to_include_check_items(self) -> "Trustedadvisor":
        '''(experimental) Grants permission to include recommendations for AWS Trusted Advisor checks.

        Access Level: Write

        https://docs.aws.amazon.com/awssupport/latest/user/security-trusted-advisor.html#trusted-advisor-operations

        :stability: experimental
        '''
        return typing.cast("Trustedadvisor", jsii.invoke(self, "toIncludeCheckItems", []))

    @jsii.member(jsii_name="toListAccountsForParent")
    def to_list_accounts_for_parent(self) -> "Trustedadvisor":
        '''(experimental) Grants permission to view, in the Trusted Advisor console, all of the accounts in an AWS organization that are contained by a root or organizational unit (OU).

        Access Level: Read

        https://docs.aws.amazon.com/awssupport/latest/user/security-trusted-advisor.html#trusted-advisor-operations

        :stability: experimental
        '''
        return typing.cast("Trustedadvisor", jsii.invoke(self, "toListAccountsForParent", []))

    @jsii.member(jsii_name="toListOrganizationalUnitsForParent")
    def to_list_organizational_units_for_parent(self) -> "Trustedadvisor":
        '''(experimental) Grants permission to view, in the Trusted Advisor console, all of the organizational units (OUs) in a parent organizational unit or root.

        Access Level: Read

        https://docs.aws.amazon.com/awssupport/latest/user/security-trusted-advisor.html#trusted-advisor-operations

        :stability: experimental
        '''
        return typing.cast("Trustedadvisor", jsii.invoke(self, "toListOrganizationalUnitsForParent", []))

    @jsii.member(jsii_name="toListRoots")
    def to_list_roots(self) -> "Trustedadvisor":
        '''(experimental) Grants permission to view, in the Trusted Advisor console, all of the roots that are defined in an AWS organization.

        Access Level: Read

        https://docs.aws.amazon.com/awssupport/latest/user/security-trusted-advisor.html#trusted-advisor-operations

        :stability: experimental
        '''
        return typing.cast("Trustedadvisor", jsii.invoke(self, "toListRoots", []))

    @jsii.member(jsii_name="toRefreshCheck")
    def to_refresh_check(self) -> "Trustedadvisor":
        '''(experimental) Grants permission to refresh an AWS Trusted Advisor check.

        Access Level: Write

        https://docs.aws.amazon.com/awssupport/latest/user/security-trusted-advisor.html#trusted-advisor-operations

        :stability: experimental
        '''
        return typing.cast("Trustedadvisor", jsii.invoke(self, "toRefreshCheck", []))

    @jsii.member(jsii_name="toSetAccountAccess")
    def to_set_account_access(self) -> "Trustedadvisor":
        '''(experimental) Grants permission to enable or disable AWS Trusted Advisor for the account.

        Access Level: Write

        https://docs.aws.amazon.com/awssupport/latest/user/security-trusted-advisor.html#trusted-advisor-operations

        :stability: experimental
        '''
        return typing.cast("Trustedadvisor", jsii.invoke(self, "toSetAccountAccess", []))

    @jsii.member(jsii_name="toSetOrganizationAccess")
    def to_set_organization_access(self) -> "Trustedadvisor":
        '''(experimental) Grants permission to enable the organizational view feature for AWS Trusted Advisor.

        Access Level: Write

        https://docs.aws.amazon.com/awssupport/latest/user/security-trusted-advisor.html#trusted-advisor-operations

        :stability: experimental
        '''
        return typing.cast("Trustedadvisor", jsii.invoke(self, "toSetOrganizationAccess", []))

    @jsii.member(jsii_name="toUpdateNotificationConfigurations")
    def to_update_notification_configurations(self) -> "Trustedadvisor":
        '''(experimental) Grants permission to create or update your email notification preferences for Trusted Advisor Priority.

        Access Level: Write

        https://docs.aws.amazon.com/awssupport/latest/user/security-trusted-advisor.html#trusted-advisor-operations

        :stability: experimental
        '''
        return typing.cast("Trustedadvisor", jsii.invoke(self, "toUpdateNotificationConfigurations", []))

    @jsii.member(jsii_name="toUpdateNotificationPreferences")
    def to_update_notification_preferences(self) -> "Trustedadvisor":
        '''(experimental) Grants permission to update notification preferences for AWS Trusted Advisor.

        Access Level: Write

        https://docs.aws.amazon.com/awssupport/latest/user/security-trusted-advisor.html#trusted-advisor-operations

        :stability: experimental
        '''
        return typing.cast("Trustedadvisor", jsii.invoke(self, "toUpdateNotificationPreferences", []))

    @jsii.member(jsii_name="toUpdateRiskStatus")
    def to_update_risk_status(self) -> "Trustedadvisor":
        '''(experimental) Grants permission to update the risk status in AWS Trusted Advisor Priority.

        Access Level: Write

        https://docs.aws.amazon.com/awssupport/latest/user/security-trusted-advisor.html#trusted-advisor-operations

        :stability: experimental
        '''
        return typing.cast("Trustedadvisor", jsii.invoke(self, "toUpdateRiskStatus", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b991861e2a98e906c8ce6a3a7ac981b34a65b7289b184cd784956fa7351190ff)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__99e7c39111cc6b742526c0bd19666e37c293c393384430fc937426266b5d3bc6)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class VendorInsights(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.VendorInsights",
):
    '''(experimental) Statement provider for service `vendor-insights <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsmarketplacevendorinsights.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `vendor-insights <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsmarketplacevendorinsights.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onDataSource")
    def on_data_source(
        self,
        resource_id: builtins.str,
        partition: typing.Optional[builtins.str] = None,
    ) -> "VendorInsights":
        '''(experimental) Adds a resource of type DataSource to the statement.

        https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsmarketplacevendorinsights.html#awsmarketplacevendorinsights-resources-for-iam-policies

        :param resource_id: - Identifier for the resourceId.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsRequestTag() - .ifAwsResourceTag() - .ifAwsTagKeys()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c39bfff3803114bae6272bac32ecb7d29c61f5251adfdb547ced9f0e2cb8dfda)
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("VendorInsights", jsii.invoke(self, "onDataSource", [resource_id, partition]))

    @jsii.member(jsii_name="onSecurityProfile")
    def on_security_profile(
        self,
        resource_id: builtins.str,
        partition: typing.Optional[builtins.str] = None,
    ) -> "VendorInsights":
        '''(experimental) Adds a resource of type SecurityProfile to the statement.

        https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsmarketplacevendorinsights.html#awsmarketplacevendorinsights-resources-for-iam-policies

        :param resource_id: - Identifier for the resourceId.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsRequestTag() - .ifAwsResourceTag() - .ifAwsTagKeys()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__492d27e727822754c2779a1861c19f041432a6fac813493d48956870f59d3292)
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("VendorInsights", jsii.invoke(self, "onSecurityProfile", [resource_id, partition]))

    @jsii.member(jsii_name="toActivateSecurityProfile")
    def to_activate_security_profile(self) -> "VendorInsights":
        '''(experimental) Grants permission to activate the security profile.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/marketplace/latest/userguide/vendor-insights-seller-controlling-access.html

        :stability: experimental
        '''
        return typing.cast("VendorInsights", jsii.invoke(self, "toActivateSecurityProfile", []))

    @jsii.member(jsii_name="toAssociateDataSource")
    def to_associate_data_source(self) -> "VendorInsights":
        '''(experimental) Grants permission to associate security profile with a data source.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        Dependent actions:

        - vendor-insights:GetDataSource

        https://docs.aws.amazon.com/marketplace/latest/userguide/vendor-insights-seller-controlling-access.html

        :stability: experimental
        '''
        return typing.cast("VendorInsights", jsii.invoke(self, "toAssociateDataSource", []))

    @jsii.member(jsii_name="toCreateDataSource")
    def to_create_data_source(self) -> "VendorInsights":
        '''(experimental) Grants permission to create a new data source.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()
        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - vendor-insights:TagResource

        https://docs.aws.amazon.com/marketplace/latest/userguide/vendor-insights-seller-controlling-access.html

        :stability: experimental
        '''
        return typing.cast("VendorInsights", jsii.invoke(self, "toCreateDataSource", []))

    @jsii.member(jsii_name="toCreateSecurityProfile")
    def to_create_security_profile(self) -> "VendorInsights":
        '''(experimental) Grants permission to create a new security profile.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()
        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - vendor-insights:TagResource

        https://docs.aws.amazon.com/marketplace/latest/userguide/vendor-insights-seller-controlling-access.html

        :stability: experimental
        '''
        return typing.cast("VendorInsights", jsii.invoke(self, "toCreateSecurityProfile", []))

    @jsii.member(jsii_name="toDeactivateSecurityProfile")
    def to_deactivate_security_profile(self) -> "VendorInsights":
        '''(experimental) Grants permission to deactivate the security profile.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/marketplace/latest/userguide/vendor-insights-seller-controlling-access.html

        :stability: experimental
        '''
        return typing.cast("VendorInsights", jsii.invoke(self, "toDeactivateSecurityProfile", []))

    @jsii.member(jsii_name="toDeleteDataSource")
    def to_delete_data_source(self) -> "VendorInsights":
        '''(experimental) Grants permission to delete a data source.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/marketplace/latest/userguide/vendor-insights-seller-controlling-access.html

        :stability: experimental
        '''
        return typing.cast("VendorInsights", jsii.invoke(self, "toDeleteDataSource", []))

    @jsii.member(jsii_name="toDisassociateDataSource")
    def to_disassociate_data_source(self) -> "VendorInsights":
        '''(experimental) Grants permission to disassociate security profile from a data source.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        Dependent actions:

        - vendor-insights:GetDataSource

        https://docs.aws.amazon.com/marketplace/latest/userguide/vendor-insights-seller-controlling-access.html

        :stability: experimental
        '''
        return typing.cast("VendorInsights", jsii.invoke(self, "toDisassociateDataSource", []))

    @jsii.member(jsii_name="toGetDataSource")
    def to_get_data_source(self) -> "VendorInsights":
        '''(experimental) Grants permission to retrieve the details of an existing data source.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/marketplace/latest/userguide/vendor-insights-seller-controlling-access.html

        :stability: experimental
        '''
        return typing.cast("VendorInsights", jsii.invoke(self, "toGetDataSource", []))

    @jsii.member(jsii_name="toGetEntitledSecurityProfileSnapshot")
    def to_get_entitled_security_profile_snapshot(self) -> "VendorInsights":
        '''(experimental) Grants permission to return the details of a security profile snapshot that requester is entitled to read.

        Access Level: Read

        https://docs.aws.amazon.com/marketplace/latest/buyerguide/buyer-vendor-insights-controlling-access.html

        :stability: experimental
        '''
        return typing.cast("VendorInsights", jsii.invoke(self, "toGetEntitledSecurityProfileSnapshot", []))

    @jsii.member(jsii_name="toGetProfileAccessTerms")
    def to_get_profile_access_terms(self) -> "VendorInsights":
        '''(experimental) Grants permission to get the access terms for a vendor insights profile.

        Access Level: Read

        https://docs.aws.amazon.com/marketplace/latest/buyerguide/buyer-vendor-insights-controlling-access.html

        :stability: experimental
        '''
        return typing.cast("VendorInsights", jsii.invoke(self, "toGetProfileAccessTerms", []))

    @jsii.member(jsii_name="toGetSecurityProfile")
    def to_get_security_profile(self) -> "VendorInsights":
        '''(experimental) Grants permission to return the details of an existing security profile.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/marketplace/latest/userguide/vendor-insights-seller-controlling-access.html

        :stability: experimental
        '''
        return typing.cast("VendorInsights", jsii.invoke(self, "toGetSecurityProfile", []))

    @jsii.member(jsii_name="toGetSecurityProfileSnapshot")
    def to_get_security_profile_snapshot(self) -> "VendorInsights":
        '''(experimental) Grants permission to return the details of a security profile snapshot.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/marketplace/latest/userguide/vendor-insights-seller-controlling-access.html

        :stability: experimental
        '''
        return typing.cast("VendorInsights", jsii.invoke(self, "toGetSecurityProfileSnapshot", []))

    @jsii.member(jsii_name="toListDataSources")
    def to_list_data_sources(self) -> "VendorInsights":
        '''(experimental) Grants permission to list existing data sources.

        Access Level: List

        https://docs.aws.amazon.com/marketplace/latest/userguide/vendor-insights-seller-controlling-access.html

        :stability: experimental
        '''
        return typing.cast("VendorInsights", jsii.invoke(self, "toListDataSources", []))

    @jsii.member(jsii_name="toListEntitledSecurityProfiles")
    def to_list_entitled_security_profiles(self) -> "VendorInsights":
        '''(experimental) Grants permission to list entitled security profiles.

        Access Level: List

        https://docs.aws.amazon.com/marketplace/latest/buyerguide/buyer-vendor-insights-controlling-access.html

        :stability: experimental
        '''
        return typing.cast("VendorInsights", jsii.invoke(self, "toListEntitledSecurityProfiles", []))

    @jsii.member(jsii_name="toListEntitledSecurityProfileSnapshots")
    def to_list_entitled_security_profile_snapshots(self) -> "VendorInsights":
        '''(experimental) Grants permission to return the snapshot summary list for an existing security profile that requester is entitled to list.

        Access Level: List

        https://docs.aws.amazon.com/marketplace/latest/buyerguide/buyer-vendor-insights-controlling-access.html

        :stability: experimental
        '''
        return typing.cast("VendorInsights", jsii.invoke(self, "toListEntitledSecurityProfileSnapshots", []))

    @jsii.member(jsii_name="toListSecurityProfiles")
    def to_list_security_profiles(self) -> "VendorInsights":
        '''(experimental) Grants permission to list existing security profiles.

        Access Level: List

        https://docs.aws.amazon.com/marketplace/latest/userguide/vendor-insights-seller-controlling-access.html

        :stability: experimental
        '''
        return typing.cast("VendorInsights", jsii.invoke(self, "toListSecurityProfiles", []))

    @jsii.member(jsii_name="toListSecurityProfileSnapshots")
    def to_list_security_profile_snapshots(self) -> "VendorInsights":
        '''(experimental) Grants permission to return the snapshot summary list for an existing security profile.

        Access Level: List

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/marketplace/latest/userguide/vendor-insights-seller-controlling-access.html

        :stability: experimental
        '''
        return typing.cast("VendorInsights", jsii.invoke(self, "toListSecurityProfileSnapshots", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "VendorInsights":
        '''(experimental) Grants permission to list tags for vendor insights resource.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/marketplace/latest/userguide/vendor-insights-seller-controlling-access.html

        :stability: experimental
        '''
        return typing.cast("VendorInsights", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "VendorInsights":
        '''(experimental) Grants permission to tag vendor insights resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsResourceTag()
        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/marketplace/latest/userguide/vendor-insights-seller-controlling-access.html

        :stability: experimental
        '''
        return typing.cast("VendorInsights", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "VendorInsights":
        '''(experimental) Grants permission to untag vendor insights resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsResourceTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/marketplace/latest/userguide/vendor-insights-seller-controlling-access.html

        :stability: experimental
        '''
        return typing.cast("VendorInsights", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateSecurityProfile")
    def to_update_security_profile(self) -> "VendorInsights":
        '''(experimental) Grants permission to update the security profile.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/marketplace/latest/userguide/vendor-insights-seller-controlling-access.html

        :stability: experimental
        '''
        return typing.cast("VendorInsights", jsii.invoke(self, "toUpdateSecurityProfile", []))

    @jsii.member(jsii_name="toUpdateSecurityProfileSnapshotCreationConfiguration")
    def to_update_security_profile_snapshot_creation_configuration(
        self,
    ) -> "VendorInsights":
        '''(experimental) Grants permission to update the security profile snapshot creation configuration.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/marketplace/latest/userguide/vendor-insights-seller-controlling-access.html

        :stability: experimental
        '''
        return typing.cast("VendorInsights", jsii.invoke(self, "toUpdateSecurityProfileSnapshotCreationConfiguration", []))

    @jsii.member(jsii_name="toUpdateSecurityProfileSnapshotReleaseConfiguration")
    def to_update_security_profile_snapshot_release_configuration(
        self,
    ) -> "VendorInsights":
        '''(experimental) Grants permission to update the security profile snapshot release configuration.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/marketplace/latest/userguide/vendor-insights-seller-controlling-access.html

        :stability: experimental
        '''
        return typing.cast("VendorInsights", jsii.invoke(self, "toUpdateSecurityProfileSnapshotReleaseConfiguration", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5c237feaca7017a5693cffb96556b9fd0677b846387614e6e81f72f642f08df5)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__70c54418264771a9c2ba0242520ef5a4ba727699d616a54f467261264954851a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Voiceid(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Voiceid",
):
    '''(experimental) Statement provider for service `voiceid <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonconnectvoiceid.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `voiceid <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonconnectvoiceid.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onDomain")
    def on_domain(
        self,
        domain_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Voiceid":
        '''(experimental) Adds a resource of type domain to the statement.

        https://docs.aws.amazon.com/connect/latest/adminguide/enable-voiceid.html#voiceid-domain

        :param domain_id: - Identifier for the domainId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b329a589724c8e883145f9ff4e75c575731605586f87c0b1cb9cdba81b34a597)
            check_type(argname="argument domain_id", value=domain_id, expected_type=type_hints["domain_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Voiceid", jsii.invoke(self, "onDomain", [domain_id, account, region, partition]))

    @jsii.member(jsii_name="toCreateDomain")
    def to_create_domain(self) -> "Voiceid":
        '''(experimental) Grants permission to create a domain.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/voiceid/latest/APIReference/API_CreateDomain.html

        :stability: experimental
        '''
        return typing.cast("Voiceid", jsii.invoke(self, "toCreateDomain", []))

    @jsii.member(jsii_name="toDeleteDomain")
    def to_delete_domain(self) -> "Voiceid":
        '''(experimental) Grants permission to delete a domain.

        Access Level: Write

        https://docs.aws.amazon.com/voiceid/latest/APIReference/API_DeleteDomain.html

        :stability: experimental
        '''
        return typing.cast("Voiceid", jsii.invoke(self, "toDeleteDomain", []))

    @jsii.member(jsii_name="toDeleteFraudster")
    def to_delete_fraudster(self) -> "Voiceid":
        '''(experimental) Grants permission to delete a fraudster.

        Access Level: Write

        https://docs.aws.amazon.com/voiceid/latest/APIReference/API_DeleteFraudster.html

        :stability: experimental
        '''
        return typing.cast("Voiceid", jsii.invoke(self, "toDeleteFraudster", []))

    @jsii.member(jsii_name="toDeleteSpeaker")
    def to_delete_speaker(self) -> "Voiceid":
        '''(experimental) Grants permission to delete a speaker.

        Access Level: Write

        https://docs.aws.amazon.com/voiceid/latest/APIReference/API_DeleteSpeaker.html

        :stability: experimental
        '''
        return typing.cast("Voiceid", jsii.invoke(self, "toDeleteSpeaker", []))

    @jsii.member(jsii_name="toDescribeComplianceConsent")
    def to_describe_compliance_consent(self) -> "Voiceid":
        '''(experimental) Grants permission to describe compliance consent.

        Access Level: Read

        https://docs.aws.amazon.com/connect/latest/adminguide/enable-voiceid.html#enable-voiceid-step1

        :stability: experimental
        '''
        return typing.cast("Voiceid", jsii.invoke(self, "toDescribeComplianceConsent", []))

    @jsii.member(jsii_name="toDescribeDomain")
    def to_describe_domain(self) -> "Voiceid":
        '''(experimental) Grants permission to describe a domain.

        Access Level: Read

        https://docs.aws.amazon.com/voiceid/latest/APIReference/API_DescribeDomain.html

        :stability: experimental
        '''
        return typing.cast("Voiceid", jsii.invoke(self, "toDescribeDomain", []))

    @jsii.member(jsii_name="toDescribeFraudster")
    def to_describe_fraudster(self) -> "Voiceid":
        '''(experimental) Grants permission to describe a fraudster.

        Access Level: Read

        https://docs.aws.amazon.com/voiceid/latest/APIReference/API_DescribeFraudster.html

        :stability: experimental
        '''
        return typing.cast("Voiceid", jsii.invoke(self, "toDescribeFraudster", []))

    @jsii.member(jsii_name="toDescribeFraudsterRegistrationJob")
    def to_describe_fraudster_registration_job(self) -> "Voiceid":
        '''(experimental) Grants permission to describe a fraudster registration job.

        Access Level: Read

        https://docs.aws.amazon.com/voiceid/latest/APIReference/API_DescribeFraudsterRegistrationJob.html

        :stability: experimental
        '''
        return typing.cast("Voiceid", jsii.invoke(self, "toDescribeFraudsterRegistrationJob", []))

    @jsii.member(jsii_name="toDescribeSpeaker")
    def to_describe_speaker(self) -> "Voiceid":
        '''(experimental) Grants permission to describe a speaker.

        Access Level: Read

        https://docs.aws.amazon.com/voiceid/latest/APIReference/API_DescribeSpeaker.html

        :stability: experimental
        '''
        return typing.cast("Voiceid", jsii.invoke(self, "toDescribeSpeaker", []))

    @jsii.member(jsii_name="toDescribeSpeakerEnrollmentJob")
    def to_describe_speaker_enrollment_job(self) -> "Voiceid":
        '''(experimental) Grants permission to describe a speaker enrollment job.

        Access Level: Read

        https://docs.aws.amazon.com/voiceid/latest/APIReference/API_DescribeSpeakerEnrollmentJob.html

        :stability: experimental
        '''
        return typing.cast("Voiceid", jsii.invoke(self, "toDescribeSpeakerEnrollmentJob", []))

    @jsii.member(jsii_name="toEvaluateSession")
    def to_evaluate_session(self) -> "Voiceid":
        '''(experimental) Grants permission to evaluate a session.

        Access Level: Write

        https://docs.aws.amazon.com/voiceid/latest/APIReference/API_EvaluateSession.html

        :stability: experimental
        '''
        return typing.cast("Voiceid", jsii.invoke(self, "toEvaluateSession", []))

    @jsii.member(jsii_name="toListDomains")
    def to_list_domains(self) -> "Voiceid":
        '''(experimental) Grants permission to list domains for an account.

        Access Level: List

        https://docs.aws.amazon.com/voiceid/latest/APIReference/API_ListDomains.html

        :stability: experimental
        '''
        return typing.cast("Voiceid", jsii.invoke(self, "toListDomains", []))

    @jsii.member(jsii_name="toListFraudsterRegistrationJobs")
    def to_list_fraudster_registration_jobs(self) -> "Voiceid":
        '''(experimental) Grants permission to list fraudster registration jobs for a domain.

        Access Level: List

        https://docs.aws.amazon.com/voiceid/latest/APIReference/API_ListFraudsterRegistrationJobs.html

        :stability: experimental
        '''
        return typing.cast("Voiceid", jsii.invoke(self, "toListFraudsterRegistrationJobs", []))

    @jsii.member(jsii_name="toListSpeakerEnrollmentJobs")
    def to_list_speaker_enrollment_jobs(self) -> "Voiceid":
        '''(experimental) Grants permission to list speaker enrollment jobs for a domain.

        Access Level: List

        https://docs.aws.amazon.com/voiceid/latest/APIReference/API_ListSpeakerEnrollmentJobs.html

        :stability: experimental
        '''
        return typing.cast("Voiceid", jsii.invoke(self, "toListSpeakerEnrollmentJobs", []))

    @jsii.member(jsii_name="toListSpeakers")
    def to_list_speakers(self) -> "Voiceid":
        '''(experimental) Grants permission to list speakers for a domain.

        Access Level: List

        https://docs.aws.amazon.com/voiceid/latest/APIReference/API_ListSpeakers.html

        :stability: experimental
        '''
        return typing.cast("Voiceid", jsii.invoke(self, "toListSpeakers", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Voiceid":
        '''(experimental) Grants permission to list tags for a Voice ID resource.

        Access Level: Read

        https://docs.aws.amazon.com/voiceid/latest/APIReference/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("Voiceid", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toOptOutSpeaker")
    def to_opt_out_speaker(self) -> "Voiceid":
        '''(experimental) Grants permission to opt out a speaker.

        Access Level: Write

        https://docs.aws.amazon.com/voiceid/latest/APIReference/API_OptOutSpeaker.html

        :stability: experimental
        '''
        return typing.cast("Voiceid", jsii.invoke(self, "toOptOutSpeaker", []))

    @jsii.member(jsii_name="toRegisterComplianceConsent")
    def to_register_compliance_consent(self) -> "Voiceid":
        '''(experimental) Grants permission to register compliance consent.

        Access Level: Write

        https://docs.aws.amazon.com/connect/latest/adminguide/enable-voiceid.html#enable-voiceid-step1

        :stability: experimental
        '''
        return typing.cast("Voiceid", jsii.invoke(self, "toRegisterComplianceConsent", []))

    @jsii.member(jsii_name="toStartFraudsterRegistrationJob")
    def to_start_fraudster_registration_job(self) -> "Voiceid":
        '''(experimental) Grants permission to start a fraudster registration job.

        Access Level: Write

        https://docs.aws.amazon.com/voiceid/latest/APIReference/API_StartFraudsterRegistrationJob.html

        :stability: experimental
        '''
        return typing.cast("Voiceid", jsii.invoke(self, "toStartFraudsterRegistrationJob", []))

    @jsii.member(jsii_name="toStartSpeakerEnrollmentJob")
    def to_start_speaker_enrollment_job(self) -> "Voiceid":
        '''(experimental) Grants permission to start a speaker enrollment job.

        Access Level: Write

        https://docs.aws.amazon.com/voiceid/latest/APIReference/API_StartSpeakerEnrollmentJob.html

        :stability: experimental
        '''
        return typing.cast("Voiceid", jsii.invoke(self, "toStartSpeakerEnrollmentJob", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Voiceid":
        '''(experimental) Grants permission to tag a Voice ID resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/voiceid/latest/APIReference/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("Voiceid", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Voiceid":
        '''(experimental) Grants permission to remove a tag from a Voice ID resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/voiceid/latest/APIReference/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("Voiceid", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateDomain")
    def to_update_domain(self) -> "Voiceid":
        '''(experimental) Grants permission to update a domain.

        Access Level: Write

        https://docs.aws.amazon.com/voiceid/latest/APIReference/API_UpdateDomain.html

        :stability: experimental
        '''
        return typing.cast("Voiceid", jsii.invoke(self, "toUpdateDomain", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fe98334824eb17a1ae4d848cbf91ab37e9ad13623e5b643f2f9cca305e625eda)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8946f78a08190edfedc5fc7022154a8d88e1965381b5a5ecf6d447e97de5b70a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class VpcLattice(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.VpcLattice",
):
    '''(experimental) Statement provider for service `vpc-lattice <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonvpclattice.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `vpc-lattice <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonvpclattice.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="ifAuthType")
    def if_auth_type(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "VpcLattice":
        '''(experimental) Filters access by the auth type specified in the request.

        https://aws.amazon.com/vpc/lattice

        Applies to actions:

        - .toCreateService()
        - .toCreateServiceNetwork()
        - .toUpdateService()
        - .toUpdateServiceNetwork()

        Applies to resource types:

        - ServiceNetwork
        - Service

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4d4cb29766035c6785047e49a48a81b0eb1c104b39eef688bc9283390a85e8f0)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("VpcLattice", jsii.invoke(self, "ifAuthType", [value, operator]))

    @jsii.member(jsii_name="ifProtocol")
    def if_protocol(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "VpcLattice":
        '''(experimental) Filters access by the protocol specified in the request.

        https://aws.amazon.com/vpc/lattice

        Applies to actions:

        - .toCreateListener()

        Applies to resource types:

        - Listener

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__06dc83cee1a57f4b63a244030a489faf44ffb6c23bd71b170b89f77499e850aa)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("VpcLattice", jsii.invoke(self, "ifProtocol", [value, operator]))

    @jsii.member(jsii_name="ifSecurityGroupIds")
    def if_security_group_ids(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "VpcLattice":
        '''(experimental) Filters access by the IDs of security groups.

        https://aws.amazon.com/vpc/lattice

        Applies to actions:

        - .toCreateServiceNetworkVpcAssociation()
        - .toUpdateServiceNetworkVpcAssociation()

        Applies to resource types:

        - ServiceNetworkVpcAssociation

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__02a6b596dcda22f265a44c0d14c6e255c39f19de5c588ae7cf0902a15825b04e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("VpcLattice", jsii.invoke(self, "ifSecurityGroupIds", [value, operator]))

    @jsii.member(jsii_name="ifServiceArn")
    def if_service_arn(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "VpcLattice":
        '''(experimental) Filters access by the ARN of a service.

        https://aws.amazon.com/vpc/lattice

        Applies to actions:

        - .toCreateServiceNetworkServiceAssociation()
        - .toDeleteServiceNetworkServiceAssociation()
        - .toGetServiceNetworkServiceAssociation()
        - .toListServiceNetworkServiceAssociations()

        Applies to resource types:

        - ServiceNetworkServiceAssociation

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3baffb97f90768ee2e7862b9293b2f08151693e7e02bb51d3dacba6c6b20a7c0)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("VpcLattice", jsii.invoke(self, "ifServiceArn", [value, operator]))

    @jsii.member(jsii_name="ifServiceNetworkArn")
    def if_service_network_arn(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "VpcLattice":
        '''(experimental) Filters access by the ARN of a service network.

        https://aws.amazon.com/vpc/lattice

        Applies to actions:

        - .toCreateServiceNetworkServiceAssociation()
        - .toCreateServiceNetworkVpcAssociation()
        - .toDeleteServiceNetworkServiceAssociation()
        - .toDeleteServiceNetworkVpcAssociation()
        - .toGetServiceNetworkServiceAssociation()
        - .toGetServiceNetworkVpcAssociation()
        - .toListServiceNetworkServiceAssociations()
        - .toListServiceNetworkVpcAssociations()
        - .toUpdateServiceNetworkVpcAssociation()

        Applies to resource types:

        - ServiceNetworkVpcAssociation
        - ServiceNetworkServiceAssociation

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6dc87d9125c6b2a75ed823c2f414e8a259b808591ef71bf511459d53559c75f9)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("VpcLattice", jsii.invoke(self, "ifServiceNetworkArn", [value, operator]))

    @jsii.member(jsii_name="ifTargetGroupArns")
    def if_target_group_arns(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "VpcLattice":
        '''(experimental) Filters access by the ARNs of target groups.

        https://aws.amazon.com/vpc/lattice

        Applies to actions:

        - .toCreateListener()
        - .toCreateRule()
        - .toUpdateListener()
        - .toUpdateRule()

        Applies to resource types:

        - Listener
        - Rule

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__82e250decd8353c559de8c68362b873476685f132e2be49fac4f6e6c9b4766c2)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("VpcLattice", jsii.invoke(self, "ifTargetGroupArns", [value, operator]))

    @jsii.member(jsii_name="ifVpcId")
    def if_vpc_id(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "VpcLattice":
        '''(experimental) Filters access by the ID of a virtual private cloud (VPC).

        https://aws.amazon.com/vpc/lattice

        Applies to actions:

        - .toCreateServiceNetworkVpcAssociation()
        - .toCreateTargetGroup()
        - .toDeleteServiceNetworkVpcAssociation()
        - .toGetServiceNetworkVpcAssociation()
        - .toListServiceNetworkVpcAssociations()
        - .toUpdateServiceNetworkVpcAssociation()

        Applies to resource types:

        - ServiceNetworkVpcAssociation
        - TargetGroup

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5af25b014132e006accae90abe7d2f44fd4cf65fbe8f2cf19754e1c3d7972085)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("VpcLattice", jsii.invoke(self, "ifVpcId", [value, operator]))

    @jsii.member(jsii_name="onAccessLogSubscription")
    def on_access_log_subscription(
        self,
        access_log_subscription_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "VpcLattice":
        '''(experimental) Adds a resource of type AccessLogSubscription to the statement.

        https://aws.amazon.com/vpc/lattice

        :param access_log_subscription_id: - Identifier for the accessLogSubscriptionId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsRequestTag() - .ifAwsResourceTag() - .ifAwsTagKeys()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__922f100acb4371c6666b1ced0e6ca008b4f7d23c66d5a165f937bd854483b296)
            check_type(argname="argument access_log_subscription_id", value=access_log_subscription_id, expected_type=type_hints["access_log_subscription_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("VpcLattice", jsii.invoke(self, "onAccessLogSubscription", [access_log_subscription_id, account, partition]))

    @jsii.member(jsii_name="onListener")
    def on_listener(
        self,
        service_id: builtins.str,
        listener_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "VpcLattice":
        '''(experimental) Adds a resource of type Listener to the statement.

        https://aws.amazon.com/vpc/lattice

        :param service_id: - Identifier for the serviceId.
        :param listener_id: - Identifier for the listenerId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsRequestTag() - .ifAwsResourceTag() - .ifAwsTagKeys() - .ifProtocol() - .ifTargetGroupArns()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9d62e4739e3c45e96f9a00e10b693cc6f34b45c1af1a50a6c6cc94cc7f707cd1)
            check_type(argname="argument service_id", value=service_id, expected_type=type_hints["service_id"])
            check_type(argname="argument listener_id", value=listener_id, expected_type=type_hints["listener_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("VpcLattice", jsii.invoke(self, "onListener", [service_id, listener_id, account, partition]))

    @jsii.member(jsii_name="onRule")
    def on_rule(
        self,
        service_id: builtins.str,
        listener_id: builtins.str,
        rule_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "VpcLattice":
        '''(experimental) Adds a resource of type Rule to the statement.

        https://aws.amazon.com/vpc/lattice

        :param service_id: - Identifier for the serviceId.
        :param listener_id: - Identifier for the listenerId.
        :param rule_id: - Identifier for the ruleId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsRequestTag() - .ifAwsResourceTag() - .ifAwsTagKeys() - .ifTargetGroupArns()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1957959de0609820c66db597e44e46eda2919dc1e9f94838206ded02648ab031)
            check_type(argname="argument service_id", value=service_id, expected_type=type_hints["service_id"])
            check_type(argname="argument listener_id", value=listener_id, expected_type=type_hints["listener_id"])
            check_type(argname="argument rule_id", value=rule_id, expected_type=type_hints["rule_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("VpcLattice", jsii.invoke(self, "onRule", [service_id, listener_id, rule_id, account, partition]))

    @jsii.member(jsii_name="onService")
    def on_service(
        self,
        service_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "VpcLattice":
        '''(experimental) Adds a resource of type Service to the statement.

        https://aws.amazon.com/vpc/lattice

        :param service_id: - Identifier for the serviceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsRequestTag() - .ifAwsResourceTag() - .ifAwsTagKeys() - .ifAuthType()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7b4062886ab0915c0ddfc465b8415875687cb896c5be651e554262df2b615ecd)
            check_type(argname="argument service_id", value=service_id, expected_type=type_hints["service_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("VpcLattice", jsii.invoke(self, "onService", [service_id, account, partition]))

    @jsii.member(jsii_name="onServiceNetwork")
    def on_service_network(
        self,
        service_network_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "VpcLattice":
        '''(experimental) Adds a resource of type ServiceNetwork to the statement.

        https://aws.amazon.com/vpc/lattice

        :param service_network_id: - Identifier for the serviceNetworkId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsRequestTag() - .ifAwsResourceTag() - .ifAwsTagKeys() - .ifAuthType()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fd8ef85439caad5d64ff053af93f824a950e1618c24ecc5c32fc0d2cb32e1ab1)
            check_type(argname="argument service_network_id", value=service_network_id, expected_type=type_hints["service_network_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("VpcLattice", jsii.invoke(self, "onServiceNetwork", [service_network_id, account, partition]))

    @jsii.member(jsii_name="onServiceNetworkServiceAssociation")
    def on_service_network_service_association(
        self,
        service_network_service_association_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "VpcLattice":
        '''(experimental) Adds a resource of type ServiceNetworkServiceAssociation to the statement.

        https://aws.amazon.com/vpc/lattice

        :param service_network_service_association_id: - Identifier for the serviceNetworkServiceAssociationId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsRequestTag() - .ifAwsResourceTag() - .ifAwsTagKeys() - .ifServiceArn() - .ifServiceNetworkArn()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6246f08febb437b74665795b16bf99b84f65afd824422b4348786f7e585f1348)
            check_type(argname="argument service_network_service_association_id", value=service_network_service_association_id, expected_type=type_hints["service_network_service_association_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("VpcLattice", jsii.invoke(self, "onServiceNetworkServiceAssociation", [service_network_service_association_id, account, partition]))

    @jsii.member(jsii_name="onServiceNetworkVpcAssociation")
    def on_service_network_vpc_association(
        self,
        service_network_vpc_association_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "VpcLattice":
        '''(experimental) Adds a resource of type ServiceNetworkVpcAssociation to the statement.

        https://aws.amazon.com/vpc/lattice

        :param service_network_vpc_association_id: - Identifier for the serviceNetworkVpcAssociationId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsRequestTag() - .ifAwsResourceTag() - .ifAwsTagKeys() - .ifSecurityGroupIds() - .ifServiceNetworkArn() - .ifVpcId()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7258ac89ebd894b17ed4ce723e2e6f218a9be00c5cb7e8e32a3baaf0833ccac5)
            check_type(argname="argument service_network_vpc_association_id", value=service_network_vpc_association_id, expected_type=type_hints["service_network_vpc_association_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("VpcLattice", jsii.invoke(self, "onServiceNetworkVpcAssociation", [service_network_vpc_association_id, account, partition]))

    @jsii.member(jsii_name="onTargetGroup")
    def on_target_group(
        self,
        target_group_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "VpcLattice":
        '''(experimental) Adds a resource of type TargetGroup to the statement.

        https://aws.amazon.com/vpc/lattice

        :param target_group_id: - Identifier for the targetGroupId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsRequestTag() - .ifAwsResourceTag() - .ifAwsTagKeys() - .ifVpcId()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2affbf42ea3184d2ca4f084740013a862b0ebb115067ba41da8cd74cd0191f32)
            check_type(argname="argument target_group_id", value=target_group_id, expected_type=type_hints["target_group_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("VpcLattice", jsii.invoke(self, "onTargetGroup", [target_group_id, account, partition]))

    @jsii.member(jsii_name="toCreateAccessLogSubscription")
    def to_create_access_log_subscription(self) -> "VpcLattice":
        '''(experimental) Grants permission to create an access log subscription.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        Dependent actions:

        - logs:CreateLogDelivery
        - logs:GetLogDelivery

        https://aws.amazon.com/vpc/lattice

        :stability: experimental
        '''
        return typing.cast("VpcLattice", jsii.invoke(self, "toCreateAccessLogSubscription", []))

    @jsii.member(jsii_name="toCreateListener")
    def to_create_listener(self) -> "VpcLattice":
        '''(experimental) Grants permission to create a listener.

        Access Level: Write

        Possible conditions:

        - .ifProtocol()
        - .ifTargetGroupArns()
        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://aws.amazon.com/vpc/lattice

        :stability: experimental
        '''
        return typing.cast("VpcLattice", jsii.invoke(self, "toCreateListener", []))

    @jsii.member(jsii_name="toCreateRule")
    def to_create_rule(self) -> "VpcLattice":
        '''(experimental) Grants permission to create a rule.

        Access Level: Write

        Possible conditions:

        - .ifTargetGroupArns()
        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://aws.amazon.com/vpc/lattice

        :stability: experimental
        '''
        return typing.cast("VpcLattice", jsii.invoke(self, "toCreateRule", []))

    @jsii.member(jsii_name="toCreateService")
    def to_create_service(self) -> "VpcLattice":
        '''(experimental) Grants permission to create a service.

        Access Level: Write

        Possible conditions:

        - .ifAuthType()
        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        Dependent actions:

        - iam:CreateServiceLinkedRole

        https://aws.amazon.com/vpc/lattice

        :stability: experimental
        '''
        return typing.cast("VpcLattice", jsii.invoke(self, "toCreateService", []))

    @jsii.member(jsii_name="toCreateServiceNetwork")
    def to_create_service_network(self) -> "VpcLattice":
        '''(experimental) Grants permission to create a service network.

        Access Level: Write

        Possible conditions:

        - .ifAuthType()
        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        Dependent actions:

        - iam:CreateServiceLinkedRole

        https://aws.amazon.com/vpc/lattice

        :stability: experimental
        '''
        return typing.cast("VpcLattice", jsii.invoke(self, "toCreateServiceNetwork", []))

    @jsii.member(jsii_name="toCreateServiceNetworkServiceAssociation")
    def to_create_service_network_service_association(self) -> "VpcLattice":
        '''(experimental) Grants permission to create a service network and service association.

        Access Level: Write

        Possible conditions:

        - .ifServiceNetworkArn()
        - .ifServiceArn()
        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://aws.amazon.com/vpc/lattice

        :stability: experimental
        '''
        return typing.cast("VpcLattice", jsii.invoke(self, "toCreateServiceNetworkServiceAssociation", []))

    @jsii.member(jsii_name="toCreateServiceNetworkVpcAssociation")
    def to_create_service_network_vpc_association(self) -> "VpcLattice":
        '''(experimental) Grants permission to create a service network and VPC association.

        Access Level: Write

        Possible conditions:

        - .ifVpcId()
        - .ifServiceNetworkArn()
        - .ifSecurityGroupIds()
        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        Dependent actions:

        - ec2:DescribeVpcs

        https://aws.amazon.com/vpc/lattice

        :stability: experimental
        '''
        return typing.cast("VpcLattice", jsii.invoke(self, "toCreateServiceNetworkVpcAssociation", []))

    @jsii.member(jsii_name="toCreateTargetGroup")
    def to_create_target_group(self) -> "VpcLattice":
        '''(experimental) Grants permission to create a target group.

        Access Level: Write

        Possible conditions:

        - .ifVpcId()
        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        Dependent actions:

        - iam:CreateServiceLinkedRole

        https://aws.amazon.com/vpc/lattice

        :stability: experimental
        '''
        return typing.cast("VpcLattice", jsii.invoke(self, "toCreateTargetGroup", []))

    @jsii.member(jsii_name="toDeleteAccessLogSubscription")
    def to_delete_access_log_subscription(self) -> "VpcLattice":
        '''(experimental) Grants permission to delete an access log subscription.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        Dependent actions:

        - logs:DeleteLogDelivery
        - logs:GetLogDelivery

        https://aws.amazon.com/vpc/lattice

        :stability: experimental
        '''
        return typing.cast("VpcLattice", jsii.invoke(self, "toDeleteAccessLogSubscription", []))

    @jsii.member(jsii_name="toDeleteAuthPolicy")
    def to_delete_auth_policy(self) -> "VpcLattice":
        '''(experimental) Grants permission to delete an auth policy.

        Access Level: Permissions management

        https://aws.amazon.com/vpc/lattice

        :stability: experimental
        '''
        return typing.cast("VpcLattice", jsii.invoke(self, "toDeleteAuthPolicy", []))

    @jsii.member(jsii_name="toDeleteListener")
    def to_delete_listener(self) -> "VpcLattice":
        '''(experimental) Grants permission to delete a listener.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://aws.amazon.com/vpc/lattice

        :stability: experimental
        '''
        return typing.cast("VpcLattice", jsii.invoke(self, "toDeleteListener", []))

    @jsii.member(jsii_name="toDeleteResourcePolicy")
    def to_delete_resource_policy(self) -> "VpcLattice":
        '''(experimental) Grants permission to delete a resource policy.

        Access Level: Write

        https://aws.amazon.com/vpc/lattice

        :stability: experimental
        '''
        return typing.cast("VpcLattice", jsii.invoke(self, "toDeleteResourcePolicy", []))

    @jsii.member(jsii_name="toDeleteRule")
    def to_delete_rule(self) -> "VpcLattice":
        '''(experimental) Grants permission to delete a rule.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://aws.amazon.com/vpc/lattice

        :stability: experimental
        '''
        return typing.cast("VpcLattice", jsii.invoke(self, "toDeleteRule", []))

    @jsii.member(jsii_name="toDeleteService")
    def to_delete_service(self) -> "VpcLattice":
        '''(experimental) Grants permission to delete a service.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://aws.amazon.com/vpc/lattice

        :stability: experimental
        '''
        return typing.cast("VpcLattice", jsii.invoke(self, "toDeleteService", []))

    @jsii.member(jsii_name="toDeleteServiceNetwork")
    def to_delete_service_network(self) -> "VpcLattice":
        '''(experimental) Grants permission to delete a service network.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://aws.amazon.com/vpc/lattice

        :stability: experimental
        '''
        return typing.cast("VpcLattice", jsii.invoke(self, "toDeleteServiceNetwork", []))

    @jsii.member(jsii_name="toDeleteServiceNetworkServiceAssociation")
    def to_delete_service_network_service_association(self) -> "VpcLattice":
        '''(experimental) Grants permission to delete a service network service association.

        Access Level: Write

        Possible conditions:

        - .ifServiceNetworkArn()
        - .ifServiceArn()
        - .ifAwsResourceTag()

        https://aws.amazon.com/vpc/lattice

        :stability: experimental
        '''
        return typing.cast("VpcLattice", jsii.invoke(self, "toDeleteServiceNetworkServiceAssociation", []))

    @jsii.member(jsii_name="toDeleteServiceNetworkVpcAssociation")
    def to_delete_service_network_vpc_association(self) -> "VpcLattice":
        '''(experimental) Grants permission to delete a service network and VPC association.

        Access Level: Write

        Possible conditions:

        - .ifVpcId()
        - .ifServiceNetworkArn()
        - .ifAwsResourceTag()

        https://aws.amazon.com/vpc/lattice

        :stability: experimental
        '''
        return typing.cast("VpcLattice", jsii.invoke(self, "toDeleteServiceNetworkVpcAssociation", []))

    @jsii.member(jsii_name="toDeleteTargetGroup")
    def to_delete_target_group(self) -> "VpcLattice":
        '''(experimental) Grants permission to delete a target group.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://aws.amazon.com/vpc/lattice

        :stability: experimental
        '''
        return typing.cast("VpcLattice", jsii.invoke(self, "toDeleteTargetGroup", []))

    @jsii.member(jsii_name="toDeregisterTargets")
    def to_deregister_targets(self) -> "VpcLattice":
        '''(experimental) Grants permission to deregister targets from a target group.

        Access Level: Write

        https://aws.amazon.com/vpc/lattice

        :stability: experimental
        '''
        return typing.cast("VpcLattice", jsii.invoke(self, "toDeregisterTargets", []))

    @jsii.member(jsii_name="toGetAccessLogSubscription")
    def to_get_access_log_subscription(self) -> "VpcLattice":
        '''(experimental) Grants permission to get information about an access log subscription.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()

        Dependent actions:

        - logs:GetLogDelivery

        https://aws.amazon.com/vpc/lattice

        :stability: experimental
        '''
        return typing.cast("VpcLattice", jsii.invoke(self, "toGetAccessLogSubscription", []))

    @jsii.member(jsii_name="toGetAuthPolicy")
    def to_get_auth_policy(self) -> "VpcLattice":
        '''(experimental) Grants permission to get information about an auth policy.

        Access Level: Read

        https://aws.amazon.com/vpc/lattice

        :stability: experimental
        '''
        return typing.cast("VpcLattice", jsii.invoke(self, "toGetAuthPolicy", []))

    @jsii.member(jsii_name="toGetListener")
    def to_get_listener(self) -> "VpcLattice":
        '''(experimental) Grants permission to get information about a listener.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()

        https://aws.amazon.com/vpc/lattice

        :stability: experimental
        '''
        return typing.cast("VpcLattice", jsii.invoke(self, "toGetListener", []))

    @jsii.member(jsii_name="toGetResourcePolicy")
    def to_get_resource_policy(self) -> "VpcLattice":
        '''(experimental) Grants permission to get information about a resource policy.

        Access Level: Read

        https://aws.amazon.com/vpc/lattice

        :stability: experimental
        '''
        return typing.cast("VpcLattice", jsii.invoke(self, "toGetResourcePolicy", []))

    @jsii.member(jsii_name="toGetRule")
    def to_get_rule(self) -> "VpcLattice":
        '''(experimental) Grants permission to get information about a rule.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()

        https://aws.amazon.com/vpc/lattice

        :stability: experimental
        '''
        return typing.cast("VpcLattice", jsii.invoke(self, "toGetRule", []))

    @jsii.member(jsii_name="toGetService")
    def to_get_service(self) -> "VpcLattice":
        '''(experimental) Grants permission to get information about a service.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()

        https://aws.amazon.com/vpc/lattice

        :stability: experimental
        '''
        return typing.cast("VpcLattice", jsii.invoke(self, "toGetService", []))

    @jsii.member(jsii_name="toGetServiceNetwork")
    def to_get_service_network(self) -> "VpcLattice":
        '''(experimental) Grants permission to get information about a service network.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()

        https://aws.amazon.com/vpc/lattice

        :stability: experimental
        '''
        return typing.cast("VpcLattice", jsii.invoke(self, "toGetServiceNetwork", []))

    @jsii.member(jsii_name="toGetServiceNetworkServiceAssociation")
    def to_get_service_network_service_association(self) -> "VpcLattice":
        '''(experimental) Grants permission to get information about a service network and service association.

        Access Level: Read

        Possible conditions:

        - .ifServiceNetworkArn()
        - .ifServiceArn()
        - .ifAwsResourceTag()

        https://aws.amazon.com/vpc/lattice

        :stability: experimental
        '''
        return typing.cast("VpcLattice", jsii.invoke(self, "toGetServiceNetworkServiceAssociation", []))

    @jsii.member(jsii_name="toGetServiceNetworkVpcAssociation")
    def to_get_service_network_vpc_association(self) -> "VpcLattice":
        '''(experimental) Grants permission to get information about a service network and VPC association.

        Access Level: Read

        Possible conditions:

        - .ifVpcId()
        - .ifServiceNetworkArn()
        - .ifAwsResourceTag()

        https://aws.amazon.com/vpc/lattice

        :stability: experimental
        '''
        return typing.cast("VpcLattice", jsii.invoke(self, "toGetServiceNetworkVpcAssociation", []))

    @jsii.member(jsii_name="toGetTargetGroup")
    def to_get_target_group(self) -> "VpcLattice":
        '''(experimental) Grants permission to get information about a target group.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()

        https://aws.amazon.com/vpc/lattice

        :stability: experimental
        '''
        return typing.cast("VpcLattice", jsii.invoke(self, "toGetTargetGroup", []))

    @jsii.member(jsii_name="toListAccessLogSubscriptions")
    def to_list_access_log_subscriptions(self) -> "VpcLattice":
        '''(experimental) Grants permission to list some or all access log subscriptions about a service network or a service.

        Access Level: List

        https://aws.amazon.com/vpc/lattice

        :stability: experimental
        '''
        return typing.cast("VpcLattice", jsii.invoke(self, "toListAccessLogSubscriptions", []))

    @jsii.member(jsii_name="toListListeners")
    def to_list_listeners(self) -> "VpcLattice":
        '''(experimental) Grants permission to list some or all listeners.

        Access Level: List

        https://aws.amazon.com/vpc/lattice

        :stability: experimental
        '''
        return typing.cast("VpcLattice", jsii.invoke(self, "toListListeners", []))

    @jsii.member(jsii_name="toListRules")
    def to_list_rules(self) -> "VpcLattice":
        '''(experimental) Grants permission to list some or all rules.

        Access Level: List

        https://aws.amazon.com/vpc/lattice

        :stability: experimental
        '''
        return typing.cast("VpcLattice", jsii.invoke(self, "toListRules", []))

    @jsii.member(jsii_name="toListServiceNetworks")
    def to_list_service_networks(self) -> "VpcLattice":
        '''(experimental) Grants permission to list the service networks owned by a caller account or shared with the caller account.

        Access Level: List

        https://aws.amazon.com/vpc/lattice

        :stability: experimental
        '''
        return typing.cast("VpcLattice", jsii.invoke(self, "toListServiceNetworks", []))

    @jsii.member(jsii_name="toListServiceNetworkServiceAssociations")
    def to_list_service_network_service_associations(self) -> "VpcLattice":
        '''(experimental) Grants permission to list some or all service network and service associations.

        Access Level: List

        Possible conditions:

        - .ifServiceNetworkArn()
        - .ifServiceArn()

        https://aws.amazon.com/vpc/lattice

        :stability: experimental
        '''
        return typing.cast("VpcLattice", jsii.invoke(self, "toListServiceNetworkServiceAssociations", []))

    @jsii.member(jsii_name="toListServiceNetworkVpcAssociations")
    def to_list_service_network_vpc_associations(self) -> "VpcLattice":
        '''(experimental) Grants permission to list some or all service network and VPC associations.

        Access Level: List

        Possible conditions:

        - .ifVpcId()
        - .ifServiceNetworkArn()

        https://aws.amazon.com/vpc/lattice

        :stability: experimental
        '''
        return typing.cast("VpcLattice", jsii.invoke(self, "toListServiceNetworkVpcAssociations", []))

    @jsii.member(jsii_name="toListServices")
    def to_list_services(self) -> "VpcLattice":
        '''(experimental) Grants permission to list the services owned by a caller account or shared with the caller account.

        Access Level: List

        https://aws.amazon.com/vpc/lattice

        :stability: experimental
        '''
        return typing.cast("VpcLattice", jsii.invoke(self, "toListServices", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "VpcLattice":
        '''(experimental) Grants permission to list tags for a vpc-lattice resource.

        Access Level: Read

        https://aws.amazon.com/vpc/lattice

        :stability: experimental
        '''
        return typing.cast("VpcLattice", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toListTargetGroups")
    def to_list_target_groups(self) -> "VpcLattice":
        '''(experimental) Grants permission to list some or all target groups.

        Access Level: List

        https://aws.amazon.com/vpc/lattice

        :stability: experimental
        '''
        return typing.cast("VpcLattice", jsii.invoke(self, "toListTargetGroups", []))

    @jsii.member(jsii_name="toListTargets")
    def to_list_targets(self) -> "VpcLattice":
        '''(experimental) Grants permission to list some or all targets in a target group.

        Access Level: List

        https://aws.amazon.com/vpc/lattice

        :stability: experimental
        '''
        return typing.cast("VpcLattice", jsii.invoke(self, "toListTargets", []))

    @jsii.member(jsii_name="toPutAuthPolicy")
    def to_put_auth_policy(self) -> "VpcLattice":
        '''(experimental) Grants permission to create or update the auth policy for a service network or a service.

        Access Level: Permissions management

        https://aws.amazon.com/vpc/lattice

        :stability: experimental
        '''
        return typing.cast("VpcLattice", jsii.invoke(self, "toPutAuthPolicy", []))

    @jsii.member(jsii_name="toPutResourcePolicy")
    def to_put_resource_policy(self) -> "VpcLattice":
        '''(experimental) Grants permission to create a resource policy for a service network or a service.

        Access Level: Write

        https://aws.amazon.com/vpc/lattice

        :stability: experimental
        '''
        return typing.cast("VpcLattice", jsii.invoke(self, "toPutResourcePolicy", []))

    @jsii.member(jsii_name="toRegisterTargets")
    def to_register_targets(self) -> "VpcLattice":
        '''(experimental) Grants permission to register targets to a target group.

        Access Level: Write

        https://aws.amazon.com/vpc/lattice

        :stability: experimental
        '''
        return typing.cast("VpcLattice", jsii.invoke(self, "toRegisterTargets", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "VpcLattice":
        '''(experimental) Grants permission to tag a vpc-lattice resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()
        - .ifAwsResourceTag()

        https://aws.amazon.com/vpc/lattice

        :stability: experimental
        '''
        return typing.cast("VpcLattice", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "VpcLattice":
        '''(experimental) Grants permission to untag a vpc-lattice resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://aws.amazon.com/vpc/lattice

        :stability: experimental
        '''
        return typing.cast("VpcLattice", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateAccessLogSubscription")
    def to_update_access_log_subscription(self) -> "VpcLattice":
        '''(experimental) Grants permission to update an access log subscription.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        Dependent actions:

        - logs:GetLogDelivery
        - logs:UpdateLogDelivery

        https://aws.amazon.com/vpc/lattice

        :stability: experimental
        '''
        return typing.cast("VpcLattice", jsii.invoke(self, "toUpdateAccessLogSubscription", []))

    @jsii.member(jsii_name="toUpdateListener")
    def to_update_listener(self) -> "VpcLattice":
        '''(experimental) Grants permission to update a listener.

        Access Level: Write

        Possible conditions:

        - .ifTargetGroupArns()
        - .ifAwsResourceTag()

        https://aws.amazon.com/vpc/lattice

        :stability: experimental
        '''
        return typing.cast("VpcLattice", jsii.invoke(self, "toUpdateListener", []))

    @jsii.member(jsii_name="toUpdateRule")
    def to_update_rule(self) -> "VpcLattice":
        '''(experimental) Grants permission to update a rule.

        Access Level: Write

        Possible conditions:

        - .ifTargetGroupArns()
        - .ifAwsResourceTag()

        https://aws.amazon.com/vpc/lattice

        :stability: experimental
        '''
        return typing.cast("VpcLattice", jsii.invoke(self, "toUpdateRule", []))

    @jsii.member(jsii_name="toUpdateService")
    def to_update_service(self) -> "VpcLattice":
        '''(experimental) Grants permission to update a service.

        Access Level: Write

        Possible conditions:

        - .ifAuthType()
        - .ifAwsResourceTag()

        https://aws.amazon.com/vpc/lattice

        :stability: experimental
        '''
        return typing.cast("VpcLattice", jsii.invoke(self, "toUpdateService", []))

    @jsii.member(jsii_name="toUpdateServiceNetwork")
    def to_update_service_network(self) -> "VpcLattice":
        '''(experimental) Grants permission to update a service network.

        Access Level: Write

        Possible conditions:

        - .ifAuthType()
        - .ifAwsResourceTag()

        https://aws.amazon.com/vpc/lattice

        :stability: experimental
        '''
        return typing.cast("VpcLattice", jsii.invoke(self, "toUpdateServiceNetwork", []))

    @jsii.member(jsii_name="toUpdateServiceNetworkVpcAssociation")
    def to_update_service_network_vpc_association(self) -> "VpcLattice":
        '''(experimental) Grants permission to update a service network and VPC association.

        Access Level: Write

        Possible conditions:

        - .ifVpcId()
        - .ifServiceNetworkArn()
        - .ifSecurityGroupIds()
        - .ifAwsResourceTag()

        Dependent actions:

        - ec2:DescribeSecurityGroups
        - ec2:DescribeVpcs

        https://aws.amazon.com/vpc/lattice

        :stability: experimental
        '''
        return typing.cast("VpcLattice", jsii.invoke(self, "toUpdateServiceNetworkVpcAssociation", []))

    @jsii.member(jsii_name="toUpdateTargetGroup")
    def to_update_target_group(self) -> "VpcLattice":
        '''(experimental) Grants permission to update a target group.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://aws.amazon.com/vpc/lattice

        :stability: experimental
        '''
        return typing.cast("VpcLattice", jsii.invoke(self, "toUpdateTargetGroup", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4c242774037627b043402bb4bde53f102f0de7edf586de9cf1725b92b17da00c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__dfe0638de1707024543363fc28a20415e82bd32c70a770a0c287d4d9f40067fd)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class VpcLatticeSvcs(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.VpcLatticeSvcs",
):
    '''(experimental) Statement provider for service `vpc-lattice-svcs <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonvpclatticeservices.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `vpc-lattice-svcs <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonvpclatticeservices.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="ifPort")
    def if_port(
        self,
        value: typing.Union[jsii.Number, typing.Sequence[jsii.Number]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "VpcLatticeSvcs":
        '''(experimental) Filters access by the destination port the request is made to.

        https://aws.amazon.com/vpc/lattice

        Applies to actions:

        - .toInvoke()

        :param value: The value(s) to check.
        :param operator: Works with `numeric operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_Numeric>`_. **Default:** ``NumericEquals``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3b88b41a34b7d16296ba6d311a3197c8e98634885d063f79c95599eebb5a4cae)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("VpcLatticeSvcs", jsii.invoke(self, "ifPort", [value, operator]))

    @jsii.member(jsii_name="ifRequestHeader")
    def if_request_header(
        self,
        header_name: builtins.str,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "VpcLatticeSvcs":
        '''(experimental) Filters access by a header name-value pair in the request headers.

        https://aws.amazon.com/vpc/lattice

        Applies to actions:

        - .toInvoke()

        :param header_name: The tag key to check.
        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__24b9b5e982036271f8dc8fffd756cfa3d9953bc1d8b4a8880e838074c532507c)
            check_type(argname="argument header_name", value=header_name, expected_type=type_hints["header_name"])
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("VpcLatticeSvcs", jsii.invoke(self, "ifRequestHeader", [header_name, value, operator]))

    @jsii.member(jsii_name="ifRequestMethod")
    def if_request_method(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "VpcLatticeSvcs":
        '''(experimental) Filters access by the method of the request.

        https://aws.amazon.com/vpc/lattice

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b9c02a57ef2c1ff8a1cac279f0da0f59558494bbda2a3e83eebed3004906fe95)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("VpcLatticeSvcs", jsii.invoke(self, "ifRequestMethod", [value, operator]))

    @jsii.member(jsii_name="ifRequestQueryString")
    def if_request_query_string(
        self,
        query_string_key: builtins.str,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "VpcLatticeSvcs":
        '''(experimental) Filters access by the query string key-value pairs in the request URL.

        https://aws.amazon.com/vpc/lattice

        Applies to actions:

        - .toInvoke()

        :param query_string_key: The tag key to check.
        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0faa5050134d67a26d24e7c578fcbf03e2caac45d5dd6f9d2da10d52d73a3b20)
            check_type(argname="argument query_string_key", value=query_string_key, expected_type=type_hints["query_string_key"])
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("VpcLatticeSvcs", jsii.invoke(self, "ifRequestQueryString", [query_string_key, value, operator]))

    @jsii.member(jsii_name="ifServiceArn")
    def if_service_arn(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "VpcLatticeSvcs":
        '''(experimental) Filters access by the ARN of the service receiving the request.

        https://aws.amazon.com/vpc/lattice

        Applies to actions:

        - .toInvoke()

        :param value: The value(s) to check.
        :param operator: Works with `arn operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_ARN>`_. **Default:** ``ArnLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e4b9e3d7a1f4fefea3a1d9171d204da29e17a105290007b557860de4a28f6bf3)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("VpcLatticeSvcs", jsii.invoke(self, "ifServiceArn", [value, operator]))

    @jsii.member(jsii_name="ifServiceNetworkArn")
    def if_service_network_arn(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "VpcLatticeSvcs":
        '''(experimental) Filters access by the ARN of the service network receiving the request.

        https://aws.amazon.com/vpc/lattice

        Applies to actions:

        - .toInvoke()

        :param value: The value(s) to check.
        :param operator: Works with `arn operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_ARN>`_. **Default:** ``ArnLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5b74664e4c0623e0669f39ca3ec5fe17b1c4de5987c0929dd5e218576497c468)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("VpcLatticeSvcs", jsii.invoke(self, "ifServiceNetworkArn", [value, operator]))

    @jsii.member(jsii_name="ifSourceVpc")
    def if_source_vpc(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "VpcLatticeSvcs":
        '''(experimental) Filters access by the VPC the request is made from.

        https://aws.amazon.com/vpc/lattice

        Applies to actions:

        - .toInvoke()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d62660d41119635ed50dc335e38a850823d2054da6c12f54da255d4eaadbe57d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("VpcLatticeSvcs", jsii.invoke(self, "ifSourceVpc", [value, operator]))

    @jsii.member(jsii_name="ifSourceVpcOwnerAccount")
    def if_source_vpc_owner_account(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "VpcLatticeSvcs":
        '''(experimental) Filters access by the owning account of the VPC the request is made from.

        https://aws.amazon.com/vpc/lattice

        Applies to actions:

        - .toInvoke()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__416135916283557e4b223098c7be2ace8467dc5c6e22fd74eca67247c4c65ba0)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("VpcLatticeSvcs", jsii.invoke(self, "ifSourceVpcOwnerAccount", [value, operator]))

    @jsii.member(jsii_name="onService")
    def on_service(
        self,
        service_id: builtins.str,
        request_path: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "VpcLatticeSvcs":
        '''(experimental) Adds a resource of type Service to the statement.

        https://aws.amazon.com/vpc/lattice

        :param service_id: - Identifier for the serviceId.
        :param request_path: - Identifier for the requestPath.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__af27088006a148cc200fa41c7d5b43d6d4c044c4c719cfe9297b12b97a5c3d18)
            check_type(argname="argument service_id", value=service_id, expected_type=type_hints["service_id"])
            check_type(argname="argument request_path", value=request_path, expected_type=type_hints["request_path"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("VpcLatticeSvcs", jsii.invoke(self, "onService", [service_id, request_path, account, region, partition]))

    @jsii.member(jsii_name="toInvoke")
    def to_invoke(self) -> "VpcLatticeSvcs":
        '''(experimental) Grants permission to invoke a VPC Lattice service.

        Access Level: Write

        Possible conditions:

        - .ifPort()
        - .ifServiceNetworkArn()
        - .ifServiceArn()
        - .ifSourceVpc()
        - .ifSourceVpcOwnerAccount()
        - .ifRequestHeader()
        - .ifRequestQueryString()

        https://aws.amazon.com/vpc/lattice

        :stability: experimental
        '''
        return typing.cast("VpcLatticeSvcs", jsii.invoke(self, "toInvoke", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fb9507a0c13718f1f477998405e2fc7a6893ebd17b835a9c91ced7f735e94fcc)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6a1653b55be2e6c6a443e0bd2661d91f962249fd746fa8acbd5d8da48d312165)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Waf(PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Waf"):
    '''(experimental) Statement provider for service `waf <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awswaf.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `waf <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awswaf.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onBytematchset")
    def on_bytematchset(
        self,
        id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Waf":
        '''(experimental) Adds a resource of type bytematchset to the statement.

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_ByteMatchSet.html

        :param id: - Identifier for the id.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__76779c1a4bc34aa4e430b156d43dd79891bebaf965806363738636544c593b7f)
            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Waf", jsii.invoke(self, "onBytematchset", [id, account, partition]))

    @jsii.member(jsii_name="onGeomatchset")
    def on_geomatchset(
        self,
        id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Waf":
        '''(experimental) Adds a resource of type geomatchset to the statement.

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_GeoMatchSet.html

        :param id: - Identifier for the id.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__acc2fa5d84be641300b75cfa40fdc39b032209f46f3a6021adbcc11b31783924)
            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Waf", jsii.invoke(self, "onGeomatchset", [id, account, partition]))

    @jsii.member(jsii_name="onIpset")
    def on_ipset(
        self,
        id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Waf":
        '''(experimental) Adds a resource of type ipset to the statement.

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_IPSet.html

        :param id: - Identifier for the id.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8453b0d114ad750e981a1e76c9caac2ab014736ddb9d19d9a5f7baff5aff056b)
            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Waf", jsii.invoke(self, "onIpset", [id, account, partition]))

    @jsii.member(jsii_name="onRatebasedrule")
    def on_ratebasedrule(
        self,
        id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Waf":
        '''(experimental) Adds a resource of type ratebasedrule to the statement.

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_RateBasedRule.html

        :param id: - Identifier for the id.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__de63cdf126c9dc98918fbcc4b3d3ebf18eb00ff88d8c18ac93a3eafa26a54b41)
            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Waf", jsii.invoke(self, "onRatebasedrule", [id, account, partition]))

    @jsii.member(jsii_name="onRegexmatchset")
    def on_regexmatchset(
        self,
        id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Waf":
        '''(experimental) Adds a resource of type regexmatchset to the statement.

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_RegexMatchSet.html

        :param id: - Identifier for the id.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__430640b363592b50cc79808bea096ac4863032072026b422d713ddea8d589cf1)
            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Waf", jsii.invoke(self, "onRegexmatchset", [id, account, partition]))

    @jsii.member(jsii_name="onRegexpatternset")
    def on_regexpatternset(
        self,
        id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Waf":
        '''(experimental) Adds a resource of type regexpatternset to the statement.

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_RegexPatternSet.html

        :param id: - Identifier for the id.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__af2e2edd65f47160fbc1f7488e0d16c9174c22a56be6daaf8ea0741d84ffcd88)
            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Waf", jsii.invoke(self, "onRegexpatternset", [id, account, partition]))

    @jsii.member(jsii_name="onRule")
    def on_rule(
        self,
        id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Waf":
        '''(experimental) Adds a resource of type rule to the statement.

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_Rule.html

        :param id: - Identifier for the id.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__93a27015a79034577e4375acd25824cd697c471bb0f113820ffaf8b65a220ec7)
            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Waf", jsii.invoke(self, "onRule", [id, account, partition]))

    @jsii.member(jsii_name="onRulegroup")
    def on_rulegroup(
        self,
        id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Waf":
        '''(experimental) Adds a resource of type rulegroup to the statement.

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_RuleGroup.html

        :param id: - Identifier for the id.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__981e99a2022b9905b90ef37e238ca7a1287072c81b9670b68b8665a954dc3842)
            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Waf", jsii.invoke(self, "onRulegroup", [id, account, partition]))

    @jsii.member(jsii_name="onSizeconstraintset")
    def on_sizeconstraintset(
        self,
        id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Waf":
        '''(experimental) Adds a resource of type sizeconstraintset to the statement.

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_SizeConstraintSet.html

        :param id: - Identifier for the id.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a4c243c7188fd23cb4fcc3defd22dd01bc8b1eff4ee1326a9a2b5062c61c0c66)
            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Waf", jsii.invoke(self, "onSizeconstraintset", [id, account, partition]))

    @jsii.member(jsii_name="onSqlinjectionmatchset")
    def on_sqlinjectionmatchset(
        self,
        id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Waf":
        '''(experimental) Adds a resource of type sqlinjectionmatchset to the statement.

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_SqlInjectionMatchSet.html

        :param id: - Identifier for the id.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9d8ab5d328169849691838a4a4e03a9a8b104060cc6432b289509b1ad9a859f7)
            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Waf", jsii.invoke(self, "onSqlinjectionmatchset", [id, account, partition]))

    @jsii.member(jsii_name="onWebacl")
    def on_webacl(
        self,
        id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Waf":
        '''(experimental) Adds a resource of type webacl to the statement.

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_WebACL.html

        :param id: - Identifier for the id.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c09781db5e19fae2a2d35425f7734d80e8ebc99ca0da87288b10f73eea706b0d)
            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Waf", jsii.invoke(self, "onWebacl", [id, account, partition]))

    @jsii.member(jsii_name="onXssmatchset")
    def on_xssmatchset(
        self,
        id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Waf":
        '''(experimental) Adds a resource of type xssmatchset to the statement.

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_XssMatchSet.html

        :param id: - Identifier for the id.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9362e89caf2967e5b481ea340ae7f1ac8e64e4c8542bab826fc84b8e6b730c9c)
            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Waf", jsii.invoke(self, "onXssmatchset", [id, account, partition]))

    @jsii.member(jsii_name="toCreateByteMatchSet")
    def to_create_byte_match_set(self) -> "Waf":
        '''(experimental) Grants permission to create a ByteMatchSet.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_CreateByteMatchSet.html

        :stability: experimental
        '''
        return typing.cast("Waf", jsii.invoke(self, "toCreateByteMatchSet", []))

    @jsii.member(jsii_name="toCreateGeoMatchSet")
    def to_create_geo_match_set(self) -> "Waf":
        '''(experimental) Grants permission to create a GeoMatchSet.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_CreateGeoMatchSet.html

        :stability: experimental
        '''
        return typing.cast("Waf", jsii.invoke(self, "toCreateGeoMatchSet", []))

    @jsii.member(jsii_name="toCreateIPSet")
    def to_create_ip_set(self) -> "Waf":
        '''(experimental) Grants permission to create an IPSet.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_CreateIPSet.html

        :stability: experimental
        '''
        return typing.cast("Waf", jsii.invoke(self, "toCreateIPSet", []))

    @jsii.member(jsii_name="toCreateRateBasedRule")
    def to_create_rate_based_rule(self) -> "Waf":
        '''(experimental) Grants permission to create a RateBasedRule for limiting the volume of requests from a single IP address.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_CreateRateBasedRule.html

        :stability: experimental
        '''
        return typing.cast("Waf", jsii.invoke(self, "toCreateRateBasedRule", []))

    @jsii.member(jsii_name="toCreateRegexMatchSet")
    def to_create_regex_match_set(self) -> "Waf":
        '''(experimental) Grants permission to create a RegexMatchSet.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_CreateRegexMatchSet.html

        :stability: experimental
        '''
        return typing.cast("Waf", jsii.invoke(self, "toCreateRegexMatchSet", []))

    @jsii.member(jsii_name="toCreateRegexPatternSet")
    def to_create_regex_pattern_set(self) -> "Waf":
        '''(experimental) Grants permission to create a RegexPatternSet.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_CreateRegexPatternSet.html

        :stability: experimental
        '''
        return typing.cast("Waf", jsii.invoke(self, "toCreateRegexPatternSet", []))

    @jsii.member(jsii_name="toCreateRule")
    def to_create_rule(self) -> "Waf":
        '''(experimental) Grants permission to create a Rule for filtering web requests.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_CreateRule.html

        :stability: experimental
        '''
        return typing.cast("Waf", jsii.invoke(self, "toCreateRule", []))

    @jsii.member(jsii_name="toCreateRuleGroup")
    def to_create_rule_group(self) -> "Waf":
        '''(experimental) Grants permission to create a RuleGroup, which is a collection of predefined rules that you can use in a WebACL.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_CreateRuleGroup.html

        :stability: experimental
        '''
        return typing.cast("Waf", jsii.invoke(self, "toCreateRuleGroup", []))

    @jsii.member(jsii_name="toCreateSizeConstraintSet")
    def to_create_size_constraint_set(self) -> "Waf":
        '''(experimental) Grants permission to create a SizeConstraintSet.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_CreateSizeConstraintSet.html

        :stability: experimental
        '''
        return typing.cast("Waf", jsii.invoke(self, "toCreateSizeConstraintSet", []))

    @jsii.member(jsii_name="toCreateSqlInjectionMatchSet")
    def to_create_sql_injection_match_set(self) -> "Waf":
        '''(experimental) Grants permission to create an SqlInjectionMatchSet.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_CreateSqlInjectionMatchSet.html

        :stability: experimental
        '''
        return typing.cast("Waf", jsii.invoke(self, "toCreateSqlInjectionMatchSet", []))

    @jsii.member(jsii_name="toCreateWebACL")
    def to_create_web_acl(self) -> "Waf":
        '''(experimental) Grants permission to create a WebACL, which contains rules for filtering web requests.

        Access Level: Permissions management

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_CreateWebACL.html

        :stability: experimental
        '''
        return typing.cast("Waf", jsii.invoke(self, "toCreateWebACL", []))

    @jsii.member(jsii_name="toCreateWebACLMigrationStack")
    def to_create_web_acl_migration_stack(self) -> "Waf":
        '''(experimental) Grants permission to create a CloudFormation web ACL template in an S3 bucket for the purposes of migrating the web ACL from AWS WAF Classic to AWS WAF v2.

        Access Level: Write

        Dependent actions:

        - s3:PutObject

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_CreateWebACLMigrationStack.html

        :stability: experimental
        '''
        return typing.cast("Waf", jsii.invoke(self, "toCreateWebACLMigrationStack", []))

    @jsii.member(jsii_name="toCreateXssMatchSet")
    def to_create_xss_match_set(self) -> "Waf":
        '''(experimental) Grants permission to create an XssMatchSet, which you use to detect requests that contain cross-site scripting attacks.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_CreateXssMatchSet.html

        :stability: experimental
        '''
        return typing.cast("Waf", jsii.invoke(self, "toCreateXssMatchSet", []))

    @jsii.member(jsii_name="toDeleteByteMatchSet")
    def to_delete_byte_match_set(self) -> "Waf":
        '''(experimental) Grants permission to delete a ByteMatchSet.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_DeleteByteMatchSet.html

        :stability: experimental
        '''
        return typing.cast("Waf", jsii.invoke(self, "toDeleteByteMatchSet", []))

    @jsii.member(jsii_name="toDeleteGeoMatchSet")
    def to_delete_geo_match_set(self) -> "Waf":
        '''(experimental) Grants permission to delete a GeoMatchSet.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_DeleteGeoMatchSet.html

        :stability: experimental
        '''
        return typing.cast("Waf", jsii.invoke(self, "toDeleteGeoMatchSet", []))

    @jsii.member(jsii_name="toDeleteIPSet")
    def to_delete_ip_set(self) -> "Waf":
        '''(experimental) Grants permission to delete an IPSet.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_DeleteIPSet.html

        :stability: experimental
        '''
        return typing.cast("Waf", jsii.invoke(self, "toDeleteIPSet", []))

    @jsii.member(jsii_name="toDeleteLoggingConfiguration")
    def to_delete_logging_configuration(self) -> "Waf":
        '''(experimental) Grants permission to delete the LoggingConfiguration from a web ACL.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_DeleteLoggingConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Waf", jsii.invoke(self, "toDeleteLoggingConfiguration", []))

    @jsii.member(jsii_name="toDeletePermissionPolicy")
    def to_delete_permission_policy(self) -> "Waf":
        '''(experimental) Grants permission to delete an IAM policy from a rule group.

        Access Level: Permissions management

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_DeletePermissionPolicy.html

        :stability: experimental
        '''
        return typing.cast("Waf", jsii.invoke(self, "toDeletePermissionPolicy", []))

    @jsii.member(jsii_name="toDeleteRateBasedRule")
    def to_delete_rate_based_rule(self) -> "Waf":
        '''(experimental) Grants permission to delete a RateBasedRule.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_DeleteRateBasedRule.html

        :stability: experimental
        '''
        return typing.cast("Waf", jsii.invoke(self, "toDeleteRateBasedRule", []))

    @jsii.member(jsii_name="toDeleteRegexMatchSet")
    def to_delete_regex_match_set(self) -> "Waf":
        '''(experimental) Grants permission to delete a RegexMatchSet.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_DeleteRegexMatchSet.html

        :stability: experimental
        '''
        return typing.cast("Waf", jsii.invoke(self, "toDeleteRegexMatchSet", []))

    @jsii.member(jsii_name="toDeleteRegexPatternSet")
    def to_delete_regex_pattern_set(self) -> "Waf":
        '''(experimental) Grants permission to delete a RegexPatternSet.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_DeleteRegexPatternSet.html

        :stability: experimental
        '''
        return typing.cast("Waf", jsii.invoke(self, "toDeleteRegexPatternSet", []))

    @jsii.member(jsii_name="toDeleteRule")
    def to_delete_rule(self) -> "Waf":
        '''(experimental) Grants permission to delete a Rule.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_DeleteRule.html

        :stability: experimental
        '''
        return typing.cast("Waf", jsii.invoke(self, "toDeleteRule", []))

    @jsii.member(jsii_name="toDeleteRuleGroup")
    def to_delete_rule_group(self) -> "Waf":
        '''(experimental) Grants permission to delete a RuleGroup.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_DeleteRuleGroup.html

        :stability: experimental
        '''
        return typing.cast("Waf", jsii.invoke(self, "toDeleteRuleGroup", []))

    @jsii.member(jsii_name="toDeleteSizeConstraintSet")
    def to_delete_size_constraint_set(self) -> "Waf":
        '''(experimental) Grants permission to delete a SizeConstraintSet.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_DeleteSizeConstraintSet.html

        :stability: experimental
        '''
        return typing.cast("Waf", jsii.invoke(self, "toDeleteSizeConstraintSet", []))

    @jsii.member(jsii_name="toDeleteSqlInjectionMatchSet")
    def to_delete_sql_injection_match_set(self) -> "Waf":
        '''(experimental) Grants permission to delete an SqlInjectionMatchSet.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_DeleteSqlInjectionMatchSet.html

        :stability: experimental
        '''
        return typing.cast("Waf", jsii.invoke(self, "toDeleteSqlInjectionMatchSet", []))

    @jsii.member(jsii_name="toDeleteWebACL")
    def to_delete_web_acl(self) -> "Waf":
        '''(experimental) Grants permission to delete a WebACL.

        Access Level: Permissions management

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_DeleteWebACL.html

        :stability: experimental
        '''
        return typing.cast("Waf", jsii.invoke(self, "toDeleteWebACL", []))

    @jsii.member(jsii_name="toDeleteXssMatchSet")
    def to_delete_xss_match_set(self) -> "Waf":
        '''(experimental) Grants permission to delete an XssMatchSet.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_DeleteXssMatchSet.html

        :stability: experimental
        '''
        return typing.cast("Waf", jsii.invoke(self, "toDeleteXssMatchSet", []))

    @jsii.member(jsii_name="toGetByteMatchSet")
    def to_get_byte_match_set(self) -> "Waf":
        '''(experimental) Grants permission to retrieve a ByteMatchSet.

        Access Level: Read

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_GetByteMatchSet.html

        :stability: experimental
        '''
        return typing.cast("Waf", jsii.invoke(self, "toGetByteMatchSet", []))

    @jsii.member(jsii_name="toGetChangeToken")
    def to_get_change_token(self) -> "Waf":
        '''(experimental) Grants permission to retrieve a change token to use in create, update, and delete requests.

        Access Level: Read

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_GetChangeToken.html

        :stability: experimental
        '''
        return typing.cast("Waf", jsii.invoke(self, "toGetChangeToken", []))

    @jsii.member(jsii_name="toGetChangeTokenStatus")
    def to_get_change_token_status(self) -> "Waf":
        '''(experimental) Grants permission to retrieve the status of a change token.

        Access Level: Read

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_GetChangeTokenStatus.html

        :stability: experimental
        '''
        return typing.cast("Waf", jsii.invoke(self, "toGetChangeTokenStatus", []))

    @jsii.member(jsii_name="toGetGeoMatchSet")
    def to_get_geo_match_set(self) -> "Waf":
        '''(experimental) Grants permission to retrieve a GeoMatchSet.

        Access Level: Read

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_GetGeoMatchSet.html

        :stability: experimental
        '''
        return typing.cast("Waf", jsii.invoke(self, "toGetGeoMatchSet", []))

    @jsii.member(jsii_name="toGetIPSet")
    def to_get_ip_set(self) -> "Waf":
        '''(experimental) Grants permission to retrieve an IPSet.

        Access Level: Read

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_GetIPSet.html

        :stability: experimental
        '''
        return typing.cast("Waf", jsii.invoke(self, "toGetIPSet", []))

    @jsii.member(jsii_name="toGetLoggingConfiguration")
    def to_get_logging_configuration(self) -> "Waf":
        '''(experimental) Grants permission to retrieve a LoggingConfiguration for a web ACL.

        Access Level: Read

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_GetLoggingConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Waf", jsii.invoke(self, "toGetLoggingConfiguration", []))

    @jsii.member(jsii_name="toGetPermissionPolicy")
    def to_get_permission_policy(self) -> "Waf":
        '''(experimental) Grants permission to retrieve an IAM policy for a rule group.

        Access Level: Read

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_GetPermissionPolicy.html

        :stability: experimental
        '''
        return typing.cast("Waf", jsii.invoke(self, "toGetPermissionPolicy", []))

    @jsii.member(jsii_name="toGetRateBasedRule")
    def to_get_rate_based_rule(self) -> "Waf":
        '''(experimental) Grants permission to retrieve a RateBasedRule.

        Access Level: Read

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_GetRateBasedRule.html

        :stability: experimental
        '''
        return typing.cast("Waf", jsii.invoke(self, "toGetRateBasedRule", []))

    @jsii.member(jsii_name="toGetRateBasedRuleManagedKeys")
    def to_get_rate_based_rule_managed_keys(self) -> "Waf":
        '''(experimental) Grants permission to retrieve the array of IP addresses that are currently being blocked by a RateBasedRule.

        Access Level: Read

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_GetRateBasedRuleManagedKeys.html

        :stability: experimental
        '''
        return typing.cast("Waf", jsii.invoke(self, "toGetRateBasedRuleManagedKeys", []))

    @jsii.member(jsii_name="toGetRegexMatchSet")
    def to_get_regex_match_set(self) -> "Waf":
        '''(experimental) Grants permission to retrieve a RegexMatchSet.

        Access Level: Read

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_GetRegexMatchSet.html

        :stability: experimental
        '''
        return typing.cast("Waf", jsii.invoke(self, "toGetRegexMatchSet", []))

    @jsii.member(jsii_name="toGetRegexPatternSet")
    def to_get_regex_pattern_set(self) -> "Waf":
        '''(experimental) Grants permission to retrieve a RegexPatternSet.

        Access Level: Read

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_GetRegexPatternSet.html

        :stability: experimental
        '''
        return typing.cast("Waf", jsii.invoke(self, "toGetRegexPatternSet", []))

    @jsii.member(jsii_name="toGetRule")
    def to_get_rule(self) -> "Waf":
        '''(experimental) Grants permission to retrieve a Rule.

        Access Level: Read

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_GetRule.html

        :stability: experimental
        '''
        return typing.cast("Waf", jsii.invoke(self, "toGetRule", []))

    @jsii.member(jsii_name="toGetRuleGroup")
    def to_get_rule_group(self) -> "Waf":
        '''(experimental) Grants permission to retrieve a RuleGroup.

        Access Level: Read

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_GetRuleGroup.html

        :stability: experimental
        '''
        return typing.cast("Waf", jsii.invoke(self, "toGetRuleGroup", []))

    @jsii.member(jsii_name="toGetSampledRequests")
    def to_get_sampled_requests(self) -> "Waf":
        '''(experimental) Grants permission to retrieve detailed information about a sample set of web requests.

        Access Level: Read

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_GetSampledRequests.html

        :stability: experimental
        '''
        return typing.cast("Waf", jsii.invoke(self, "toGetSampledRequests", []))

    @jsii.member(jsii_name="toGetSizeConstraintSet")
    def to_get_size_constraint_set(self) -> "Waf":
        '''(experimental) Grants permission to retrieve a SizeConstraintSet.

        Access Level: Read

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_GetSizeConstraintSet.html

        :stability: experimental
        '''
        return typing.cast("Waf", jsii.invoke(self, "toGetSizeConstraintSet", []))

    @jsii.member(jsii_name="toGetSqlInjectionMatchSet")
    def to_get_sql_injection_match_set(self) -> "Waf":
        '''(experimental) Grants permission to retrieve an SqlInjectionMatchSet.

        Access Level: Read

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_GetSqlInjectionMatchSet.html

        :stability: experimental
        '''
        return typing.cast("Waf", jsii.invoke(self, "toGetSqlInjectionMatchSet", []))

    @jsii.member(jsii_name="toGetWebACL")
    def to_get_web_acl(self) -> "Waf":
        '''(experimental) Grants permission to retrieve a WebACL.

        Access Level: Read

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_GetWebACL.html

        :stability: experimental
        '''
        return typing.cast("Waf", jsii.invoke(self, "toGetWebACL", []))

    @jsii.member(jsii_name="toGetXssMatchSet")
    def to_get_xss_match_set(self) -> "Waf":
        '''(experimental) Grants permission to retrieve an XssMatchSet.

        Access Level: Read

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_GetXssMatchSet.html

        :stability: experimental
        '''
        return typing.cast("Waf", jsii.invoke(self, "toGetXssMatchSet", []))

    @jsii.member(jsii_name="toListActivatedRulesInRuleGroup")
    def to_list_activated_rules_in_rule_group(self) -> "Waf":
        '''(experimental) Grants permission to retrieve an array of ActivatedRule objects.

        Access Level: List

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_ListActivatedRulesInRuleGroup.html

        :stability: experimental
        '''
        return typing.cast("Waf", jsii.invoke(self, "toListActivatedRulesInRuleGroup", []))

    @jsii.member(jsii_name="toListByteMatchSets")
    def to_list_byte_match_sets(self) -> "Waf":
        '''(experimental) Grants permission to retrieve an array of ByteMatchSetSummary objects.

        Access Level: List

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_ListByteMatchSets.html

        :stability: experimental
        '''
        return typing.cast("Waf", jsii.invoke(self, "toListByteMatchSets", []))

    @jsii.member(jsii_name="toListGeoMatchSets")
    def to_list_geo_match_sets(self) -> "Waf":
        '''(experimental) Grants permission to retrieve an array of GeoMatchSetSummary objects.

        Access Level: List

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_ListGeoMatchSets.html

        :stability: experimental
        '''
        return typing.cast("Waf", jsii.invoke(self, "toListGeoMatchSets", []))

    @jsii.member(jsii_name="toListIPSets")
    def to_list_ip_sets(self) -> "Waf":
        '''(experimental) Grants permission to retrieve an array of IPSetSummary objects.

        Access Level: List

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_ListIPSets.html

        :stability: experimental
        '''
        return typing.cast("Waf", jsii.invoke(self, "toListIPSets", []))

    @jsii.member(jsii_name="toListLoggingConfigurations")
    def to_list_logging_configurations(self) -> "Waf":
        '''(experimental) Grants permission to retrieve an array of LoggingConfiguration objects.

        Access Level: List

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_ListLoggingConfigurations.html

        :stability: experimental
        '''
        return typing.cast("Waf", jsii.invoke(self, "toListLoggingConfigurations", []))

    @jsii.member(jsii_name="toListRateBasedRules")
    def to_list_rate_based_rules(self) -> "Waf":
        '''(experimental) Grants permission to retrieve an array of RuleSummary objects.

        Access Level: List

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_ListRateBasedRules.html

        :stability: experimental
        '''
        return typing.cast("Waf", jsii.invoke(self, "toListRateBasedRules", []))

    @jsii.member(jsii_name="toListRegexMatchSets")
    def to_list_regex_match_sets(self) -> "Waf":
        '''(experimental) Grants permission to retrieve an array of RegexMatchSetSummary objects.

        Access Level: List

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_ListRegexMatchSets.html

        :stability: experimental
        '''
        return typing.cast("Waf", jsii.invoke(self, "toListRegexMatchSets", []))

    @jsii.member(jsii_name="toListRegexPatternSets")
    def to_list_regex_pattern_sets(self) -> "Waf":
        '''(experimental) Grants permission to retrieve an array of RegexPatternSetSummary objects.

        Access Level: List

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_ListRegexPatternSets.html

        :stability: experimental
        '''
        return typing.cast("Waf", jsii.invoke(self, "toListRegexPatternSets", []))

    @jsii.member(jsii_name="toListRuleGroups")
    def to_list_rule_groups(self) -> "Waf":
        '''(experimental) Grants permission to retrieve an array of RuleGroup objects.

        Access Level: List

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_ListRuleGroups.html

        :stability: experimental
        '''
        return typing.cast("Waf", jsii.invoke(self, "toListRuleGroups", []))

    @jsii.member(jsii_name="toListRules")
    def to_list_rules(self) -> "Waf":
        '''(experimental) Grants permission to retrieve an array of RuleSummary objects.

        Access Level: List

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_ListRules.html

        :stability: experimental
        '''
        return typing.cast("Waf", jsii.invoke(self, "toListRules", []))

    @jsii.member(jsii_name="toListSizeConstraintSets")
    def to_list_size_constraint_sets(self) -> "Waf":
        '''(experimental) Grants permission to retrieve an array of SizeConstraintSetSummary objects.

        Access Level: List

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_ListSizeConstraintSets.html

        :stability: experimental
        '''
        return typing.cast("Waf", jsii.invoke(self, "toListSizeConstraintSets", []))

    @jsii.member(jsii_name="toListSqlInjectionMatchSets")
    def to_list_sql_injection_match_sets(self) -> "Waf":
        '''(experimental) Grants permission to retrieve an array of SqlInjectionMatchSet objects.

        Access Level: List

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_ListSqlInjectionMatchSets.html

        :stability: experimental
        '''
        return typing.cast("Waf", jsii.invoke(self, "toListSqlInjectionMatchSets", []))

    @jsii.member(jsii_name="toListSubscribedRuleGroups")
    def to_list_subscribed_rule_groups(self) -> "Waf":
        '''(experimental) Grants permission to retrieve an array of RuleGroup objects that you are subscribed to.

        Access Level: List

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_ListSubscribedRuleGroups.html

        :stability: experimental
        '''
        return typing.cast("Waf", jsii.invoke(self, "toListSubscribedRuleGroups", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Waf":
        '''(experimental) Grants permission to retrieve the tags for a resource.

        Access Level: Read

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("Waf", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toListWebACLs")
    def to_list_web_ac_ls(self) -> "Waf":
        '''(experimental) Grants permission to retrieve an array of WebACLSummary objects.

        Access Level: List

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_ListWebACLs.html

        :stability: experimental
        '''
        return typing.cast("Waf", jsii.invoke(self, "toListWebACLs", []))

    @jsii.member(jsii_name="toListXssMatchSets")
    def to_list_xss_match_sets(self) -> "Waf":
        '''(experimental) Grants permission to retrieve an array of XssMatchSet objects.

        Access Level: List

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_ListXssMatchSets.html

        :stability: experimental
        '''
        return typing.cast("Waf", jsii.invoke(self, "toListXssMatchSets", []))

    @jsii.member(jsii_name="toPutLoggingConfiguration")
    def to_put_logging_configuration(self) -> "Waf":
        '''(experimental) Grants permission to associate a LoggingConfiguration with a specified web ACL.

        Access Level: Write

        Dependent actions:

        - iam:CreateServiceLinkedRole

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_PutLoggingConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Waf", jsii.invoke(self, "toPutLoggingConfiguration", []))

    @jsii.member(jsii_name="toPutPermissionPolicy")
    def to_put_permission_policy(self) -> "Waf":
        '''(experimental) Grants permission to attach an IAM policy to a rule group, to share the rule group between accounts.

        Access Level: Permissions management

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_PutPermissionPolicy.html

        :stability: experimental
        '''
        return typing.cast("Waf", jsii.invoke(self, "toPutPermissionPolicy", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Waf":
        '''(experimental) Grants permission to add a Tag to a resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_TagResource.html

        :stability: experimental
        '''
        return typing.cast("Waf", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Waf":
        '''(experimental) Grants permission to remove a Tag from a resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("Waf", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateByteMatchSet")
    def to_update_byte_match_set(self) -> "Waf":
        '''(experimental) Grants permission to insert or delete ByteMatchTuple objects in a ByteMatchSet.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_UpdateByteMatchSet.html

        :stability: experimental
        '''
        return typing.cast("Waf", jsii.invoke(self, "toUpdateByteMatchSet", []))

    @jsii.member(jsii_name="toUpdateGeoMatchSet")
    def to_update_geo_match_set(self) -> "Waf":
        '''(experimental) Grants permission to insert or delete GeoMatchConstraint objects in a GeoMatchSet.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_UpdateGeoMatchSet.html

        :stability: experimental
        '''
        return typing.cast("Waf", jsii.invoke(self, "toUpdateGeoMatchSet", []))

    @jsii.member(jsii_name="toUpdateIPSet")
    def to_update_ip_set(self) -> "Waf":
        '''(experimental) Grants permission to insert or delete IPSetDescriptor objects in an IPSet.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_UpdateIPSet.html

        :stability: experimental
        '''
        return typing.cast("Waf", jsii.invoke(self, "toUpdateIPSet", []))

    @jsii.member(jsii_name="toUpdateRateBasedRule")
    def to_update_rate_based_rule(self) -> "Waf":
        '''(experimental) Grants permission to modify a rate based rule.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_UpdateRateBasedRule.html

        :stability: experimental
        '''
        return typing.cast("Waf", jsii.invoke(self, "toUpdateRateBasedRule", []))

    @jsii.member(jsii_name="toUpdateRegexMatchSet")
    def to_update_regex_match_set(self) -> "Waf":
        '''(experimental) Grants permission to insert or delete RegexMatchTuple objects in a RegexMatchSet.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_UpdateRegexMatchSet.html

        :stability: experimental
        '''
        return typing.cast("Waf", jsii.invoke(self, "toUpdateRegexMatchSet", []))

    @jsii.member(jsii_name="toUpdateRegexPatternSet")
    def to_update_regex_pattern_set(self) -> "Waf":
        '''(experimental) Grants permission to insert or delete RegexPatternStrings in a RegexPatternSet.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_UpdateRegexPatternSet.html

        :stability: experimental
        '''
        return typing.cast("Waf", jsii.invoke(self, "toUpdateRegexPatternSet", []))

    @jsii.member(jsii_name="toUpdateRule")
    def to_update_rule(self) -> "Waf":
        '''(experimental) Grants permission to modify a Rule.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_UpdateRule.html

        :stability: experimental
        '''
        return typing.cast("Waf", jsii.invoke(self, "toUpdateRule", []))

    @jsii.member(jsii_name="toUpdateRuleGroup")
    def to_update_rule_group(self) -> "Waf":
        '''(experimental) Grants permission to insert or delete ActivatedRule objects in a RuleGroup.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_UpdateRuleGroup.html

        :stability: experimental
        '''
        return typing.cast("Waf", jsii.invoke(self, "toUpdateRuleGroup", []))

    @jsii.member(jsii_name="toUpdateSizeConstraintSet")
    def to_update_size_constraint_set(self) -> "Waf":
        '''(experimental) Grants permission to insert or delete SizeConstraint objects in a SizeConstraintSet.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_UpdateSizeConstraintSet.html

        :stability: experimental
        '''
        return typing.cast("Waf", jsii.invoke(self, "toUpdateSizeConstraintSet", []))

    @jsii.member(jsii_name="toUpdateSqlInjectionMatchSet")
    def to_update_sql_injection_match_set(self) -> "Waf":
        '''(experimental) Grants permission to insert or delete SqlInjectionMatchTuple objects in an SqlInjectionMatchSet.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_UpdateSqlInjectionMatchSet.html

        :stability: experimental
        '''
        return typing.cast("Waf", jsii.invoke(self, "toUpdateSqlInjectionMatchSet", []))

    @jsii.member(jsii_name="toUpdateWebACL")
    def to_update_web_acl(self) -> "Waf":
        '''(experimental) Grants permission to insert or delete ActivatedRule objects in a WebACL.

        Access Level: Permissions management

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_UpdateWebACL.html

        :stability: experimental
        '''
        return typing.cast("Waf", jsii.invoke(self, "toUpdateWebACL", []))

    @jsii.member(jsii_name="toUpdateXssMatchSet")
    def to_update_xss_match_set(self) -> "Waf":
        '''(experimental) Grants permission to insert or delete XssMatchTuple objects in an XssMatchSet.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_UpdateXssMatchSet.html

        :stability: experimental
        '''
        return typing.cast("Waf", jsii.invoke(self, "toUpdateXssMatchSet", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e2d29aae26c0ef16c0ca0062c88c8e1f2fae50f81e6943c792de0b7f7a82e26d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__cc841cff90db1da9ad8a0b282a945b0fd0e1d69ee78f0b93653061e19951dd1b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class WafRegional(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.WafRegional",
):
    '''(experimental) Statement provider for service `waf-regional <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awswafregional.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `waf-regional <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awswafregional.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onBytematchset")
    def on_bytematchset(
        self,
        id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "WafRegional":
        '''(experimental) Adds a resource of type bytematchset to the statement.

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_ByteMatchSet.html

        :param id: - Identifier for the id.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2d65006b938169e53b186ae89d1aa564e84a5d882c3059c055a378cba2184d15)
            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("WafRegional", jsii.invoke(self, "onBytematchset", [id, account, region, partition]))

    @jsii.member(jsii_name="onGeomatchset")
    def on_geomatchset(
        self,
        id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "WafRegional":
        '''(experimental) Adds a resource of type geomatchset to the statement.

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_GeoMatchSet.html

        :param id: - Identifier for the id.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fae83eb3ea85ac923f74f36c70eb4da4c60bd1703197a0b0389fc1eeeacd38a1)
            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("WafRegional", jsii.invoke(self, "onGeomatchset", [id, account, region, partition]))

    @jsii.member(jsii_name="onIpset")
    def on_ipset(
        self,
        id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "WafRegional":
        '''(experimental) Adds a resource of type ipset to the statement.

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_IPSet.html

        :param id: - Identifier for the id.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d2afe0c585e45ce2b1f0a348fa06a6a6096f45ada007de965afb5a41d56707c2)
            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("WafRegional", jsii.invoke(self, "onIpset", [id, account, region, partition]))

    @jsii.member(jsii_name="onLoadbalancerApp")
    def on_loadbalancer_app(
        self,
        load_balancer_name: builtins.str,
        load_balancer_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "WafRegional":
        '''(experimental) Adds a resource of type loadbalancer/app/ to the statement.

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_WebACL.html

        :param load_balancer_name: - Identifier for the loadBalancerName.
        :param load_balancer_id: - Identifier for the loadBalancerId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ff6e6060086fd86d8ecdd76bcb5292d181f330a550048ebd951bf2734ceb1e5e)
            check_type(argname="argument load_balancer_name", value=load_balancer_name, expected_type=type_hints["load_balancer_name"])
            check_type(argname="argument load_balancer_id", value=load_balancer_id, expected_type=type_hints["load_balancer_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("WafRegional", jsii.invoke(self, "onLoadbalancerApp", [load_balancer_name, load_balancer_id, account, region, partition]))

    @jsii.member(jsii_name="onRatebasedrule")
    def on_ratebasedrule(
        self,
        id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "WafRegional":
        '''(experimental) Adds a resource of type ratebasedrule to the statement.

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_RateBasedRule.html

        :param id: - Identifier for the id.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5941ddfdc5f667a4168ababeaf1e23086457b5f83bd4d6e31376e37e7572cf77)
            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("WafRegional", jsii.invoke(self, "onRatebasedrule", [id, account, region, partition]))

    @jsii.member(jsii_name="onRegexmatchset")
    def on_regexmatchset(
        self,
        id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "WafRegional":
        '''(experimental) Adds a resource of type regexmatchset to the statement.

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_RegexMatchSet.html

        :param id: - Identifier for the id.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__07397effba45535f45c8ec946ea83acc1e6395e0d02c31c6bd31d97a5474f358)
            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("WafRegional", jsii.invoke(self, "onRegexmatchset", [id, account, region, partition]))

    @jsii.member(jsii_name="onRegexpatternset")
    def on_regexpatternset(
        self,
        id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "WafRegional":
        '''(experimental) Adds a resource of type regexpatternset to the statement.

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_RegexPatternSet.html

        :param id: - Identifier for the id.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__afaecd1bfc4b39c4c870e787d122c5957643c5ce64b5b76c9186c20a0c6391bc)
            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("WafRegional", jsii.invoke(self, "onRegexpatternset", [id, account, region, partition]))

    @jsii.member(jsii_name="onRule")
    def on_rule(
        self,
        id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "WafRegional":
        '''(experimental) Adds a resource of type rule to the statement.

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_Rule.html

        :param id: - Identifier for the id.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4a7cfdd747a286447a5aac4e78d8634e62921b2444ae015d85c5f0e544792b59)
            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("WafRegional", jsii.invoke(self, "onRule", [id, account, region, partition]))

    @jsii.member(jsii_name="onRulegroup")
    def on_rulegroup(
        self,
        id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "WafRegional":
        '''(experimental) Adds a resource of type rulegroup to the statement.

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_RuleGroup.html

        :param id: - Identifier for the id.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8144f504b3e53084bf98b997a88eb99be203d03c1bfd2820a00a8f0e48109cd9)
            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("WafRegional", jsii.invoke(self, "onRulegroup", [id, account, region, partition]))

    @jsii.member(jsii_name="onSizeconstraintset")
    def on_sizeconstraintset(
        self,
        id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "WafRegional":
        '''(experimental) Adds a resource of type sizeconstraintset to the statement.

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_SizeConstraintSet.html

        :param id: - Identifier for the id.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b2e8dbb15d653074a91eaadb8e477bd72a4234a8602af8074ccb48b954224e2b)
            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("WafRegional", jsii.invoke(self, "onSizeconstraintset", [id, account, region, partition]))

    @jsii.member(jsii_name="onSqlinjectionmatchset")
    def on_sqlinjectionmatchset(
        self,
        id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "WafRegional":
        '''(experimental) Adds a resource of type sqlinjectionmatchset to the statement.

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_SqlInjectionMatchSet.html

        :param id: - Identifier for the id.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f0eec7a748c88bfcb04edb7389536a4d9683b8ff3f243886ee03400b66dfce29)
            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("WafRegional", jsii.invoke(self, "onSqlinjectionmatchset", [id, account, region, partition]))

    @jsii.member(jsii_name="onWebacl")
    def on_webacl(
        self,
        id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "WafRegional":
        '''(experimental) Adds a resource of type webacl to the statement.

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_WebACL.html

        :param id: - Identifier for the id.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4262c224964314d9b5ff9c37cd11d31cfbb3015d99ee92476c32326c35c51b64)
            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("WafRegional", jsii.invoke(self, "onWebacl", [id, account, region, partition]))

    @jsii.member(jsii_name="onXssmatchset")
    def on_xssmatchset(
        self,
        id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "WafRegional":
        '''(experimental) Adds a resource of type xssmatchset to the statement.

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_XssMatchSet.html

        :param id: - Identifier for the id.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bff643d66050efaf5e8c58f018f8adadbcc3ffce8d3148c4efce913eff5afab1)
            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("WafRegional", jsii.invoke(self, "onXssmatchset", [id, account, region, partition]))

    @jsii.member(jsii_name="toAssociateWebACL")
    def to_associate_web_acl(self) -> "WafRegional":
        '''(experimental) Grants permission to associate a web ACL with a resource.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_AssociateWebACL.html

        :stability: experimental
        '''
        return typing.cast("WafRegional", jsii.invoke(self, "toAssociateWebACL", []))

    @jsii.member(jsii_name="toCreateByteMatchSet")
    def to_create_byte_match_set(self) -> "WafRegional":
        '''(experimental) Grants permission to create a ByteMatchSet.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_CreateByteMatchSet.html

        :stability: experimental
        '''
        return typing.cast("WafRegional", jsii.invoke(self, "toCreateByteMatchSet", []))

    @jsii.member(jsii_name="toCreateGeoMatchSet")
    def to_create_geo_match_set(self) -> "WafRegional":
        '''(experimental) Grants permission to create a GeoMatchSet.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_CreateGeoMatchSet.html

        :stability: experimental
        '''
        return typing.cast("WafRegional", jsii.invoke(self, "toCreateGeoMatchSet", []))

    @jsii.member(jsii_name="toCreateIPSet")
    def to_create_ip_set(self) -> "WafRegional":
        '''(experimental) Grants permission to create an IPSet.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_CreateIPSet.html

        :stability: experimental
        '''
        return typing.cast("WafRegional", jsii.invoke(self, "toCreateIPSet", []))

    @jsii.member(jsii_name="toCreateRateBasedRule")
    def to_create_rate_based_rule(self) -> "WafRegional":
        '''(experimental) Grants permission to create a RateBasedRule.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_CreateRateBasedRule.html

        :stability: experimental
        '''
        return typing.cast("WafRegional", jsii.invoke(self, "toCreateRateBasedRule", []))

    @jsii.member(jsii_name="toCreateRegexMatchSet")
    def to_create_regex_match_set(self) -> "WafRegional":
        '''(experimental) Grants permission to create a RegexMatchSet.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_CreateRegexMatchSet.html

        :stability: experimental
        '''
        return typing.cast("WafRegional", jsii.invoke(self, "toCreateRegexMatchSet", []))

    @jsii.member(jsii_name="toCreateRegexPatternSet")
    def to_create_regex_pattern_set(self) -> "WafRegional":
        '''(experimental) Grants permission to create a RegexPatternSet.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_CreateRegexPatternSet.html

        :stability: experimental
        '''
        return typing.cast("WafRegional", jsii.invoke(self, "toCreateRegexPatternSet", []))

    @jsii.member(jsii_name="toCreateRule")
    def to_create_rule(self) -> "WafRegional":
        '''(experimental) Grants permission to create a Rule.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_CreateRule.html

        :stability: experimental
        '''
        return typing.cast("WafRegional", jsii.invoke(self, "toCreateRule", []))

    @jsii.member(jsii_name="toCreateRuleGroup")
    def to_create_rule_group(self) -> "WafRegional":
        '''(experimental) Grants permission to create a RuleGroup.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_CreateRuleGroup.html

        :stability: experimental
        '''
        return typing.cast("WafRegional", jsii.invoke(self, "toCreateRuleGroup", []))

    @jsii.member(jsii_name="toCreateSizeConstraintSet")
    def to_create_size_constraint_set(self) -> "WafRegional":
        '''(experimental) Grants permission to create a SizeConstraintSet.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_CreateSizeConstraintSet.html

        :stability: experimental
        '''
        return typing.cast("WafRegional", jsii.invoke(self, "toCreateSizeConstraintSet", []))

    @jsii.member(jsii_name="toCreateSqlInjectionMatchSet")
    def to_create_sql_injection_match_set(self) -> "WafRegional":
        '''(experimental) Grants permission to create an SqlInjectionMatchSet.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_CreateSqlInjectionMatchSet.html

        :stability: experimental
        '''
        return typing.cast("WafRegional", jsii.invoke(self, "toCreateSqlInjectionMatchSet", []))

    @jsii.member(jsii_name="toCreateWebACL")
    def to_create_web_acl(self) -> "WafRegional":
        '''(experimental) Grants permission to create a WebACL.

        Access Level: Permissions management

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_CreateWebACL.html

        :stability: experimental
        '''
        return typing.cast("WafRegional", jsii.invoke(self, "toCreateWebACL", []))

    @jsii.member(jsii_name="toCreateWebACLMigrationStack")
    def to_create_web_acl_migration_stack(self) -> "WafRegional":
        '''(experimental) Grants permission to create a CloudFormation web ACL template in an S3 bucket for the purposes of migrating the web ACL from AWS WAF Classic to AWS WAF v2.

        Access Level: Write

        Dependent actions:

        - s3:PutObject

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_CreateWebACLMigrationStack.html

        :stability: experimental
        '''
        return typing.cast("WafRegional", jsii.invoke(self, "toCreateWebACLMigrationStack", []))

    @jsii.member(jsii_name="toCreateXssMatchSet")
    def to_create_xss_match_set(self) -> "WafRegional":
        '''(experimental) Grants permission to create an XssMatchSet.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_CreateXssMatchSet.html

        :stability: experimental
        '''
        return typing.cast("WafRegional", jsii.invoke(self, "toCreateXssMatchSet", []))

    @jsii.member(jsii_name="toDeleteByteMatchSet")
    def to_delete_byte_match_set(self) -> "WafRegional":
        '''(experimental) Grants permission to delete a ByteMatchSet.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_DeleteByteMatchSet.html

        :stability: experimental
        '''
        return typing.cast("WafRegional", jsii.invoke(self, "toDeleteByteMatchSet", []))

    @jsii.member(jsii_name="toDeleteGeoMatchSet")
    def to_delete_geo_match_set(self) -> "WafRegional":
        '''(experimental) Grants permission to delete a GeoMatchSet.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_DeleteGeoMatchSet.html

        :stability: experimental
        '''
        return typing.cast("WafRegional", jsii.invoke(self, "toDeleteGeoMatchSet", []))

    @jsii.member(jsii_name="toDeleteIPSet")
    def to_delete_ip_set(self) -> "WafRegional":
        '''(experimental) Grants permission to delete an IPSet.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_DeleteIPSet.html

        :stability: experimental
        '''
        return typing.cast("WafRegional", jsii.invoke(self, "toDeleteIPSet", []))

    @jsii.member(jsii_name="toDeleteLoggingConfiguration")
    def to_delete_logging_configuration(self) -> "WafRegional":
        '''(experimental) Grants permission to delete a LoggingConfiguration from a web ACL.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_DeleteLoggingConfiguration.html

        :stability: experimental
        '''
        return typing.cast("WafRegional", jsii.invoke(self, "toDeleteLoggingConfiguration", []))

    @jsii.member(jsii_name="toDeletePermissionPolicy")
    def to_delete_permission_policy(self) -> "WafRegional":
        '''(experimental) Grants permission to delete an IAM policy from a rule group.

        Access Level: Permissions management

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_DeletePermissionPolicy.html

        :stability: experimental
        '''
        return typing.cast("WafRegional", jsii.invoke(self, "toDeletePermissionPolicy", []))

    @jsii.member(jsii_name="toDeleteRateBasedRule")
    def to_delete_rate_based_rule(self) -> "WafRegional":
        '''(experimental) Grants permission to delete a RateBasedRule.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_DeleteRateBasedRule.html

        :stability: experimental
        '''
        return typing.cast("WafRegional", jsii.invoke(self, "toDeleteRateBasedRule", []))

    @jsii.member(jsii_name="toDeleteRegexMatchSet")
    def to_delete_regex_match_set(self) -> "WafRegional":
        '''(experimental) Grants permission to delete a RegexMatchSet.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_DeleteRegexMatchSet.html

        :stability: experimental
        '''
        return typing.cast("WafRegional", jsii.invoke(self, "toDeleteRegexMatchSet", []))

    @jsii.member(jsii_name="toDeleteRegexPatternSet")
    def to_delete_regex_pattern_set(self) -> "WafRegional":
        '''(experimental) Grants permission to delete a RegexPatternSet.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_DeleteRegexPatternSet.html

        :stability: experimental
        '''
        return typing.cast("WafRegional", jsii.invoke(self, "toDeleteRegexPatternSet", []))

    @jsii.member(jsii_name="toDeleteRule")
    def to_delete_rule(self) -> "WafRegional":
        '''(experimental) Grants permission to delete a Rule.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_DeleteRule.html

        :stability: experimental
        '''
        return typing.cast("WafRegional", jsii.invoke(self, "toDeleteRule", []))

    @jsii.member(jsii_name="toDeleteRuleGroup")
    def to_delete_rule_group(self) -> "WafRegional":
        '''(experimental) Grants permission to delete a RuleGroup.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_DeleteRuleGroup.html

        :stability: experimental
        '''
        return typing.cast("WafRegional", jsii.invoke(self, "toDeleteRuleGroup", []))

    @jsii.member(jsii_name="toDeleteSizeConstraintSet")
    def to_delete_size_constraint_set(self) -> "WafRegional":
        '''(experimental) Grants permission to delete a SizeConstraintSet.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_DeleteSizeConstraintSet.html

        :stability: experimental
        '''
        return typing.cast("WafRegional", jsii.invoke(self, "toDeleteSizeConstraintSet", []))

    @jsii.member(jsii_name="toDeleteSqlInjectionMatchSet")
    def to_delete_sql_injection_match_set(self) -> "WafRegional":
        '''(experimental) Grants permission to delete an SqlInjectionMatchSet.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_DeleteSqlInjectionMatchSet.html

        :stability: experimental
        '''
        return typing.cast("WafRegional", jsii.invoke(self, "toDeleteSqlInjectionMatchSet", []))

    @jsii.member(jsii_name="toDeleteWebACL")
    def to_delete_web_acl(self) -> "WafRegional":
        '''(experimental) Grants permission to delete a WebACL.

        Access Level: Permissions management

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_DeleteWebACL.html

        :stability: experimental
        '''
        return typing.cast("WafRegional", jsii.invoke(self, "toDeleteWebACL", []))

    @jsii.member(jsii_name="toDeleteXssMatchSet")
    def to_delete_xss_match_set(self) -> "WafRegional":
        '''(experimental) Grants permission to delete an XssMatchSet.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_DeleteXssMatchSet.html

        :stability: experimental
        '''
        return typing.cast("WafRegional", jsii.invoke(self, "toDeleteXssMatchSet", []))

    @jsii.member(jsii_name="toDisassociateWebACL")
    def to_disassociate_web_acl(self) -> "WafRegional":
        '''(experimental) Grants permission to delete an association between a web ACL and a resource.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_DisassociateWebACL.html

        :stability: experimental
        '''
        return typing.cast("WafRegional", jsii.invoke(self, "toDisassociateWebACL", []))

    @jsii.member(jsii_name="toGetByteMatchSet")
    def to_get_byte_match_set(self) -> "WafRegional":
        '''(experimental) Grants permission to retrieve a ByteMatchSet.

        Access Level: Read

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_GetByteMatchSet.html

        :stability: experimental
        '''
        return typing.cast("WafRegional", jsii.invoke(self, "toGetByteMatchSet", []))

    @jsii.member(jsii_name="toGetChangeToken")
    def to_get_change_token(self) -> "WafRegional":
        '''(experimental) Grants permission to retrieve a change token to use in create, update, and delete requests.

        Access Level: Read

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_GetChangeToken.html

        :stability: experimental
        '''
        return typing.cast("WafRegional", jsii.invoke(self, "toGetChangeToken", []))

    @jsii.member(jsii_name="toGetChangeTokenStatus")
    def to_get_change_token_status(self) -> "WafRegional":
        '''(experimental) Grants permission to retrieve the status of a change token.

        Access Level: Read

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_GetChangeTokenStatus.html

        :stability: experimental
        '''
        return typing.cast("WafRegional", jsii.invoke(self, "toGetChangeTokenStatus", []))

    @jsii.member(jsii_name="toGetGeoMatchSet")
    def to_get_geo_match_set(self) -> "WafRegional":
        '''(experimental) Grants permission to retrieve a GeoMatchSet.

        Access Level: Read

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_GetGeoMatchSet.html

        :stability: experimental
        '''
        return typing.cast("WafRegional", jsii.invoke(self, "toGetGeoMatchSet", []))

    @jsii.member(jsii_name="toGetIPSet")
    def to_get_ip_set(self) -> "WafRegional":
        '''(experimental) Grants permission to retrieve an IPSet.

        Access Level: Read

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_GetIPSet.html

        :stability: experimental
        '''
        return typing.cast("WafRegional", jsii.invoke(self, "toGetIPSet", []))

    @jsii.member(jsii_name="toGetLoggingConfiguration")
    def to_get_logging_configuration(self) -> "WafRegional":
        '''(experimental) Grants permission to retrieve a LoggingConfiguration.

        Access Level: Read

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_GetLoggingConfiguration.html

        :stability: experimental
        '''
        return typing.cast("WafRegional", jsii.invoke(self, "toGetLoggingConfiguration", []))

    @jsii.member(jsii_name="toGetPermissionPolicy")
    def to_get_permission_policy(self) -> "WafRegional":
        '''(experimental) Grants permission to retrieve an IAM policy attached to a RuleGroup.

        Access Level: Read

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_GetPermissionPolicy.html

        :stability: experimental
        '''
        return typing.cast("WafRegional", jsii.invoke(self, "toGetPermissionPolicy", []))

    @jsii.member(jsii_name="toGetRateBasedRule")
    def to_get_rate_based_rule(self) -> "WafRegional":
        '''(experimental) Grants permission to retrieve a RateBasedRule.

        Access Level: Read

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_GetRateBasedRule.html

        :stability: experimental
        '''
        return typing.cast("WafRegional", jsii.invoke(self, "toGetRateBasedRule", []))

    @jsii.member(jsii_name="toGetRateBasedRuleManagedKeys")
    def to_get_rate_based_rule_managed_keys(self) -> "WafRegional":
        '''(experimental) Grants permission to retrieve the array of IP addresses that are currently being blocked by a RateBasedRule.

        Access Level: Read

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_GetRateBasedRuleManagedKeys.html

        :stability: experimental
        '''
        return typing.cast("WafRegional", jsii.invoke(self, "toGetRateBasedRuleManagedKeys", []))

    @jsii.member(jsii_name="toGetRegexMatchSet")
    def to_get_regex_match_set(self) -> "WafRegional":
        '''(experimental) Grants permission to retrieve a RegexMatchSet.

        Access Level: Read

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_GetRegexMatchSet.html

        :stability: experimental
        '''
        return typing.cast("WafRegional", jsii.invoke(self, "toGetRegexMatchSet", []))

    @jsii.member(jsii_name="toGetRegexPatternSet")
    def to_get_regex_pattern_set(self) -> "WafRegional":
        '''(experimental) Grants permission to retrieve a RegexPatternSet.

        Access Level: Read

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_GetRegexPatternSet.html

        :stability: experimental
        '''
        return typing.cast("WafRegional", jsii.invoke(self, "toGetRegexPatternSet", []))

    @jsii.member(jsii_name="toGetRule")
    def to_get_rule(self) -> "WafRegional":
        '''(experimental) Grants permission to retrieve a Rule.

        Access Level: Read

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_GetRule.html

        :stability: experimental
        '''
        return typing.cast("WafRegional", jsii.invoke(self, "toGetRule", []))

    @jsii.member(jsii_name="toGetRuleGroup")
    def to_get_rule_group(self) -> "WafRegional":
        '''(experimental) Grants permission to retrieve a RuleGroup.

        Access Level: Read

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_GetRuleGroup.html

        :stability: experimental
        '''
        return typing.cast("WafRegional", jsii.invoke(self, "toGetRuleGroup", []))

    @jsii.member(jsii_name="toGetSampledRequests")
    def to_get_sampled_requests(self) -> "WafRegional":
        '''(experimental) Grants permission to retrieve detailed information for a sample set of web requests.

        Access Level: Read

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_GetSampledRequests.html

        :stability: experimental
        '''
        return typing.cast("WafRegional", jsii.invoke(self, "toGetSampledRequests", []))

    @jsii.member(jsii_name="toGetSizeConstraintSet")
    def to_get_size_constraint_set(self) -> "WafRegional":
        '''(experimental) Grants permission to retrieve a SizeConstraintSet.

        Access Level: Read

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_GetSizeConstraintSet.html

        :stability: experimental
        '''
        return typing.cast("WafRegional", jsii.invoke(self, "toGetSizeConstraintSet", []))

    @jsii.member(jsii_name="toGetSqlInjectionMatchSet")
    def to_get_sql_injection_match_set(self) -> "WafRegional":
        '''(experimental) Grants permission to retrieve an SqlInjectionMatchSet.

        Access Level: Read

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_GetSqlInjectionMatchSet.html

        :stability: experimental
        '''
        return typing.cast("WafRegional", jsii.invoke(self, "toGetSqlInjectionMatchSet", []))

    @jsii.member(jsii_name="toGetWebACL")
    def to_get_web_acl(self) -> "WafRegional":
        '''(experimental) Grants permission to retrieve a WebACL.

        Access Level: Read

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_GetWebACL.html

        :stability: experimental
        '''
        return typing.cast("WafRegional", jsii.invoke(self, "toGetWebACL", []))

    @jsii.member(jsii_name="toGetWebACLForResource")
    def to_get_web_acl_for_resource(self) -> "WafRegional":
        '''(experimental) Grants permission to retrieve a WebACL that's associated with a specified resource.

        Access Level: Read

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_GetWebACLForResource.html

        :stability: experimental
        '''
        return typing.cast("WafRegional", jsii.invoke(self, "toGetWebACLForResource", []))

    @jsii.member(jsii_name="toGetXssMatchSet")
    def to_get_xss_match_set(self) -> "WafRegional":
        '''(experimental) Grants permission to retrieve an XssMatchSet.

        Access Level: Read

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_GetXssMatchSet.html

        :stability: experimental
        '''
        return typing.cast("WafRegional", jsii.invoke(self, "toGetXssMatchSet", []))

    @jsii.member(jsii_name="toListActivatedRulesInRuleGroup")
    def to_list_activated_rules_in_rule_group(self) -> "WafRegional":
        '''(experimental) Grants permission to retrieve an array of ActivatedRule objects.

        Access Level: List

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_ListActivatedRulesInRuleGroup.html

        :stability: experimental
        '''
        return typing.cast("WafRegional", jsii.invoke(self, "toListActivatedRulesInRuleGroup", []))

    @jsii.member(jsii_name="toListByteMatchSets")
    def to_list_byte_match_sets(self) -> "WafRegional":
        '''(experimental) Grants permission to retrieve an array of ByteMatchSetSummary objects.

        Access Level: List

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_ListByteMatchSets.html

        :stability: experimental
        '''
        return typing.cast("WafRegional", jsii.invoke(self, "toListByteMatchSets", []))

    @jsii.member(jsii_name="toListGeoMatchSets")
    def to_list_geo_match_sets(self) -> "WafRegional":
        '''(experimental) Grants permission to retrieve an array of GeoMatchSetSummary objects.

        Access Level: List

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_ListGeoMatchSets.html

        :stability: experimental
        '''
        return typing.cast("WafRegional", jsii.invoke(self, "toListGeoMatchSets", []))

    @jsii.member(jsii_name="toListIPSets")
    def to_list_ip_sets(self) -> "WafRegional":
        '''(experimental) Grants permission to retrieve an array of IPSetSummary objects.

        Access Level: List

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_ListIPSets.html

        :stability: experimental
        '''
        return typing.cast("WafRegional", jsii.invoke(self, "toListIPSets", []))

    @jsii.member(jsii_name="toListLoggingConfigurations")
    def to_list_logging_configurations(self) -> "WafRegional":
        '''(experimental) Grants permission to retrieve an array of LoggingConfiguration objects.

        Access Level: List

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_ListLoggingConfigurations.html

        :stability: experimental
        '''
        return typing.cast("WafRegional", jsii.invoke(self, "toListLoggingConfigurations", []))

    @jsii.member(jsii_name="toListRateBasedRules")
    def to_list_rate_based_rules(self) -> "WafRegional":
        '''(experimental) Grants permission to retrieve an array of RuleSummary objects.

        Access Level: List

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_ListRateBasedRules.html

        :stability: experimental
        '''
        return typing.cast("WafRegional", jsii.invoke(self, "toListRateBasedRules", []))

    @jsii.member(jsii_name="toListRegexMatchSets")
    def to_list_regex_match_sets(self) -> "WafRegional":
        '''(experimental) Grants permission to retrieve an array of RegexMatchSetSummary objects.

        Access Level: List

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_ListRegexMatchSets.html

        :stability: experimental
        '''
        return typing.cast("WafRegional", jsii.invoke(self, "toListRegexMatchSets", []))

    @jsii.member(jsii_name="toListRegexPatternSets")
    def to_list_regex_pattern_sets(self) -> "WafRegional":
        '''(experimental) Grants permission to retrieve an array of RegexPatternSetSummary objects.

        Access Level: List

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_ListRegexPatternSets.html

        :stability: experimental
        '''
        return typing.cast("WafRegional", jsii.invoke(self, "toListRegexPatternSets", []))

    @jsii.member(jsii_name="toListResourcesForWebACL")
    def to_list_resources_for_web_acl(self) -> "WafRegional":
        '''(experimental) Grants permission to retrieve an array of resources associated with a specified WebACL.

        Access Level: List

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_ListResourcesForWebACL.html

        :stability: experimental
        '''
        return typing.cast("WafRegional", jsii.invoke(self, "toListResourcesForWebACL", []))

    @jsii.member(jsii_name="toListRuleGroups")
    def to_list_rule_groups(self) -> "WafRegional":
        '''(experimental) Grants permission to retrieve an array of RuleGroup objects.

        Access Level: List

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_ListRuleGroups.html

        :stability: experimental
        '''
        return typing.cast("WafRegional", jsii.invoke(self, "toListRuleGroups", []))

    @jsii.member(jsii_name="toListRules")
    def to_list_rules(self) -> "WafRegional":
        '''(experimental) Grants permission to retrieve an array of RuleSummary objects.

        Access Level: List

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_ListRules.html

        :stability: experimental
        '''
        return typing.cast("WafRegional", jsii.invoke(self, "toListRules", []))

    @jsii.member(jsii_name="toListSizeConstraintSets")
    def to_list_size_constraint_sets(self) -> "WafRegional":
        '''(experimental) Grants permission to retrieve an array of SizeConstraintSetSummary objects.

        Access Level: List

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_ListSizeConstraintSets.html

        :stability: experimental
        '''
        return typing.cast("WafRegional", jsii.invoke(self, "toListSizeConstraintSets", []))

    @jsii.member(jsii_name="toListSqlInjectionMatchSets")
    def to_list_sql_injection_match_sets(self) -> "WafRegional":
        '''(experimental) Grants permission to retrieve an array of SqlInjectionMatchSet objects.

        Access Level: List

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_ListSqlInjectionMatchSets.html

        :stability: experimental
        '''
        return typing.cast("WafRegional", jsii.invoke(self, "toListSqlInjectionMatchSets", []))

    @jsii.member(jsii_name="toListSubscribedRuleGroups")
    def to_list_subscribed_rule_groups(self) -> "WafRegional":
        '''(experimental) Grants permission to retrieve an array of RuleGroup objects that you are subscribed to.

        Access Level: List

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_ListSubscribedRuleGroups.html

        :stability: experimental
        '''
        return typing.cast("WafRegional", jsii.invoke(self, "toListSubscribedRuleGroups", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "WafRegional":
        '''(experimental) Grants permission to lists the Tags for a resource.

        Access Level: Read

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("WafRegional", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toListWebACLs")
    def to_list_web_ac_ls(self) -> "WafRegional":
        '''(experimental) Grants permission to retrieve an array of WebACLSummary objects.

        Access Level: List

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_ListWebACLs.html

        :stability: experimental
        '''
        return typing.cast("WafRegional", jsii.invoke(self, "toListWebACLs", []))

    @jsii.member(jsii_name="toListXssMatchSets")
    def to_list_xss_match_sets(self) -> "WafRegional":
        '''(experimental) Grants permission to retrieve an array of XssMatchSet objects.

        Access Level: List

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_ListXssMatchSets.html

        :stability: experimental
        '''
        return typing.cast("WafRegional", jsii.invoke(self, "toListXssMatchSets", []))

    @jsii.member(jsii_name="toPutLoggingConfiguration")
    def to_put_logging_configuration(self) -> "WafRegional":
        '''(experimental) Grants permission to associates a LoggingConfiguration with a web ACL.

        Access Level: Write

        Dependent actions:

        - iam:CreateServiceLinkedRole

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_PutLoggingConfiguration.html

        :stability: experimental
        '''
        return typing.cast("WafRegional", jsii.invoke(self, "toPutLoggingConfiguration", []))

    @jsii.member(jsii_name="toPutPermissionPolicy")
    def to_put_permission_policy(self) -> "WafRegional":
        '''(experimental) Grants permission to attach an IAM policy to a specified rule group, to support rule group sharing between accounts.

        Access Level: Permissions management

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_PutPermissionPolicy.html

        :stability: experimental
        '''
        return typing.cast("WafRegional", jsii.invoke(self, "toPutPermissionPolicy", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "WafRegional":
        '''(experimental) Grants permission to add a Tag to a resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_TagResource.html

        :stability: experimental
        '''
        return typing.cast("WafRegional", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "WafRegional":
        '''(experimental) Grants permission to remove a Tag from a resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("WafRegional", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateByteMatchSet")
    def to_update_byte_match_set(self) -> "WafRegional":
        '''(experimental) Grants permission to insert or delete ByteMatchTuple objects in a ByteMatchSet.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_UpdateByteMatchSet.html

        :stability: experimental
        '''
        return typing.cast("WafRegional", jsii.invoke(self, "toUpdateByteMatchSet", []))

    @jsii.member(jsii_name="toUpdateGeoMatchSet")
    def to_update_geo_match_set(self) -> "WafRegional":
        '''(experimental) Grants permission to insert or delete GeoMatchConstraint objects in a GeoMatchSet.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_UpdateGeoMatchSet.html

        :stability: experimental
        '''
        return typing.cast("WafRegional", jsii.invoke(self, "toUpdateGeoMatchSet", []))

    @jsii.member(jsii_name="toUpdateIPSet")
    def to_update_ip_set(self) -> "WafRegional":
        '''(experimental) Grants permission to insert or delete IPSetDescriptor objects in an IPSet.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_UpdateIPSet.html

        :stability: experimental
        '''
        return typing.cast("WafRegional", jsii.invoke(self, "toUpdateIPSet", []))

    @jsii.member(jsii_name="toUpdateRateBasedRule")
    def to_update_rate_based_rule(self) -> "WafRegional":
        '''(experimental) Grants permission to insert or delete predicate objects in a rate based rule and update the RateLimit in the rule.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_UpdateRateBasedRule.html

        :stability: experimental
        '''
        return typing.cast("WafRegional", jsii.invoke(self, "toUpdateRateBasedRule", []))

    @jsii.member(jsii_name="toUpdateRegexMatchSet")
    def to_update_regex_match_set(self) -> "WafRegional":
        '''(experimental) Grants permission to insert or delete RegexMatchTuple objects in a RegexMatchSet.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_UpdateRegexMatchSet.html

        :stability: experimental
        '''
        return typing.cast("WafRegional", jsii.invoke(self, "toUpdateRegexMatchSet", []))

    @jsii.member(jsii_name="toUpdateRegexPatternSet")
    def to_update_regex_pattern_set(self) -> "WafRegional":
        '''(experimental) Grants permission to insert or delete RegexPatternStrings in a RegexPatternSet.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_UpdateRegexPatternSet.html

        :stability: experimental
        '''
        return typing.cast("WafRegional", jsii.invoke(self, "toUpdateRegexPatternSet", []))

    @jsii.member(jsii_name="toUpdateRule")
    def to_update_rule(self) -> "WafRegional":
        '''(experimental) Grants permission to insert or delete predicate objects in a Rule.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_UpdateRule.html

        :stability: experimental
        '''
        return typing.cast("WafRegional", jsii.invoke(self, "toUpdateRule", []))

    @jsii.member(jsii_name="toUpdateRuleGroup")
    def to_update_rule_group(self) -> "WafRegional":
        '''(experimental) Grants permission to insert or delete ActivatedRule objects in a RuleGroup.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_UpdateRuleGroup.html

        :stability: experimental
        '''
        return typing.cast("WafRegional", jsii.invoke(self, "toUpdateRuleGroup", []))

    @jsii.member(jsii_name="toUpdateSizeConstraintSet")
    def to_update_size_constraint_set(self) -> "WafRegional":
        '''(experimental) Grants permission to insert or delete SizeConstraint objects in a SizeConstraintSet.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_UpdateSizeConstraintSet.html

        :stability: experimental
        '''
        return typing.cast("WafRegional", jsii.invoke(self, "toUpdateSizeConstraintSet", []))

    @jsii.member(jsii_name="toUpdateSqlInjectionMatchSet")
    def to_update_sql_injection_match_set(self) -> "WafRegional":
        '''(experimental) Grants permission to insert or delete SqlInjectionMatchTuple objects in an SqlInjectionMatchSet.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_UpdateSqlInjectionMatchSet.html

        :stability: experimental
        '''
        return typing.cast("WafRegional", jsii.invoke(self, "toUpdateSqlInjectionMatchSet", []))

    @jsii.member(jsii_name="toUpdateWebACL")
    def to_update_web_acl(self) -> "WafRegional":
        '''(experimental) Grants permission to insert or delete ActivatedRule objects in a WebACL.

        Access Level: Permissions management

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_UpdateWebACL.html

        :stability: experimental
        '''
        return typing.cast("WafRegional", jsii.invoke(self, "toUpdateWebACL", []))

    @jsii.member(jsii_name="toUpdateXssMatchSet")
    def to_update_xss_match_set(self) -> "WafRegional":
        '''(experimental) Grants permission to insert or delete XssMatchTuple objects in an XssMatchSet.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_UpdateXssMatchSet.html

        :stability: experimental
        '''
        return typing.cast("WafRegional", jsii.invoke(self, "toUpdateXssMatchSet", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__520e6238384bc42fc4bdc3972c026736c5394a00b96f635faff7b7f8feb19a58)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__77afe2c4e774b3931041a46e0e69b375422f9db3fc4253d065211099d62d98da)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Wafv2(PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Wafv2"):
    '''(experimental) Statement provider for service `wafv2 <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awswafv2.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `wafv2 <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awswafv2.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onApigateway")
    def on_apigateway(
        self,
        api_id: builtins.str,
        stage_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Wafv2":
        '''(experimental) Adds a resource of type apigateway to the statement.

        https://docs.aws.amazon.com/waf/latest/APIReference/API_WebACL.html

        :param api_id: - Identifier for the apiId.
        :param stage_name: - Identifier for the stageName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__89cb2198b3175886e9884056b819480ea19773565b4796f56ae88d9a239f8938)
            check_type(argname="argument api_id", value=api_id, expected_type=type_hints["api_id"])
            check_type(argname="argument stage_name", value=stage_name, expected_type=type_hints["stage_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Wafv2", jsii.invoke(self, "onApigateway", [api_id, stage_name, account, region, partition]))

    @jsii.member(jsii_name="onAppsync")
    def on_appsync(
        self,
        graph_qlapi_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Wafv2":
        '''(experimental) Adds a resource of type appsync to the statement.

        https://docs.aws.amazon.com/waf/latest/APIReference/API_WebACL.html

        :param graph_qlapi_id: - Identifier for the graphQLAPIId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ecd5636b9db99c2490c60c96682e2121dac6e86a51602a4f2981cf66d508cbc0)
            check_type(argname="argument graph_qlapi_id", value=graph_qlapi_id, expected_type=type_hints["graph_qlapi_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Wafv2", jsii.invoke(self, "onAppsync", [graph_qlapi_id, account, region, partition]))

    @jsii.member(jsii_name="onIpset")
    def on_ipset(
        self,
        scope: builtins.str,
        name: builtins.str,
        id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Wafv2":
        '''(experimental) Adds a resource of type ipset to the statement.

        https://docs.aws.amazon.com/waf/latest/APIReference/API_IPSet.html

        :param scope: - Identifier for the scope.
        :param name: - Identifier for the name.
        :param id: - Identifier for the id.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__936375468dc7580eecfa9538d61bd98911b00fc6ae47c1539bc1b9601e891112)
            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Wafv2", jsii.invoke(self, "onIpset", [scope, name, id, account, region, partition]))

    @jsii.member(jsii_name="onLoadbalancerApp")
    def on_loadbalancer_app(
        self,
        load_balancer_name: builtins.str,
        load_balancer_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Wafv2":
        '''(experimental) Adds a resource of type loadbalancer/app/ to the statement.

        https://docs.aws.amazon.com/waf/latest/APIReference/API_WebACL.html

        :param load_balancer_name: - Identifier for the loadBalancerName.
        :param load_balancer_id: - Identifier for the loadBalancerId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__64f1d339d04272a7743c82c4764fefd097151937e61abd8828b78220f82c4f2c)
            check_type(argname="argument load_balancer_name", value=load_balancer_name, expected_type=type_hints["load_balancer_name"])
            check_type(argname="argument load_balancer_id", value=load_balancer_id, expected_type=type_hints["load_balancer_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Wafv2", jsii.invoke(self, "onLoadbalancerApp", [load_balancer_name, load_balancer_id, account, region, partition]))

    @jsii.member(jsii_name="onManagedruleset")
    def on_managedruleset(
        self,
        scope: builtins.str,
        name: builtins.str,
        id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Wafv2":
        '''(experimental) Adds a resource of type managedruleset to the statement.

        https://docs.aws.amazon.com/waf/latest/APIReference/API_ManagedRuleSet.html

        :param scope: - Identifier for the scope.
        :param name: - Identifier for the name.
        :param id: - Identifier for the id.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__cac5401bcaa6cdc08fdb1642d62e861136f632cfce1accde60044598d7ff4ee0)
            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Wafv2", jsii.invoke(self, "onManagedruleset", [scope, name, id, account, region, partition]))

    @jsii.member(jsii_name="onRegexpatternset")
    def on_regexpatternset(
        self,
        scope: builtins.str,
        name: builtins.str,
        id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Wafv2":
        '''(experimental) Adds a resource of type regexpatternset to the statement.

        https://docs.aws.amazon.com/waf/latest/APIReference/API_RegexPatternSet.html

        :param scope: - Identifier for the scope.
        :param name: - Identifier for the name.
        :param id: - Identifier for the id.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bd7fd8782c053fe9102a5c5102068c348b7594fa2e15772ec188ec12d08c6a34)
            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Wafv2", jsii.invoke(self, "onRegexpatternset", [scope, name, id, account, region, partition]))

    @jsii.member(jsii_name="onRulegroup")
    def on_rulegroup(
        self,
        scope: builtins.str,
        name: builtins.str,
        id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Wafv2":
        '''(experimental) Adds a resource of type rulegroup to the statement.

        https://docs.aws.amazon.com/waf/latest/APIReference/API_RuleGroup.html

        :param scope: - Identifier for the scope.
        :param name: - Identifier for the name.
        :param id: - Identifier for the id.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1b6dce75e44c7c8ea703422bcf09fab86847bd84c266e6ab2fc170baa5b190d1)
            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Wafv2", jsii.invoke(self, "onRulegroup", [scope, name, id, account, region, partition]))

    @jsii.member(jsii_name="onUserpool")
    def on_userpool(
        self,
        user_pool_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Wafv2":
        '''(experimental) Adds a resource of type userpool to the statement.

        https://docs.aws.amazon.com/waf/latest/APIReference/API_WebACL.html

        :param user_pool_id: - Identifier for the userPoolId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ff71cafe0f53ce8aca997e76d2c220c4e4e2601ca5a22b37b4c2aa16b23a4661)
            check_type(argname="argument user_pool_id", value=user_pool_id, expected_type=type_hints["user_pool_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Wafv2", jsii.invoke(self, "onUserpool", [user_pool_id, account, region, partition]))

    @jsii.member(jsii_name="onWebacl")
    def on_webacl(
        self,
        scope: builtins.str,
        name: builtins.str,
        id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Wafv2":
        '''(experimental) Adds a resource of type webacl to the statement.

        https://docs.aws.amazon.com/waf/latest/APIReference/API_WebACL.html

        :param scope: - Identifier for the scope.
        :param name: - Identifier for the name.
        :param id: - Identifier for the id.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ca2d1199a61b5ac370190d3226c21fbb095e43708de83d74c5d3211eb233a13b)
            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Wafv2", jsii.invoke(self, "onWebacl", [scope, name, id, account, region, partition]))

    @jsii.member(jsii_name="toAssociateWebACL")
    def to_associate_web_acl(self) -> "Wafv2":
        '''(experimental) Grants permission to associate a WebACL with a resource.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/APIReference/API_AssociateWebACL.html

        :stability: experimental
        '''
        return typing.cast("Wafv2", jsii.invoke(self, "toAssociateWebACL", []))

    @jsii.member(jsii_name="toCheckCapacity")
    def to_check_capacity(self) -> "Wafv2":
        '''(experimental) Grants permission to calculate web ACL capacity unit (WCU) requirements for a specified scope and set of rules.

        Access Level: Read

        https://docs.aws.amazon.com/waf/latest/APIReference/API_CheckCapacity.html

        :stability: experimental
        '''
        return typing.cast("Wafv2", jsii.invoke(self, "toCheckCapacity", []))

    @jsii.member(jsii_name="toCreateIPSet")
    def to_create_ip_set(self) -> "Wafv2":
        '''(experimental) Grants permission to create an IPSet.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/waf/latest/APIReference/API_CreateIPSet.html

        :stability: experimental
        '''
        return typing.cast("Wafv2", jsii.invoke(self, "toCreateIPSet", []))

    @jsii.member(jsii_name="toCreateRegexPatternSet")
    def to_create_regex_pattern_set(self) -> "Wafv2":
        '''(experimental) Grants permission to create a RegexPatternSet.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/waf/latest/APIReference/API_CreateRegexPatternSet.html

        :stability: experimental
        '''
        return typing.cast("Wafv2", jsii.invoke(self, "toCreateRegexPatternSet", []))

    @jsii.member(jsii_name="toCreateRuleGroup")
    def to_create_rule_group(self) -> "Wafv2":
        '''(experimental) Grants permission to create a RuleGroup.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/waf/latest/APIReference/API_CreateRuleGroup.html

        :stability: experimental
        '''
        return typing.cast("Wafv2", jsii.invoke(self, "toCreateRuleGroup", []))

    @jsii.member(jsii_name="toCreateWebACL")
    def to_create_web_acl(self) -> "Wafv2":
        '''(experimental) Grants permission to create a WebACL.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/waf/latest/APIReference/API_CreateWebACL.html

        :stability: experimental
        '''
        return typing.cast("Wafv2", jsii.invoke(self, "toCreateWebACL", []))

    @jsii.member(jsii_name="toDeleteFirewallManagerRuleGroups")
    def to_delete_firewall_manager_rule_groups(self) -> "Wafv2":
        '''(experimental) Grants permission to delete FirewallManagedRulesGroups from a WebACL if not managed by Firewall Manager anymore.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/APIReference/API_DeleteFirewallManagerRuleGroups.html

        :stability: experimental
        '''
        return typing.cast("Wafv2", jsii.invoke(self, "toDeleteFirewallManagerRuleGroups", []))

    @jsii.member(jsii_name="toDeleteIPSet")
    def to_delete_ip_set(self) -> "Wafv2":
        '''(experimental) Grants permission to delete an IPSet.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/APIReference/API_DeleteIPSet.html

        :stability: experimental
        '''
        return typing.cast("Wafv2", jsii.invoke(self, "toDeleteIPSet", []))

    @jsii.member(jsii_name="toDeleteLoggingConfiguration")
    def to_delete_logging_configuration(self) -> "Wafv2":
        '''(experimental) Grants permission to delete the LoggingConfiguration from a WebACL.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/APIReference/API_DeleteLoggingConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Wafv2", jsii.invoke(self, "toDeleteLoggingConfiguration", []))

    @jsii.member(jsii_name="toDeletePermissionPolicy")
    def to_delete_permission_policy(self) -> "Wafv2":
        '''(experimental) Grants permission to delete the PermissionPolicy on a RuleGroup.

        Access Level: Permissions management

        https://docs.aws.amazon.com/waf/latest/APIReference/API_DeletePermissionPolicy.html

        :stability: experimental
        '''
        return typing.cast("Wafv2", jsii.invoke(self, "toDeletePermissionPolicy", []))

    @jsii.member(jsii_name="toDeleteRegexPatternSet")
    def to_delete_regex_pattern_set(self) -> "Wafv2":
        '''(experimental) Grants permission to delete a RegexPatternSet.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/APIReference/API_DeleteRegexPatternSet.html

        :stability: experimental
        '''
        return typing.cast("Wafv2", jsii.invoke(self, "toDeleteRegexPatternSet", []))

    @jsii.member(jsii_name="toDeleteRuleGroup")
    def to_delete_rule_group(self) -> "Wafv2":
        '''(experimental) Grants permission to delete a RuleGroup.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/APIReference/API_DeleteRuleGroup.html

        :stability: experimental
        '''
        return typing.cast("Wafv2", jsii.invoke(self, "toDeleteRuleGroup", []))

    @jsii.member(jsii_name="toDeleteWebACL")
    def to_delete_web_acl(self) -> "Wafv2":
        '''(experimental) Grants permission to delete a WebACL.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/APIReference/API_DeleteWebACL.html

        :stability: experimental
        '''
        return typing.cast("Wafv2", jsii.invoke(self, "toDeleteWebACL", []))

    @jsii.member(jsii_name="toDescribeManagedRuleGroup")
    def to_describe_managed_rule_group(self) -> "Wafv2":
        '''(experimental) Grants permission to retrieve high-level information for a managed rule group.

        Access Level: Read

        https://docs.aws.amazon.com/waf/latest/APIReference/API_DescribeManagedRuleGroup.html

        :stability: experimental
        '''
        return typing.cast("Wafv2", jsii.invoke(self, "toDescribeManagedRuleGroup", []))

    @jsii.member(jsii_name="toDisassociateFirewallManager")
    def to_disassociate_firewall_manager(self) -> "Wafv2":
        '''(experimental) Grants permission to disassociate Firewall Manager from a WebACL.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/APIReference/API_DisassociateFirewallManager.html

        :stability: experimental
        '''
        return typing.cast("Wafv2", jsii.invoke(self, "toDisassociateFirewallManager", []))

    @jsii.member(jsii_name="toDisassociateWebACL")
    def to_disassociate_web_acl(self) -> "Wafv2":
        '''(experimental) Grants permission to disassociate a WebACL from an application resource.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/APIReference/API_DisassociateWebACL.html

        :stability: experimental
        '''
        return typing.cast("Wafv2", jsii.invoke(self, "toDisassociateWebACL", []))

    @jsii.member(jsii_name="toGenerateMobileSdkReleaseUrl")
    def to_generate_mobile_sdk_release_url(self) -> "Wafv2":
        '''(experimental) Grants permission to generate a presigned download URL for the specified release of the mobile SDK.

        Access Level: Read

        https://docs.aws.amazon.com/waf/latest/APIReference/API_GenerateMobileSdkReleaseUrl.html

        :stability: experimental
        '''
        return typing.cast("Wafv2", jsii.invoke(self, "toGenerateMobileSdkReleaseUrl", []))

    @jsii.member(jsii_name="toGetIPSet")
    def to_get_ip_set(self) -> "Wafv2":
        '''(experimental) Grants permission to retrieve details about an IPSet.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/waf/latest/APIReference/API_GetIPSet.html

        :stability: experimental
        '''
        return typing.cast("Wafv2", jsii.invoke(self, "toGetIPSet", []))

    @jsii.member(jsii_name="toGetLoggingConfiguration")
    def to_get_logging_configuration(self) -> "Wafv2":
        '''(experimental) Grants permission to retrieve LoggingConfiguration for a WebACL.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/waf/latest/APIReference/API_GetLoggingConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Wafv2", jsii.invoke(self, "toGetLoggingConfiguration", []))

    @jsii.member(jsii_name="toGetManagedRuleSet")
    def to_get_managed_rule_set(self) -> "Wafv2":
        '''(experimental) Grants permission to retrieve details about a ManagedRuleSet.

        Access Level: Read

        https://docs.aws.amazon.com/waf/latest/APIReference/API_GetManagedRuleSet.html

        :stability: experimental
        '''
        return typing.cast("Wafv2", jsii.invoke(self, "toGetManagedRuleSet", []))

    @jsii.member(jsii_name="toGetMobileSdkRelease")
    def to_get_mobile_sdk_release(self) -> "Wafv2":
        '''(experimental) Grants permission to retrieve information for the specified mobile SDK release, including release notes and tags.

        Access Level: Read

        https://docs.aws.amazon.com/waf/latest/APIReference/API_GetMobileSdkRelease.html

        :stability: experimental
        '''
        return typing.cast("Wafv2", jsii.invoke(self, "toGetMobileSdkRelease", []))

    @jsii.member(jsii_name="toGetPermissionPolicy")
    def to_get_permission_policy(self) -> "Wafv2":
        '''(experimental) Grants permission to retrieve a PermissionPolicy for a RuleGroup.

        Access Level: Read

        https://docs.aws.amazon.com/waf/latest/APIReference/API_GetPermissionPolicy.html

        :stability: experimental
        '''
        return typing.cast("Wafv2", jsii.invoke(self, "toGetPermissionPolicy", []))

    @jsii.member(jsii_name="toGetRateBasedStatementManagedKeys")
    def to_get_rate_based_statement_managed_keys(self) -> "Wafv2":
        '''(experimental) Grants permission to retrieve the keys that are currently blocked by a rate-based rule.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/waf/latest/APIReference/API_GetRateBasedStatementManagedKeys.html

        :stability: experimental
        '''
        return typing.cast("Wafv2", jsii.invoke(self, "toGetRateBasedStatementManagedKeys", []))

    @jsii.member(jsii_name="toGetRegexPatternSet")
    def to_get_regex_pattern_set(self) -> "Wafv2":
        '''(experimental) Grants permission to retrieve details about a RegexPatternSet.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/waf/latest/APIReference/API_GetRegexPatternSet.html

        :stability: experimental
        '''
        return typing.cast("Wafv2", jsii.invoke(self, "toGetRegexPatternSet", []))

    @jsii.member(jsii_name="toGetRuleGroup")
    def to_get_rule_group(self) -> "Wafv2":
        '''(experimental) Grants permission to retrieve details about a RuleGroup.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/waf/latest/APIReference/API_GetRuleGroup.html

        :stability: experimental
        '''
        return typing.cast("Wafv2", jsii.invoke(self, "toGetRuleGroup", []))

    @jsii.member(jsii_name="toGetSampledRequests")
    def to_get_sampled_requests(self) -> "Wafv2":
        '''(experimental) Grants permission to retrieve detailed information about a sampling of web requests.

        Access Level: Read

        https://docs.aws.amazon.com/waf/latest/APIReference/API_GetSampledRequests.html

        :stability: experimental
        '''
        return typing.cast("Wafv2", jsii.invoke(self, "toGetSampledRequests", []))

    @jsii.member(jsii_name="toGetWebACL")
    def to_get_web_acl(self) -> "Wafv2":
        '''(experimental) Grants permission to retrieve details about a WebACL.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/waf/latest/APIReference/API_GetWebACL.html

        :stability: experimental
        '''
        return typing.cast("Wafv2", jsii.invoke(self, "toGetWebACL", []))

    @jsii.member(jsii_name="toGetWebACLForResource")
    def to_get_web_acl_for_resource(self) -> "Wafv2":
        '''(experimental) Grants permission to retrieve the WebACL that's associated with a resource.

        Access Level: Read

        https://docs.aws.amazon.com/waf/latest/APIReference/API_GetWebACLForResource.html

        :stability: experimental
        '''
        return typing.cast("Wafv2", jsii.invoke(self, "toGetWebACLForResource", []))

    @jsii.member(jsii_name="toListAvailableManagedRuleGroups")
    def to_list_available_managed_rule_groups(self) -> "Wafv2":
        '''(experimental) Grants permission to retrieve an array of managed rule groups that are available for you to use.

        Access Level: List

        https://docs.aws.amazon.com/waf/latest/APIReference/API_ListAvailableManagedRuleGroups.html

        :stability: experimental
        '''
        return typing.cast("Wafv2", jsii.invoke(self, "toListAvailableManagedRuleGroups", []))

    @jsii.member(jsii_name="toListAvailableManagedRuleGroupVersions")
    def to_list_available_managed_rule_group_versions(self) -> "Wafv2":
        '''(experimental) Grants permission to retrieve an array of managed rule group versions that are available for you to use.

        Access Level: List

        https://docs.aws.amazon.com/waf/latest/APIReference/API_ListAvailableManagedRuleGroupVersions.html

        :stability: experimental
        '''
        return typing.cast("Wafv2", jsii.invoke(self, "toListAvailableManagedRuleGroupVersions", []))

    @jsii.member(jsii_name="toListIPSets")
    def to_list_ip_sets(self) -> "Wafv2":
        '''(experimental) Grants permission to retrieve an array of IPSetSummary objects for the IP sets that you manage.

        Access Level: List

        https://docs.aws.amazon.com/waf/latest/APIReference/API_ListIPSets.html

        :stability: experimental
        '''
        return typing.cast("Wafv2", jsii.invoke(self, "toListIPSets", []))

    @jsii.member(jsii_name="toListLoggingConfigurations")
    def to_list_logging_configurations(self) -> "Wafv2":
        '''(experimental) Grants permission to retrieve an array of your LoggingConfiguration objects.

        Access Level: List

        https://docs.aws.amazon.com/waf/latest/APIReference/API_ListLoggingConfigurations.html

        :stability: experimental
        '''
        return typing.cast("Wafv2", jsii.invoke(self, "toListLoggingConfigurations", []))

    @jsii.member(jsii_name="toListManagedRuleSets")
    def to_list_managed_rule_sets(self) -> "Wafv2":
        '''(experimental) Grants permission to retrieve an array of your ManagedRuleSet objects.

        Access Level: List

        https://docs.aws.amazon.com/waf/latest/APIReference/API_ListManagedRuleSets.html

        :stability: experimental
        '''
        return typing.cast("Wafv2", jsii.invoke(self, "toListManagedRuleSets", []))

    @jsii.member(jsii_name="toListMobileSdkReleases")
    def to_list_mobile_sdk_releases(self) -> "Wafv2":
        '''(experimental) Grants permission to retrieve a list of the available releases for the mobile SDK and the specified device platform.

        Access Level: List

        https://docs.aws.amazon.com/waf/latest/APIReference/API_ListMobileSdkReleases.html

        :stability: experimental
        '''
        return typing.cast("Wafv2", jsii.invoke(self, "toListMobileSdkReleases", []))

    @jsii.member(jsii_name="toListRegexPatternSets")
    def to_list_regex_pattern_sets(self) -> "Wafv2":
        '''(experimental) Grants permission to retrieve an array of RegexPatternSetSummary objects for the regex pattern sets that you manage.

        Access Level: List

        https://docs.aws.amazon.com/waf/latest/APIReference/API_ListRegexPatternSets.html

        :stability: experimental
        '''
        return typing.cast("Wafv2", jsii.invoke(self, "toListRegexPatternSets", []))

    @jsii.member(jsii_name="toListResourcesForWebACL")
    def to_list_resources_for_web_acl(self) -> "Wafv2":
        '''(experimental) Grants permission to retrieve an array of the Amazon Resource Names (ARNs) for the resources that are associated with a web ACL.

        Access Level: List

        https://docs.aws.amazon.com/waf/latest/APIReference/API_ListResourcesForWebACL.html

        :stability: experimental
        '''
        return typing.cast("Wafv2", jsii.invoke(self, "toListResourcesForWebACL", []))

    @jsii.member(jsii_name="toListRuleGroups")
    def to_list_rule_groups(self) -> "Wafv2":
        '''(experimental) Grants permission to retrieve an array of RuleGroupSummary objects for the rule groups that you manage.

        Access Level: List

        https://docs.aws.amazon.com/waf/latest/APIReference/API_ListRuleGroups.html

        :stability: experimental
        '''
        return typing.cast("Wafv2", jsii.invoke(self, "toListRuleGroups", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Wafv2":
        '''(experimental) Grants permission to list tags for a resource.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/waf/latest/APIReference/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("Wafv2", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toListWebACLs")
    def to_list_web_ac_ls(self) -> "Wafv2":
        '''(experimental) Grants permission to retrieve an array of WebACLSummary objects for the web ACLs that you manage.

        Access Level: List

        https://docs.aws.amazon.com/waf/latest/APIReference/API_ListWebACLs.html

        :stability: experimental
        '''
        return typing.cast("Wafv2", jsii.invoke(self, "toListWebACLs", []))

    @jsii.member(jsii_name="toPutFirewallManagerRuleGroups")
    def to_put_firewall_manager_rule_groups(self) -> "Wafv2":
        '''(experimental) Grants permission to create FirewallManagedRulesGroups in a WebACL.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/APIReference/API_PutFirewallManagerRuleGroups.html

        :stability: experimental
        '''
        return typing.cast("Wafv2", jsii.invoke(self, "toPutFirewallManagerRuleGroups", []))

    @jsii.member(jsii_name="toPutLoggingConfiguration")
    def to_put_logging_configuration(self) -> "Wafv2":
        '''(experimental) Grants permission to enable a LoggingConfiguration, to start logging for a web ACL.

        Access Level: Write

        Dependent actions:

        - iam:CreateServiceLinkedRole

        https://docs.aws.amazon.com/waf/latest/APIReference/API_PutLoggingConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Wafv2", jsii.invoke(self, "toPutLoggingConfiguration", []))

    @jsii.member(jsii_name="toPutManagedRuleSetVersions")
    def to_put_managed_rule_set_versions(self) -> "Wafv2":
        '''(experimental) Grants permission to enable create a new or update an existing version of a ManagedRuleSet.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/APIReference/API_PutManagedRuleSetVersions.html

        :stability: experimental
        '''
        return typing.cast("Wafv2", jsii.invoke(self, "toPutManagedRuleSetVersions", []))

    @jsii.member(jsii_name="toPutPermissionPolicy")
    def to_put_permission_policy(self) -> "Wafv2":
        '''(experimental) Grants permission to attach an IAM policy to a resource, used to share rule groups between accounts.

        Access Level: Permissions management

        https://docs.aws.amazon.com/waf/latest/APIReference/API_PutPermissionPolicy.html

        :stability: experimental
        '''
        return typing.cast("Wafv2", jsii.invoke(self, "toPutPermissionPolicy", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Wafv2":
        '''(experimental) Grants permission to associate tags with a AWS resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()
        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/waf/latest/APIReference/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("Wafv2", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Wafv2":
        '''(experimental) Grants permission to disassociate tags from an AWS resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/waf/latest/APIReference/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("Wafv2", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateIPSet")
    def to_update_ip_set(self) -> "Wafv2":
        '''(experimental) Grants permission to update an IPSet.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/waf/latest/APIReference/API_UpdateIPSet.html

        :stability: experimental
        '''
        return typing.cast("Wafv2", jsii.invoke(self, "toUpdateIPSet", []))

    @jsii.member(jsii_name="toUpdateManagedRuleSetVersionExpiryDate")
    def to_update_managed_rule_set_version_expiry_date(self) -> "Wafv2":
        '''(experimental) Grants permission to update the expiry date of a version in ManagedRuleSet.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/APIReference/API_UpdateManagedRuleSetVersionExpiryDate.html

        :stability: experimental
        '''
        return typing.cast("Wafv2", jsii.invoke(self, "toUpdateManagedRuleSetVersionExpiryDate", []))

    @jsii.member(jsii_name="toUpdateRegexPatternSet")
    def to_update_regex_pattern_set(self) -> "Wafv2":
        '''(experimental) Grants permission to update a RegexPatternSet.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/waf/latest/APIReference/API_UpdateRegexPatternSet.html

        :stability: experimental
        '''
        return typing.cast("Wafv2", jsii.invoke(self, "toUpdateRegexPatternSet", []))

    @jsii.member(jsii_name="toUpdateRuleGroup")
    def to_update_rule_group(self) -> "Wafv2":
        '''(experimental) Grants permission to update a RuleGroup.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/waf/latest/APIReference/API_UpdateRuleGroup.html

        :stability: experimental
        '''
        return typing.cast("Wafv2", jsii.invoke(self, "toUpdateRuleGroup", []))

    @jsii.member(jsii_name="toUpdateWebACL")
    def to_update_web_acl(self) -> "Wafv2":
        '''(experimental) Grants permission to update a WebACL.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/waf/latest/APIReference/API_UpdateWebACL.html

        :stability: experimental
        '''
        return typing.cast("Wafv2", jsii.invoke(self, "toUpdateWebACL", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2d8a852ced943578df863aabffaa47041d14be45a00885cb35fdeedcf3b5efc5)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f5bead9f41fdbeb8a2ad5ce5dcc8ad572d6d5c4c27a746b4ef2cd6cd3f5979d0)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Wam(PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Wam"):
    '''(experimental) Statement provider for service `wam <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonworkspacesapplicationmanager.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `wam <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonworkspacesapplicationmanager.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="toAuthenticatePackager")
    def to_authenticate_packager(self) -> "Wam":
        '''(experimental) Allows the Amazon WAM packaging instance to access your application package catalog.

        Access Level: Write

        https://docs.aws.amazon.com/wam/latest/adminguide/iam.html

        :stability: experimental
        '''
        return typing.cast("Wam", jsii.invoke(self, "toAuthenticatePackager", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__273aca2911dc9ce070dcbafabc645500550bcd8df7ad6eb5a58990cafb7a2cd0)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b14d2d93399d618ce7633b3b7f27b82236ec0ed24c9657b2cccef0c1fd25afb9)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Wellarchitected(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Wellarchitected",
):
    '''(experimental) Statement provider for service `wellarchitected <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awswell-architectedtool.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `wellarchitected <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awswell-architectedtool.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onLens")
    def on_lens(
        self,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Wellarchitected":
        '''(experimental) Adds a resource of type lens to the statement.

        https://docs.aws.amazon.com/wellarchitected/latest/APIReference/API_Lens.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0a9b6615d1fa83c148cb04e24b5cafc83b067da60a3b5a73e47a8e1c793e9712)
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Wellarchitected", jsii.invoke(self, "onLens", [resource_id, account, region, partition]))

    @jsii.member(jsii_name="onWorkload")
    def on_workload(
        self,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Wellarchitected":
        '''(experimental) Adds a resource of type workload to the statement.

        https://docs.aws.amazon.com/wellarchitected/latest/APIReference/API_Workload.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ee951edaafd2d64937965d83943c50a9a65732ac92a61384702cf01c1b37f5ed)
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Wellarchitected", jsii.invoke(self, "onWorkload", [resource_id, account, region, partition]))

    @jsii.member(jsii_name="toAssociateLenses")
    def to_associate_lenses(self) -> "Wellarchitected":
        '''(experimental) Grants permission to associate a lens to the specified workload.

        Access Level: Write

        https://docs.aws.amazon.com/wellarchitected/latest/APIReference/API_AssociateLenses.html

        :stability: experimental
        '''
        return typing.cast("Wellarchitected", jsii.invoke(self, "toAssociateLenses", []))

    @jsii.member(jsii_name="toCreateLensShare")
    def to_create_lens_share(self) -> "Wellarchitected":
        '''(experimental) Grants permission to an owner of a lens to share with other AWS accounts and IAM Users.

        Access Level: Write

        https://docs.aws.amazon.com/wellarchitected/latest/APIReference/API_CreateLensShare.html

        :stability: experimental
        '''
        return typing.cast("Wellarchitected", jsii.invoke(self, "toCreateLensShare", []))

    @jsii.member(jsii_name="toCreateLensVersion")
    def to_create_lens_version(self) -> "Wellarchitected":
        '''(experimental) Grants permission to create a new lens version.

        Access Level: Write

        https://docs.aws.amazon.com/wellarchitected/latest/APIReference/API_CreateLensVersion.html

        :stability: experimental
        '''
        return typing.cast("Wellarchitected", jsii.invoke(self, "toCreateLensVersion", []))

    @jsii.member(jsii_name="toCreateMilestone")
    def to_create_milestone(self) -> "Wellarchitected":
        '''(experimental) Grants permission to create a new milestone for the specified workload.

        Access Level: Write

        https://docs.aws.amazon.com/wellarchitected/latest/APIReference/API_CreateMilestone.html

        :stability: experimental
        '''
        return typing.cast("Wellarchitected", jsii.invoke(self, "toCreateMilestone", []))

    @jsii.member(jsii_name="toCreateWorkload")
    def to_create_workload(self) -> "Wellarchitected":
        '''(experimental) Grants permission to create a new workload.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/wellarchitected/latest/APIReference/API_CreateWorkload.html

        :stability: experimental
        '''
        return typing.cast("Wellarchitected", jsii.invoke(self, "toCreateWorkload", []))

    @jsii.member(jsii_name="toCreateWorkloadShare")
    def to_create_workload_share(self) -> "Wellarchitected":
        '''(experimental) Grants permission to share a workload with another account.

        Access Level: Write

        https://docs.aws.amazon.com/wellarchitected/latest/APIReference/API_CreateWorkloadShare.html

        :stability: experimental
        '''
        return typing.cast("Wellarchitected", jsii.invoke(self, "toCreateWorkloadShare", []))

    @jsii.member(jsii_name="toDeleteLens")
    def to_delete_lens(self) -> "Wellarchitected":
        '''(experimental) Grants permission to delete a lens.

        Access Level: Write

        https://docs.aws.amazon.com/wellarchitected/latest/APIReference/API_DeleteLens.html

        :stability: experimental
        '''
        return typing.cast("Wellarchitected", jsii.invoke(self, "toDeleteLens", []))

    @jsii.member(jsii_name="toDeleteLensShare")
    def to_delete_lens_share(self) -> "Wellarchitected":
        '''(experimental) Grants permission to delete an existing lens share.

        Access Level: Write

        https://docs.aws.amazon.com/wellarchitected/latest/APIReference/API_DeleteLensShare.html

        :stability: experimental
        '''
        return typing.cast("Wellarchitected", jsii.invoke(self, "toDeleteLensShare", []))

    @jsii.member(jsii_name="toDeleteWorkload")
    def to_delete_workload(self) -> "Wellarchitected":
        '''(experimental) Grants permission to delete an existing workload.

        Access Level: Write

        https://docs.aws.amazon.com/wellarchitected/latest/APIReference/API_DeleteWorkload.html

        :stability: experimental
        '''
        return typing.cast("Wellarchitected", jsii.invoke(self, "toDeleteWorkload", []))

    @jsii.member(jsii_name="toDeleteWorkloadShare")
    def to_delete_workload_share(self) -> "Wellarchitected":
        '''(experimental) Grants permission to delete an existing workload share.

        Access Level: Write

        https://docs.aws.amazon.com/wellarchitected/latest/APIReference/API_DeleteWorkloadShare.html

        :stability: experimental
        '''
        return typing.cast("Wellarchitected", jsii.invoke(self, "toDeleteWorkloadShare", []))

    @jsii.member(jsii_name="toDisassociateLenses")
    def to_disassociate_lenses(self) -> "Wellarchitected":
        '''(experimental) Grants permission to disassociate a lens from the specified workload.

        Access Level: Write

        https://docs.aws.amazon.com/wellarchitected/latest/APIReference/API_DisassociateLenses.html

        :stability: experimental
        '''
        return typing.cast("Wellarchitected", jsii.invoke(self, "toDisassociateLenses", []))

    @jsii.member(jsii_name="toExportLens")
    def to_export_lens(self) -> "Wellarchitected":
        '''(experimental) Grants permission to export an existing lens.

        Access Level: Read

        https://docs.aws.amazon.com/wellarchitected/latest/APIReference/API_ExportLens.html

        :stability: experimental
        '''
        return typing.cast("Wellarchitected", jsii.invoke(self, "toExportLens", []))

    @jsii.member(jsii_name="toGetAnswer")
    def to_get_answer(self) -> "Wellarchitected":
        '''(experimental) Grants permission to retrieve the specified answer from the specified lens review.

        Access Level: Read

        https://docs.aws.amazon.com/wellarchitected/latest/APIReference/API_GetAnswer.html

        :stability: experimental
        '''
        return typing.cast("Wellarchitected", jsii.invoke(self, "toGetAnswer", []))

    @jsii.member(jsii_name="toGetLens")
    def to_get_lens(self) -> "Wellarchitected":
        '''(experimental) Grants permission to get an existing lens.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/wellarchitected/latest/APIReference/API_DeleteLensShare.html

        :stability: experimental
        '''
        return typing.cast("Wellarchitected", jsii.invoke(self, "toGetLens", []))

    @jsii.member(jsii_name="toGetLensReview")
    def to_get_lens_review(self) -> "Wellarchitected":
        '''(experimental) Grants permission to retrieve the specified lens review of the specified workload.

        Access Level: Read

        https://docs.aws.amazon.com/wellarchitected/latest/APIReference/API_GetLensReview.html

        :stability: experimental
        '''
        return typing.cast("Wellarchitected", jsii.invoke(self, "toGetLensReview", []))

    @jsii.member(jsii_name="toGetLensReviewReport")
    def to_get_lens_review_report(self) -> "Wellarchitected":
        '''(experimental) Grants permission to retrieve the report for the specified lens review.

        Access Level: Read

        https://docs.aws.amazon.com/wellarchitected/latest/APIReference/API_GetLensReviewReport.html

        :stability: experimental
        '''
        return typing.cast("Wellarchitected", jsii.invoke(self, "toGetLensReviewReport", []))

    @jsii.member(jsii_name="toGetLensVersionDifference")
    def to_get_lens_version_difference(self) -> "Wellarchitected":
        '''(experimental) Grants permission to get the difference between the specified lens version and latest available lens version.

        Access Level: Read

        https://docs.aws.amazon.com/wellarchitected/latest/APIReference/API_GetLensVersionDifference.html

        :stability: experimental
        '''
        return typing.cast("Wellarchitected", jsii.invoke(self, "toGetLensVersionDifference", []))

    @jsii.member(jsii_name="toGetMilestone")
    def to_get_milestone(self) -> "Wellarchitected":
        '''(experimental) Grants permission to retrieve the specified milestone of the specified workload.

        Access Level: Read

        https://docs.aws.amazon.com/wellarchitected/latest/APIReference/API_GetMilestone.html

        :stability: experimental
        '''
        return typing.cast("Wellarchitected", jsii.invoke(self, "toGetMilestone", []))

    @jsii.member(jsii_name="toGetWorkload")
    def to_get_workload(self) -> "Wellarchitected":
        '''(experimental) Grants permission to retrieve the specified workload.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/wellarchitected/latest/APIReference/API_GetWorkload.html

        :stability: experimental
        '''
        return typing.cast("Wellarchitected", jsii.invoke(self, "toGetWorkload", []))

    @jsii.member(jsii_name="toImportLens")
    def to_import_lens(self) -> "Wellarchitected":
        '''(experimental) Grants permission to import a new lens.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/wellarchitected/latest/APIReference/API_ImportLens.html

        :stability: experimental
        '''
        return typing.cast("Wellarchitected", jsii.invoke(self, "toImportLens", []))

    @jsii.member(jsii_name="toListAnswers")
    def to_list_answers(self) -> "Wellarchitected":
        '''(experimental) Grants permission to list the answers from the specified lens review.

        Access Level: List

        https://docs.aws.amazon.com/wellarchitected/latest/APIReference/API_ListAnswers.html

        :stability: experimental
        '''
        return typing.cast("Wellarchitected", jsii.invoke(self, "toListAnswers", []))

    @jsii.member(jsii_name="toListCheckDetails")
    def to_list_check_details(self) -> "Wellarchitected":
        '''(experimental) Grants permission to list the check-details for the workload.

        Access Level: List

        https://docs.aws.amazon.com/wellarchitected/latest/APIReference/API_ListCheckDetails.html

        :stability: experimental
        '''
        return typing.cast("Wellarchitected", jsii.invoke(self, "toListCheckDetails", []))

    @jsii.member(jsii_name="toListCheckSummaries")
    def to_list_check_summaries(self) -> "Wellarchitected":
        '''(experimental) Grants permission to list the check-summaries for the workload.

        Access Level: List

        https://docs.aws.amazon.com/wellarchitected/latest/APIReference/API_ListCheckSummaries.html

        :stability: experimental
        '''
        return typing.cast("Wellarchitected", jsii.invoke(self, "toListCheckSummaries", []))

    @jsii.member(jsii_name="toListLenses")
    def to_list_lenses(self) -> "Wellarchitected":
        '''(experimental) Grants permission to list the lenses available to this account.

        Access Level: List

        https://docs.aws.amazon.com/wellarchitected/latest/APIReference/API_ListLenses.html

        :stability: experimental
        '''
        return typing.cast("Wellarchitected", jsii.invoke(self, "toListLenses", []))

    @jsii.member(jsii_name="toListLensReviewImprovements")
    def to_list_lens_review_improvements(self) -> "Wellarchitected":
        '''(experimental) Grants permission to list the improvements of the specified lens review.

        Access Level: List

        https://docs.aws.amazon.com/wellarchitected/latest/APIReference/API_ListLensReviewImprovements.html

        :stability: experimental
        '''
        return typing.cast("Wellarchitected", jsii.invoke(self, "toListLensReviewImprovements", []))

    @jsii.member(jsii_name="toListLensReviews")
    def to_list_lens_reviews(self) -> "Wellarchitected":
        '''(experimental) Grants permission to list the lens reviews of the specified workload.

        Access Level: List

        https://docs.aws.amazon.com/wellarchitected/latest/APIReference/API_ListLensReviews.html

        :stability: experimental
        '''
        return typing.cast("Wellarchitected", jsii.invoke(self, "toListLensReviews", []))

    @jsii.member(jsii_name="toListLensShares")
    def to_list_lens_shares(self) -> "Wellarchitected":
        '''(experimental) Grants permission to list all shares created for a lens.

        Access Level: List

        https://docs.aws.amazon.com/wellarchitected/latest/APIReference/API_ListLensShares.html

        :stability: experimental
        '''
        return typing.cast("Wellarchitected", jsii.invoke(self, "toListLensShares", []))

    @jsii.member(jsii_name="toListMilestones")
    def to_list_milestones(self) -> "Wellarchitected":
        '''(experimental) Grants permission to list the milestones of the specified workload.

        Access Level: List

        https://docs.aws.amazon.com/wellarchitected/latest/APIReference/API_ListMilestones.html

        :stability: experimental
        '''
        return typing.cast("Wellarchitected", jsii.invoke(self, "toListMilestones", []))

    @jsii.member(jsii_name="toListNotifications")
    def to_list_notifications(self) -> "Wellarchitected":
        '''(experimental) Grants permission to list notifications related to the account or specified resource.

        Access Level: List

        https://docs.aws.amazon.com/wellarchitected/latest/APIReference/API_ListNotifications.html

        :stability: experimental
        '''
        return typing.cast("Wellarchitected", jsii.invoke(self, "toListNotifications", []))

    @jsii.member(jsii_name="toListShareInvitations")
    def to_list_share_invitations(self) -> "Wellarchitected":
        '''(experimental) Grants permission to list the workload share invitations of the specified account or user.

        Access Level: List

        https://docs.aws.amazon.com/wellarchitected/latest/APIReference/API_ListShareInvitations.html

        :stability: experimental
        '''
        return typing.cast("Wellarchitected", jsii.invoke(self, "toListShareInvitations", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Wellarchitected":
        '''(experimental) Grants permission to list tags for a Well-Architected resource.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/wellarchitected/latest/APIReference/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("Wellarchitected", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toListWorkloads")
    def to_list_workloads(self) -> "Wellarchitected":
        '''(experimental) Grants permission to list the workloads in this account.

        Access Level: List

        https://docs.aws.amazon.com/wellarchitected/latest/APIReference/API_ListWorkloads.html

        :stability: experimental
        '''
        return typing.cast("Wellarchitected", jsii.invoke(self, "toListWorkloads", []))

    @jsii.member(jsii_name="toListWorkloadShares")
    def to_list_workload_shares(self) -> "Wellarchitected":
        '''(experimental) Grants permission to list the workload shares of the specified workload.

        Access Level: List

        https://docs.aws.amazon.com/wellarchitected/latest/APIReference/API_ListWorkloadShares.html

        :stability: experimental
        '''
        return typing.cast("Wellarchitected", jsii.invoke(self, "toListWorkloadShares", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Wellarchitected":
        '''(experimental) Grants permission to tag a Well-Architected resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/wellarchitected/latest/APIReference/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("Wellarchitected", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Wellarchitected":
        '''(experimental) Grants permission to untag a Well-Architected resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/wellarchitected/latest/APIReference/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("Wellarchitected", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateAnswer")
    def to_update_answer(self) -> "Wellarchitected":
        '''(experimental) Grants permission to update properties of the specified answer.

        Access Level: Write

        https://docs.aws.amazon.com/wellarchitected/latest/APIReference/API_UpdateAnswer.html

        :stability: experimental
        '''
        return typing.cast("Wellarchitected", jsii.invoke(self, "toUpdateAnswer", []))

    @jsii.member(jsii_name="toUpdateGlobalSettings")
    def to_update_global_settings(self) -> "Wellarchitected":
        '''(experimental) Grants permission to update settings to enable aws-organization support.

        Access Level: Write

        https://docs.aws.amazon.com/wellarchitected/latest/APIReference/API_UpdateGlobalSettings.html

        :stability: experimental
        '''
        return typing.cast("Wellarchitected", jsii.invoke(self, "toUpdateGlobalSettings", []))

    @jsii.member(jsii_name="toUpdateLensReview")
    def to_update_lens_review(self) -> "Wellarchitected":
        '''(experimental) Grants permission to update properties of the specified lens review.

        Access Level: Write

        https://docs.aws.amazon.com/wellarchitected/latest/APIReference/API_UpdateLensReview.html

        :stability: experimental
        '''
        return typing.cast("Wellarchitected", jsii.invoke(self, "toUpdateLensReview", []))

    @jsii.member(jsii_name="toUpdateShareInvitation")
    def to_update_share_invitation(self) -> "Wellarchitected":
        '''(experimental) Grants permission to update status of the specified workload share invitation.

        Access Level: Write

        https://docs.aws.amazon.com/wellarchitected/latest/APIReference/API_UpdateShareInvitation.html

        :stability: experimental
        '''
        return typing.cast("Wellarchitected", jsii.invoke(self, "toUpdateShareInvitation", []))

    @jsii.member(jsii_name="toUpdateWorkload")
    def to_update_workload(self) -> "Wellarchitected":
        '''(experimental) Grants permission to update properties of the specified workload.

        Access Level: Write

        https://docs.aws.amazon.com/wellarchitected/latest/APIReference/API_UpdateWorkload.html

        :stability: experimental
        '''
        return typing.cast("Wellarchitected", jsii.invoke(self, "toUpdateWorkload", []))

    @jsii.member(jsii_name="toUpdateWorkloadShare")
    def to_update_workload_share(self) -> "Wellarchitected":
        '''(experimental) Grants permission to update properties of the specified workload.

        Access Level: Write

        https://docs.aws.amazon.com/wellarchitected/latest/APIReference/API_UpdateWorkloadShare.html

        :stability: experimental
        '''
        return typing.cast("Wellarchitected", jsii.invoke(self, "toUpdateWorkloadShare", []))

    @jsii.member(jsii_name="toUpgradeLensReview")
    def to_upgrade_lens_review(self) -> "Wellarchitected":
        '''(experimental) Grants permission to upgrade the specified lens review to use the latest version of the associated lens.

        Access Level: Write

        https://docs.aws.amazon.com/wellarchitected/latest/APIReference/API_UpgradeLensReview.html

        :stability: experimental
        '''
        return typing.cast("Wellarchitected", jsii.invoke(self, "toUpgradeLensReview", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__54ac9ebc17beb13824dfc5aaf774ac49198130637b43206a68cf26f4f76906cc)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__97fbf4845fa86ed93ac2417b32ee854b6342a49bcbea4f52b1e80851b5e685e0)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Wickr(PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Wickr"):
    '''(experimental) Statement provider for service `wickr <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awswickr.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `wickr <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awswickr.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="toCreateAdminSession")
    def to_create_admin_session(self) -> "Wickr":
        '''(experimental) Grants permission to create and manage Wickr networks.

        Access Level: Write

        https://docs.aws.amazon.com/wickr/latest/adminguide/security-iam.html

        :stability: experimental
        '''
        return typing.cast("Wickr", jsii.invoke(self, "toCreateAdminSession", []))

    @jsii.member(jsii_name="toListNetworks")
    def to_list_networks(self) -> "Wickr":
        '''(experimental) Grants permission to view Wickr networks.

        Access Level: Write

        https://docs.aws.amazon.com/wickr/latest/adminguide/security-iam.html

        :stability: experimental
        '''
        return typing.cast("Wickr", jsii.invoke(self, "toListNetworks", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4e0713cd32f8bef53e9e4a5a1e1fcf8ebbce3db18cac5d55efe3d52250b37dc8)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6d18c58daa5d367e518e07d306c7df5ba8fe6225efb6712957f696a8ed54c5c2)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Wisdom(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Wisdom",
):
    '''(experimental) Statement provider for service `wisdom <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonconnectwisdom.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `wisdom <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonconnectwisdom.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onAssistant")
    def on_assistant(
        self,
        assistant_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Wisdom":
        '''(experimental) Adds a resource of type Assistant to the statement.

        https://docs.aws.amazon.com/wisdom/latest/APIReference/API_AssistantData.html

        :param assistant_id: - Identifier for the assistantId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4c6f9dbfb753537dde4e19542aec7b84a4be0c9a4b72226eba9c2b1ea887aecb)
            check_type(argname="argument assistant_id", value=assistant_id, expected_type=type_hints["assistant_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Wisdom", jsii.invoke(self, "onAssistant", [assistant_id, account, region, partition]))

    @jsii.member(jsii_name="onAssistantAssociation")
    def on_assistant_association(
        self,
        assistant_id: builtins.str,
        assistant_association_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Wisdom":
        '''(experimental) Adds a resource of type AssistantAssociation to the statement.

        https://docs.aws.amazon.com/wisdom/latest/APIReference/API_AssistantAssociationData.html

        :param assistant_id: - Identifier for the assistantId.
        :param assistant_association_id: - Identifier for the assistantAssociationId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__21e43f4eef88ed9761128c4979690bb6284e0fa5f0a4c9d666c2f212f0d79583)
            check_type(argname="argument assistant_id", value=assistant_id, expected_type=type_hints["assistant_id"])
            check_type(argname="argument assistant_association_id", value=assistant_association_id, expected_type=type_hints["assistant_association_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Wisdom", jsii.invoke(self, "onAssistantAssociation", [assistant_id, assistant_association_id, account, region, partition]))

    @jsii.member(jsii_name="onContent")
    def on_content(
        self,
        knowledge_base_id: builtins.str,
        content_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Wisdom":
        '''(experimental) Adds a resource of type Content to the statement.

        https://docs.aws.amazon.com/wisdom/latest/APIReference/API_ContentData.html

        :param knowledge_base_id: - Identifier for the knowledgeBaseId.
        :param content_id: - Identifier for the contentId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__76d6c5677d39d4494d50ca8e11068423ee4f12d12011f874c2f82b8f99de6614)
            check_type(argname="argument knowledge_base_id", value=knowledge_base_id, expected_type=type_hints["knowledge_base_id"])
            check_type(argname="argument content_id", value=content_id, expected_type=type_hints["content_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Wisdom", jsii.invoke(self, "onContent", [knowledge_base_id, content_id, account, region, partition]))

    @jsii.member(jsii_name="onKnowledgeBase")
    def on_knowledge_base(
        self,
        knowledge_base_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Wisdom":
        '''(experimental) Adds a resource of type KnowledgeBase to the statement.

        https://docs.aws.amazon.com/wisdom/latest/APIReference/API_KnowledgeBaseData.html

        :param knowledge_base_id: - Identifier for the knowledgeBaseId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1b4f37732295839a3ce1d2c4cf78a54941bc2a6cda8c7facb83b9d84c7ce7671)
            check_type(argname="argument knowledge_base_id", value=knowledge_base_id, expected_type=type_hints["knowledge_base_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Wisdom", jsii.invoke(self, "onKnowledgeBase", [knowledge_base_id, account, region, partition]))

    @jsii.member(jsii_name="onSession")
    def on_session(
        self,
        assistant_id: builtins.str,
        session_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Wisdom":
        '''(experimental) Adds a resource of type Session to the statement.

        https://docs.aws.amazon.com/wisdom/latest/APIReference/API_SessionData.html

        :param assistant_id: - Identifier for the assistantId.
        :param session_id: - Identifier for the sessionId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e3ee43d869967d26dfcfb2217244b2b93bbd2f15008b0e71691261d0193ee9a3)
            check_type(argname="argument assistant_id", value=assistant_id, expected_type=type_hints["assistant_id"])
            check_type(argname="argument session_id", value=session_id, expected_type=type_hints["session_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Wisdom", jsii.invoke(self, "onSession", [assistant_id, session_id, account, region, partition]))

    @jsii.member(jsii_name="toCreateAssistant")
    def to_create_assistant(self) -> "Wisdom":
        '''(experimental) Grants permission to create an assistant.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/wisdom/latest/APIReference/API_CreateAssistant.html

        :stability: experimental
        '''
        return typing.cast("Wisdom", jsii.invoke(self, "toCreateAssistant", []))

    @jsii.member(jsii_name="toCreateAssistantAssociation")
    def to_create_assistant_association(self) -> "Wisdom":
        '''(experimental) Grants permission to create an association between an assistant and another resource.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/wisdom/latest/APIReference/API_CreateAssistantAssociation.html

        :stability: experimental
        '''
        return typing.cast("Wisdom", jsii.invoke(self, "toCreateAssistantAssociation", []))

    @jsii.member(jsii_name="toCreateContent")
    def to_create_content(self) -> "Wisdom":
        '''(experimental) Grants permission to create content.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/wisdom/latest/APIReference/API_CreateContent.html

        :stability: experimental
        '''
        return typing.cast("Wisdom", jsii.invoke(self, "toCreateContent", []))

    @jsii.member(jsii_name="toCreateKnowledgeBase")
    def to_create_knowledge_base(self) -> "Wisdom":
        '''(experimental) Grants permission to create a knowledge base.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/wisdom/latest/APIReference/API_CreateKnowledgeBase.html

        :stability: experimental
        '''
        return typing.cast("Wisdom", jsii.invoke(self, "toCreateKnowledgeBase", []))

    @jsii.member(jsii_name="toCreateSession")
    def to_create_session(self) -> "Wisdom":
        '''(experimental) Grants permission to create a session.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/wisdom/latest/APIReference/API_CreateSession.html

        :stability: experimental
        '''
        return typing.cast("Wisdom", jsii.invoke(self, "toCreateSession", []))

    @jsii.member(jsii_name="toDeleteAssistant")
    def to_delete_assistant(self) -> "Wisdom":
        '''(experimental) Grants permission to delete an assistant.

        Access Level: Write

        https://docs.aws.amazon.com/wisdom/latest/APIReference/API_DeleteAssistant.html

        :stability: experimental
        '''
        return typing.cast("Wisdom", jsii.invoke(self, "toDeleteAssistant", []))

    @jsii.member(jsii_name="toDeleteAssistantAssociation")
    def to_delete_assistant_association(self) -> "Wisdom":
        '''(experimental) Grants permission to delete an assistant association.

        Access Level: Write

        https://docs.aws.amazon.com/wisdom/latest/APIReference/API_DeleteAssistantAssociation.html

        :stability: experimental
        '''
        return typing.cast("Wisdom", jsii.invoke(self, "toDeleteAssistantAssociation", []))

    @jsii.member(jsii_name="toDeleteContent")
    def to_delete_content(self) -> "Wisdom":
        '''(experimental) Grants permission to delete content.

        Access Level: Write

        https://docs.aws.amazon.com/wisdom/latest/APIReference/API_DeleteContent.html

        :stability: experimental
        '''
        return typing.cast("Wisdom", jsii.invoke(self, "toDeleteContent", []))

    @jsii.member(jsii_name="toDeleteKnowledgeBase")
    def to_delete_knowledge_base(self) -> "Wisdom":
        '''(experimental) Grants permission to delete a knowledge base.

        Access Level: Write

        https://docs.aws.amazon.com/wisdom/latest/APIReference/API_DeleteKnowledgeBase.html

        :stability: experimental
        '''
        return typing.cast("Wisdom", jsii.invoke(self, "toDeleteKnowledgeBase", []))

    @jsii.member(jsii_name="toGetAssistant")
    def to_get_assistant(self) -> "Wisdom":
        '''(experimental) Grants permission to retrieve information about an assistant.

        Access Level: Read

        https://docs.aws.amazon.com/wisdom/latest/APIReference/API_GetAssistant.html

        :stability: experimental
        '''
        return typing.cast("Wisdom", jsii.invoke(self, "toGetAssistant", []))

    @jsii.member(jsii_name="toGetAssistantAssociation")
    def to_get_assistant_association(self) -> "Wisdom":
        '''(experimental) Grants permission to retrieve information about an assistant association.

        Access Level: Read

        https://docs.aws.amazon.com/wisdom/latest/APIReference/API_GetAssistantAssociation.html

        :stability: experimental
        '''
        return typing.cast("Wisdom", jsii.invoke(self, "toGetAssistantAssociation", []))

    @jsii.member(jsii_name="toGetContent")
    def to_get_content(self) -> "Wisdom":
        '''(experimental) Grants permission to retrieve content, including a pre-signed URL to download the content.

        Access Level: Read

        https://docs.aws.amazon.com/wisdom/latest/APIReference/API_GetContent.html

        :stability: experimental
        '''
        return typing.cast("Wisdom", jsii.invoke(self, "toGetContent", []))

    @jsii.member(jsii_name="toGetContentSummary")
    def to_get_content_summary(self) -> "Wisdom":
        '''(experimental) Grants permission to retrieve summary information about the content.

        Access Level: Read

        https://docs.aws.amazon.com/wisdom/latest/APIReference/API_GetContentSummary.html

        :stability: experimental
        '''
        return typing.cast("Wisdom", jsii.invoke(self, "toGetContentSummary", []))

    @jsii.member(jsii_name="toGetKnowledgeBase")
    def to_get_knowledge_base(self) -> "Wisdom":
        '''(experimental) Grants permission to retrieve information about the knowledge base.

        Access Level: Read

        https://docs.aws.amazon.com/wisdom/latest/APIReference/API_GetKnowledgeBase.html

        :stability: experimental
        '''
        return typing.cast("Wisdom", jsii.invoke(self, "toGetKnowledgeBase", []))

    @jsii.member(jsii_name="toGetRecommendations")
    def to_get_recommendations(self) -> "Wisdom":
        '''(experimental) Grants permission to retrieve recommendations for the specified session.

        Access Level: Read

        https://docs.aws.amazon.com/wisdom/latest/APIReference/API_GetRecommendations.html

        :stability: experimental
        '''
        return typing.cast("Wisdom", jsii.invoke(self, "toGetRecommendations", []))

    @jsii.member(jsii_name="toGetSession")
    def to_get_session(self) -> "Wisdom":
        '''(experimental) Grants permission to retrieve information for a specified session.

        Access Level: Read

        https://docs.aws.amazon.com/wisdom/latest/APIReference/API_GetSession.html

        :stability: experimental
        '''
        return typing.cast("Wisdom", jsii.invoke(self, "toGetSession", []))

    @jsii.member(jsii_name="toListAssistantAssociations")
    def to_list_assistant_associations(self) -> "Wisdom":
        '''(experimental) Grants permission to list information about assistant associations.

        Access Level: List

        https://docs.aws.amazon.com/wisdom/latest/APIReference/API_ListAssistantAssociations.html

        :stability: experimental
        '''
        return typing.cast("Wisdom", jsii.invoke(self, "toListAssistantAssociations", []))

    @jsii.member(jsii_name="toListAssistants")
    def to_list_assistants(self) -> "Wisdom":
        '''(experimental) Grants permission to list information about assistants.

        Access Level: List

        https://docs.aws.amazon.com/wisdom/latest/APIReference/API_ListAssistants.html

        :stability: experimental
        '''
        return typing.cast("Wisdom", jsii.invoke(self, "toListAssistants", []))

    @jsii.member(jsii_name="toListContents")
    def to_list_contents(self) -> "Wisdom":
        '''(experimental) Grants permission to list the content with a knowledge base.

        Access Level: List

        https://docs.aws.amazon.com/wisdom/latest/APIReference/API_ListContents.html

        :stability: experimental
        '''
        return typing.cast("Wisdom", jsii.invoke(self, "toListContents", []))

    @jsii.member(jsii_name="toListKnowledgeBases")
    def to_list_knowledge_bases(self) -> "Wisdom":
        '''(experimental) Grants permission to list information about knowledge bases.

        Access Level: List

        https://docs.aws.amazon.com/wisdom/latest/APIReference/API_ListKnowledgeBases.html

        :stability: experimental
        '''
        return typing.cast("Wisdom", jsii.invoke(self, "toListKnowledgeBases", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Wisdom":
        '''(experimental) Grants permission to list the tags for the specified resource.

        Access Level: Read

        https://docs.aws.amazon.com/wisdom/latest/APIReference/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("Wisdom", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toNotifyRecommendationsReceived")
    def to_notify_recommendations_received(self) -> "Wisdom":
        '''(experimental) Grants permission to remove the specified recommendations from the specified assistant's queue of newly available recommendations.

        Access Level: Write

        https://docs.aws.amazon.com/wisdom/latest/APIReference/API_NotifyRecommendationsReceived.html

        :stability: experimental
        '''
        return typing.cast("Wisdom", jsii.invoke(self, "toNotifyRecommendationsReceived", []))

    @jsii.member(jsii_name="toQueryAssistant")
    def to_query_assistant(self) -> "Wisdom":
        '''(experimental) Grants permission to perform a manual search against the specified assistant.

        Access Level: Read

        https://docs.aws.amazon.com/wisdom/latest/APIReference/API_QueryAssistant.html

        :stability: experimental
        '''
        return typing.cast("Wisdom", jsii.invoke(self, "toQueryAssistant", []))

    @jsii.member(jsii_name="toRemoveKnowledgeBaseTemplateUri")
    def to_remove_knowledge_base_template_uri(self) -> "Wisdom":
        '''(experimental) Grants permission to remove a URI template from a knowledge base.

        Access Level: Write

        https://docs.aws.amazon.com/wisdom/latest/APIReference/API_RemoveKnowledgeBaseTemplateUri.html

        :stability: experimental
        '''
        return typing.cast("Wisdom", jsii.invoke(self, "toRemoveKnowledgeBaseTemplateUri", []))

    @jsii.member(jsii_name="toSearchContent")
    def to_search_content(self) -> "Wisdom":
        '''(experimental) Grants permission to search for content referencing a specified knowledge base.

        Can be used to get a specific content resource by its name

        Access Level: Read

        https://docs.aws.amazon.com/wisdom/latest/APIReference/API_SearchContent.html

        :stability: experimental
        '''
        return typing.cast("Wisdom", jsii.invoke(self, "toSearchContent", []))

    @jsii.member(jsii_name="toSearchSessions")
    def to_search_sessions(self) -> "Wisdom":
        '''(experimental) Grants permission to search for sessions referencing a specified assistant.

        Can be used to et a specific session resource by its name

        Access Level: Read

        https://docs.aws.amazon.com/wisdom/latest/APIReference/API_SearchSessions.html

        :stability: experimental
        '''
        return typing.cast("Wisdom", jsii.invoke(self, "toSearchSessions", []))

    @jsii.member(jsii_name="toStartContentUpload")
    def to_start_content_upload(self) -> "Wisdom":
        '''(experimental) Grants permission to get a URL to upload content to a knowledge base.

        Access Level: Write

        https://docs.aws.amazon.com/wisdom/latest/APIReference/API_StartContentUpload.html

        :stability: experimental
        '''
        return typing.cast("Wisdom", jsii.invoke(self, "toStartContentUpload", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Wisdom":
        '''(experimental) Grants permission to add the specified tags to the specified resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/wisdom/latest/APIReference/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("Wisdom", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Wisdom":
        '''(experimental) Grants permission to remove the specified tags from the specified resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/wisdom/latest/APIReference/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("Wisdom", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateContent")
    def to_update_content(self) -> "Wisdom":
        '''(experimental) Grants permission to update information about the content.

        Access Level: Write

        https://docs.aws.amazon.com/wisdom/latest/APIReference/API_UpdateContent.html

        :stability: experimental
        '''
        return typing.cast("Wisdom", jsii.invoke(self, "toUpdateContent", []))

    @jsii.member(jsii_name="toUpdateKnowledgeBaseTemplateUri")
    def to_update_knowledge_base_template_uri(self) -> "Wisdom":
        '''(experimental) Grants permission to update the template URI of a knowledge base.

        Access Level: Write

        https://docs.aws.amazon.com/wisdom/latest/APIReference/API_UpdateKnowledgeBaseTemplateUri.html

        :stability: experimental
        '''
        return typing.cast("Wisdom", jsii.invoke(self, "toUpdateKnowledgeBaseTemplateUri", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__331c4134916c6efab0f48c33424d262be30e1d2ea042269d889ad612623c2306)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a5ca4df6e15de9afcb93db9aca6d365757827f6d10da0525cf6d579ddce671c4)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Workdocs(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Workdocs",
):
    '''(experimental) Statement provider for service `workdocs <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonworkdocs.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `workdocs <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonworkdocs.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="toAbortDocumentVersionUpload")
    def to_abort_document_version_upload(self) -> "Workdocs":
        '''(experimental) Grants permission to abort the upload of the specified document version that was previously initiated by InitiateDocumentVersionUpload.

        Access Level: Write

        https://docs.aws.amazon.com/workdocs/latest/APIReference/API_AbortDocumentVersionUpload.html

        :stability: experimental
        '''
        return typing.cast("Workdocs", jsii.invoke(self, "toAbortDocumentVersionUpload", []))

    @jsii.member(jsii_name="toActivateUser")
    def to_activate_user(self) -> "Workdocs":
        '''(experimental) Grants permission to activate the specified user. Only active users can access Amazon WorkDocs.

        Access Level: Write

        https://docs.aws.amazon.com/workdocs/latest/APIReference/API_ActivateUser.html

        :stability: experimental
        '''
        return typing.cast("Workdocs", jsii.invoke(self, "toActivateUser", []))

    @jsii.member(jsii_name="toAddNotificationPermissions")
    def to_add_notification_permissions(self) -> "Workdocs":
        '''(experimental) Grants permission to add principals that are allowed to call notification subscription APIs for a given WorkDocs site.

        Access Level: Write

        https://docs.aws.amazon.com/workdocs/latest/adminguide/manage-notifications.html

        :stability: experimental
        '''
        return typing.cast("Workdocs", jsii.invoke(self, "toAddNotificationPermissions", []))

    @jsii.member(jsii_name="toAddResourcePermissions")
    def to_add_resource_permissions(self) -> "Workdocs":
        '''(experimental) Grants permission to create a set of permissions for the specified folder or document.

        Access Level: Write

        https://docs.aws.amazon.com/workdocs/latest/APIReference/API_AddResourcePermissions.html

        :stability: experimental
        '''
        return typing.cast("Workdocs", jsii.invoke(self, "toAddResourcePermissions", []))

    @jsii.member(jsii_name="toAddUserToGroup")
    def to_add_user_to_group(self) -> "Workdocs":
        '''(experimental) Grants permission to add a user to a group.

        Access Level: Write

        https://docs.aws.amazon.com/workdocs/latest/adminguide/manage_set_admin.html

        :stability: experimental
        '''
        return typing.cast("Workdocs", jsii.invoke(self, "toAddUserToGroup", []))

    @jsii.member(jsii_name="toCheckAlias")
    def to_check_alias(self) -> "Workdocs":
        '''(experimental) Grants permission to check an alias.

        Access Level: Read

        https://docs.aws.amazon.com/workdocs/latest/adminguide/cloud_quick_start.html

        :stability: experimental
        '''
        return typing.cast("Workdocs", jsii.invoke(self, "toCheckAlias", []))

    @jsii.member(jsii_name="toCreateComment")
    def to_create_comment(self) -> "Workdocs":
        '''(experimental) Grants permission to add a new comment to the specified document version.

        Access Level: Write

        https://docs.aws.amazon.com/workdocs/latest/APIReference/API_CreateComment.html

        :stability: experimental
        '''
        return typing.cast("Workdocs", jsii.invoke(self, "toCreateComment", []))

    @jsii.member(jsii_name="toCreateCustomMetadata")
    def to_create_custom_metadata(self) -> "Workdocs":
        '''(experimental) Grants permission to add one or more custom properties to the specified resource.

        Access Level: Write

        https://docs.aws.amazon.com/workdocs/latest/APIReference/API_CreateCustomMetadata.html

        :stability: experimental
        '''
        return typing.cast("Workdocs", jsii.invoke(self, "toCreateCustomMetadata", []))

    @jsii.member(jsii_name="toCreateFolder")
    def to_create_folder(self) -> "Workdocs":
        '''(experimental) Grants permission to create a folder with the specified name and parent folder.

        Access Level: Write

        https://docs.aws.amazon.com/workdocs/latest/APIReference/API_CreateFolder.html

        :stability: experimental
        '''
        return typing.cast("Workdocs", jsii.invoke(self, "toCreateFolder", []))

    @jsii.member(jsii_name="toCreateInstance")
    def to_create_instance(self) -> "Workdocs":
        '''(experimental) Grants permission to create an instance.

        Access Level: Write

        https://docs.aws.amazon.com/workdocs/latest/adminguide/getting_started.html

        :stability: experimental
        '''
        return typing.cast("Workdocs", jsii.invoke(self, "toCreateInstance", []))

    @jsii.member(jsii_name="toCreateLabels")
    def to_create_labels(self) -> "Workdocs":
        '''(experimental) Grants permission to add labels to the given resource.

        Access Level: Write

        https://docs.aws.amazon.com/workdocs/latest/APIReference/API_CreateLabels.html

        :stability: experimental
        '''
        return typing.cast("Workdocs", jsii.invoke(self, "toCreateLabels", []))

    @jsii.member(jsii_name="toCreateNotificationSubscription")
    def to_create_notification_subscription(self) -> "Workdocs":
        '''(experimental) Grants permission to configure WorkDocs to use Amazon SNS notifications.

        Access Level: Write

        https://docs.aws.amazon.com/workdocs/latest/APIReference/API_CreateNotificationSubscription.html

        :stability: experimental
        '''
        return typing.cast("Workdocs", jsii.invoke(self, "toCreateNotificationSubscription", []))

    @jsii.member(jsii_name="toCreateUser")
    def to_create_user(self) -> "Workdocs":
        '''(experimental) Grants permission to create a user in a Simple AD or Microsoft AD directory.

        Access Level: Write

        https://docs.aws.amazon.com/workdocs/latest/APIReference/API_CreateUser.html

        :stability: experimental
        '''
        return typing.cast("Workdocs", jsii.invoke(self, "toCreateUser", []))

    @jsii.member(jsii_name="toDeactivateUser")
    def to_deactivate_user(self) -> "Workdocs":
        '''(experimental) Grants permission to deactivate the specified user, which revokes the user's access to Amazon WorkDocs.

        Access Level: Write

        https://docs.aws.amazon.com/workdocs/latest/APIReference/API_DeactivateUser.html

        :stability: experimental
        '''
        return typing.cast("Workdocs", jsii.invoke(self, "toDeactivateUser", []))

    @jsii.member(jsii_name="toDeleteComment")
    def to_delete_comment(self) -> "Workdocs":
        '''(experimental) Grants permission to delete the specified comment from the document version.

        Access Level: Write

        https://docs.aws.amazon.com/workdocs/latest/APIReference/API_DeleteComment.html

        :stability: experimental
        '''
        return typing.cast("Workdocs", jsii.invoke(self, "toDeleteComment", []))

    @jsii.member(jsii_name="toDeleteCustomMetadata")
    def to_delete_custom_metadata(self) -> "Workdocs":
        '''(experimental) Grants permission to delete custom metadata from the specified resource.

        Access Level: Write

        https://docs.aws.amazon.com/workdocs/latest/APIReference/API_DeleteCustomMetadata.html

        :stability: experimental
        '''
        return typing.cast("Workdocs", jsii.invoke(self, "toDeleteCustomMetadata", []))

    @jsii.member(jsii_name="toDeleteDocument")
    def to_delete_document(self) -> "Workdocs":
        '''(experimental) Grants permission to permanently delete the specified document and its associated metadata.

        Access Level: Write

        https://docs.aws.amazon.com/workdocs/latest/APIReference/API_DeleteDocument.html

        :stability: experimental
        '''
        return typing.cast("Workdocs", jsii.invoke(self, "toDeleteDocument", []))

    @jsii.member(jsii_name="toDeleteDocumentVersion")
    def to_delete_document_version(self) -> "Workdocs":
        '''(experimental) Grants permission to delete versions of a specified document.

        Access Level: Write

        https://docs.aws.amazon.com/workdocs/latest/APIReference/API_DeleteDocumentVersion.html

        :stability: experimental
        '''
        return typing.cast("Workdocs", jsii.invoke(self, "toDeleteDocumentVersion", []))

    @jsii.member(jsii_name="toDeleteFolder")
    def to_delete_folder(self) -> "Workdocs":
        '''(experimental) Grants permission to permanently delete the specified folder and its contents.

        Access Level: Write

        https://docs.aws.amazon.com/workdocs/latest/APIReference/API_DeleteFolder.html

        :stability: experimental
        '''
        return typing.cast("Workdocs", jsii.invoke(self, "toDeleteFolder", []))

    @jsii.member(jsii_name="toDeleteFolderContents")
    def to_delete_folder_contents(self) -> "Workdocs":
        '''(experimental) Grants permission to delete the contents of the specified folder.

        Access Level: Write

        https://docs.aws.amazon.com/workdocs/latest/APIReference/API_DeleteFolderContents.html

        :stability: experimental
        '''
        return typing.cast("Workdocs", jsii.invoke(self, "toDeleteFolderContents", []))

    @jsii.member(jsii_name="toDeleteInstance")
    def to_delete_instance(self) -> "Workdocs":
        '''(experimental) Grants permission to delete an instance.

        Access Level: Write

        https://docs.aws.amazon.com/workdocs/latest/adminguide/manage-sites.html#delete_site

        :stability: experimental
        '''
        return typing.cast("Workdocs", jsii.invoke(self, "toDeleteInstance", []))

    @jsii.member(jsii_name="toDeleteLabels")
    def to_delete_labels(self) -> "Workdocs":
        '''(experimental) Grants permission to delete one or more labels from a resource.

        Access Level: Write

        https://docs.aws.amazon.com/workdocs/latest/APIReference/API_DeleteLabels.html

        :stability: experimental
        '''
        return typing.cast("Workdocs", jsii.invoke(self, "toDeleteLabels", []))

    @jsii.member(jsii_name="toDeleteNotificationPermissions")
    def to_delete_notification_permissions(self) -> "Workdocs":
        '''(experimental) Grants permission to delete principals that are allowed to call notification subscription APIs for a given WorkDocs site.

        Access Level: Write

        https://docs.aws.amazon.com/workdocs/latest/adminguide/manage-notifications.html

        :stability: experimental
        '''
        return typing.cast("Workdocs", jsii.invoke(self, "toDeleteNotificationPermissions", []))

    @jsii.member(jsii_name="toDeleteNotificationSubscription")
    def to_delete_notification_subscription(self) -> "Workdocs":
        '''(experimental) Grants permission to delete the specified subscription from the specified organization.

        Access Level: Write

        https://docs.aws.amazon.com/workdocs/latest/APIReference/API_DeleteNotificationSubscription.html

        :stability: experimental
        '''
        return typing.cast("Workdocs", jsii.invoke(self, "toDeleteNotificationSubscription", []))

    @jsii.member(jsii_name="toDeleteUser")
    def to_delete_user(self) -> "Workdocs":
        '''(experimental) Grants permission to delete the specified user from a Simple AD or Microsoft AD directory.

        Access Level: Write

        https://docs.aws.amazon.com/workdocs/latest/APIReference/API_DeleteUser.html

        :stability: experimental
        '''
        return typing.cast("Workdocs", jsii.invoke(self, "toDeleteUser", []))

    @jsii.member(jsii_name="toDeregisterDirectory")
    def to_deregister_directory(self) -> "Workdocs":
        '''(experimental) Grants permission to deregister a directory.

        Access Level: Write

        https://docs.aws.amazon.com/workdocs/latest/adminguide/manage-sites.html#delete_site

        :stability: experimental
        '''
        return typing.cast("Workdocs", jsii.invoke(self, "toDeregisterDirectory", []))

    @jsii.member(jsii_name="toDescribeActivities")
    def to_describe_activities(self) -> "Workdocs":
        '''(experimental) Grants permission to fetch user activities in a specified time period.

        Access Level: List

        https://docs.aws.amazon.com/workdocs/latest/APIReference/API_DescribeActivities.html

        :stability: experimental
        '''
        return typing.cast("Workdocs", jsii.invoke(self, "toDescribeActivities", []))

    @jsii.member(jsii_name="toDescribeAvailableDirectories")
    def to_describe_available_directories(self) -> "Workdocs":
        '''(experimental) Grants permission to describe available directories.

        Access Level: List

        https://docs.aws.amazon.com/workdocs/latest/adminguide/getting_started.html

        :stability: experimental
        '''
        return typing.cast("Workdocs", jsii.invoke(self, "toDescribeAvailableDirectories", []))

    @jsii.member(jsii_name="toDescribeComments")
    def to_describe_comments(self) -> "Workdocs":
        '''(experimental) Grants permission to list all the comments for the specified document version.

        Access Level: List

        https://docs.aws.amazon.com/workdocs/latest/APIReference/API_DescribeComments.html

        :stability: experimental
        '''
        return typing.cast("Workdocs", jsii.invoke(self, "toDescribeComments", []))

    @jsii.member(jsii_name="toDescribeDocumentVersions")
    def to_describe_document_versions(self) -> "Workdocs":
        '''(experimental) Grants permission to retrieve the document versions for the specified document.

        Access Level: List

        https://docs.aws.amazon.com/workdocs/latest/APIReference/API_DescribeDocumentVersions.html

        :stability: experimental
        '''
        return typing.cast("Workdocs", jsii.invoke(self, "toDescribeDocumentVersions", []))

    @jsii.member(jsii_name="toDescribeFolderContents")
    def to_describe_folder_contents(self) -> "Workdocs":
        '''(experimental) Grants permission to describe the contents of the specified folder, including its documents and sub-folders.

        Access Level: List

        https://docs.aws.amazon.com/workdocs/latest/APIReference/API_DescribeFolderContents.html

        :stability: experimental
        '''
        return typing.cast("Workdocs", jsii.invoke(self, "toDescribeFolderContents", []))

    @jsii.member(jsii_name="toDescribeGroups")
    def to_describe_groups(self) -> "Workdocs":
        '''(experimental) Grants permission to describe the user groups.

        Access Level: List

        https://docs.aws.amazon.com/workdocs/latest/APIReference/API_DescribeGroups.html

        :stability: experimental
        '''
        return typing.cast("Workdocs", jsii.invoke(self, "toDescribeGroups", []))

    @jsii.member(jsii_name="toDescribeInstances")
    def to_describe_instances(self) -> "Workdocs":
        '''(experimental) Grants permission to describe instances.

        Access Level: List

        https://docs.aws.amazon.com/workdocs/latest/adminguide/getting_started.html

        :stability: experimental
        '''
        return typing.cast("Workdocs", jsii.invoke(self, "toDescribeInstances", []))

    @jsii.member(jsii_name="toDescribeNotificationPermissions")
    def to_describe_notification_permissions(self) -> "Workdocs":
        '''(experimental) Grants permission to describe principals that are allowed to call notification subscription APIs for a given WorkDocs site.

        Access Level: List

        https://docs.aws.amazon.com/workdocs/latest/adminguide/manage-notifications.html

        :stability: experimental
        '''
        return typing.cast("Workdocs", jsii.invoke(self, "toDescribeNotificationPermissions", []))

    @jsii.member(jsii_name="toDescribeNotificationSubscriptions")
    def to_describe_notification_subscriptions(self) -> "Workdocs":
        '''(experimental) Grants permission to list the specified notification subscriptions.

        Access Level: List

        https://docs.aws.amazon.com/workdocs/latest/APIReference/API_DescribeNotificationSubscriptions.html

        :stability: experimental
        '''
        return typing.cast("Workdocs", jsii.invoke(self, "toDescribeNotificationSubscriptions", []))

    @jsii.member(jsii_name="toDescribeResourcePermissions")
    def to_describe_resource_permissions(self) -> "Workdocs":
        '''(experimental) Grants permission to view a description of a specified resource's permissions.

        Access Level: List

        https://docs.aws.amazon.com/workdocs/latest/APIReference/API_DescribeResourcePermissions.html

        :stability: experimental
        '''
        return typing.cast("Workdocs", jsii.invoke(self, "toDescribeResourcePermissions", []))

    @jsii.member(jsii_name="toDescribeRootFolders")
    def to_describe_root_folders(self) -> "Workdocs":
        '''(experimental) Grants permission to describe the root folders.

        Access Level: List

        https://docs.aws.amazon.com/workdocs/latest/APIReference/API_DescribeRootFolders.html

        :stability: experimental
        '''
        return typing.cast("Workdocs", jsii.invoke(self, "toDescribeRootFolders", []))

    @jsii.member(jsii_name="toDescribeUsers")
    def to_describe_users(self) -> "Workdocs":
        '''(experimental) Grants permission to view a description of the specified users.

        You can describe all users or filter the results (for example, by status or organization)

        Access Level: List

        https://docs.aws.amazon.com/workdocs/latest/APIReference/API_DescribeUsers.html

        :stability: experimental
        '''
        return typing.cast("Workdocs", jsii.invoke(self, "toDescribeUsers", []))

    @jsii.member(jsii_name="toDownloadDocumentVersion")
    def to_download_document_version(self) -> "Workdocs":
        '''(experimental) Grants permission to download a specified document version.

        Access Level: Read

        https://docs.aws.amazon.com/workdocs/latest/APIReference/API_GetDocumentVersion.html

        :stability: experimental
        '''
        return typing.cast("Workdocs", jsii.invoke(self, "toDownloadDocumentVersion", []))

    @jsii.member(jsii_name="toGetCurrentUser")
    def to_get_current_user(self) -> "Workdocs":
        '''(experimental) Grants permission to retrieve the details of the current user.

        Access Level: Read

        https://docs.aws.amazon.com/workdocs/latest/APIReference/API_GetCurrentUser.html

        :stability: experimental
        '''
        return typing.cast("Workdocs", jsii.invoke(self, "toGetCurrentUser", []))

    @jsii.member(jsii_name="toGetDocument")
    def to_get_document(self) -> "Workdocs":
        '''(experimental) Grants permission to retrieve the specified document object.

        Access Level: Read

        https://docs.aws.amazon.com/workdocs/latest/APIReference/API_GetDocument.html

        :stability: experimental
        '''
        return typing.cast("Workdocs", jsii.invoke(self, "toGetDocument", []))

    @jsii.member(jsii_name="toGetDocumentPath")
    def to_get_document_path(self) -> "Workdocs":
        '''(experimental) Grants permission to retrieve the path information (the hierarchy from the root folder) for the requested document.

        Access Level: Read

        https://docs.aws.amazon.com/workdocs/latest/APIReference/API_GetDocumentPath.html

        :stability: experimental
        '''
        return typing.cast("Workdocs", jsii.invoke(self, "toGetDocumentPath", []))

    @jsii.member(jsii_name="toGetDocumentVersion")
    def to_get_document_version(self) -> "Workdocs":
        '''(experimental) Grants permission to retrieve version metadata for the specified document.

        Access Level: Read

        https://docs.aws.amazon.com/workdocs/latest/APIReference/API_GetDocumentVersion.html

        :stability: experimental
        '''
        return typing.cast("Workdocs", jsii.invoke(self, "toGetDocumentVersion", []))

    @jsii.member(jsii_name="toGetFolder")
    def to_get_folder(self) -> "Workdocs":
        '''(experimental) Grants permission to retrieve the metadata of the specified folder.

        Access Level: Read

        https://docs.aws.amazon.com/workdocs/latest/APIReference/API_GetFolder.html

        :stability: experimental
        '''
        return typing.cast("Workdocs", jsii.invoke(self, "toGetFolder", []))

    @jsii.member(jsii_name="toGetFolderPath")
    def to_get_folder_path(self) -> "Workdocs":
        '''(experimental) Grants permission to retrieve the path information (the hierarchy from the root folder) for the specified folder.

        Access Level: Read

        https://docs.aws.amazon.com/workdocs/latest/APIReference/API_GetFolderPath.html

        :stability: experimental
        '''
        return typing.cast("Workdocs", jsii.invoke(self, "toGetFolderPath", []))

    @jsii.member(jsii_name="toGetGroup")
    def to_get_group(self) -> "Workdocs":
        '''(experimental) Grants permission to retrieve details for the specified group.

        Access Level: Read

        https://docs.aws.amazon.com/workdocs/latest/APIReference/API_Operations.html

        :stability: experimental
        '''
        return typing.cast("Workdocs", jsii.invoke(self, "toGetGroup", []))

    @jsii.member(jsii_name="toGetResources")
    def to_get_resources(self) -> "Workdocs":
        '''(experimental) Grants permission to get a collection of resources.

        Access Level: Read

        https://docs.aws.amazon.com/workdocs/latest/APIReference/API_GetResources.html

        :stability: experimental
        '''
        return typing.cast("Workdocs", jsii.invoke(self, "toGetResources", []))

    @jsii.member(jsii_name="toInitiateDocumentVersionUpload")
    def to_initiate_document_version_upload(self) -> "Workdocs":
        '''(experimental) Grants permission to create a new document object and version object.

        Access Level: Write

        https://docs.aws.amazon.com/workdocs/latest/APIReference/API_InitiateDocumentVersionUpload.html

        :stability: experimental
        '''
        return typing.cast("Workdocs", jsii.invoke(self, "toInitiateDocumentVersionUpload", []))

    @jsii.member(jsii_name="toRegisterDirectory")
    def to_register_directory(self) -> "Workdocs":
        '''(experimental) Grants permission to register a directory.

        Access Level: Write

        https://docs.aws.amazon.com/workdocs/latest/adminguide/existing-dir-setup.html

        :stability: experimental
        '''
        return typing.cast("Workdocs", jsii.invoke(self, "toRegisterDirectory", []))

    @jsii.member(jsii_name="toRemoveAllResourcePermissions")
    def to_remove_all_resource_permissions(self) -> "Workdocs":
        '''(experimental) Grants permission to remove all the permissions from the specified resource.

        Access Level: Write

        https://docs.aws.amazon.com/workdocs/latest/APIReference/API_RemoveAllResourcePermissions.html

        :stability: experimental
        '''
        return typing.cast("Workdocs", jsii.invoke(self, "toRemoveAllResourcePermissions", []))

    @jsii.member(jsii_name="toRemoveResourcePermission")
    def to_remove_resource_permission(self) -> "Workdocs":
        '''(experimental) Grants permission to remove the permission for the specified principal from the specified resource.

        Access Level: Write

        https://docs.aws.amazon.com/workdocs/latest/APIReference/API_RemoveResourcePermission.html

        :stability: experimental
        '''
        return typing.cast("Workdocs", jsii.invoke(self, "toRemoveResourcePermission", []))

    @jsii.member(jsii_name="toRestoreDocumentVersions")
    def to_restore_document_versions(self) -> "Workdocs":
        '''(experimental) Grants permission to restore versions of a specified document.

        Access Level: Write

        https://docs.aws.amazon.com/workdocs/latest/APIReference/API_RestoreDocumentVersions.html

        :stability: experimental
        '''
        return typing.cast("Workdocs", jsii.invoke(self, "toRestoreDocumentVersions", []))

    @jsii.member(jsii_name="toUpdateDocument")
    def to_update_document(self) -> "Workdocs":
        '''(experimental) Grants permission to update the specified attributes of the specified document.

        Access Level: Write

        https://docs.aws.amazon.com/workdocs/latest/APIReference/API_UpdateDocument.html

        :stability: experimental
        '''
        return typing.cast("Workdocs", jsii.invoke(self, "toUpdateDocument", []))

    @jsii.member(jsii_name="toUpdateDocumentVersion")
    def to_update_document_version(self) -> "Workdocs":
        '''(experimental) Grants permission to change the status of the document version to ACTIVE.

        Access Level: Write

        https://docs.aws.amazon.com/workdocs/latest/APIReference/API_UpdateDocumentVersion.html

        :stability: experimental
        '''
        return typing.cast("Workdocs", jsii.invoke(self, "toUpdateDocumentVersion", []))

    @jsii.member(jsii_name="toUpdateFolder")
    def to_update_folder(self) -> "Workdocs":
        '''(experimental) Grants permission to update the specified attributes of the specified folder.

        Access Level: Write

        https://docs.aws.amazon.com/workdocs/latest/APIReference/API_UpdateFolder.html

        :stability: experimental
        '''
        return typing.cast("Workdocs", jsii.invoke(self, "toUpdateFolder", []))

    @jsii.member(jsii_name="toUpdateInstanceAlias")
    def to_update_instance_alias(self) -> "Workdocs":
        '''(experimental) Grants permission to update an instance alias.

        Access Level: Write

        https://docs.aws.amazon.com/workdocs/latest/adminguide/getting_started.html

        :stability: experimental
        '''
        return typing.cast("Workdocs", jsii.invoke(self, "toUpdateInstanceAlias", []))

    @jsii.member(jsii_name="toUpdateUser")
    def to_update_user(self) -> "Workdocs":
        '''(experimental) Grants permission to update the specified attributes of the specified user, and grants or revokes administrative privileges to the Amazon WorkDocs site.

        Access Level: Write

        https://docs.aws.amazon.com/workdocs/latest/APIReference/API_UpdateUser.html

        :stability: experimental
        '''
        return typing.cast("Workdocs", jsii.invoke(self, "toUpdateUser", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__62945e054ad0ecd19f49bef5b2e860f4ebe8e6a1c29c6e78bf891c907ebd6c14)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e6a127f6a34ad8b2c2a8d9268eff9e251ce860053e258811ee00a3b09397cee1)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Worklink(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Worklink",
):
    '''(experimental) Statement provider for service `worklink <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonworklink.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `worklink <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonworklink.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onFleet")
    def on_fleet(
        self,
        fleet_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Worklink":
        '''(experimental) Adds a resource of type fleet to the statement.

        https://docs.aws.amazon.com/worklink/latest/api/API_CreateFleet.html

        :param fleet_name: - Identifier for the fleetName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e3cdb8d0589dbde818b9af4ec8344c2ab6d16b33af199f9870ce2d392945856c)
            check_type(argname="argument fleet_name", value=fleet_name, expected_type=type_hints["fleet_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Worklink", jsii.invoke(self, "onFleet", [fleet_name, account, partition]))

    @jsii.member(jsii_name="toAssociateDomain")
    def to_associate_domain(self) -> "Worklink":
        '''(experimental) Grants permission to associate a domain with an Amazon WorkLink fleet.

        Access Level: Write

        https://docs.aws.amazon.com/worklink/latest/api/API_AssociateDomain.html

        :stability: experimental
        '''
        return typing.cast("Worklink", jsii.invoke(self, "toAssociateDomain", []))

    @jsii.member(jsii_name="toAssociateWebsiteAuthorizationProvider")
    def to_associate_website_authorization_provider(self) -> "Worklink":
        '''(experimental) Grants permission to associate a website authorization provider with an Amazon WorkLink fleet.

        Access Level: Write

        https://docs.aws.amazon.com/worklink/latest/api/API_AssociateWebsiteAuthorizationProvider.html

        :stability: experimental
        '''
        return typing.cast("Worklink", jsii.invoke(self, "toAssociateWebsiteAuthorizationProvider", []))

    @jsii.member(jsii_name="toAssociateWebsiteCertificateAuthority")
    def to_associate_website_certificate_authority(self) -> "Worklink":
        '''(experimental) Grants permission to associate a website certificate authority with an Amazon WorkLink fleet.

        Access Level: Write

        https://docs.aws.amazon.com/worklink/latest/api/API_AssociateWebsiteCertificateAuthority.html

        :stability: experimental
        '''
        return typing.cast("Worklink", jsii.invoke(self, "toAssociateWebsiteCertificateAuthority", []))

    @jsii.member(jsii_name="toCreateFleet")
    def to_create_fleet(self) -> "Worklink":
        '''(experimental) Grants permission to create an Amazon WorkLink fleet.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/worklink/latest/api/API_CreateFleet.html

        :stability: experimental
        '''
        return typing.cast("Worklink", jsii.invoke(self, "toCreateFleet", []))

    @jsii.member(jsii_name="toDeleteFleet")
    def to_delete_fleet(self) -> "Worklink":
        '''(experimental) Grants permission to delete an Amazon WorkLink fleet.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/worklink/latest/api/API_DeleteFleet.html

        :stability: experimental
        '''
        return typing.cast("Worklink", jsii.invoke(self, "toDeleteFleet", []))

    @jsii.member(jsii_name="toDescribeAuditStreamConfiguration")
    def to_describe_audit_stream_configuration(self) -> "Worklink":
        '''(experimental) Grants permission to describe the audit stream configuration for an Amazon WorkLink fleet.

        Access Level: Read

        https://docs.aws.amazon.com/worklink/latest/api/API_DescribeAuditStreamConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Worklink", jsii.invoke(self, "toDescribeAuditStreamConfiguration", []))

    @jsii.member(jsii_name="toDescribeCompanyNetworkConfiguration")
    def to_describe_company_network_configuration(self) -> "Worklink":
        '''(experimental) Grants permission to describe the company network configuration for an Amazon WorkLink fleet.

        Access Level: Read

        https://docs.aws.amazon.com/worklink/latest/api/API_DescribeCompanyNetworkConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Worklink", jsii.invoke(self, "toDescribeCompanyNetworkConfiguration", []))

    @jsii.member(jsii_name="toDescribeDevice")
    def to_describe_device(self) -> "Worklink":
        '''(experimental) Grants permission to describe details of a device associated with an Amazon WorkLink fleet.

        Access Level: Read

        https://docs.aws.amazon.com/worklink/latest/api/API_DescribeDevice.html

        :stability: experimental
        '''
        return typing.cast("Worklink", jsii.invoke(self, "toDescribeDevice", []))

    @jsii.member(jsii_name="toDescribeDevicePolicyConfiguration")
    def to_describe_device_policy_configuration(self) -> "Worklink":
        '''(experimental) Grants permission to describe the device policy configuration for an Amazon WorkLink fleet.

        Access Level: Read

        https://docs.aws.amazon.com/worklink/latest/api/API_DescribeDevicePolicyConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Worklink", jsii.invoke(self, "toDescribeDevicePolicyConfiguration", []))

    @jsii.member(jsii_name="toDescribeDomain")
    def to_describe_domain(self) -> "Worklink":
        '''(experimental) Grants permission to describe details about a domain associated with an Amazon WorkLink fleet.

        Access Level: Read

        https://docs.aws.amazon.com/worklink/latest/api/API_DescribeDomain.html

        :stability: experimental
        '''
        return typing.cast("Worklink", jsii.invoke(self, "toDescribeDomain", []))

    @jsii.member(jsii_name="toDescribeFleetMetadata")
    def to_describe_fleet_metadata(self) -> "Worklink":
        '''(experimental) Grants permission to describe metadata of an Amazon WorkLink fleet.

        Access Level: Read

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/worklink/latest/api/API_DescribeFleetMetadata.html

        :stability: experimental
        '''
        return typing.cast("Worklink", jsii.invoke(self, "toDescribeFleetMetadata", []))

    @jsii.member(jsii_name="toDescribeIdentityProviderConfiguration")
    def to_describe_identity_provider_configuration(self) -> "Worklink":
        '''(experimental) Grants permission to describe the identity provider configuration for an Amazon WorkLink fleet.

        Access Level: Read

        https://docs.aws.amazon.com/worklink/latest/api/API_DescribeIdentityProviderConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Worklink", jsii.invoke(self, "toDescribeIdentityProviderConfiguration", []))

    @jsii.member(jsii_name="toDescribeWebsiteCertificateAuthority")
    def to_describe_website_certificate_authority(self) -> "Worklink":
        '''(experimental) Grants permission to describe a website certificate authority associated with an Amazon WorkLink fleet.

        Access Level: Read

        https://docs.aws.amazon.com/worklink/latest/api/API_DescribeWebsiteCertificateAuthority.html

        :stability: experimental
        '''
        return typing.cast("Worklink", jsii.invoke(self, "toDescribeWebsiteCertificateAuthority", []))

    @jsii.member(jsii_name="toDisassociateDomain")
    def to_disassociate_domain(self) -> "Worklink":
        '''(experimental) Grants permission to disassociate a domain from an Amazon WorkLink fleet.

        Access Level: Write

        https://docs.aws.amazon.com/worklink/latest/api/API_DisassociateDomain.html

        :stability: experimental
        '''
        return typing.cast("Worklink", jsii.invoke(self, "toDisassociateDomain", []))

    @jsii.member(jsii_name="toDisassociateWebsiteAuthorizationProvider")
    def to_disassociate_website_authorization_provider(self) -> "Worklink":
        '''(experimental) Grants permission to disassociate a website authorization provider from an Amazon WorkLink fleet.

        Access Level: Write

        https://docs.aws.amazon.com/worklink/latest/api/API_DisassociateWebsiteAuthorizationProvider.html

        :stability: experimental
        '''
        return typing.cast("Worklink", jsii.invoke(self, "toDisassociateWebsiteAuthorizationProvider", []))

    @jsii.member(jsii_name="toDisassociateWebsiteCertificateAuthority")
    def to_disassociate_website_certificate_authority(self) -> "Worklink":
        '''(experimental) Grants permission to disassociate a website certificate authority from an Amazon WorkLink fleet.

        Access Level: Write

        https://docs.aws.amazon.com/worklink/latest/api/API_DisassociateWebsiteCertificateAuthority.html

        :stability: experimental
        '''
        return typing.cast("Worklink", jsii.invoke(self, "toDisassociateWebsiteCertificateAuthority", []))

    @jsii.member(jsii_name="toListDevices")
    def to_list_devices(self) -> "Worklink":
        '''(experimental) Grants permission to list the devices associated with an Amazon WorkLink fleet.

        Access Level: List

        https://docs.aws.amazon.com/worklink/latest/api/API_ListDevices.html

        :stability: experimental
        '''
        return typing.cast("Worklink", jsii.invoke(self, "toListDevices", []))

    @jsii.member(jsii_name="toListDomains")
    def to_list_domains(self) -> "Worklink":
        '''(experimental) Grants permission to list the associated domains for an Amazon WorkLink fleet.

        Access Level: List

        https://docs.aws.amazon.com/worklink/latest/api/API_ListDomains.html

        :stability: experimental
        '''
        return typing.cast("Worklink", jsii.invoke(self, "toListDomains", []))

    @jsii.member(jsii_name="toListFleets")
    def to_list_fleets(self) -> "Worklink":
        '''(experimental) Grants permission to list the Amazon WorkLink fleets associated with the account.

        Access Level: List

        https://docs.aws.amazon.com/worklink/latest/api/API_ListFleets.html

        :stability: experimental
        '''
        return typing.cast("Worklink", jsii.invoke(self, "toListFleets", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Worklink":
        '''(experimental) Grants permission to list tags for a resource.

        Access Level: Read

        https://docs.aws.amazon.com/worklink/latest/api/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("Worklink", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toListWebsiteAuthorizationProviders")
    def to_list_website_authorization_providers(self) -> "Worklink":
        '''(experimental) Grants permission to list the website authorization providers for an Amazon WorkLink fleet.

        Access Level: List

        https://docs.aws.amazon.com/worklink/latest/api/API_ListWebsiteAuthorizationProviders.html

        :stability: experimental
        '''
        return typing.cast("Worklink", jsii.invoke(self, "toListWebsiteAuthorizationProviders", []))

    @jsii.member(jsii_name="toListWebsiteCertificateAuthorities")
    def to_list_website_certificate_authorities(self) -> "Worklink":
        '''(experimental) Grants permission to list the website certificate authorities associated with an Amazon WorkLink fleet.

        Access Level: List

        https://docs.aws.amazon.com/worklink/latest/api/API_ListWebsiteCertificateAuthorities.html

        :stability: experimental
        '''
        return typing.cast("Worklink", jsii.invoke(self, "toListWebsiteCertificateAuthorities", []))

    @jsii.member(jsii_name="toRestoreDomainAccess")
    def to_restore_domain_access(self) -> "Worklink":
        '''(experimental) Grants permission to restore access to a domain associated with an Amazon WorkLink fleet.

        Access Level: Write

        https://docs.aws.amazon.com/worklink/latest/api/API_RestoreDomainAccess.html

        :stability: experimental
        '''
        return typing.cast("Worklink", jsii.invoke(self, "toRestoreDomainAccess", []))

    @jsii.member(jsii_name="toRevokeDomainAccess")
    def to_revoke_domain_access(self) -> "Worklink":
        '''(experimental) Grants permission to revoke access to a domain associated with an Amazon WorkLink fleet.

        Access Level: Write

        https://docs.aws.amazon.com/worklink/latest/api/API_RevokeDomainAccess.html

        :stability: experimental
        '''
        return typing.cast("Worklink", jsii.invoke(self, "toRevokeDomainAccess", []))

    @jsii.member(jsii_name="toSearchEntity")
    def to_search_entity(self) -> "Worklink":
        '''(experimental) Grants permission to list devices for an Amazon WorkLink fleet.

        Access Level: List

        https://docs.aws.amazon.com/worklink/latest/ag/manage-devices.html

        :stability: experimental
        '''
        return typing.cast("Worklink", jsii.invoke(self, "toSearchEntity", []))

    @jsii.member(jsii_name="toSignOutUser")
    def to_sign_out_user(self) -> "Worklink":
        '''(experimental) Grants permission to sign out a user from an Amazon WorkLink fleet.

        Access Level: Write

        https://docs.aws.amazon.com/worklink/latest/api/API_SignOutUser.html

        :stability: experimental
        '''
        return typing.cast("Worklink", jsii.invoke(self, "toSignOutUser", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Worklink":
        '''(experimental) Grants permission to add one or more tags to a resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/worklink/latest/api/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("Worklink", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Worklink":
        '''(experimental) Grants permission to remove one or more tags from a resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/worklink/latest/api/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("Worklink", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateAuditStreamConfiguration")
    def to_update_audit_stream_configuration(self) -> "Worklink":
        '''(experimental) Grants permission to update the audit stream configuration for an Amazon WorkLink fleet.

        Access Level: Write

        https://docs.aws.amazon.com/worklink/latest/api/API_UpdateAuditStreamConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Worklink", jsii.invoke(self, "toUpdateAuditStreamConfiguration", []))

    @jsii.member(jsii_name="toUpdateCompanyNetworkConfiguration")
    def to_update_company_network_configuration(self) -> "Worklink":
        '''(experimental) Grants permission to update the company network configuration for an Amazon WorkLink fleet.

        Access Level: Write

        https://docs.aws.amazon.com/worklink/latest/api/API_UpdateCompanyNetworkConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Worklink", jsii.invoke(self, "toUpdateCompanyNetworkConfiguration", []))

    @jsii.member(jsii_name="toUpdateDevicePolicyConfiguration")
    def to_update_device_policy_configuration(self) -> "Worklink":
        '''(experimental) Grants permission to update the device policy configuration for an Amazon WorkLink fleet.

        Access Level: Write

        https://docs.aws.amazon.com/worklink/latest/api/API_UpdateDevicePolicyConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Worklink", jsii.invoke(self, "toUpdateDevicePolicyConfiguration", []))

    @jsii.member(jsii_name="toUpdateDomainMetadata")
    def to_update_domain_metadata(self) -> "Worklink":
        '''(experimental) Grants permission to update the metadata for a domain associated with an Amazon WorkLink fleet.

        Access Level: Write

        https://docs.aws.amazon.com/worklink/latest/api/API_UpdateDomainMetadata.html

        :stability: experimental
        '''
        return typing.cast("Worklink", jsii.invoke(self, "toUpdateDomainMetadata", []))

    @jsii.member(jsii_name="toUpdateFleetMetadata")
    def to_update_fleet_metadata(self) -> "Worklink":
        '''(experimental) Grants permission to update the metadata of an Amazon WorkLink fleet.

        Access Level: Write

        https://docs.aws.amazon.com/worklink/latest/api/API_UpdateFleetMetadata.html

        :stability: experimental
        '''
        return typing.cast("Worklink", jsii.invoke(self, "toUpdateFleetMetadata", []))

    @jsii.member(jsii_name="toUpdateIdentityProviderConfiguration")
    def to_update_identity_provider_configuration(self) -> "Worklink":
        '''(experimental) Grants permission to update the identity provider configuration for an Amazon WorkLink fleet.

        Access Level: Write

        https://docs.aws.amazon.com/worklink/latest/api/API_UpdateIdentityProviderConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Worklink", jsii.invoke(self, "toUpdateIdentityProviderConfiguration", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6f24714649555ae2ee616a96e0f18e46c094d425fabb30feb93d33b1a4339e92)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__56b671a73f936c5fd00fbc4c1db5a00feece6443bc6c00ab6d0c955fa8ddc7cb)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Workmail(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Workmail",
):
    '''(experimental) Statement provider for service `workmail <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonworkmail.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `workmail <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonworkmail.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onOrganization")
    def on_organization(
        self,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Workmail":
        '''(experimental) Adds a resource of type organization to the statement.

        https://docs.aws.amazon.com/workmail/latest/adminguide/organizations_overview.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__06899eeb1774d361c45d1f8ad1a3810f18b2309815c4a90dea187b5f119b9df6)
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Workmail", jsii.invoke(self, "onOrganization", [resource_id, account, region, partition]))

    @jsii.member(jsii_name="toAddMembersToGroup")
    def to_add_members_to_group(self) -> "Workmail":
        '''(experimental) Grants permission to add a list of members (users or groups) to a group.

        Access Level: Write

        https://docs.aws.amazon.com/workmail/latest/adminguide/groups_overview.html

        :stability: experimental
        '''
        return typing.cast("Workmail", jsii.invoke(self, "toAddMembersToGroup", []))

    @jsii.member(jsii_name="toAssociateDelegateToResource")
    def to_associate_delegate_to_resource(self) -> "Workmail":
        '''(experimental) Grants permission to add a member (user or group) to the resource's set of delegates.

        Access Level: Write

        https://docs.aws.amazon.com/workmail/latest/APIReference/API_AssociateDelegateToResource.html

        :stability: experimental
        '''
        return typing.cast("Workmail", jsii.invoke(self, "toAssociateDelegateToResource", []))

    @jsii.member(jsii_name="toAssociateMemberToGroup")
    def to_associate_member_to_group(self) -> "Workmail":
        '''(experimental) Grants permission to add a member (user or group) to the group's set.

        Access Level: Write

        https://docs.aws.amazon.com/workmail/latest/APIReference/API_AssociateMemberToGroup.html

        :stability: experimental
        '''
        return typing.cast("Workmail", jsii.invoke(self, "toAssociateMemberToGroup", []))

    @jsii.member(jsii_name="toAssumeImpersonationRole")
    def to_assume_impersonation_role(self) -> "Workmail":
        '''(experimental) Grants permission to assume an impersonation role for the given Amazon WorkMail organization.

        Access Level: Write

        https://docs.aws.amazon.com/workmail/latest/APIReference/API_AssumeImpersonationRole.html

        :stability: experimental
        '''
        return typing.cast("Workmail", jsii.invoke(self, "toAssumeImpersonationRole", []))

    @jsii.member(jsii_name="toCancelMailboxExportJob")
    def to_cancel_mailbox_export_job(self) -> "Workmail":
        '''(experimental) Grants permission to cancel a currently running mailbox export job.

        Access Level: Write

        https://docs.aws.amazon.com/workmail/latest/APIReference/API_CancelMailboxExportJob.html

        :stability: experimental
        '''
        return typing.cast("Workmail", jsii.invoke(self, "toCancelMailboxExportJob", []))

    @jsii.member(jsii_name="toCreateAlias")
    def to_create_alias(self) -> "Workmail":
        '''(experimental) Grants permission to add an alias to the set of a given member (user or group) of WorkMail.

        Access Level: Write

        https://docs.aws.amazon.com/workmail/latest/APIReference/API_CreateAlias.html

        :stability: experimental
        '''
        return typing.cast("Workmail", jsii.invoke(self, "toCreateAlias", []))

    @jsii.member(jsii_name="toCreateAvailabilityConfiguration")
    def to_create_availability_configuration(self) -> "Workmail":
        '''(experimental) Grants permission to create an AvailabilityConfiguration for the given Amazon WorkMail organization and domain.

        Access Level: Write

        https://docs.aws.amazon.com/workmail/latest/APIReference/API_CreateAvailabilityConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Workmail", jsii.invoke(self, "toCreateAvailabilityConfiguration", []))

    @jsii.member(jsii_name="toCreateGroup")
    def to_create_group(self) -> "Workmail":
        '''(experimental) Grants permission to create a group that can be used in WorkMail by calling the RegisterToWorkMail operation.

        Access Level: Write

        https://docs.aws.amazon.com/workmail/latest/APIReference/API_CreateGroup.html

        :stability: experimental
        '''
        return typing.cast("Workmail", jsii.invoke(self, "toCreateGroup", []))

    @jsii.member(jsii_name="toCreateImpersonationRole")
    def to_create_impersonation_role(self) -> "Workmail":
        '''(experimental) Grants permission to create an impersonation role for the given Amazon WorkMail organization.

        Access Level: Write

        https://docs.aws.amazon.com/workmail/latest/APIReference/API_CreateImpersonationRole.html

        :stability: experimental
        '''
        return typing.cast("Workmail", jsii.invoke(self, "toCreateImpersonationRole", []))

    @jsii.member(jsii_name="toCreateInboundMailFlowRule")
    def to_create_inbound_mail_flow_rule(self) -> "Workmail":
        '''(experimental) Grants permission to create an inbound email flow rule which will apply to all email sent to an organization.

        Access Level: Write

        https://docs.aws.amazon.com/workmail/latest/adminguide/create-email-rules.html

        :stability: experimental
        '''
        return typing.cast("Workmail", jsii.invoke(self, "toCreateInboundMailFlowRule", []))

    @jsii.member(jsii_name="toCreateMailDomain")
    def to_create_mail_domain(self) -> "Workmail":
        '''(experimental) Grants permission to create a mail domain.

        Access Level: Write

        https://docs.aws.amazon.com/workmail/latest/adminguide/add_domain.html

        :stability: experimental
        '''
        return typing.cast("Workmail", jsii.invoke(self, "toCreateMailDomain", []))

    @jsii.member(jsii_name="toCreateMailUser")
    def to_create_mail_user(self) -> "Workmail":
        '''(experimental) Grants permission to create a user in the directory.

        Access Level: Write

        https://docs.aws.amazon.com/workmail/latest/adminguide/manage-users.html

        :stability: experimental
        '''
        return typing.cast("Workmail", jsii.invoke(self, "toCreateMailUser", []))

    @jsii.member(jsii_name="toCreateMobileDeviceAccessRule")
    def to_create_mobile_device_access_rule(self) -> "Workmail":
        '''(experimental) Grants permission to create a new mobile device access rule.

        Access Level: Write

        https://docs.aws.amazon.com/workmail/latest/APIReference/API_CreateMobileDeviceAccessRule.html

        :stability: experimental
        '''
        return typing.cast("Workmail", jsii.invoke(self, "toCreateMobileDeviceAccessRule", []))

    @jsii.member(jsii_name="toCreateOrganization")
    def to_create_organization(self) -> "Workmail":
        '''(experimental) Grants permission to create a new Amazon WorkMail organization.

        Access Level: Write

        https://docs.aws.amazon.com/workmail/latest/APIReference/API_CreateOrganization.html

        :stability: experimental
        '''
        return typing.cast("Workmail", jsii.invoke(self, "toCreateOrganization", []))

    @jsii.member(jsii_name="toCreateOutboundMailFlowRule")
    def to_create_outbound_mail_flow_rule(self) -> "Workmail":
        '''(experimental) Grants permission to create an outbound email flow rule which will apply to all email sent from an organization.

        Access Level: Write

        https://docs.aws.amazon.com/workmail/latest/adminguide/create-email-rules.html

        :stability: experimental
        '''
        return typing.cast("Workmail", jsii.invoke(self, "toCreateOutboundMailFlowRule", []))

    @jsii.member(jsii_name="toCreateResource")
    def to_create_resource(self) -> "Workmail":
        '''(experimental) Grants permission to create a new WorkMail resource.

        Access Level: Write

        https://docs.aws.amazon.com/workmail/latest/APIReference/API_CreateResource.html

        :stability: experimental
        '''
        return typing.cast("Workmail", jsii.invoke(self, "toCreateResource", []))

    @jsii.member(jsii_name="toCreateSmtpGateway")
    def to_create_smtp_gateway(self) -> "Workmail":
        '''(experimental) Grants permission to register an SMTP gateway to a WorkMail organization.

        Access Level: Write

        https://docs.aws.amazon.com/workmail/latest/adminguide/smtp-gateway.html

        :stability: experimental
        '''
        return typing.cast("Workmail", jsii.invoke(self, "toCreateSmtpGateway", []))

    @jsii.member(jsii_name="toCreateUser")
    def to_create_user(self) -> "Workmail":
        '''(experimental) Grants permission to create a user, which can be enabled afterwards by calling the RegisterToWorkMail operation.

        Access Level: Write

        https://docs.aws.amazon.com/workmail/latest/APIReference/API_CreateUser.html

        :stability: experimental
        '''
        return typing.cast("Workmail", jsii.invoke(self, "toCreateUser", []))

    @jsii.member(jsii_name="toDeleteAccessControlRule")
    def to_delete_access_control_rule(self) -> "Workmail":
        '''(experimental) Grants permission to delete an access control rule.

        Access Level: Write

        https://docs.aws.amazon.com/workmail/latest/APIReference/API_DeleteAccessControlRule.html

        :stability: experimental
        '''
        return typing.cast("Workmail", jsii.invoke(self, "toDeleteAccessControlRule", []))

    @jsii.member(jsii_name="toDeleteAlias")
    def to_delete_alias(self) -> "Workmail":
        '''(experimental) Grants permission to remove one or more specified aliases from a set of aliases for a given user.

        Access Level: Write

        https://docs.aws.amazon.com/workmail/latest/APIReference/API_DeleteAlias.html

        :stability: experimental
        '''
        return typing.cast("Workmail", jsii.invoke(self, "toDeleteAlias", []))

    @jsii.member(jsii_name="toDeleteAvailabilityConfiguration")
    def to_delete_availability_configuration(self) -> "Workmail":
        '''(experimental) Grants permission to delete the AvailabilityConfiguration for the given Amazon WorkMail organization and domain.

        Access Level: Write

        https://docs.aws.amazon.com/workmail/latest/APIReference/API_DeleteAvailabilityConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Workmail", jsii.invoke(self, "toDeleteAvailabilityConfiguration", []))

    @jsii.member(jsii_name="toDeleteEmailMonitoringConfiguration")
    def to_delete_email_monitoring_configuration(self) -> "Workmail":
        '''(experimental) Grants permission to delete the email monitoring configuration for an organization.

        Access Level: Write

        https://docs.aws.amazon.com/workmail/latest/APIReference/API_DeleteEmailMonitoringConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Workmail", jsii.invoke(self, "toDeleteEmailMonitoringConfiguration", []))

    @jsii.member(jsii_name="toDeleteGroup")
    def to_delete_group(self) -> "Workmail":
        '''(experimental) Grants permission to delete a group from WorkMail.

        Access Level: Write

        https://docs.aws.amazon.com/workmail/latest/APIReference/API_DeleteGroup.html

        :stability: experimental
        '''
        return typing.cast("Workmail", jsii.invoke(self, "toDeleteGroup", []))

    @jsii.member(jsii_name="toDeleteImpersonationRole")
    def to_delete_impersonation_role(self) -> "Workmail":
        '''(experimental) Grants permission to delete an impersonation role for the given Amazon WorkMail organization.

        Access Level: Write

        https://docs.aws.amazon.com/workmail/latest/APIReference/API_DeleteImpersonationRole.html

        :stability: experimental
        '''
        return typing.cast("Workmail", jsii.invoke(self, "toDeleteImpersonationRole", []))

    @jsii.member(jsii_name="toDeleteInboundMailFlowRule")
    def to_delete_inbound_mail_flow_rule(self) -> "Workmail":
        '''(experimental) Grants permission to remove an inbound email flow rule to no longer apply to emails sent to an organization.

        Access Level: Write

        https://docs.aws.amazon.com/workmail/latest/adminguide/remove-email-flow-rule.html

        :stability: experimental
        '''
        return typing.cast("Workmail", jsii.invoke(self, "toDeleteInboundMailFlowRule", []))

    @jsii.member(jsii_name="toDeleteMailboxPermissions")
    def to_delete_mailbox_permissions(self) -> "Workmail":
        '''(experimental) Grants permission to delete permissions granted to a member (user or group).

        Access Level: Write

        https://docs.aws.amazon.com/workmail/latest/APIReference/API_DeleteMailboxPermissions.html

        :stability: experimental
        '''
        return typing.cast("Workmail", jsii.invoke(self, "toDeleteMailboxPermissions", []))

    @jsii.member(jsii_name="toDeleteMailDomain")
    def to_delete_mail_domain(self) -> "Workmail":
        '''(experimental) Grants permission to remove an unused mail domain from an organization.

        Access Level: Write

        https://docs.aws.amazon.com/workmail/latest/adminguide/remove_domain.html

        :stability: experimental
        '''
        return typing.cast("Workmail", jsii.invoke(self, "toDeleteMailDomain", []))

    @jsii.member(jsii_name="toDeleteMobileDevice")
    def to_delete_mobile_device(self) -> "Workmail":
        '''(experimental) Grants permission to remove a mobile device from a user.

        Access Level: Write

        https://docs.aws.amazon.com/workmail/latest/adminguide/manage-devices.html#remove_mobile_device

        :stability: experimental
        '''
        return typing.cast("Workmail", jsii.invoke(self, "toDeleteMobileDevice", []))

    @jsii.member(jsii_name="toDeleteMobileDeviceAccessOverride")
    def to_delete_mobile_device_access_override(self) -> "Workmail":
        '''(experimental) Grants permission to delete a mobile device access override.

        Access Level: Write

        https://docs.aws.amazon.com/workmail/latest/APIReference/API_DeleteMobileDeviceAccessOverride.html

        :stability: experimental
        '''
        return typing.cast("Workmail", jsii.invoke(self, "toDeleteMobileDeviceAccessOverride", []))

    @jsii.member(jsii_name="toDeleteMobileDeviceAccessRule")
    def to_delete_mobile_device_access_rule(self) -> "Workmail":
        '''(experimental) Grants permission to delete a mobile device access rule.

        Access Level: Write

        https://docs.aws.amazon.com/workmail/latest/APIReference/API_DeleteMobileDeviceAccessRule.html

        :stability: experimental
        '''
        return typing.cast("Workmail", jsii.invoke(self, "toDeleteMobileDeviceAccessRule", []))

    @jsii.member(jsii_name="toDeleteOrganization")
    def to_delete_organization(self) -> "Workmail":
        '''(experimental) Grants permission to delete an Amazon WorkMail organization and all underlying AWS resources managed by Amazon WorkMail as part of the organization.

        Access Level: Write

        https://docs.aws.amazon.com/workmail/latest/APIReference/API_DeleteOrganization.html

        :stability: experimental
        '''
        return typing.cast("Workmail", jsii.invoke(self, "toDeleteOrganization", []))

    @jsii.member(jsii_name="toDeleteOutboundMailFlowRule")
    def to_delete_outbound_mail_flow_rule(self) -> "Workmail":
        '''(experimental) Grants permission to remove an outbound email flow rule so that it no longer applies to emails sent from an organization.

        Access Level: Write

        https://docs.aws.amazon.com/workmail/latest/adminguide/remove-email-flow-rule.html

        :stability: experimental
        '''
        return typing.cast("Workmail", jsii.invoke(self, "toDeleteOutboundMailFlowRule", []))

    @jsii.member(jsii_name="toDeleteResource")
    def to_delete_resource(self) -> "Workmail":
        '''(experimental) Grants permission to delete the specified resource.

        Access Level: Write

        https://docs.aws.amazon.com/workmail/latest/APIReference/API_DeleteResource.html

        :stability: experimental
        '''
        return typing.cast("Workmail", jsii.invoke(self, "toDeleteResource", []))

    @jsii.member(jsii_name="toDeleteRetentionPolicy")
    def to_delete_retention_policy(self) -> "Workmail":
        '''(experimental) Grants permission to delete the retention policy based on the supplied organization and policy identifiers.

        Access Level: Write

        https://docs.aws.amazon.com/workmail/latest/APIReference/API_DeleteRetentionPolicy.html

        :stability: experimental
        '''
        return typing.cast("Workmail", jsii.invoke(self, "toDeleteRetentionPolicy", []))

    @jsii.member(jsii_name="toDeleteSmtpGateway")
    def to_delete_smtp_gateway(self) -> "Workmail":
        '''(experimental) Grants permission to remove an SMTP gateway from an organization.

        Access Level: Write

        https://docs.aws.amazon.com/workmail/latest/adminguide/smtp-gateway.html

        :stability: experimental
        '''
        return typing.cast("Workmail", jsii.invoke(self, "toDeleteSmtpGateway", []))

    @jsii.member(jsii_name="toDeleteUser")
    def to_delete_user(self) -> "Workmail":
        '''(experimental) Grants permission to delete a user from WorkMail and all subsequent systems.

        Access Level: Write

        https://docs.aws.amazon.com/workmail/latest/APIReference/API_DeleteUser.html

        :stability: experimental
        '''
        return typing.cast("Workmail", jsii.invoke(self, "toDeleteUser", []))

    @jsii.member(jsii_name="toDeregisterFromWorkMail")
    def to_deregister_from_work_mail(self) -> "Workmail":
        '''(experimental) Grants permission to mark a user, group, or resource as no longer used in WorkMail.

        Access Level: Write

        https://docs.aws.amazon.com/workmail/latest/APIReference/API_DeregisterFromWorkMail.html

        :stability: experimental
        '''
        return typing.cast("Workmail", jsii.invoke(self, "toDeregisterFromWorkMail", []))

    @jsii.member(jsii_name="toDeregisterMailDomain")
    def to_deregister_mail_domain(self) -> "Workmail":
        '''(experimental) Grants permission to deregister a mail domain from an organization.

        Access Level: Write

        https://docs.aws.amazon.com/workmail/latest/APIReference/API_DeregisterMailDomain.html

        :stability: experimental
        '''
        return typing.cast("Workmail", jsii.invoke(self, "toDeregisterMailDomain", []))

    @jsii.member(jsii_name="toDescribeDirectories")
    def to_describe_directories(self) -> "Workmail":
        '''(experimental) Grants permission to show a list of directories available for use in creating an organization.

        Access Level: List

        https://docs.aws.amazon.com/workmail/latest/adminguide/add_new_organization.html

        :stability: experimental
        '''
        return typing.cast("Workmail", jsii.invoke(self, "toDescribeDirectories", []))

    @jsii.member(jsii_name="toDescribeEmailMonitoringConfiguration")
    def to_describe_email_monitoring_configuration(self) -> "Workmail":
        '''(experimental) Grants permission to retrieve the email monitoring configuration for an organization.

        Access Level: Read

        https://docs.aws.amazon.com/workmail/latest/APIReference/API_DescribeEmailMonitoringConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Workmail", jsii.invoke(self, "toDescribeEmailMonitoringConfiguration", []))

    @jsii.member(jsii_name="toDescribeGroup")
    def to_describe_group(self) -> "Workmail":
        '''(experimental) Grants permission to read the details for a group.

        Access Level: List

        https://docs.aws.amazon.com/workmail/latest/APIReference/API_DescribeGroup.html

        :stability: experimental
        '''
        return typing.cast("Workmail", jsii.invoke(self, "toDescribeGroup", []))

    @jsii.member(jsii_name="toDescribeInboundDmarcSettings")
    def to_describe_inbound_dmarc_settings(self) -> "Workmail":
        '''(experimental) Grants permission to read the settings in a DMARC policy for a specified organization.

        Access Level: Read

        https://docs.aws.amazon.com/workmail/latest/APIReference/API_DescribeInboundDmarcSettings.html

        :stability: experimental
        '''
        return typing.cast("Workmail", jsii.invoke(self, "toDescribeInboundDmarcSettings", []))

    @jsii.member(jsii_name="toDescribeInboundMailFlowRule")
    def to_describe_inbound_mail_flow_rule(self) -> "Workmail":
        '''(experimental) Grants permission to read the details of an inbound mail flow rule configured for an organization.

        Access Level: Read

        https://docs.aws.amazon.com/workmail/latest/adminguide/email-flows.html#email-flows-rule-actions

        :stability: experimental
        '''
        return typing.cast("Workmail", jsii.invoke(self, "toDescribeInboundMailFlowRule", []))

    @jsii.member(jsii_name="toDescribeKmsKeys")
    def to_describe_kms_keys(self) -> "Workmail":
        '''(experimental) Grants permission to show a list of KMS Keys available for use in creating an organization.

        Access Level: List

        https://docs.aws.amazon.com/workmail/latest/adminguide/add_new_organization.html

        :stability: experimental
        '''
        return typing.cast("Workmail", jsii.invoke(self, "toDescribeKmsKeys", []))

    @jsii.member(jsii_name="toDescribeMailboxExportJob")
    def to_describe_mailbox_export_job(self) -> "Workmail":
        '''(experimental) Grants permission to retrieve details of a mailbox export job.

        Access Level: Read

        https://docs.aws.amazon.com/workmail/latest/APIReference/API_DescribeMailboxExportJob.html

        :stability: experimental
        '''
        return typing.cast("Workmail", jsii.invoke(self, "toDescribeMailboxExportJob", []))

    @jsii.member(jsii_name="toDescribeMailDomains")
    def to_describe_mail_domains(self) -> "Workmail":
        '''(experimental) Grants permission to show the details of all mail domains associated with the organization.

        Access Level: List

        https://docs.aws.amazon.com/workmail/latest/adminguide/domains_overview.html

        :stability: experimental
        '''
        return typing.cast("Workmail", jsii.invoke(self, "toDescribeMailDomains", []))

    @jsii.member(jsii_name="toDescribeMailGroups")
    def to_describe_mail_groups(self) -> "Workmail":
        '''(experimental) Grants permission to show the details of all groups associated with the organization.

        Access Level: List

        https://docs.aws.amazon.com/workmail/latest/adminguide/groups_overview.html

        :stability: experimental
        '''
        return typing.cast("Workmail", jsii.invoke(self, "toDescribeMailGroups", []))

    @jsii.member(jsii_name="toDescribeMailUsers")
    def to_describe_mail_users(self) -> "Workmail":
        '''(experimental) Grants permission to show the details of all users associated with the organization.

        Access Level: List

        https://docs.aws.amazon.com/workmail/latest/adminguide/users_overview.html

        :stability: experimental
        '''
        return typing.cast("Workmail", jsii.invoke(self, "toDescribeMailUsers", []))

    @jsii.member(jsii_name="toDescribeOrganization")
    def to_describe_organization(self) -> "Workmail":
        '''(experimental) Grants permission to read details of an organization.

        Access Level: List

        https://docs.aws.amazon.com/workmail/latest/APIReference/API_DescribeOrganization.html

        :stability: experimental
        '''
        return typing.cast("Workmail", jsii.invoke(self, "toDescribeOrganization", []))

    @jsii.member(jsii_name="toDescribeOrganizations")
    def to_describe_organizations(self) -> "Workmail":
        '''(experimental) Grants permission to show a summary of all organizations associated with the account.

        Access Level: List

        https://docs.aws.amazon.com/workmail/latest/adminguide/organizations_overview.html

        :stability: experimental
        '''
        return typing.cast("Workmail", jsii.invoke(self, "toDescribeOrganizations", []))

    @jsii.member(jsii_name="toDescribeOutboundMailFlowRule")
    def to_describe_outbound_mail_flow_rule(self) -> "Workmail":
        '''(experimental) Grants permission to read the details of an outbound mail flow rule configured for an organization.

        Access Level: Read

        https://docs.aws.amazon.com/workmail/latest/adminguide/email-flows.html#email-flows-rule-outbound

        :stability: experimental
        '''
        return typing.cast("Workmail", jsii.invoke(self, "toDescribeOutboundMailFlowRule", []))

    @jsii.member(jsii_name="toDescribeResource")
    def to_describe_resource(self) -> "Workmail":
        '''(experimental) Grants permission to read the details for a resource.

        Access Level: List

        https://docs.aws.amazon.com/workmail/latest/APIReference/API_DescribeResource.html

        :stability: experimental
        '''
        return typing.cast("Workmail", jsii.invoke(self, "toDescribeResource", []))

    @jsii.member(jsii_name="toDescribeSmtpGateway")
    def to_describe_smtp_gateway(self) -> "Workmail":
        '''(experimental) Grants permission to read the details of an SMTP gateway registered to an organization.

        Access Level: Read

        https://docs.aws.amazon.com/workmail/latest/adminguide/smtp-gateway.html

        :stability: experimental
        '''
        return typing.cast("Workmail", jsii.invoke(self, "toDescribeSmtpGateway", []))

    @jsii.member(jsii_name="toDescribeUser")
    def to_describe_user(self) -> "Workmail":
        '''(experimental) Grants permission to read details for a user.

        Access Level: List

        https://docs.aws.amazon.com/workmail/latest/APIReference/API_DescribeUser.html

        :stability: experimental
        '''
        return typing.cast("Workmail", jsii.invoke(self, "toDescribeUser", []))

    @jsii.member(jsii_name="toDisableMailGroups")
    def to_disable_mail_groups(self) -> "Workmail":
        '''(experimental) Grants permission to disable a mail group when it is not being used, in order to allow it to be deleted.

        Access Level: Write

        https://docs.aws.amazon.com/workmail/latest/adminguide/remove_group.html

        :stability: experimental
        '''
        return typing.cast("Workmail", jsii.invoke(self, "toDisableMailGroups", []))

    @jsii.member(jsii_name="toDisableMailUsers")
    def to_disable_mail_users(self) -> "Workmail":
        '''(experimental) Grants permission to disable a user mailbox when it is no longer being used, in order to allow it to be deleted.

        Access Level: Write

        https://docs.aws.amazon.com/workmail/latest/adminguide/manage-mailboxes.html#delete_user_mailbox

        :stability: experimental
        '''
        return typing.cast("Workmail", jsii.invoke(self, "toDisableMailUsers", []))

    @jsii.member(jsii_name="toDisassociateDelegateFromResource")
    def to_disassociate_delegate_from_resource(self) -> "Workmail":
        '''(experimental) Grants permission to remove a member from the resource's set of delegates.

        Access Level: Write

        https://docs.aws.amazon.com/workmail/latest/APIReference/API_DisassociateDelegateFromResource.html

        :stability: experimental
        '''
        return typing.cast("Workmail", jsii.invoke(self, "toDisassociateDelegateFromResource", []))

    @jsii.member(jsii_name="toDisassociateMemberFromGroup")
    def to_disassociate_member_from_group(self) -> "Workmail":
        '''(experimental) Grants permission to remove a member from a group.

        Access Level: Write

        https://docs.aws.amazon.com/workmail/latest/APIReference/API_DisassociateMemberFromGroup.html

        :stability: experimental
        '''
        return typing.cast("Workmail", jsii.invoke(self, "toDisassociateMemberFromGroup", []))

    @jsii.member(jsii_name="toEnableMailDomain")
    def to_enable_mail_domain(self) -> "Workmail":
        '''(experimental) Grants permission to enable a mail domain in the organization.

        Access Level: Write

        https://docs.aws.amazon.com/workmail/latest/adminguide/add_domain.html

        :stability: experimental
        '''
        return typing.cast("Workmail", jsii.invoke(self, "toEnableMailDomain", []))

    @jsii.member(jsii_name="toEnableMailGroups")
    def to_enable_mail_groups(self) -> "Workmail":
        '''(experimental) Grants permission to enable a mail group after it has been created to allow it to receive mail.

        Access Level: Write

        https://docs.aws.amazon.com/workmail/latest/adminguide/enable_existing_group.html

        :stability: experimental
        '''
        return typing.cast("Workmail", jsii.invoke(self, "toEnableMailGroups", []))

    @jsii.member(jsii_name="toEnableMailUsers")
    def to_enable_mail_users(self) -> "Workmail":
        '''(experimental) Grants permission to enable a user's mailbox after it has been created to allow it to receive mail.

        Access Level: Write

        https://docs.aws.amazon.com/workmail/latest/adminguide/manage-users.html#enable_existing_user

        :stability: experimental
        '''
        return typing.cast("Workmail", jsii.invoke(self, "toEnableMailUsers", []))

    @jsii.member(jsii_name="toGetAccessControlEffect")
    def to_get_access_control_effect(self) -> "Workmail":
        '''(experimental) Grants permission to get the effects of access control rules as they apply to a specified IPv4 address, access protocol action, or user ID.

        Access Level: Read

        https://docs.aws.amazon.com/workmail/latest/APIReference/API_GetAccessControlEffect.html

        :stability: experimental
        '''
        return typing.cast("Workmail", jsii.invoke(self, "toGetAccessControlEffect", []))

    @jsii.member(jsii_name="toGetDefaultRetentionPolicy")
    def to_get_default_retention_policy(self) -> "Workmail":
        '''(experimental) Grants permission to retrieve the retention policy associated at an organizational level.

        Access Level: Read

        https://docs.aws.amazon.com/workmail/latest/APIReference/API_GetDefaultRetentionPolicy.html

        :stability: experimental
        '''
        return typing.cast("Workmail", jsii.invoke(self, "toGetDefaultRetentionPolicy", []))

    @jsii.member(jsii_name="toGetImpersonationRole")
    def to_get_impersonation_role(self) -> "Workmail":
        '''(experimental) Grants permission to retrieve an impersonation role for the given Amazon WorkMail organization.

        Access Level: Read

        https://docs.aws.amazon.com/workmail/latest/APIReference/API_GetImpersonationRole.html

        :stability: experimental
        '''
        return typing.cast("Workmail", jsii.invoke(self, "toGetImpersonationRole", []))

    @jsii.member(jsii_name="toGetImpersonationRoleEffect")
    def to_get_impersonation_role_effect(self) -> "Workmail":
        '''(experimental) Grants permission to get the effect of the rules associated to an impersonation role for a specific user.

        Access Level: Read

        https://docs.aws.amazon.com/workmail/latest/APIReference/API_GetImpersonationRoleEffect.html

        :stability: experimental
        '''
        return typing.cast("Workmail", jsii.invoke(self, "toGetImpersonationRoleEffect", []))

    @jsii.member(jsii_name="toGetJournalingRules")
    def to_get_journaling_rules(self) -> "Workmail":
        '''(experimental) Grants permission to read the configured journaling and fallback email addresses for email journaling.

        Access Level: Read

        https://docs.aws.amazon.com/workmail/latest/adminguide/journaling_overview.html

        :stability: experimental
        '''
        return typing.cast("Workmail", jsii.invoke(self, "toGetJournalingRules", []))

    @jsii.member(jsii_name="toGetMailboxDetails")
    def to_get_mailbox_details(self) -> "Workmail":
        '''(experimental) Grants permission to read the details of the user's mailbox.

        Access Level: Read

        https://docs.aws.amazon.com/workmail/latest/APIReference/API_GetMailboxDetails.html

        :stability: experimental
        '''
        return typing.cast("Workmail", jsii.invoke(self, "toGetMailboxDetails", []))

    @jsii.member(jsii_name="toGetMailDomain")
    def to_get_mail_domain(self) -> "Workmail":
        '''(experimental) Grants permission to retrieve details of a given mail domain in an organization.

        Access Level: Read

        https://docs.aws.amazon.com/workmail/latest/APIReference/API_GetMailDomain.html

        :stability: experimental
        '''
        return typing.cast("Workmail", jsii.invoke(self, "toGetMailDomain", []))

    @jsii.member(jsii_name="toGetMailDomainDetails")
    def to_get_mail_domain_details(self) -> "Workmail":
        '''(experimental) Grants permission to get the details of the mail domain.

        Access Level: Read

        https://docs.aws.amazon.com/workmail/latest/adminguide/domains_overview.html

        :stability: experimental
        '''
        return typing.cast("Workmail", jsii.invoke(self, "toGetMailDomainDetails", []))

    @jsii.member(jsii_name="toGetMailGroupDetails")
    def to_get_mail_group_details(self) -> "Workmail":
        '''(experimental) Grants permission to get the details of the mail group.

        Access Level: Read

        https://docs.aws.amazon.com/workmail/latest/adminguide/groups_overview.html

        :stability: experimental
        '''
        return typing.cast("Workmail", jsii.invoke(self, "toGetMailGroupDetails", []))

    @jsii.member(jsii_name="toGetMailUserDetails")
    def to_get_mail_user_details(self) -> "Workmail":
        '''(experimental) Grants permission to get the details of the user's mailbox and account.

        Access Level: Read

        https://docs.aws.amazon.com/workmail/latest/adminguide/users_overview.html

        :stability: experimental
        '''
        return typing.cast("Workmail", jsii.invoke(self, "toGetMailUserDetails", []))

    @jsii.member(jsii_name="toGetMobileDeviceAccessEffect")
    def to_get_mobile_device_access_effect(self) -> "Workmail":
        '''(experimental) Grants permission to simulate the effect of the mobile device access rules for the given attributes of a sample access event.

        Access Level: Read

        https://docs.aws.amazon.com/workmail/latest/APIReference/API_GetMobileDeviceAccessEffect.html

        :stability: experimental
        '''
        return typing.cast("Workmail", jsii.invoke(self, "toGetMobileDeviceAccessEffect", []))

    @jsii.member(jsii_name="toGetMobileDeviceAccessOverride")
    def to_get_mobile_device_access_override(self) -> "Workmail":
        '''(experimental) Grants permission to retrieve a mobile device access override.

        Access Level: Read

        https://docs.aws.amazon.com/workmail/latest/APIReference/API_GetMobileDeviceAccessOverride.html

        :stability: experimental
        '''
        return typing.cast("Workmail", jsii.invoke(self, "toGetMobileDeviceAccessOverride", []))

    @jsii.member(jsii_name="toGetMobileDeviceDetails")
    def to_get_mobile_device_details(self) -> "Workmail":
        '''(experimental) Grants permission to get the details of the mobile device.

        Access Level: Read

        https://docs.aws.amazon.com/workmail/latest/adminguide/manage-devices.html

        :stability: experimental
        '''
        return typing.cast("Workmail", jsii.invoke(self, "toGetMobileDeviceDetails", []))

    @jsii.member(jsii_name="toGetMobileDevicesForUser")
    def to_get_mobile_devices_for_user(self) -> "Workmail":
        '''(experimental) Grants permission to get a list of the mobile devices associated with the user.

        Access Level: Read

        https://docs.aws.amazon.com/workmail/latest/adminguide/manage-devices.html

        :stability: experimental
        '''
        return typing.cast("Workmail", jsii.invoke(self, "toGetMobileDevicesForUser", []))

    @jsii.member(jsii_name="toGetMobilePolicyDetails")
    def to_get_mobile_policy_details(self) -> "Workmail":
        '''(experimental) Grants permission to get the details of the mobile device policy associated with the organization.

        Access Level: Read

        https://docs.aws.amazon.com/workmail/latest/adminguide/edit_organization_mobile_policy.html

        :stability: experimental
        '''
        return typing.cast("Workmail", jsii.invoke(self, "toGetMobilePolicyDetails", []))

    @jsii.member(jsii_name="toListAccessControlRules")
    def to_list_access_control_rules(self) -> "Workmail":
        '''(experimental) Grants permission to list the access control rules.

        Access Level: Read

        https://docs.aws.amazon.com/workmail/latest/APIReference/API_ListAccessControlRules.html

        :stability: experimental
        '''
        return typing.cast("Workmail", jsii.invoke(self, "toListAccessControlRules", []))

    @jsii.member(jsii_name="toListAliases")
    def to_list_aliases(self) -> "Workmail":
        '''(experimental) Grants permission to list the aliases associated with a given entity.

        Access Level: List

        https://docs.aws.amazon.com/workmail/latest/APIReference/API_ListAliases.html

        :stability: experimental
        '''
        return typing.cast("Workmail", jsii.invoke(self, "toListAliases", []))

    @jsii.member(jsii_name="toListAvailabilityConfigurations")
    def to_list_availability_configurations(self) -> "Workmail":
        '''(experimental) Grants permission to list all the AvailabilityConfiguration's for the given Amazon WorkMail organization.

        Access Level: Read

        https://docs.aws.amazon.com/workmail/latest/APIReference/API_ListAvailabilityConfigurations.html

        :stability: experimental
        '''
        return typing.cast("Workmail", jsii.invoke(self, "toListAvailabilityConfigurations", []))

    @jsii.member(jsii_name="toListGroupMembers")
    def to_list_group_members(self) -> "Workmail":
        '''(experimental) Grants permission to read an overview of the members of a group.

        Users and groups can be members of a group

        Access Level: List

        https://docs.aws.amazon.com/workmail/latest/APIReference/API_ListGroupMembers.html

        :stability: experimental
        '''
        return typing.cast("Workmail", jsii.invoke(self, "toListGroupMembers", []))

    @jsii.member(jsii_name="toListGroups")
    def to_list_groups(self) -> "Workmail":
        '''(experimental) Grants permission to list summaries of the organization's groups.

        Access Level: List

        https://docs.aws.amazon.com/workmail/latest/APIReference/API_ListGroups.html

        :stability: experimental
        '''
        return typing.cast("Workmail", jsii.invoke(self, "toListGroups", []))

    @jsii.member(jsii_name="toListImpersonationRoles")
    def to_list_impersonation_roles(self) -> "Workmail":
        '''(experimental) Grants permission to list the impersonation roles for the given Amazon WorkMail organization.

        Access Level: List

        https://docs.aws.amazon.com/workmail/latest/APIReference/API_ListImpersonationRoles.html

        :stability: experimental
        '''
        return typing.cast("Workmail", jsii.invoke(self, "toListImpersonationRoles", []))

    @jsii.member(jsii_name="toListInboundMailFlowRules")
    def to_list_inbound_mail_flow_rules(self) -> "Workmail":
        '''(experimental) Grants permission to list inbound mail flow rules configured for an organization.

        Access Level: List

        https://docs.aws.amazon.com/workmail/latest/adminguide/email-flows.html#email-flows-rule-actions

        :stability: experimental
        '''
        return typing.cast("Workmail", jsii.invoke(self, "toListInboundMailFlowRules", []))

    @jsii.member(jsii_name="toListMailboxExportJobs")
    def to_list_mailbox_export_jobs(self) -> "Workmail":
        '''(experimental) Grants permission to list mailbox export jobs.

        Access Level: List

        https://docs.aws.amazon.com/workmail/latest/APIReference/API_ListMailboxExportJobs.html

        :stability: experimental
        '''
        return typing.cast("Workmail", jsii.invoke(self, "toListMailboxExportJobs", []))

    @jsii.member(jsii_name="toListMailboxPermissions")
    def to_list_mailbox_permissions(self) -> "Workmail":
        '''(experimental) Grants permission to list the mailbox permissions associated with a user, group, or resource mailbox.

        Access Level: List

        https://docs.aws.amazon.com/workmail/latest/APIReference/API_ListMailboxPermissions.html

        :stability: experimental
        '''
        return typing.cast("Workmail", jsii.invoke(self, "toListMailboxPermissions", []))

    @jsii.member(jsii_name="toListMailDomains")
    def to_list_mail_domains(self) -> "Workmail":
        '''(experimental) Grants permission to list the mail domains for a given organization.

        Access Level: List

        https://docs.aws.amazon.com/workmail/latest/APIReference/API_ListMailDomains.html

        :stability: experimental
        '''
        return typing.cast("Workmail", jsii.invoke(self, "toListMailDomains", []))

    @jsii.member(jsii_name="toListMembersInMailGroup")
    def to_list_members_in_mail_group(self) -> "Workmail":
        '''(experimental) Grants permission to get a list of all the members in a mail group.

        Access Level: Read

        https://docs.aws.amazon.com/workmail/latest/adminguide/groups_overview.html

        :stability: experimental
        '''
        return typing.cast("Workmail", jsii.invoke(self, "toListMembersInMailGroup", []))

    @jsii.member(jsii_name="toListMobileDeviceAccessOverrides")
    def to_list_mobile_device_access_overrides(self) -> "Workmail":
        '''(experimental) Grants permission to list the mobile device access overrides.

        Access Level: Read

        https://docs.aws.amazon.com/workmail/latest/APIReference/API_ListMobileDeviceAccessOverrides.html

        :stability: experimental
        '''
        return typing.cast("Workmail", jsii.invoke(self, "toListMobileDeviceAccessOverrides", []))

    @jsii.member(jsii_name="toListMobileDeviceAccessRules")
    def to_list_mobile_device_access_rules(self) -> "Workmail":
        '''(experimental) Grants permission to list the mobile device access rules.

        Access Level: Read

        https://docs.aws.amazon.com/workmail/latest/APIReference/API_ListMobileDeviceAccessRules.html

        :stability: experimental
        '''
        return typing.cast("Workmail", jsii.invoke(self, "toListMobileDeviceAccessRules", []))

    @jsii.member(jsii_name="toListOrganizations")
    def to_list_organizations(self) -> "Workmail":
        '''(experimental) Grants permission to list the non-deleted organizations.

        Access Level: List

        https://docs.aws.amazon.com/workmail/latest/APIReference/API_ListOrganizations.html

        :stability: experimental
        '''
        return typing.cast("Workmail", jsii.invoke(self, "toListOrganizations", []))

    @jsii.member(jsii_name="toListOutboundMailFlowRules")
    def to_list_outbound_mail_flow_rules(self) -> "Workmail":
        '''(experimental) Grants permission to list outbound mail flow rules configured for an organization.

        Access Level: List

        https://docs.aws.amazon.com/workmail/latest/adminguide/email-flows.html#email-flows-rule-outbound

        :stability: experimental
        '''
        return typing.cast("Workmail", jsii.invoke(self, "toListOutboundMailFlowRules", []))

    @jsii.member(jsii_name="toListResourceDelegates")
    def to_list_resource_delegates(self) -> "Workmail":
        '''(experimental) Grants permission to list the delegates associated with a resource.

        Access Level: List

        https://docs.aws.amazon.com/workmail/latest/APIReference/API_ListResourceDelegates.html

        :stability: experimental
        '''
        return typing.cast("Workmail", jsii.invoke(self, "toListResourceDelegates", []))

    @jsii.member(jsii_name="toListResources")
    def to_list_resources(self) -> "Workmail":
        '''(experimental) Grants permission to list the organization's resources.

        Access Level: List

        https://docs.aws.amazon.com/workmail/latest/APIReference/API_ListResources.html

        :stability: experimental
        '''
        return typing.cast("Workmail", jsii.invoke(self, "toListResources", []))

    @jsii.member(jsii_name="toListSmtpGateways")
    def to_list_smtp_gateways(self) -> "Workmail":
        '''(experimental) Grants permission to list SMTP gateways registered to the organization.

        Access Level: List

        https://docs.aws.amazon.com/workmail/latest/adminguide/smtp-gateway.html

        :stability: experimental
        '''
        return typing.cast("Workmail", jsii.invoke(self, "toListSmtpGateways", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Workmail":
        '''(experimental) Grants permission to list the tags applied to an Amazon WorkMail organization resource.

        Access Level: List

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/workmail/latest/APIReference/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("Workmail", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toListUsers")
    def to_list_users(self) -> "Workmail":
        '''(experimental) Grants permission to list the organization's users.

        Access Level: List

        https://docs.aws.amazon.com/workmail/latest/APIReference/API_ListUsers.html

        :stability: experimental
        '''
        return typing.cast("Workmail", jsii.invoke(self, "toListUsers", []))

    @jsii.member(jsii_name="toPutAccessControlRule")
    def to_put_access_control_rule(self) -> "Workmail":
        '''(experimental) Grants permission to add a new access control rule.

        Access Level: Write

        https://docs.aws.amazon.com/workmail/latest/APIReference/API_PutAccessControlRule.html

        :stability: experimental
        '''
        return typing.cast("Workmail", jsii.invoke(self, "toPutAccessControlRule", []))

    @jsii.member(jsii_name="toPutEmailMonitoringConfiguration")
    def to_put_email_monitoring_configuration(self) -> "Workmail":
        '''(experimental) Grants permission to add or update the email monitoring configuration for an organization.

        Access Level: Write

        https://docs.aws.amazon.com/workmail/latest/APIReference/API_PutEmailMonitoringConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Workmail", jsii.invoke(self, "toPutEmailMonitoringConfiguration", []))

    @jsii.member(jsii_name="toPutInboundDmarcSettings")
    def to_put_inbound_dmarc_settings(self) -> "Workmail":
        '''(experimental) Grants permission to enable or disable a DMARC policy for a given organization.

        Access Level: Write

        https://docs.aws.amazon.com/workmail/latest/APIReference/API_PutInboundDmarcSettings.html

        :stability: experimental
        '''
        return typing.cast("Workmail", jsii.invoke(self, "toPutInboundDmarcSettings", []))

    @jsii.member(jsii_name="toPutMailboxPermissions")
    def to_put_mailbox_permissions(self) -> "Workmail":
        '''(experimental) Grants permission to set permissions for a user, group, or resource, replacing any existing permissions.

        Access Level: Write

        https://docs.aws.amazon.com/workmail/latest/APIReference/API_PutMailboxPermissions.html

        :stability: experimental
        '''
        return typing.cast("Workmail", jsii.invoke(self, "toPutMailboxPermissions", []))

    @jsii.member(jsii_name="toPutMobileDeviceAccessOverride")
    def to_put_mobile_device_access_override(self) -> "Workmail":
        '''(experimental) Grants permission to add or update a mobile device access override.

        Access Level: Write

        https://docs.aws.amazon.com/workmail/latest/APIReference/API_PutMobileDeviceAccessOverride.html

        :stability: experimental
        '''
        return typing.cast("Workmail", jsii.invoke(self, "toPutMobileDeviceAccessOverride", []))

    @jsii.member(jsii_name="toPutRetentionPolicy")
    def to_put_retention_policy(self) -> "Workmail":
        '''(experimental) Grants permission to add or update the retention policy.

        Access Level: Write

        https://docs.aws.amazon.com/workmail/latest/APIReference/API_PutRetentionPolicy.html

        :stability: experimental
        '''
        return typing.cast("Workmail", jsii.invoke(self, "toPutRetentionPolicy", []))

    @jsii.member(jsii_name="toRegisterMailDomain")
    def to_register_mail_domain(self) -> "Workmail":
        '''(experimental) Grants permission to register a new mail domain in an organization.

        Access Level: Write

        https://docs.aws.amazon.com/workmail/latest/APIReference/API_RegisterMailDomain.html

        :stability: experimental
        '''
        return typing.cast("Workmail", jsii.invoke(self, "toRegisterMailDomain", []))

    @jsii.member(jsii_name="toRegisterToWorkMail")
    def to_register_to_work_mail(self) -> "Workmail":
        '''(experimental) Grants permission to register an existing and disabled user, group, or resource for use by associating a mailbox and calendaring capabilities.

        Access Level: Write

        https://docs.aws.amazon.com/workmail/latest/APIReference/API_RegisterToWorkMail.html

        :stability: experimental
        '''
        return typing.cast("Workmail", jsii.invoke(self, "toRegisterToWorkMail", []))

    @jsii.member(jsii_name="toRemoveMembersFromGroup")
    def to_remove_members_from_group(self) -> "Workmail":
        '''(experimental) Grants permission to remove members from a mail group.

        Access Level: Write

        https://docs.aws.amazon.com/workmail/latest/adminguide/groups_overview.html

        :stability: experimental
        '''
        return typing.cast("Workmail", jsii.invoke(self, "toRemoveMembersFromGroup", []))

    @jsii.member(jsii_name="toResetPassword")
    def to_reset_password(self) -> "Workmail":
        '''(experimental) Grants permission to allow the administrator to reset the password for a user.

        Access Level: Write

        https://docs.aws.amazon.com/workmail/latest/APIReference/API_ResetPassword.html

        :stability: experimental
        '''
        return typing.cast("Workmail", jsii.invoke(self, "toResetPassword", []))

    @jsii.member(jsii_name="toResetUserPassword")
    def to_reset_user_password(self) -> "Workmail":
        '''(experimental) Grants permission to reset the password for a user's account.

        Access Level: Write

        https://docs.aws.amazon.com/workmail/latest/adminguide/manage-users.html#reset_user_password

        :stability: experimental
        '''
        return typing.cast("Workmail", jsii.invoke(self, "toResetUserPassword", []))

    @jsii.member(jsii_name="toSearchMembers")
    def to_search_members(self) -> "Workmail":
        '''(experimental) Grants permission to perform a prefix search to find a specific user in a mail group.

        Access Level: Read

        https://docs.aws.amazon.com/workmail/latest/adminguide/groups_overview.html

        :stability: experimental
        '''
        return typing.cast("Workmail", jsii.invoke(self, "toSearchMembers", []))

    @jsii.member(jsii_name="toSetAdmin")
    def to_set_admin(self) -> "Workmail":
        '''(experimental) Grants permission to mark a user as being an administrator.

        Access Level: Write

        https://docs.aws.amazon.com/workmail/latest/adminguide/users_overview.html

        :stability: experimental
        '''
        return typing.cast("Workmail", jsii.invoke(self, "toSetAdmin", []))

    @jsii.member(jsii_name="toSetDefaultMailDomain")
    def to_set_default_mail_domain(self) -> "Workmail":
        '''(experimental) Grants permission to set the default mail domain for the organization.

        Access Level: Write

        https://docs.aws.amazon.com/workmail/latest/adminguide/default_domain.html

        :stability: experimental
        '''
        return typing.cast("Workmail", jsii.invoke(self, "toSetDefaultMailDomain", []))

    @jsii.member(jsii_name="toSetJournalingRules")
    def to_set_journaling_rules(self) -> "Workmail":
        '''(experimental) Grants permission to set journaling and fallback email addresses for email journaling.

        Access Level: Write

        https://docs.aws.amazon.com/workmail/latest/adminguide/journaling_overview.html

        :stability: experimental
        '''
        return typing.cast("Workmail", jsii.invoke(self, "toSetJournalingRules", []))

    @jsii.member(jsii_name="toSetMailGroupDetails")
    def to_set_mail_group_details(self) -> "Workmail":
        '''(experimental) Grants permission to set the details of the mail group which has just been created.

        Access Level: Write

        https://docs.aws.amazon.com/workmail/latest/adminguide/add_new_group.html

        :stability: experimental
        '''
        return typing.cast("Workmail", jsii.invoke(self, "toSetMailGroupDetails", []))

    @jsii.member(jsii_name="toSetMailUserDetails")
    def to_set_mail_user_details(self) -> "Workmail":
        '''(experimental) Grants permission to set the details for the user account which has just been created.

        Access Level: Write

        https://docs.aws.amazon.com/workmail/latest/adminguide/manage-users.html

        :stability: experimental
        '''
        return typing.cast("Workmail", jsii.invoke(self, "toSetMailUserDetails", []))

    @jsii.member(jsii_name="toSetMobilePolicyDetails")
    def to_set_mobile_policy_details(self) -> "Workmail":
        '''(experimental) Grants permission to set the details of a mobile policy associated with the organization.

        Access Level: Write

        https://docs.aws.amazon.com/workmail/latest/adminguide/edit_organization_mobile_policy.html

        :stability: experimental
        '''
        return typing.cast("Workmail", jsii.invoke(self, "toSetMobilePolicyDetails", []))

    @jsii.member(jsii_name="toStartMailboxExportJob")
    def to_start_mailbox_export_job(self) -> "Workmail":
        '''(experimental) Grants permission to start a new mailbox export job.

        Access Level: Write

        https://docs.aws.amazon.com/workmail/latest/APIReference/API_StartMailboxExportJob.html

        :stability: experimental
        '''
        return typing.cast("Workmail", jsii.invoke(self, "toStartMailboxExportJob", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Workmail":
        '''(experimental) Grants permission to tag the specified Amazon WorkMail organization resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/workmail/latest/APIReference/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("Workmail", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toTestAvailabilityConfiguration")
    def to_test_availability_configuration(self) -> "Workmail":
        '''(experimental) Grants permission to performs a test on an availability provider to ensure that access is allowed.

        Access Level: Read

        https://docs.aws.amazon.com/workmail/latest/APIReference/API_TestAvailabilityConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Workmail", jsii.invoke(self, "toTestAvailabilityConfiguration", []))

    @jsii.member(jsii_name="toTestInboundMailFlowRules")
    def to_test_inbound_mail_flow_rules(self) -> "Workmail":
        '''(experimental) Grants permission to test what inbound rules will apply to an email with a given sender and recipient.

        Access Level: Write

        https://docs.aws.amazon.com/workmail/latest/adminguide/test-email-flow-rule.html

        :stability: experimental
        '''
        return typing.cast("Workmail", jsii.invoke(self, "toTestInboundMailFlowRules", []))

    @jsii.member(jsii_name="toTestOutboundMailFlowRules")
    def to_test_outbound_mail_flow_rules(self) -> "Workmail":
        '''(experimental) Grants permission to test what outbound rules will apply to an email with a given sender and recipient.

        Access Level: Write

        https://docs.aws.amazon.com/workmail/latest/adminguide/test-email-flow-rule.html

        :stability: experimental
        '''
        return typing.cast("Workmail", jsii.invoke(self, "toTestOutboundMailFlowRules", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Workmail":
        '''(experimental) Grants permission to untag the specified Amazon WorkMail organization resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/workmail/latest/APIReference/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("Workmail", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateAvailabilityConfiguration")
    def to_update_availability_configuration(self) -> "Workmail":
        '''(experimental) Grants permission to update an existing AvailabilityConfiguration for the given Amazon WorkMail organization and domain.

        Access Level: Write

        https://docs.aws.amazon.com/workmail/latest/APIReference/API_UpdateAvailabilityConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Workmail", jsii.invoke(self, "toUpdateAvailabilityConfiguration", []))

    @jsii.member(jsii_name="toUpdateDefaultMailDomain")
    def to_update_default_mail_domain(self) -> "Workmail":
        '''(experimental) Grants permission to update which domain is the default domain for an organization.

        Access Level: Write

        https://docs.aws.amazon.com/workmail/latest/APIReference/API_UpdateDefaultMailDomain.html

        :stability: experimental
        '''
        return typing.cast("Workmail", jsii.invoke(self, "toUpdateDefaultMailDomain", []))

    @jsii.member(jsii_name="toUpdateImpersonationRole")
    def to_update_impersonation_role(self) -> "Workmail":
        '''(experimental) Grants permission to update an existing impersonation role for the given Amazon WorkMail organization.

        Access Level: Write

        https://docs.aws.amazon.com/workmail/latest/APIReference/API_UpdateImpersonationRole.html

        :stability: experimental
        '''
        return typing.cast("Workmail", jsii.invoke(self, "toUpdateImpersonationRole", []))

    @jsii.member(jsii_name="toUpdateInboundMailFlowRule")
    def to_update_inbound_mail_flow_rule(self) -> "Workmail":
        '''(experimental) Grants permission to update the details of an inbound email flow rule which will apply to all email sent to an organization.

        Access Level: Write

        https://docs.aws.amazon.com/workmail/latest/adminguide/modify-email-flow-rule.html

        :stability: experimental
        '''
        return typing.cast("Workmail", jsii.invoke(self, "toUpdateInboundMailFlowRule", []))

    @jsii.member(jsii_name="toUpdateMailboxQuota")
    def to_update_mailbox_quota(self) -> "Workmail":
        '''(experimental) Grants permission to update the maximum size (in MB) of the user's mailbox.

        Access Level: Write

        https://docs.aws.amazon.com/workmail/latest/APIReference/API_UpdateMailboxQuota.html

        :stability: experimental
        '''
        return typing.cast("Workmail", jsii.invoke(self, "toUpdateMailboxQuota", []))

    @jsii.member(jsii_name="toUpdateMobileDeviceAccessRule")
    def to_update_mobile_device_access_rule(self) -> "Workmail":
        '''(experimental) Grants permission to update a mobile device access rule.

        Access Level: Write

        https://docs.aws.amazon.com/workmail/latest/APIReference/API_UpdateMobileDeviceAccessRule.html

        :stability: experimental
        '''
        return typing.cast("Workmail", jsii.invoke(self, "toUpdateMobileDeviceAccessRule", []))

    @jsii.member(jsii_name="toUpdateOutboundMailFlowRule")
    def to_update_outbound_mail_flow_rule(self) -> "Workmail":
        '''(experimental) Grants permission to update the details of an outbound email flow rule which will apply to all email sent from an organization.

        Access Level: Write

        https://docs.aws.amazon.com/workmail/latest/adminguide/modify-email-flow-rule.html

        :stability: experimental
        '''
        return typing.cast("Workmail", jsii.invoke(self, "toUpdateOutboundMailFlowRule", []))

    @jsii.member(jsii_name="toUpdatePrimaryEmailAddress")
    def to_update_primary_email_address(self) -> "Workmail":
        '''(experimental) Grants permission to update the primary email for a user, group, or resource.

        Access Level: Write

        https://docs.aws.amazon.com/workmail/latest/APIReference/API_UpdatePrimaryEmailAddress.html

        :stability: experimental
        '''
        return typing.cast("Workmail", jsii.invoke(self, "toUpdatePrimaryEmailAddress", []))

    @jsii.member(jsii_name="toUpdateResource")
    def to_update_resource(self) -> "Workmail":
        '''(experimental) Grants permission to update details for the resource.

        Access Level: Write

        https://docs.aws.amazon.com/workmail/latest/APIReference/API_UpdateResource.html

        :stability: experimental
        '''
        return typing.cast("Workmail", jsii.invoke(self, "toUpdateResource", []))

    @jsii.member(jsii_name="toUpdateSmtpGateway")
    def to_update_smtp_gateway(self) -> "Workmail":
        '''(experimental) Grants permission to update the details of an existing SMTP gateway registered to an organization.

        Access Level: Write

        https://docs.aws.amazon.com/workmail/latest/adminguide/smtp-gateway.html

        :stability: experimental
        '''
        return typing.cast("Workmail", jsii.invoke(self, "toUpdateSmtpGateway", []))

    @jsii.member(jsii_name="toWipeMobileDevice")
    def to_wipe_mobile_device(self) -> "Workmail":
        '''(experimental) Grants permission to remotely wipe the mobile device associated with a user's account.

        Access Level: Write

        https://docs.aws.amazon.com/workmail/latest/adminguide/manage-devices.html#remote_wipe_device

        :stability: experimental
        '''
        return typing.cast("Workmail", jsii.invoke(self, "toWipeMobileDevice", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__539e20888d42e55104a776fe69b7ab084aff1d998ab2008aa111138a9fb077a1)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__492041d5da269469aa18f0ea16a95b18a67ed48ad3a06a91b000040c1e3f1489)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Workmailmessageflow(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Workmailmessageflow",
):
    '''(experimental) Statement provider for service `workmailmessageflow <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonworkmailmessageflow.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `workmailmessageflow <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonworkmailmessageflow.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onRawMessage")
    def on_raw_message(
        self,
        organization_id: builtins.str,
        context: builtins.str,
        message_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Workmailmessageflow":
        '''(experimental) Adds a resource of type RawMessage to the statement.

        https://docs.aws.amazon.com/workmail/latest/adminguide/lambda-content.html

        :param organization_id: - Identifier for the organizationId.
        :param context: - Identifier for the context.
        :param message_id: - Identifier for the messageId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e47bb82a2c138eac5ec45ffbd8a15a41ca9dfc344bcf167077836d162d2daceb)
            check_type(argname="argument organization_id", value=organization_id, expected_type=type_hints["organization_id"])
            check_type(argname="argument context", value=context, expected_type=type_hints["context"])
            check_type(argname="argument message_id", value=message_id, expected_type=type_hints["message_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Workmailmessageflow", jsii.invoke(self, "onRawMessage", [organization_id, context, message_id, account, region, partition]))

    @jsii.member(jsii_name="toGetRawMessageContent")
    def to_get_raw_message_content(self) -> "Workmailmessageflow":
        '''(experimental) Grants permission to read the content of email messages with the specified message ID.

        Access Level: Read

        https://docs.aws.amazon.com/workmail/latest/APIReference/API_messageflow_GetRawMessageContent.html

        :stability: experimental
        '''
        return typing.cast("Workmailmessageflow", jsii.invoke(self, "toGetRawMessageContent", []))

    @jsii.member(jsii_name="toPutRawMessageContent")
    def to_put_raw_message_content(self) -> "Workmailmessageflow":
        '''(experimental) Grants permission to update the content of email messages with the specified message ID.

        Access Level: Write

        https://docs.aws.amazon.com/workmail/latest/APIReference/API_messageflow_PutRawMessageContent.html

        :stability: experimental
        '''
        return typing.cast("Workmailmessageflow", jsii.invoke(self, "toPutRawMessageContent", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2b0794a2aa163e2736146a5511bab191c6417d030f29782a1656e82c8b8eed58)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__45c77c7a7a34dfdfa057614f891cdd71f9fd27c4606dbfa88bb4e848595cf463)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Workspaces(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Workspaces",
):
    '''(experimental) Statement provider for service `workspaces <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonworkspaces.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `workspaces <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonworkspaces.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="ifUserId")
    def if_user_id(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Workspaces":
        '''(experimental) Filters access by the ID of the Workspaces user.

        https://docs.aws.amazon.com/workspaces/latest/adminguide/external-identity-providers-setting-up-saml.html#external-identity-providers-embed-inline-policy-for-IAM-role

        Applies to actions:

        - .toStream()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__be7dca1b491695c4f8ccf75bf614203cbfa154d46dc97419249c0362e1f57405)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Workspaces", jsii.invoke(self, "ifUserId", [value, operator]))

    @jsii.member(jsii_name="onConnectionalias")
    def on_connectionalias(
        self,
        connection_alias_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Workspaces":
        '''(experimental) Adds a resource of type connectionalias to the statement.

        https://docs.aws.amazon.com/workspaces/latest/adminguide/cross-region-redirection.html

        :param connection_alias_id: - Identifier for the connectionAliasId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__daf8c0ffcd4a7f152ab3b8bce68acbc84071b7858fa274924b32ced297dc3348)
            check_type(argname="argument connection_alias_id", value=connection_alias_id, expected_type=type_hints["connection_alias_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Workspaces", jsii.invoke(self, "onConnectionalias", [connection_alias_id, account, region, partition]))

    @jsii.member(jsii_name="onDirectoryid")
    def on_directoryid(
        self,
        directory_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Workspaces":
        '''(experimental) Adds a resource of type directoryid to the statement.

        https://docs.aws.amazon.com/workspaces/latest/adminguide/manage-workspaces-directory.html

        :param directory_id: - Identifier for the directoryId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__38a9d26afb12f55c0b89f4c35dea55fa22669390a1b4db32b96f02773332ee6e)
            check_type(argname="argument directory_id", value=directory_id, expected_type=type_hints["directory_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Workspaces", jsii.invoke(self, "onDirectoryid", [directory_id, account, region, partition]))

    @jsii.member(jsii_name="onWorkspacebundle")
    def on_workspacebundle(
        self,
        bundle_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Workspaces":
        '''(experimental) Adds a resource of type workspacebundle to the statement.

        https://docs.aws.amazon.com/workspaces/latest/adminguide/bundles.html

        :param bundle_id: - Identifier for the bundleId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__eec046e5f4517a9c30efe420e9c38405edd2e71677fa9ce3dbca6746d1675c55)
            check_type(argname="argument bundle_id", value=bundle_id, expected_type=type_hints["bundle_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Workspaces", jsii.invoke(self, "onWorkspacebundle", [bundle_id, account, region, partition]))

    @jsii.member(jsii_name="onWorkspaceid")
    def on_workspaceid(
        self,
        workspace_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Workspaces":
        '''(experimental) Adds a resource of type workspaceid to the statement.

        https://docs.aws.amazon.com/workspaces/latest/adminguide/wsp_workspace_management.html

        :param workspace_id: - Identifier for the workspaceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d3c800399ce8ea52d6741f25c02cbfd9e2584d03413bc5cf5bda2b2d1b337e1c)
            check_type(argname="argument workspace_id", value=workspace_id, expected_type=type_hints["workspace_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Workspaces", jsii.invoke(self, "onWorkspaceid", [workspace_id, account, region, partition]))

    @jsii.member(jsii_name="onWorkspaceimage")
    def on_workspaceimage(
        self,
        image_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Workspaces":
        '''(experimental) Adds a resource of type workspaceimage to the statement.

        https://docs.aws.amazon.com/workspaces/latest/adminguide/bundles.html

        :param image_id: - Identifier for the imageId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1c0e265bb1590313aff6a192667aba8bbb71ea49835dabd4db66aae78e4f2346)
            check_type(argname="argument image_id", value=image_id, expected_type=type_hints["image_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Workspaces", jsii.invoke(self, "onWorkspaceimage", [image_id, account, region, partition]))

    @jsii.member(jsii_name="onWorkspaceipgroup")
    def on_workspaceipgroup(
        self,
        group_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Workspaces":
        '''(experimental) Adds a resource of type workspaceipgroup to the statement.

        https://docs.aws.amazon.com/workspaces/latest/adminguide/amazon-workspaces-ip-access-control-groups.html

        :param group_id: - Identifier for the groupId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__985319aaa02da53533c80f9640eba9b4896696494a80677233ce0864fe93f443)
            check_type(argname="argument group_id", value=group_id, expected_type=type_hints["group_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Workspaces", jsii.invoke(self, "onWorkspaceipgroup", [group_id, account, region, partition]))

    @jsii.member(jsii_name="toAssociateConnectionAlias")
    def to_associate_connection_alias(self) -> "Workspaces":
        '''(experimental) Grants permission to associate connection aliases with directories.

        Access Level: Write

        https://docs.aws.amazon.com/workspaces/latest/api/API_AssociateConnectionAlias.html

        :stability: experimental
        '''
        return typing.cast("Workspaces", jsii.invoke(self, "toAssociateConnectionAlias", []))

    @jsii.member(jsii_name="toAssociateIpGroups")
    def to_associate_ip_groups(self) -> "Workspaces":
        '''(experimental) Grants permission to associate IP access control groups with directories.

        Access Level: Write

        https://docs.aws.amazon.com/workspaces/latest/api/API_AssociateIpGroups.html

        :stability: experimental
        '''
        return typing.cast("Workspaces", jsii.invoke(self, "toAssociateIpGroups", []))

    @jsii.member(jsii_name="toAuthorizeIpRules")
    def to_authorize_ip_rules(self) -> "Workspaces":
        '''(experimental) Grants permission to add rules to IP access control groups.

        Access Level: Write

        https://docs.aws.amazon.com/workspaces/latest/api/API_AuthorizeIpRules.html

        :stability: experimental
        '''
        return typing.cast("Workspaces", jsii.invoke(self, "toAuthorizeIpRules", []))

    @jsii.member(jsii_name="toCopyWorkspaceImage")
    def to_copy_workspace_image(self) -> "Workspaces":
        '''(experimental) Grants permission to copy a WorkSpace image.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - workspaces:DescribeWorkspaceImages

        https://docs.aws.amazon.com/workspaces/latest/api/API_CopyWorkspaceImage.html

        :stability: experimental
        '''
        return typing.cast("Workspaces", jsii.invoke(self, "toCopyWorkspaceImage", []))

    @jsii.member(jsii_name="toCreateConnectClientAddIn")
    def to_create_connect_client_add_in(self) -> "Workspaces":
        '''(experimental) Grants permission to create an Amazon Connect client add-in within a directory.

        Access Level: Write

        https://docs.aws.amazon.com/workspaces/latest/api/API_CreateConnectClientAddIn.html

        :stability: experimental
        '''
        return typing.cast("Workspaces", jsii.invoke(self, "toCreateConnectClientAddIn", []))

    @jsii.member(jsii_name="toCreateConnectionAlias")
    def to_create_connection_alias(self) -> "Workspaces":
        '''(experimental) Grants permission to create connection aliases for use with cross-Region redirection.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/workspaces/latest/api/API_CreateConnectionAlias.html

        :stability: experimental
        '''
        return typing.cast("Workspaces", jsii.invoke(self, "toCreateConnectionAlias", []))

    @jsii.member(jsii_name="toCreateIpGroup")
    def to_create_ip_group(self) -> "Workspaces":
        '''(experimental) Grants permission to create IP access control groups.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/workspaces/latest/api/API_CreateIpGroup.html

        :stability: experimental
        '''
        return typing.cast("Workspaces", jsii.invoke(self, "toCreateIpGroup", []))

    @jsii.member(jsii_name="toCreateStandbyWorkspaces")
    def to_create_standby_workspaces(self) -> "Workspaces":
        '''(experimental) Grants permission to create one or more Standby WorkSpaces.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/workspaces/latest/api/API_CreateStandbyWorkspaces.html

        :stability: experimental
        '''
        return typing.cast("Workspaces", jsii.invoke(self, "toCreateStandbyWorkspaces", []))

    @jsii.member(jsii_name="toCreateTags")
    def to_create_tags(self) -> "Workspaces":
        '''(experimental) Grants permission to create tags for WorkSpaces resources.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/workspaces/latest/api/API_CreateTags.html

        :stability: experimental
        '''
        return typing.cast("Workspaces", jsii.invoke(self, "toCreateTags", []))

    @jsii.member(jsii_name="toCreateUpdatedWorkspaceImage")
    def to_create_updated_workspace_image(self) -> "Workspaces":
        '''(experimental) Grants permission to create an updated WorkSpace image.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/workspaces/latest/api/API_CreateUpdatedWorkspaceImage.html

        :stability: experimental
        '''
        return typing.cast("Workspaces", jsii.invoke(self, "toCreateUpdatedWorkspaceImage", []))

    @jsii.member(jsii_name="toCreateWorkspaceBundle")
    def to_create_workspace_bundle(self) -> "Workspaces":
        '''(experimental) Grants permission to create a WorkSpace bundle.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - workspaces:CreateTags

        https://docs.aws.amazon.com/workspaces/latest/api/API_CreateWorkspaceBundle.html

        :stability: experimental
        '''
        return typing.cast("Workspaces", jsii.invoke(self, "toCreateWorkspaceBundle", []))

    @jsii.member(jsii_name="toCreateWorkspaceImage")
    def to_create_workspace_image(self) -> "Workspaces":
        '''(experimental) Grants permission to create a new WorkSpace image.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/workspaces/latest/api/API_CreateWorkspaceImage.html

        :stability: experimental
        '''
        return typing.cast("Workspaces", jsii.invoke(self, "toCreateWorkspaceImage", []))

    @jsii.member(jsii_name="toCreateWorkspaces")
    def to_create_workspaces(self) -> "Workspaces":
        '''(experimental) Grants permission to create one or more WorkSpaces.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/workspaces/latest/api/API_CreateWorkspaces.html

        :stability: experimental
        '''
        return typing.cast("Workspaces", jsii.invoke(self, "toCreateWorkspaces", []))

    @jsii.member(jsii_name="toDeleteClientBranding")
    def to_delete_client_branding(self) -> "Workspaces":
        '''(experimental) Grants permission to delete AWS WorkSpaces Client branding data within a directory.

        Access Level: Write

        https://docs.aws.amazon.com/workspaces/latest/api/API_DeleteClientBranding.html

        :stability: experimental
        '''
        return typing.cast("Workspaces", jsii.invoke(self, "toDeleteClientBranding", []))

    @jsii.member(jsii_name="toDeleteConnectClientAddIn")
    def to_delete_connect_client_add_in(self) -> "Workspaces":
        '''(experimental) Grants permission to delete an Amazon Connect client add-in that is configured within a directory.

        Access Level: Write

        https://docs.aws.amazon.com/workspaces/latest/api/API_DeleteConnectClientAddIn.html

        :stability: experimental
        '''
        return typing.cast("Workspaces", jsii.invoke(self, "toDeleteConnectClientAddIn", []))

    @jsii.member(jsii_name="toDeleteConnectionAlias")
    def to_delete_connection_alias(self) -> "Workspaces":
        '''(experimental) Grants permission to delete connection aliases.

        Access Level: Write

        https://docs.aws.amazon.com/workspaces/latest/api/API_DeleteConnectionAlias.html

        :stability: experimental
        '''
        return typing.cast("Workspaces", jsii.invoke(self, "toDeleteConnectionAlias", []))

    @jsii.member(jsii_name="toDeleteIpGroup")
    def to_delete_ip_group(self) -> "Workspaces":
        '''(experimental) Grants permission to delete IP access control groups.

        Access Level: Write

        https://docs.aws.amazon.com/workspaces/latest/api/API_DeleteIpGroup.html

        :stability: experimental
        '''
        return typing.cast("Workspaces", jsii.invoke(self, "toDeleteIpGroup", []))

    @jsii.member(jsii_name="toDeleteTags")
    def to_delete_tags(self) -> "Workspaces":
        '''(experimental) Grants permission to delete tags from WorkSpaces resources.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/workspaces/latest/api/API_DeleteTags.html

        :stability: experimental
        '''
        return typing.cast("Workspaces", jsii.invoke(self, "toDeleteTags", []))

    @jsii.member(jsii_name="toDeleteWorkspaceBundle")
    def to_delete_workspace_bundle(self) -> "Workspaces":
        '''(experimental) Grants permission to delete WorkSpace bundles.

        Access Level: Write

        https://docs.aws.amazon.com/workspaces/latest/api/API_DeleteWorkspaceBundle.html

        :stability: experimental
        '''
        return typing.cast("Workspaces", jsii.invoke(self, "toDeleteWorkspaceBundle", []))

    @jsii.member(jsii_name="toDeleteWorkspaceImage")
    def to_delete_workspace_image(self) -> "Workspaces":
        '''(experimental) Grants permission to delete WorkSpace images.

        Access Level: Write

        https://docs.aws.amazon.com/workspaces/latest/api/API_DeleteWorkspaceImage.html

        :stability: experimental
        '''
        return typing.cast("Workspaces", jsii.invoke(self, "toDeleteWorkspaceImage", []))

    @jsii.member(jsii_name="toDeregisterWorkspaceDirectory")
    def to_deregister_workspace_directory(self) -> "Workspaces":
        '''(experimental) Grants permission to deregister directories from use with Amazon WorkSpaces.

        Access Level: Write

        https://docs.aws.amazon.com/workspaces/latest/api/API_DeregisterWorkspaceDirectory.html

        :stability: experimental
        '''
        return typing.cast("Workspaces", jsii.invoke(self, "toDeregisterWorkspaceDirectory", []))

    @jsii.member(jsii_name="toDescribeAccount")
    def to_describe_account(self) -> "Workspaces":
        '''(experimental) Grants permission to retrieve the configuration of Bring Your Own License (BYOL) for WorkSpaces accounts.

        Access Level: Read

        https://docs.aws.amazon.com/workspaces/latest/api/API_DescribeAccount.html

        :stability: experimental
        '''
        return typing.cast("Workspaces", jsii.invoke(self, "toDescribeAccount", []))

    @jsii.member(jsii_name="toDescribeAccountModifications")
    def to_describe_account_modifications(self) -> "Workspaces":
        '''(experimental) Grants permission to retrieve modifications to the configuration of Bring Your Own License (BYOL) for WorkSpaces accounts.

        Access Level: Read

        https://docs.aws.amazon.com/workspaces/latest/api/API_DescribeAccountModifications.html

        :stability: experimental
        '''
        return typing.cast("Workspaces", jsii.invoke(self, "toDescribeAccountModifications", []))

    @jsii.member(jsii_name="toDescribeClientBranding")
    def to_describe_client_branding(self) -> "Workspaces":
        '''(experimental) Grants permission to retrieve AWS WorkSpaces Client branding data within a directory.

        Access Level: Read

        https://docs.aws.amazon.com/workspaces/latest/api/API_DescribeClientBranding.html

        :stability: experimental
        '''
        return typing.cast("Workspaces", jsii.invoke(self, "toDescribeClientBranding", []))

    @jsii.member(jsii_name="toDescribeClientProperties")
    def to_describe_client_properties(self) -> "Workspaces":
        '''(experimental) Grants permission to retrieve information about WorkSpaces clients.

        Access Level: List

        https://docs.aws.amazon.com/workspaces/latest/api/API_DescribeClientProperties.html

        :stability: experimental
        '''
        return typing.cast("Workspaces", jsii.invoke(self, "toDescribeClientProperties", []))

    @jsii.member(jsii_name="toDescribeConnectClientAddIns")
    def to_describe_connect_client_add_ins(self) -> "Workspaces":
        '''(experimental) Grants permission to retrieve a list of Amazon Connect client add-ins that have been created.

        Access Level: List

        https://docs.aws.amazon.com/workspaces/latest/api/API_DescribeConnectClientAddIns.html

        :stability: experimental
        '''
        return typing.cast("Workspaces", jsii.invoke(self, "toDescribeConnectClientAddIns", []))

    @jsii.member(jsii_name="toDescribeConnectionAliases")
    def to_describe_connection_aliases(self) -> "Workspaces":
        '''(experimental) Grants permission to retrieve a list that describes the connection aliases used for cross-Region redirection.

        Access Level: Read

        https://docs.aws.amazon.com/workspaces/latest/api/API_DescribeConnectionAliases.html

        :stability: experimental
        '''
        return typing.cast("Workspaces", jsii.invoke(self, "toDescribeConnectionAliases", []))

    @jsii.member(jsii_name="toDescribeConnectionAliasPermissions")
    def to_describe_connection_alias_permissions(self) -> "Workspaces":
        '''(experimental) Grants permission to retrieve the permissions that the owners of connection aliases have granted to other AWS accounts for connection aliases.

        Access Level: Read

        https://docs.aws.amazon.com/workspaces/latest/api/API_DescribeConnectionAliasPermissions.html

        :stability: experimental
        '''
        return typing.cast("Workspaces", jsii.invoke(self, "toDescribeConnectionAliasPermissions", []))

    @jsii.member(jsii_name="toDescribeIpGroups")
    def to_describe_ip_groups(self) -> "Workspaces":
        '''(experimental) Grants permission to retrieve information about IP access control groups.

        Access Level: Read

        https://docs.aws.amazon.com/workspaces/latest/api/API_DescribeIpGroups.html

        :stability: experimental
        '''
        return typing.cast("Workspaces", jsii.invoke(self, "toDescribeIpGroups", []))

    @jsii.member(jsii_name="toDescribeTags")
    def to_describe_tags(self) -> "Workspaces":
        '''(experimental) Grants permission to describe the tags for WorkSpaces resources.

        Access Level: Read

        https://docs.aws.amazon.com/workspaces/latest/api/API_DescribeTags.html

        :stability: experimental
        '''
        return typing.cast("Workspaces", jsii.invoke(self, "toDescribeTags", []))

    @jsii.member(jsii_name="toDescribeWorkspaceBundles")
    def to_describe_workspace_bundles(self) -> "Workspaces":
        '''(experimental) Grants permission to obtain information about WorkSpace bundles.

        Access Level: List

        https://docs.aws.amazon.com/workspaces/latest/api/API_DescribeWorkspaceBundles.html

        :stability: experimental
        '''
        return typing.cast("Workspaces", jsii.invoke(self, "toDescribeWorkspaceBundles", []))

    @jsii.member(jsii_name="toDescribeWorkspaceDirectories")
    def to_describe_workspace_directories(self) -> "Workspaces":
        '''(experimental) Grants permission to retrieve information about directories that are registered with WorkSpaces.

        Access Level: Read

        https://docs.aws.amazon.com/workspaces/latest/api/API_DescribeWorkspaceDirectories.html

        :stability: experimental
        '''
        return typing.cast("Workspaces", jsii.invoke(self, "toDescribeWorkspaceDirectories", []))

    @jsii.member(jsii_name="toDescribeWorkspaceImagePermissions")
    def to_describe_workspace_image_permissions(self) -> "Workspaces":
        '''(experimental) Grants permission to retrieve information about WorkSpace image permissions.

        Access Level: Read

        https://docs.aws.amazon.com/workspaces/latest/api/API_DescribeWorkspaceImagePermissions.html

        :stability: experimental
        '''
        return typing.cast("Workspaces", jsii.invoke(self, "toDescribeWorkspaceImagePermissions", []))

    @jsii.member(jsii_name="toDescribeWorkspaceImages")
    def to_describe_workspace_images(self) -> "Workspaces":
        '''(experimental) Grants permission to retrieve information about WorkSpace images.

        Access Level: List

        https://docs.aws.amazon.com/workspaces/latest/api/API_DescribeWorkspaceImages.html

        :stability: experimental
        '''
        return typing.cast("Workspaces", jsii.invoke(self, "toDescribeWorkspaceImages", []))

    @jsii.member(jsii_name="toDescribeWorkspaces")
    def to_describe_workspaces(self) -> "Workspaces":
        '''(experimental) Grants permission to obtain information about WorkSpaces.

        Access Level: List

        https://docs.aws.amazon.com/workspaces/latest/api/API_DescribeWorkspaces.html

        :stability: experimental
        '''
        return typing.cast("Workspaces", jsii.invoke(self, "toDescribeWorkspaces", []))

    @jsii.member(jsii_name="toDescribeWorkspacesConnectionStatus")
    def to_describe_workspaces_connection_status(self) -> "Workspaces":
        '''(experimental) Grants permission to obtain the connection status of WorkSpaces.

        Access Level: Read

        https://docs.aws.amazon.com/workspaces/latest/api/API_DescribeWorkspacesConnectionStatus.html

        :stability: experimental
        '''
        return typing.cast("Workspaces", jsii.invoke(self, "toDescribeWorkspacesConnectionStatus", []))

    @jsii.member(jsii_name="toDescribeWorkspaceSnapshots")
    def to_describe_workspace_snapshots(self) -> "Workspaces":
        '''(experimental) Grants permission to retrieve information about WorkSpace snapshots.

        Access Level: List

        https://docs.aws.amazon.com/workspaces/latest/api/API_DescribeWorkspaceSnapshots.html

        :stability: experimental
        '''
        return typing.cast("Workspaces", jsii.invoke(self, "toDescribeWorkspaceSnapshots", []))

    @jsii.member(jsii_name="toDisassociateConnectionAlias")
    def to_disassociate_connection_alias(self) -> "Workspaces":
        '''(experimental) Grants permission to disassociate connection aliases from directories.

        Access Level: Write

        https://docs.aws.amazon.com/workspaces/latest/api/API_DisassociateConnectionAlias.html

        :stability: experimental
        '''
        return typing.cast("Workspaces", jsii.invoke(self, "toDisassociateConnectionAlias", []))

    @jsii.member(jsii_name="toDisassociateIpGroups")
    def to_disassociate_ip_groups(self) -> "Workspaces":
        '''(experimental) Grants permission to disassociate IP access control groups from directories.

        Access Level: Write

        https://docs.aws.amazon.com/workspaces/latest/api/API_DisassociateIpGroups.html

        :stability: experimental
        '''
        return typing.cast("Workspaces", jsii.invoke(self, "toDisassociateIpGroups", []))

    @jsii.member(jsii_name="toImportClientBranding")
    def to_import_client_branding(self) -> "Workspaces":
        '''(experimental) Grants permission to import AWS WorkSpaces Client branding data within a directory.

        Access Level: Write

        https://docs.aws.amazon.com/workspaces/latest/api/API_ImportClientBranding.html

        :stability: experimental
        '''
        return typing.cast("Workspaces", jsii.invoke(self, "toImportClientBranding", []))

    @jsii.member(jsii_name="toImportWorkspaceImage")
    def to_import_workspace_image(self) -> "Workspaces":
        '''(experimental) Grants permission to import Bring Your Own License (BYOL) images into Amazon WorkSpaces.

        Access Level: Write

        Dependent actions:

        - ec2:DescribeImages
        - ec2:ModifyImageAttribute

        https://docs.aws.amazon.com/workspaces/latest/api/API_ImportWorkspaceImage.html

        :stability: experimental
        '''
        return typing.cast("Workspaces", jsii.invoke(self, "toImportWorkspaceImage", []))

    @jsii.member(jsii_name="toListAvailableManagementCidrRanges")
    def to_list_available_management_cidr_ranges(self) -> "Workspaces":
        '''(experimental) Grants permission to list the available CIDR ranges for enabling Bring Your Own License (BYOL) for WorkSpaces accounts.

        Access Level: List

        https://docs.aws.amazon.com/workspaces/latest/api/API_ListAvailableManagementCidrRanges.html

        :stability: experimental
        '''
        return typing.cast("Workspaces", jsii.invoke(self, "toListAvailableManagementCidrRanges", []))

    @jsii.member(jsii_name="toMigrateWorkspace")
    def to_migrate_workspace(self) -> "Workspaces":
        '''(experimental) Grants permission to migrate WorkSpaces.

        Access Level: Write

        https://docs.aws.amazon.com/workspaces/latest/api/API_MigrateWorkspace.html

        :stability: experimental
        '''
        return typing.cast("Workspaces", jsii.invoke(self, "toMigrateWorkspace", []))

    @jsii.member(jsii_name="toModifyAccount")
    def to_modify_account(self) -> "Workspaces":
        '''(experimental) Grants permission to modify the configuration of Bring Your Own License (BYOL) for WorkSpaces accounts.

        Access Level: Write

        https://docs.aws.amazon.com/workspaces/latest/api/API_ModifyAccount.html

        :stability: experimental
        '''
        return typing.cast("Workspaces", jsii.invoke(self, "toModifyAccount", []))

    @jsii.member(jsii_name="toModifyCertificateBasedAuthProperties")
    def to_modify_certificate_based_auth_properties(self) -> "Workspaces":
        '''(experimental) Grants permission to modify the certificate-based authorization properties of a directory.

        Access Level: Write

        https://docs.aws.amazon.com/workspaces/latest/api/API_ModifyCertificateBasedAuthProperties.html

        :stability: experimental
        '''
        return typing.cast("Workspaces", jsii.invoke(self, "toModifyCertificateBasedAuthProperties", []))

    @jsii.member(jsii_name="toModifyClientProperties")
    def to_modify_client_properties(self) -> "Workspaces":
        '''(experimental) Grants permission to modify the properties of WorkSpaces clients.

        Access Level: Write

        https://docs.aws.amazon.com/workspaces/latest/api/API_ModifyClientProperties.html

        :stability: experimental
        '''
        return typing.cast("Workspaces", jsii.invoke(self, "toModifyClientProperties", []))

    @jsii.member(jsii_name="toModifySamlProperties")
    def to_modify_saml_properties(self) -> "Workspaces":
        '''(experimental) Grants permission to modify the SAML properties of a directory.

        Access Level: Write

        https://docs.aws.amazon.com/workspaces/latest/api/API_ModifySamlProperties.html

        :stability: experimental
        '''
        return typing.cast("Workspaces", jsii.invoke(self, "toModifySamlProperties", []))

    @jsii.member(jsii_name="toModifySelfservicePermissions")
    def to_modify_selfservice_permissions(self) -> "Workspaces":
        '''(experimental) Grants permission to modify the self-service WorkSpace management capabilities for your users.

        Access Level: Permissions management

        https://docs.aws.amazon.com/workspaces/latest/api/API_ModifySelfservicePermissions.html

        :stability: experimental
        '''
        return typing.cast("Workspaces", jsii.invoke(self, "toModifySelfservicePermissions", []))

    @jsii.member(jsii_name="toModifyWorkspaceAccessProperties")
    def to_modify_workspace_access_properties(self) -> "Workspaces":
        '''(experimental) Grants permission to specify which devices and operating systems users can use to access their WorkSpaces.

        Access Level: Write

        https://docs.aws.amazon.com/workspaces/latest/api/API_ModifyWorkspaceAccessProperties.html

        :stability: experimental
        '''
        return typing.cast("Workspaces", jsii.invoke(self, "toModifyWorkspaceAccessProperties", []))

    @jsii.member(jsii_name="toModifyWorkspaceCreationProperties")
    def to_modify_workspace_creation_properties(self) -> "Workspaces":
        '''(experimental) Grants permission to modify the default properties used to create WorkSpaces.

        Access Level: Write

        https://docs.aws.amazon.com/workspaces/latest/api/API_ModifyWorkspaceCreationProperties.html

        :stability: experimental
        '''
        return typing.cast("Workspaces", jsii.invoke(self, "toModifyWorkspaceCreationProperties", []))

    @jsii.member(jsii_name="toModifyWorkspaceProperties")
    def to_modify_workspace_properties(self) -> "Workspaces":
        '''(experimental) Grants permission to modify WorkSpace properties, including the running mode and the AutoStop period.

        Access Level: Write

        https://docs.aws.amazon.com/workspaces/latest/api/API_ModifyWorkspaceProperties.html

        :stability: experimental
        '''
        return typing.cast("Workspaces", jsii.invoke(self, "toModifyWorkspaceProperties", []))

    @jsii.member(jsii_name="toModifyWorkspaceState")
    def to_modify_workspace_state(self) -> "Workspaces":
        '''(experimental) Grants permission to modify the state of WorkSpaces.

        Access Level: Write

        https://docs.aws.amazon.com/workspaces/latest/api/API_ModifyWorkspaceState.html

        :stability: experimental
        '''
        return typing.cast("Workspaces", jsii.invoke(self, "toModifyWorkspaceState", []))

    @jsii.member(jsii_name="toRebootWorkspaces")
    def to_reboot_workspaces(self) -> "Workspaces":
        '''(experimental) Grants permission to reboot WorkSpaces.

        Access Level: Write

        https://docs.aws.amazon.com/workspaces/latest/api/API_RebootWorkspaces.html

        :stability: experimental
        '''
        return typing.cast("Workspaces", jsii.invoke(self, "toRebootWorkspaces", []))

    @jsii.member(jsii_name="toRebuildWorkspaces")
    def to_rebuild_workspaces(self) -> "Workspaces":
        '''(experimental) Grants permission to rebuild WorkSpaces.

        Access Level: Write

        https://docs.aws.amazon.com/workspaces/latest/api/API_RebuildWorkspaces.html

        :stability: experimental
        '''
        return typing.cast("Workspaces", jsii.invoke(self, "toRebuildWorkspaces", []))

    @jsii.member(jsii_name="toRegisterWorkspaceDirectory")
    def to_register_workspace_directory(self) -> "Workspaces":
        '''(experimental) Grants permission to register directories for use with Amazon WorkSpaces.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/workspaces/latest/api/API_RegisterWorkspaceDirectory.html

        :stability: experimental
        '''
        return typing.cast("Workspaces", jsii.invoke(self, "toRegisterWorkspaceDirectory", []))

    @jsii.member(jsii_name="toRestoreWorkspace")
    def to_restore_workspace(self) -> "Workspaces":
        '''(experimental) Grants permission to restore WorkSpaces.

        Access Level: Write

        https://docs.aws.amazon.com/workspaces/latest/api/API_RestoreWorkspace.html

        :stability: experimental
        '''
        return typing.cast("Workspaces", jsii.invoke(self, "toRestoreWorkspace", []))

    @jsii.member(jsii_name="toRevokeIpRules")
    def to_revoke_ip_rules(self) -> "Workspaces":
        '''(experimental) Grants permission to remove rules from IP access control groups.

        Access Level: Write

        https://docs.aws.amazon.com/workspaces/latest/api/API_RevokeIpRules.html

        :stability: experimental
        '''
        return typing.cast("Workspaces", jsii.invoke(self, "toRevokeIpRules", []))

    @jsii.member(jsii_name="toStartWorkspaces")
    def to_start_workspaces(self) -> "Workspaces":
        '''(experimental) Grants permission to start AutoStop WorkSpaces.

        Access Level: Write

        https://docs.aws.amazon.com/workspaces/latest/api/API_StartWorkspaces.html

        :stability: experimental
        '''
        return typing.cast("Workspaces", jsii.invoke(self, "toStartWorkspaces", []))

    @jsii.member(jsii_name="toStopWorkspaces")
    def to_stop_workspaces(self) -> "Workspaces":
        '''(experimental) Grants permission to stop AutoStop WorkSpaces.

        Access Level: Write

        https://docs.aws.amazon.com/workspaces/latest/api/API_StopWorkspaces.html

        :stability: experimental
        '''
        return typing.cast("Workspaces", jsii.invoke(self, "toStopWorkspaces", []))

    @jsii.member(jsii_name="toStream")
    def to_stream(self) -> "Workspaces":
        '''(experimental) Grants permission to federated users to sign in by using their existing credentials and stream their workspace.

        Access Level: Write

        Possible conditions:

        - .ifUserId()

        https://docs.aws.amazon.com/workspaces/latest/api/API_Stream.html

        :stability: experimental
        '''
        return typing.cast("Workspaces", jsii.invoke(self, "toStream", []))

    @jsii.member(jsii_name="toTerminateWorkspaces")
    def to_terminate_workspaces(self) -> "Workspaces":
        '''(experimental) Grants permission to terminate WorkSpaces.

        Access Level: Write

        https://docs.aws.amazon.com/workspaces/latest/api/API_TerminateWorkspaces.html

        :stability: experimental
        '''
        return typing.cast("Workspaces", jsii.invoke(self, "toTerminateWorkspaces", []))

    @jsii.member(jsii_name="toUpdateConnectClientAddIn")
    def to_update_connect_client_add_in(self) -> "Workspaces":
        '''(experimental) Grants permission to update an Amazon Connect client add-in.

        Use this action to update the name and endpoint URL of an Amazon Connect client add-in

        Access Level: Write

        https://docs.aws.amazon.com/workspaces/latest/api/API_UpdateConnectClientAddIn.html

        :stability: experimental
        '''
        return typing.cast("Workspaces", jsii.invoke(self, "toUpdateConnectClientAddIn", []))

    @jsii.member(jsii_name="toUpdateConnectionAliasPermission")
    def to_update_connection_alias_permission(self) -> "Workspaces":
        '''(experimental) Grants permission to share or unshare connection aliases with other accounts.

        Access Level: Permissions management

        https://docs.aws.amazon.com/workspaces/latest/api/API_UpdateConnectionAliasPermission.html

        :stability: experimental
        '''
        return typing.cast("Workspaces", jsii.invoke(self, "toUpdateConnectionAliasPermission", []))

    @jsii.member(jsii_name="toUpdateRulesOfIpGroup")
    def to_update_rules_of_ip_group(self) -> "Workspaces":
        '''(experimental) Grants permission to replace rules for IP access control groups.

        Access Level: Write

        https://docs.aws.amazon.com/workspaces/latest/api/API_UpdateRulesOfIpGroup.html

        :stability: experimental
        '''
        return typing.cast("Workspaces", jsii.invoke(self, "toUpdateRulesOfIpGroup", []))

    @jsii.member(jsii_name="toUpdateWorkspaceBundle")
    def to_update_workspace_bundle(self) -> "Workspaces":
        '''(experimental) Grants permission to update the WorkSpace images used in WorkSpace bundles.

        Access Level: Write

        https://docs.aws.amazon.com/workspaces/latest/api/API_UpdateWorkspaceBundle.html

        :stability: experimental
        '''
        return typing.cast("Workspaces", jsii.invoke(self, "toUpdateWorkspaceBundle", []))

    @jsii.member(jsii_name="toUpdateWorkspaceImagePermission")
    def to_update_workspace_image_permission(self) -> "Workspaces":
        '''(experimental) Grants permission to share or unshare WorkSpace images with other accounts by specifying whether other accounts have permission to copy the image.

        Access Level: Permissions management

        https://docs.aws.amazon.com/workspaces/latest/api/API_UpdateWorkspaceImagePermission.html

        :stability: experimental
        '''
        return typing.cast("Workspaces", jsii.invoke(self, "toUpdateWorkspaceImagePermission", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__56acab34efca7b88274db7f19646ad578dac75a4d96bb8a2e4273da7dc2feca4)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0a1a26277a60c9ca917f05c46815fb65e709fa961e1f45d12fe918ab3e77d280)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class WorkspacesWeb(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.WorkspacesWeb",
):
    '''(experimental) Statement provider for service `workspaces-web <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonworkspacesweb.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `workspaces-web <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonworkspacesweb.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onBrowserSettings")
    def on_browser_settings(
        self,
        browser_settings_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "WorkspacesWeb":
        '''(experimental) Adds a resource of type browserSettings to the statement.

        https://docs.aws.amazon.com/workspaces-web/latest/APIReference/API_CreateBrowserSettings.html

        :param browser_settings_id: - Identifier for the browserSettingsId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d246f38a1b07f4a0cd60aa268f7acf9dd499cf7be8a1f4542ea3c2a1675bea7f)
            check_type(argname="argument browser_settings_id", value=browser_settings_id, expected_type=type_hints["browser_settings_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("WorkspacesWeb", jsii.invoke(self, "onBrowserSettings", [browser_settings_id, account, region, partition]))

    @jsii.member(jsii_name="onNetworkSettings")
    def on_network_settings(
        self,
        network_settings_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "WorkspacesWeb":
        '''(experimental) Adds a resource of type networkSettings to the statement.

        https://docs.aws.amazon.com/workspaces-web/latest/APIReference/API_CreateNetworkSettings.html

        :param network_settings_id: - Identifier for the networkSettingsId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5534bea05f39e826cc04f83586cf239fddff1616603ea3df05f5f04ec072a140)
            check_type(argname="argument network_settings_id", value=network_settings_id, expected_type=type_hints["network_settings_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("WorkspacesWeb", jsii.invoke(self, "onNetworkSettings", [network_settings_id, account, region, partition]))

    @jsii.member(jsii_name="onPortal")
    def on_portal(
        self,
        portal_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "WorkspacesWeb":
        '''(experimental) Adds a resource of type portal to the statement.

        https://docs.aws.amazon.com/workspaces-web/latest/APIReference/API_CreatePortal.html

        :param portal_id: - Identifier for the portalId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c06fc6641cdc46d52ef733acb754a3932858f3d5927946e42d9c17bc67b039ee)
            check_type(argname="argument portal_id", value=portal_id, expected_type=type_hints["portal_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("WorkspacesWeb", jsii.invoke(self, "onPortal", [portal_id, account, region, partition]))

    @jsii.member(jsii_name="onTrustStore")
    def on_trust_store(
        self,
        trust_store_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "WorkspacesWeb":
        '''(experimental) Adds a resource of type trustStore to the statement.

        https://docs.aws.amazon.com/workspaces-web/latest/APIReference/API_CreateTrustStore.html

        :param trust_store_id: - Identifier for the trustStoreId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e0beec7850656c3972dd51fa5949a5d65e6da6b979466eaec8037ea82d116ede)
            check_type(argname="argument trust_store_id", value=trust_store_id, expected_type=type_hints["trust_store_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("WorkspacesWeb", jsii.invoke(self, "onTrustStore", [trust_store_id, account, region, partition]))

    @jsii.member(jsii_name="onUserAccessLoggingSettings")
    def on_user_access_logging_settings(
        self,
        user_access_logging_settings_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "WorkspacesWeb":
        '''(experimental) Adds a resource of type userAccessLoggingSettings to the statement.

        https://docs.aws.amazon.com/workspaces-web/latest/APIReference/API_CreateUserAccessLoggingSettings.html

        :param user_access_logging_settings_id: - Identifier for the userAccessLoggingSettingsId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d0206bbe0d89194bb06d5377cc5670b5e27ef3ec8b4b7687742b3b60c038f7e0)
            check_type(argname="argument user_access_logging_settings_id", value=user_access_logging_settings_id, expected_type=type_hints["user_access_logging_settings_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("WorkspacesWeb", jsii.invoke(self, "onUserAccessLoggingSettings", [user_access_logging_settings_id, account, region, partition]))

    @jsii.member(jsii_name="onUserSettings")
    def on_user_settings(
        self,
        user_settings_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "WorkspacesWeb":
        '''(experimental) Adds a resource of type userSettings to the statement.

        https://docs.aws.amazon.com/workspaces-web/latest/APIReference/API_CreateUserSettings.html

        :param user_settings_id: - Identifier for the userSettingsId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7fe37c06c207b6beb35fd565325787e0928071a15123d596c71df1ffb7ebdde5)
            check_type(argname="argument user_settings_id", value=user_settings_id, expected_type=type_hints["user_settings_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("WorkspacesWeb", jsii.invoke(self, "onUserSettings", [user_settings_id, account, region, partition]))

    @jsii.member(jsii_name="toAssociateBrowserSettings")
    def to_associate_browser_settings(self) -> "WorkspacesWeb":
        '''(experimental) Grants permission to associate browser settings to web portals.

        Access Level: Write

        https://docs.aws.amazon.com/workspaces-web/latest/APIReference/API_AssociateBrowserSettings.html

        :stability: experimental
        '''
        return typing.cast("WorkspacesWeb", jsii.invoke(self, "toAssociateBrowserSettings", []))

    @jsii.member(jsii_name="toAssociateNetworkSettings")
    def to_associate_network_settings(self) -> "WorkspacesWeb":
        '''(experimental) Grants permission to associate network settings to web portals.

        Access Level: Write

        Dependent actions:

        - ec2:CreateNetworkInterface
        - ec2:CreateNetworkInterfacePermission
        - ec2:CreateTags
        - ec2:DeleteNetworkInterface
        - ec2:DeleteNetworkInterfacePermission
        - ec2:ModifyNetworkInterfaceAttribute

        https://docs.aws.amazon.com/workspaces-web/latest/APIReference/API_AssociateNetworkSettings.html

        :stability: experimental
        '''
        return typing.cast("WorkspacesWeb", jsii.invoke(self, "toAssociateNetworkSettings", []))

    @jsii.member(jsii_name="toAssociateTrustStore")
    def to_associate_trust_store(self) -> "WorkspacesWeb":
        '''(experimental) Grants permission to associate trust stores with web portals.

        Access Level: Write

        https://docs.aws.amazon.com/workspaces-web/latest/APIReference/API_AssociateTrustStore.html

        :stability: experimental
        '''
        return typing.cast("WorkspacesWeb", jsii.invoke(self, "toAssociateTrustStore", []))

    @jsii.member(jsii_name="toAssociateUserAccessLoggingSettings")
    def to_associate_user_access_logging_settings(self) -> "WorkspacesWeb":
        '''(experimental) Grants permission to associate user access logging settings with web portals.

        Access Level: Write

        Dependent actions:

        - kinesis:PutRecord
        - kinesis:PutRecords

        https://docs.aws.amazon.com/workspaces-web/latest/APIReference/API_AssociateUserAccessLoggingSettings.html

        :stability: experimental
        '''
        return typing.cast("WorkspacesWeb", jsii.invoke(self, "toAssociateUserAccessLoggingSettings", []))

    @jsii.member(jsii_name="toAssociateUserSettings")
    def to_associate_user_settings(self) -> "WorkspacesWeb":
        '''(experimental) Grants permission to associate user settings with web portals.

        Access Level: Write

        https://docs.aws.amazon.com/workspaces-web/latest/APIReference/API_AssociateUserSettings.html

        :stability: experimental
        '''
        return typing.cast("WorkspacesWeb", jsii.invoke(self, "toAssociateUserSettings", []))

    @jsii.member(jsii_name="toCreateBrowserSettings")
    def to_create_browser_settings(self) -> "WorkspacesWeb":
        '''(experimental) Grants permission to create browser settings.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        Dependent actions:

        - kms:CreateGrant
        - kms:Decrypt
        - kms:DescribeKey
        - kms:GenerateDataKey

        https://docs.aws.amazon.com/workspaces-web/latest/APIReference/API_CreateBrowserSettings.html

        :stability: experimental
        '''
        return typing.cast("WorkspacesWeb", jsii.invoke(self, "toCreateBrowserSettings", []))

    @jsii.member(jsii_name="toCreateIdentityProvider")
    def to_create_identity_provider(self) -> "WorkspacesWeb":
        '''(experimental) Grants permission to create identity providers.

        Access Level: Write

        https://docs.aws.amazon.com/workspaces-web/latest/APIReference/API_CreateIdentityProvider.html

        :stability: experimental
        '''
        return typing.cast("WorkspacesWeb", jsii.invoke(self, "toCreateIdentityProvider", []))

    @jsii.member(jsii_name="toCreateNetworkSettings")
    def to_create_network_settings(self) -> "WorkspacesWeb":
        '''(experimental) Grants permission to create network settings.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        Dependent actions:

        - iam:CreateServiceLinkedRole

        https://docs.aws.amazon.com/workspaces-web/latest/APIReference/API_CreateNetworkSettings.html

        :stability: experimental
        '''
        return typing.cast("WorkspacesWeb", jsii.invoke(self, "toCreateNetworkSettings", []))

    @jsii.member(jsii_name="toCreatePortal")
    def to_create_portal(self) -> "WorkspacesWeb":
        '''(experimental) Grants permission to create web portals.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        Dependent actions:

        - iam:CreateServiceLinkedRole
        - kms:CreateGrant
        - kms:Decrypt
        - kms:DescribeKey
        - kms:GenerateDataKey

        https://docs.aws.amazon.com/workspaces-web/latest/APIReference/API_CreatePortal.html

        :stability: experimental
        '''
        return typing.cast("WorkspacesWeb", jsii.invoke(self, "toCreatePortal", []))

    @jsii.member(jsii_name="toCreateTrustStore")
    def to_create_trust_store(self) -> "WorkspacesWeb":
        '''(experimental) Grants permission to create trust stores.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/workspaces-web/latest/APIReference/API_CreateTrustStore.html

        :stability: experimental
        '''
        return typing.cast("WorkspacesWeb", jsii.invoke(self, "toCreateTrustStore", []))

    @jsii.member(jsii_name="toCreateUserAccessLoggingSettings")
    def to_create_user_access_logging_settings(self) -> "WorkspacesWeb":
        '''(experimental) Grants permission to create user access logging settings.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/workspaces-web/latest/APIReference/API_CreateUserAccessLoggingSettings.html

        :stability: experimental
        '''
        return typing.cast("WorkspacesWeb", jsii.invoke(self, "toCreateUserAccessLoggingSettings", []))

    @jsii.member(jsii_name="toCreateUserSettings")
    def to_create_user_settings(self) -> "WorkspacesWeb":
        '''(experimental) Grants permission to create user settings.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/workspaces-web/latest/APIReference/API_CreateUserSettings.html

        :stability: experimental
        '''
        return typing.cast("WorkspacesWeb", jsii.invoke(self, "toCreateUserSettings", []))

    @jsii.member(jsii_name="toDeleteBrowserSettings")
    def to_delete_browser_settings(self) -> "WorkspacesWeb":
        '''(experimental) Grants permission to delete browser settings.

        Access Level: Write

        https://docs.aws.amazon.com/workspaces-web/latest/APIReference/API_DeleteBrowserSettings.html

        :stability: experimental
        '''
        return typing.cast("WorkspacesWeb", jsii.invoke(self, "toDeleteBrowserSettings", []))

    @jsii.member(jsii_name="toDeleteIdentityProvider")
    def to_delete_identity_provider(self) -> "WorkspacesWeb":
        '''(experimental) Grants permission to delete identity providers.

        Access Level: Write

        https://docs.aws.amazon.com/workspaces-web/latest/APIReference/API_DeleteIdentityProvider.html

        :stability: experimental
        '''
        return typing.cast("WorkspacesWeb", jsii.invoke(self, "toDeleteIdentityProvider", []))

    @jsii.member(jsii_name="toDeleteNetworkSettings")
    def to_delete_network_settings(self) -> "WorkspacesWeb":
        '''(experimental) Grants permission to delete network settings.

        Access Level: Write

        https://docs.aws.amazon.com/workspaces-web/latest/APIReference/API_DeleteNetworkSettings.html

        :stability: experimental
        '''
        return typing.cast("WorkspacesWeb", jsii.invoke(self, "toDeleteNetworkSettings", []))

    @jsii.member(jsii_name="toDeletePortal")
    def to_delete_portal(self) -> "WorkspacesWeb":
        '''(experimental) Grants permission to delete web portals.

        Access Level: Write

        https://docs.aws.amazon.com/workspaces-web/latest/APIReference/API_DeletePortal.html

        :stability: experimental
        '''
        return typing.cast("WorkspacesWeb", jsii.invoke(self, "toDeletePortal", []))

    @jsii.member(jsii_name="toDeleteTrustStore")
    def to_delete_trust_store(self) -> "WorkspacesWeb":
        '''(experimental) Grants permission to delete trust stores.

        Access Level: Write

        https://docs.aws.amazon.com/workspaces-web/latest/APIReference/API_DeleteTrustStore.html

        :stability: experimental
        '''
        return typing.cast("WorkspacesWeb", jsii.invoke(self, "toDeleteTrustStore", []))

    @jsii.member(jsii_name="toDeleteUserAccessLoggingSettings")
    def to_delete_user_access_logging_settings(self) -> "WorkspacesWeb":
        '''(experimental) Grants permission to delete user access logging settings.

        Access Level: Write

        https://docs.aws.amazon.com/workspaces-web/latest/APIReference/API_DeleteUserAccessLoggingSettings.html

        :stability: experimental
        '''
        return typing.cast("WorkspacesWeb", jsii.invoke(self, "toDeleteUserAccessLoggingSettings", []))

    @jsii.member(jsii_name="toDeleteUserSettings")
    def to_delete_user_settings(self) -> "WorkspacesWeb":
        '''(experimental) Grants permission to delete user settings.

        Access Level: Write

        https://docs.aws.amazon.com/workspaces-web/latest/APIReference/API_DeleteUserSettings.html

        :stability: experimental
        '''
        return typing.cast("WorkspacesWeb", jsii.invoke(self, "toDeleteUserSettings", []))

    @jsii.member(jsii_name="toDisassociateBrowserSettings")
    def to_disassociate_browser_settings(self) -> "WorkspacesWeb":
        '''(experimental) Grants permission to disassociate browser settings from web portals.

        Access Level: Write

        https://docs.aws.amazon.com/workspaces-web/latest/APIReference/API_DisassociateBrowserSettings.html

        :stability: experimental
        '''
        return typing.cast("WorkspacesWeb", jsii.invoke(self, "toDisassociateBrowserSettings", []))

    @jsii.member(jsii_name="toDisassociateNetworkSettings")
    def to_disassociate_network_settings(self) -> "WorkspacesWeb":
        '''(experimental) Grants permission to disassociate network settings from web portals.

        Access Level: Write

        https://docs.aws.amazon.com/workspaces-web/latest/APIReference/API_DisassociateNetworkSettings.html

        :stability: experimental
        '''
        return typing.cast("WorkspacesWeb", jsii.invoke(self, "toDisassociateNetworkSettings", []))

    @jsii.member(jsii_name="toDisassociateTrustStore")
    def to_disassociate_trust_store(self) -> "WorkspacesWeb":
        '''(experimental) Grants permission to disassociate trust stores from web portals.

        Access Level: Write

        https://docs.aws.amazon.com/workspaces-web/latest/APIReference/API_DisassociateTrustStore.html

        :stability: experimental
        '''
        return typing.cast("WorkspacesWeb", jsii.invoke(self, "toDisassociateTrustStore", []))

    @jsii.member(jsii_name="toDisassociateUserAccessLoggingSettings")
    def to_disassociate_user_access_logging_settings(self) -> "WorkspacesWeb":
        '''(experimental) Grants permission to disassociate user access logging settings from web portals.

        Access Level: Write

        https://docs.aws.amazon.com/workspaces-web/latest/APIReference/API_DisassociateUserAccessLoggingSettings.html

        :stability: experimental
        '''
        return typing.cast("WorkspacesWeb", jsii.invoke(self, "toDisassociateUserAccessLoggingSettings", []))

    @jsii.member(jsii_name="toDisassociateUserSettings")
    def to_disassociate_user_settings(self) -> "WorkspacesWeb":
        '''(experimental) Grants permission to disassociate user settings from web portals.

        Access Level: Write

        https://docs.aws.amazon.com/workspaces-web/latest/APIReference/API_DisassociateUserSettings.html

        :stability: experimental
        '''
        return typing.cast("WorkspacesWeb", jsii.invoke(self, "toDisassociateUserSettings", []))

    @jsii.member(jsii_name="toGetBrowserSettings")
    def to_get_browser_settings(self) -> "WorkspacesWeb":
        '''(experimental) Grants permission to get details on browser settings.

        Access Level: Read

        https://docs.aws.amazon.com/workspaces-web/latest/APIReference/API_GetBrowserSettings.html

        :stability: experimental
        '''
        return typing.cast("WorkspacesWeb", jsii.invoke(self, "toGetBrowserSettings", []))

    @jsii.member(jsii_name="toGetIdentityProvider")
    def to_get_identity_provider(self) -> "WorkspacesWeb":
        '''(experimental) Grants permission to get details on identity providers.

        Access Level: Read

        https://docs.aws.amazon.com/workspaces-web/latest/APIReference/API_GetIdentityProvider.html

        :stability: experimental
        '''
        return typing.cast("WorkspacesWeb", jsii.invoke(self, "toGetIdentityProvider", []))

    @jsii.member(jsii_name="toGetNetworkSettings")
    def to_get_network_settings(self) -> "WorkspacesWeb":
        '''(experimental) Grants permission to get details on network settings.

        Access Level: Read

        https://docs.aws.amazon.com/workspaces-web/latest/APIReference/API_GetNetworkSettings.html

        :stability: experimental
        '''
        return typing.cast("WorkspacesWeb", jsii.invoke(self, "toGetNetworkSettings", []))

    @jsii.member(jsii_name="toGetPortal")
    def to_get_portal(self) -> "WorkspacesWeb":
        '''(experimental) Grants permission to get details on web portals.

        Access Level: Read

        https://docs.aws.amazon.com/workspaces-web/latest/APIReference/API_GetPortal.html

        :stability: experimental
        '''
        return typing.cast("WorkspacesWeb", jsii.invoke(self, "toGetPortal", []))

    @jsii.member(jsii_name="toGetPortalServiceProviderMetadata")
    def to_get_portal_service_provider_metadata(self) -> "WorkspacesWeb":
        '''(experimental) Grants permission to get service provider metadata information for web portals.

        Access Level: Read

        https://docs.aws.amazon.com/workspaces-web/latest/APIReference/API_GetPortalServiceProviderMetadata.html

        :stability: experimental
        '''
        return typing.cast("WorkspacesWeb", jsii.invoke(self, "toGetPortalServiceProviderMetadata", []))

    @jsii.member(jsii_name="toGetTrustStore")
    def to_get_trust_store(self) -> "WorkspacesWeb":
        '''(experimental) Grants permission to get details on trust stores.

        Access Level: Read

        https://docs.aws.amazon.com/workspaces-web/latest/APIReference/API_GetTrustStore.html

        :stability: experimental
        '''
        return typing.cast("WorkspacesWeb", jsii.invoke(self, "toGetTrustStore", []))

    @jsii.member(jsii_name="toGetTrustStoreCertificate")
    def to_get_trust_store_certificate(self) -> "WorkspacesWeb":
        '''(experimental) Grants permission to get certificates from trust stores.

        Access Level: Read

        https://docs.aws.amazon.com/workspaces-web/latest/APIReference/API_GetTrustStoreCertificate.html

        :stability: experimental
        '''
        return typing.cast("WorkspacesWeb", jsii.invoke(self, "toGetTrustStoreCertificate", []))

    @jsii.member(jsii_name="toGetUserAccessLoggingSettings")
    def to_get_user_access_logging_settings(self) -> "WorkspacesWeb":
        '''(experimental) Grants permission to get details on user access logging settings.

        Access Level: Read

        https://docs.aws.amazon.com/workspaces-web/latest/APIReference/API_GetUserAccessLoggingSettings.html

        :stability: experimental
        '''
        return typing.cast("WorkspacesWeb", jsii.invoke(self, "toGetUserAccessLoggingSettings", []))

    @jsii.member(jsii_name="toGetUserSettings")
    def to_get_user_settings(self) -> "WorkspacesWeb":
        '''(experimental) Grants permission to get details on user settings.

        Access Level: Read

        https://docs.aws.amazon.com/workspaces-web/latest/APIReference/API_GetUserSettings.html

        :stability: experimental
        '''
        return typing.cast("WorkspacesWeb", jsii.invoke(self, "toGetUserSettings", []))

    @jsii.member(jsii_name="toListBrowserSettings")
    def to_list_browser_settings(self) -> "WorkspacesWeb":
        '''(experimental) Grants permission to list browser settings.

        Access Level: Read

        https://docs.aws.amazon.com/workspaces-web/latest/APIReference/API_ListBrowserSettings.html

        :stability: experimental
        '''
        return typing.cast("WorkspacesWeb", jsii.invoke(self, "toListBrowserSettings", []))

    @jsii.member(jsii_name="toListIdentityProviders")
    def to_list_identity_providers(self) -> "WorkspacesWeb":
        '''(experimental) Grants permission to list identity providers.

        Access Level: Read

        https://docs.aws.amazon.com/workspaces-web/latest/APIReference/API_ListIdentityProviders.html

        :stability: experimental
        '''
        return typing.cast("WorkspacesWeb", jsii.invoke(self, "toListIdentityProviders", []))

    @jsii.member(jsii_name="toListNetworkSettings")
    def to_list_network_settings(self) -> "WorkspacesWeb":
        '''(experimental) Grants permission to list network settings.

        Access Level: Read

        https://docs.aws.amazon.com/workspaces-web/latest/APIReference/API_ListNetworkSettings.html

        :stability: experimental
        '''
        return typing.cast("WorkspacesWeb", jsii.invoke(self, "toListNetworkSettings", []))

    @jsii.member(jsii_name="toListPortals")
    def to_list_portals(self) -> "WorkspacesWeb":
        '''(experimental) Grants permission to list web portals.

        Access Level: Read

        https://docs.aws.amazon.com/workspaces-web/latest/APIReference/API_ListPortals.html

        :stability: experimental
        '''
        return typing.cast("WorkspacesWeb", jsii.invoke(self, "toListPortals", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "WorkspacesWeb":
        '''(experimental) Grants permission to list tags for a resource.

        Access Level: Read

        https://docs.aws.amazon.com/workspaces-web/latest/APIReference/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("WorkspacesWeb", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toListTrustStoreCertificates")
    def to_list_trust_store_certificates(self) -> "WorkspacesWeb":
        '''(experimental) Grants permission to list certificates in a trust store.

        Access Level: Read

        https://docs.aws.amazon.com/workspaces-web/latest/APIReference/API_ListTrustStoreCertificates.html

        :stability: experimental
        '''
        return typing.cast("WorkspacesWeb", jsii.invoke(self, "toListTrustStoreCertificates", []))

    @jsii.member(jsii_name="toListTrustStores")
    def to_list_trust_stores(self) -> "WorkspacesWeb":
        '''(experimental) Grants permission to list trust stores.

        Access Level: Read

        https://docs.aws.amazon.com/workspaces-web/latest/APIReference/API_ListTrustStores.html

        :stability: experimental
        '''
        return typing.cast("WorkspacesWeb", jsii.invoke(self, "toListTrustStores", []))

    @jsii.member(jsii_name="toListUserAccessLoggingSettings")
    def to_list_user_access_logging_settings(self) -> "WorkspacesWeb":
        '''(experimental) Grants permission to list user access logging settings.

        Access Level: Read

        https://docs.aws.amazon.com/workspaces-web/latest/APIReference/API_ListUserAccessLoggingSettings.html

        :stability: experimental
        '''
        return typing.cast("WorkspacesWeb", jsii.invoke(self, "toListUserAccessLoggingSettings", []))

    @jsii.member(jsii_name="toListUserSettings")
    def to_list_user_settings(self) -> "WorkspacesWeb":
        '''(experimental) Grants permission to list user settings.

        Access Level: Read

        https://docs.aws.amazon.com/workspaces-web/latest/APIReference/API_ListUserSettings.html

        :stability: experimental
        '''
        return typing.cast("WorkspacesWeb", jsii.invoke(self, "toListUserSettings", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "WorkspacesWeb":
        '''(experimental) Grants permission to add one or more tags to a resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/workspaces-web/latest/APIReference/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("WorkspacesWeb", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "WorkspacesWeb":
        '''(experimental) Grants permission to remove one or more tags from a resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/workspaces-web/latest/APIReference/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("WorkspacesWeb", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateBrowserSettings")
    def to_update_browser_settings(self) -> "WorkspacesWeb":
        '''(experimental) Grants permission to update browser settings.

        Access Level: Write

        https://docs.aws.amazon.com/workspaces-web/latest/APIReference/API_UpdateBrowserSettings.html

        :stability: experimental
        '''
        return typing.cast("WorkspacesWeb", jsii.invoke(self, "toUpdateBrowserSettings", []))

    @jsii.member(jsii_name="toUpdateIdentityProvider")
    def to_update_identity_provider(self) -> "WorkspacesWeb":
        '''(experimental) Grants permission to update identity provider.

        Access Level: Write

        https://docs.aws.amazon.com/workspaces-web/latest/APIReference/API_UpdateIdentityProvider.html

        :stability: experimental
        '''
        return typing.cast("WorkspacesWeb", jsii.invoke(self, "toUpdateIdentityProvider", []))

    @jsii.member(jsii_name="toUpdateNetworkSettings")
    def to_update_network_settings(self) -> "WorkspacesWeb":
        '''(experimental) Grants permission to update network settings.

        Access Level: Write

        Dependent actions:

        - ec2:CreateNetworkInterface
        - ec2:CreateNetworkInterfacePermission
        - ec2:CreateTags
        - ec2:DeleteNetworkInterface
        - ec2:DeleteNetworkInterfacePermission
        - ec2:ModifyNetworkInterfaceAttribute

        https://docs.aws.amazon.com/workspaces-web/latest/APIReference/API_UpdateNetworkSettings.html

        :stability: experimental
        '''
        return typing.cast("WorkspacesWeb", jsii.invoke(self, "toUpdateNetworkSettings", []))

    @jsii.member(jsii_name="toUpdatePortal")
    def to_update_portal(self) -> "WorkspacesWeb":
        '''(experimental) Grants permission to update web portals.

        Access Level: Write

        https://docs.aws.amazon.com/workspaces-web/latest/APIReference/API_UpdatePortal.html

        :stability: experimental
        '''
        return typing.cast("WorkspacesWeb", jsii.invoke(self, "toUpdatePortal", []))

    @jsii.member(jsii_name="toUpdateTrustStore")
    def to_update_trust_store(self) -> "WorkspacesWeb":
        '''(experimental) Grants permission to update trust stores.

        Access Level: Write

        https://docs.aws.amazon.com/workspaces-web/latest/APIReference/API_UpdateTrustStore.html

        :stability: experimental
        '''
        return typing.cast("WorkspacesWeb", jsii.invoke(self, "toUpdateTrustStore", []))

    @jsii.member(jsii_name="toUpdateUserAccessLoggingSettings")
    def to_update_user_access_logging_settings(self) -> "WorkspacesWeb":
        '''(experimental) Grants permission to update user access logging settings.

        Access Level: Write

        Dependent actions:

        - kinesis:PutRecord
        - kinesis:PutRecords

        https://docs.aws.amazon.com/workspaces-web/latest/APIReference/API_UpdateUserAccessLoggingSettings.html

        :stability: experimental
        '''
        return typing.cast("WorkspacesWeb", jsii.invoke(self, "toUpdateUserAccessLoggingSettings", []))

    @jsii.member(jsii_name="toUpdateUserSettings")
    def to_update_user_settings(self) -> "WorkspacesWeb":
        '''(experimental) Grants permission to update user settings.

        Access Level: Write

        https://docs.aws.amazon.com/workspaces-web/latest/APIReference/API_UpdateUserSettings.html

        :stability: experimental
        '''
        return typing.cast("WorkspacesWeb", jsii.invoke(self, "toUpdateUserSettings", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6e3831b20c655e12f4851744ff2104d4870c1722a75ee88ddccc578cb37f31eb)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__73c75a025197ec7b3a3935ba1eaf39f035b5630889ac4b1fcd7c7ff209b6658d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Xray(PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Xray"):
    '''(experimental) Statement provider for service `xray <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsx-ray.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `xray <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsx-ray.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onGroup")
    def on_group(
        self,
        group_name: builtins.str,
        id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Xray":
        '''(experimental) Adds a resource of type group to the statement.

        https://docs.aws.amazon.com/xray/latest/devguide/xray-concepts.html#xray-concepts-groups

        :param group_name: - Identifier for the groupName.
        :param id: - Identifier for the id.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__56360d65d155fdd9b85f88757436d6711d4a08ff4cc12bc368b305b99fbe142d)
            check_type(argname="argument group_name", value=group_name, expected_type=type_hints["group_name"])
            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Xray", jsii.invoke(self, "onGroup", [group_name, id, account, region, partition]))

    @jsii.member(jsii_name="onSamplingRule")
    def on_sampling_rule(
        self,
        sampling_rule_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Xray":
        '''(experimental) Adds a resource of type sampling-rule to the statement.

        https://docs.aws.amazon.com/xray/latest/devguide/xray-concepts.html#xray-concepts-sampling

        :param sampling_rule_name: - Identifier for the samplingRuleName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6995b439f88218d8a353ad3708d066d6f4420039f9776796250dd9011dc26bd4)
            check_type(argname="argument sampling_rule_name", value=sampling_rule_name, expected_type=type_hints["sampling_rule_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Xray", jsii.invoke(self, "onSamplingRule", [sampling_rule_name, account, region, partition]))

    @jsii.member(jsii_name="toBatchGetTraces")
    def to_batch_get_traces(self) -> "Xray":
        '''(experimental) Grants permission to retrieve a list of traces specified by ID.

        Each trace is a collection of segment documents that originates from a single request. Use GetTraceSummaries to get a list of trace IDs

        Access Level: List

        https://docs.aws.amazon.com/xray/latest/api/API_BatchGetTraces.html

        :stability: experimental
        '''
        return typing.cast("Xray", jsii.invoke(self, "toBatchGetTraces", []))

    @jsii.member(jsii_name="toBatchGetTraceSummaryById")
    def to_batch_get_trace_summary_by_id(self) -> "Xray":
        '''(experimental) Grants permission to retrieve metadata for a list of traces specified by ID.

        Access Level: Read

        https://docs.aws.amazon.com/xray/latest/devguide/security_iam_id-based-policy-examples.html#security_iam_id-based-policy-examples-console

        :stability: experimental
        '''
        return typing.cast("Xray", jsii.invoke(self, "toBatchGetTraceSummaryById", []))

    @jsii.member(jsii_name="toCreateGroup")
    def to_create_group(self) -> "Xray":
        '''(experimental) Grants permission to create a group resource with a name and a filter expression.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/xray/latest/api/API_CreateGroup.html

        :stability: experimental
        '''
        return typing.cast("Xray", jsii.invoke(self, "toCreateGroup", []))

    @jsii.member(jsii_name="toCreateSamplingRule")
    def to_create_sampling_rule(self) -> "Xray":
        '''(experimental) Grants permission to create a rule to control sampling behavior for instrumented applications.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/xray/latest/api/API_CreateSamplingRule.html

        :stability: experimental
        '''
        return typing.cast("Xray", jsii.invoke(self, "toCreateSamplingRule", []))

    @jsii.member(jsii_name="toDeleteGroup")
    def to_delete_group(self) -> "Xray":
        '''(experimental) Grants permission to delete a group resource.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/xray/latest/api/API_DeleteGroup.html

        :stability: experimental
        '''
        return typing.cast("Xray", jsii.invoke(self, "toDeleteGroup", []))

    @jsii.member(jsii_name="toDeleteResourcePolicy")
    def to_delete_resource_policy(self) -> "Xray":
        '''(experimental) Grants permission to delete resource policies.

        Access Level: Write

        https://docs.aws.amazon.com/xray/latest/api/API_DeleteResourcePolicy.html

        :stability: experimental
        '''
        return typing.cast("Xray", jsii.invoke(self, "toDeleteResourcePolicy", []))

    @jsii.member(jsii_name="toDeleteSamplingRule")
    def to_delete_sampling_rule(self) -> "Xray":
        '''(experimental) Grants permission to delete a sampling rule.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/xray/latest/api/API_DeleteSamplingRule.html

        :stability: experimental
        '''
        return typing.cast("Xray", jsii.invoke(self, "toDeleteSamplingRule", []))

    @jsii.member(jsii_name="toGetDistinctTraceGraphs")
    def to_get_distinct_trace_graphs(self) -> "Xray":
        '''(experimental) Grants permission to retrieve distinct service graphs for one or more specific trace IDs.

        Access Level: Read

        https://docs.aws.amazon.com/xray/latest/devguide/security_iam_id-based-policy-examples.html#security_iam_id-based-policy-examples-console

        :stability: experimental
        '''
        return typing.cast("Xray", jsii.invoke(self, "toGetDistinctTraceGraphs", []))

    @jsii.member(jsii_name="toGetEncryptionConfig")
    def to_get_encryption_config(self) -> "Xray":
        '''(experimental) Grants permission to retrieve the current encryption configuration for X-Ray data.

        Access Level: Read

        https://docs.aws.amazon.com/xray/latest/api/API_GetEncryptionConfig.html

        :stability: experimental
        '''
        return typing.cast("Xray", jsii.invoke(self, "toGetEncryptionConfig", []))

    @jsii.member(jsii_name="toGetGroup")
    def to_get_group(self) -> "Xray":
        '''(experimental) Grants permission to retrieve group resource details.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/xray/latest/api/API_GetGroup.html

        :stability: experimental
        '''
        return typing.cast("Xray", jsii.invoke(self, "toGetGroup", []))

    @jsii.member(jsii_name="toGetGroups")
    def to_get_groups(self) -> "Xray":
        '''(experimental) Grants permission to retrieve all active group details.

        Access Level: Read

        https://docs.aws.amazon.com/xray/latest/api/API_GetGroups.html

        :stability: experimental
        '''
        return typing.cast("Xray", jsii.invoke(self, "toGetGroups", []))

    @jsii.member(jsii_name="toGetInsight")
    def to_get_insight(self) -> "Xray":
        '''(experimental) Grants permission to retrieve the details of a specific insight.

        Access Level: Read

        https://docs.aws.amazon.com/xray/latest/api/API_GetInsight.html

        :stability: experimental
        '''
        return typing.cast("Xray", jsii.invoke(self, "toGetInsight", []))

    @jsii.member(jsii_name="toGetInsightEvents")
    def to_get_insight_events(self) -> "Xray":
        '''(experimental) Grants permission to retrieve the events of a specific insight.

        Access Level: Read

        https://docs.aws.amazon.com/xray/latest/api/API_GetInsightEvents.html

        :stability: experimental
        '''
        return typing.cast("Xray", jsii.invoke(self, "toGetInsightEvents", []))

    @jsii.member(jsii_name="toGetInsightImpactGraph")
    def to_get_insight_impact_graph(self) -> "Xray":
        '''(experimental) Grants permission to retrieve the part of the service graph which is impacted for a specific insight.

        Access Level: Read

        https://docs.aws.amazon.com/xray/latest/api/API_GetInsightImpactGraph.html

        :stability: experimental
        '''
        return typing.cast("Xray", jsii.invoke(self, "toGetInsightImpactGraph", []))

    @jsii.member(jsii_name="toGetInsightSummaries")
    def to_get_insight_summaries(self) -> "Xray":
        '''(experimental) Grants permission to retrieve the summary of all insights for a group and time range with optional filters.

        Access Level: Read

        https://docs.aws.amazon.com/xray/latest/api/API_GetInsightSummaries.html

        :stability: experimental
        '''
        return typing.cast("Xray", jsii.invoke(self, "toGetInsightSummaries", []))

    @jsii.member(jsii_name="toGetSamplingRules")
    def to_get_sampling_rules(self) -> "Xray":
        '''(experimental) Grants permission to retrieve all sampling rules.

        Access Level: Read

        https://docs.aws.amazon.com/xray/latest/api/API_GetSamplingRules.html

        :stability: experimental
        '''
        return typing.cast("Xray", jsii.invoke(self, "toGetSamplingRules", []))

    @jsii.member(jsii_name="toGetSamplingStatisticSummaries")
    def to_get_sampling_statistic_summaries(self) -> "Xray":
        '''(experimental) Grants permission to retrieve information about recent sampling results for all sampling rules.

        Access Level: Read

        https://docs.aws.amazon.com/xray/latest/api/API_GetSamplingStatisticSummaries.html

        :stability: experimental
        '''
        return typing.cast("Xray", jsii.invoke(self, "toGetSamplingStatisticSummaries", []))

    @jsii.member(jsii_name="toGetSamplingTargets")
    def to_get_sampling_targets(self) -> "Xray":
        '''(experimental) Grants permission to request a sampling quota for rules that the service is using to sample requests.

        Access Level: Read

        https://docs.aws.amazon.com/xray/latest/api/API_GetSamplingTargets.html

        :stability: experimental
        '''
        return typing.cast("Xray", jsii.invoke(self, "toGetSamplingTargets", []))

    @jsii.member(jsii_name="toGetServiceGraph")
    def to_get_service_graph(self) -> "Xray":
        '''(experimental) Grants permission to retrieve a document that describes services that process incoming requests, and downstream services that they call as a result.

        Access Level: Read

        https://docs.aws.amazon.com/xray/latest/api/API_GetServiceGraph.html

        :stability: experimental
        '''
        return typing.cast("Xray", jsii.invoke(self, "toGetServiceGraph", []))

    @jsii.member(jsii_name="toGetTimeSeriesServiceStatistics")
    def to_get_time_series_service_statistics(self) -> "Xray":
        '''(experimental) Grants permission to retrieve an aggregation of service statistics defined by a specific time range bucketed into time intervals.

        Access Level: Read

        https://docs.aws.amazon.com/xray/latest/api/API_GetTimeSeriesServiceStatistics.html

        :stability: experimental
        '''
        return typing.cast("Xray", jsii.invoke(self, "toGetTimeSeriesServiceStatistics", []))

    @jsii.member(jsii_name="toGetTraceGraph")
    def to_get_trace_graph(self) -> "Xray":
        '''(experimental) Grants permission to retrieve a service graph for one or more specific trace IDs.

        Access Level: Read

        https://docs.aws.amazon.com/xray/latest/api/API_GetTraceGraph.html

        :stability: experimental
        '''
        return typing.cast("Xray", jsii.invoke(self, "toGetTraceGraph", []))

    @jsii.member(jsii_name="toGetTraceSummaries")
    def to_get_trace_summaries(self) -> "Xray":
        '''(experimental) Grants permission to retrieve IDs and metadata for traces available for a specified time frame using an optional filter.

        To get the full traces, pass the trace IDs to BatchGetTraces

        Access Level: Read

        https://docs.aws.amazon.com/xray/latest/api/API_GetTraceSummaries.html

        :stability: experimental
        '''
        return typing.cast("Xray", jsii.invoke(self, "toGetTraceSummaries", []))

    @jsii.member(jsii_name="toLink")
    def to_link(self) -> "Xray":
        '''(experimental) Grants permission to share X-Ray resources with a monitoring account.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/CloudWatch-Unified-Cross-Account-Setup.html#CloudWatch-Unified-Cross-Account-Setup-permissions

        :stability: experimental
        '''
        return typing.cast("Xray", jsii.invoke(self, "toLink", []))

    @jsii.member(jsii_name="toListResourcePolicies")
    def to_list_resource_policies(self) -> "Xray":
        '''(experimental) Grants permission to list resource policies.

        Access Level: List

        https://docs.aws.amazon.com/xray/latest/api/API_ListResourcePolicies.html

        :stability: experimental
        '''
        return typing.cast("Xray", jsii.invoke(self, "toListResourcePolicies", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Xray":
        '''(experimental) Grants permission to list tags for an X-Ray resource.

        Access Level: List

        https://docs.aws.amazon.com/xray/latest/api/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("Xray", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toPutEncryptionConfig")
    def to_put_encryption_config(self) -> "Xray":
        '''(experimental) Grants permission to update the encryption configuration for X-Ray data.

        Access Level: Permissions management

        https://docs.aws.amazon.com/xray/latest/api/API_PutEncryptionConfig.html

        :stability: experimental
        '''
        return typing.cast("Xray", jsii.invoke(self, "toPutEncryptionConfig", []))

    @jsii.member(jsii_name="toPutResourcePolicy")
    def to_put_resource_policy(self) -> "Xray":
        '''(experimental) Grants permission to create or update resource policies.

        Access Level: Write

        https://docs.aws.amazon.com/xray/latest/api/API_PutResourcePolicy.html

        :stability: experimental
        '''
        return typing.cast("Xray", jsii.invoke(self, "toPutResourcePolicy", []))

    @jsii.member(jsii_name="toPutTelemetryRecords")
    def to_put_telemetry_records(self) -> "Xray":
        '''(experimental) Grants permission to send AWS X-Ray daemon telemetry to the service.

        Access Level: Write

        https://docs.aws.amazon.com/xray/latest/api/API_PutTelemetryRecords.html

        :stability: experimental
        '''
        return typing.cast("Xray", jsii.invoke(self, "toPutTelemetryRecords", []))

    @jsii.member(jsii_name="toPutTraceSegments")
    def to_put_trace_segments(self) -> "Xray":
        '''(experimental) Grants permission to upload segment documents to AWS X-Ray.

        The X-Ray SDK generates segment documents and sends them to the X-Ray daemon, which uploads them in batches

        Access Level: Write

        https://docs.aws.amazon.com/xray/latest/api/API_PutTraceSegments.html

        :stability: experimental
        '''
        return typing.cast("Xray", jsii.invoke(self, "toPutTraceSegments", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Xray":
        '''(experimental) Grants permission to add tags to an X-Ray resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/xray/latest/api/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("Xray", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Xray":
        '''(experimental) Grants permission to remove tags from an X-Ray resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/xray/latest/api/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("Xray", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateGroup")
    def to_update_group(self) -> "Xray":
        '''(experimental) Grants permission to update a group resource.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/xray/latest/api/API_UpdateGroup.html

        :stability: experimental
        '''
        return typing.cast("Xray", jsii.invoke(self, "toUpdateGroup", []))

    @jsii.member(jsii_name="toUpdateSamplingRule")
    def to_update_sampling_rule(self) -> "Xray":
        '''(experimental) Grants permission to modify a sampling rule's configuration.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/xray/latest/api/API_UpdateSamplingRule.html

        :stability: experimental
        '''
        return typing.cast("Xray", jsii.invoke(self, "toUpdateSamplingRule", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__083aed5f6aeadd3f00e8ff56c828e3d61f5280f55b73e714c4445de8611d6f99)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9fdde4dc3c6b1be8d2413ad8549b257c4ebca20996da004e4ec629dbf42145a9)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class A2c(PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.A2c"):
    '''(experimental) Statement provider for service `a2c <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsapp2container.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `a2c <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsapp2container.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="toGetContainerizationJobDetails")
    def to_get_containerization_job_details(self) -> "A2c":
        '''(experimental) Grants permission to get the details of all Containerization jobs.

        Access Level: Read

        https://docs.aws.amazon.com/tk-dotnet-refactoring/latest/userguide/what-is-tk-dotnet-refactoring.html

        :stability: experimental
        '''
        return typing.cast("A2c", jsii.invoke(self, "toGetContainerizationJobDetails", []))

    @jsii.member(jsii_name="toGetDeploymentJobDetails")
    def to_get_deployment_job_details(self) -> "A2c":
        '''(experimental) Grants permission to get the details of all Deployment jobs.

        Access Level: Read

        https://docs.aws.amazon.com/tk-dotnet-refactoring/latest/userguide/what-is-tk-dotnet-refactoring.html

        :stability: experimental
        '''
        return typing.cast("A2c", jsii.invoke(self, "toGetDeploymentJobDetails", []))

    @jsii.member(jsii_name="toStartContainerizationJob")
    def to_start_containerization_job(self) -> "A2c":
        '''(experimental) Grants permission to start a Containerization job.

        Access Level: Write

        https://docs.aws.amazon.com/tk-dotnet-refactoring/latest/userguide/what-is-tk-dotnet-refactoring.html

        :stability: experimental
        '''
        return typing.cast("A2c", jsii.invoke(self, "toStartContainerizationJob", []))

    @jsii.member(jsii_name="toStartDeploymentJob")
    def to_start_deployment_job(self) -> "A2c":
        '''(experimental) Grants permission to start a Deploymnet job.

        Access Level: Write

        https://docs.aws.amazon.com/tk-dotnet-refactoring/latest/userguide/what-is-tk-dotnet-refactoring.html

        :stability: experimental
        '''
        return typing.cast("A2c", jsii.invoke(self, "toStartDeploymentJob", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__12e81c3324c7bab9bbce77500f7e190d2bd79cc31bd797fcdf14fd127047d292)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__df42739d7ee4329f6325ff52d9b4698093385eefa9b4e3c01ae04e7609e85860)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class A4b(PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.A4b"):
    '''(experimental) Statement provider for service `a4b <https://docs.aws.amazon.com/service-authorization/latest/reference/list_alexaforbusiness.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `a4b <https://docs.aws.amazon.com/service-authorization/latest/reference/list_alexaforbusiness.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="ifAmazonId")
    def if_amazon_id(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "A4b":
        '''(experimental) Filters actions based on the Amazon Id in the request.

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_RegisterAVSDevice.html

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__099176664d52cf1a0841199166efd4c267c5f182966e29ebddeabaf6badbbbbd)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("A4b", jsii.invoke(self, "ifAmazonId", [value, operator]))

    @jsii.member(jsii_name="ifFiltersDeviceType")
    def if_filters_device_type(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "A4b":
        '''(experimental) Filters actions based on the device type in the request.

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_SearchDevices.html

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5d2b571b22b6c37916b1d0af76232eb6f408a5d2939e22ee2a57adf5dff11393)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("A4b", jsii.invoke(self, "ifFiltersDeviceType", [value, operator]))

    @jsii.member(jsii_name="onAddressbook")
    def on_addressbook(
        self,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "A4b":
        '''(experimental) Adds a resource of type addressbook to the statement.

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_AddressBook.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2786eba1789b876dcf68b18fb5209e3122357545c4d33cebc9d9008fdc180aee)
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("A4b", jsii.invoke(self, "onAddressbook", [resource_id, account, region, partition]))

    @jsii.member(jsii_name="onConferenceprovider")
    def on_conferenceprovider(
        self,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "A4b":
        '''(experimental) Adds a resource of type conferenceprovider to the statement.

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_ConferenceProvider.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c5d941c9eeaed909f315030d9c016c17369d65da3500f08eefa2c7949af86255)
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("A4b", jsii.invoke(self, "onConferenceprovider", [resource_id, account, region, partition]))

    @jsii.member(jsii_name="onContact")
    def on_contact(
        self,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "A4b":
        '''(experimental) Adds a resource of type contact to the statement.

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_Contact.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1e2b8a75dbbbba55fc243fb44e4d229eb5ca85f159d15c456bb016a9993825ea)
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("A4b", jsii.invoke(self, "onContact", [resource_id, account, region, partition]))

    @jsii.member(jsii_name="onDevice")
    def on_device(
        self,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "A4b":
        '''(experimental) Adds a resource of type device to the statement.

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_Device.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0264cd4d9d6eb29b570ab89f20f30683bf219d9ba9374cfacd08c4d449101e8b)
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("A4b", jsii.invoke(self, "onDevice", [resource_id, account, region, partition]))

    @jsii.member(jsii_name="onGateway")
    def on_gateway(
        self,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "A4b":
        '''(experimental) Adds a resource of type gateway to the statement.

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_Gateway.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__abe75982b8c1932d972ce51cc783819f16bd0ace9d386889a0f225544956ec0d)
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("A4b", jsii.invoke(self, "onGateway", [resource_id, account, region, partition]))

    @jsii.member(jsii_name="onGatewaygroup")
    def on_gatewaygroup(
        self,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "A4b":
        '''(experimental) Adds a resource of type gatewaygroup to the statement.

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_GatewayGroup.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ce862b63436362fa657c57d06c8364b9b414070f8696fc5153d4029e763186d6)
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("A4b", jsii.invoke(self, "onGatewaygroup", [resource_id, account, region, partition]))

    @jsii.member(jsii_name="onNetworkprofile")
    def on_networkprofile(
        self,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "A4b":
        '''(experimental) Adds a resource of type networkprofile to the statement.

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_NetworkProfile.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f8c40448d4857cf9f7486cd3a847841dd59216a990a8fc608264946a10f8b870)
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("A4b", jsii.invoke(self, "onNetworkprofile", [resource_id, account, region, partition]))

    @jsii.member(jsii_name="onProfile")
    def on_profile(
        self,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "A4b":
        '''(experimental) Adds a resource of type profile to the statement.

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_Profile.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5b2a139026115125016228775042f075cbb7a94552ca8679e44f8c3f75b03b4a)
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("A4b", jsii.invoke(self, "onProfile", [resource_id, account, region, partition]))

    @jsii.member(jsii_name="onRoom")
    def on_room(
        self,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "A4b":
        '''(experimental) Adds a resource of type room to the statement.

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_Room.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__47c0feb90e0da664319d1a7a47d57d6903104e425816da9782790b7206ab4632)
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("A4b", jsii.invoke(self, "onRoom", [resource_id, account, region, partition]))

    @jsii.member(jsii_name="onSchedule")
    def on_schedule(
        self,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "A4b":
        '''(experimental) Adds a resource of type schedule to the statement.

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_BusinessReportSchedule.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__81d1b53130ca04866c3232e8f7696e7735f3bc1bd7c042278be909f5e0c63b6b)
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("A4b", jsii.invoke(self, "onSchedule", [resource_id, account, region, partition]))

    @jsii.member(jsii_name="onSkillgroup")
    def on_skillgroup(
        self,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "A4b":
        '''(experimental) Adds a resource of type skillgroup to the statement.

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_SkillGroup.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2380ef7e1105c820133c77c6f8ce88c5d3b81f005526c15a7e514773d8e3274f)
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("A4b", jsii.invoke(self, "onSkillgroup", [resource_id, account, region, partition]))

    @jsii.member(jsii_name="onUser")
    def on_user(
        self,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "A4b":
        '''(experimental) Adds a resource of type user to the statement.

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_UserData.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__100b58dbd3acd4d18433f4f2ac145ae7ce8238e8ce7686568605d158049277e6)
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("A4b", jsii.invoke(self, "onUser", [resource_id, account, region, partition]))

    @jsii.member(jsii_name="toApproveSkill")
    def to_approve_skill(self) -> "A4b":
        '''(experimental) Grants permission to associate a skill with the organization under the customer's AWS account.

        Access Level: Write

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_ApproveSkill.html

        :stability: experimental
        '''
        return typing.cast("A4b", jsii.invoke(self, "toApproveSkill", []))

    @jsii.member(jsii_name="toAssociateContactWithAddressBook")
    def to_associate_contact_with_address_book(self) -> "A4b":
        '''(experimental) Grants permission to associate a contact with a given address book.

        Access Level: Write

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_AssociateContactWithAddressBook.html

        :stability: experimental
        '''
        return typing.cast("A4b", jsii.invoke(self, "toAssociateContactWithAddressBook", []))

    @jsii.member(jsii_name="toAssociateDeviceWithNetworkProfile")
    def to_associate_device_with_network_profile(self) -> "A4b":
        '''(experimental) Grants permission to associate a device with the specified network profile.

        Access Level: Write

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_AssociateDeviceWithNetworkProfile.html

        :stability: experimental
        '''
        return typing.cast("A4b", jsii.invoke(self, "toAssociateDeviceWithNetworkProfile", []))

    @jsii.member(jsii_name="toAssociateDeviceWithRoom")
    def to_associate_device_with_room(self) -> "A4b":
        '''(experimental) Grants permission to associate device with given room.

        Access Level: Write

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_AssociateDeviceWithRoom.html

        :stability: experimental
        '''
        return typing.cast("A4b", jsii.invoke(self, "toAssociateDeviceWithRoom", []))

    @jsii.member(jsii_name="toAssociateSkillGroupWithRoom")
    def to_associate_skill_group_with_room(self) -> "A4b":
        '''(experimental) Grants permission to associate the skill group with given room.

        Access Level: Write

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_AssociateSkillGroupWithRoom.html

        :stability: experimental
        '''
        return typing.cast("A4b", jsii.invoke(self, "toAssociateSkillGroupWithRoom", []))

    @jsii.member(jsii_name="toAssociateSkillWithSkillGroup")
    def to_associate_skill_with_skill_group(self) -> "A4b":
        '''(experimental) Grants permission to associate a skill with a skill group.

        Access Level: Write

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_AssociateSkillWithSkillGroup.html

        :stability: experimental
        '''
        return typing.cast("A4b", jsii.invoke(self, "toAssociateSkillWithSkillGroup", []))

    @jsii.member(jsii_name="toAssociateSkillWithUsers")
    def to_associate_skill_with_users(self) -> "A4b":
        '''(experimental) Grants permission to make a private skill available for enrolled users to enable on their devices.

        Access Level: Write

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_AssociateSkillWithUsers.html

        :stability: experimental
        '''
        return typing.cast("A4b", jsii.invoke(self, "toAssociateSkillWithUsers", []))

    @jsii.member(jsii_name="toCompleteRegistration")
    def to_complete_registration(self) -> "A4b":
        '''(experimental) Grants permission to complete the operation of registering an Alexa device.

        Access Level: Write

        https://docs.aws.amazon.com/a4b/latest/ag/manage-devices.html

        :stability: experimental
        '''
        return typing.cast("A4b", jsii.invoke(self, "toCompleteRegistration", []))

    @jsii.member(jsii_name="toCreateAddressBook")
    def to_create_address_book(self) -> "A4b":
        '''(experimental) Grants permission to create an address book with the specified details.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_CreateAddressBook.html

        :stability: experimental
        '''
        return typing.cast("A4b", jsii.invoke(self, "toCreateAddressBook", []))

    @jsii.member(jsii_name="toCreateBusinessReportSchedule")
    def to_create_business_report_schedule(self) -> "A4b":
        '''(experimental) Grants permission to create a recurring schedule for usage reports to deliver to the specified S3 location with a specified daily or weekly interval.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_CreateBusinessReportSchedule.html

        :stability: experimental
        '''
        return typing.cast("A4b", jsii.invoke(self, "toCreateBusinessReportSchedule", []))

    @jsii.member(jsii_name="toCreateConferenceProvider")
    def to_create_conference_provider(self) -> "A4b":
        '''(experimental) Grants permission to add a new conference provider under the user's AWS account.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_CreateConferenceProvider.html

        :stability: experimental
        '''
        return typing.cast("A4b", jsii.invoke(self, "toCreateConferenceProvider", []))

    @jsii.member(jsii_name="toCreateContact")
    def to_create_contact(self) -> "A4b":
        '''(experimental) Grants permission to create a contact with the specified details.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_CreateContact.html

        :stability: experimental
        '''
        return typing.cast("A4b", jsii.invoke(self, "toCreateContact", []))

    @jsii.member(jsii_name="toCreateGatewayGroup")
    def to_create_gateway_group(self) -> "A4b":
        '''(experimental) Grants permission to create a gateway group with the specified details.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_CreateGatewayGroup.html

        :stability: experimental
        '''
        return typing.cast("A4b", jsii.invoke(self, "toCreateGatewayGroup", []))

    @jsii.member(jsii_name="toCreateNetworkProfile")
    def to_create_network_profile(self) -> "A4b":
        '''(experimental) Grants permission to create a network profile with the specified details.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_CreateNetworkProfile.html

        :stability: experimental
        '''
        return typing.cast("A4b", jsii.invoke(self, "toCreateNetworkProfile", []))

    @jsii.member(jsii_name="toCreateProfile")
    def to_create_profile(self) -> "A4b":
        '''(experimental) Grants permission to create a new profile.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_CreateProfile.html

        :stability: experimental
        '''
        return typing.cast("A4b", jsii.invoke(self, "toCreateProfile", []))

    @jsii.member(jsii_name="toCreateRoom")
    def to_create_room(self) -> "A4b":
        '''(experimental) Grants permission to create room with the specified details.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_CreateRoom.html

        :stability: experimental
        '''
        return typing.cast("A4b", jsii.invoke(self, "toCreateRoom", []))

    @jsii.member(jsii_name="toCreateSkillGroup")
    def to_create_skill_group(self) -> "A4b":
        '''(experimental) Grants permission to create a skill group with given name and description.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_CreateSkillGroup.html

        :stability: experimental
        '''
        return typing.cast("A4b", jsii.invoke(self, "toCreateSkillGroup", []))

    @jsii.member(jsii_name="toCreateUser")
    def to_create_user(self) -> "A4b":
        '''(experimental) Grants permission to create a user.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_CreateUser.html

        :stability: experimental
        '''
        return typing.cast("A4b", jsii.invoke(self, "toCreateUser", []))

    @jsii.member(jsii_name="toDeleteAddressBook")
    def to_delete_address_book(self) -> "A4b":
        '''(experimental) Grants permission to delete an address book by the address book ARN.

        Access Level: Write

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_DeleteAddressBook.html

        :stability: experimental
        '''
        return typing.cast("A4b", jsii.invoke(self, "toDeleteAddressBook", []))

    @jsii.member(jsii_name="toDeleteBusinessReportSchedule")
    def to_delete_business_report_schedule(self) -> "A4b":
        '''(experimental) Grants permission to delete the recurring report delivery schedule with the specified schedule ARN.

        Access Level: Write

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_DeleteBusinessReportSchedule.html

        :stability: experimental
        '''
        return typing.cast("A4b", jsii.invoke(self, "toDeleteBusinessReportSchedule", []))

    @jsii.member(jsii_name="toDeleteConferenceProvider")
    def to_delete_conference_provider(self) -> "A4b":
        '''(experimental) Grants permission to delete a conference provider.

        Access Level: Write

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_DeleteConferenceProvider.html

        :stability: experimental
        '''
        return typing.cast("A4b", jsii.invoke(self, "toDeleteConferenceProvider", []))

    @jsii.member(jsii_name="toDeleteContact")
    def to_delete_contact(self) -> "A4b":
        '''(experimental) Grants permission to delete a contact by the contact ARN.

        Access Level: Write

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_DeleteContact.html

        :stability: experimental
        '''
        return typing.cast("A4b", jsii.invoke(self, "toDeleteContact", []))

    @jsii.member(jsii_name="toDeleteDevice")
    def to_delete_device(self) -> "A4b":
        '''(experimental) Grants permission to remove a device from Alexa For Business.

        Access Level: Write

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_DeleteDevice.html

        :stability: experimental
        '''
        return typing.cast("A4b", jsii.invoke(self, "toDeleteDevice", []))

    @jsii.member(jsii_name="toDeleteDeviceUsageData")
    def to_delete_device_usage_data(self) -> "A4b":
        '''(experimental) Grants permission to delete the device's entire previous history of voice input data and associated response data.

        Access Level: Write

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_DeleteDeviceUsageData.html

        :stability: experimental
        '''
        return typing.cast("A4b", jsii.invoke(self, "toDeleteDeviceUsageData", []))

    @jsii.member(jsii_name="toDeleteGatewayGroup")
    def to_delete_gateway_group(self) -> "A4b":
        '''(experimental) Grants permission to delete a gateway group.

        Access Level: Write

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_DeleteGatewayGroup.html

        :stability: experimental
        '''
        return typing.cast("A4b", jsii.invoke(self, "toDeleteGatewayGroup", []))

    @jsii.member(jsii_name="toDeleteNetworkProfile")
    def to_delete_network_profile(self) -> "A4b":
        '''(experimental) Grants permission to delete a network profile by the network profile ARN.

        Access Level: Write

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_DeleteNetworkProfile.html

        :stability: experimental
        '''
        return typing.cast("A4b", jsii.invoke(self, "toDeleteNetworkProfile", []))

    @jsii.member(jsii_name="toDeleteProfile")
    def to_delete_profile(self) -> "A4b":
        '''(experimental) Grants permission to delete profile by profile ARN.

        Access Level: Write

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_DeleteProfile.html

        :stability: experimental
        '''
        return typing.cast("A4b", jsii.invoke(self, "toDeleteProfile", []))

    @jsii.member(jsii_name="toDeleteRoom")
    def to_delete_room(self) -> "A4b":
        '''(experimental) Grants permission to delete room.

        Access Level: Write

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_DeleteRoom.html

        :stability: experimental
        '''
        return typing.cast("A4b", jsii.invoke(self, "toDeleteRoom", []))

    @jsii.member(jsii_name="toDeleteRoomSkillParameter")
    def to_delete_room_skill_parameter(self) -> "A4b":
        '''(experimental) Grants permission to delete a parameter from a skill and room.

        Access Level: Write

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_DeleteRoomSkillParameter.html

        :stability: experimental
        '''
        return typing.cast("A4b", jsii.invoke(self, "toDeleteRoomSkillParameter", []))

    @jsii.member(jsii_name="toDeleteSkillAuthorization")
    def to_delete_skill_authorization(self) -> "A4b":
        '''(experimental) Grants permission to unlink a third-party account from a skill.

        Access Level: Write

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_DeleteSkillAuthorization.html

        :stability: experimental
        '''
        return typing.cast("A4b", jsii.invoke(self, "toDeleteSkillAuthorization", []))

    @jsii.member(jsii_name="toDeleteSkillGroup")
    def to_delete_skill_group(self) -> "A4b":
        '''(experimental) Grants permission to delete skill group with skill group ARN.

        Access Level: Write

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_DeleteSkillGroup.html

        :stability: experimental
        '''
        return typing.cast("A4b", jsii.invoke(self, "toDeleteSkillGroup", []))

    @jsii.member(jsii_name="toDeleteUser")
    def to_delete_user(self) -> "A4b":
        '''(experimental) Grants permission to delete a user.

        Access Level: Write

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_DeleteUser.html

        :stability: experimental
        '''
        return typing.cast("A4b", jsii.invoke(self, "toDeleteUser", []))

    @jsii.member(jsii_name="toDisassociateContactFromAddressBook")
    def to_disassociate_contact_from_address_book(self) -> "A4b":
        '''(experimental) Grants permission to disassociate a contact from a given address book.

        Access Level: Write

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_DisassociateContactFromAddressBook.html

        :stability: experimental
        '''
        return typing.cast("A4b", jsii.invoke(self, "toDisassociateContactFromAddressBook", []))

    @jsii.member(jsii_name="toDisassociateDeviceFromRoom")
    def to_disassociate_device_from_room(self) -> "A4b":
        '''(experimental) Grants permission to disassociate device from its current room.

        Access Level: Write

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_DisassociateDeviceFromRoom.html

        :stability: experimental
        '''
        return typing.cast("A4b", jsii.invoke(self, "toDisassociateDeviceFromRoom", []))

    @jsii.member(jsii_name="toDisassociateSkillFromSkillGroup")
    def to_disassociate_skill_from_skill_group(self) -> "A4b":
        '''(experimental) Grants permission to disassociate a skill from a skill group.

        Access Level: Write

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_DisassociateSkillFromSkillGroup.html

        :stability: experimental
        '''
        return typing.cast("A4b", jsii.invoke(self, "toDisassociateSkillFromSkillGroup", []))

    @jsii.member(jsii_name="toDisassociateSkillFromUsers")
    def to_disassociate_skill_from_users(self) -> "A4b":
        '''(experimental) Grants permission to make a private skill unavailable for enrolled users and prevent them from enabling it on their devices.

        Access Level: Write

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_DisassociateSkillFromUsers.html

        :stability: experimental
        '''
        return typing.cast("A4b", jsii.invoke(self, "toDisassociateSkillFromUsers", []))

    @jsii.member(jsii_name="toDisassociateSkillGroupFromRoom")
    def to_disassociate_skill_group_from_room(self) -> "A4b":
        '''(experimental) Grants permission to disassociate the skill group from given room.

        Access Level: Write

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_DisassociateSkillGroupFromRoom.html

        :stability: experimental
        '''
        return typing.cast("A4b", jsii.invoke(self, "toDisassociateSkillGroupFromRoom", []))

    @jsii.member(jsii_name="toForgetSmartHomeAppliances")
    def to_forget_smart_home_appliances(self) -> "A4b":
        '''(experimental) Grants permission to forget smart home appliances associated to a room.

        Access Level: Write

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_ForgetSmartHomeAppliances.html

        :stability: experimental
        '''
        return typing.cast("A4b", jsii.invoke(self, "toForgetSmartHomeAppliances", []))

    @jsii.member(jsii_name="toGetAddressBook")
    def to_get_address_book(self) -> "A4b":
        '''(experimental) Grants permission to get the address book details by the address book ARN.

        Access Level: Read

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_GetAddressBook.html

        :stability: experimental
        '''
        return typing.cast("A4b", jsii.invoke(self, "toGetAddressBook", []))

    @jsii.member(jsii_name="toGetConferencePreference")
    def to_get_conference_preference(self) -> "A4b":
        '''(experimental) Grants permission to retrieve the existing conference preferences.

        Access Level: Read

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_GetConferencePreference.html

        :stability: experimental
        '''
        return typing.cast("A4b", jsii.invoke(self, "toGetConferencePreference", []))

    @jsii.member(jsii_name="toGetConferenceProvider")
    def to_get_conference_provider(self) -> "A4b":
        '''(experimental) Grants permission to get details about a specific conference provider.

        Access Level: Read

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_GetConferenceProvider.html

        :stability: experimental
        '''
        return typing.cast("A4b", jsii.invoke(self, "toGetConferenceProvider", []))

    @jsii.member(jsii_name="toGetContact")
    def to_get_contact(self) -> "A4b":
        '''(experimental) Grants permission to get the contact details by the contact ARN.

        Access Level: Read

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_GetContact.html

        :stability: experimental
        '''
        return typing.cast("A4b", jsii.invoke(self, "toGetContact", []))

    @jsii.member(jsii_name="toGetDevice")
    def to_get_device(self) -> "A4b":
        '''(experimental) Grants permission to get device details.

        Access Level: Read

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_GetDevice.html

        :stability: experimental
        '''
        return typing.cast("A4b", jsii.invoke(self, "toGetDevice", []))

    @jsii.member(jsii_name="toGetGateway")
    def to_get_gateway(self) -> "A4b":
        '''(experimental) Grants permission to retrieve the details of a gateway.

        Access Level: Read

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_GetGateway.html

        :stability: experimental
        '''
        return typing.cast("A4b", jsii.invoke(self, "toGetGateway", []))

    @jsii.member(jsii_name="toGetGatewayGroup")
    def to_get_gateway_group(self) -> "A4b":
        '''(experimental) Grants permission to retrieve the details of a gateway group.

        Access Level: Read

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_GetGatewayGroup.html

        :stability: experimental
        '''
        return typing.cast("A4b", jsii.invoke(self, "toGetGatewayGroup", []))

    @jsii.member(jsii_name="toGetInvitationConfiguration")
    def to_get_invitation_configuration(self) -> "A4b":
        '''(experimental) Grants permission to retrieve the configured values for the user enrollment invitation email template.

        Access Level: Read

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_GetInvitationConfiguration.html

        :stability: experimental
        '''
        return typing.cast("A4b", jsii.invoke(self, "toGetInvitationConfiguration", []))

    @jsii.member(jsii_name="toGetNetworkProfile")
    def to_get_network_profile(self) -> "A4b":
        '''(experimental) Grants permission to get the network profile details by the network profile ARN.

        Access Level: Read

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_GetNetworkProfile.html

        :stability: experimental
        '''
        return typing.cast("A4b", jsii.invoke(self, "toGetNetworkProfile", []))

    @jsii.member(jsii_name="toGetProfile")
    def to_get_profile(self) -> "A4b":
        '''(experimental) Grants permission to get profile when provided with Profile ARN.

        Access Level: Read

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_GetProfile.html

        :stability: experimental
        '''
        return typing.cast("A4b", jsii.invoke(self, "toGetProfile", []))

    @jsii.member(jsii_name="toGetRoom")
    def to_get_room(self) -> "A4b":
        '''(experimental) Grants permission to get room details.

        Access Level: Read

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_GetRoom.html

        :stability: experimental
        '''
        return typing.cast("A4b", jsii.invoke(self, "toGetRoom", []))

    @jsii.member(jsii_name="toGetRoomSkillParameter")
    def to_get_room_skill_parameter(self) -> "A4b":
        '''(experimental) Grants permission to get an existing parameter that has been set for a skill and room.

        Access Level: Read

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_GetRoomSkillParameter.html

        :stability: experimental
        '''
        return typing.cast("A4b", jsii.invoke(self, "toGetRoomSkillParameter", []))

    @jsii.member(jsii_name="toGetSkillGroup")
    def to_get_skill_group(self) -> "A4b":
        '''(experimental) Grants permission to get skill group details with skill group ARN.

        Access Level: Read

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_GetSkillGroup.html

        :stability: experimental
        '''
        return typing.cast("A4b", jsii.invoke(self, "toGetSkillGroup", []))

    @jsii.member(jsii_name="toListBusinessReportSchedules")
    def to_list_business_report_schedules(self) -> "A4b":
        '''(experimental) Grants permission to list the details of the schedules that a user configured.

        Access Level: List

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_ListBusinessReportSchedules.html

        :stability: experimental
        '''
        return typing.cast("A4b", jsii.invoke(self, "toListBusinessReportSchedules", []))

    @jsii.member(jsii_name="toListConferenceProviders")
    def to_list_conference_providers(self) -> "A4b":
        '''(experimental) Grants permission to list conference providers under a specific AWS account.

        Access Level: List

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_ListConferenceProviders.html

        :stability: experimental
        '''
        return typing.cast("A4b", jsii.invoke(self, "toListConferenceProviders", []))

    @jsii.member(jsii_name="toListDeviceEvents")
    def to_list_device_events(self) -> "A4b":
        '''(experimental) Grants permission to list the device event history, including device connection status, for up to 30 days.

        Access Level: List

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_ListDeviceEvents.html

        :stability: experimental
        '''
        return typing.cast("A4b", jsii.invoke(self, "toListDeviceEvents", []))

    @jsii.member(jsii_name="toListGatewayGroups")
    def to_list_gateway_groups(self) -> "A4b":
        '''(experimental) Grants permission to list gateway group summaries.

        Access Level: List

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_ListGatewayGroups.html

        :stability: experimental
        '''
        return typing.cast("A4b", jsii.invoke(self, "toListGatewayGroups", []))

    @jsii.member(jsii_name="toListGateways")
    def to_list_gateways(self) -> "A4b":
        '''(experimental) Grants permission to list gateway summaries.

        Access Level: List

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_ListGateways.html

        :stability: experimental
        '''
        return typing.cast("A4b", jsii.invoke(self, "toListGateways", []))

    @jsii.member(jsii_name="toListSkills")
    def to_list_skills(self) -> "A4b":
        '''(experimental) Grants permission to list skills.

        Access Level: List

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_ListSkills.html

        :stability: experimental
        '''
        return typing.cast("A4b", jsii.invoke(self, "toListSkills", []))

    @jsii.member(jsii_name="toListSkillsStoreCategories")
    def to_list_skills_store_categories(self) -> "A4b":
        '''(experimental) Grants permission to list all categories in the Alexa skill store.

        Access Level: List

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_ListSkillsStoreCategories.html

        :stability: experimental
        '''
        return typing.cast("A4b", jsii.invoke(self, "toListSkillsStoreCategories", []))

    @jsii.member(jsii_name="toListSkillsStoreSkillsByCategory")
    def to_list_skills_store_skills_by_category(self) -> "A4b":
        '''(experimental) Grants permission to list all skills in the Alexa skill store by category.

        Access Level: List

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_ListSkillsStoreSkillsByCategory.html

        :stability: experimental
        '''
        return typing.cast("A4b", jsii.invoke(self, "toListSkillsStoreSkillsByCategory", []))

    @jsii.member(jsii_name="toListSmartHomeAppliances")
    def to_list_smart_home_appliances(self) -> "A4b":
        '''(experimental) Grants permission to list all of the smart home appliances associated with a room.

        Access Level: List

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_ListSmartHomeAppliances.html

        :stability: experimental
        '''
        return typing.cast("A4b", jsii.invoke(self, "toListSmartHomeAppliances", []))

    @jsii.member(jsii_name="toListTags")
    def to_list_tags(self) -> "A4b":
        '''(experimental) Grants permission to list all tags on a resource.

        Access Level: Read

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_ListTags.html

        :stability: experimental
        '''
        return typing.cast("A4b", jsii.invoke(self, "toListTags", []))

    @jsii.member(jsii_name="toPutConferencePreference")
    def to_put_conference_preference(self) -> "A4b":
        '''(experimental) Grants permission to set the conference preferences on a specific conference provider at the account level.

        Access Level: Write

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_PutConferencePreference.html

        :stability: experimental
        '''
        return typing.cast("A4b", jsii.invoke(self, "toPutConferencePreference", []))

    @jsii.member(jsii_name="toPutDeviceSetupEvents")
    def to_put_device_setup_events(self) -> "A4b":
        '''(experimental) Grants permission to publish Alexa device setup events.

        Access Level: Write

        https://docs.aws.amazon.com/a4b/latest/ag/manage-devices.html

        :stability: experimental
        '''
        return typing.cast("A4b", jsii.invoke(self, "toPutDeviceSetupEvents", []))

    @jsii.member(jsii_name="toPutInvitationConfiguration")
    def to_put_invitation_configuration(self) -> "A4b":
        '''(experimental) Grants permission to configure the email template for the user enrollment invitation with the specified attributes.

        Access Level: Write

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_PutInvitationConfiguration.html

        :stability: experimental
        '''
        return typing.cast("A4b", jsii.invoke(self, "toPutInvitationConfiguration", []))

    @jsii.member(jsii_name="toPutRoomSkillParameter")
    def to_put_room_skill_parameter(self) -> "A4b":
        '''(experimental) Grants permission to put a room specific parameter for a skill.

        Access Level: Write

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_PutRoomSkillParameter.html

        :stability: experimental
        '''
        return typing.cast("A4b", jsii.invoke(self, "toPutRoomSkillParameter", []))

    @jsii.member(jsii_name="toPutSkillAuthorization")
    def to_put_skill_authorization(self) -> "A4b":
        '''(experimental) Grants permission to link a user's account to a third-party skill provider.

        Access Level: Write

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_PutSkillAuthorization.html

        :stability: experimental
        '''
        return typing.cast("A4b", jsii.invoke(self, "toPutSkillAuthorization", []))

    @jsii.member(jsii_name="toRegisterAVSDevice")
    def to_register_avs_device(self) -> "A4b":
        '''(experimental) Grants permission to register an Alexa-enabled device built by an Original Equipment Manufacturer (OEM) using Alexa Voice Service (AVS).

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_RegisterAVSDevice.html

        :stability: experimental
        '''
        return typing.cast("A4b", jsii.invoke(self, "toRegisterAVSDevice", []))

    @jsii.member(jsii_name="toRegisterDevice")
    def to_register_device(self) -> "A4b":
        '''(experimental) Grants permission to register an Alexa device.

        Access Level: Write

        https://docs.aws.amazon.com/a4b/latest/ag/manage-devices.html

        :stability: experimental
        '''
        return typing.cast("A4b", jsii.invoke(self, "toRegisterDevice", []))

    @jsii.member(jsii_name="toRejectSkill")
    def to_reject_skill(self) -> "A4b":
        '''(experimental) Grants permission to disassociate a skill from the organization under a user's AWS account.

        Access Level: Write

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_RejectSkill.html

        :stability: experimental
        '''
        return typing.cast("A4b", jsii.invoke(self, "toRejectSkill", []))

    @jsii.member(jsii_name="toResolveRoom")
    def to_resolve_room(self) -> "A4b":
        '''(experimental) Grants permission to resolve room information.

        Access Level: Read

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_ResolveRoom.html

        :stability: experimental
        '''
        return typing.cast("A4b", jsii.invoke(self, "toResolveRoom", []))

    @jsii.member(jsii_name="toRevokeInvitation")
    def to_revoke_invitation(self) -> "A4b":
        '''(experimental) Grants permission to revoke an invitation.

        Access Level: Write

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_RevokeInvitation.html

        :stability: experimental
        '''
        return typing.cast("A4b", jsii.invoke(self, "toRevokeInvitation", []))

    @jsii.member(jsii_name="toSearchAddressBooks")
    def to_search_address_books(self) -> "A4b":
        '''(experimental) Grants permission to search address books and list the ones that meet a set of filter and sort criteria.

        Access Level: List

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_SearchAddressBooks.html

        :stability: experimental
        '''
        return typing.cast("A4b", jsii.invoke(self, "toSearchAddressBooks", []))

    @jsii.member(jsii_name="toSearchContacts")
    def to_search_contacts(self) -> "A4b":
        '''(experimental) Grants permission to search contacts and list the ones that meet a set of filter and sort criteria.

        Access Level: List

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_SearchContacts.html

        :stability: experimental
        '''
        return typing.cast("A4b", jsii.invoke(self, "toSearchContacts", []))

    @jsii.member(jsii_name="toSearchDevices")
    def to_search_devices(self) -> "A4b":
        '''(experimental) Grants permission to search for devices.

        Access Level: List

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_SearchDevices.html

        :stability: experimental
        '''
        return typing.cast("A4b", jsii.invoke(self, "toSearchDevices", []))

    @jsii.member(jsii_name="toSearchNetworkProfiles")
    def to_search_network_profiles(self) -> "A4b":
        '''(experimental) Grants permission to search network profiles and list the ones that meet a set of filter and sort criteria.

        Access Level: List

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_SearchNetworkProfiles.html

        :stability: experimental
        '''
        return typing.cast("A4b", jsii.invoke(self, "toSearchNetworkProfiles", []))

    @jsii.member(jsii_name="toSearchProfiles")
    def to_search_profiles(self) -> "A4b":
        '''(experimental) Grants permission to search for profiles.

        Access Level: List

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_SearchProfiles.html

        :stability: experimental
        '''
        return typing.cast("A4b", jsii.invoke(self, "toSearchProfiles", []))

    @jsii.member(jsii_name="toSearchRooms")
    def to_search_rooms(self) -> "A4b":
        '''(experimental) Grants permission to search for rooms.

        Access Level: List

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_SearchRooms.html

        :stability: experimental
        '''
        return typing.cast("A4b", jsii.invoke(self, "toSearchRooms", []))

    @jsii.member(jsii_name="toSearchSkillGroups")
    def to_search_skill_groups(self) -> "A4b":
        '''(experimental) Grants permission to search for skill groups.

        Access Level: List

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_SearchSkillGroups.html

        :stability: experimental
        '''
        return typing.cast("A4b", jsii.invoke(self, "toSearchSkillGroups", []))

    @jsii.member(jsii_name="toSearchUsers")
    def to_search_users(self) -> "A4b":
        '''(experimental) Grants permission to search for users.

        Access Level: List

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_SearchUsers.html

        :stability: experimental
        '''
        return typing.cast("A4b", jsii.invoke(self, "toSearchUsers", []))

    @jsii.member(jsii_name="toSendAnnouncement")
    def to_send_announcement(self) -> "A4b":
        '''(experimental) Grants permission to trigger an asynchronous flow to send text, SSML, or audio announcements to rooms that are identified by a search or filter.

        Access Level: Write

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_SendAnnouncement.html

        :stability: experimental
        '''
        return typing.cast("A4b", jsii.invoke(self, "toSendAnnouncement", []))

    @jsii.member(jsii_name="toSendInvitation")
    def to_send_invitation(self) -> "A4b":
        '''(experimental) Grants permission to send an invitation to a user.

        Access Level: Write

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_SendInvitation.html

        :stability: experimental
        '''
        return typing.cast("A4b", jsii.invoke(self, "toSendInvitation", []))

    @jsii.member(jsii_name="toStartDeviceSync")
    def to_start_device_sync(self) -> "A4b":
        '''(experimental) Grants permission to restore the device and its account to its known, default settings by clearing all information and settings set by its previous users.

        Access Level: Write

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_StartDeviceSync.html

        :stability: experimental
        '''
        return typing.cast("A4b", jsii.invoke(self, "toStartDeviceSync", []))

    @jsii.member(jsii_name="toStartSmartHomeApplianceDiscovery")
    def to_start_smart_home_appliance_discovery(self) -> "A4b":
        '''(experimental) Grants permission to initiate the discovery of any smart home appliances associated with the room.

        Access Level: Read

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_StartSmartHomeApplianceDiscovery.html

        :stability: experimental
        '''
        return typing.cast("A4b", jsii.invoke(self, "toStartSmartHomeApplianceDiscovery", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "A4b":
        '''(experimental) Grants permission to add metadata tags to a resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("A4b", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "A4b":
        '''(experimental) Grants permission to remove metadata tags from a resource.

        Access Level: Tagging

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("A4b", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateAddressBook")
    def to_update_address_book(self) -> "A4b":
        '''(experimental) Grants permission to update address book details by the address book ARN.

        Access Level: Write

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_UpdateAddressBook.html

        :stability: experimental
        '''
        return typing.cast("A4b", jsii.invoke(self, "toUpdateAddressBook", []))

    @jsii.member(jsii_name="toUpdateBusinessReportSchedule")
    def to_update_business_report_schedule(self) -> "A4b":
        '''(experimental) Grants permission to update the configuration of the report delivery schedule with the specified schedule ARN.

        Access Level: Write

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_UpdateBusinessReportSchedule.html

        :stability: experimental
        '''
        return typing.cast("A4b", jsii.invoke(self, "toUpdateBusinessReportSchedule", []))

    @jsii.member(jsii_name="toUpdateConferenceProvider")
    def to_update_conference_provider(self) -> "A4b":
        '''(experimental) Grants permission to update an existing conference provider's settings.

        Access Level: Write

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_UpdateConferenceProvider.html

        :stability: experimental
        '''
        return typing.cast("A4b", jsii.invoke(self, "toUpdateConferenceProvider", []))

    @jsii.member(jsii_name="toUpdateContact")
    def to_update_contact(self) -> "A4b":
        '''(experimental) Grants permission to update the contact details by the contact ARN.

        Access Level: Write

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_UpdateContact.html

        :stability: experimental
        '''
        return typing.cast("A4b", jsii.invoke(self, "toUpdateContact", []))

    @jsii.member(jsii_name="toUpdateDevice")
    def to_update_device(self) -> "A4b":
        '''(experimental) Grants permission to update device name.

        Access Level: Write

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_UpdateDevice.html

        :stability: experimental
        '''
        return typing.cast("A4b", jsii.invoke(self, "toUpdateDevice", []))

    @jsii.member(jsii_name="toUpdateGateway")
    def to_update_gateway(self) -> "A4b":
        '''(experimental) Grants permission to update the details of a gateway.

        Access Level: Write

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_UpdateGateway.html

        :stability: experimental
        '''
        return typing.cast("A4b", jsii.invoke(self, "toUpdateGateway", []))

    @jsii.member(jsii_name="toUpdateGatewayGroup")
    def to_update_gateway_group(self) -> "A4b":
        '''(experimental) Grants permission to update the details of a gateway group.

        Access Level: Write

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_UpdateGatewayGroup.html

        :stability: experimental
        '''
        return typing.cast("A4b", jsii.invoke(self, "toUpdateGatewayGroup", []))

    @jsii.member(jsii_name="toUpdateNetworkProfile")
    def to_update_network_profile(self) -> "A4b":
        '''(experimental) Grants permission to update a network profile by the network profile ARN.

        Access Level: Write

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_UpdateNetworkProfile.html

        :stability: experimental
        '''
        return typing.cast("A4b", jsii.invoke(self, "toUpdateNetworkProfile", []))

    @jsii.member(jsii_name="toUpdateProfile")
    def to_update_profile(self) -> "A4b":
        '''(experimental) Grants permission to update an existing profile.

        Access Level: Write

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_UpdateProfile.html

        :stability: experimental
        '''
        return typing.cast("A4b", jsii.invoke(self, "toUpdateProfile", []))

    @jsii.member(jsii_name="toUpdateRoom")
    def to_update_room(self) -> "A4b":
        '''(experimental) Grants permission to update room details.

        Access Level: Write

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_UpdateRoom.html

        :stability: experimental
        '''
        return typing.cast("A4b", jsii.invoke(self, "toUpdateRoom", []))

    @jsii.member(jsii_name="toUpdateSkillGroup")
    def to_update_skill_group(self) -> "A4b":
        '''(experimental) Grants permission to update skill group details with skill group ARN.

        Access Level: Write

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_UpdateSkillGroup.html

        :stability: experimental
        '''
        return typing.cast("A4b", jsii.invoke(self, "toUpdateSkillGroup", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7a5da53e234837e185092405110d77cd2a020fea36dc674c9319412c1dd38fa7)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__da43c715a14a1236901f9911d9c3d5a8b9ee767897a1248dba9ec6c2af247ff2)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class AccessAnalyzer(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.AccessAnalyzer",
):
    '''(experimental) Statement provider for service `access-analyzer <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiamaccessanalyzer.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `access-analyzer <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiamaccessanalyzer.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onAnalyzer")
    def on_analyzer(
        self,
        analyzer_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "AccessAnalyzer":
        '''(experimental) Adds a resource of type Analyzer to the statement.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/access-analyzer-getting-started.html#permission-resources

        :param analyzer_name: - Identifier for the analyzerName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f6814119f6783ed3acb4ddc70123b66e749f68d4f854492d9b80bd50f1d70cc6)
            check_type(argname="argument analyzer_name", value=analyzer_name, expected_type=type_hints["analyzer_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("AccessAnalyzer", jsii.invoke(self, "onAnalyzer", [analyzer_name, account, region, partition]))

    @jsii.member(jsii_name="onArchiveRule")
    def on_archive_rule(
        self,
        analyzer_name: builtins.str,
        rule_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "AccessAnalyzer":
        '''(experimental) Adds a resource of type ArchiveRule to the statement.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/access-analyzer-getting-started.html#permission-resources

        :param analyzer_name: - Identifier for the analyzerName.
        :param rule_name: - Identifier for the ruleName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8a41f6d5627026f68efdfa40159ed80662bc8a70e83bf23f4898aa938624f5ff)
            check_type(argname="argument analyzer_name", value=analyzer_name, expected_type=type_hints["analyzer_name"])
            check_type(argname="argument rule_name", value=rule_name, expected_type=type_hints["rule_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("AccessAnalyzer", jsii.invoke(self, "onArchiveRule", [analyzer_name, rule_name, account, region, partition]))

    @jsii.member(jsii_name="toApplyArchiveRule")
    def to_apply_archive_rule(self) -> "AccessAnalyzer":
        '''(experimental) Grants permission to apply an archive rule.

        Access Level: Write

        https://docs.aws.amazon.com/access-analyzer/latest/APIReference/API_ApplyArchiveRule.html

        :stability: experimental
        '''
        return typing.cast("AccessAnalyzer", jsii.invoke(self, "toApplyArchiveRule", []))

    @jsii.member(jsii_name="toCancelPolicyGeneration")
    def to_cancel_policy_generation(self) -> "AccessAnalyzer":
        '''(experimental) Grants permission to cancel a policy generation.

        Access Level: Write

        https://docs.aws.amazon.com/access-analyzer/latest/APIReference/API_CancelPolicyGeneration.html

        :stability: experimental
        '''
        return typing.cast("AccessAnalyzer", jsii.invoke(self, "toCancelPolicyGeneration", []))

    @jsii.member(jsii_name="toCreateAccessPreview")
    def to_create_access_preview(self) -> "AccessAnalyzer":
        '''(experimental) Grants permission to create an access preview for the specified analyzer.

        Access Level: Write

        https://docs.aws.amazon.com/access-analyzer/latest/APIReference/API_CreateAccessPreview.html

        :stability: experimental
        '''
        return typing.cast("AccessAnalyzer", jsii.invoke(self, "toCreateAccessPreview", []))

    @jsii.member(jsii_name="toCreateAnalyzer")
    def to_create_analyzer(self) -> "AccessAnalyzer":
        '''(experimental) Grants permission to create an analyzer.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - iam:CreateServiceLinkedRole

        https://docs.aws.amazon.com/access-analyzer/latest/APIReference/API_CreateAnalyzer.html

        :stability: experimental
        '''
        return typing.cast("AccessAnalyzer", jsii.invoke(self, "toCreateAnalyzer", []))

    @jsii.member(jsii_name="toCreateArchiveRule")
    def to_create_archive_rule(self) -> "AccessAnalyzer":
        '''(experimental) Grants permission to create an archive rule for the specified analyzer.

        Access Level: Write

        https://docs.aws.amazon.com/access-analyzer/latest/APIReference/API_CreateArchiveRule.html

        :stability: experimental
        '''
        return typing.cast("AccessAnalyzer", jsii.invoke(self, "toCreateArchiveRule", []))

    @jsii.member(jsii_name="toDeleteAnalyzer")
    def to_delete_analyzer(self) -> "AccessAnalyzer":
        '''(experimental) Grants permission to delete the specified analyzer.

        Access Level: Write

        https://docs.aws.amazon.com/access-analyzer/latest/APIReference/API_DeleteAnalyzer.html

        :stability: experimental
        '''
        return typing.cast("AccessAnalyzer", jsii.invoke(self, "toDeleteAnalyzer", []))

    @jsii.member(jsii_name="toDeleteArchiveRule")
    def to_delete_archive_rule(self) -> "AccessAnalyzer":
        '''(experimental) Grants permission to delete archive rules for the specified analyzer.

        Access Level: Write

        https://docs.aws.amazon.com/access-analyzer/latest/APIReference/API_DeleteArchiveRule.html

        :stability: experimental
        '''
        return typing.cast("AccessAnalyzer", jsii.invoke(self, "toDeleteArchiveRule", []))

    @jsii.member(jsii_name="toGetAccessPreview")
    def to_get_access_preview(self) -> "AccessAnalyzer":
        '''(experimental) Grants permission to retrieve information about an access preview.

        Access Level: Read

        https://docs.aws.amazon.com/access-analyzer/latest/APIReference/API_GetAccessPreview.html

        :stability: experimental
        '''
        return typing.cast("AccessAnalyzer", jsii.invoke(self, "toGetAccessPreview", []))

    @jsii.member(jsii_name="toGetAnalyzedResource")
    def to_get_analyzed_resource(self) -> "AccessAnalyzer":
        '''(experimental) Grants permission to retrieve information about an analyzed resource.

        Access Level: Read

        https://docs.aws.amazon.com/access-analyzer/latest/APIReference/API_GetAnalyzedResource.html

        :stability: experimental
        '''
        return typing.cast("AccessAnalyzer", jsii.invoke(self, "toGetAnalyzedResource", []))

    @jsii.member(jsii_name="toGetAnalyzer")
    def to_get_analyzer(self) -> "AccessAnalyzer":
        '''(experimental) Grants permission to retrieve information about analyzers.

        Access Level: Read

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/access-analyzer/latest/APIReference/API_GetAnalyzer.html

        :stability: experimental
        '''
        return typing.cast("AccessAnalyzer", jsii.invoke(self, "toGetAnalyzer", []))

    @jsii.member(jsii_name="toGetArchiveRule")
    def to_get_archive_rule(self) -> "AccessAnalyzer":
        '''(experimental) Grants permission to retrieve information about archive rules for the specified analyzer.

        Access Level: Read

        https://docs.aws.amazon.com/access-analyzer/latest/APIReference/API_GetArchiveRule.html

        :stability: experimental
        '''
        return typing.cast("AccessAnalyzer", jsii.invoke(self, "toGetArchiveRule", []))

    @jsii.member(jsii_name="toGetFinding")
    def to_get_finding(self) -> "AccessAnalyzer":
        '''(experimental) Grants permission to retrieve findings.

        Access Level: Read

        https://docs.aws.amazon.com/access-analyzer/latest/APIReference/API_GetFinding.html

        :stability: experimental
        '''
        return typing.cast("AccessAnalyzer", jsii.invoke(self, "toGetFinding", []))

    @jsii.member(jsii_name="toGetGeneratedPolicy")
    def to_get_generated_policy(self) -> "AccessAnalyzer":
        '''(experimental) Grants permission to retrieve a policy that was generated using StartPolicyGeneration.

        Access Level: Read

        https://docs.aws.amazon.com/access-analyzer/latest/APIReference/API_GetGeneratedPolicy.html

        :stability: experimental
        '''
        return typing.cast("AccessAnalyzer", jsii.invoke(self, "toGetGeneratedPolicy", []))

    @jsii.member(jsii_name="toListAccessPreviewFindings")
    def to_list_access_preview_findings(self) -> "AccessAnalyzer":
        '''(experimental) Grants permission to retrieve a list of findings from an access preview.

        Access Level: Read

        https://docs.aws.amazon.com/access-analyzer/latest/APIReference/API_ListAccessPreviewFindings.html

        :stability: experimental
        '''
        return typing.cast("AccessAnalyzer", jsii.invoke(self, "toListAccessPreviewFindings", []))

    @jsii.member(jsii_name="toListAccessPreviews")
    def to_list_access_previews(self) -> "AccessAnalyzer":
        '''(experimental) Grants permission to retrieve a list of access previews.

        Access Level: List

        https://docs.aws.amazon.com/access-analyzer/latest/APIReference/API_ListAccessPreviews.html

        :stability: experimental
        '''
        return typing.cast("AccessAnalyzer", jsii.invoke(self, "toListAccessPreviews", []))

    @jsii.member(jsii_name="toListAnalyzedResources")
    def to_list_analyzed_resources(self) -> "AccessAnalyzer":
        '''(experimental) Grants permission to retrieve a list of resources that have been analyzed.

        Access Level: Read

        https://docs.aws.amazon.com/access-analyzer/latest/APIReference/API_ListAnalyzedResources.html

        :stability: experimental
        '''
        return typing.cast("AccessAnalyzer", jsii.invoke(self, "toListAnalyzedResources", []))

    @jsii.member(jsii_name="toListAnalyzers")
    def to_list_analyzers(self) -> "AccessAnalyzer":
        '''(experimental) Grants permission to retrieves a list of analyzers.

        Access Level: List

        https://docs.aws.amazon.com/access-analyzer/latest/APIReference/API_ListAnalyzers.html

        :stability: experimental
        '''
        return typing.cast("AccessAnalyzer", jsii.invoke(self, "toListAnalyzers", []))

    @jsii.member(jsii_name="toListArchiveRules")
    def to_list_archive_rules(self) -> "AccessAnalyzer":
        '''(experimental) Grants permission to retrieve a list of archive rules from an analyzer.

        Access Level: List

        https://docs.aws.amazon.com/access-analyzer/latest/APIReference/API_ListArchiveRules.html

        :stability: experimental
        '''
        return typing.cast("AccessAnalyzer", jsii.invoke(self, "toListArchiveRules", []))

    @jsii.member(jsii_name="toListFindings")
    def to_list_findings(self) -> "AccessAnalyzer":
        '''(experimental) Grants permission to retrieve a list of findings from an analyzer.

        Access Level: Read

        https://docs.aws.amazon.com/access-analyzer/latest/APIReference/API_ListFindings.html

        :stability: experimental
        '''
        return typing.cast("AccessAnalyzer", jsii.invoke(self, "toListFindings", []))

    @jsii.member(jsii_name="toListPolicyGenerations")
    def to_list_policy_generations(self) -> "AccessAnalyzer":
        '''(experimental) Grants permission to list all the recently started policy generations.

        Access Level: Read

        https://docs.aws.amazon.com/access-analyzer/latest/APIReference/API_ListPolicyGenerations.html

        :stability: experimental
        '''
        return typing.cast("AccessAnalyzer", jsii.invoke(self, "toListPolicyGenerations", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "AccessAnalyzer":
        '''(experimental) Grants permission to retrieve a list of tags applied to a resource.

        Access Level: Read

        https://docs.aws.amazon.com/access-analyzer/latest/APIReference/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("AccessAnalyzer", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toStartPolicyGeneration")
    def to_start_policy_generation(self) -> "AccessAnalyzer":
        '''(experimental) Grants permission to start a policy generation.

        Access Level: Write

        Dependent actions:

        - iam:PassRole

        https://docs.aws.amazon.com/access-analyzer/latest/APIReference/API_StartPolicyGeneration.html

        :stability: experimental
        '''
        return typing.cast("AccessAnalyzer", jsii.invoke(self, "toStartPolicyGeneration", []))

    @jsii.member(jsii_name="toStartResourceScan")
    def to_start_resource_scan(self) -> "AccessAnalyzer":
        '''(experimental) Grants permission to start a scan of the policies applied to a resource.

        Access Level: Write

        https://docs.aws.amazon.com/access-analyzer/latest/APIReference/API_StartResourceScan.html

        :stability: experimental
        '''
        return typing.cast("AccessAnalyzer", jsii.invoke(self, "toStartResourceScan", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "AccessAnalyzer":
        '''(experimental) Grants permission to add a tag to a resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/access-analyzer/latest/APIReference/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("AccessAnalyzer", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "AccessAnalyzer":
        '''(experimental) Grants permission to remove a tag from a resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/access-analyzer/latest/APIReference/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("AccessAnalyzer", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateArchiveRule")
    def to_update_archive_rule(self) -> "AccessAnalyzer":
        '''(experimental) Grants permission to modify an archive rule.

        Access Level: Write

        https://docs.aws.amazon.com/access-analyzer/latest/APIReference/API_UpdateArchiveRule.html

        :stability: experimental
        '''
        return typing.cast("AccessAnalyzer", jsii.invoke(self, "toUpdateArchiveRule", []))

    @jsii.member(jsii_name="toUpdateFindings")
    def to_update_findings(self) -> "AccessAnalyzer":
        '''(experimental) Grants permission to modify findings.

        Access Level: Write

        https://docs.aws.amazon.com/access-analyzer/latest/APIReference/API_UpdateFindings.html

        :stability: experimental
        '''
        return typing.cast("AccessAnalyzer", jsii.invoke(self, "toUpdateFindings", []))

    @jsii.member(jsii_name="toValidatePolicy")
    def to_validate_policy(self) -> "AccessAnalyzer":
        '''(experimental) Grants permission to validate a policy.

        Access Level: Read

        https://docs.aws.amazon.com/access-analyzer/latest/APIReference/API_ValidatePolicy.html

        :stability: experimental
        '''
        return typing.cast("AccessAnalyzer", jsii.invoke(self, "toValidatePolicy", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4349597f2aeca0967d4917b23b84ce2fdbf0529d3e09fe37ab9454aa5b47321a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4a909d850378a895e0bd067eea116897a2ed8e2b260b06dc8e77d4906614bded)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Account(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Account",
):
    '''(experimental) Statement provider for service `account <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsaccountmanagement.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `account <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsaccountmanagement.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="ifAccountResourceOrgPaths")
    def if_account_resource_org_paths(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Account":
        '''(experimental) Filters access by the resource path for an account in an organization.

        https://docs.aws.amazon.com/accounts/latest/reference/security_iam_service-with-iam.html#security_iam_service-with-iam-id-based-policies-conditionkeys

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f1b61620b551217185045d1bcbd34021e63c0c0e3b1a546616b6529b00e2bdf6)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Account", jsii.invoke(self, "ifAccountResourceOrgPaths", [value, operator]))

    @jsii.member(jsii_name="ifAccountResourceOrgTags")
    def if_account_resource_org_tags(
        self,
        tag_key: builtins.str,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Account":
        '''(experimental) Filters access by resource tags for an account in an organization.

        https://docs.aws.amazon.com/accounts/latest/reference/security_iam_service-with-iam.html#security_iam_service-with-iam-id-based-policies-conditionkeys

        :param tag_key: The tag key to check.
        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__941199d13ff3caa325ea480de71bfec6a8efee94f272fbfada48143aadd91fa0)
            check_type(argname="argument tag_key", value=tag_key, expected_type=type_hints["tag_key"])
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Account", jsii.invoke(self, "ifAccountResourceOrgTags", [tag_key, value, operator]))

    @jsii.member(jsii_name="ifAlternateContactTypes")
    def if_alternate_contact_types(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Account":
        '''(experimental) Filters access by alternate contact types.

        https://docs.aws.amazon.com/accounts/latest/reference/security_iam_service-with-iam.html#security_iam_service-with-iam-id-based-policies-conditionkeys

        Applies to actions:

        - .toDeleteAlternateContact()
        - .toGetAlternateContact()
        - .toPutAlternateContact()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2643b3a9fff1de165e36c095b89d5d8a73aa8eb7075a4d2526b7a28c8c675278)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Account", jsii.invoke(self, "ifAlternateContactTypes", [value, operator]))

    @jsii.member(jsii_name="ifTargetRegion")
    def if_target_region(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Account":
        '''(experimental) Filters access by a list of Regions. Enables or disables all the Regions specified here.

        https://docs.aws.amazon.com/accounts/latest/reference/security_iam_service-with-iam.html#security_iam_service-with-iam-id-based-policies-conditionkeys

        Applies to actions:

        - .toDisableRegion()
        - .toEnableRegion()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9bd31900113c07f8d016da0ff542f899b25b4e8cf84bcc7c1c7c845641772679)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Account", jsii.invoke(self, "ifTargetRegion", [value, operator]))

    @jsii.member(jsii_name="onAccount")
    def on_account(
        self,
        account: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Account":
        '''(experimental) Adds a resource of type account to the statement.

        https://docs.aws.amazon.com/accounts/latest/reference/security_iam_service-with-iam.html#security_iam_service-with-iam-id-based-policies-resources

        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2df2dbf5f5525f25556901ed08e3e31cd2e5f3fe3e2c74fd0186d00899425485)
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Account", jsii.invoke(self, "onAccount", [account, partition]))

    @jsii.member(jsii_name="onAccountInOrganization")
    def on_account_in_organization(
        self,
        management_account_id: builtins.str,
        organization_id: builtins.str,
        member_account_id: builtins.str,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Account":
        '''(experimental) Adds a resource of type accountInOrganization to the statement.

        https://docs.aws.amazon.com/accounts/latest/reference/security_iam_service-with-iam.html#security_iam_service-with-iam-id-based-policies-resources

        :param management_account_id: - Identifier for the managementAccountId.
        :param organization_id: - Identifier for the organizationId.
        :param member_account_id: - Identifier for the memberAccountId.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7c50710096876c8441151493cb672754ae2aa2c526b75ce549109cbfd7e75a16)
            check_type(argname="argument management_account_id", value=management_account_id, expected_type=type_hints["management_account_id"])
            check_type(argname="argument organization_id", value=organization_id, expected_type=type_hints["organization_id"])
            check_type(argname="argument member_account_id", value=member_account_id, expected_type=type_hints["member_account_id"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Account", jsii.invoke(self, "onAccountInOrganization", [management_account_id, organization_id, member_account_id, partition]))

    @jsii.member(jsii_name="toDeleteAlternateContact")
    def to_delete_alternate_contact(self) -> "Account":
        '''(experimental) Grants permission to delete the alternate contacts for an account.

        Access Level: Write

        Possible conditions:

        - .ifAlternateContactTypes()

        https://docs.aws.amazon.com/accounts/latest/reference/API_DeleteAlternateContact.html

        :stability: experimental
        '''
        return typing.cast("Account", jsii.invoke(self, "toDeleteAlternateContact", []))

    @jsii.member(jsii_name="toDisableRegion")
    def to_disable_region(self) -> "Account":
        '''(experimental) Grants permission to disable use of a Region.

        Access Level: Write

        Possible conditions:

        - .ifTargetRegion()

        https://docs.aws.amazon.com/general/latest/gr/rande-manage.html

        :stability: experimental
        '''
        return typing.cast("Account", jsii.invoke(self, "toDisableRegion", []))

    @jsii.member(jsii_name="toEnableRegion")
    def to_enable_region(self) -> "Account":
        '''(experimental) Grants permission to enable use of a Region.

        Access Level: Write

        Possible conditions:

        - .ifTargetRegion()

        https://docs.aws.amazon.com/general/latest/gr/rande-manage.html

        :stability: experimental
        '''
        return typing.cast("Account", jsii.invoke(self, "toEnableRegion", []))

    @jsii.member(jsii_name="toGetAlternateContact")
    def to_get_alternate_contact(self) -> "Account":
        '''(experimental) Grants permission to retrieve the alternate contacts for an account.

        Access Level: Read

        Possible conditions:

        - .ifAlternateContactTypes()

        https://docs.aws.amazon.com/accounts/latest/reference/API_GetAlternateContact.html

        :stability: experimental
        '''
        return typing.cast("Account", jsii.invoke(self, "toGetAlternateContact", []))

    @jsii.member(jsii_name="toGetContactInformation")
    def to_get_contact_information(self) -> "Account":
        '''(experimental) Grants permission to retrieve the primary contact information for an account.

        Access Level: Read

        https://docs.aws.amazon.com/accounts/latest/reference/API_GetContactInformation.html

        :stability: experimental
        '''
        return typing.cast("Account", jsii.invoke(self, "toGetContactInformation", []))

    @jsii.member(jsii_name="toListRegions")
    def to_list_regions(self) -> "Account":
        '''(experimental) Grants permission to list the available Regions.

        Access Level: List

        https://docs.aws.amazon.com/general/latest/gr/rande-manage.html

        :stability: experimental
        '''
        return typing.cast("Account", jsii.invoke(self, "toListRegions", []))

    @jsii.member(jsii_name="toPutAlternateContact")
    def to_put_alternate_contact(self) -> "Account":
        '''(experimental) Grants permission to modify the alternate contacts for an account.

        Access Level: Write

        Possible conditions:

        - .ifAlternateContactTypes()

        https://docs.aws.amazon.com/accounts/latest/reference/API_PutAlternateContact.html

        :stability: experimental
        '''
        return typing.cast("Account", jsii.invoke(self, "toPutAlternateContact", []))

    @jsii.member(jsii_name="toPutContactInformation")
    def to_put_contact_information(self) -> "Account":
        '''(experimental) Grants permission to update the primary contact information for an account.

        Access Level: Write

        https://docs.aws.amazon.com/accounts/latest/reference/API_PutContactInformation.html

        :stability: experimental
        '''
        return typing.cast("Account", jsii.invoke(self, "toPutContactInformation", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ee481377d92f7f58759284641a9c8265a811b73d1e63dae9752176f9131f0f0c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__37aadead19c69d55b20cc779c1f68f1a3056315f18885ffa9bfec295d9effbb9)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Acm(PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Acm"):
    '''(experimental) Statement provider for service `acm <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awscertificatemanager.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `acm <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awscertificatemanager.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onCertificate")
    def on_certificate(
        self,
        certificate_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Acm":
        '''(experimental) Adds a resource of type certificate to the statement.

        https://docs.aws.amazon.com/acm/latest/userguide/authen-overview.html#acm-resources-operations

        :param certificate_id: - Identifier for the certificateId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f4aa47aa9fbcdb1c41ad140ab4cbfc9a527de09bb53e6f730c3696685b5e641b)
            check_type(argname="argument certificate_id", value=certificate_id, expected_type=type_hints["certificate_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Acm", jsii.invoke(self, "onCertificate", [certificate_id, account, region, partition]))

    @jsii.member(jsii_name="toAddTagsToCertificate")
    def to_add_tags_to_certificate(self) -> "Acm":
        '''(experimental) Grants permission to add one or more tags to a certificate.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/acm/latest/APIReference/API_AddTagsToCertificate.html

        :stability: experimental
        '''
        return typing.cast("Acm", jsii.invoke(self, "toAddTagsToCertificate", []))

    @jsii.member(jsii_name="toDeleteCertificate")
    def to_delete_certificate(self) -> "Acm":
        '''(experimental) Grants permission to delete a certificate and its associated private key.

        Access Level: Write

        https://docs.aws.amazon.com/acm/latest/APIReference/API_DeleteCertificate.html

        :stability: experimental
        '''
        return typing.cast("Acm", jsii.invoke(self, "toDeleteCertificate", []))

    @jsii.member(jsii_name="toDescribeCertificate")
    def to_describe_certificate(self) -> "Acm":
        '''(experimental) Grants permission to retreive a certificates and its metadata.

        Access Level: Read

        https://docs.aws.amazon.com/acm/latest/APIReference/API_DescribeCertificate.html

        :stability: experimental
        '''
        return typing.cast("Acm", jsii.invoke(self, "toDescribeCertificate", []))

    @jsii.member(jsii_name="toExportCertificate")
    def to_export_certificate(self) -> "Acm":
        '''(experimental) Grants permission to export a private certificate issued by a private certificate authority (CA) for use anywhere.

        Access Level: Read

        https://docs.aws.amazon.com/acm/latest/APIReference/API_ExportCertificate.html

        :stability: experimental
        '''
        return typing.cast("Acm", jsii.invoke(self, "toExportCertificate", []))

    @jsii.member(jsii_name="toGetAccountConfiguration")
    def to_get_account_configuration(self) -> "Acm":
        '''(experimental) Grants permission to retrieve account level configuration from AWS Certificate Manager.

        Access Level: Read

        https://docs.aws.amazon.com/acm/latest/APIReference/API_GetAccountConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Acm", jsii.invoke(self, "toGetAccountConfiguration", []))

    @jsii.member(jsii_name="toGetCertificate")
    def to_get_certificate(self) -> "Acm":
        '''(experimental) Grants permission to retrieve a certificate and certificate chain for a certificate ARN.

        Access Level: Read

        https://docs.aws.amazon.com/acm/latest/APIReference/API_GetCertificate.html

        :stability: experimental
        '''
        return typing.cast("Acm", jsii.invoke(self, "toGetCertificate", []))

    @jsii.member(jsii_name="toImportCertificate")
    def to_import_certificate(self) -> "Acm":
        '''(experimental) Grants permission to import a 3rd party certificate into AWS Certificate Manager (ACM).

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/acm/latest/APIReference/API_ImportCertificate.html

        :stability: experimental
        '''
        return typing.cast("Acm", jsii.invoke(self, "toImportCertificate", []))

    @jsii.member(jsii_name="toListCertificates")
    def to_list_certificates(self) -> "Acm":
        '''(experimental) Grants permission to retrieve a list of the certificate ARNs and the domain name for each ARN.

        Access Level: List

        https://docs.aws.amazon.com/acm/latest/APIReference/API_ListCertificates.html

        :stability: experimental
        '''
        return typing.cast("Acm", jsii.invoke(self, "toListCertificates", []))

    @jsii.member(jsii_name="toListTagsForCertificate")
    def to_list_tags_for_certificate(self) -> "Acm":
        '''(experimental) Grants permission to lists the tags that have been associated with a certificate.

        Access Level: Read

        https://docs.aws.amazon.com/acm/latest/APIReference/API_ListTagsForCertificate.html

        :stability: experimental
        '''
        return typing.cast("Acm", jsii.invoke(self, "toListTagsForCertificate", []))

    @jsii.member(jsii_name="toPutAccountConfiguration")
    def to_put_account_configuration(self) -> "Acm":
        '''(experimental) Grants permission to update account level configuration in AWS Certificate Manager.

        Access Level: Write

        https://docs.aws.amazon.com/acm/latest/APIReference/API_PutAccountConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Acm", jsii.invoke(self, "toPutAccountConfiguration", []))

    @jsii.member(jsii_name="toRemoveTagsFromCertificate")
    def to_remove_tags_from_certificate(self) -> "Acm":
        '''(experimental) Grants permission to remove one or more tags from a certificate.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/acm/latest/APIReference/API_RemoveTagsFromCertificate.html

        :stability: experimental
        '''
        return typing.cast("Acm", jsii.invoke(self, "toRemoveTagsFromCertificate", []))

    @jsii.member(jsii_name="toRenewCertificate")
    def to_renew_certificate(self) -> "Acm":
        '''(experimental) Grants permission to renew an eligible private certificate.

        Access Level: Write

        https://docs.aws.amazon.com/acm/latest/APIReference/API_RenewCertificate.html

        :stability: experimental
        '''
        return typing.cast("Acm", jsii.invoke(self, "toRenewCertificate", []))

    @jsii.member(jsii_name="toRequestCertificate")
    def to_request_certificate(self) -> "Acm":
        '''(experimental) Grants permission to requests a public or private certificate.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/acm/latest/APIReference/API_RequestCertificate.html

        :stability: experimental
        '''
        return typing.cast("Acm", jsii.invoke(self, "toRequestCertificate", []))

    @jsii.member(jsii_name="toResendValidationEmail")
    def to_resend_validation_email(self) -> "Acm":
        '''(experimental) Grants permission to resend an email to request domain ownership validation.

        Access Level: Write

        https://docs.aws.amazon.com/acm/latest/APIReference/API_ResendValidationEmail.html

        :stability: experimental
        '''
        return typing.cast("Acm", jsii.invoke(self, "toResendValidationEmail", []))

    @jsii.member(jsii_name="toUpdateCertificateOptions")
    def to_update_certificate_options(self) -> "Acm":
        '''(experimental) Grants permission to update a certificate configuration.

        Use this to specify whether to opt in to or out of certificate transparency logging

        Access Level: Write

        https://docs.aws.amazon.com/acm/latest/APIReference/API_UpdateCertificateOptions.html

        :stability: experimental
        '''
        return typing.cast("Acm", jsii.invoke(self, "toUpdateCertificateOptions", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__43731315834b1b6253d1e2917750daffe7a207253e405e57063d2ee885f5e05f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7d27a7e85ead09c9994002df30544f8b05bcc59305aca4b155eb3cf5f877635a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class AcmPca(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.AcmPca",
):
    '''(experimental) Statement provider for service `acm-pca <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsprivatecertificateauthority.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `acm-pca <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsprivatecertificateauthority.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="ifTemplateArn")
    def if_template_arn(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "AcmPca":
        '''(experimental) Filters issue certificate requests based on the presence of TemplateArn in the request.

        https://docs.aws.amazon.com/privateca/latest/userguide/UsingTemplates.html#template-varieties

        Applies to actions:

        - .toIssueCertificate()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d85a98059a8149aa92465cdbaab161a8304e64b4e9d178f6ff37f9079cc1c5f2)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("AcmPca", jsii.invoke(self, "ifTemplateArn", [value, operator]))

    @jsii.member(jsii_name="onCertificateAuthority")
    def on_certificate_authority(
        self,
        certificate_authority_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "AcmPca":
        '''(experimental) Adds a resource of type certificate-authority to the statement.

        https://docs.aws.amazon.com/privateca/latest/userguide/authen-overview.html#acm-pca-resources-operations

        :param certificate_authority_id: - Identifier for the certificateAuthorityId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__14814049472060c583d4177d3b33aaf0a450c5e75ba37c691edc516e4f421d2d)
            check_type(argname="argument certificate_authority_id", value=certificate_authority_id, expected_type=type_hints["certificate_authority_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("AcmPca", jsii.invoke(self, "onCertificateAuthority", [certificate_authority_id, account, region, partition]))

    @jsii.member(jsii_name="toCreateCertificateAuthority")
    def to_create_certificate_authority(self) -> "AcmPca":
        '''(experimental) Grants permission to create an AWS Private CA and its associated private key and configuration.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/privateca/latest/APIReference/API_CreateCertificateAuthority.html

        :stability: experimental
        '''
        return typing.cast("AcmPca", jsii.invoke(self, "toCreateCertificateAuthority", []))

    @jsii.member(jsii_name="toCreateCertificateAuthorityAuditReport")
    def to_create_certificate_authority_audit_report(self) -> "AcmPca":
        '''(experimental) Grants permission to create an audit report for an AWS Private CA.

        Access Level: Write

        https://docs.aws.amazon.com/privateca/latest/APIReference/API_CreateCertificateAuthorityAuditReport.html

        :stability: experimental
        '''
        return typing.cast("AcmPca", jsii.invoke(self, "toCreateCertificateAuthorityAuditReport", []))

    @jsii.member(jsii_name="toCreatePermission")
    def to_create_permission(self) -> "AcmPca":
        '''(experimental) Grants permission to create a permission for an AWS Private CA.

        Access Level: Permissions management

        https://docs.aws.amazon.com/privateca/latest/APIReference/API_CreatePermission.html

        :stability: experimental
        '''
        return typing.cast("AcmPca", jsii.invoke(self, "toCreatePermission", []))

    @jsii.member(jsii_name="toDeleteCertificateAuthority")
    def to_delete_certificate_authority(self) -> "AcmPca":
        '''(experimental) Grants permission to delete an AWS Private CA and its associated private key and configuration.

        Access Level: Write

        https://docs.aws.amazon.com/privateca/latest/APIReference/API_DeleteCertificateAuthority.html

        :stability: experimental
        '''
        return typing.cast("AcmPca", jsii.invoke(self, "toDeleteCertificateAuthority", []))

    @jsii.member(jsii_name="toDeletePermission")
    def to_delete_permission(self) -> "AcmPca":
        '''(experimental) Grants permission to delete a permission for an AWS Private CA.

        Access Level: Permissions management

        https://docs.aws.amazon.com/privateca/latest/APIReference/API_DeletePermission.html

        :stability: experimental
        '''
        return typing.cast("AcmPca", jsii.invoke(self, "toDeletePermission", []))

    @jsii.member(jsii_name="toDeletePolicy")
    def to_delete_policy(self) -> "AcmPca":
        '''(experimental) Grants permission to delete the policy for an AWS Private CA.

        Access Level: Permissions management

        https://docs.aws.amazon.com/privateca/latest/APIReference/API_DeletePolicy.html

        :stability: experimental
        '''
        return typing.cast("AcmPca", jsii.invoke(self, "toDeletePolicy", []))

    @jsii.member(jsii_name="toDescribeCertificateAuthority")
    def to_describe_certificate_authority(self) -> "AcmPca":
        '''(experimental) Grants permission to return a list of the configuration and status fields contained in the specified AWS Private CA.

        Access Level: Read

        https://docs.aws.amazon.com/privateca/latest/APIReference/API_DescribeCertificateAuthority.html

        :stability: experimental
        '''
        return typing.cast("AcmPca", jsii.invoke(self, "toDescribeCertificateAuthority", []))

    @jsii.member(jsii_name="toDescribeCertificateAuthorityAuditReport")
    def to_describe_certificate_authority_audit_report(self) -> "AcmPca":
        '''(experimental) Grants permission to return the status and information about an AWS Private CA audit report.

        Access Level: Read

        https://docs.aws.amazon.com/privateca/latest/APIReference/API_DescribeCertificateAuthorityAuditReport.html

        :stability: experimental
        '''
        return typing.cast("AcmPca", jsii.invoke(self, "toDescribeCertificateAuthorityAuditReport", []))

    @jsii.member(jsii_name="toGetCertificate")
    def to_get_certificate(self) -> "AcmPca":
        '''(experimental) Grants permission to retrieve an AWS Private CA certificate and certificate chain for the certificate authority specified by an ARN.

        Access Level: Read

        https://docs.aws.amazon.com/privateca/latest/APIReference/API_GetCertificate.html

        :stability: experimental
        '''
        return typing.cast("AcmPca", jsii.invoke(self, "toGetCertificate", []))

    @jsii.member(jsii_name="toGetCertificateAuthorityCertificate")
    def to_get_certificate_authority_certificate(self) -> "AcmPca":
        '''(experimental) Grants permission to retrieve an AWS Private CA certificate and certificate chain for the certificate authority specified by an ARN.

        Access Level: Read

        https://docs.aws.amazon.com/privateca/latest/APIReference/API_GetCertificateAuthorityCertificate.html

        :stability: experimental
        '''
        return typing.cast("AcmPca", jsii.invoke(self, "toGetCertificateAuthorityCertificate", []))

    @jsii.member(jsii_name="toGetCertificateAuthorityCsr")
    def to_get_certificate_authority_csr(self) -> "AcmPca":
        '''(experimental) Grants permission to retrieve an AWS Private CA certificate signing request (CSR) for the certificate-authority specified by an ARN.

        Access Level: Read

        https://docs.aws.amazon.com/privateca/latest/APIReference/API_GetCertificateAuthorityCsr.html

        :stability: experimental
        '''
        return typing.cast("AcmPca", jsii.invoke(self, "toGetCertificateAuthorityCsr", []))

    @jsii.member(jsii_name="toGetPolicy")
    def to_get_policy(self) -> "AcmPca":
        '''(experimental) Grants permission to retrieve the policy on an AWS Private CA.

        Access Level: Read

        https://docs.aws.amazon.com/privateca/latest/APIReference/API_GetPolicy.html

        :stability: experimental
        '''
        return typing.cast("AcmPca", jsii.invoke(self, "toGetPolicy", []))

    @jsii.member(jsii_name="toImportCertificateAuthorityCertificate")
    def to_import_certificate_authority_certificate(self) -> "AcmPca":
        '''(experimental) Grants permission to import an SSL/TLS certificate into AWS Private CA for use as the CA certificate of an AWS Private CA.

        Access Level: Write

        https://docs.aws.amazon.com/privateca/latest/APIReference/API_ImportCertificateAuthorityCertificate.html

        :stability: experimental
        '''
        return typing.cast("AcmPca", jsii.invoke(self, "toImportCertificateAuthorityCertificate", []))

    @jsii.member(jsii_name="toIssueCertificate")
    def to_issue_certificate(self) -> "AcmPca":
        '''(experimental) Grants permission to issue an AWS Private CA certificate.

        Access Level: Write

        Possible conditions:

        - .ifTemplateArn()

        https://docs.aws.amazon.com/privateca/latest/APIReference/API_IssueCertificate.html

        :stability: experimental
        '''
        return typing.cast("AcmPca", jsii.invoke(self, "toIssueCertificate", []))

    @jsii.member(jsii_name="toListCertificateAuthorities")
    def to_list_certificate_authorities(self) -> "AcmPca":
        '''(experimental) Grants permission to retrieve a list of the AWS Private CA certificate authority ARNs, and a summary of the status of each CA in the calling account.

        Access Level: List

        https://docs.aws.amazon.com/privateca/latest/APIReference/API_ListCertificateAuthorities.html

        :stability: experimental
        '''
        return typing.cast("AcmPca", jsii.invoke(self, "toListCertificateAuthorities", []))

    @jsii.member(jsii_name="toListPermissions")
    def to_list_permissions(self) -> "AcmPca":
        '''(experimental) Grants permission to list the permissions that have been applied to the AWS Private CA certificate authority.

        Access Level: Read

        https://docs.aws.amazon.com/privateca/latest/APIReference/API_ListPermissions.html

        :stability: experimental
        '''
        return typing.cast("AcmPca", jsii.invoke(self, "toListPermissions", []))

    @jsii.member(jsii_name="toListTags")
    def to_list_tags(self) -> "AcmPca":
        '''(experimental) Grants permission to list the tags that have been applied to the AWS Private CA certificate authority.

        Access Level: Read

        https://docs.aws.amazon.com/privateca/latest/APIReference/API_ListTags.html

        :stability: experimental
        '''
        return typing.cast("AcmPca", jsii.invoke(self, "toListTags", []))

    @jsii.member(jsii_name="toPutPolicy")
    def to_put_policy(self) -> "AcmPca":
        '''(experimental) Grants permission to put a policy on an AWS Private CA.

        Access Level: Permissions management

        https://docs.aws.amazon.com/privateca/latest/APIReference/API_PutPolicy.html

        :stability: experimental
        '''
        return typing.cast("AcmPca", jsii.invoke(self, "toPutPolicy", []))

    @jsii.member(jsii_name="toRestoreCertificateAuthority")
    def to_restore_certificate_authority(self) -> "AcmPca":
        '''(experimental) Grants permission to restore an AWS Private CA from the deleted state to the state it was in when deleted.

        Access Level: Write

        https://docs.aws.amazon.com/privateca/latest/APIReference/API_RestoreCertificateAuthority.html

        :stability: experimental
        '''
        return typing.cast("AcmPca", jsii.invoke(self, "toRestoreCertificateAuthority", []))

    @jsii.member(jsii_name="toRevokeCertificate")
    def to_revoke_certificate(self) -> "AcmPca":
        '''(experimental) Grants permission to revoke a certificate issued by an AWS Private CA.

        Access Level: Write

        https://docs.aws.amazon.com/privateca/latest/APIReference/API_RevokeCertificate.html

        :stability: experimental
        '''
        return typing.cast("AcmPca", jsii.invoke(self, "toRevokeCertificate", []))

    @jsii.member(jsii_name="toTagCertificateAuthority")
    def to_tag_certificate_authority(self) -> "AcmPca":
        '''(experimental) Grants permission to add one or more tags to an AWS Private CA.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/privateca/latest/APIReference/API_TagCertificateAuthority.html

        :stability: experimental
        '''
        return typing.cast("AcmPca", jsii.invoke(self, "toTagCertificateAuthority", []))

    @jsii.member(jsii_name="toUntagCertificateAuthority")
    def to_untag_certificate_authority(self) -> "AcmPca":
        '''(experimental) Grants permission to remove one or more tags from an AWS Private CA.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/privateca/latest/APIReference/API_UntagCertificateAuthority.html

        :stability: experimental
        '''
        return typing.cast("AcmPca", jsii.invoke(self, "toUntagCertificateAuthority", []))

    @jsii.member(jsii_name="toUpdateCertificateAuthority")
    def to_update_certificate_authority(self) -> "AcmPca":
        '''(experimental) Grants permission to update the configuration of an AWS Private CA.

        Access Level: Write

        https://docs.aws.amazon.com/privateca/latest/APIReference/API_UpdateCertificateAuthority.html

        :stability: experimental
        '''
        return typing.cast("AcmPca", jsii.invoke(self, "toUpdateCertificateAuthority", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4d59ec2cefc62cfb96fb1e9bdcdb2953069b4ef668ff75e5ae35aa2a4b0ae8f6)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a79a936dd6d638ddad4d8122dfa3cb1e216c97b801cdd43cdd8cd65e73cbe85a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Activate(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Activate",
):
    '''(experimental) Statement provider for service `activate <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsactivate.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `activate <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsactivate.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="toCreateForm")
    def to_create_form(self) -> "Activate":
        '''(experimental) Grants permission to submit an Activate application form.

        Access Level: Write

        :stability: experimental
        '''
        return typing.cast("Activate", jsii.invoke(self, "toCreateForm", []))

    @jsii.member(jsii_name="toGetAccountContact")
    def to_get_account_contact(self) -> "Activate":
        '''(experimental) Grants permission to get the AWS account contact information.

        Access Level: Read

        :stability: experimental
        '''
        return typing.cast("Activate", jsii.invoke(self, "toGetAccountContact", []))

    @jsii.member(jsii_name="toGetContentInfo")
    def to_get_content_info(self) -> "Activate":
        '''(experimental) Grants permission to get Activate tech posts and offer information.

        Access Level: Read

        :stability: experimental
        '''
        return typing.cast("Activate", jsii.invoke(self, "toGetContentInfo", []))

    @jsii.member(jsii_name="toGetCosts")
    def to_get_costs(self) -> "Activate":
        '''(experimental) Grants permission to get the AWS cost information.

        Access Level: Read

        :stability: experimental
        '''
        return typing.cast("Activate", jsii.invoke(self, "toGetCosts", []))

    @jsii.member(jsii_name="toGetCredits")
    def to_get_credits(self) -> "Activate":
        '''(experimental) Grants permission to get the AWS credit information.

        Access Level: Read

        :stability: experimental
        '''
        return typing.cast("Activate", jsii.invoke(self, "toGetCredits", []))

    @jsii.member(jsii_name="toGetMemberInfo")
    def to_get_member_info(self) -> "Activate":
        '''(experimental) Grants permission to get the Activate member information.

        Access Level: Read

        :stability: experimental
        '''
        return typing.cast("Activate", jsii.invoke(self, "toGetMemberInfo", []))

    @jsii.member(jsii_name="toGetProgram")
    def to_get_program(self) -> "Activate":
        '''(experimental) Grants permission to get an Activate program.

        Access Level: Read

        :stability: experimental
        '''
        return typing.cast("Activate", jsii.invoke(self, "toGetProgram", []))

    @jsii.member(jsii_name="toPutMemberInfo")
    def to_put_member_info(self) -> "Activate":
        '''(experimental) Grants permission to create or update the Activate member information.

        Access Level: Write

        :stability: experimental
        '''
        return typing.cast("Activate", jsii.invoke(self, "toPutMemberInfo", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6041471496aa4ef4f4cc66a5a97d9f01a4527747f9074b68c29a50c859b15016)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__36279c6cc54d0d9a5e8b7d08d8c55eb0e3cd106fd8ddc4886edbd5655bb6bc13)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Airflow(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Airflow",
):
    '''(experimental) Statement provider for service `airflow <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonmanagedworkflowsforapacheairflow.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `airflow <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonmanagedworkflowsforapacheairflow.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onEnvironment")
    def on_environment(
        self,
        environment_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Airflow":
        '''(experimental) Adds a resource of type environment to the statement.

        https://docs.aws.amazon.com/mwaa/latest/userguide/mwaa-actions-resources.html#mwaa-resources

        :param environment_name: - Identifier for the environmentName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__de79b29cba93cb779e412376cc195666e8206fa0d174e13c7c58cc0216bd9e7c)
            check_type(argname="argument environment_name", value=environment_name, expected_type=type_hints["environment_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Airflow", jsii.invoke(self, "onEnvironment", [environment_name, account, region, partition]))

    @jsii.member(jsii_name="onRbacRole")
    def on_rbac_role(
        self,
        environment_name: builtins.str,
        role_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Airflow":
        '''(experimental) Adds a resource of type rbac-role to the statement.

        https://docs.aws.amazon.com/mwaa/latest/userguide/mwaa-actions-resources.html#mwaa-resources

        :param environment_name: - Identifier for the environmentName.
        :param role_name: - Identifier for the roleName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7ef8481df6d95cb24fe8ba18db4e69814788a2cb2e9e860b50414b28bb04af00)
            check_type(argname="argument environment_name", value=environment_name, expected_type=type_hints["environment_name"])
            check_type(argname="argument role_name", value=role_name, expected_type=type_hints["role_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Airflow", jsii.invoke(self, "onRbacRole", [environment_name, role_name, account, region, partition]))

    @jsii.member(jsii_name="toCreateCliToken")
    def to_create_cli_token(self) -> "Airflow":
        '''(experimental) Grants permission to create a short-lived token that allows a user to invoke Airflow CLI via an endpoint on the Apache Airflow Webserver.

        Access Level: Write

        https://docs.aws.amazon.com/mwaa/latest/userguide/mwaa-actions-resources.html

        :stability: experimental
        '''
        return typing.cast("Airflow", jsii.invoke(self, "toCreateCliToken", []))

    @jsii.member(jsii_name="toCreateEnvironment")
    def to_create_environment(self) -> "Airflow":
        '''(experimental) Grants permission to create an Amazon MWAA environment.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()
        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/mwaa/latest/userguide/mwaa-actions-resources.html

        :stability: experimental
        '''
        return typing.cast("Airflow", jsii.invoke(self, "toCreateEnvironment", []))

    @jsii.member(jsii_name="toCreateWebLoginToken")
    def to_create_web_login_token(self) -> "Airflow":
        '''(experimental) Grants permission to create a short-lived token that allows a user to log into Apache Airflow web UI.

        Access Level: Write

        https://docs.aws.amazon.com/mwaa/latest/userguide/mwaa-actions-resources.html

        :stability: experimental
        '''
        return typing.cast("Airflow", jsii.invoke(self, "toCreateWebLoginToken", []))

    @jsii.member(jsii_name="toDeleteEnvironment")
    def to_delete_environment(self) -> "Airflow":
        '''(experimental) Grants permission to delete an Amazon MWAA environment.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/mwaa/latest/userguide/mwaa-actions-resources.html

        :stability: experimental
        '''
        return typing.cast("Airflow", jsii.invoke(self, "toDeleteEnvironment", []))

    @jsii.member(jsii_name="toGetEnvironment")
    def to_get_environment(self) -> "Airflow":
        '''(experimental) Grants permission to view details about an Amazon MWAA environment.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/mwaa/latest/userguide/mwaa-actions-resources.html

        :stability: experimental
        '''
        return typing.cast("Airflow", jsii.invoke(self, "toGetEnvironment", []))

    @jsii.member(jsii_name="toListEnvironments")
    def to_list_environments(self) -> "Airflow":
        '''(experimental) Grants permission to list the Amazon MWAA environments in your account.

        Access Level: List

        https://docs.aws.amazon.com/mwaa/latest/userguide/mwaa-actions-resources.html

        :stability: experimental
        '''
        return typing.cast("Airflow", jsii.invoke(self, "toListEnvironments", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Airflow":
        '''(experimental) Grants permission to lists tag for an Amazon MWAA environment.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/mwaa/latest/userguide/mwaa-actions-resources.html

        :stability: experimental
        '''
        return typing.cast("Airflow", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toPublishMetrics")
    def to_publish_metrics(self) -> "Airflow":
        '''(experimental) Grants permission to publish metrics for an Amazon MWAA environment.

        Access Level: Write

        https://docs.aws.amazon.com/mwaa/latest/userguide/mwaa-actions-resources.html

        :stability: experimental
        '''
        return typing.cast("Airflow", jsii.invoke(self, "toPublishMetrics", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Airflow":
        '''(experimental) Grants permission to tag an Amazon MWAA environment.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()
        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/mwaa/latest/userguide/mwaa-actions-resources.html

        :stability: experimental
        '''
        return typing.cast("Airflow", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Airflow":
        '''(experimental) Grants permission to untag an Amazon MWAA environment.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/mwaa/latest/userguide/mwaa-actions-resources.html

        :stability: experimental
        '''
        return typing.cast("Airflow", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateEnvironment")
    def to_update_environment(self) -> "Airflow":
        '''(experimental) Grants permission to modify an Amazon MWAA environment.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/mwaa/latest/userguide/mwaa-actions-resources.html

        :stability: experimental
        '''
        return typing.cast("Airflow", jsii.invoke(self, "toUpdateEnvironment", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6adafd7e4795f67696a3fbb38b6745cce1fb4f797efd69b2d0e1347b903e4e4d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__02e427f093065ff324dca88d9bcc59548ffe5ead70182234be53c46845ea1792)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class All(PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.All"):
    '''(experimental) Action provider for all services.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Action provider for all services.

        Use this provider to globally allow/deny actions, based on global conditions.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])


class Amplify(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Amplify",
):
    '''(experimental) Statement provider for service `amplify <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsamplify.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `amplify <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsamplify.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onApps")
    def on_apps(
        self,
        app_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Amplify":
        '''(experimental) Adds a resource of type apps to the statement.

        https://docs.aws.amazon.com/amplify/latest/userguide/welcome.html

        :param app_id: - Identifier for the appId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d530644189d7b2cde1a945f59bbbbfa3726b20863004756b081cd63643f88ef3)
            check_type(argname="argument app_id", value=app_id, expected_type=type_hints["app_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Amplify", jsii.invoke(self, "onApps", [app_id, account, region, partition]))

    @jsii.member(jsii_name="onBranches")
    def on_branches(
        self,
        app_id: builtins.str,
        branch_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Amplify":
        '''(experimental) Adds a resource of type branches to the statement.

        https://docs.aws.amazon.com/amplify/latest/userguide/welcome.html

        :param app_id: - Identifier for the appId.
        :param branch_name: - Identifier for the branchName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ddf9aaed98f208bb8ce028947e7d765ed59a1be501cde1a023c9a4ce282617e7)
            check_type(argname="argument app_id", value=app_id, expected_type=type_hints["app_id"])
            check_type(argname="argument branch_name", value=branch_name, expected_type=type_hints["branch_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Amplify", jsii.invoke(self, "onBranches", [app_id, branch_name, account, region, partition]))

    @jsii.member(jsii_name="onDomains")
    def on_domains(
        self,
        app_id: builtins.str,
        domain_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Amplify":
        '''(experimental) Adds a resource of type domains to the statement.

        https://docs.aws.amazon.com/amplify/latest/userguide/welcome.html

        :param app_id: - Identifier for the appId.
        :param domain_name: - Identifier for the domainName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__be3b229a5db0d37cdaac030b586160c999ac86c5c11fb89cecad4871c97dae8e)
            check_type(argname="argument app_id", value=app_id, expected_type=type_hints["app_id"])
            check_type(argname="argument domain_name", value=domain_name, expected_type=type_hints["domain_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Amplify", jsii.invoke(self, "onDomains", [app_id, domain_name, account, region, partition]))

    @jsii.member(jsii_name="onJobs")
    def on_jobs(
        self,
        app_id: builtins.str,
        branch_name: builtins.str,
        job_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Amplify":
        '''(experimental) Adds a resource of type jobs to the statement.

        https://docs.aws.amazon.com/amplify/latest/userguide/welcome.html

        :param app_id: - Identifier for the appId.
        :param branch_name: - Identifier for the branchName.
        :param job_id: - Identifier for the jobId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a4c71f59cf62b948b26667041837ff4cdc3e9fd62f12732e183dac6230de807f)
            check_type(argname="argument app_id", value=app_id, expected_type=type_hints["app_id"])
            check_type(argname="argument branch_name", value=branch_name, expected_type=type_hints["branch_name"])
            check_type(argname="argument job_id", value=job_id, expected_type=type_hints["job_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Amplify", jsii.invoke(self, "onJobs", [app_id, branch_name, job_id, account, region, partition]))

    @jsii.member(jsii_name="toCreateApp")
    def to_create_app(self) -> "Amplify":
        '''(experimental) Creates a new Amplify App.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/amplify/latest/userguide/welcome.html

        :stability: experimental
        '''
        return typing.cast("Amplify", jsii.invoke(self, "toCreateApp", []))

    @jsii.member(jsii_name="toCreateBackendEnvironment")
    def to_create_backend_environment(self) -> "Amplify":
        '''(experimental) Creates a new backend environment for an Amplify App.

        Access Level: Write

        https://docs.aws.amazon.com/amplify/latest/userguide/welcome.html

        :stability: experimental
        '''
        return typing.cast("Amplify", jsii.invoke(self, "toCreateBackendEnvironment", []))

    @jsii.member(jsii_name="toCreateBranch")
    def to_create_branch(self) -> "Amplify":
        '''(experimental) Creates a new Branch for an Amplify App.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/amplify/latest/userguide/welcome.html

        :stability: experimental
        '''
        return typing.cast("Amplify", jsii.invoke(self, "toCreateBranch", []))

    @jsii.member(jsii_name="toCreateDeployment")
    def to_create_deployment(self) -> "Amplify":
        '''(experimental) Create a deployment for manual deploy apps. (Apps are not connected to repository).

        Access Level: Write

        https://docs.aws.amazon.com/amplify/latest/userguide/welcome.html

        :stability: experimental
        '''
        return typing.cast("Amplify", jsii.invoke(self, "toCreateDeployment", []))

    @jsii.member(jsii_name="toCreateDomainAssociation")
    def to_create_domain_association(self) -> "Amplify":
        '''(experimental) Create a new DomainAssociation on an App.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/amplify/latest/userguide/welcome.html

        :stability: experimental
        '''
        return typing.cast("Amplify", jsii.invoke(self, "toCreateDomainAssociation", []))

    @jsii.member(jsii_name="toCreateWebHook")
    def to_create_web_hook(self) -> "Amplify":
        '''(experimental) Create a new webhook on an App.

        Access Level: Write

        https://docs.aws.amazon.com/amplify/latest/userguide/welcome.html

        :stability: experimental
        '''
        return typing.cast("Amplify", jsii.invoke(self, "toCreateWebHook", []))

    @jsii.member(jsii_name="toDeleteApp")
    def to_delete_app(self) -> "Amplify":
        '''(experimental) Delete an existing Amplify App by appId.

        Access Level: Write

        https://docs.aws.amazon.com/amplify/latest/userguide/welcome.html

        :stability: experimental
        '''
        return typing.cast("Amplify", jsii.invoke(self, "toDeleteApp", []))

    @jsii.member(jsii_name="toDeleteBackendEnvironment")
    def to_delete_backend_environment(self) -> "Amplify":
        '''(experimental) Deletes a branch for an Amplify App.

        Access Level: Write

        https://docs.aws.amazon.com/amplify/latest/userguide/welcome.html

        :stability: experimental
        '''
        return typing.cast("Amplify", jsii.invoke(self, "toDeleteBackendEnvironment", []))

    @jsii.member(jsii_name="toDeleteBranch")
    def to_delete_branch(self) -> "Amplify":
        '''(experimental) Deletes a branch for an Amplify App.

        Access Level: Write

        https://docs.aws.amazon.com/amplify/latest/userguide/welcome.html

        :stability: experimental
        '''
        return typing.cast("Amplify", jsii.invoke(self, "toDeleteBranch", []))

    @jsii.member(jsii_name="toDeleteDomainAssociation")
    def to_delete_domain_association(self) -> "Amplify":
        '''(experimental) Deletes a DomainAssociation.

        Access Level: Write

        https://docs.aws.amazon.com/amplify/latest/userguide/welcome.html

        :stability: experimental
        '''
        return typing.cast("Amplify", jsii.invoke(self, "toDeleteDomainAssociation", []))

    @jsii.member(jsii_name="toDeleteJob")
    def to_delete_job(self) -> "Amplify":
        '''(experimental) Delete a job, for an Amplify branch, part of Amplify App.

        Access Level: Write

        https://docs.aws.amazon.com/amplify/latest/userguide/welcome.html

        :stability: experimental
        '''
        return typing.cast("Amplify", jsii.invoke(self, "toDeleteJob", []))

    @jsii.member(jsii_name="toDeleteWebHook")
    def to_delete_web_hook(self) -> "Amplify":
        '''(experimental) Delete a webhook by id.

        Access Level: Write

        https://docs.aws.amazon.com/amplify/latest/userguide/welcome.html

        :stability: experimental
        '''
        return typing.cast("Amplify", jsii.invoke(self, "toDeleteWebHook", []))

    @jsii.member(jsii_name="toGenerateAccessLogs")
    def to_generate_access_logs(self) -> "Amplify":
        '''(experimental) Generate website access logs for a specific time range via a pre-signed URL.

        Access Level: Write

        https://docs.aws.amazon.com/amplify/latest/userguide/welcome.html

        :stability: experimental
        '''
        return typing.cast("Amplify", jsii.invoke(self, "toGenerateAccessLogs", []))

    @jsii.member(jsii_name="toGetApp")
    def to_get_app(self) -> "Amplify":
        '''(experimental) Retrieves an existing Amplify App by appId.

        Access Level: Read

        https://docs.aws.amazon.com/amplify/latest/userguide/welcome.html

        :stability: experimental
        '''
        return typing.cast("Amplify", jsii.invoke(self, "toGetApp", []))

    @jsii.member(jsii_name="toGetArtifactUrl")
    def to_get_artifact_url(self) -> "Amplify":
        '''(experimental) Retrieves artifact info that corresponds to a artifactId.

        Access Level: Read

        https://docs.aws.amazon.com/amplify/latest/userguide/welcome.html

        :stability: experimental
        '''
        return typing.cast("Amplify", jsii.invoke(self, "toGetArtifactUrl", []))

    @jsii.member(jsii_name="toGetBackendEnvironment")
    def to_get_backend_environment(self) -> "Amplify":
        '''(experimental) Retrieves a backend environment for an Amplify App.

        Access Level: Read

        https://docs.aws.amazon.com/amplify/latest/userguide/welcome.html

        :stability: experimental
        '''
        return typing.cast("Amplify", jsii.invoke(self, "toGetBackendEnvironment", []))

    @jsii.member(jsii_name="toGetBranch")
    def to_get_branch(self) -> "Amplify":
        '''(experimental) Retrieves a branch for an Amplify App.

        Access Level: Read

        https://docs.aws.amazon.com/amplify/latest/userguide/welcome.html

        :stability: experimental
        '''
        return typing.cast("Amplify", jsii.invoke(self, "toGetBranch", []))

    @jsii.member(jsii_name="toGetDomainAssociation")
    def to_get_domain_association(self) -> "Amplify":
        '''(experimental) Retrieves domain info that corresponds to an appId and domainName.

        Access Level: Read

        https://docs.aws.amazon.com/amplify/latest/userguide/welcome.html

        :stability: experimental
        '''
        return typing.cast("Amplify", jsii.invoke(self, "toGetDomainAssociation", []))

    @jsii.member(jsii_name="toGetJob")
    def to_get_job(self) -> "Amplify":
        '''(experimental) Get a job for a branch, part of an Amplify App.

        Access Level: Read

        https://docs.aws.amazon.com/amplify/latest/userguide/welcome.html

        :stability: experimental
        '''
        return typing.cast("Amplify", jsii.invoke(self, "toGetJob", []))

    @jsii.member(jsii_name="toGetWebHook")
    def to_get_web_hook(self) -> "Amplify":
        '''(experimental) Retrieves webhook info that corresponds to a webhookId.

        Access Level: Read

        https://docs.aws.amazon.com/amplify/latest/userguide/welcome.html

        :stability: experimental
        '''
        return typing.cast("Amplify", jsii.invoke(self, "toGetWebHook", []))

    @jsii.member(jsii_name="toListApps")
    def to_list_apps(self) -> "Amplify":
        '''(experimental) Lists existing Amplify Apps.

        Access Level: List

        https://docs.aws.amazon.com/amplify/latest/userguide/welcome.html

        :stability: experimental
        '''
        return typing.cast("Amplify", jsii.invoke(self, "toListApps", []))

    @jsii.member(jsii_name="toListArtifacts")
    def to_list_artifacts(self) -> "Amplify":
        '''(experimental) List artifacts with an app, a branch, a job and an artifact type.

        Access Level: List

        https://docs.aws.amazon.com/amplify/latest/userguide/welcome.html

        :stability: experimental
        '''
        return typing.cast("Amplify", jsii.invoke(self, "toListArtifacts", []))

    @jsii.member(jsii_name="toListBackendEnvironments")
    def to_list_backend_environments(self) -> "Amplify":
        '''(experimental) Lists backend environments for an Amplify App.

        Access Level: List

        https://docs.aws.amazon.com/amplify/latest/userguide/welcome.html

        :stability: experimental
        '''
        return typing.cast("Amplify", jsii.invoke(self, "toListBackendEnvironments", []))

    @jsii.member(jsii_name="toListBranches")
    def to_list_branches(self) -> "Amplify":
        '''(experimental) Lists branches for an Amplify App.

        Access Level: List

        https://docs.aws.amazon.com/amplify/latest/userguide/welcome.html

        :stability: experimental
        '''
        return typing.cast("Amplify", jsii.invoke(self, "toListBranches", []))

    @jsii.member(jsii_name="toListDomainAssociations")
    def to_list_domain_associations(self) -> "Amplify":
        '''(experimental) List domains with an app.

        Access Level: List

        https://docs.aws.amazon.com/amplify/latest/userguide/welcome.html

        :stability: experimental
        '''
        return typing.cast("Amplify", jsii.invoke(self, "toListDomainAssociations", []))

    @jsii.member(jsii_name="toListJobs")
    def to_list_jobs(self) -> "Amplify":
        '''(experimental) List Jobs for a branch, part of an Amplify App.

        Access Level: List

        https://docs.aws.amazon.com/amplify/latest/userguide/welcome.html

        :stability: experimental
        '''
        return typing.cast("Amplify", jsii.invoke(self, "toListJobs", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Amplify":
        '''(experimental) List tags for an AWS Amplify Console resource.

        Access Level: Read

        https://docs.aws.amazon.com/amplify/latest/userguide/welcome.html

        :stability: experimental
        '''
        return typing.cast("Amplify", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toListWebHooks")
    def to_list_web_hooks(self) -> "Amplify":
        '''(experimental) List webhooks on an App.

        Access Level: List

        https://docs.aws.amazon.com/amplify/latest/userguide/welcome.html

        :stability: experimental
        '''
        return typing.cast("Amplify", jsii.invoke(self, "toListWebHooks", []))

    @jsii.member(jsii_name="toStartDeployment")
    def to_start_deployment(self) -> "Amplify":
        '''(experimental) Start a deployment for manual deploy apps. (Apps are not connected to repository).

        Access Level: Write

        https://docs.aws.amazon.com/amplify/latest/userguide/welcome.html

        :stability: experimental
        '''
        return typing.cast("Amplify", jsii.invoke(self, "toStartDeployment", []))

    @jsii.member(jsii_name="toStartJob")
    def to_start_job(self) -> "Amplify":
        '''(experimental) Starts a new job for a branch, part of an Amplify App.

        Access Level: Write

        https://docs.aws.amazon.com/amplify/latest/userguide/welcome.html

        :stability: experimental
        '''
        return typing.cast("Amplify", jsii.invoke(self, "toStartJob", []))

    @jsii.member(jsii_name="toStopJob")
    def to_stop_job(self) -> "Amplify":
        '''(experimental) Stop a job that is in progress, for an Amplify branch, part of Amplify App.

        Access Level: Write

        https://docs.aws.amazon.com/amplify/latest/userguide/welcome.html

        :stability: experimental
        '''
        return typing.cast("Amplify", jsii.invoke(self, "toStopJob", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Amplify":
        '''(experimental) This action tags an AWS Amplify Console resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/amplify/latest/userguide/welcome.html

        :stability: experimental
        '''
        return typing.cast("Amplify", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Amplify":
        '''(experimental) This action removes a tag from an AWS Amplify Console resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/amplify/latest/userguide/welcome.html

        :stability: experimental
        '''
        return typing.cast("Amplify", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateApp")
    def to_update_app(self) -> "Amplify":
        '''(experimental) Updates an existing Amplify App.

        Access Level: Write

        https://docs.aws.amazon.com/amplify/latest/userguide/welcome.html

        :stability: experimental
        '''
        return typing.cast("Amplify", jsii.invoke(self, "toUpdateApp", []))

    @jsii.member(jsii_name="toUpdateBranch")
    def to_update_branch(self) -> "Amplify":
        '''(experimental) Updates a branch for an Amplify App.

        Access Level: Write

        https://docs.aws.amazon.com/amplify/latest/userguide/welcome.html

        :stability: experimental
        '''
        return typing.cast("Amplify", jsii.invoke(self, "toUpdateBranch", []))

    @jsii.member(jsii_name="toUpdateDomainAssociation")
    def to_update_domain_association(self) -> "Amplify":
        '''(experimental) Update a DomainAssociation on an App.

        Access Level: Write

        https://docs.aws.amazon.com/amplify/latest/userguide/welcome.html

        :stability: experimental
        '''
        return typing.cast("Amplify", jsii.invoke(self, "toUpdateDomainAssociation", []))

    @jsii.member(jsii_name="toUpdateWebHook")
    def to_update_web_hook(self) -> "Amplify":
        '''(experimental) Update a webhook.

        Access Level: Write

        https://docs.aws.amazon.com/amplify/latest/userguide/welcome.html

        :stability: experimental
        '''
        return typing.cast("Amplify", jsii.invoke(self, "toUpdateWebHook", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c3492c9460852b76a8d51cf5e5932f87e5fa11a0ebd2fdf3148dc122fb013716)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bccbf40d004b8db72ee06479e931eaf7728c6d4587b2ec990205b38d23eb4874)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Amplifybackend(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Amplifybackend",
):
    '''(experimental) Statement provider for service `amplifybackend <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsamplifyadmin.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `amplifybackend <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsamplifyadmin.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onApi")
    def on_api(
        self,
        app_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Amplifybackend":
        '''(experimental) Adds a resource of type api to the statement.

        https://docs.aws.amazon.com/amplify-admin-ui/latest/APIReference/backend-appid-api.html

        :param app_id: - Identifier for the appId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__059e24908074564faf0e2fb38eb458bf2c380b002ad1b86f24c3054131a73135)
            check_type(argname="argument app_id", value=app_id, expected_type=type_hints["app_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Amplifybackend", jsii.invoke(self, "onApi", [app_id, account, region, partition]))

    @jsii.member(jsii_name="onAuth")
    def on_auth(
        self,
        app_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Amplifybackend":
        '''(experimental) Adds a resource of type auth to the statement.

        https://docs.aws.amazon.com/amplify-admin-ui/latest/APIReference/backend-appid-auth.html

        :param app_id: - Identifier for the appId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8be44c0064d102c3e0ad7f7468dbffb3f3723b97658e7c6647fde84cd423e90f)
            check_type(argname="argument app_id", value=app_id, expected_type=type_hints["app_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Amplifybackend", jsii.invoke(self, "onAuth", [app_id, account, region, partition]))

    @jsii.member(jsii_name="onBackend")
    def on_backend(
        self,
        app_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Amplifybackend":
        '''(experimental) Adds a resource of type backend to the statement.

        https://docs.aws.amazon.com/amplify-admin-ui/latest/APIReference/backend.html

        :param app_id: - Identifier for the appId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__79e0f90cdf91d0378fa013b8e20f646adbeef965073232df9dd8f353fe7c718c)
            check_type(argname="argument app_id", value=app_id, expected_type=type_hints["app_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Amplifybackend", jsii.invoke(self, "onBackend", [app_id, account, region, partition]))

    @jsii.member(jsii_name="onConfig")
    def on_config(
        self,
        app_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Amplifybackend":
        '''(experimental) Adds a resource of type config to the statement.

        https://docs.aws.amazon.com/amplify-admin-ui/latest/APIReference/backend-appid-config.html

        :param app_id: - Identifier for the appId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__345da9cb6fbff89662399e5120cbada6d9a643ac35cf209810f52867956704fc)
            check_type(argname="argument app_id", value=app_id, expected_type=type_hints["app_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Amplifybackend", jsii.invoke(self, "onConfig", [app_id, account, region, partition]))

    @jsii.member(jsii_name="onEnvironment")
    def on_environment(
        self,
        app_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Amplifybackend":
        '''(experimental) Adds a resource of type environment to the statement.

        https://docs.aws.amazon.com/amplify-admin-ui/latest/APIReference/backend-appid-api-backendenvironmentname-details.html

        :param app_id: - Identifier for the appId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__70a9193aace0fd9a5e362a3543b1e6c4da8731de921ad62265f1fcf88886c8b3)
            check_type(argname="argument app_id", value=app_id, expected_type=type_hints["app_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Amplifybackend", jsii.invoke(self, "onEnvironment", [app_id, account, region, partition]))

    @jsii.member(jsii_name="onJob")
    def on_job(
        self,
        app_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Amplifybackend":
        '''(experimental) Adds a resource of type job to the statement.

        https://docs.aws.amazon.com/amplify-admin-ui/latest/APIReference/backend-appid-job-backendenvironmentname.html

        :param app_id: - Identifier for the appId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__16cdc213e9a03fde8c9f17c1229ae2628e8500bf66a7176a11e6d97412aef075)
            check_type(argname="argument app_id", value=app_id, expected_type=type_hints["app_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Amplifybackend", jsii.invoke(self, "onJob", [app_id, account, region, partition]))

    @jsii.member(jsii_name="onStorage")
    def on_storage(
        self,
        app_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Amplifybackend":
        '''(experimental) Adds a resource of type storage to the statement.

        https://docs.aws.amazon.com/amplify-admin-ui/latest/APIReference/backend-appid-storage.html

        :param app_id: - Identifier for the appId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ba15fdb1d0d87aa87ea70ad9cb38baf31194af3f9e61a9262ac2e19fba6b54f1)
            check_type(argname="argument app_id", value=app_id, expected_type=type_hints["app_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Amplifybackend", jsii.invoke(self, "onStorage", [app_id, account, region, partition]))

    @jsii.member(jsii_name="onToken")
    def on_token(
        self,
        app_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Amplifybackend":
        '''(experimental) Adds a resource of type token to the statement.

        https://docs.aws.amazon.com/amplify-admin-ui/latest/APIReference/backend-appid-token.html

        :param app_id: - Identifier for the appId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9d7d7cc93a433c18425db639d92af1f2129387196fb54852831ac8f6464591bb)
            check_type(argname="argument app_id", value=app_id, expected_type=type_hints["app_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Amplifybackend", jsii.invoke(self, "onToken", [app_id, account, region, partition]))

    @jsii.member(jsii_name="toCloneBackend")
    def to_clone_backend(self) -> "Amplifybackend":
        '''(experimental) Grants permission to clone an existing Amplify Admin backend environment into a new Amplify Admin backend enviroment.

        Access Level: Write

        https://docs.aws.amazon.com/amplify-admin-ui/latest/APIReference/backend-appid-environments-backendenvironmentname-clone.html#CloneBackend

        :stability: experimental
        '''
        return typing.cast("Amplifybackend", jsii.invoke(self, "toCloneBackend", []))

    @jsii.member(jsii_name="toCreateBackend")
    def to_create_backend(self) -> "Amplifybackend":
        '''(experimental) Grants permission to create a new Amplify Admin backend environment by Amplify appId.

        Access Level: Write

        https://docs.aws.amazon.com/amplify-admin-ui/latest/APIReference/backend.html#CreateBackend

        :stability: experimental
        '''
        return typing.cast("Amplifybackend", jsii.invoke(self, "toCreateBackend", []))

    @jsii.member(jsii_name="toCreateBackendAPI")
    def to_create_backend_api(self) -> "Amplifybackend":
        '''(experimental) Grants permission to create an API for an existing Amplify Admin backend environment by appId and backendEnvironmentName.

        Access Level: Write

        https://docs.aws.amazon.com/amplify-admin-ui/latest/APIReference/backend-appid-api.html#CreateBackendAPI

        :stability: experimental
        '''
        return typing.cast("Amplifybackend", jsii.invoke(self, "toCreateBackendAPI", []))

    @jsii.member(jsii_name="toCreateBackendAuth")
    def to_create_backend_auth(self) -> "Amplifybackend":
        '''(experimental) Grants permission to create an auth resource for an existing Amplify Admin backend environment by appId and backendEnvironmentName.

        Access Level: Write

        https://docs.aws.amazon.com/amplify-admin-ui/latest/APIReference/backend-appid-auth.html#CreateBackendAuth

        :stability: experimental
        '''
        return typing.cast("Amplifybackend", jsii.invoke(self, "toCreateBackendAuth", []))

    @jsii.member(jsii_name="toCreateBackendConfig")
    def to_create_backend_config(self) -> "Amplifybackend":
        '''(experimental) Grants permission to create a new Amplify Admin backend config by Amplify appId.

        Access Level: Write

        https://docs.aws.amazon.com/amplify-admin-ui/latest/APIReference/backend-appid-config.html#CreateBackendConfig

        :stability: experimental
        '''
        return typing.cast("Amplifybackend", jsii.invoke(self, "toCreateBackendConfig", []))

    @jsii.member(jsii_name="toCreateBackendStorage")
    def to_create_backend_storage(self) -> "Amplifybackend":
        '''(experimental) Grants permission to create a backend storage resource.

        Access Level: Write

        https://docs.aws.amazon.com/amplify-admin-ui/latest/APIReference/backend-appid-storage.html#CreateBackendStorage

        :stability: experimental
        '''
        return typing.cast("Amplifybackend", jsii.invoke(self, "toCreateBackendStorage", []))

    @jsii.member(jsii_name="toCreateToken")
    def to_create_token(self) -> "Amplifybackend":
        '''(experimental) Grants permission to create an Amplify Admin challenge token by appId.

        Access Level: Write

        https://docs.aws.amazon.com/amplify-admin-ui/latest/APIReference/backend-appid-challenge.html#CreateToken

        :stability: experimental
        '''
        return typing.cast("Amplifybackend", jsii.invoke(self, "toCreateToken", []))

    @jsii.member(jsii_name="toDeleteBackend")
    def to_delete_backend(self) -> "Amplifybackend":
        '''(experimental) Grants permission to delete an existing Amplify Admin backend environment by appId and backendEnvironmentName.

        Access Level: Write

        https://docs.aws.amazon.com/amplify-admin-ui/latest/APIReference/backend-appid-environments-backendenvironmentname-remove.html#DeleteBackend

        :stability: experimental
        '''
        return typing.cast("Amplifybackend", jsii.invoke(self, "toDeleteBackend", []))

    @jsii.member(jsii_name="toDeleteBackendAPI")
    def to_delete_backend_api(self) -> "Amplifybackend":
        '''(experimental) Grants permission to delete an API of an existing Amplify Admin backend environment by appId and backendEnvironmentName.

        Access Level: Write

        https://docs.aws.amazon.com/amplify-admin-ui/latest/APIReference/backend-appid-api-backendenvironmentname-remove.html#DeleteBackendAPI

        :stability: experimental
        '''
        return typing.cast("Amplifybackend", jsii.invoke(self, "toDeleteBackendAPI", []))

    @jsii.member(jsii_name="toDeleteBackendAuth")
    def to_delete_backend_auth(self) -> "Amplifybackend":
        '''(experimental) Grants permission to delete an auth resource of an existing Amplify Admin backend environment by appId and backendEnvironmentName.

        Access Level: Write

        https://docs.aws.amazon.com/amplify-admin-ui/latest/APIReference/backend-appid-auth-backendenvironmentname-remove.html#DeleteBackendAuth

        :stability: experimental
        '''
        return typing.cast("Amplifybackend", jsii.invoke(self, "toDeleteBackendAuth", []))

    @jsii.member(jsii_name="toDeleteBackendStorage")
    def to_delete_backend_storage(self) -> "Amplifybackend":
        '''(experimental) Grants permission to delete a backend storage resource.

        Access Level: Write

        https://docs.aws.amazon.com/amplify-admin-ui/latest/APIReference/backend-appid-storage.html#DeleteBackendStorage

        :stability: experimental
        '''
        return typing.cast("Amplifybackend", jsii.invoke(self, "toDeleteBackendStorage", []))

    @jsii.member(jsii_name="toDeleteToken")
    def to_delete_token(self) -> "Amplifybackend":
        '''(experimental) Grants permission to delete an Amplify Admin challenge token by appId.

        Access Level: Write

        https://docs.aws.amazon.com/amplify-admin-ui/latest/APIReference/backend-appid-challenge-sessionid-remove.html#DeleteToken

        :stability: experimental
        '''
        return typing.cast("Amplifybackend", jsii.invoke(self, "toDeleteToken", []))

    @jsii.member(jsii_name="toGenerateBackendAPIModels")
    def to_generate_backend_api_models(self) -> "Amplifybackend":
        '''(experimental) Grants permission to generate models for an API of an existing Amplify Admin backend environment by appId and backendEnvironmentName.

        Access Level: Write

        https://docs.aws.amazon.com/amplify-admin-ui/latest/APIReference/backend-appid-api-backendenvironmentname-generatemodels.html#GenerateBackendAPIModels

        :stability: experimental
        '''
        return typing.cast("Amplifybackend", jsii.invoke(self, "toGenerateBackendAPIModels", []))

    @jsii.member(jsii_name="toGetBackend")
    def to_get_backend(self) -> "Amplifybackend":
        '''(experimental) Grants permission to retrieve an existing Amplify Admin backend environment by appId and backendEnvironmentName.

        Access Level: Read

        https://docs.aws.amazon.com/amplify-admin-ui/latest/APIReference/backend-appid-details.html#GetBackend

        :stability: experimental
        '''
        return typing.cast("Amplifybackend", jsii.invoke(self, "toGetBackend", []))

    @jsii.member(jsii_name="toGetBackendAPI")
    def to_get_backend_api(self) -> "Amplifybackend":
        '''(experimental) Grants permission to retrieve an API of an existing Amplify Admin backend environment by appId and backendEnvironmentName.

        Access Level: Read

        https://docs.aws.amazon.com/amplify-admin-ui/latest/APIReference/backend-appid-api-backendenvironmentname-details.html#GetBackendAPI

        :stability: experimental
        '''
        return typing.cast("Amplifybackend", jsii.invoke(self, "toGetBackendAPI", []))

    @jsii.member(jsii_name="toGetBackendAPIModels")
    def to_get_backend_api_models(self) -> "Amplifybackend":
        '''(experimental) Grants permission to retrieve models for an API of an existing Amplify Admin backend environment by appId and backendEnvironmentName.

        Access Level: Read

        https://docs.aws.amazon.com/amplify-admin-ui/latest/APIReference/backend-appid-api-backendenvironmentname-getmodels.html#GetBackendAPIModels

        :stability: experimental
        '''
        return typing.cast("Amplifybackend", jsii.invoke(self, "toGetBackendAPIModels", []))

    @jsii.member(jsii_name="toGetBackendAuth")
    def to_get_backend_auth(self) -> "Amplifybackend":
        '''(experimental) Grants permission to retrieve an auth resource of an existing Amplify Admin backend environment by appId and backendEnvironmentName.

        Access Level: Read

        https://docs.aws.amazon.com/amplify-admin-ui/latest/APIReference/backend-appid-auth-backendenvironmentname-details.html#GetBackendAuth

        :stability: experimental
        '''
        return typing.cast("Amplifybackend", jsii.invoke(self, "toGetBackendAuth", []))

    @jsii.member(jsii_name="toGetBackendJob")
    def to_get_backend_job(self) -> "Amplifybackend":
        '''(experimental) Grants permission to retrieve a job of an existing Amplify Admin backend environment by appId and backendEnvironmentName.

        Access Level: Read

        https://docs.aws.amazon.com/amplify-admin-ui/latest/APIReference/backend-appid-job-backendenvironmentname-jobid.html#GetBackendJob

        :stability: experimental
        '''
        return typing.cast("Amplifybackend", jsii.invoke(self, "toGetBackendJob", []))

    @jsii.member(jsii_name="toGetBackendStorage")
    def to_get_backend_storage(self) -> "Amplifybackend":
        '''(experimental) Grants permission to retrieve an existing backend storage resource.

        Access Level: Read

        https://docs.aws.amazon.com/amplify-admin-ui/latest/APIReference/backend-appid-storage.html#GetBackendStorage

        :stability: experimental
        '''
        return typing.cast("Amplifybackend", jsii.invoke(self, "toGetBackendStorage", []))

    @jsii.member(jsii_name="toGetToken")
    def to_get_token(self) -> "Amplifybackend":
        '''(experimental) Grants permission to retrieve an Amplify Admin challenge token by appId.

        Access Level: Read

        https://docs.aws.amazon.com/amplify-admin-ui/latest/APIReference/backend-appid-challenge-sessionid.html#GetToken

        :stability: experimental
        '''
        return typing.cast("Amplifybackend", jsii.invoke(self, "toGetToken", []))

    @jsii.member(jsii_name="toImportBackendAuth")
    def to_import_backend_auth(self) -> "Amplifybackend":
        '''(experimental) Grants permission to import an existing auth resource of an Amplify Admin backend environment by appId and backendEnvironmentName.

        Access Level: Write

        https://docs.aws.amazon.com/amplify-admin-ui/latest/APIReference/backend-appid-auth-backendenvironmentname.html#ImportBackendAuth

        :stability: experimental
        '''
        return typing.cast("Amplifybackend", jsii.invoke(self, "toImportBackendAuth", []))

    @jsii.member(jsii_name="toImportBackendStorage")
    def to_import_backend_storage(self) -> "Amplifybackend":
        '''(experimental) Grants permission to import an existing backend storage resource.

        Access Level: Write

        https://docs.aws.amazon.com/amplify-admin-ui/latest/APIReference/backend-appid-storage.html#ImportBackendStorage

        :stability: experimental
        '''
        return typing.cast("Amplifybackend", jsii.invoke(self, "toImportBackendStorage", []))

    @jsii.member(jsii_name="toListBackendJobs")
    def to_list_backend_jobs(self) -> "Amplifybackend":
        '''(experimental) Grants permission to retrieve the jobs of an existing Amplify Admin backend environment by appId and backendEnvironmentName.

        Access Level: List

        https://docs.aws.amazon.com/amplify-admin-ui/latest/APIReference/backend-appid-job-backendenvironmentname.html#ListBackendJobs

        :stability: experimental
        '''
        return typing.cast("Amplifybackend", jsii.invoke(self, "toListBackendJobs", []))

    @jsii.member(jsii_name="toListS3Buckets")
    def to_list_s3_buckets(self) -> "Amplifybackend":
        '''(experimental) Grants permission to retrieve s3 buckets.

        Access Level: List

        https://docs.aws.amazon.com/amplify-admin-ui/latest/APIReference/backend-appid-storage.html#ListS3Buckets

        :stability: experimental
        '''
        return typing.cast("Amplifybackend", jsii.invoke(self, "toListS3Buckets", []))

    @jsii.member(jsii_name="toRemoveAllBackends")
    def to_remove_all_backends(self) -> "Amplifybackend":
        '''(experimental) Grants permission to delete all existing Amplify Admin backend environments by appId.

        Access Level: Write

        https://docs.aws.amazon.com/amplify-admin-ui/latest/APIReference/backend-appid-remove.html#RemoveAllBackends

        :stability: experimental
        '''
        return typing.cast("Amplifybackend", jsii.invoke(self, "toRemoveAllBackends", []))

    @jsii.member(jsii_name="toRemoveBackendConfig")
    def to_remove_backend_config(self) -> "Amplifybackend":
        '''(experimental) Grants permission to delete an Amplify Admin backend config by Amplify appId.

        Access Level: Write

        https://docs.aws.amazon.com/amplify-admin-ui/latest/APIReference/backend-appid-config-remove.html#RemoveBackendConfig

        :stability: experimental
        '''
        return typing.cast("Amplifybackend", jsii.invoke(self, "toRemoveBackendConfig", []))

    @jsii.member(jsii_name="toUpdateBackendAPI")
    def to_update_backend_api(self) -> "Amplifybackend":
        '''(experimental) Grants permission to update an API of an existing Amplify Admin backend environment by appId and backendEnvironmentName.

        Access Level: Write

        https://docs.aws.amazon.com/amplify-admin-ui/latest/APIReference/backend-appid-api-backendenvironmentname.html#UpdateBackendAPI

        :stability: experimental
        '''
        return typing.cast("Amplifybackend", jsii.invoke(self, "toUpdateBackendAPI", []))

    @jsii.member(jsii_name="toUpdateBackendAuth")
    def to_update_backend_auth(self) -> "Amplifybackend":
        '''(experimental) Grants permission to update an auth resource of an existing Amplify Admin backend environment by appId and backendEnvironmentName.

        Access Level: Write

        https://docs.aws.amazon.com/amplify-admin-ui/latest/APIReference/backend-appid-auth-backendenvironmentname.html#UpdateBackendAuth

        :stability: experimental
        '''
        return typing.cast("Amplifybackend", jsii.invoke(self, "toUpdateBackendAuth", []))

    @jsii.member(jsii_name="toUpdateBackendConfig")
    def to_update_backend_config(self) -> "Amplifybackend":
        '''(experimental) Grants permission to update an Amplify Admin backend config by Amplify appId.

        Access Level: Write

        https://docs.aws.amazon.com/amplify-admin-ui/latest/APIReference/backend-appid-config-update.html#UpdateBackendConfig

        :stability: experimental
        '''
        return typing.cast("Amplifybackend", jsii.invoke(self, "toUpdateBackendConfig", []))

    @jsii.member(jsii_name="toUpdateBackendJob")
    def to_update_backend_job(self) -> "Amplifybackend":
        '''(experimental) Grants permission to update a job of an existing Amplify Admin backend environment by appId and backendEnvironmentName.

        Access Level: Write

        https://docs.aws.amazon.com/amplify-admin-ui/latest/APIReference/backend-appid-job-backendenvironmentname-jobid.html#UpdateBackendJob

        :stability: experimental
        '''
        return typing.cast("Amplifybackend", jsii.invoke(self, "toUpdateBackendJob", []))

    @jsii.member(jsii_name="toUpdateBackendStorage")
    def to_update_backend_storage(self) -> "Amplifybackend":
        '''(experimental) Grants permission to update a backend storage resource.

        Access Level: Write

        https://docs.aws.amazon.com/amplify-admin-ui/latest/APIReference/backend-appid-storage.html#UpdateBackendStorage

        :stability: experimental
        '''
        return typing.cast("Amplifybackend", jsii.invoke(self, "toUpdateBackendStorage", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6157c3c6b818849c2b8b07f539e42bbe3819a37a81daeafec222fd94cf1a145a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6e23a978fd7b1666e2b4133221304ea233dc4e7caaf9cbb839c55e04b08d7079)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Amplifyuibuilder(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Amplifyuibuilder",
):
    '''(experimental) Statement provider for service `amplifyuibuilder <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsamplifyuibuilder.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `amplifyuibuilder <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsamplifyuibuilder.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="ifComponentResourceAppId")
    def if_component_resource_app_id(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Amplifyuibuilder":
        '''(experimental) Filters access by the app ID.

        https://docs.aws.amazon.com/amplify/latest/APIReference/API_App.html

        Applies to resource types:

        - ComponentResource

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__790a1b732a71dfbd1b95650b8dd602ceb93bb73117b9a20d0347abc791ff4a08)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Amplifyuibuilder", jsii.invoke(self, "ifComponentResourceAppId", [value, operator]))

    @jsii.member(jsii_name="ifComponentResourceEnvironmentName")
    def if_component_resource_environment_name(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Amplifyuibuilder":
        '''(experimental) Filters access by the backend environment name.

        https://docs.aws.amazon.com/amplify/latest/APIReference/API_BackendEnvironment.html

        Applies to resource types:

        - ComponentResource

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2157a067f52a04fc49667ae7d06f27e63d80a3b70f032fb06f565dd27f1a783d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Amplifyuibuilder", jsii.invoke(self, "ifComponentResourceEnvironmentName", [value, operator]))

    @jsii.member(jsii_name="ifComponentResourceId")
    def if_component_resource_id(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Amplifyuibuilder":
        '''(experimental) Filters access by the component ID.

        https://docs.aws.amazon.com/amplifyuibuilder/latest/APIReference/API_Component.html

        Applies to resource types:

        - ComponentResource

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__75b361528f34d77565682ef1daa9705a9dc10420420d3cafb8f3eb656ca3ce87)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Amplifyuibuilder", jsii.invoke(self, "ifComponentResourceId", [value, operator]))

    @jsii.member(jsii_name="ifFormResourceAppId")
    def if_form_resource_app_id(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Amplifyuibuilder":
        '''(experimental) Filters access by the app ID.

        https://docs.aws.amazon.com/amplify/latest/APIReference/API_App.html

        Applies to resource types:

        - FormResource

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5649a82f51d1b2007b15f3809c0e921d7ac11c8b04ccede3ec21483504f1ab45)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Amplifyuibuilder", jsii.invoke(self, "ifFormResourceAppId", [value, operator]))

    @jsii.member(jsii_name="ifFormResourceEnvironmentName")
    def if_form_resource_environment_name(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Amplifyuibuilder":
        '''(experimental) Filters access by the backend environment name.

        https://docs.aws.amazon.com/amplify/latest/APIReference/API_BackendEnvironment.html

        Applies to resource types:

        - FormResource

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__499c049561ba7ad370981bd14ce9c93497d702afcdcc7c936be179ac886fc517)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Amplifyuibuilder", jsii.invoke(self, "ifFormResourceEnvironmentName", [value, operator]))

    @jsii.member(jsii_name="ifFormResourceId")
    def if_form_resource_id(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Amplifyuibuilder":
        '''(experimental) Filters access by the form ID.

        https://docs.aws.amazon.com/amplifyuibuilder/latest/APIReference/API_Form.html

        Applies to resource types:

        - FormResource

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__38e798df152c13c33fc85dcc7e3feb29fad3a205ebe78606fe6064ddc416a21c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Amplifyuibuilder", jsii.invoke(self, "ifFormResourceId", [value, operator]))

    @jsii.member(jsii_name="ifThemeResourceAppId")
    def if_theme_resource_app_id(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Amplifyuibuilder":
        '''(experimental) Filters access by the app ID.

        https://docs.aws.amazon.com/amplify/latest/APIReference/API_App.html

        Applies to resource types:

        - ThemeResource

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__079c2c473c7ede40065bb03c8f1f75c9e75709aa42a0cfa4dd4946dab35c3e73)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Amplifyuibuilder", jsii.invoke(self, "ifThemeResourceAppId", [value, operator]))

    @jsii.member(jsii_name="ifThemeResourceEnvironmentName")
    def if_theme_resource_environment_name(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Amplifyuibuilder":
        '''(experimental) Filters access by the backend environment name.

        https://docs.aws.amazon.com/amplify/latest/APIReference/API_BackendEnvironment.html

        Applies to resource types:

        - ThemeResource

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6d813dcc9de161d03d3bf5ca7e1287ea7376884664910917603d0dc2d5b40c9b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Amplifyuibuilder", jsii.invoke(self, "ifThemeResourceEnvironmentName", [value, operator]))

    @jsii.member(jsii_name="ifThemeResourceId")
    def if_theme_resource_id(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Amplifyuibuilder":
        '''(experimental) Filters access by the theme ID.

        https://docs.aws.amazon.com/amplifyuibuilder/latest/APIReference/API_Theme.html

        Applies to resource types:

        - ThemeResource

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0b91c29a086b5ca70da1f239a0850e006aea40f844066d4cd538a3d624c75e45)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Amplifyuibuilder", jsii.invoke(self, "ifThemeResourceId", [value, operator]))

    @jsii.member(jsii_name="onComponentResource")
    def on_component_resource(
        self,
        app_id: builtins.str,
        environment_name: builtins.str,
        id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Amplifyuibuilder":
        '''(experimental) Adds a resource of type ComponentResource to the statement.

        https://docs.aws.amazon.com/amplifyuibuilder/latest/APIReference/API_Component.html

        :param app_id: - Identifier for the appId.
        :param environment_name: - Identifier for the environmentName.
        :param id: - Identifier for the id.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifComponentResourceAppId() - .ifComponentResourceEnvironmentName() - .ifComponentResourceId() - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d419cee9625a03b1950182092bfafc73563901ef44e0e561ea4916fb009e0d7a)
            check_type(argname="argument app_id", value=app_id, expected_type=type_hints["app_id"])
            check_type(argname="argument environment_name", value=environment_name, expected_type=type_hints["environment_name"])
            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Amplifyuibuilder", jsii.invoke(self, "onComponentResource", [app_id, environment_name, id, account, region, partition]))

    @jsii.member(jsii_name="onFormResource")
    def on_form_resource(
        self,
        app_id: builtins.str,
        environment_name: builtins.str,
        id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Amplifyuibuilder":
        '''(experimental) Adds a resource of type FormResource to the statement.

        https://docs.aws.amazon.com/amplifyuibuilder/latest/APIReference/API_Form.html

        :param app_id: - Identifier for the appId.
        :param environment_name: - Identifier for the environmentName.
        :param id: - Identifier for the id.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifFormResourceAppId() - .ifFormResourceEnvironmentName() - .ifFormResourceId() - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0b7cbb2f9db9c65ecdd67d8ebc2efa47c12a0169aefcd294e5de5fb63f7d0e43)
            check_type(argname="argument app_id", value=app_id, expected_type=type_hints["app_id"])
            check_type(argname="argument environment_name", value=environment_name, expected_type=type_hints["environment_name"])
            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Amplifyuibuilder", jsii.invoke(self, "onFormResource", [app_id, environment_name, id, account, region, partition]))

    @jsii.member(jsii_name="onThemeResource")
    def on_theme_resource(
        self,
        app_id: builtins.str,
        environment_name: builtins.str,
        id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Amplifyuibuilder":
        '''(experimental) Adds a resource of type ThemeResource to the statement.

        https://docs.aws.amazon.com/amplifyuibuilder/latest/APIReference/API_Theme.html

        :param app_id: - Identifier for the appId.
        :param environment_name: - Identifier for the environmentName.
        :param id: - Identifier for the id.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifThemeResourceAppId() - .ifThemeResourceEnvironmentName() - .ifThemeResourceId() - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__35cd6d4072d4fc40b5d7307e18b896c2560a792be62e0f1734b48f76dc527408)
            check_type(argname="argument app_id", value=app_id, expected_type=type_hints["app_id"])
            check_type(argname="argument environment_name", value=environment_name, expected_type=type_hints["environment_name"])
            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Amplifyuibuilder", jsii.invoke(self, "onThemeResource", [app_id, environment_name, id, account, region, partition]))

    @jsii.member(jsii_name="toCreateComponent")
    def to_create_component(self) -> "Amplifyuibuilder":
        '''(experimental) Grants permission to create a component.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - amplify:GetApp

        https://docs.aws.amazon.com/amplifyuibuilder/latest/APIReference/API_CreateComponent.html

        :stability: experimental
        '''
        return typing.cast("Amplifyuibuilder", jsii.invoke(self, "toCreateComponent", []))

    @jsii.member(jsii_name="toCreateForm")
    def to_create_form(self) -> "Amplifyuibuilder":
        '''(experimental) Grants permission to create a form.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - amplify:GetApp

        https://docs.aws.amazon.com/amplifyuibuilder/latest/APIReference/API_CreateForm.html

        :stability: experimental
        '''
        return typing.cast("Amplifyuibuilder", jsii.invoke(self, "toCreateForm", []))

    @jsii.member(jsii_name="toCreateTheme")
    def to_create_theme(self) -> "Amplifyuibuilder":
        '''(experimental) Grants permission to create a theme.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - amplify:GetApp

        https://docs.aws.amazon.com/amplifyuibuilder/latest/APIReference/API_CreateTheme.html

        :stability: experimental
        '''
        return typing.cast("Amplifyuibuilder", jsii.invoke(self, "toCreateTheme", []))

    @jsii.member(jsii_name="toDeleteComponent")
    def to_delete_component(self) -> "Amplifyuibuilder":
        '''(experimental) Grants permission to delete a component.

        Access Level: Write

        Dependent actions:

        - amplify:GetApp

        https://docs.aws.amazon.com/amplifyuibuilder/latest/APIReference/API_DeleteComponent.html

        :stability: experimental
        '''
        return typing.cast("Amplifyuibuilder", jsii.invoke(self, "toDeleteComponent", []))

    @jsii.member(jsii_name="toDeleteForm")
    def to_delete_form(self) -> "Amplifyuibuilder":
        '''(experimental) Grants permission to delete a form.

        Access Level: Write

        Dependent actions:

        - amplify:GetApp

        https://docs.aws.amazon.com/amplifyuibuilder/latest/APIReference/API_DeleteForm.html

        :stability: experimental
        '''
        return typing.cast("Amplifyuibuilder", jsii.invoke(self, "toDeleteForm", []))

    @jsii.member(jsii_name="toDeleteTheme")
    def to_delete_theme(self) -> "Amplifyuibuilder":
        '''(experimental) Grants permission to delete a theme.

        Access Level: Write

        Dependent actions:

        - amplify:GetApp

        https://docs.aws.amazon.com/amplifyuibuilder/latest/APIReference/API_DeleteTheme.html

        :stability: experimental
        '''
        return typing.cast("Amplifyuibuilder", jsii.invoke(self, "toDeleteTheme", []))

    @jsii.member(jsii_name="toExportComponents")
    def to_export_components(self) -> "Amplifyuibuilder":
        '''(experimental) Grants permission to export components.

        Access Level: Read

        https://docs.aws.amazon.com/amplifyuibuilder/latest/APIReference/API_ExportComponents.html

        :stability: experimental
        '''
        return typing.cast("Amplifyuibuilder", jsii.invoke(self, "toExportComponents", []))

    @jsii.member(jsii_name="toExportForms")
    def to_export_forms(self) -> "Amplifyuibuilder":
        '''(experimental) Grants permission to export forms.

        Access Level: Read

        https://docs.aws.amazon.com/amplifyuibuilder/latest/APIReference/API_ExportForms.html

        :stability: experimental
        '''
        return typing.cast("Amplifyuibuilder", jsii.invoke(self, "toExportForms", []))

    @jsii.member(jsii_name="toExportThemes")
    def to_export_themes(self) -> "Amplifyuibuilder":
        '''(experimental) Grants permission to export themes.

        Access Level: Read

        https://docs.aws.amazon.com/amplifyuibuilder/latest/APIReference/API_ExportThemes.html

        :stability: experimental
        '''
        return typing.cast("Amplifyuibuilder", jsii.invoke(self, "toExportThemes", []))

    @jsii.member(jsii_name="toGetComponent")
    def to_get_component(self) -> "Amplifyuibuilder":
        '''(experimental) Grants permission to get an existing component.

        Access Level: Read

        Dependent actions:

        - amplify:GetApp

        https://docs.aws.amazon.com/amplifyuibuilder/latest/APIReference/API_GetComponent.html

        :stability: experimental
        '''
        return typing.cast("Amplifyuibuilder", jsii.invoke(self, "toGetComponent", []))

    @jsii.member(jsii_name="toGetForm")
    def to_get_form(self) -> "Amplifyuibuilder":
        '''(experimental) Grants permission to get an existing form.

        Access Level: Read

        Dependent actions:

        - amplify:GetApp

        https://docs.aws.amazon.com/amplifyuibuilder/latest/APIReference/API_GetForm.html

        :stability: experimental
        '''
        return typing.cast("Amplifyuibuilder", jsii.invoke(self, "toGetForm", []))

    @jsii.member(jsii_name="toGetMetadata")
    def to_get_metadata(self) -> "Amplifyuibuilder":
        '''(experimental) Grants permission to get an existing metadata.

        Access Level: Read

        https://docs.aws.amazon.com/amplifyuibuilder/latest/APIReference/API_GetMetadata.html

        :stability: experimental
        '''
        return typing.cast("Amplifyuibuilder", jsii.invoke(self, "toGetMetadata", []))

    @jsii.member(jsii_name="toGetTheme")
    def to_get_theme(self) -> "Amplifyuibuilder":
        '''(experimental) Grants permission to get an existing theme.

        Access Level: Read

        Dependent actions:

        - amplify:GetApp

        https://docs.aws.amazon.com/amplifyuibuilder/latest/APIReference/API_GetTheme.html

        :stability: experimental
        '''
        return typing.cast("Amplifyuibuilder", jsii.invoke(self, "toGetTheme", []))

    @jsii.member(jsii_name="toListComponents")
    def to_list_components(self) -> "Amplifyuibuilder":
        '''(experimental) Grants permission to list components.

        Access Level: List

        Dependent actions:

        - amplify:GetApp

        https://docs.aws.amazon.com/amplifyuibuilder/latest/APIReference/API_ListComponents.html

        :stability: experimental
        '''
        return typing.cast("Amplifyuibuilder", jsii.invoke(self, "toListComponents", []))

    @jsii.member(jsii_name="toListForms")
    def to_list_forms(self) -> "Amplifyuibuilder":
        '''(experimental) Grants permission to list forms.

        Access Level: List

        Dependent actions:

        - amplify:GetApp

        https://docs.aws.amazon.com/amplifyuibuilder/latest/APIReference/API_ListForms.html

        :stability: experimental
        '''
        return typing.cast("Amplifyuibuilder", jsii.invoke(self, "toListForms", []))

    @jsii.member(jsii_name="toListThemes")
    def to_list_themes(self) -> "Amplifyuibuilder":
        '''(experimental) Grants permission to list themes.

        Access Level: List

        Dependent actions:

        - amplify:GetApp

        https://docs.aws.amazon.com/amplifyuibuilder/latest/APIReference/API_ListThemes.html

        :stability: experimental
        '''
        return typing.cast("Amplifyuibuilder", jsii.invoke(self, "toListThemes", []))

    @jsii.member(jsii_name="toPutMetadataFlag")
    def to_put_metadata_flag(self) -> "Amplifyuibuilder":
        '''(experimental) Grants permission to put an existing metadata.

        Access Level: Write

        https://docs.aws.amazon.com/amplifyuibuilder/latest/APIReference/API_PutMetadataFlag.html

        :stability: experimental
        '''
        return typing.cast("Amplifyuibuilder", jsii.invoke(self, "toPutMetadataFlag", []))

    @jsii.member(jsii_name="toResetMetadataFlag")
    def to_reset_metadata_flag(self) -> "Amplifyuibuilder":
        '''(experimental) Grants permission to reset an existing metadata.

        Access Level: Write

        https://docs.aws.amazon.com/amplifyuibuilder/latest/APIReference/API_ResetMetadataFlag.html

        :stability: experimental
        '''
        return typing.cast("Amplifyuibuilder", jsii.invoke(self, "toResetMetadataFlag", []))

    @jsii.member(jsii_name="toUpdateComponent")
    def to_update_component(self) -> "Amplifyuibuilder":
        '''(experimental) Grants permission to update a component.

        Access Level: Write

        Dependent actions:

        - amplify:GetApp

        https://docs.aws.amazon.com/amplifyuibuilder/latest/APIReference/API_UpdateComponent.html

        :stability: experimental
        '''
        return typing.cast("Amplifyuibuilder", jsii.invoke(self, "toUpdateComponent", []))

    @jsii.member(jsii_name="toUpdateForm")
    def to_update_form(self) -> "Amplifyuibuilder":
        '''(experimental) Grants permission to update a form.

        Access Level: Write

        Dependent actions:

        - amplify:GetApp

        https://docs.aws.amazon.com/amplifyuibuilder/latest/APIReference/API_UpdateForm.html

        :stability: experimental
        '''
        return typing.cast("Amplifyuibuilder", jsii.invoke(self, "toUpdateForm", []))

    @jsii.member(jsii_name="toUpdateTheme")
    def to_update_theme(self) -> "Amplifyuibuilder":
        '''(experimental) Grants permission to update a theme.

        Access Level: Write

        Dependent actions:

        - amplify:GetApp

        https://docs.aws.amazon.com/amplifyuibuilder/latest/APIReference/API_UpdateTheme.html

        :stability: experimental
        '''
        return typing.cast("Amplifyuibuilder", jsii.invoke(self, "toUpdateTheme", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__75db7bc3403b9ce28b68260bcf42061445dd3750f8427777105d1a079b792068)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c8c8d939fcf59b4999dbfd1f022e325a18bca6f3c2244adbbfb50e1afa7c080c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Aoss(PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Aoss"):
    '''(experimental) Statement provider for service `aoss <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonopensearchserverless.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `aoss <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonopensearchserverless.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="ifCollection")
    def if_collection(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Aoss":
        '''(experimental) Filters access by the collection name.

        https://docs.aws.amazon.com/opensearch-service/latest/developerguide/security-iam-serverless.html#security_iam_serverless-conditionkeys

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0520ec7a8f07ffb88a7154ed656ad953d8ef429f91f4218cce03cef5bd465a41)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Aoss", jsii.invoke(self, "ifCollection", [value, operator]))

    @jsii.member(jsii_name="ifCollectionId")
    def if_collection_id(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Aoss":
        '''(experimental) Filters access by the identifier of the collection.

        https://docs.aws.amazon.com/opensearch-service/latest/developerguide/security-iam-serverless.html#security_iam_serverless-conditionkeys

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__daf0bee9cdffbaf93739d59a8913e27e1b9c32ac0072ee0f6f7750b6362dd585)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Aoss", jsii.invoke(self, "ifCollectionId", [value, operator]))

    @jsii.member(jsii_name="ifIndex")
    def if_index(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Aoss":
        '''(experimental) Filters access by the index.

        https://docs.aws.amazon.com/opensearch-service/latest/developerguide/security-iam-serverless.html#security_iam_serverless-conditionkeys

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e8e22a8553973ecdedad75fa515cdf6bda1fb589eeb9ae45652fca49121cf903)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Aoss", jsii.invoke(self, "ifIndex", [value, operator]))

    @jsii.member(jsii_name="onCollection")
    def on_collection(
        self,
        collection_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Aoss":
        '''(experimental) Adds a resource of type Collection to the statement.

        https://docs.aws.amazon.com/opensearch-service/latest/developerguide/serverless-overview.html

        :param collection_id: - Identifier for the collectionId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__59620958ad1cdbaae165c962363a90b0ebcbd51e801bd4a874474f114ec27347)
            check_type(argname="argument collection_id", value=collection_id, expected_type=type_hints["collection_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Aoss", jsii.invoke(self, "onCollection", [collection_id, account, region, partition]))

    @jsii.member(jsii_name="toBatchGetCollection")
    def to_batch_get_collection(self) -> "Aoss":
        '''(experimental) Grants permission to get attributes for one or more collections.

        Access Level: Read

        https://docs.aws.amazon.com/opensearch-service/latest/ServerlessAPIReference/API_BatchGetCollection.html

        :stability: experimental
        '''
        return typing.cast("Aoss", jsii.invoke(self, "toBatchGetCollection", []))

    @jsii.member(jsii_name="toBatchGetVpcEndpoint")
    def to_batch_get_vpc_endpoint(self) -> "Aoss":
        '''(experimental) Grants permission to get attributes for one or more VPC endpoints.

        Access Level: Read

        https://docs.aws.amazon.com/opensearch-service/latest/ServerlessAPIReference/API_BatchGetVpcEndpoint.html

        :stability: experimental
        '''
        return typing.cast("Aoss", jsii.invoke(self, "toBatchGetVpcEndpoint", []))

    @jsii.member(jsii_name="toCreateAccessPolicy")
    def to_create_access_policy(self) -> "Aoss":
        '''(experimental) Grants permission to create a data access policy.

        Access Level: Write

        https://docs.aws.amazon.com/opensearch-service/latest/ServerlessAPIReference/API_CreateAccessPolicy.html

        :stability: experimental
        '''
        return typing.cast("Aoss", jsii.invoke(self, "toCreateAccessPolicy", []))

    @jsii.member(jsii_name="toCreateCollection")
    def to_create_collection(self) -> "Aoss":
        '''(experimental) Grants permission to create a serverless collection.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/opensearch-service/latest/ServerlessAPIReference/API_CreateCollection.html

        :stability: experimental
        '''
        return typing.cast("Aoss", jsii.invoke(self, "toCreateCollection", []))

    @jsii.member(jsii_name="toCreateSecurityConfig")
    def to_create_security_config(self) -> "Aoss":
        '''(experimental) Grants permission to create a serverless security configuration.

        Access Level: Write

        https://docs.aws.amazon.com/opensearch-service/latest/ServerlessAPIReference/API_CreateSecurityConfig.html

        :stability: experimental
        '''
        return typing.cast("Aoss", jsii.invoke(self, "toCreateSecurityConfig", []))

    @jsii.member(jsii_name="toCreateSecurityPolicy")
    def to_create_security_policy(self) -> "Aoss":
        '''(experimental) Grants permission to create a network or encryption policy.

        Access Level: Write

        https://docs.aws.amazon.com/opensearch-service/latest/ServerlessAPIReference/API_CreateSecurityPolicy.html

        :stability: experimental
        '''
        return typing.cast("Aoss", jsii.invoke(self, "toCreateSecurityPolicy", []))

    @jsii.member(jsii_name="toCreateVpcEndpoint")
    def to_create_vpc_endpoint(self) -> "Aoss":
        '''(experimental) Grants permission to create an OpenSearch-Serverless-managed interface VPC endpoint.

        Access Level: Write

        https://docs.aws.amazon.com/opensearch-service/latest/ServerlessAPIReference/API_CreateVpcEndpoint.html

        :stability: experimental
        '''
        return typing.cast("Aoss", jsii.invoke(self, "toCreateVpcEndpoint", []))

    @jsii.member(jsii_name="toDeleteAccessPolicy")
    def to_delete_access_policy(self) -> "Aoss":
        '''(experimental) Grants permission to delete a data access policy.

        Access Level: Write

        https://docs.aws.amazon.com/opensearch-service/latest/ServerlessAPIReference/API_DeleteAccessPolicy.html

        :stability: experimental
        '''
        return typing.cast("Aoss", jsii.invoke(self, "toDeleteAccessPolicy", []))

    @jsii.member(jsii_name="toDeleteCollection")
    def to_delete_collection(self) -> "Aoss":
        '''(experimental) Grants permission to delete a serverless collection.

        Access Level: Write

        https://docs.aws.amazon.com/opensearch-service/latest/ServerlessAPIReference/API_DeleteCollection.html

        :stability: experimental
        '''
        return typing.cast("Aoss", jsii.invoke(self, "toDeleteCollection", []))

    @jsii.member(jsii_name="toDeleteSecurityConfig")
    def to_delete_security_config(self) -> "Aoss":
        '''(experimental) Grants permission to delete a security configuration.

        Access Level: Write

        https://docs.aws.amazon.com/opensearch-service/latest/ServerlessAPIReference/API_DeleteSecurityConfig.html

        :stability: experimental
        '''
        return typing.cast("Aoss", jsii.invoke(self, "toDeleteSecurityConfig", []))

    @jsii.member(jsii_name="toDeleteSecurityPolicy")
    def to_delete_security_policy(self) -> "Aoss":
        '''(experimental) Grants permission to delete a security policy.

        Access Level: Write

        https://docs.aws.amazon.com/opensearch-service/latest/ServerlessAPIReference/API_DeleteSecurityPolicy.html

        :stability: experimental
        '''
        return typing.cast("Aoss", jsii.invoke(self, "toDeleteSecurityPolicy", []))

    @jsii.member(jsii_name="toDeleteVpcEndpoint")
    def to_delete_vpc_endpoint(self) -> "Aoss":
        '''(experimental) Grants permission to delete an OpenSearch Serverless-managed interface VPC endpoint.

        Access Level: Write

        https://docs.aws.amazon.com/opensearch-service/latest/ServerlessAPIReference/API_DeleteVpcEndpoint.html

        :stability: experimental
        '''
        return typing.cast("Aoss", jsii.invoke(self, "toDeleteVpcEndpoint", []))

    @jsii.member(jsii_name="toGetAccessPolicy")
    def to_get_access_policy(self) -> "Aoss":
        '''(experimental) Grants permission to get information about a data access policy.

        Access Level: Read

        https://docs.aws.amazon.com/opensearch-service/latest/ServerlessAPIReference/API_GetAccessPolicy.html

        :stability: experimental
        '''
        return typing.cast("Aoss", jsii.invoke(self, "toGetAccessPolicy", []))

    @jsii.member(jsii_name="toGetAccountSettings")
    def to_get_account_settings(self) -> "Aoss":
        '''(experimental) Grants permission to get account settings, including capacity settings.

        Access Level: Read

        https://docs.aws.amazon.com/opensearch-service/latest/ServerlessAPIReference/API_GetAccountSettings.html

        :stability: experimental
        '''
        return typing.cast("Aoss", jsii.invoke(self, "toGetAccountSettings", []))

    @jsii.member(jsii_name="toGetPoliciesStats")
    def to_get_policies_stats(self) -> "Aoss":
        '''(experimental) Grants permission to get statistis about the security policies in your account.

        Access Level: Read

        https://docs.aws.amazon.com/opensearch-service/latest/ServerlessAPIReference/API_GetPoliciesStats.html

        :stability: experimental
        '''
        return typing.cast("Aoss", jsii.invoke(self, "toGetPoliciesStats", []))

    @jsii.member(jsii_name="toGetSecurityConfig")
    def to_get_security_config(self) -> "Aoss":
        '''(experimental) Grants permission to get information about a serverless security configuration.

        Access Level: Read

        https://docs.aws.amazon.com/opensearch-service/latest/ServerlessAPIReference/API_GetSecurityConfig.html

        :stability: experimental
        '''
        return typing.cast("Aoss", jsii.invoke(self, "toGetSecurityConfig", []))

    @jsii.member(jsii_name="toGetSecurityPolicy")
    def to_get_security_policy(self) -> "Aoss":
        '''(experimental) Grants permission to get information about a security policy.

        Access Level: Read

        https://docs.aws.amazon.com/opensearch-service/latest/ServerlessAPIReference/API_GetSecurityPolicy.html

        :stability: experimental
        '''
        return typing.cast("Aoss", jsii.invoke(self, "toGetSecurityPolicy", []))

    @jsii.member(jsii_name="toListAccessPolicies")
    def to_list_access_policies(self) -> "Aoss":
        '''(experimental) Grants permission to list data access policies.

        Access Level: List

        https://docs.aws.amazon.com/opensearch-service/latest/ServerlessAPIReference/API_ListAccessPolicies.html

        :stability: experimental
        '''
        return typing.cast("Aoss", jsii.invoke(self, "toListAccessPolicies", []))

    @jsii.member(jsii_name="toListCollections")
    def to_list_collections(self) -> "Aoss":
        '''(experimental) Grants permission to list collections.

        Access Level: List

        https://docs.aws.amazon.com/opensearch-service/latest/ServerlessAPIReference/API_ListCollections.html

        :stability: experimental
        '''
        return typing.cast("Aoss", jsii.invoke(self, "toListCollections", []))

    @jsii.member(jsii_name="toListSecurityConfigs")
    def to_list_security_configs(self) -> "Aoss":
        '''(experimental) Grants permission to list security configurations.

        Access Level: List

        https://docs.aws.amazon.com/opensearch-service/latest/ServerlessAPIReference/API_ListSecurityConfigs.html

        :stability: experimental
        '''
        return typing.cast("Aoss", jsii.invoke(self, "toListSecurityConfigs", []))

    @jsii.member(jsii_name="toListSecurityPolicies")
    def to_list_security_policies(self) -> "Aoss":
        '''(experimental) Grants permission to list security policies.

        Access Level: List

        https://docs.aws.amazon.com/opensearch-service/latest/ServerlessAPIReference/API_ListSecurityPolicies.html

        :stability: experimental
        '''
        return typing.cast("Aoss", jsii.invoke(self, "toListSecurityPolicies", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Aoss":
        '''(experimental) Grants permission to list tags for a collection.

        Access Level: List

        https://docs.aws.amazon.com/opensearch-service/latest/ServerlessAPIReference/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("Aoss", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toListVpcEndpoints")
    def to_list_vpc_endpoints(self) -> "Aoss":
        '''(experimental) Grants permission to list OpenSearch Serverless-managed VPC endpoints.

        Access Level: List

        https://docs.aws.amazon.com/opensearch-service/latest/ServerlessAPIReference/API_ListVpcEndpoints.html

        :stability: experimental
        '''
        return typing.cast("Aoss", jsii.invoke(self, "toListVpcEndpoints", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Aoss":
        '''(experimental) Grants permission to tag a serverless collection.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/opensearch-service/latest/ServerlessAPIReference/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("Aoss", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Aoss":
        '''(experimental) Grants permission to remove tags from a collection.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/opensearch-service/latest/ServerlessAPIReference/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("Aoss", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateAccessPolicy")
    def to_update_access_policy(self) -> "Aoss":
        '''(experimental) Grants permission to update a data access policy.

        Access Level: Write

        https://docs.aws.amazon.com/opensearch-service/latest/ServerlessAPIReference/API_UpdateAccessPolicy.html

        :stability: experimental
        '''
        return typing.cast("Aoss", jsii.invoke(self, "toUpdateAccessPolicy", []))

    @jsii.member(jsii_name="toUpdateAccountSettings")
    def to_update_account_settings(self) -> "Aoss":
        '''(experimental) Grants permission to update account settings, including capacity settings.

        Access Level: Write

        https://docs.aws.amazon.com/opensearch-service/latest/ServerlessAPIReference/API_UpdateAccountSettings.html

        :stability: experimental
        '''
        return typing.cast("Aoss", jsii.invoke(self, "toUpdateAccountSettings", []))

    @jsii.member(jsii_name="toUpdateCollection")
    def to_update_collection(self) -> "Aoss":
        '''(experimental) Grants permission to update a collection.

        Access Level: Write

        https://docs.aws.amazon.com/opensearch-service/latest/ServerlessAPIReference/API_UpdateCollection.html

        :stability: experimental
        '''
        return typing.cast("Aoss", jsii.invoke(self, "toUpdateCollection", []))

    @jsii.member(jsii_name="toUpdateSecurityConfig")
    def to_update_security_config(self) -> "Aoss":
        '''(experimental) Grants permission to update a security configuration.

        Access Level: Write

        https://docs.aws.amazon.com/opensearch-service/latest/ServerlessAPIReference/API_UpdateSecurityConfig.html

        :stability: experimental
        '''
        return typing.cast("Aoss", jsii.invoke(self, "toUpdateSecurityConfig", []))

    @jsii.member(jsii_name="toUpdateSecurityPolicy")
    def to_update_security_policy(self) -> "Aoss":
        '''(experimental) Grants permission to update a security policy.

        Access Level: Write

        https://docs.aws.amazon.com/opensearch-service/latest/ServerlessAPIReference/API_UpdateSecurityPolicy.html

        :stability: experimental
        '''
        return typing.cast("Aoss", jsii.invoke(self, "toUpdateSecurityPolicy", []))

    @jsii.member(jsii_name="toUpdateVpcEndpoint")
    def to_update_vpc_endpoint(self) -> "Aoss":
        '''(experimental) Grants permission to update an OpenSearch Serverless-managed VPC endpoint.

        Access Level: Write

        https://docs.aws.amazon.com/opensearch-service/latest/ServerlessAPIReference/API_UpdateVpcEndpoint.html

        :stability: experimental
        '''
        return typing.cast("Aoss", jsii.invoke(self, "toUpdateVpcEndpoint", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5ec3e05591e36e4e026ceac030dcc22181fe4e96b8713b1e6709fcdb418b2c46)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d40f908dbb0ffdca8234cd0027e2800ed31e6cba9c59c6bbb4051a59fa9768fa)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Apigateway(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Apigateway",
):
    '''(experimental) Statement provider for service `apigateway <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonapigatewaymanagement.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `apigateway <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonapigatewaymanagement.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="ifRequestAccessLoggingDestination")
    def if_request_access_logging_destination(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Apigateway":
        '''(experimental) Filters access by access log destination. Available during the CreateStage and UpdateStage operations.

        https://docs.aws.amazon.com/apigateway/latest/developerguide/security_iam_service-with-iam.html

        Applies to resource types:

        - Stage
        - Stages

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__288bd55d2b49f78cd622c68dd466c77f7c314fb899d103ce75b0dda8a491efb7)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Apigateway", jsii.invoke(self, "ifRequestAccessLoggingDestination", [value, operator]))

    @jsii.member(jsii_name="ifRequestAccessLoggingFormat")
    def if_request_access_logging_format(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Apigateway":
        '''(experimental) Filters access by access log format. Available during the CreateStage and UpdateStage operations.

        https://docs.aws.amazon.com/apigateway/latest/developerguide/security_iam_service-with-iam.html

        Applies to resource types:

        - Stage
        - Stages

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f90def41b71f696adf8a8abf88f6718cd99214f3a533bf4b746eeab89b5f50f9)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Apigateway", jsii.invoke(self, "ifRequestAccessLoggingFormat", [value, operator]))

    @jsii.member(jsii_name="ifRequestApiKeyRequired")
    def if_request_api_key_required(
        self,
        value: typing.Optional[builtins.bool] = None,
    ) -> "Apigateway":
        '''(experimental) Filters access based on whether an API key is required or not.

        Available during the CreateMethod and PutMethod operations. Also available as a collection during import and reimport

        https://docs.aws.amazon.com/apigateway/latest/developerguide/security_iam_service-with-iam.html

        Applies to resource types:

        - Method
        - RestApi
        - RestApis

        :param value: ``true`` or ``false``. **Default:** ``true``

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8f4f8e5ecfaa53ef21a6d2d58f46794bb61920a11de780396d5519980817c8d2)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast("Apigateway", jsii.invoke(self, "ifRequestApiKeyRequired", [value]))

    @jsii.member(jsii_name="ifRequestApiName")
    def if_request_api_name(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Apigateway":
        '''(experimental) Filters access by API name. Available during the CreateRestApi and UpdateRestApi operations.

        https://docs.aws.amazon.com/apigateway/latest/developerguide/security_iam_service-with-iam.html

        Applies to resource types:

        - RestApi
        - RestApis

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__dafaaab5603b9f3e962c609661e93d43f25ea940f1bef7456d65f17bcd84d701)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Apigateway", jsii.invoke(self, "ifRequestApiName", [value, operator]))

    @jsii.member(jsii_name="ifRequestAuthorizerType")
    def if_request_authorizer_type(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Apigateway":
        '''(experimental) Filters access by type of authorizer in the request, for example TOKEN, REQUEST, JWT.

        Available during CreateAuthorizer and UpdateAuthorizer. Also available during import and reimport as an ArrayOfString

        https://docs.aws.amazon.com/apigateway/latest/developerguide/security_iam_service-with-iam.html

        Applies to resource types:

        - Authorizer
        - Authorizers
        - RestApi
        - RestApis

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e1d4c2bc183c80d3cb92663353e40f8344d0dba7e8971b306cfa1a2c9972437f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Apigateway", jsii.invoke(self, "ifRequestAuthorizerType", [value, operator]))

    @jsii.member(jsii_name="ifRequestAuthorizerUri")
    def if_request_authorizer_uri(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Apigateway":
        '''(experimental) Filters access by URI of a Lambda authorizer function.

        Available during CreateAuthorizer and UpdateAuthorizer. Also available during import and reimport as an ArrayOfString

        https://docs.aws.amazon.com/apigateway/latest/developerguide/security_iam_service-with-iam.html

        Applies to resource types:

        - Authorizer
        - Authorizers
        - RestApi
        - RestApis

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bedd9d24f25781c08b0a3ec8410f8315e873280b805a36b78c645135cdc99fd2)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Apigateway", jsii.invoke(self, "ifRequestAuthorizerUri", [value, operator]))

    @jsii.member(jsii_name="ifRequestDisableExecuteApiEndpoint")
    def if_request_disable_execute_api_endpoint(
        self,
        value: typing.Optional[builtins.bool] = None,
    ) -> "Apigateway":
        '''(experimental) Filters access by status of the default execute-api endpoint. Available during the CreateRestApi and DeleteRestApi operations.

        https://docs.aws.amazon.com/apigateway/latest/developerguide/security_iam_service-with-iam.html

        Applies to resource types:

        - RestApi
        - RestApis

        :param value: ``true`` or ``false``. **Default:** ``true``

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__522fed4c0826fa278514cb0dbe8d704dc10d2b495f18d8c7875c73fae54b18ea)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast("Apigateway", jsii.invoke(self, "ifRequestDisableExecuteApiEndpoint", [value]))

    @jsii.member(jsii_name="ifRequestEndpointType")
    def if_request_endpoint_type(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Apigateway":
        '''(experimental) Filters access by endpoint type. Available during the CreateDomainName, UpdateDomainName, CreateRestApi, and UpdateRestApi operations.

        https://docs.aws.amazon.com/apigateway/latest/developerguide/security_iam_service-with-iam.html

        Applies to resource types:

        - DomainName
        - DomainNames
        - RestApi
        - RestApis

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c3557eb53037e756ee24a69c32d9b63dd20e2d9f58f03a925c69c8dee7fc9273)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Apigateway", jsii.invoke(self, "ifRequestEndpointType", [value, operator]))

    @jsii.member(jsii_name="ifRequestMtlsTrustStoreUri")
    def if_request_mtls_trust_store_uri(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Apigateway":
        '''(experimental) Filters access by URI of the truststore used for mutual TLS authentication. Available during the CreateDomainName and UpdateDomainName operations.

        https://docs.aws.amazon.com/apigateway/latest/developerguide/security_iam_service-with-iam.html

        Applies to resource types:

        - DomainName
        - DomainNames

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__46524fbccea04b5ab7efa2a85010dc88a29ff8b57eb997f5dfa2bbc288e0837d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Apigateway", jsii.invoke(self, "ifRequestMtlsTrustStoreUri", [value, operator]))

    @jsii.member(jsii_name="ifRequestMtlsTrustStoreVersion")
    def if_request_mtls_trust_store_version(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Apigateway":
        '''(experimental) Filters access by version of the truststore used for mutual TLS authentication. Available during the CreateDomainName and UpdateDomainName operations.

        https://docs.aws.amazon.com/apigateway/latest/developerguide/security_iam_service-with-iam.html

        Applies to resource types:

        - DomainName
        - DomainNames

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4880fef66681c136eb580bd959379dbaad777f668af40e52367b7bb482365926)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Apigateway", jsii.invoke(self, "ifRequestMtlsTrustStoreVersion", [value, operator]))

    @jsii.member(jsii_name="ifRequestRouteAuthorizationType")
    def if_request_route_authorization_type(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Apigateway":
        '''(experimental) Filters access by authorization type, for example NONE, AWS_IAM, CUSTOM, JWT, COGNITO_USER_POOLS.

        Available during the CreateMethod and PutMethod operations Also available as a collection during import

        https://docs.aws.amazon.com/apigateway/latest/developerguide/security_iam_service-with-iam.html

        Applies to resource types:

        - Method
        - RestApi
        - RestApis

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__10b170d0a8f4403227cc951833983c34d9b79bad47f4ba5e3912938ba4edd44d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Apigateway", jsii.invoke(self, "ifRequestRouteAuthorizationType", [value, operator]))

    @jsii.member(jsii_name="ifRequestSecurityPolicy")
    def if_request_security_policy(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Apigateway":
        '''(experimental) Filters access by TLS version. Available during the CreateDomain and UpdateDomain operations.

        https://docs.aws.amazon.com/apigateway/latest/developerguide/security_iam_service-with-iam.html

        Applies to resource types:

        - DomainName
        - DomainNames

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e1b06dca5ce2d1f6e01a6b30db4c25ed527dda34579ff4069ac4bb9f1729d212)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Apigateway", jsii.invoke(self, "ifRequestSecurityPolicy", [value, operator]))

    @jsii.member(jsii_name="ifRequestStageName")
    def if_request_stage_name(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Apigateway":
        '''(experimental) Filters access by stage name of the deployment that you attempt to create. Available during the CreateDeployment operation.

        https://docs.aws.amazon.com/apigateway/latest/developerguide/security_iam_service-with-iam.html

        Applies to resource types:

        - Deployments

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6284edeb5e59d59c8a341fcf88027569fd49d9f61d2e953836474acedc1b1fe9)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Apigateway", jsii.invoke(self, "ifRequestStageName", [value, operator]))

    @jsii.member(jsii_name="ifResourceAccessLoggingDestination")
    def if_resource_access_logging_destination(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Apigateway":
        '''(experimental) Filters access by access log destination of the current Stage resource. Available during the UpdateStage and DeleteStage operations.

        https://docs.aws.amazon.com/apigateway/latest/developerguide/security_iam_service-with-iam.html

        Applies to resource types:

        - Stage

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7c0eed2ab55a7e36e5521083498e118bc430471efbea5deaca4ee4a36d97b801)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Apigateway", jsii.invoke(self, "ifResourceAccessLoggingDestination", [value, operator]))

    @jsii.member(jsii_name="ifResourceAccessLoggingFormat")
    def if_resource_access_logging_format(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Apigateway":
        '''(experimental) Filters access by access log format of the current Stage resource. Available during the UpdateStage and DeleteStage operations.

        https://docs.aws.amazon.com/apigateway/latest/developerguide/security_iam_service-with-iam.html

        Applies to resource types:

        - Stage

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9377090531500f52e883062d8245fbe53aac1fb06b38dc87d18b45806a6e55ea)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Apigateway", jsii.invoke(self, "ifResourceAccessLoggingFormat", [value, operator]))

    @jsii.member(jsii_name="ifResourceApiKeyRequired")
    def if_resource_api_key_required(
        self,
        value: typing.Optional[builtins.bool] = None,
    ) -> "Apigateway":
        '''(experimental) Filters access based on whether an API key is required or not for the existing Method resource.

        Available during the PutMethod and DeleteMethod operations. Also available as a collection during reimport

        https://docs.aws.amazon.com/apigateway/latest/developerguide/security_iam_service-with-iam.html

        Applies to resource types:

        - Method
        - RestApi

        :param value: ``true`` or ``false``. **Default:** ``true``

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0e0d20549ee97242c717eda1a8acabfd3f7a00263cc44e03301f7438403403aa)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast("Apigateway", jsii.invoke(self, "ifResourceApiKeyRequired", [value]))

    @jsii.member(jsii_name="ifResourceApiName")
    def if_resource_api_name(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Apigateway":
        '''(experimental) Filters access by API name of the existing RestApi resource. Available during UpdateRestApi and DeleteRestApi operations.

        https://docs.aws.amazon.com/apigateway/latest/developerguide/security_iam_service-with-iam.html

        Applies to resource types:

        - RestApi

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9a69653a0fa34c6a39e4f6791395bb87a5235ed2b2f6d150c5cf37697c1e32bc)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Apigateway", jsii.invoke(self, "ifResourceApiName", [value, operator]))

    @jsii.member(jsii_name="ifResourceAuthorizerType")
    def if_resource_authorizer_type(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Apigateway":
        '''(experimental) Filters access by the current type of authorizer, for example TOKEN, REQUEST, JWT.

        Available during UpdateAuthorizer and DeleteAuthorizer operations. Also available during reimport as an ArrayOfString

        https://docs.aws.amazon.com/apigateway/latest/developerguide/security_iam_service-with-iam.html

        Applies to resource types:

        - Authorizer
        - RestApi

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__cc7357074935b27133dfb10b672aee6e22da9e353db10007f5b85ef6d8217434)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Apigateway", jsii.invoke(self, "ifResourceAuthorizerType", [value, operator]))

    @jsii.member(jsii_name="ifResourceAuthorizerUri")
    def if_resource_authorizer_uri(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Apigateway":
        '''(experimental) Filters access by URI of a Lambda authorizer function.

        Available during UpdateAuthorizer and DeleteAuthorizer operations. Also available during reimport as an ArrayOfString

        https://docs.aws.amazon.com/apigateway/latest/developerguide/security_iam_service-with-iam.html

        Applies to resource types:

        - Authorizer
        - RestApi

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1983b3f247f2218282140b880d087977cdda0b124918110d4edbc7126a546526)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Apigateway", jsii.invoke(self, "ifResourceAuthorizerUri", [value, operator]))

    @jsii.member(jsii_name="ifResourceDisableExecuteApiEndpoint")
    def if_resource_disable_execute_api_endpoint(
        self,
        value: typing.Optional[builtins.bool] = None,
    ) -> "Apigateway":
        '''(experimental) Filters access by status of the default execute-api endpoint of the current RestApi resource.

        Available during UpdateRestApi and DeleteRestApi operations

        https://docs.aws.amazon.com/apigateway/latest/developerguide/security_iam_service-with-iam.html

        Applies to resource types:

        - RestApi

        :param value: ``true`` or ``false``. **Default:** ``true``

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__98cb24062ad95f5a684e792900bc35a58905888cb7f782930c9e9596a19423cd)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast("Apigateway", jsii.invoke(self, "ifResourceDisableExecuteApiEndpoint", [value]))

    @jsii.member(jsii_name="ifResourceEndpointType")
    def if_resource_endpoint_type(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Apigateway":
        '''(experimental) Filters access by endpoint type. Available during the UpdateDomainName, DeleteDomainName, UpdateRestApi, and DeleteRestApi operations.

        https://docs.aws.amazon.com/apigateway/latest/developerguide/security_iam_service-with-iam.html

        Applies to resource types:

        - DomainName
        - RestApi

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a6dd974392d8196f4b79d4401f917cf7afe5d8559b063bff85cccebe35ac77d9)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Apigateway", jsii.invoke(self, "ifResourceEndpointType", [value, operator]))

    @jsii.member(jsii_name="ifResourceMtlsTrustStoreUri")
    def if_resource_mtls_trust_store_uri(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Apigateway":
        '''(experimental) Filters access by URI of the truststore used for mutual TLS authentication. Available during UpdateDomainName and DeleteDomainName operations.

        https://docs.aws.amazon.com/apigateway/latest/developerguide/security_iam_service-with-iam.html

        Applies to resource types:

        - DomainName

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d7a11d04b287fee1b14a410c6576c728d8ff2e8270e3121adc077ba4fb3a86cf)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Apigateway", jsii.invoke(self, "ifResourceMtlsTrustStoreUri", [value, operator]))

    @jsii.member(jsii_name="ifResourceMtlsTrustStoreVersion")
    def if_resource_mtls_trust_store_version(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Apigateway":
        '''(experimental) Filters access by version of the truststore used for mutual TLS authentication. Available during UpdateDomainName and DeleteDomainName operations.

        https://docs.aws.amazon.com/apigateway/latest/developerguide/security_iam_service-with-iam.html

        Applies to resource types:

        - DomainName

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b91000805f9c02bfde183d1054cf996783626a0cc90e0b8f5dd3638d38c19c10)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Apigateway", jsii.invoke(self, "ifResourceMtlsTrustStoreVersion", [value, operator]))

    @jsii.member(jsii_name="ifResourceRouteAuthorizationType")
    def if_resource_route_authorization_type(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Apigateway":
        '''(experimental) Filters access by authorization type of the existing Method resource, for example NONE, AWS_IAM, CUSTOM, JWT, COGNITO_USER_POOLS.

        Available during the PutMethod and DeleteMethod operations. Also available as a collection during reimport

        https://docs.aws.amazon.com/apigateway/latest/developerguide/security_iam_service-with-iam.html

        Applies to resource types:

        - Method
        - RestApi

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d4b99ab451d333559980916109d69b469e6cac3b941622c0effdd2a4eb4ead28)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Apigateway", jsii.invoke(self, "ifResourceRouteAuthorizationType", [value, operator]))

    @jsii.member(jsii_name="ifResourceSecurityPolicy")
    def if_resource_security_policy(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Apigateway":
        '''(experimental) Filters access by TLS version. Available during UpdateDomain and DeleteDomain operations.

        https://docs.aws.amazon.com/apigateway/latest/developerguide/security_iam_service-with-iam.html

        Applies to resource types:

        - DomainName

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__96be8ea01279b891fcdc61db2d2ecd5b3d82feb207112a19402d86419c98cbd1)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Apigateway", jsii.invoke(self, "ifResourceSecurityPolicy", [value, operator]))

    @jsii.member(jsii_name="onAccount")
    def on_account(
        self,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Apigateway":
        '''(experimental) Adds a resource of type Account to the statement.

        https://docs.aws.amazon.com/apigateway/latest/developerguide/security_iam_service-with-iam.html

        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ded7d4a34ec309d9aae88af69ecdf2930ce0ce95c8c2895e87c3f977e661702a)
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Apigateway", jsii.invoke(self, "onAccount", [region, partition]))

    @jsii.member(jsii_name="onApiKey")
    def on_api_key(
        self,
        api_key_id: builtins.str,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Apigateway":
        '''(experimental) Adds a resource of type ApiKey to the statement.

        https://docs.aws.amazon.com/apigateway/latest/developerguide/security_iam_service-with-iam.html

        :param api_key_id: - Identifier for the apiKeyId.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__be7cd1ef7238fd09c7178e8eea1bb2f7ddea019d77f8cf6a1c5952de540744bd)
            check_type(argname="argument api_key_id", value=api_key_id, expected_type=type_hints["api_key_id"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Apigateway", jsii.invoke(self, "onApiKey", [api_key_id, region, partition]))

    @jsii.member(jsii_name="onApiKeys")
    def on_api_keys(
        self,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Apigateway":
        '''(experimental) Adds a resource of type ApiKeys to the statement.

        https://docs.aws.amazon.com/apigateway/latest/developerguide/security_iam_service-with-iam.html

        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6c7220aa15605707f9d13cea9d2e8b2e86a0306a92e9827d93c1163ceb148c9b)
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Apigateway", jsii.invoke(self, "onApiKeys", [region, partition]))

    @jsii.member(jsii_name="onAuthorizer")
    def on_authorizer(
        self,
        rest_api_id: builtins.str,
        authorizer_id: builtins.str,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Apigateway":
        '''(experimental) Adds a resource of type Authorizer to the statement.

        https://docs.aws.amazon.com/apigateway/latest/developerguide/security_iam_service-with-iam.html

        :param rest_api_id: - Identifier for the restApiId.
        :param authorizer_id: - Identifier for the authorizerId.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifRequestAuthorizerType() - .ifRequestAuthorizerUri() - .ifResourceAuthorizerType() - .ifResourceAuthorizerUri() - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__399601807f0b12ee6ddc3f3777b371a19204e1aa04fad44ea4d5d90a7a9fd73f)
            check_type(argname="argument rest_api_id", value=rest_api_id, expected_type=type_hints["rest_api_id"])
            check_type(argname="argument authorizer_id", value=authorizer_id, expected_type=type_hints["authorizer_id"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Apigateway", jsii.invoke(self, "onAuthorizer", [rest_api_id, authorizer_id, region, partition]))

    @jsii.member(jsii_name="onAuthorizers")
    def on_authorizers(
        self,
        rest_api_id: builtins.str,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Apigateway":
        '''(experimental) Adds a resource of type Authorizers to the statement.

        https://docs.aws.amazon.com/apigateway/latest/developerguide/security_iam_service-with-iam.html

        :param rest_api_id: - Identifier for the restApiId.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifRequestAuthorizerType() - .ifRequestAuthorizerUri() - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5faa821e51b35a2b14aabf9930e41658bf5698aa207a3695a6aadffb32f711ab)
            check_type(argname="argument rest_api_id", value=rest_api_id, expected_type=type_hints["rest_api_id"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Apigateway", jsii.invoke(self, "onAuthorizers", [rest_api_id, region, partition]))

    @jsii.member(jsii_name="onBasePathMapping")
    def on_base_path_mapping(
        self,
        domain_name: builtins.str,
        base_path: builtins.str,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Apigateway":
        '''(experimental) Adds a resource of type BasePathMapping to the statement.

        https://docs.aws.amazon.com/apigateway/latest/developerguide/security_iam_service-with-iam.html

        :param domain_name: - Identifier for the domainName.
        :param base_path: - Identifier for the basePath.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7209423e380a6d0ece70aa938174b157e8219a5c3dd6787fc5af77cd4fe3317c)
            check_type(argname="argument domain_name", value=domain_name, expected_type=type_hints["domain_name"])
            check_type(argname="argument base_path", value=base_path, expected_type=type_hints["base_path"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Apigateway", jsii.invoke(self, "onBasePathMapping", [domain_name, base_path, region, partition]))

    @jsii.member(jsii_name="onBasePathMappings")
    def on_base_path_mappings(
        self,
        domain_name: builtins.str,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Apigateway":
        '''(experimental) Adds a resource of type BasePathMappings to the statement.

        https://docs.aws.amazon.com/apigateway/latest/developerguide/security_iam_service-with-iam.html

        :param domain_name: - Identifier for the domainName.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ac1b4458c736f9e4d2400b7ca51a1e02c918b6c187988e9695bc0ae8f660d05c)
            check_type(argname="argument domain_name", value=domain_name, expected_type=type_hints["domain_name"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Apigateway", jsii.invoke(self, "onBasePathMappings", [domain_name, region, partition]))

    @jsii.member(jsii_name="onClientCertificate")
    def on_client_certificate(
        self,
        client_certificate_id: builtins.str,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Apigateway":
        '''(experimental) Adds a resource of type ClientCertificate to the statement.

        https://docs.aws.amazon.com/apigateway/latest/developerguide/security_iam_service-with-iam.html

        :param client_certificate_id: - Identifier for the clientCertificateId.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__473d9cb9156b2ed0e815cd6a7bc1c2e54c3698a0924d9993803e454b65fe9508)
            check_type(argname="argument client_certificate_id", value=client_certificate_id, expected_type=type_hints["client_certificate_id"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Apigateway", jsii.invoke(self, "onClientCertificate", [client_certificate_id, region, partition]))

    @jsii.member(jsii_name="onClientCertificates")
    def on_client_certificates(
        self,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Apigateway":
        '''(experimental) Adds a resource of type ClientCertificates to the statement.

        https://docs.aws.amazon.com/apigateway/latest/developerguide/security_iam_service-with-iam.html

        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__25a23af57520cea45faa07f05237af280f99710a161aad94b51b75c65998bb96)
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Apigateway", jsii.invoke(self, "onClientCertificates", [region, partition]))

    @jsii.member(jsii_name="onDeployment")
    def on_deployment(
        self,
        rest_api_id: builtins.str,
        deployment_id: builtins.str,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Apigateway":
        '''(experimental) Adds a resource of type Deployment to the statement.

        https://docs.aws.amazon.com/apigateway/latest/developerguide/security_iam_service-with-iam.html

        :param rest_api_id: - Identifier for the restApiId.
        :param deployment_id: - Identifier for the deploymentId.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9bf994f32fc73e715ea99d1ed917f1b595505195e2924aa5dc5541f993081b60)
            check_type(argname="argument rest_api_id", value=rest_api_id, expected_type=type_hints["rest_api_id"])
            check_type(argname="argument deployment_id", value=deployment_id, expected_type=type_hints["deployment_id"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Apigateway", jsii.invoke(self, "onDeployment", [rest_api_id, deployment_id, region, partition]))

    @jsii.member(jsii_name="onDeployments")
    def on_deployments(
        self,
        rest_api_id: builtins.str,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Apigateway":
        '''(experimental) Adds a resource of type Deployments to the statement.

        https://docs.aws.amazon.com/apigateway/latest/developerguide/security_iam_service-with-iam.html

        :param rest_api_id: - Identifier for the restApiId.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifRequestStageName()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5ed76ba11dc7022bbf5b39bf07e5a953bd73fd3261da8e35b819804ee78210fb)
            check_type(argname="argument rest_api_id", value=rest_api_id, expected_type=type_hints["rest_api_id"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Apigateway", jsii.invoke(self, "onDeployments", [rest_api_id, region, partition]))

    @jsii.member(jsii_name="onDocumentationPart")
    def on_documentation_part(
        self,
        rest_api_id: builtins.str,
        documentation_part_id: builtins.str,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Apigateway":
        '''(experimental) Adds a resource of type DocumentationPart to the statement.

        https://docs.aws.amazon.com/apigateway/latest/developerguide/security_iam_service-with-iam.html

        :param rest_api_id: - Identifier for the restApiId.
        :param documentation_part_id: - Identifier for the documentationPartId.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a915f335b0c11558ba64cb141799977dc562c3b4f23a0a20841e595c5174b934)
            check_type(argname="argument rest_api_id", value=rest_api_id, expected_type=type_hints["rest_api_id"])
            check_type(argname="argument documentation_part_id", value=documentation_part_id, expected_type=type_hints["documentation_part_id"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Apigateway", jsii.invoke(self, "onDocumentationPart", [rest_api_id, documentation_part_id, region, partition]))

    @jsii.member(jsii_name="onDocumentationParts")
    def on_documentation_parts(
        self,
        rest_api_id: builtins.str,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Apigateway":
        '''(experimental) Adds a resource of type DocumentationParts to the statement.

        https://docs.aws.amazon.com/apigateway/latest/developerguide/security_iam_service-with-iam.html

        :param rest_api_id: - Identifier for the restApiId.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5e898f8b0283210b313bdf53607eb94ae7504885f571f3a80548d79b3d46673a)
            check_type(argname="argument rest_api_id", value=rest_api_id, expected_type=type_hints["rest_api_id"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Apigateway", jsii.invoke(self, "onDocumentationParts", [rest_api_id, region, partition]))

    @jsii.member(jsii_name="onDocumentationVersion")
    def on_documentation_version(
        self,
        rest_api_id: builtins.str,
        documentation_version_id: builtins.str,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Apigateway":
        '''(experimental) Adds a resource of type DocumentationVersion to the statement.

        https://docs.aws.amazon.com/apigateway/latest/developerguide/security_iam_service-with-iam.html

        :param rest_api_id: - Identifier for the restApiId.
        :param documentation_version_id: - Identifier for the documentationVersionId.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__31d536d1b7a2efdae068357516c042e9978790d8f730abe1b492cd7f69d74324)
            check_type(argname="argument rest_api_id", value=rest_api_id, expected_type=type_hints["rest_api_id"])
            check_type(argname="argument documentation_version_id", value=documentation_version_id, expected_type=type_hints["documentation_version_id"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Apigateway", jsii.invoke(self, "onDocumentationVersion", [rest_api_id, documentation_version_id, region, partition]))

    @jsii.member(jsii_name="onDocumentationVersions")
    def on_documentation_versions(
        self,
        rest_api_id: builtins.str,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Apigateway":
        '''(experimental) Adds a resource of type DocumentationVersions to the statement.

        https://docs.aws.amazon.com/apigateway/latest/developerguide/security_iam_service-with-iam.html

        :param rest_api_id: - Identifier for the restApiId.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__30544719366ed85f366288f6e12fd7489a00b2a6f71427d9dbf7ff26bbed59b7)
            check_type(argname="argument rest_api_id", value=rest_api_id, expected_type=type_hints["rest_api_id"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Apigateway", jsii.invoke(self, "onDocumentationVersions", [rest_api_id, region, partition]))

    @jsii.member(jsii_name="onDomainName")
    def on_domain_name(
        self,
        domain_name: builtins.str,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Apigateway":
        '''(experimental) Adds a resource of type DomainName to the statement.

        https://docs.aws.amazon.com/apigateway/latest/developerguide/security_iam_service-with-iam.html

        :param domain_name: - Identifier for the domainName.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifRequestEndpointType() - .ifRequestMtlsTrustStoreUri() - .ifRequestMtlsTrustStoreVersion() - .ifRequestSecurityPolicy() - .ifResourceEndpointType() - .ifResourceMtlsTrustStoreUri() - .ifResourceMtlsTrustStoreVersion() - .ifResourceSecurityPolicy() - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b0f0ce96e690729cb9006edf805546a88d3fef79e44d1f24887f46615b8928aa)
            check_type(argname="argument domain_name", value=domain_name, expected_type=type_hints["domain_name"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Apigateway", jsii.invoke(self, "onDomainName", [domain_name, region, partition]))

    @jsii.member(jsii_name="onDomainNames")
    def on_domain_names(
        self,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Apigateway":
        '''(experimental) Adds a resource of type DomainNames to the statement.

        https://docs.aws.amazon.com/apigateway/latest/developerguide/security_iam_service-with-iam.html

        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifRequestEndpointType() - .ifRequestMtlsTrustStoreUri() - .ifRequestMtlsTrustStoreVersion() - .ifRequestSecurityPolicy() - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2447ee12aec53d4a982836e93f28f4af366e2bb28b80dfb7ea59a564505d1ffb)
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Apigateway", jsii.invoke(self, "onDomainNames", [region, partition]))

    @jsii.member(jsii_name="onGatewayResponse")
    def on_gateway_response(
        self,
        rest_api_id: builtins.str,
        response_type: builtins.str,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Apigateway":
        '''(experimental) Adds a resource of type GatewayResponse to the statement.

        https://docs.aws.amazon.com/apigateway/latest/developerguide/security_iam_service-with-iam.html

        :param rest_api_id: - Identifier for the restApiId.
        :param response_type: - Identifier for the responseType.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4d087ebd0bd19b0ed3ec49a5eaa6642218a9d5f3032bfbeede3eaa4c945c9848)
            check_type(argname="argument rest_api_id", value=rest_api_id, expected_type=type_hints["rest_api_id"])
            check_type(argname="argument response_type", value=response_type, expected_type=type_hints["response_type"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Apigateway", jsii.invoke(self, "onGatewayResponse", [rest_api_id, response_type, region, partition]))

    @jsii.member(jsii_name="onGatewayResponses")
    def on_gateway_responses(
        self,
        rest_api_id: builtins.str,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Apigateway":
        '''(experimental) Adds a resource of type GatewayResponses to the statement.

        https://docs.aws.amazon.com/apigateway/latest/developerguide/security_iam_service-with-iam.html

        :param rest_api_id: - Identifier for the restApiId.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3ec8a0cbaf8ff8ee08ef9a4e52d1b42c315b29523323d3b6aab84738ec637010)
            check_type(argname="argument rest_api_id", value=rest_api_id, expected_type=type_hints["rest_api_id"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Apigateway", jsii.invoke(self, "onGatewayResponses", [rest_api_id, region, partition]))

    @jsii.member(jsii_name="onIntegration")
    def on_integration(
        self,
        rest_api_id: builtins.str,
        resource_id: builtins.str,
        http_method_type: builtins.str,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Apigateway":
        '''(experimental) Adds a resource of type Integration to the statement.

        https://docs.aws.amazon.com/apigateway/latest/developerguide/security_iam_service-with-iam.html

        :param rest_api_id: - Identifier for the restApiId.
        :param resource_id: - Identifier for the resourceId.
        :param http_method_type: - Identifier for the httpMethodType.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__dff3f0c3dd01f8072cbf1451ccea60b4b8771b81c67629bb8a8d6a53a27cbafe)
            check_type(argname="argument rest_api_id", value=rest_api_id, expected_type=type_hints["rest_api_id"])
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument http_method_type", value=http_method_type, expected_type=type_hints["http_method_type"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Apigateway", jsii.invoke(self, "onIntegration", [rest_api_id, resource_id, http_method_type, region, partition]))

    @jsii.member(jsii_name="onIntegrationResponse")
    def on_integration_response(
        self,
        rest_api_id: builtins.str,
        resource_id: builtins.str,
        http_method_type: builtins.str,
        status_code: builtins.str,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Apigateway":
        '''(experimental) Adds a resource of type IntegrationResponse to the statement.

        https://docs.aws.amazon.com/apigateway/latest/developerguide/security_iam_service-with-iam.html

        :param rest_api_id: - Identifier for the restApiId.
        :param resource_id: - Identifier for the resourceId.
        :param http_method_type: - Identifier for the httpMethodType.
        :param status_code: - Identifier for the statusCode.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__eed00952cdb1a52d1640682adf3210690c15bc14e59e18917ba096d5a30784c5)
            check_type(argname="argument rest_api_id", value=rest_api_id, expected_type=type_hints["rest_api_id"])
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument http_method_type", value=http_method_type, expected_type=type_hints["http_method_type"])
            check_type(argname="argument status_code", value=status_code, expected_type=type_hints["status_code"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Apigateway", jsii.invoke(self, "onIntegrationResponse", [rest_api_id, resource_id, http_method_type, status_code, region, partition]))

    @jsii.member(jsii_name="onMethod")
    def on_method(
        self,
        rest_api_id: builtins.str,
        resource_id: builtins.str,
        http_method_type: builtins.str,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Apigateway":
        '''(experimental) Adds a resource of type Method to the statement.

        https://docs.aws.amazon.com/apigateway/latest/developerguide/security_iam_service-with-iam.html

        :param rest_api_id: - Identifier for the restApiId.
        :param resource_id: - Identifier for the resourceId.
        :param http_method_type: - Identifier for the httpMethodType.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifRequestApiKeyRequired() - .ifRequestRouteAuthorizationType() - .ifResourceApiKeyRequired() - .ifResourceRouteAuthorizationType() - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__599257c84ea901c14e37ca42aee68a2b9034a67e5e779aef95ef70f8e0141deb)
            check_type(argname="argument rest_api_id", value=rest_api_id, expected_type=type_hints["rest_api_id"])
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument http_method_type", value=http_method_type, expected_type=type_hints["http_method_type"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Apigateway", jsii.invoke(self, "onMethod", [rest_api_id, resource_id, http_method_type, region, partition]))

    @jsii.member(jsii_name="onMethodResponse")
    def on_method_response(
        self,
        rest_api_id: builtins.str,
        resource_id: builtins.str,
        http_method_type: builtins.str,
        status_code: builtins.str,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Apigateway":
        '''(experimental) Adds a resource of type MethodResponse to the statement.

        https://docs.aws.amazon.com/apigateway/latest/developerguide/security_iam_service-with-iam.html

        :param rest_api_id: - Identifier for the restApiId.
        :param resource_id: - Identifier for the resourceId.
        :param http_method_type: - Identifier for the httpMethodType.
        :param status_code: - Identifier for the statusCode.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__37788b1b6fbf1ae70bf3ea201b70e355d59d8efae9b629be8dcde7f2c520e48c)
            check_type(argname="argument rest_api_id", value=rest_api_id, expected_type=type_hints["rest_api_id"])
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument http_method_type", value=http_method_type, expected_type=type_hints["http_method_type"])
            check_type(argname="argument status_code", value=status_code, expected_type=type_hints["status_code"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Apigateway", jsii.invoke(self, "onMethodResponse", [rest_api_id, resource_id, http_method_type, status_code, region, partition]))

    @jsii.member(jsii_name="onModel")
    def on_model(
        self,
        rest_api_id: builtins.str,
        model_name: builtins.str,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Apigateway":
        '''(experimental) Adds a resource of type Model to the statement.

        https://docs.aws.amazon.com/apigateway/latest/developerguide/security_iam_service-with-iam.html

        :param rest_api_id: - Identifier for the restApiId.
        :param model_name: - Identifier for the modelName.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__efd25cdcbba55ccf7132eb86016f453caca91981582c0e8af6f97cf325942387)
            check_type(argname="argument rest_api_id", value=rest_api_id, expected_type=type_hints["rest_api_id"])
            check_type(argname="argument model_name", value=model_name, expected_type=type_hints["model_name"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Apigateway", jsii.invoke(self, "onModel", [rest_api_id, model_name, region, partition]))

    @jsii.member(jsii_name="onModels")
    def on_models(
        self,
        rest_api_id: builtins.str,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Apigateway":
        '''(experimental) Adds a resource of type Models to the statement.

        https://docs.aws.amazon.com/apigateway/latest/developerguide/security_iam_service-with-iam.html

        :param rest_api_id: - Identifier for the restApiId.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__021c673bc41b8ce104c52cbc20fa74a48af48fe20e9d48d07c4456a52ce77eaa)
            check_type(argname="argument rest_api_id", value=rest_api_id, expected_type=type_hints["rest_api_id"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Apigateway", jsii.invoke(self, "onModels", [rest_api_id, region, partition]))

    @jsii.member(jsii_name="onRequestValidator")
    def on_request_validator(
        self,
        rest_api_id: builtins.str,
        request_validator_id: builtins.str,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Apigateway":
        '''(experimental) Adds a resource of type RequestValidator to the statement.

        https://docs.aws.amazon.com/apigateway/latest/developerguide/security_iam_service-with-iam.html

        :param rest_api_id: - Identifier for the restApiId.
        :param request_validator_id: - Identifier for the requestValidatorId.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3bf753d07ee5cdf2414cbaf77df21c7b83d6427aad76f82e718aa2b844a28572)
            check_type(argname="argument rest_api_id", value=rest_api_id, expected_type=type_hints["rest_api_id"])
            check_type(argname="argument request_validator_id", value=request_validator_id, expected_type=type_hints["request_validator_id"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Apigateway", jsii.invoke(self, "onRequestValidator", [rest_api_id, request_validator_id, region, partition]))

    @jsii.member(jsii_name="onRequestValidators")
    def on_request_validators(
        self,
        rest_api_id: builtins.str,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Apigateway":
        '''(experimental) Adds a resource of type RequestValidators to the statement.

        https://docs.aws.amazon.com/apigateway/latest/developerguide/security_iam_service-with-iam.html

        :param rest_api_id: - Identifier for the restApiId.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a1a7f1b6aa18e4b72d5ce96ff069af2d1f1755f4aaa814565b27b00aad2cf613)
            check_type(argname="argument rest_api_id", value=rest_api_id, expected_type=type_hints["rest_api_id"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Apigateway", jsii.invoke(self, "onRequestValidators", [rest_api_id, region, partition]))

    @jsii.member(jsii_name="onResource")
    def on_resource(
        self,
        rest_api_id: builtins.str,
        resource_id: builtins.str,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Apigateway":
        '''(experimental) Adds a resource of type Resource to the statement.

        https://docs.aws.amazon.com/apigateway/latest/developerguide/security_iam_service-with-iam.html

        :param rest_api_id: - Identifier for the restApiId.
        :param resource_id: - Identifier for the resourceId.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__cd6ff0a546000372415080bf968b25ddc7877da1eaffe14722d1d1f044edf75a)
            check_type(argname="argument rest_api_id", value=rest_api_id, expected_type=type_hints["rest_api_id"])
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Apigateway", jsii.invoke(self, "onResource", [rest_api_id, resource_id, region, partition]))

    @jsii.member(jsii_name="onResources")
    def on_resources(
        self,
        rest_api_id: builtins.str,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Apigateway":
        '''(experimental) Adds a resource of type Resources to the statement.

        https://docs.aws.amazon.com/apigateway/latest/developerguide/security_iam_service-with-iam.html

        :param rest_api_id: - Identifier for the restApiId.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2a27fe18d45cf6ee7b1af65aab55b1dab7c171d0c5bc531b906375c71024c2bc)
            check_type(argname="argument rest_api_id", value=rest_api_id, expected_type=type_hints["rest_api_id"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Apigateway", jsii.invoke(self, "onResources", [rest_api_id, region, partition]))

    @jsii.member(jsii_name="onRestApi")
    def on_rest_api(
        self,
        rest_api_id: builtins.str,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Apigateway":
        '''(experimental) Adds a resource of type RestApi to the statement.

        https://docs.aws.amazon.com/apigateway/latest/developerguide/security_iam_service-with-iam.html

        :param rest_api_id: - Identifier for the restApiId.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifRequestApiKeyRequired() - .ifRequestApiName() - .ifRequestAuthorizerType() - .ifRequestAuthorizerUri() - .ifRequestDisableExecuteApiEndpoint() - .ifRequestEndpointType() - .ifRequestRouteAuthorizationType() - .ifResourceApiKeyRequired() - .ifResourceApiName() - .ifResourceAuthorizerType() - .ifResourceAuthorizerUri() - .ifResourceDisableExecuteApiEndpoint() - .ifResourceEndpointType() - .ifResourceRouteAuthorizationType() - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8a4827cb885eae8a9668eaf25e04322f0f554943062c22f67849975c08471a29)
            check_type(argname="argument rest_api_id", value=rest_api_id, expected_type=type_hints["rest_api_id"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Apigateway", jsii.invoke(self, "onRestApi", [rest_api_id, region, partition]))

    @jsii.member(jsii_name="onRestApis")
    def on_rest_apis(
        self,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Apigateway":
        '''(experimental) Adds a resource of type RestApis to the statement.

        https://docs.aws.amazon.com/apigateway/latest/developerguide/security_iam_service-with-iam.html

        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifRequestApiKeyRequired() - .ifRequestApiName() - .ifRequestAuthorizerType() - .ifRequestAuthorizerUri() - .ifRequestDisableExecuteApiEndpoint() - .ifRequestEndpointType() - .ifRequestRouteAuthorizationType() - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0cc81c73e502a417546d36c10df166932aa2034e36f82ad3e77bf6667bc2c83b)
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Apigateway", jsii.invoke(self, "onRestApis", [region, partition]))

    @jsii.member(jsii_name="onSdk")
    def on_sdk(
        self,
        rest_api_id: builtins.str,
        stage_name: builtins.str,
        sdk_type: builtins.str,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Apigateway":
        '''(experimental) Adds a resource of type Sdk to the statement.

        https://docs.aws.amazon.com/apigateway/latest/developerguide/security_iam_service-with-iam.html

        :param rest_api_id: - Identifier for the restApiId.
        :param stage_name: - Identifier for the stageName.
        :param sdk_type: - Identifier for the sdkType.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7926202a8b855daede707e748d31c41c0d98e93832be25eed09127f26726f2a9)
            check_type(argname="argument rest_api_id", value=rest_api_id, expected_type=type_hints["rest_api_id"])
            check_type(argname="argument stage_name", value=stage_name, expected_type=type_hints["stage_name"])
            check_type(argname="argument sdk_type", value=sdk_type, expected_type=type_hints["sdk_type"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Apigateway", jsii.invoke(self, "onSdk", [rest_api_id, stage_name, sdk_type, region, partition]))

    @jsii.member(jsii_name="onStage")
    def on_stage(
        self,
        rest_api_id: builtins.str,
        stage_name: builtins.str,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Apigateway":
        '''(experimental) Adds a resource of type Stage to the statement.

        https://docs.aws.amazon.com/apigateway/latest/developerguide/security_iam_service-with-iam.html

        :param rest_api_id: - Identifier for the restApiId.
        :param stage_name: - Identifier for the stageName.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifRequestAccessLoggingDestination() - .ifRequestAccessLoggingFormat() - .ifResourceAccessLoggingDestination() - .ifResourceAccessLoggingFormat() - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2b2a1b6c92042d3555ce901a9436673588ff0635408b553ef161f3ecbb0d6ced)
            check_type(argname="argument rest_api_id", value=rest_api_id, expected_type=type_hints["rest_api_id"])
            check_type(argname="argument stage_name", value=stage_name, expected_type=type_hints["stage_name"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Apigateway", jsii.invoke(self, "onStage", [rest_api_id, stage_name, region, partition]))

    @jsii.member(jsii_name="onStages")
    def on_stages(
        self,
        rest_api_id: builtins.str,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Apigateway":
        '''(experimental) Adds a resource of type Stages to the statement.

        https://docs.aws.amazon.com/apigateway/latest/developerguide/security_iam_service-with-iam.html

        :param rest_api_id: - Identifier for the restApiId.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifRequestAccessLoggingDestination() - .ifRequestAccessLoggingFormat() - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8cbad33ea2d8e822af01e365fcc023b5026b3f72fb2b0ba90b1b433c2fc0b38f)
            check_type(argname="argument rest_api_id", value=rest_api_id, expected_type=type_hints["rest_api_id"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Apigateway", jsii.invoke(self, "onStages", [rest_api_id, region, partition]))

    @jsii.member(jsii_name="onTemplate")
    def on_template(
        self,
        model_name: builtins.str,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Apigateway":
        '''(experimental) Adds a resource of type Template to the statement.

        https://docs.aws.amazon.com/apigateway/latest/developerguide/security_iam_service-with-iam.html

        :param model_name: - Identifier for the modelName.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e4cbcb2e263dce233c53b7d5ec9190c44150ec27dfbb152249cfeaba831357df)
            check_type(argname="argument model_name", value=model_name, expected_type=type_hints["model_name"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Apigateway", jsii.invoke(self, "onTemplate", [model_name, region, partition]))

    @jsii.member(jsii_name="onUsagePlan")
    def on_usage_plan(
        self,
        usage_plan_id: builtins.str,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Apigateway":
        '''(experimental) Adds a resource of type UsagePlan to the statement.

        https://docs.aws.amazon.com/apigateway/latest/developerguide/security_iam_service-with-iam.html

        :param usage_plan_id: - Identifier for the usagePlanId.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9d309e5788b3995b084670c907690ee323657bd2e88e01d1a43c9a450b810d38)
            check_type(argname="argument usage_plan_id", value=usage_plan_id, expected_type=type_hints["usage_plan_id"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Apigateway", jsii.invoke(self, "onUsagePlan", [usage_plan_id, region, partition]))

    @jsii.member(jsii_name="onUsagePlanKey")
    def on_usage_plan_key(
        self,
        usage_plan_id: builtins.str,
        id: builtins.str,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Apigateway":
        '''(experimental) Adds a resource of type UsagePlanKey to the statement.

        https://docs.aws.amazon.com/apigateway/latest/developerguide/security_iam_service-with-iam.html

        :param usage_plan_id: - Identifier for the usagePlanId.
        :param id: - Identifier for the id.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__32b1977d8fd8e3b89456a557e37eaccaf27d93d5f19f1abdd1d96088109f6a3a)
            check_type(argname="argument usage_plan_id", value=usage_plan_id, expected_type=type_hints["usage_plan_id"])
            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Apigateway", jsii.invoke(self, "onUsagePlanKey", [usage_plan_id, id, region, partition]))

    @jsii.member(jsii_name="onUsagePlanKeys")
    def on_usage_plan_keys(
        self,
        usage_plan_id: builtins.str,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Apigateway":
        '''(experimental) Adds a resource of type UsagePlanKeys to the statement.

        https://docs.aws.amazon.com/apigateway/latest/developerguide/security_iam_service-with-iam.html

        :param usage_plan_id: - Identifier for the usagePlanId.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f17190dcd27f7f10ac5c1ec27c579daad8a95132d480ed20c4982b5edb188d05)
            check_type(argname="argument usage_plan_id", value=usage_plan_id, expected_type=type_hints["usage_plan_id"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Apigateway", jsii.invoke(self, "onUsagePlanKeys", [usage_plan_id, region, partition]))

    @jsii.member(jsii_name="onUsagePlans")
    def on_usage_plans(
        self,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Apigateway":
        '''(experimental) Adds a resource of type UsagePlans to the statement.

        https://docs.aws.amazon.com/apigateway/latest/developerguide/security_iam_service-with-iam.html

        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__66275bcc17c2689faebfda4790a3481954f08a122f4c94d9cd75c5876eb91a61)
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Apigateway", jsii.invoke(self, "onUsagePlans", [region, partition]))

    @jsii.member(jsii_name="onVpcLink")
    def on_vpc_link(
        self,
        vpc_link_id: builtins.str,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Apigateway":
        '''(experimental) Adds a resource of type VpcLink to the statement.

        https://docs.aws.amazon.com/apigateway/latest/developerguide/security_iam_service-with-iam.html

        :param vpc_link_id: - Identifier for the vpcLinkId.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__afa9440b8259f8ab0c858bc932912bcb557290fc419d6bcec6e7b417adf5bcfe)
            check_type(argname="argument vpc_link_id", value=vpc_link_id, expected_type=type_hints["vpc_link_id"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Apigateway", jsii.invoke(self, "onVpcLink", [vpc_link_id, region, partition]))

    @jsii.member(jsii_name="onVpcLinks")
    def on_vpc_links(
        self,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Apigateway":
        '''(experimental) Adds a resource of type VpcLinks to the statement.

        https://docs.aws.amazon.com/apigateway/latest/developerguide/security_iam_service-with-iam.html

        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7bce8d10a82b7224819cfd55f72e6e4aae4ab7383a8ef9ed4e65193039a36b38)
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Apigateway", jsii.invoke(self, "onVpcLinks", [region, partition]))

    @jsii.member(jsii_name="toAddCertificateToDomain")
    def to_add_certificate_to_domain(self) -> "Apigateway":
        '''(experimental) Grants permission to add certificates for mutual TLS authentication to a domain name.

        This is an additional authorization control for managing the DomainName resource due to the sensitive nature of mTLS

        Access Level: Permissions management

        https://docs.aws.amazon.com/apigateway/api-reference/ADD_CERTIFICATE_TO_DOMAIN.html

        :stability: experimental
        '''
        return typing.cast("Apigateway", jsii.invoke(self, "toAddCertificateToDomain", []))

    @jsii.member(jsii_name="toDELETE")
    def to_delete(self) -> "Apigateway":
        '''(experimental) Grants permission to delete a particular resource.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/apigateway/api-reference/API_DELETE.html

        :stability: experimental
        '''
        return typing.cast("Apigateway", jsii.invoke(self, "toDELETE", []))

    @jsii.member(jsii_name="toGET")
    def to_get(self) -> "Apigateway":
        '''(experimental) Grants permission to read a particular resource.

        Access Level: Read

        https://docs.aws.amazon.com/apigateway/api-reference/API_GET.html

        :stability: experimental
        '''
        return typing.cast("Apigateway", jsii.invoke(self, "toGET", []))

    @jsii.member(jsii_name="toPATCH")
    def to_patch(self) -> "Apigateway":
        '''(experimental) Grants permission to update a particular resource.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/apigateway/api-reference/API_PATCH.html

        :stability: experimental
        '''
        return typing.cast("Apigateway", jsii.invoke(self, "toPATCH", []))

    @jsii.member(jsii_name="toPOST")
    def to_post(self) -> "Apigateway":
        '''(experimental) Grants permission to create a particular resource.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/apigateway/api-reference/API_POST.html

        :stability: experimental
        '''
        return typing.cast("Apigateway", jsii.invoke(self, "toPOST", []))

    @jsii.member(jsii_name="toPUT")
    def to_put(self) -> "Apigateway":
        '''(experimental) Grants permission to update a particular resource.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/apigateway/api-reference/API_PUT.html

        :stability: experimental
        '''
        return typing.cast("Apigateway", jsii.invoke(self, "toPUT", []))

    @jsii.member(jsii_name="toRemoveCertificateFromDomain")
    def to_remove_certificate_from_domain(self) -> "Apigateway":
        '''(experimental) Grants permission to remove certificates for mutual TLS authentication from a domain name.

        This is an additional authorization control for managing the DomainName resource due to the sensitive nature of mTLS

        Access Level: Permissions management

        https://docs.aws.amazon.com/apigateway/api-reference/REMOVE_CERTIFICATE_FROM_DOMAIN.html

        :stability: experimental
        '''
        return typing.cast("Apigateway", jsii.invoke(self, "toRemoveCertificateFromDomain", []))

    @jsii.member(jsii_name="toSetWebACL")
    def to_set_web_acl(self) -> "Apigateway":
        '''(experimental) Grants permission set a WAF access control list (ACL).

        This is an additional authorization control for managing the Stage resource due to the sensitive nature of WebAcl's

        Access Level: Permissions management

        https://docs.aws.amazon.com/apigateway/api-reference/WEBACL_SET.html

        :stability: experimental
        '''
        return typing.cast("Apigateway", jsii.invoke(self, "toSetWebACL", []))

    @jsii.member(jsii_name="toUpdateRestApiPolicy")
    def to_update_rest_api_policy(self) -> "Apigateway":
        '''(experimental) Grants permission to manage the IAM resource policy for an API.

        This is an additional authorization control for managing an API due to the sensitive nature of the resource policy

        Access Level: Permissions management

        https://docs.aws.amazon.com/apigateway/api-reference/UPDATE_REST_API_POLICY.html

        :stability: experimental
        '''
        return typing.cast("Apigateway", jsii.invoke(self, "toUpdateRestApiPolicy", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__78d12e6093b0078092f83d65e86bc1682017750ed0bad8461c5f5362be7c7861)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e1b11b5183116680bd47f4ae5eb6156d12ee3db7ac53279e1ad1e1aa6f3105dd)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class ApigatewayV2(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.ApigatewayV2",
):
    '''(experimental) Statement provider for service `apigateway-v2 <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonapigatewaymanagementv2.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `apigateway-v2 <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonapigatewaymanagementv2.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="ifRequestAccessLoggingDestination")
    def if_request_access_logging_destination(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "ApigatewayV2":
        '''(experimental) Filters access by access log destination. Available during the CreateStage and UpdateStage operations.

        https://docs.aws.amazon.com/apigateway/latest/developerguide/security_iam_service-with-iam.html

        Applies to resource types:

        - Stage
        - Stages

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c6b09ddbbb0a9d28f7acc51696a0e84fcb3c6b11ea46f6679453eb6d001cf885)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("ApigatewayV2", jsii.invoke(self, "ifRequestAccessLoggingDestination", [value, operator]))

    @jsii.member(jsii_name="ifRequestAccessLoggingFormat")
    def if_request_access_logging_format(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "ApigatewayV2":
        '''(experimental) Filters access by access log format. Available during the CreateStage and UpdateStage operations.

        https://docs.aws.amazon.com/apigateway/latest/developerguide/security_iam_service-with-iam.html

        Applies to resource types:

        - Stage
        - Stages

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a5863b25fd224b0a40c3b37b51c9a9606f14e8ecee13364b2e7061206f3bacc6)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("ApigatewayV2", jsii.invoke(self, "ifRequestAccessLoggingFormat", [value, operator]))

    @jsii.member(jsii_name="ifRequestApiKeyRequired")
    def if_request_api_key_required(
        self,
        value: typing.Optional[builtins.bool] = None,
    ) -> "ApigatewayV2":
        '''(experimental) Filters access by the requirement of API.

        Available during the CreateRoute and UpdateRoute operations. Also available as a collection during import and reimport

        https://docs.aws.amazon.com/apigateway/latest/developerguide/security_iam_service-with-iam.html

        Applies to resource types:

        - Api
        - Apis
        - Route
        - Routes

        :param value: ``true`` or ``false``. **Default:** ``true``

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1869b8627a0c75dd5bb054bbe4cf3c86fcf909b0bfae91d5dc7847f90dd4c562)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast("ApigatewayV2", jsii.invoke(self, "ifRequestApiKeyRequired", [value]))

    @jsii.member(jsii_name="ifRequestApiName")
    def if_request_api_name(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "ApigatewayV2":
        '''(experimental) Filters access by API name. Available during the CreateApi and UpdateApi operations.

        https://docs.aws.amazon.com/apigateway/latest/developerguide/security_iam_service-with-iam.html

        Applies to resource types:

        - Api
        - Apis

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__38c864ac306cf22d32e758be6efc528cf44a289e615522f9049d3d6c88acfdf6)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("ApigatewayV2", jsii.invoke(self, "ifRequestApiName", [value, operator]))

    @jsii.member(jsii_name="ifRequestAuthorizerType")
    def if_request_authorizer_type(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "ApigatewayV2":
        '''(experimental) Filters access by type of authorizer in the request, for example REQUEST or JWT.

        Available during CreateAuthorizer and UpdateAuthorizer. Also available during import and reimport as an ArrayOfString

        https://docs.aws.amazon.com/apigateway/latest/developerguide/security_iam_service-with-iam.html

        Applies to resource types:

        - Api
        - Apis
        - Authorizer
        - Authorizers

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b8a62f73d7c0055c603631f3699a58017d3f43a5ec8c0b0671e766f1981c72de)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("ApigatewayV2", jsii.invoke(self, "ifRequestAuthorizerType", [value, operator]))

    @jsii.member(jsii_name="ifRequestAuthorizerUri")
    def if_request_authorizer_uri(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "ApigatewayV2":
        '''(experimental) Filters access by URI of a Lambda authorizer function.

        Available during CreateAuthorizer and UpdateAuthorizer. Also available during import and reimport as an ArrayOfString

        https://docs.aws.amazon.com/apigateway/latest/developerguide/security_iam_service-with-iam.html

        Applies to resource types:

        - Api
        - Apis
        - Authorizer
        - Authorizers

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c60a16028cb2acf26827c57c700b06f1135c4fd34a2b952f5652a6be6c56e7cc)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("ApigatewayV2", jsii.invoke(self, "ifRequestAuthorizerUri", [value, operator]))

    @jsii.member(jsii_name="ifRequestDisableExecuteApiEndpoint")
    def if_request_disable_execute_api_endpoint(
        self,
        value: typing.Optional[builtins.bool] = None,
    ) -> "ApigatewayV2":
        '''(experimental) Filters access by status of the default execute-api endpoint. Available during the CreateApi and UpdateApi operations.

        https://docs.aws.amazon.com/apigateway/latest/developerguide/security_iam_service-with-iam.html

        Applies to resource types:

        - Api
        - Apis

        :param value: ``true`` or ``false``. **Default:** ``true``

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ed71d62a9984b742a1b070bc42ef6e32aa22846d574a60eac2eda7a37412ff77)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast("ApigatewayV2", jsii.invoke(self, "ifRequestDisableExecuteApiEndpoint", [value]))

    @jsii.member(jsii_name="ifRequestEndpointType")
    def if_request_endpoint_type(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "ApigatewayV2":
        '''(experimental) Filters access by endpoint type. Available during the CreateDomainName, UpdateDomainName, CreateApi, and UpdateApi operations.

        https://docs.aws.amazon.com/apigateway/latest/developerguide/security_iam_service-with-iam.html

        Applies to resource types:

        - Api
        - Apis

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7ae1f9031129c4db89fe583df4b04ead1b9461a003a73be3baaeff3d7e65d23a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("ApigatewayV2", jsii.invoke(self, "ifRequestEndpointType", [value, operator]))

    @jsii.member(jsii_name="ifRequestMtlsTrustStoreUri")
    def if_request_mtls_trust_store_uri(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "ApigatewayV2":
        '''(experimental) Filters access by URI of the truststore used for mutual TLS authentication. Available during the CreateDomainName and UpdateDomainName operations.

        https://docs.aws.amazon.com/apigateway/latest/developerguide/security_iam_service-with-iam.html

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__15e1ceeda04ddf356daa9192836994dd6405a36d23b5b5373b4b1216a5e930d4)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("ApigatewayV2", jsii.invoke(self, "ifRequestMtlsTrustStoreUri", [value, operator]))

    @jsii.member(jsii_name="ifRequestMtlsTrustStoreVersion")
    def if_request_mtls_trust_store_version(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "ApigatewayV2":
        '''(experimental) Filters access by version of the truststore used for mutual TLS authentication. Available during the CreateDomainName and UpdateDomainName operations.

        https://docs.aws.amazon.com/apigateway/latest/developerguide/security_iam_service-with-iam.html

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fddf4972542627bf833bb4a510d51af4afd530808b2db4a5b071becd43e18d88)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("ApigatewayV2", jsii.invoke(self, "ifRequestMtlsTrustStoreVersion", [value, operator]))

    @jsii.member(jsii_name="ifRequestRouteAuthorizationType")
    def if_request_route_authorization_type(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "ApigatewayV2":
        '''(experimental) Filters access by authorization type, for example NONE, AWS_IAM, CUSTOM, JWT.

        Available during the CreateRoute and UpdateRoute operations. Also available as a collection during import

        https://docs.aws.amazon.com/apigateway/latest/developerguide/security_iam_service-with-iam.html

        Applies to resource types:

        - Api
        - Apis
        - Route
        - Routes

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__449e45aad212bdb129426eaf160036d2493dd08f7f78fbdd8d2efcb003a34ddd)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("ApigatewayV2", jsii.invoke(self, "ifRequestRouteAuthorizationType", [value, operator]))

    @jsii.member(jsii_name="ifRequestSecurityPolicy")
    def if_request_security_policy(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "ApigatewayV2":
        '''(experimental) Filters access by TLS version. Available during the CreateDomain and UpdateDomain operations.

        https://docs.aws.amazon.com/apigateway/latest/developerguide/security_iam_service-with-iam.html

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__38b8ccfdc32f640b982f397c34a5b8be78f03e48ba794d6fec2416e9a7fe3933)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("ApigatewayV2", jsii.invoke(self, "ifRequestSecurityPolicy", [value, operator]))

    @jsii.member(jsii_name="ifRequestStageName")
    def if_request_stage_name(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "ApigatewayV2":
        '''(experimental) Filters access by stage name of the deployment that you attempt to create. Available during the CreateDeployment operation.

        https://docs.aws.amazon.com/apigateway/latest/developerguide/security_iam_service-with-iam.html

        Applies to resource types:

        - Deployments

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2a2844cb47bb767c52fc024c47bc40ccade430d968cb1ce39f059745059335fc)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("ApigatewayV2", jsii.invoke(self, "ifRequestStageName", [value, operator]))

    @jsii.member(jsii_name="ifResourceAccessLoggingDestination")
    def if_resource_access_logging_destination(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "ApigatewayV2":
        '''(experimental) Filters access by access log destination of the current Stage resource. Available during the UpdateStage and DeleteStage operations.

        https://docs.aws.amazon.com/apigateway/latest/developerguide/security_iam_service-with-iam.html

        Applies to resource types:

        - Stage

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e2b6b9472223ecf1a1f87fc49c237ed99bf2407aa806959bce964cc28f3301ac)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("ApigatewayV2", jsii.invoke(self, "ifResourceAccessLoggingDestination", [value, operator]))

    @jsii.member(jsii_name="ifResourceAccessLoggingFormat")
    def if_resource_access_logging_format(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "ApigatewayV2":
        '''(experimental) Filters access by access log format of the current Stage resource. Available during the UpdateStage and DeleteStage operations.

        https://docs.aws.amazon.com/apigateway/latest/developerguide/security_iam_service-with-iam.html

        Applies to resource types:

        - Stage

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f0157dd15c1b3d9346792f19b0e750b96e45112e6a06da77fad14c60fa665f54)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("ApigatewayV2", jsii.invoke(self, "ifResourceAccessLoggingFormat", [value, operator]))

    @jsii.member(jsii_name="ifResourceApiKeyRequired")
    def if_resource_api_key_required(
        self,
        value: typing.Optional[builtins.bool] = None,
    ) -> "ApigatewayV2":
        '''(experimental) Filters access by the requirement of API key for the existing Route resource.

        Available during the UpdateRoute and DeleteRoute operations. Also available as a collection during reimport

        https://docs.aws.amazon.com/apigateway/latest/developerguide/security_iam_service-with-iam.html

        Applies to resource types:

        - Api
        - Route

        :param value: ``true`` or ``false``. **Default:** ``true``

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__21419b51c127f266a5a98cf6e76f042c734860b0f28b0904291663950fc517c0)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast("ApigatewayV2", jsii.invoke(self, "ifResourceApiKeyRequired", [value]))

    @jsii.member(jsii_name="ifResourceApiName")
    def if_resource_api_name(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "ApigatewayV2":
        '''(experimental) Filters access by API name. Available during the UpdateApi and DeleteApi operations.

        https://docs.aws.amazon.com/apigateway/latest/developerguide/security_iam_service-with-iam.html

        Applies to resource types:

        - Api

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ca157cefb2462578f84c8ba961f53aa0c28e640a8f31e6b136a332b6f010ac5a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("ApigatewayV2", jsii.invoke(self, "ifResourceApiName", [value, operator]))

    @jsii.member(jsii_name="ifResourceAuthorizerType")
    def if_resource_authorizer_type(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "ApigatewayV2":
        '''(experimental) Filters access by the current type of authorizer, for example REQUEST or JWT.

        Available during UpdateAuthorizer and DeleteAuthorizer operations. Also available during import and reimport as an ArrayOfString

        https://docs.aws.amazon.com/apigateway/latest/developerguide/security_iam_service-with-iam.html

        Applies to resource types:

        - Api
        - Authorizer

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__56308a0715f4afc4fb9473bcbea9d8efc8cf7f2487d63ce8c818c50c126ccd27)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("ApigatewayV2", jsii.invoke(self, "ifResourceAuthorizerType", [value, operator]))

    @jsii.member(jsii_name="ifResourceAuthorizerUri")
    def if_resource_authorizer_uri(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "ApigatewayV2":
        '''(experimental) Filters access by the URI of the current Lambda authorizer associated with the current API.

        Available during UpdateAuthorizer and DeleteAuthorizer. Also available as a collection during reimport

        https://docs.aws.amazon.com/apigateway/latest/developerguide/security_iam_service-with-iam.html

        Applies to resource types:

        - Api
        - Authorizer

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f3f34a3a0cf8e63f5c755722328f82ce7748588fecc266be030ff888f730bd0d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("ApigatewayV2", jsii.invoke(self, "ifResourceAuthorizerUri", [value, operator]))

    @jsii.member(jsii_name="ifResourceDisableExecuteApiEndpoint")
    def if_resource_disable_execute_api_endpoint(
        self,
        value: typing.Optional[builtins.bool] = None,
    ) -> "ApigatewayV2":
        '''(experimental) Filters access by status of the default execute-api endpoint. Available during the UpdateApi and DeleteApi operations.

        https://docs.aws.amazon.com/apigateway/latest/developerguide/security_iam_service-with-iam.html

        Applies to resource types:

        - Api

        :param value: ``true`` or ``false``. **Default:** ``true``

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a1d28155dceaab85b36d11e49e5c636645a6b71f58dcfccdc8ef5809cbe1d97a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast("ApigatewayV2", jsii.invoke(self, "ifResourceDisableExecuteApiEndpoint", [value]))

    @jsii.member(jsii_name="ifResourceEndpointType")
    def if_resource_endpoint_type(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "ApigatewayV2":
        '''(experimental) Filters access by endpoint type. Available during the UpdateDomainName, DeleteDomainName, UpdateApi, and DeleteApi operations.

        https://docs.aws.amazon.com/apigateway/latest/developerguide/security_iam_service-with-iam.html

        Applies to resource types:

        - Api

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5a01f35bf0e3dceabe3265bef01cbec08d4c6adfacfcb4fc341beeab1e3c33a3)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("ApigatewayV2", jsii.invoke(self, "ifResourceEndpointType", [value, operator]))

    @jsii.member(jsii_name="ifResourceMtlsTrustStoreUri")
    def if_resource_mtls_trust_store_uri(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "ApigatewayV2":
        '''(experimental) Filters access by URI of the truststore used for mutual TLS authentication. Available during the UpdateDomainName and DeleteDomainName operations.

        https://docs.aws.amazon.com/apigateway/latest/developerguide/security_iam_service-with-iam.html

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c905430433f6024bca5160e2d4228a1984dd613bd6bac18c7726a23c0e9aa67f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("ApigatewayV2", jsii.invoke(self, "ifResourceMtlsTrustStoreUri", [value, operator]))

    @jsii.member(jsii_name="ifResourceMtlsTrustStoreVersion")
    def if_resource_mtls_trust_store_version(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "ApigatewayV2":
        '''(experimental) Filters access by version of the truststore used for mutual TLS authentication. Available during the UpdateDomainName and DeleteDomainName operations.

        https://docs.aws.amazon.com/apigateway/latest/developerguide/security_iam_service-with-iam.html

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5381df5405aebce4c13901d343ea63861c45f952a3f4eef6b668db9706afb571)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("ApigatewayV2", jsii.invoke(self, "ifResourceMtlsTrustStoreVersion", [value, operator]))

    @jsii.member(jsii_name="ifResourceRouteAuthorizationType")
    def if_resource_route_authorization_type(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "ApigatewayV2":
        '''(experimental) Filters access by authorization type of the existing Route resource, for example NONE, AWS_IAM, CUSTOM.

        Available during the UpdateRoute and DeleteRoute operations. Also available as a collection during reimport

        https://docs.aws.amazon.com/apigateway/latest/developerguide/security_iam_service-with-iam.html

        Applies to resource types:

        - Api
        - Route

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__952e5c6ee15fc863443e634b6abba093742952255bb945086774fd2c446e28db)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("ApigatewayV2", jsii.invoke(self, "ifResourceRouteAuthorizationType", [value, operator]))

    @jsii.member(jsii_name="ifResourceSecurityPolicy")
    def if_resource_security_policy(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "ApigatewayV2":
        '''(experimental) Filters access by TLS version. Available during the UpdateDomainName and DeleteDomainName operations.

        https://docs.aws.amazon.com/apigateway/latest/developerguide/security_iam_service-with-iam.html

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9e2f9846480c840fea9f0cd8f1e4b44a1dbd663fcd4b04103b2fc2d28e2f61df)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("ApigatewayV2", jsii.invoke(self, "ifResourceSecurityPolicy", [value, operator]))

    @jsii.member(jsii_name="onAccessLogSettings")
    def on_access_log_settings(
        self,
        api_id: builtins.str,
        stage_name: builtins.str,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "ApigatewayV2":
        '''(experimental) Adds a resource of type AccessLogSettings to the statement.

        https://docs.aws.amazon.com/apigateway/latest/developerguide/security_iam_service-with-iam.html

        :param api_id: - Identifier for the apiId.
        :param stage_name: - Identifier for the stageName.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a84e435e5c29b02cb3bfb31b942d2ede28a21614ab5614a85f0bfe1987a54951)
            check_type(argname="argument api_id", value=api_id, expected_type=type_hints["api_id"])
            check_type(argname="argument stage_name", value=stage_name, expected_type=type_hints["stage_name"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("ApigatewayV2", jsii.invoke(self, "onAccessLogSettings", [api_id, stage_name, region, partition]))

    @jsii.member(jsii_name="onApi")
    def on_api(
        self,
        api_id: builtins.str,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "ApigatewayV2":
        '''(experimental) Adds a resource of type Api to the statement.

        https://docs.aws.amazon.com/apigateway/latest/developerguide/security_iam_service-with-iam.html

        :param api_id: - Identifier for the apiId.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifRequestApiKeyRequired() - .ifRequestApiName() - .ifRequestAuthorizerType() - .ifRequestAuthorizerUri() - .ifRequestDisableExecuteApiEndpoint() - .ifRequestEndpointType() - .ifRequestRouteAuthorizationType() - .ifResourceApiKeyRequired() - .ifResourceApiName() - .ifResourceAuthorizerType() - .ifResourceAuthorizerUri() - .ifResourceDisableExecuteApiEndpoint() - .ifResourceEndpointType() - .ifResourceRouteAuthorizationType() - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__cd518592fb23656b88697fe6b0eb7feb5bd737cacc6dec5f754799aac29c675e)
            check_type(argname="argument api_id", value=api_id, expected_type=type_hints["api_id"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("ApigatewayV2", jsii.invoke(self, "onApi", [api_id, region, partition]))

    @jsii.member(jsii_name="onApiMapping")
    def on_api_mapping(
        self,
        domain_name: builtins.str,
        api_mapping_id: builtins.str,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "ApigatewayV2":
        '''(experimental) Adds a resource of type ApiMapping to the statement.

        https://docs.aws.amazon.com/apigateway/latest/developerguide/security_iam_service-with-iam.html

        :param domain_name: - Identifier for the domainName.
        :param api_mapping_id: - Identifier for the apiMappingId.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3864e4e4f4533b82119da8100b5f9ad8037e2793e7c5279e012a298e80778bdc)
            check_type(argname="argument domain_name", value=domain_name, expected_type=type_hints["domain_name"])
            check_type(argname="argument api_mapping_id", value=api_mapping_id, expected_type=type_hints["api_mapping_id"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("ApigatewayV2", jsii.invoke(self, "onApiMapping", [domain_name, api_mapping_id, region, partition]))

    @jsii.member(jsii_name="onApiMappings")
    def on_api_mappings(
        self,
        domain_name: builtins.str,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "ApigatewayV2":
        '''(experimental) Adds a resource of type ApiMappings to the statement.

        https://docs.aws.amazon.com/apigateway/latest/developerguide/security_iam_service-with-iam.html

        :param domain_name: - Identifier for the domainName.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5b2604e095bd5ee07ed6ac73311f2ed0fcce59a0121ba182cc03bcf6f9b61cc1)
            check_type(argname="argument domain_name", value=domain_name, expected_type=type_hints["domain_name"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("ApigatewayV2", jsii.invoke(self, "onApiMappings", [domain_name, region, partition]))

    @jsii.member(jsii_name="onApis")
    def on_apis(
        self,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "ApigatewayV2":
        '''(experimental) Adds a resource of type Apis to the statement.

        https://docs.aws.amazon.com/apigateway/latest/developerguide/security_iam_service-with-iam.html

        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifRequestApiKeyRequired() - .ifRequestApiName() - .ifRequestAuthorizerType() - .ifRequestAuthorizerUri() - .ifRequestDisableExecuteApiEndpoint() - .ifRequestEndpointType() - .ifRequestRouteAuthorizationType() - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f061e8d6d93a87943e9047d494bf912be28c7d38e911d1656e38ffeb70f7dcf9)
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("ApigatewayV2", jsii.invoke(self, "onApis", [region, partition]))

    @jsii.member(jsii_name="onAuthorizer")
    def on_authorizer(
        self,
        api_id: builtins.str,
        authorizer_id: builtins.str,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "ApigatewayV2":
        '''(experimental) Adds a resource of type Authorizer to the statement.

        https://docs.aws.amazon.com/apigateway/latest/developerguide/security_iam_service-with-iam.html

        :param api_id: - Identifier for the apiId.
        :param authorizer_id: - Identifier for the authorizerId.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifRequestAuthorizerType() - .ifRequestAuthorizerUri() - .ifResourceAuthorizerType() - .ifResourceAuthorizerUri() - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__90872229f7b3a6815306d7fad6ad337efff25af6842b9944bc6008c1585a79c1)
            check_type(argname="argument api_id", value=api_id, expected_type=type_hints["api_id"])
            check_type(argname="argument authorizer_id", value=authorizer_id, expected_type=type_hints["authorizer_id"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("ApigatewayV2", jsii.invoke(self, "onAuthorizer", [api_id, authorizer_id, region, partition]))

    @jsii.member(jsii_name="onAuthorizers")
    def on_authorizers(
        self,
        api_id: builtins.str,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "ApigatewayV2":
        '''(experimental) Adds a resource of type Authorizers to the statement.

        https://docs.aws.amazon.com/apigateway/latest/developerguide/security_iam_service-with-iam.html

        :param api_id: - Identifier for the apiId.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifRequestAuthorizerType() - .ifRequestAuthorizerUri() - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__69316163fbc1796075ae889128a9cbb83e246925d0dfb38435e4e00888975d30)
            check_type(argname="argument api_id", value=api_id, expected_type=type_hints["api_id"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("ApigatewayV2", jsii.invoke(self, "onAuthorizers", [api_id, region, partition]))

    @jsii.member(jsii_name="onAuthorizersCache")
    def on_authorizers_cache(
        self,
        api_id: builtins.str,
        stage_name: builtins.str,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "ApigatewayV2":
        '''(experimental) Adds a resource of type AuthorizersCache to the statement.

        https://docs.aws.amazon.com/apigateway/latest/developerguide/security_iam_service-with-iam.html

        :param api_id: - Identifier for the apiId.
        :param stage_name: - Identifier for the stageName.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__709613228b08259d5dc7026658f7f4d641e8c889dcd647844689e43df0280a5c)
            check_type(argname="argument api_id", value=api_id, expected_type=type_hints["api_id"])
            check_type(argname="argument stage_name", value=stage_name, expected_type=type_hints["stage_name"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("ApigatewayV2", jsii.invoke(self, "onAuthorizersCache", [api_id, stage_name, region, partition]))

    @jsii.member(jsii_name="onCors")
    def on_cors(
        self,
        api_id: builtins.str,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "ApigatewayV2":
        '''(experimental) Adds a resource of type Cors to the statement.

        https://docs.aws.amazon.com/apigateway/latest/developerguide/security_iam_service-with-iam.html

        :param api_id: - Identifier for the apiId.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3d40c372bcc45babb244e235a1cd4a2a16aa08de64fcb3161118344d2fa18264)
            check_type(argname="argument api_id", value=api_id, expected_type=type_hints["api_id"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("ApigatewayV2", jsii.invoke(self, "onCors", [api_id, region, partition]))

    @jsii.member(jsii_name="onDeployment")
    def on_deployment(
        self,
        api_id: builtins.str,
        deployment_id: builtins.str,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "ApigatewayV2":
        '''(experimental) Adds a resource of type Deployment to the statement.

        https://docs.aws.amazon.com/apigateway/latest/developerguide/security_iam_service-with-iam.html

        :param api_id: - Identifier for the apiId.
        :param deployment_id: - Identifier for the deploymentId.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d34c861e185613566823cea274c1ac73811b0bf9727f6b8f811dc04e10c56bc0)
            check_type(argname="argument api_id", value=api_id, expected_type=type_hints["api_id"])
            check_type(argname="argument deployment_id", value=deployment_id, expected_type=type_hints["deployment_id"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("ApigatewayV2", jsii.invoke(self, "onDeployment", [api_id, deployment_id, region, partition]))

    @jsii.member(jsii_name="onDeployments")
    def on_deployments(
        self,
        api_id: builtins.str,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "ApigatewayV2":
        '''(experimental) Adds a resource of type Deployments to the statement.

        https://docs.aws.amazon.com/apigateway/latest/developerguide/security_iam_service-with-iam.html

        :param api_id: - Identifier for the apiId.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifRequestStageName() - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ca2c44e5c0f7a115e24bf344626e9e80b19fe2062fe4f430a473865570d6a644)
            check_type(argname="argument api_id", value=api_id, expected_type=type_hints["api_id"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("ApigatewayV2", jsii.invoke(self, "onDeployments", [api_id, region, partition]))

    @jsii.member(jsii_name="onExportedAPI")
    def on_exported_api(
        self,
        api_id: builtins.str,
        specification: builtins.str,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "ApigatewayV2":
        '''(experimental) Adds a resource of type ExportedAPI to the statement.

        https://docs.aws.amazon.com/apigateway/latest/developerguide/security_iam_service-with-iam.html

        :param api_id: - Identifier for the apiId.
        :param specification: - Identifier for the specification.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__abf2319d5b32943acc8e2d56790bc5d43096719b2d8496805c524491328f84bb)
            check_type(argname="argument api_id", value=api_id, expected_type=type_hints["api_id"])
            check_type(argname="argument specification", value=specification, expected_type=type_hints["specification"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("ApigatewayV2", jsii.invoke(self, "onExportedAPI", [api_id, specification, region, partition]))

    @jsii.member(jsii_name="onIntegration")
    def on_integration(
        self,
        api_id: builtins.str,
        integration_id: builtins.str,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "ApigatewayV2":
        '''(experimental) Adds a resource of type Integration to the statement.

        https://docs.aws.amazon.com/apigateway/latest/developerguide/security_iam_service-with-iam.html

        :param api_id: - Identifier for the apiId.
        :param integration_id: - Identifier for the integrationId.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6dce252eb85908cabd710c9c0cf8a803df1a21b0237d7e871ad1673609ea1639)
            check_type(argname="argument api_id", value=api_id, expected_type=type_hints["api_id"])
            check_type(argname="argument integration_id", value=integration_id, expected_type=type_hints["integration_id"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("ApigatewayV2", jsii.invoke(self, "onIntegration", [api_id, integration_id, region, partition]))

    @jsii.member(jsii_name="onIntegrationResponse")
    def on_integration_response(
        self,
        api_id: builtins.str,
        integration_id: builtins.str,
        integration_response_id: builtins.str,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "ApigatewayV2":
        '''(experimental) Adds a resource of type IntegrationResponse to the statement.

        https://docs.aws.amazon.com/apigateway/latest/developerguide/security_iam_service-with-iam.html

        :param api_id: - Identifier for the apiId.
        :param integration_id: - Identifier for the integrationId.
        :param integration_response_id: - Identifier for the integrationResponseId.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e47c1478c040b518604cc8f6acc8f403887ce24b84c4d6e29019eb22e5c180a9)
            check_type(argname="argument api_id", value=api_id, expected_type=type_hints["api_id"])
            check_type(argname="argument integration_id", value=integration_id, expected_type=type_hints["integration_id"])
            check_type(argname="argument integration_response_id", value=integration_response_id, expected_type=type_hints["integration_response_id"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("ApigatewayV2", jsii.invoke(self, "onIntegrationResponse", [api_id, integration_id, integration_response_id, region, partition]))

    @jsii.member(jsii_name="onIntegrationResponses")
    def on_integration_responses(
        self,
        api_id: builtins.str,
        integration_id: builtins.str,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "ApigatewayV2":
        '''(experimental) Adds a resource of type IntegrationResponses to the statement.

        https://docs.aws.amazon.com/apigateway/latest/developerguide/security_iam_service-with-iam.html

        :param api_id: - Identifier for the apiId.
        :param integration_id: - Identifier for the integrationId.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__db776678364f7907dceec69779c730469ee14c2dcda930bc9f91cff62a439b46)
            check_type(argname="argument api_id", value=api_id, expected_type=type_hints["api_id"])
            check_type(argname="argument integration_id", value=integration_id, expected_type=type_hints["integration_id"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("ApigatewayV2", jsii.invoke(self, "onIntegrationResponses", [api_id, integration_id, region, partition]))

    @jsii.member(jsii_name="onIntegrations")
    def on_integrations(
        self,
        api_id: builtins.str,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "ApigatewayV2":
        '''(experimental) Adds a resource of type Integrations to the statement.

        https://docs.aws.amazon.com/apigateway/latest/developerguide/security_iam_service-with-iam.html

        :param api_id: - Identifier for the apiId.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fae92def6014ef7a2d876cf145e63719b7815f463d3b7102cc5e0da5464afce4)
            check_type(argname="argument api_id", value=api_id, expected_type=type_hints["api_id"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("ApigatewayV2", jsii.invoke(self, "onIntegrations", [api_id, region, partition]))

    @jsii.member(jsii_name="onModel")
    def on_model(
        self,
        api_id: builtins.str,
        model_id: builtins.str,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "ApigatewayV2":
        '''(experimental) Adds a resource of type Model to the statement.

        https://docs.aws.amazon.com/apigateway/latest/developerguide/security_iam_service-with-iam.html

        :param api_id: - Identifier for the apiId.
        :param model_id: - Identifier for the modelId.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b1f1aec85c86f2c6c837617b1dd73421f0734675e22d466200ea3c8a07fc18b4)
            check_type(argname="argument api_id", value=api_id, expected_type=type_hints["api_id"])
            check_type(argname="argument model_id", value=model_id, expected_type=type_hints["model_id"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("ApigatewayV2", jsii.invoke(self, "onModel", [api_id, model_id, region, partition]))

    @jsii.member(jsii_name="onModels")
    def on_models(
        self,
        api_id: builtins.str,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "ApigatewayV2":
        '''(experimental) Adds a resource of type Models to the statement.

        https://docs.aws.amazon.com/apigateway/latest/developerguide/security_iam_service-with-iam.html

        :param api_id: - Identifier for the apiId.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f9d3355b8358b49d3e52fa92150574a175b77fb457ef29776e0ef785868f1540)
            check_type(argname="argument api_id", value=api_id, expected_type=type_hints["api_id"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("ApigatewayV2", jsii.invoke(self, "onModels", [api_id, region, partition]))

    @jsii.member(jsii_name="onModelTemplate")
    def on_model_template(
        self,
        api_id: builtins.str,
        model_id: builtins.str,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "ApigatewayV2":
        '''(experimental) Adds a resource of type ModelTemplate to the statement.

        https://docs.aws.amazon.com/apigateway/latest/developerguide/security_iam_service-with-iam.html

        :param api_id: - Identifier for the apiId.
        :param model_id: - Identifier for the modelId.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3205a00c2ac3a2cf8fd5b1d9c5b72ffccfc18ae7b4ebc02607a39978ecff5842)
            check_type(argname="argument api_id", value=api_id, expected_type=type_hints["api_id"])
            check_type(argname="argument model_id", value=model_id, expected_type=type_hints["model_id"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("ApigatewayV2", jsii.invoke(self, "onModelTemplate", [api_id, model_id, region, partition]))

    @jsii.member(jsii_name="onRoute")
    def on_route(
        self,
        api_id: builtins.str,
        route_id: builtins.str,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "ApigatewayV2":
        '''(experimental) Adds a resource of type Route to the statement.

        https://docs.aws.amazon.com/apigateway/latest/developerguide/security_iam_service-with-iam.html

        :param api_id: - Identifier for the apiId.
        :param route_id: - Identifier for the routeId.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifRequestApiKeyRequired() - .ifRequestRouteAuthorizationType() - .ifResourceApiKeyRequired() - .ifResourceRouteAuthorizationType() - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__535cdf6bd645138e8bf4a936a0a7afb0e3b6c075c71da802bd114491aad90c71)
            check_type(argname="argument api_id", value=api_id, expected_type=type_hints["api_id"])
            check_type(argname="argument route_id", value=route_id, expected_type=type_hints["route_id"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("ApigatewayV2", jsii.invoke(self, "onRoute", [api_id, route_id, region, partition]))

    @jsii.member(jsii_name="onRouteRequestParameter")
    def on_route_request_parameter(
        self,
        api_id: builtins.str,
        route_id: builtins.str,
        request_parameter_key: builtins.str,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "ApigatewayV2":
        '''(experimental) Adds a resource of type RouteRequestParameter to the statement.

        https://docs.aws.amazon.com/apigateway/latest/developerguide/security_iam_service-with-iam.html

        :param api_id: - Identifier for the apiId.
        :param route_id: - Identifier for the routeId.
        :param request_parameter_key: - Identifier for the requestParameterKey.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9f08791ff7ee244dac0f52c244ac971111ec41e37c786827a1f6641a87c43126)
            check_type(argname="argument api_id", value=api_id, expected_type=type_hints["api_id"])
            check_type(argname="argument route_id", value=route_id, expected_type=type_hints["route_id"])
            check_type(argname="argument request_parameter_key", value=request_parameter_key, expected_type=type_hints["request_parameter_key"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("ApigatewayV2", jsii.invoke(self, "onRouteRequestParameter", [api_id, route_id, request_parameter_key, region, partition]))

    @jsii.member(jsii_name="onRouteResponse")
    def on_route_response(
        self,
        api_id: builtins.str,
        route_id: builtins.str,
        route_response_id: builtins.str,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "ApigatewayV2":
        '''(experimental) Adds a resource of type RouteResponse to the statement.

        https://docs.aws.amazon.com/apigateway/latest/developerguide/security_iam_service-with-iam.html

        :param api_id: - Identifier for the apiId.
        :param route_id: - Identifier for the routeId.
        :param route_response_id: - Identifier for the routeResponseId.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d1bdc5064e2874d9bb381038a17f8eeb9c31b0a57b17bb9e43a9b0af893107c0)
            check_type(argname="argument api_id", value=api_id, expected_type=type_hints["api_id"])
            check_type(argname="argument route_id", value=route_id, expected_type=type_hints["route_id"])
            check_type(argname="argument route_response_id", value=route_response_id, expected_type=type_hints["route_response_id"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("ApigatewayV2", jsii.invoke(self, "onRouteResponse", [api_id, route_id, route_response_id, region, partition]))

    @jsii.member(jsii_name="onRouteResponses")
    def on_route_responses(
        self,
        api_id: builtins.str,
        route_id: builtins.str,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "ApigatewayV2":
        '''(experimental) Adds a resource of type RouteResponses to the statement.

        https://docs.aws.amazon.com/apigateway/latest/developerguide/security_iam_service-with-iam.html

        :param api_id: - Identifier for the apiId.
        :param route_id: - Identifier for the routeId.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__95ee59bb917b73265bf1fd7098747ff4ad3f70c60021ad3066090fdb0ec1757f)
            check_type(argname="argument api_id", value=api_id, expected_type=type_hints["api_id"])
            check_type(argname="argument route_id", value=route_id, expected_type=type_hints["route_id"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("ApigatewayV2", jsii.invoke(self, "onRouteResponses", [api_id, route_id, region, partition]))

    @jsii.member(jsii_name="onRoutes")
    def on_routes(
        self,
        api_id: builtins.str,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "ApigatewayV2":
        '''(experimental) Adds a resource of type Routes to the statement.

        https://docs.aws.amazon.com/apigateway/latest/developerguide/security_iam_service-with-iam.html

        :param api_id: - Identifier for the apiId.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifRequestApiKeyRequired() - .ifRequestRouteAuthorizationType() - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__46db5922ba8d077575c8af2252ab6b745c62619bf3f59af664527bb68ff34b0d)
            check_type(argname="argument api_id", value=api_id, expected_type=type_hints["api_id"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("ApigatewayV2", jsii.invoke(self, "onRoutes", [api_id, region, partition]))

    @jsii.member(jsii_name="onRouteSettings")
    def on_route_settings(
        self,
        api_id: builtins.str,
        stage_name: builtins.str,
        route_key: builtins.str,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "ApigatewayV2":
        '''(experimental) Adds a resource of type RouteSettings to the statement.

        https://docs.aws.amazon.com/apigateway/latest/developerguide/security_iam_service-with-iam.html

        :param api_id: - Identifier for the apiId.
        :param stage_name: - Identifier for the stageName.
        :param route_key: - Identifier for the routeKey.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__444b046116d15f58fbbb28f3ae4e71a49103c9bb450c9e333b54b626f0124091)
            check_type(argname="argument api_id", value=api_id, expected_type=type_hints["api_id"])
            check_type(argname="argument stage_name", value=stage_name, expected_type=type_hints["stage_name"])
            check_type(argname="argument route_key", value=route_key, expected_type=type_hints["route_key"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("ApigatewayV2", jsii.invoke(self, "onRouteSettings", [api_id, stage_name, route_key, region, partition]))

    @jsii.member(jsii_name="onStage")
    def on_stage(
        self,
        api_id: builtins.str,
        stage_name: builtins.str,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "ApigatewayV2":
        '''(experimental) Adds a resource of type Stage to the statement.

        https://docs.aws.amazon.com/apigateway/latest/developerguide/security_iam_service-with-iam.html

        :param api_id: - Identifier for the apiId.
        :param stage_name: - Identifier for the stageName.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifRequestAccessLoggingDestination() - .ifRequestAccessLoggingFormat() - .ifResourceAccessLoggingDestination() - .ifResourceAccessLoggingFormat() - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__cd01afdb29da0c31b53d85aea6df7e8f4659ec3a35908b4c35e2b0ea5b2bc6c2)
            check_type(argname="argument api_id", value=api_id, expected_type=type_hints["api_id"])
            check_type(argname="argument stage_name", value=stage_name, expected_type=type_hints["stage_name"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("ApigatewayV2", jsii.invoke(self, "onStage", [api_id, stage_name, region, partition]))

    @jsii.member(jsii_name="onStages")
    def on_stages(
        self,
        api_id: builtins.str,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "ApigatewayV2":
        '''(experimental) Adds a resource of type Stages to the statement.

        https://docs.aws.amazon.com/apigateway/latest/developerguide/security_iam_service-with-iam.html

        :param api_id: - Identifier for the apiId.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifRequestAccessLoggingDestination() - .ifRequestAccessLoggingFormat() - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e824570fe0283f99fae4458abf511b7e27296bbe5d66ce4f56a13a7530c99873)
            check_type(argname="argument api_id", value=api_id, expected_type=type_hints["api_id"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("ApigatewayV2", jsii.invoke(self, "onStages", [api_id, region, partition]))

    @jsii.member(jsii_name="toDELETE")
    def to_delete(self) -> "ApigatewayV2":
        '''(experimental) Grants permission to delete a particular resource.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/apigatewayv2/latest/api-reference/API_DELETE.html

        :stability: experimental
        '''
        return typing.cast("ApigatewayV2", jsii.invoke(self, "toDELETE", []))

    @jsii.member(jsii_name="toGET")
    def to_get(self) -> "ApigatewayV2":
        '''(experimental) Grants permission to read a particular resource.

        Access Level: Read

        https://docs.aws.amazon.com/apigatewayv2/latest/api-reference/API_GET.html

        :stability: experimental
        '''
        return typing.cast("ApigatewayV2", jsii.invoke(self, "toGET", []))

    @jsii.member(jsii_name="toPATCH")
    def to_patch(self) -> "ApigatewayV2":
        '''(experimental) Grants permission to update a particular resource.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/apigatewayv2/latest/api-reference/API_PATCH.html

        :stability: experimental
        '''
        return typing.cast("ApigatewayV2", jsii.invoke(self, "toPATCH", []))

    @jsii.member(jsii_name="toPOST")
    def to_post(self) -> "ApigatewayV2":
        '''(experimental) Grants permission to create a particular resource.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/apigatewayv2/latest/api-reference/API_POST.html

        :stability: experimental
        '''
        return typing.cast("ApigatewayV2", jsii.invoke(self, "toPOST", []))

    @jsii.member(jsii_name="toPUT")
    def to_put(self) -> "ApigatewayV2":
        '''(experimental) Grants permission to update a particular resource.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/apigatewayv2/latest/api-reference/API_PUT.html

        :stability: experimental
        '''
        return typing.cast("ApigatewayV2", jsii.invoke(self, "toPUT", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__154f65b36cb322ded9f12d9e27d80e29944fa00a5b6ca2e2710ad2426afa6dbd)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f2b0b208d1cdada7f9a72a71cbc0494e60572d23908e02a805b1b477d90f9a3c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class AppIntegrations(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.AppIntegrations",
):
    '''(experimental) Statement provider for service `app-integrations <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonappintegrations.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `app-integrations <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonappintegrations.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onDataIntegration")
    def on_data_integration(
        self,
        data_integration_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "AppIntegrations":
        '''(experimental) Adds a resource of type data-integration to the statement.

        https://docs.aws.amazon.com/connect/latest/adminguide/API_DataIntegration.html

        :param data_integration_id: - Identifier for the dataIntegrationId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__48825ddd1115e5be0f8d01ee369671152b05a5a7b422b3758e0302212f3fe92d)
            check_type(argname="argument data_integration_id", value=data_integration_id, expected_type=type_hints["data_integration_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("AppIntegrations", jsii.invoke(self, "onDataIntegration", [data_integration_id, account, region, partition]))

    @jsii.member(jsii_name="onDataIntegrationAssociation")
    def on_data_integration_association(
        self,
        data_integration_id: builtins.str,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "AppIntegrations":
        '''(experimental) Adds a resource of type data-integration-association to the statement.

        https://docs.aws.amazon.com/connect/latest/adminguide/API_DataIntegrationAssociation.html

        :param data_integration_id: - Identifier for the dataIntegrationId.
        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7341df38f7c13c0f1c5dd50b7db7df11854d40d4937f9f64909d5176ad815cd7)
            check_type(argname="argument data_integration_id", value=data_integration_id, expected_type=type_hints["data_integration_id"])
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("AppIntegrations", jsii.invoke(self, "onDataIntegrationAssociation", [data_integration_id, resource_id, account, region, partition]))

    @jsii.member(jsii_name="onEventIntegration")
    def on_event_integration(
        self,
        event_integration_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "AppIntegrations":
        '''(experimental) Adds a resource of type event-integration to the statement.

        https://docs.aws.amazon.com/connect/latest/adminguide/API_EventIntegration.html

        :param event_integration_name: - Identifier for the eventIntegrationName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fcb71b71f866b231582352abffe8b2f4a4b7e7651b7c0f5343fb9de4cb42d9fa)
            check_type(argname="argument event_integration_name", value=event_integration_name, expected_type=type_hints["event_integration_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("AppIntegrations", jsii.invoke(self, "onEventIntegration", [event_integration_name, account, region, partition]))

    @jsii.member(jsii_name="onEventIntegrationAssociation")
    def on_event_integration_association(
        self,
        event_integration_name: builtins.str,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "AppIntegrations":
        '''(experimental) Adds a resource of type event-integration-association to the statement.

        https://docs.aws.amazon.com/connect/latest/adminguide/API_EventIntegrationAssociation.html

        :param event_integration_name: - Identifier for the eventIntegrationName.
        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2d4274fb63dfc16e1bb092be8171bcdb2adb63cb45bd3bd2cafa057d9bb324ea)
            check_type(argname="argument event_integration_name", value=event_integration_name, expected_type=type_hints["event_integration_name"])
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("AppIntegrations", jsii.invoke(self, "onEventIntegrationAssociation", [event_integration_name, resource_id, account, region, partition]))

    @jsii.member(jsii_name="toCreateDataIntegration")
    def to_create_data_integration(self) -> "AppIntegrations":
        '''(experimental) Grants permission to create a new DataIntegration.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - appflow:CreateFlow
        - iam:AttachRolePolicy
        - iam:CreateServiceLinkedRole
        - iam:PutRolePolicy

        https://docs.aws.amazon.com/appintegrations/latest/APIReference/API_CreateDataIntegration.html

        :stability: experimental
        '''
        return typing.cast("AppIntegrations", jsii.invoke(self, "toCreateDataIntegration", []))

    @jsii.member(jsii_name="toCreateDataIntegrationAssociation")
    def to_create_data_integration_association(self) -> "AppIntegrations":
        '''(experimental) Grants permission to create a DataIntegrationAssociation.

        Access Level: Write

        https://docs.aws.amazon.com/appintegrations/latest/APIReference/API_CreateDataIntegrationAssociation.html

        :stability: experimental
        '''
        return typing.cast("AppIntegrations", jsii.invoke(self, "toCreateDataIntegrationAssociation", []))

    @jsii.member(jsii_name="toCreateEventIntegration")
    def to_create_event_integration(self) -> "AppIntegrations":
        '''(experimental) Grants permission to create a new EventIntegration.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - iam:AttachRolePolicy
        - iam:CreateServiceLinkedRole
        - iam:PutRolePolicy

        https://docs.aws.amazon.com/appintegrations/latest/APIReference/API_CreateEventIntegration.html

        :stability: experimental
        '''
        return typing.cast("AppIntegrations", jsii.invoke(self, "toCreateEventIntegration", []))

    @jsii.member(jsii_name="toCreateEventIntegrationAssociation")
    def to_create_event_integration_association(self) -> "AppIntegrations":
        '''(experimental) Grants permission to create an EventIntegrationAssociation.

        Access Level: Write

        Dependent actions:

        - events:PutRule
        - events:PutTargets

        https://docs.aws.amazon.com/appintegrations/latest/APIReference/API_CreateEventIntegrationAssociation.html

        :stability: experimental
        '''
        return typing.cast("AppIntegrations", jsii.invoke(self, "toCreateEventIntegrationAssociation", []))

    @jsii.member(jsii_name="toDeleteDataIntegration")
    def to_delete_data_integration(self) -> "AppIntegrations":
        '''(experimental) Grants permission to delete a DataIntegration.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/appintegrations/latest/APIReference/API_DeleteDataIntegration.html

        :stability: experimental
        '''
        return typing.cast("AppIntegrations", jsii.invoke(self, "toDeleteDataIntegration", []))

    @jsii.member(jsii_name="toDeleteDataIntegrationAssociation")
    def to_delete_data_integration_association(self) -> "AppIntegrations":
        '''(experimental) Grants permission to delete a DataIntegrationAssociation.

        Access Level: Write

        https://docs.aws.amazon.com/appintegrations/latest/APIReference/API_DeleteDataIntegrationAssociation.html

        :stability: experimental
        '''
        return typing.cast("AppIntegrations", jsii.invoke(self, "toDeleteDataIntegrationAssociation", []))

    @jsii.member(jsii_name="toDeleteEventIntegration")
    def to_delete_event_integration(self) -> "AppIntegrations":
        '''(experimental) Grants permission to delete an EventIntegration.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/appintegrations/latest/APIReference/API_DeleteEventIntegration.html

        :stability: experimental
        '''
        return typing.cast("AppIntegrations", jsii.invoke(self, "toDeleteEventIntegration", []))

    @jsii.member(jsii_name="toDeleteEventIntegrationAssociation")
    def to_delete_event_integration_association(self) -> "AppIntegrations":
        '''(experimental) Grants permission to delete an EventIntegrationAssociation.

        Access Level: Write

        Dependent actions:

        - events:DeleteRule
        - events:ListTargetsByRule
        - events:RemoveTargets

        https://docs.aws.amazon.com/appintegrations/latest/APIReference/API_DeleteEventIntegrationAssociation.html

        :stability: experimental
        '''
        return typing.cast("AppIntegrations", jsii.invoke(self, "toDeleteEventIntegrationAssociation", []))

    @jsii.member(jsii_name="toGetDataIntegration")
    def to_get_data_integration(self) -> "AppIntegrations":
        '''(experimental) Grants permission to view details about DataIntegrations.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/appintegrations/latest/APIReference/API_GetDataIntegration.html

        :stability: experimental
        '''
        return typing.cast("AppIntegrations", jsii.invoke(self, "toGetDataIntegration", []))

    @jsii.member(jsii_name="toGetEventIntegration")
    def to_get_event_integration(self) -> "AppIntegrations":
        '''(experimental) Grants permission to view details about EventIntegrations.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/appintegrations/latest/APIReference/API_GetEventIntegration.html

        :stability: experimental
        '''
        return typing.cast("AppIntegrations", jsii.invoke(self, "toGetEventIntegration", []))

    @jsii.member(jsii_name="toListDataIntegrationAssociations")
    def to_list_data_integration_associations(self) -> "AppIntegrations":
        '''(experimental) Grants permission to list DataIntegrationAssociations.

        Access Level: List

        https://docs.aws.amazon.com/appintegrations/latest/APIReference/API_ListDataIntegrationAssociations

        :stability: experimental
        '''
        return typing.cast("AppIntegrations", jsii.invoke(self, "toListDataIntegrationAssociations", []))

    @jsii.member(jsii_name="toListDataIntegrations")
    def to_list_data_integrations(self) -> "AppIntegrations":
        '''(experimental) Grants permission to list DataIntegrations.

        Access Level: List

        https://docs.aws.amazon.com/appintegrations/latest/APIReference/API_ListDataIntegrations.html

        :stability: experimental
        '''
        return typing.cast("AppIntegrations", jsii.invoke(self, "toListDataIntegrations", []))

    @jsii.member(jsii_name="toListEventIntegrationAssociations")
    def to_list_event_integration_associations(self) -> "AppIntegrations":
        '''(experimental) Grants permission to list EventIntegrationAssociations.

        Access Level: Read

        https://docs.aws.amazon.com/appintegrations/latest/APIReference/API_ListEventIntegrationAssociations

        :stability: experimental
        '''
        return typing.cast("AppIntegrations", jsii.invoke(self, "toListEventIntegrationAssociations", []))

    @jsii.member(jsii_name="toListEventIntegrations")
    def to_list_event_integrations(self) -> "AppIntegrations":
        '''(experimental) Grants permission to list EventIntegrations.

        Access Level: List

        https://docs.aws.amazon.com/appintegrations/latest/APIReference/API_ListEventIntegrations.html

        :stability: experimental
        '''
        return typing.cast("AppIntegrations", jsii.invoke(self, "toListEventIntegrations", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "AppIntegrations":
        '''(experimental) Grants permission to lists tag for an Amazon AppIntegration resource.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/appintegrations/latest/APIReference/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("AppIntegrations", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "AppIntegrations":
        '''(experimental) Grants permission to tag an Amazon AppIntegration resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()
        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/appintegrations/latest/APIReference/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("AppIntegrations", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "AppIntegrations":
        '''(experimental) Grants permission to untag an Amazon AppIntegration resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/appintegrations/latest/APIReference/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("AppIntegrations", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateDataIntegration")
    def to_update_data_integration(self) -> "AppIntegrations":
        '''(experimental) Grants permission to modify a DataIntegration.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/appintegrations/latest/APIReference/API_UpdateDataIntegration.html

        :stability: experimental
        '''
        return typing.cast("AppIntegrations", jsii.invoke(self, "toUpdateDataIntegration", []))

    @jsii.member(jsii_name="toUpdateEventIntegration")
    def to_update_event_integration(self) -> "AppIntegrations":
        '''(experimental) Grants permission to modify an EventIntegration.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/appintegrations/latest/APIReference/API_UpdateEventIntegration.html

        :stability: experimental
        '''
        return typing.cast("AppIntegrations", jsii.invoke(self, "toUpdateEventIntegration", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a57cfe335ca1877e0d07050b875c53bd9a26a2ba554527ff1d5be02dacd07324)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3a727de420c6e7f7c77245286d53be6e326aef9cac5018f8a75d909460517744)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Appconfig(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Appconfig",
):
    '''(experimental) Statement provider for service `appconfig <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsappconfig.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `appconfig <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsappconfig.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onApplication")
    def on_application(
        self,
        application_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Appconfig":
        '''(experimental) Adds a resource of type application to the statement.

        https://docs.aws.amazon.com/appconfig/latest/userguide/appconfig-creating-application.html

        :param application_id: - Identifier for the applicationId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__18cb28388a50635069d0f8c3f0b58a2dadf6ae75fec379ae250758940a14a451)
            check_type(argname="argument application_id", value=application_id, expected_type=type_hints["application_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Appconfig", jsii.invoke(self, "onApplication", [application_id, account, region, partition]))

    @jsii.member(jsii_name="onConfiguration")
    def on_configuration(
        self,
        application_id: builtins.str,
        environment_id: builtins.str,
        configuration_profile_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Appconfig":
        '''(experimental) Adds a resource of type configuration to the statement.

        https://docs.aws.amazon.com/appconfig/latest/userguide/appconfig-retrieving-the-configuration.html

        :param application_id: - Identifier for the applicationId.
        :param environment_id: - Identifier for the environmentId.
        :param configuration_profile_id: - Identifier for the configurationProfileId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e941c92ba795683c876ce7e9f0aac78ec5a10d6dee33dbaee8bfc23ed0eafd0e)
            check_type(argname="argument application_id", value=application_id, expected_type=type_hints["application_id"])
            check_type(argname="argument environment_id", value=environment_id, expected_type=type_hints["environment_id"])
            check_type(argname="argument configuration_profile_id", value=configuration_profile_id, expected_type=type_hints["configuration_profile_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Appconfig", jsii.invoke(self, "onConfiguration", [application_id, environment_id, configuration_profile_id, account, region, partition]))

    @jsii.member(jsii_name="onConfigurationprofile")
    def on_configurationprofile(
        self,
        application_id: builtins.str,
        configuration_profile_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Appconfig":
        '''(experimental) Adds a resource of type configurationprofile to the statement.

        https://docs.aws.amazon.com/appconfig/latest/userguide/appconfig-creating-configuration-and-profile.html

        :param application_id: - Identifier for the applicationId.
        :param configuration_profile_id: - Identifier for the configurationProfileId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__94e5269474420d3d7d06c06cdf8f0fa01da11ecf04e591923de7a8bb1e769785)
            check_type(argname="argument application_id", value=application_id, expected_type=type_hints["application_id"])
            check_type(argname="argument configuration_profile_id", value=configuration_profile_id, expected_type=type_hints["configuration_profile_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Appconfig", jsii.invoke(self, "onConfigurationprofile", [application_id, configuration_profile_id, account, region, partition]))

    @jsii.member(jsii_name="onDeployment")
    def on_deployment(
        self,
        application_id: builtins.str,
        environment_id: builtins.str,
        deployment_number: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Appconfig":
        '''(experimental) Adds a resource of type deployment to the statement.

        https://docs.aws.amazon.com/appconfig/latest/userguide/appconfig-deploying.html

        :param application_id: - Identifier for the applicationId.
        :param environment_id: - Identifier for the environmentId.
        :param deployment_number: - Identifier for the deploymentNumber.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__eeadfe41201e40133b471a16b5076bd971edadf0c60e70cf88341c8ea919e98a)
            check_type(argname="argument application_id", value=application_id, expected_type=type_hints["application_id"])
            check_type(argname="argument environment_id", value=environment_id, expected_type=type_hints["environment_id"])
            check_type(argname="argument deployment_number", value=deployment_number, expected_type=type_hints["deployment_number"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Appconfig", jsii.invoke(self, "onDeployment", [application_id, environment_id, deployment_number, account, region, partition]))

    @jsii.member(jsii_name="onDeploymentstrategy")
    def on_deploymentstrategy(
        self,
        deployment_strategy_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Appconfig":
        '''(experimental) Adds a resource of type deploymentstrategy to the statement.

        https://docs.aws.amazon.com/appconfig/latest/userguide/appconfig-creating-deployment-strategy.html

        :param deployment_strategy_id: - Identifier for the deploymentStrategyId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6dfdf7c5d370b01f1d8b23ed270ad6db363ea2ea77441aba06c8e8dc180c35cb)
            check_type(argname="argument deployment_strategy_id", value=deployment_strategy_id, expected_type=type_hints["deployment_strategy_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Appconfig", jsii.invoke(self, "onDeploymentstrategy", [deployment_strategy_id, account, region, partition]))

    @jsii.member(jsii_name="onEnvironment")
    def on_environment(
        self,
        application_id: builtins.str,
        environment_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Appconfig":
        '''(experimental) Adds a resource of type environment to the statement.

        https://docs.aws.amazon.com/appconfig/latest/userguide/appconfig-creating-environment.html

        :param application_id: - Identifier for the applicationId.
        :param environment_id: - Identifier for the environmentId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__77bdf8b5e7443a6782e7a8527c1b2abe9b7072040302d8f545794426c98ba8fc)
            check_type(argname="argument application_id", value=application_id, expected_type=type_hints["application_id"])
            check_type(argname="argument environment_id", value=environment_id, expected_type=type_hints["environment_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Appconfig", jsii.invoke(self, "onEnvironment", [application_id, environment_id, account, region, partition]))

    @jsii.member(jsii_name="onExtension")
    def on_extension(
        self,
        extension_id: builtins.str,
        extension_version_number: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Appconfig":
        '''(experimental) Adds a resource of type extension to the statement.

        https://docs.aws.amazon.com/appconfig/latest/userguide/working-with-appconfig-extensions.html

        :param extension_id: - Identifier for the extensionId.
        :param extension_version_number: - Identifier for the extensionVersionNumber.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__cce90cb77f7eb6dc250e6f497a39e1057479c7f28a989a7dc500262698db17f3)
            check_type(argname="argument extension_id", value=extension_id, expected_type=type_hints["extension_id"])
            check_type(argname="argument extension_version_number", value=extension_version_number, expected_type=type_hints["extension_version_number"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Appconfig", jsii.invoke(self, "onExtension", [extension_id, extension_version_number, account, region, partition]))

    @jsii.member(jsii_name="onExtensionassociation")
    def on_extensionassociation(
        self,
        extension_association_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Appconfig":
        '''(experimental) Adds a resource of type extensionassociation to the statement.

        https://docs.aws.amazon.com/appconfig/latest/userguide/working-with-appconfig-extensions.html

        :param extension_association_id: - Identifier for the extensionAssociationId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__513ecdfe1b465a9811541d93846af0b05ea9d08d125afd7ebd0b098bf24c8f30)
            check_type(argname="argument extension_association_id", value=extension_association_id, expected_type=type_hints["extension_association_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Appconfig", jsii.invoke(self, "onExtensionassociation", [extension_association_id, account, region, partition]))

    @jsii.member(jsii_name="onHostedconfigurationversion")
    def on_hostedconfigurationversion(
        self,
        application_id: builtins.str,
        configuration_profile_id: builtins.str,
        version_number: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Appconfig":
        '''(experimental) Adds a resource of type hostedconfigurationversion to the statement.

        https://docs.aws.amazon.com/appconfig/latest/userguide/appconfig-creating-configuration-and-profile.html

        :param application_id: - Identifier for the applicationId.
        :param configuration_profile_id: - Identifier for the configurationProfileId.
        :param version_number: - Identifier for the versionNumber.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ad4414be3391e54021057570c27345accb1ca08481eb90601ca9873f8b9870c9)
            check_type(argname="argument application_id", value=application_id, expected_type=type_hints["application_id"])
            check_type(argname="argument configuration_profile_id", value=configuration_profile_id, expected_type=type_hints["configuration_profile_id"])
            check_type(argname="argument version_number", value=version_number, expected_type=type_hints["version_number"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Appconfig", jsii.invoke(self, "onHostedconfigurationversion", [application_id, configuration_profile_id, version_number, account, region, partition]))

    @jsii.member(jsii_name="toCreateApplication")
    def to_create_application(self) -> "Appconfig":
        '''(experimental) Grants permission to create an application.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/appconfig/2019-10-09/APIReference/API_CreateApplication.html

        :stability: experimental
        '''
        return typing.cast("Appconfig", jsii.invoke(self, "toCreateApplication", []))

    @jsii.member(jsii_name="toCreateConfigurationProfile")
    def to_create_configuration_profile(self) -> "Appconfig":
        '''(experimental) Grants permission to create a configuration profile.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/appconfig/2019-10-09/APIReference/API_CreateConfigurationProfile.html

        :stability: experimental
        '''
        return typing.cast("Appconfig", jsii.invoke(self, "toCreateConfigurationProfile", []))

    @jsii.member(jsii_name="toCreateDeploymentStrategy")
    def to_create_deployment_strategy(self) -> "Appconfig":
        '''(experimental) Grants permission to create a deployment strategy.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/appconfig/2019-10-09/APIReference/API_CreateDeploymentStrategy.html

        :stability: experimental
        '''
        return typing.cast("Appconfig", jsii.invoke(self, "toCreateDeploymentStrategy", []))

    @jsii.member(jsii_name="toCreateEnvironment")
    def to_create_environment(self) -> "Appconfig":
        '''(experimental) Grants permission to create an environment.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/appconfig/2019-10-09/APIReference/API_CreateEnvironment.html

        :stability: experimental
        '''
        return typing.cast("Appconfig", jsii.invoke(self, "toCreateEnvironment", []))

    @jsii.member(jsii_name="toCreateExtension")
    def to_create_extension(self) -> "Appconfig":
        '''(experimental) Grants permission to create an extension.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/appconfig/2019-10-09/APIReference/API_CreateExtension.html

        :stability: experimental
        '''
        return typing.cast("Appconfig", jsii.invoke(self, "toCreateExtension", []))

    @jsii.member(jsii_name="toCreateExtensionAssociation")
    def to_create_extension_association(self) -> "Appconfig":
        '''(experimental) Grants permission to create an extension association.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/appconfig/2019-10-09/APIReference/API_CreateExtensionAssociation.html

        :stability: experimental
        '''
        return typing.cast("Appconfig", jsii.invoke(self, "toCreateExtensionAssociation", []))

    @jsii.member(jsii_name="toCreateHostedConfigurationVersion")
    def to_create_hosted_configuration_version(self) -> "Appconfig":
        '''(experimental) Grants permission to create a hosted configuration version.

        Access Level: Write

        https://docs.aws.amazon.com/appconfig/2019-10-09/APIReference/API_CreateHostedConfigurationVersion.html

        :stability: experimental
        '''
        return typing.cast("Appconfig", jsii.invoke(self, "toCreateHostedConfigurationVersion", []))

    @jsii.member(jsii_name="toDeleteApplication")
    def to_delete_application(self) -> "Appconfig":
        '''(experimental) Grants permission to delete an application.

        Access Level: Write

        https://docs.aws.amazon.com/appconfig/2019-10-09/APIReference/API_DeleteApplication.html

        :stability: experimental
        '''
        return typing.cast("Appconfig", jsii.invoke(self, "toDeleteApplication", []))

    @jsii.member(jsii_name="toDeleteConfigurationProfile")
    def to_delete_configuration_profile(self) -> "Appconfig":
        '''(experimental) Grants permission to delete a configuration profile.

        Access Level: Write

        https://docs.aws.amazon.com/appconfig/2019-10-09/APIReference/API_DeleteConfigurationProfile.html

        :stability: experimental
        '''
        return typing.cast("Appconfig", jsii.invoke(self, "toDeleteConfigurationProfile", []))

    @jsii.member(jsii_name="toDeleteDeploymentStrategy")
    def to_delete_deployment_strategy(self) -> "Appconfig":
        '''(experimental) Grants permission to delete a deployment strategy.

        Access Level: Write

        https://docs.aws.amazon.com/appconfig/2019-10-09/APIReference/API_DeleteDeploymentStrategy.html

        :stability: experimental
        '''
        return typing.cast("Appconfig", jsii.invoke(self, "toDeleteDeploymentStrategy", []))

    @jsii.member(jsii_name="toDeleteEnvironment")
    def to_delete_environment(self) -> "Appconfig":
        '''(experimental) Grants permission to delete an environment.

        Access Level: Write

        https://docs.aws.amazon.com/appconfig/2019-10-09/APIReference/API_DeleteEnvironment.html

        :stability: experimental
        '''
        return typing.cast("Appconfig", jsii.invoke(self, "toDeleteEnvironment", []))

    @jsii.member(jsii_name="toDeleteExtension")
    def to_delete_extension(self) -> "Appconfig":
        '''(experimental) Grants permission to delete an extension.

        Access Level: Write

        https://docs.aws.amazon.com/appconfig/2019-10-09/APIReference/API_DeleteExtension.html

        :stability: experimental
        '''
        return typing.cast("Appconfig", jsii.invoke(self, "toDeleteExtension", []))

    @jsii.member(jsii_name="toDeleteExtensionAssociation")
    def to_delete_extension_association(self) -> "Appconfig":
        '''(experimental) Grants permission to delete an extension association.

        Access Level: Write

        https://docs.aws.amazon.com/appconfig/2019-10-09/APIReference/API_DeleteExtensionAssociation.html

        :stability: experimental
        '''
        return typing.cast("Appconfig", jsii.invoke(self, "toDeleteExtensionAssociation", []))

    @jsii.member(jsii_name="toDeleteHostedConfigurationVersion")
    def to_delete_hosted_configuration_version(self) -> "Appconfig":
        '''(experimental) Grants permission to delete a hosted configuration version.

        Access Level: Write

        https://docs.aws.amazon.com/appconfig/2019-10-09/APIReference/API_DeleteHostedConfigurationVersion.html

        :stability: experimental
        '''
        return typing.cast("Appconfig", jsii.invoke(self, "toDeleteHostedConfigurationVersion", []))

    @jsii.member(jsii_name="toGetApplication")
    def to_get_application(self) -> "Appconfig":
        '''(experimental) Grants permission to view details about an application.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/appconfig/2019-10-09/APIReference/API_GetApplication.html

        :stability: experimental
        '''
        return typing.cast("Appconfig", jsii.invoke(self, "toGetApplication", []))

    @jsii.member(jsii_name="toGetConfiguration")
    def to_get_configuration(self) -> "Appconfig":
        '''(experimental) Grants permission to view details about a configuration.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/appconfig/2019-10-09/APIReference/API_GetConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Appconfig", jsii.invoke(self, "toGetConfiguration", []))

    @jsii.member(jsii_name="toGetConfigurationProfile")
    def to_get_configuration_profile(self) -> "Appconfig":
        '''(experimental) Grants permission to view details about a configuration profile.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/appconfig/2019-10-09/APIReference/API_GetConfigurationProfile.html

        :stability: experimental
        '''
        return typing.cast("Appconfig", jsii.invoke(self, "toGetConfigurationProfile", []))

    @jsii.member(jsii_name="toGetDeployment")
    def to_get_deployment(self) -> "Appconfig":
        '''(experimental) Grants permission to view details about a deployment.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/appconfig/2019-10-09/APIReference/API_GetDeployment.html

        :stability: experimental
        '''
        return typing.cast("Appconfig", jsii.invoke(self, "toGetDeployment", []))

    @jsii.member(jsii_name="toGetDeploymentStrategy")
    def to_get_deployment_strategy(self) -> "Appconfig":
        '''(experimental) Grants permission to view details about a deployment strategy.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/appconfig/2019-10-09/APIReference/API_GetDeploymentStrategy.html

        :stability: experimental
        '''
        return typing.cast("Appconfig", jsii.invoke(self, "toGetDeploymentStrategy", []))

    @jsii.member(jsii_name="toGetEnvironment")
    def to_get_environment(self) -> "Appconfig":
        '''(experimental) Grants permission to view details about an environment.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/appconfig/2019-10-09/APIReference/API_GetEnvironment.html

        :stability: experimental
        '''
        return typing.cast("Appconfig", jsii.invoke(self, "toGetEnvironment", []))

    @jsii.member(jsii_name="toGetExtension")
    def to_get_extension(self) -> "Appconfig":
        '''(experimental) Grants permission to view details about an extension.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/appconfig/2019-10-09/APIReference/API_GetExtension.html

        :stability: experimental
        '''
        return typing.cast("Appconfig", jsii.invoke(self, "toGetExtension", []))

    @jsii.member(jsii_name="toGetExtensionAssociation")
    def to_get_extension_association(self) -> "Appconfig":
        '''(experimental) Grants permission to view details about an extension association.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/appconfig/2019-10-09/APIReference/API_GetExtensionAssociation.html

        :stability: experimental
        '''
        return typing.cast("Appconfig", jsii.invoke(self, "toGetExtensionAssociation", []))

    @jsii.member(jsii_name="toGetHostedConfigurationVersion")
    def to_get_hosted_configuration_version(self) -> "Appconfig":
        '''(experimental) Grants permission to view details about a hosted configuration version.

        Access Level: Read

        https://docs.aws.amazon.com/appconfig/2019-10-09/APIReference/API_GetHostedConfigurationVersion.html

        :stability: experimental
        '''
        return typing.cast("Appconfig", jsii.invoke(self, "toGetHostedConfigurationVersion", []))

    @jsii.member(jsii_name="toGetLatestConfiguration")
    def to_get_latest_configuration(self) -> "Appconfig":
        '''(experimental) Grants permission to retrieve a deployed configuration.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/appconfig/2019-10-09/APIReference/API_appconfigdata_GetLatestConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Appconfig", jsii.invoke(self, "toGetLatestConfiguration", []))

    @jsii.member(jsii_name="toListApplications")
    def to_list_applications(self) -> "Appconfig":
        '''(experimental) Grants permission to list the applications in your account.

        Access Level: List

        https://docs.aws.amazon.com/appconfig/2019-10-09/APIReference/API_ListApplications.html

        :stability: experimental
        '''
        return typing.cast("Appconfig", jsii.invoke(self, "toListApplications", []))

    @jsii.member(jsii_name="toListConfigurationProfiles")
    def to_list_configuration_profiles(self) -> "Appconfig":
        '''(experimental) Grants permission to list the configuration profiles for an application.

        Access Level: List

        https://docs.aws.amazon.com/appconfig/2019-10-09/APIReference/API_ListConfigurationProfiles.html

        :stability: experimental
        '''
        return typing.cast("Appconfig", jsii.invoke(self, "toListConfigurationProfiles", []))

    @jsii.member(jsii_name="toListDeployments")
    def to_list_deployments(self) -> "Appconfig":
        '''(experimental) Grants permission to list the deployments for an environment.

        Access Level: List

        https://docs.aws.amazon.com/appconfig/2019-10-09/APIReference/API_ListDeployments.html

        :stability: experimental
        '''
        return typing.cast("Appconfig", jsii.invoke(self, "toListDeployments", []))

    @jsii.member(jsii_name="toListDeploymentStrategies")
    def to_list_deployment_strategies(self) -> "Appconfig":
        '''(experimental) Grants permission to list the deployment strategies for your account.

        Access Level: List

        https://docs.aws.amazon.com/appconfig/2019-10-09/APIReference/API_ListDeploymentStrategies.html

        :stability: experimental
        '''
        return typing.cast("Appconfig", jsii.invoke(self, "toListDeploymentStrategies", []))

    @jsii.member(jsii_name="toListEnvironments")
    def to_list_environments(self) -> "Appconfig":
        '''(experimental) Grants permission to list the environments for an application.

        Access Level: List

        https://docs.aws.amazon.com/appconfig/2019-10-09/APIReference/API_ListEnvironments.html

        :stability: experimental
        '''
        return typing.cast("Appconfig", jsii.invoke(self, "toListEnvironments", []))

    @jsii.member(jsii_name="toListExtensionAssociations")
    def to_list_extension_associations(self) -> "Appconfig":
        '''(experimental) Grants permission to list the extension associations in your account.

        Access Level: List

        https://docs.aws.amazon.com/appconfig/2019-10-09/APIReference/API_ListExtensionAssociations.html

        :stability: experimental
        '''
        return typing.cast("Appconfig", jsii.invoke(self, "toListExtensionAssociations", []))

    @jsii.member(jsii_name="toListExtensions")
    def to_list_extensions(self) -> "Appconfig":
        '''(experimental) Grants permission to list the extensions in your account.

        Access Level: List

        https://docs.aws.amazon.com/appconfig/2019-10-09/APIReference/API_ListExtensions.html

        :stability: experimental
        '''
        return typing.cast("Appconfig", jsii.invoke(self, "toListExtensions", []))

    @jsii.member(jsii_name="toListHostedConfigurationVersions")
    def to_list_hosted_configuration_versions(self) -> "Appconfig":
        '''(experimental) Grants permission to list the hosted configuration versions for a configuration profile.

        Access Level: List

        https://docs.aws.amazon.com/appconfig/2019-10-09/APIReference/API_ListHostedConfigurationVersions.html

        :stability: experimental
        '''
        return typing.cast("Appconfig", jsii.invoke(self, "toListHostedConfigurationVersions", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Appconfig":
        '''(experimental) Grants permission to view a list of resource tags for a specified resource.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/appconfig/2019-10-09/APIReference/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("Appconfig", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toStartConfigurationSession")
    def to_start_configuration_session(self) -> "Appconfig":
        '''(experimental) Grants permission to start a configuration session.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/appconfig/2019-10-09/APIReference/API_appconfigdata_StartConfigurationSession.html

        :stability: experimental
        '''
        return typing.cast("Appconfig", jsii.invoke(self, "toStartConfigurationSession", []))

    @jsii.member(jsii_name="toStartDeployment")
    def to_start_deployment(self) -> "Appconfig":
        '''(experimental) Grants permission to initiate a deployment.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/appconfig/2019-10-09/APIReference/API_StartDeployment.html

        :stability: experimental
        '''
        return typing.cast("Appconfig", jsii.invoke(self, "toStartDeployment", []))

    @jsii.member(jsii_name="toStopDeployment")
    def to_stop_deployment(self) -> "Appconfig":
        '''(experimental) Grants permission to stop a deployment.

        Access Level: Write

        https://docs.aws.amazon.com/appconfig/2019-10-09/APIReference/API_StopDeployment.html

        :stability: experimental
        '''
        return typing.cast("Appconfig", jsii.invoke(self, "toStopDeployment", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Appconfig":
        '''(experimental) Grants permission to tag an appconfig resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()
        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/appconfig/2019-10-09/APIReference/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("Appconfig", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Appconfig":
        '''(experimental) Grants permission to untag an appconfig resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/appconfig/2019-10-09/APIReference/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("Appconfig", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateApplication")
    def to_update_application(self) -> "Appconfig":
        '''(experimental) Grants permission to modify an application.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/appconfig/2019-10-09/APIReference/API_UpdateApplication.html

        :stability: experimental
        '''
        return typing.cast("Appconfig", jsii.invoke(self, "toUpdateApplication", []))

    @jsii.member(jsii_name="toUpdateConfigurationProfile")
    def to_update_configuration_profile(self) -> "Appconfig":
        '''(experimental) Grants permission to modify a configuration profile.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/appconfig/2019-10-09/APIReference/API_UpdateConfigurationProfile.html

        :stability: experimental
        '''
        return typing.cast("Appconfig", jsii.invoke(self, "toUpdateConfigurationProfile", []))

    @jsii.member(jsii_name="toUpdateDeploymentStrategy")
    def to_update_deployment_strategy(self) -> "Appconfig":
        '''(experimental) Grants permission to modify a deployment strategy.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/appconfig/2019-10-09/APIReference/API_UpdateDeploymentStrategy.html

        :stability: experimental
        '''
        return typing.cast("Appconfig", jsii.invoke(self, "toUpdateDeploymentStrategy", []))

    @jsii.member(jsii_name="toUpdateEnvironment")
    def to_update_environment(self) -> "Appconfig":
        '''(experimental) Grants permission to modify an environment.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/appconfig/2019-10-09/APIReference/API_UpdateEnvironment.html

        :stability: experimental
        '''
        return typing.cast("Appconfig", jsii.invoke(self, "toUpdateEnvironment", []))

    @jsii.member(jsii_name="toUpdateExtension")
    def to_update_extension(self) -> "Appconfig":
        '''(experimental) Grants permission to modify an extension.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/appconfig/2019-10-09/APIReference/API_UpdateExtension.html

        :stability: experimental
        '''
        return typing.cast("Appconfig", jsii.invoke(self, "toUpdateExtension", []))

    @jsii.member(jsii_name="toUpdateExtensionAssociation")
    def to_update_extension_association(self) -> "Appconfig":
        '''(experimental) Grants permission to modify an extension association.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/appconfig/2019-10-09/APIReference/API_UpdateExtensionAssociation.html

        :stability: experimental
        '''
        return typing.cast("Appconfig", jsii.invoke(self, "toUpdateExtensionAssociation", []))

    @jsii.member(jsii_name="toValidateConfiguration")
    def to_validate_configuration(self) -> "Appconfig":
        '''(experimental) Grants permission to validate a configuration.

        Access Level: Write

        https://docs.aws.amazon.com/appconfig/2019-10-09/APIReference/API_ValidateConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Appconfig", jsii.invoke(self, "toValidateConfiguration", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__168652440e2b0d6c18057de24a3194c4c6ecdcbd56893f7b1f359cca515367b2)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__16c686283c261fae4f001b7e0516dc58123c586463f1bf4ee1ae9df74520439e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Appflow(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Appflow",
):
    '''(experimental) Statement provider for service `appflow <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonappflow.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `appflow <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonappflow.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onConnector")
    def on_connector(
        self,
        connector_label: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Appflow":
        '''(experimental) Adds a resource of type connector to the statement.

        https://docs.aws.amazon.com/appflow/1.0/APIReference/API_ConnectorDefinition.html

        :param connector_label: - Identifier for the connectorLabel.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__cee38472dfd8279c6a9f54ff1e707b30825dedc0f7069c6382aa690958204e02)
            check_type(argname="argument connector_label", value=connector_label, expected_type=type_hints["connector_label"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Appflow", jsii.invoke(self, "onConnector", [connector_label, account, region, partition]))

    @jsii.member(jsii_name="onConnectorprofile")
    def on_connectorprofile(
        self,
        profile_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Appflow":
        '''(experimental) Adds a resource of type connectorprofile to the statement.

        https://docs.aws.amazon.com/appflow/1.0/APIReference/API_ConnectorProfile.html

        :param profile_name: - Identifier for the profileName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e6dbdf2d2d8736ee0ce25f75042d034e7f8cd12167ef5ba41d8460e8b2ca2229)
            check_type(argname="argument profile_name", value=profile_name, expected_type=type_hints["profile_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Appflow", jsii.invoke(self, "onConnectorprofile", [profile_name, account, region, partition]))

    @jsii.member(jsii_name="onFlow")
    def on_flow(
        self,
        flow_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Appflow":
        '''(experimental) Adds a resource of type flow to the statement.

        https://docs.aws.amazon.com/appflow/1.0/APIReference/API_FlowDefinition.html

        :param flow_name: - Identifier for the flowName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__41a24bf717a5dcb14e601deb0c0299eada0b5502e426bb7a5737d8e78ae2de25)
            check_type(argname="argument flow_name", value=flow_name, expected_type=type_hints["flow_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Appflow", jsii.invoke(self, "onFlow", [flow_name, account, region, partition]))

    @jsii.member(jsii_name="toCreateConnectorProfile")
    def to_create_connector_profile(self) -> "Appflow":
        '''(experimental) Grants permission to create a login profile to be used with Amazon AppFlow flows.

        Access Level: Write

        https://docs.aws.amazon.com/appflow/1.0/APIReference/API_CreateConnectorProfile.html

        :stability: experimental
        '''
        return typing.cast("Appflow", jsii.invoke(self, "toCreateConnectorProfile", []))

    @jsii.member(jsii_name="toCreateFlow")
    def to_create_flow(self) -> "Appflow":
        '''(experimental) Grants permission to create an Amazon AppFlow flow.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/appflow/1.0/APIReference/API_CreateFlow.html

        :stability: experimental
        '''
        return typing.cast("Appflow", jsii.invoke(self, "toCreateFlow", []))

    @jsii.member(jsii_name="toDeleteConnectorProfile")
    def to_delete_connector_profile(self) -> "Appflow":
        '''(experimental) Grants permission to delete a login profile configured in Amazon AppFlow.

        Access Level: Write

        https://docs.aws.amazon.com/appflow/1.0/APIReference/API_DescribeConnectorProfiles.html

        :stability: experimental
        '''
        return typing.cast("Appflow", jsii.invoke(self, "toDeleteConnectorProfile", []))

    @jsii.member(jsii_name="toDeleteFlow")
    def to_delete_flow(self) -> "Appflow":
        '''(experimental) Grants permission to delete an Amazon AppFlow flow.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/appflow/1.0/APIReference/API_DeleteFlow.html

        :stability: experimental
        '''
        return typing.cast("Appflow", jsii.invoke(self, "toDeleteFlow", []))

    @jsii.member(jsii_name="toDescribeConnector")
    def to_describe_connector(self) -> "Appflow":
        '''(experimental) Grants permission to describe a connector registered in Amazon AppFlow.

        Access Level: Read

        https://docs.aws.amazon.com/appflow/1.0/APIReference/API_DescribeConnector.html

        :stability: experimental
        '''
        return typing.cast("Appflow", jsii.invoke(self, "toDescribeConnector", []))

    @jsii.member(jsii_name="toDescribeConnectorEntity")
    def to_describe_connector_entity(self) -> "Appflow":
        '''(experimental) Grants permission to describe all fields for an object in a login profile configured in Amazon AppFlow.

        Access Level: Read

        https://docs.aws.amazon.com/appflow/1.0/APIReference/API_DescribeConnectorEntity.html

        :stability: experimental
        '''
        return typing.cast("Appflow", jsii.invoke(self, "toDescribeConnectorEntity", []))

    @jsii.member(jsii_name="toDescribeConnectorFields")
    def to_describe_connector_fields(self) -> "Appflow":
        '''(experimental) Grants permission to describe all fields for an object in a login profile configured in Amazon AppFlow (Console Only).

        Access Level: Read

        https://docs.aws.amazon.com/appflow/latest/userguide/identity-access-management.html#appflow-api-actions

        :stability: experimental
        '''
        return typing.cast("Appflow", jsii.invoke(self, "toDescribeConnectorFields", []))

    @jsii.member(jsii_name="toDescribeConnectorProfiles")
    def to_describe_connector_profiles(self) -> "Appflow":
        '''(experimental) Grants permission to describe all login profiles configured in Amazon AppFlow.

        Access Level: Read

        https://docs.aws.amazon.com/appflow/1.0/APIReference/API_DescribeConnectorProfiles.html

        :stability: experimental
        '''
        return typing.cast("Appflow", jsii.invoke(self, "toDescribeConnectorProfiles", []))

    @jsii.member(jsii_name="toDescribeConnectors")
    def to_describe_connectors(self) -> "Appflow":
        '''(experimental) Grants permission to describe all connectors supported by Amazon AppFlow.

        Access Level: Read

        https://docs.aws.amazon.com/appflow/1.0/APIReference/API_DescribeConnectors.html

        :stability: experimental
        '''
        return typing.cast("Appflow", jsii.invoke(self, "toDescribeConnectors", []))

    @jsii.member(jsii_name="toDescribeFlow")
    def to_describe_flow(self) -> "Appflow":
        '''(experimental) Grants permission to describe a specific flow configured in Amazon AppFlow.

        Access Level: Read

        https://docs.aws.amazon.com/appflow/1.0/APIReference/API_DescribeFlow.html

        :stability: experimental
        '''
        return typing.cast("Appflow", jsii.invoke(self, "toDescribeFlow", []))

    @jsii.member(jsii_name="toDescribeFlowExecution")
    def to_describe_flow_execution(self) -> "Appflow":
        '''(experimental) Grants permission to describe all flow executions for a flow configured in Amazon AppFlow (Console Only).

        Access Level: Read

        https://docs.aws.amazon.com/appflow/latest/userguide/identity-access-management.html#appflow-api-actions

        :stability: experimental
        '''
        return typing.cast("Appflow", jsii.invoke(self, "toDescribeFlowExecution", []))

    @jsii.member(jsii_name="toDescribeFlowExecutionRecords")
    def to_describe_flow_execution_records(self) -> "Appflow":
        '''(experimental) Grants permission to describe all flow executions for a flow configured in Amazon AppFlow.

        Access Level: Read

        https://docs.aws.amazon.com/appflow/1.0/APIReference/API_DescribeFlowExecutionRecords.html

        :stability: experimental
        '''
        return typing.cast("Appflow", jsii.invoke(self, "toDescribeFlowExecutionRecords", []))

    @jsii.member(jsii_name="toDescribeFlows")
    def to_describe_flows(self) -> "Appflow":
        '''(experimental) Grants permission to describe all flows configured in Amazon AppFlow (Console Only).

        Access Level: Read

        https://docs.aws.amazon.com/appflow/latest/userguide/identity-access-management.html#appflow-api-actions

        :stability: experimental
        '''
        return typing.cast("Appflow", jsii.invoke(self, "toDescribeFlows", []))

    @jsii.member(jsii_name="toListConnectorEntities")
    def to_list_connector_entities(self) -> "Appflow":
        '''(experimental) Grants permission to list all objects for a login profile configured in Amazon AppFlow.

        Access Level: List

        https://docs.aws.amazon.com/appflow/1.0/APIReference/API_ListConnectorEntities.html

        :stability: experimental
        '''
        return typing.cast("Appflow", jsii.invoke(self, "toListConnectorEntities", []))

    @jsii.member(jsii_name="toListConnectorFields")
    def to_list_connector_fields(self) -> "Appflow":
        '''(experimental) Grants permission to list all objects for a login profile configured in Amazon AppFlow (Console Only).

        Access Level: Read

        https://docs.aws.amazon.com/appflow/latest/userguide/identity-access-management.html#appflow-api-actions

        :stability: experimental
        '''
        return typing.cast("Appflow", jsii.invoke(self, "toListConnectorFields", []))

    @jsii.member(jsii_name="toListConnectors")
    def to_list_connectors(self) -> "Appflow":
        '''(experimental) Grants permission to list all connectors supported in Amazon AppFlow.

        Access Level: List

        https://docs.aws.amazon.com/appflow/1.0/APIReference/API_ListConnectors.html

        :stability: experimental
        '''
        return typing.cast("Appflow", jsii.invoke(self, "toListConnectors", []))

    @jsii.member(jsii_name="toListFlows")
    def to_list_flows(self) -> "Appflow":
        '''(experimental) Grants permission to list all flows configured in Amazon AppFlow.

        Access Level: List

        https://docs.aws.amazon.com/appflow/1.0/APIReference/API_ListFlows.html

        :stability: experimental
        '''
        return typing.cast("Appflow", jsii.invoke(self, "toListFlows", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Appflow":
        '''(experimental) Grants permission to list tags for a flow.

        Access Level: Read

        https://docs.aws.amazon.com/appflow/1.0/APIReference/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("Appflow", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toRegisterConnector")
    def to_register_connector(self) -> "Appflow":
        '''(experimental) Grants permission to register an Amazon AppFlow connector.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/appflow/1.0/APIReference/API_RegisterConnector.html

        :stability: experimental
        '''
        return typing.cast("Appflow", jsii.invoke(self, "toRegisterConnector", []))

    @jsii.member(jsii_name="toRunFlow")
    def to_run_flow(self) -> "Appflow":
        '''(experimental) Grants permission to run a flow configured in Amazon AppFlow (Console Only).

        Access Level: Write

        https://docs.aws.amazon.com/appflow/latest/userguide/identity-access-management.html#appflow-api-actions

        :stability: experimental
        '''
        return typing.cast("Appflow", jsii.invoke(self, "toRunFlow", []))

    @jsii.member(jsii_name="toStartFlow")
    def to_start_flow(self) -> "Appflow":
        '''(experimental) Grants permission to activate (for scheduled and event-triggered flows) or run (for on-demand flows) a flow configured in Amazon AppFlow.

        Access Level: Write

        https://docs.aws.amazon.com/appflow/1.0/APIReference/API_StartFlow.html

        :stability: experimental
        '''
        return typing.cast("Appflow", jsii.invoke(self, "toStartFlow", []))

    @jsii.member(jsii_name="toStopFlow")
    def to_stop_flow(self) -> "Appflow":
        '''(experimental) Grants permission to deactivate a scheduled or event-triggered flow configured in Amazon AppFlow.

        Access Level: Write

        https://docs.aws.amazon.com/appflow/1.0/APIReference/API_StopFlow.html

        :stability: experimental
        '''
        return typing.cast("Appflow", jsii.invoke(self, "toStopFlow", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Appflow":
        '''(experimental) Grants permission to tag a flow.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/appflow/1.0/APIReference/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("Appflow", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUnRegisterConnector")
    def to_un_register_connector(self) -> "Appflow":
        '''(experimental) Grants permission to un-register a connector in Amazon AppFlow.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/appflow/1.0/APIReference/API_UnregisterConnector.html

        :stability: experimental
        '''
        return typing.cast("Appflow", jsii.invoke(self, "toUnRegisterConnector", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Appflow":
        '''(experimental) Grants permission to untag a flow.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/appflow/1.0/APIReference/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("Appflow", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateConnectorProfile")
    def to_update_connector_profile(self) -> "Appflow":
        '''(experimental) Grants permission to update a login profile configured in Amazon AppFlow.

        Access Level: Write

        https://docs.aws.amazon.com/appflow/1.0/APIReference/API_UpdateConnectorProfile.html

        :stability: experimental
        '''
        return typing.cast("Appflow", jsii.invoke(self, "toUpdateConnectorProfile", []))

    @jsii.member(jsii_name="toUpdateConnectorRegistration")
    def to_update_connector_registration(self) -> "Appflow":
        '''(experimental) Grants permission to update a registered connector configured in Amazon AppFlow.

        Access Level: Write

        https://docs.aws.amazon.com/appflow/1.0/APIReference/API_UpdateConnectorRegistration.html

        :stability: experimental
        '''
        return typing.cast("Appflow", jsii.invoke(self, "toUpdateConnectorRegistration", []))

    @jsii.member(jsii_name="toUpdateFlow")
    def to_update_flow(self) -> "Appflow":
        '''(experimental) Grants permission to update a flow configured in Amazon AppFlow.

        Access Level: Write

        https://docs.aws.amazon.com/appflow/1.0/APIReference/API_UpdateFlow.html

        :stability: experimental
        '''
        return typing.cast("Appflow", jsii.invoke(self, "toUpdateFlow", []))

    @jsii.member(jsii_name="toUseConnectorProfile")
    def to_use_connector_profile(self) -> "Appflow":
        '''(experimental) Grants permission to use a connector profile while creating a flow in Amazon AppFlow.

        Access Level: Write

        :stability: experimental
        '''
        return typing.cast("Appflow", jsii.invoke(self, "toUseConnectorProfile", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2920868cd4ba5b70e717d15b690b04ddd13ea92cb3b7761f64e24e609bb96179)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4124692277ebe800a6d0df4fd9cdc8ffe476d52bbabf00599368840250e40cde)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class ApplicationAutoscaling(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.ApplicationAutoscaling",
):
    '''(experimental) Statement provider for service `application-autoscaling <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsapplicationautoscaling.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `application-autoscaling <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsapplicationautoscaling.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="toDeleteScalingPolicy")
    def to_delete_scaling_policy(self) -> "ApplicationAutoscaling":
        '''(experimental) Grants permission to delete a scaling policy.

        Access Level: Write

        https://docs.aws.amazon.com/autoscaling/application/APIReference/API_DeleteScalingPolicy.html

        :stability: experimental
        '''
        return typing.cast("ApplicationAutoscaling", jsii.invoke(self, "toDeleteScalingPolicy", []))

    @jsii.member(jsii_name="toDeleteScheduledAction")
    def to_delete_scheduled_action(self) -> "ApplicationAutoscaling":
        '''(experimental) Grants permission to delete a scheduled action.

        Access Level: Write

        https://docs.aws.amazon.com/autoscaling/application/APIReference/API_DeleteScheduledAction.html

        :stability: experimental
        '''
        return typing.cast("ApplicationAutoscaling", jsii.invoke(self, "toDeleteScheduledAction", []))

    @jsii.member(jsii_name="toDeregisterScalableTarget")
    def to_deregister_scalable_target(self) -> "ApplicationAutoscaling":
        '''(experimental) Grants permission to deregister a scalable target.

        Access Level: Write

        https://docs.aws.amazon.com/autoscaling/application/APIReference/API_DeregisterScalableTarget.html

        :stability: experimental
        '''
        return typing.cast("ApplicationAutoscaling", jsii.invoke(self, "toDeregisterScalableTarget", []))

    @jsii.member(jsii_name="toDescribeScalableTargets")
    def to_describe_scalable_targets(self) -> "ApplicationAutoscaling":
        '''(experimental) Grants permission to describe one or more scalable targets in the specified namespace.

        Access Level: Read

        https://docs.aws.amazon.com/autoscaling/application/APIReference/API_DescribeScalableTargets.html

        :stability: experimental
        '''
        return typing.cast("ApplicationAutoscaling", jsii.invoke(self, "toDescribeScalableTargets", []))

    @jsii.member(jsii_name="toDescribeScalingActivities")
    def to_describe_scaling_activities(self) -> "ApplicationAutoscaling":
        '''(experimental) Grants permission to describe a set of scaling activities or all scaling activities in the specified namespace.

        Access Level: Read

        https://docs.aws.amazon.com/autoscaling/application/APIReference/API_DescribeScalingActivities.html

        :stability: experimental
        '''
        return typing.cast("ApplicationAutoscaling", jsii.invoke(self, "toDescribeScalingActivities", []))

    @jsii.member(jsii_name="toDescribeScalingPolicies")
    def to_describe_scaling_policies(self) -> "ApplicationAutoscaling":
        '''(experimental) Grants permission to describe a set of scaling policies or all scaling policies in the specified namespace.

        Access Level: Read

        https://docs.aws.amazon.com/autoscaling/application/APIReference/API_DescribeScalingPolicies.html

        :stability: experimental
        '''
        return typing.cast("ApplicationAutoscaling", jsii.invoke(self, "toDescribeScalingPolicies", []))

    @jsii.member(jsii_name="toDescribeScheduledActions")
    def to_describe_scheduled_actions(self) -> "ApplicationAutoscaling":
        '''(experimental) Grants permission to describe a set of scheduled actions or all scheduled actions in the specified namespace.

        Access Level: Read

        https://docs.aws.amazon.com/autoscaling/application/APIReference/API_DescribeScheduledActions.html

        :stability: experimental
        '''
        return typing.cast("ApplicationAutoscaling", jsii.invoke(self, "toDescribeScheduledActions", []))

    @jsii.member(jsii_name="toPutScalingPolicy")
    def to_put_scaling_policy(self) -> "ApplicationAutoscaling":
        '''(experimental) Grants permission to create and update a scaling policy for a scalable target.

        Access Level: Write

        https://docs.aws.amazon.com/autoscaling/application/APIReference/API_PutScalingPolicy.html

        :stability: experimental
        '''
        return typing.cast("ApplicationAutoscaling", jsii.invoke(self, "toPutScalingPolicy", []))

    @jsii.member(jsii_name="toPutScheduledAction")
    def to_put_scheduled_action(self) -> "ApplicationAutoscaling":
        '''(experimental) Grants permission to create and update a scheduled action for a scalable target.

        Access Level: Write

        https://docs.aws.amazon.com/autoscaling/application/APIReference/API_PutScheduledAction.html

        :stability: experimental
        '''
        return typing.cast("ApplicationAutoscaling", jsii.invoke(self, "toPutScheduledAction", []))

    @jsii.member(jsii_name="toRegisterScalableTarget")
    def to_register_scalable_target(self) -> "ApplicationAutoscaling":
        '''(experimental) Grants permission to register AWS or custom resources as scalable targets with Application Auto Scaling and to update configuration parameters used to manage a scalable target.

        Access Level: Write

        https://docs.aws.amazon.com/autoscaling/application/APIReference/API_RegisterScalableTarget.html

        :stability: experimental
        '''
        return typing.cast("ApplicationAutoscaling", jsii.invoke(self, "toRegisterScalableTarget", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__01683d8b1354bb823bd87ec31d5e26676eed3bb3c42e2ff15034013a0ee0d9e7)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__55bd072152c03875196038590f1aa3af1e136edd17b862b19468180ee16d9ff9)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class ApplicationCostProfiler(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.ApplicationCostProfiler",
):
    '''(experimental) Statement provider for service `application-cost-profiler <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsapplicationcostprofilerservice.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `application-cost-profiler <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsapplicationcostprofilerservice.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="toDeleteReportDefinition")
    def to_delete_report_definition(self) -> "ApplicationCostProfiler":
        '''(experimental) Grants permission to delete the configuration with specific Application Cost Profiler Report thereby effectively disabling report generation.

        Access Level: Write

        https://docs.aws.amazon.com/application-cost-profiler/latest/APIReference/API_DeleteReportDefinition.html

        :stability: experimental
        '''
        return typing.cast("ApplicationCostProfiler", jsii.invoke(self, "toDeleteReportDefinition", []))

    @jsii.member(jsii_name="toGetReportDefinition")
    def to_get_report_definition(self) -> "ApplicationCostProfiler":
        '''(experimental) Grants permission to fetch the configuration with specific Application Cost Profiler Report request.

        Access Level: Read

        https://docs.aws.amazon.com/application-cost-profiler/latest/APIReference/API_GetReportDefinition.html

        :stability: experimental
        '''
        return typing.cast("ApplicationCostProfiler", jsii.invoke(self, "toGetReportDefinition", []))

    @jsii.member(jsii_name="toImportApplicationUsage")
    def to_import_application_usage(self) -> "ApplicationCostProfiler":
        '''(experimental) Grants permission to import the application usage from S3.

        Access Level: Write

        https://docs.aws.amazon.com/application-cost-profiler/latest/APIReference/API_ImportApplicationUsage.html

        :stability: experimental
        '''
        return typing.cast("ApplicationCostProfiler", jsii.invoke(self, "toImportApplicationUsage", []))

    @jsii.member(jsii_name="toListReportDefinitions")
    def to_list_report_definitions(self) -> "ApplicationCostProfiler":
        '''(experimental) Grants permission to get a list of the different Application Cost Profiler Report configurations they have created.

        Access Level: Read

        https://docs.aws.amazon.com/application-cost-profiler/latest/APIReference/API_ListReportDefinitions.html

        :stability: experimental
        '''
        return typing.cast("ApplicationCostProfiler", jsii.invoke(self, "toListReportDefinitions", []))

    @jsii.member(jsii_name="toPutReportDefinition")
    def to_put_report_definition(self) -> "ApplicationCostProfiler":
        '''(experimental) Grants permission to create Application Cost Profiler Report configurations.

        Access Level: Write

        https://docs.aws.amazon.com/application-cost-profiler/latest/APIReference/API_PutReportDefinition.html

        :stability: experimental
        '''
        return typing.cast("ApplicationCostProfiler", jsii.invoke(self, "toPutReportDefinition", []))

    @jsii.member(jsii_name="toUpdateReportDefinition")
    def to_update_report_definition(self) -> "ApplicationCostProfiler":
        '''(experimental) Grants permission to update an existing Application Cost Profiler Report configuration.

        Access Level: Write

        https://docs.aws.amazon.com/application-cost-profiler/latest/APIReference/API_UpdateReportDefinition.html

        :stability: experimental
        '''
        return typing.cast("ApplicationCostProfiler", jsii.invoke(self, "toUpdateReportDefinition", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8221537e9c00ab89c1cdd9fee9f50cc5c52af10bfa17150613f3eb5c09dea3b9)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f8eb56d3b7bbf37040a98a8af9122bb18a1b998fca813211bebd38b221cfe174)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Applicationinsights(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Applicationinsights",
):
    '''(experimental) Statement provider for service `applicationinsights <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazoncloudwatchapplicationinsights.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `applicationinsights <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazoncloudwatchapplicationinsights.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="toCreateApplication")
    def to_create_application(self) -> "Applicationinsights":
        '''(experimental) Grants permission to create an application from a resource group.

        Access Level: Write

        https://docs.aws.amazon.com/cloudwatch/latest/APIReference/API_CreateApplication.html

        :stability: experimental
        '''
        return typing.cast("Applicationinsights", jsii.invoke(self, "toCreateApplication", []))

    @jsii.member(jsii_name="toCreateComponent")
    def to_create_component(self) -> "Applicationinsights":
        '''(experimental) Grants permission to create a component from a group of resources.

        Access Level: Write

        https://docs.aws.amazon.com/cloudwatch/latest/APIReference/API_CreateComponent.html

        :stability: experimental
        '''
        return typing.cast("Applicationinsights", jsii.invoke(self, "toCreateComponent", []))

    @jsii.member(jsii_name="toCreateLogPattern")
    def to_create_log_pattern(self) -> "Applicationinsights":
        '''(experimental) Grants permission to create log a pattern.

        Access Level: Write

        https://docs.aws.amazon.com/cloudwatch/latest/APIReference/API_CreateLogPattern.html

        :stability: experimental
        '''
        return typing.cast("Applicationinsights", jsii.invoke(self, "toCreateLogPattern", []))

    @jsii.member(jsii_name="toDeleteApplication")
    def to_delete_application(self) -> "Applicationinsights":
        '''(experimental) Grants permission to delete an application.

        Access Level: Write

        https://docs.aws.amazon.com/cloudwatch/latest/APIReference/API_DeleteApplication.html

        :stability: experimental
        '''
        return typing.cast("Applicationinsights", jsii.invoke(self, "toDeleteApplication", []))

    @jsii.member(jsii_name="toDeleteComponent")
    def to_delete_component(self) -> "Applicationinsights":
        '''(experimental) Grants permission to delete a component.

        Access Level: Write

        https://docs.aws.amazon.com/cloudwatch/latest/APIReference/API_DeleteComponent.html

        :stability: experimental
        '''
        return typing.cast("Applicationinsights", jsii.invoke(self, "toDeleteComponent", []))

    @jsii.member(jsii_name="toDeleteLogPattern")
    def to_delete_log_pattern(self) -> "Applicationinsights":
        '''(experimental) Grants permission to delete a log pattern.

        Access Level: Write

        https://docs.aws.amazon.com/cloudwatch/latest/APIReference/API_DeleteLogPattern.html

        :stability: experimental
        '''
        return typing.cast("Applicationinsights", jsii.invoke(self, "toDeleteLogPattern", []))

    @jsii.member(jsii_name="toDescribeApplication")
    def to_describe_application(self) -> "Applicationinsights":
        '''(experimental) Grants permission to describe an application.

        Access Level: Read

        https://docs.aws.amazon.com/cloudwatch/latest/APIReference/API_DescribeApplication.html

        :stability: experimental
        '''
        return typing.cast("Applicationinsights", jsii.invoke(self, "toDescribeApplication", []))

    @jsii.member(jsii_name="toDescribeComponent")
    def to_describe_component(self) -> "Applicationinsights":
        '''(experimental) Grants permission to describe a component.

        Access Level: Read

        https://docs.aws.amazon.com/cloudwatch/latest/APIReference/API_DescribeComponent.html

        :stability: experimental
        '''
        return typing.cast("Applicationinsights", jsii.invoke(self, "toDescribeComponent", []))

    @jsii.member(jsii_name="toDescribeComponentConfiguration")
    def to_describe_component_configuration(self) -> "Applicationinsights":
        '''(experimental) Grants permission to describe a component's configuration.

        Access Level: Read

        https://docs.aws.amazon.com/cloudwatch/latest/APIReference/API_DescribeComponentConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Applicationinsights", jsii.invoke(self, "toDescribeComponentConfiguration", []))

    @jsii.member(jsii_name="toDescribeComponentConfigurationRecommendation")
    def to_describe_component_configuration_recommendation(
        self,
    ) -> "Applicationinsights":
        '''(experimental) Grants permission to describe the recommended application component configuration.

        Access Level: Read

        https://docs.aws.amazon.com/cloudwatch/latest/APIReference/API_DescribeComponentConfigurationRecommendation.html

        :stability: experimental
        '''
        return typing.cast("Applicationinsights", jsii.invoke(self, "toDescribeComponentConfigurationRecommendation", []))

    @jsii.member(jsii_name="toDescribeLogPattern")
    def to_describe_log_pattern(self) -> "Applicationinsights":
        '''(experimental) Grants permission to describe a log pattern.

        Access Level: Read

        https://docs.aws.amazon.com/cloudwatch/latest/APIReference/API_DescribeLogPattern.html

        :stability: experimental
        '''
        return typing.cast("Applicationinsights", jsii.invoke(self, "toDescribeLogPattern", []))

    @jsii.member(jsii_name="toDescribeObservation")
    def to_describe_observation(self) -> "Applicationinsights":
        '''(experimental) Grants permission to describe an observation.

        Access Level: Read

        https://docs.aws.amazon.com/cloudwatch/latest/APIReference/API_DescribeObservation.html

        :stability: experimental
        '''
        return typing.cast("Applicationinsights", jsii.invoke(self, "toDescribeObservation", []))

    @jsii.member(jsii_name="toDescribeProblem")
    def to_describe_problem(self) -> "Applicationinsights":
        '''(experimental) Grants permission to describe a problem.

        Access Level: Read

        https://docs.aws.amazon.com/cloudwatch/latest/APIReference/API_DescribeProblem.html

        :stability: experimental
        '''
        return typing.cast("Applicationinsights", jsii.invoke(self, "toDescribeProblem", []))

    @jsii.member(jsii_name="toDescribeProblemObservations")
    def to_describe_problem_observations(self) -> "Applicationinsights":
        '''(experimental) Grants permission to describe the observation in a problem.

        Access Level: Read

        https://docs.aws.amazon.com/cloudwatch/latest/APIReference/API_DescribeProblemObservations.html

        :stability: experimental
        '''
        return typing.cast("Applicationinsights", jsii.invoke(self, "toDescribeProblemObservations", []))

    @jsii.member(jsii_name="toListApplications")
    def to_list_applications(self) -> "Applicationinsights":
        '''(experimental) Grants permission to list all applications.

        Access Level: List

        https://docs.aws.amazon.com/cloudwatch/latest/APIReference/API_ListApplications.html

        :stability: experimental
        '''
        return typing.cast("Applicationinsights", jsii.invoke(self, "toListApplications", []))

    @jsii.member(jsii_name="toListComponents")
    def to_list_components(self) -> "Applicationinsights":
        '''(experimental) Grants permission to list an application's components.

        Access Level: List

        https://docs.aws.amazon.com/cloudwatch/latest/APIReference/API_ListComponents.html

        :stability: experimental
        '''
        return typing.cast("Applicationinsights", jsii.invoke(self, "toListComponents", []))

    @jsii.member(jsii_name="toListConfigurationHistory")
    def to_list_configuration_history(self) -> "Applicationinsights":
        '''(experimental) Grants permission to list configuration history.

        Access Level: List

        https://docs.aws.amazon.com/cloudwatch/latest/APIReference/API_ListConfigurationHistory.html

        :stability: experimental
        '''
        return typing.cast("Applicationinsights", jsii.invoke(self, "toListConfigurationHistory", []))

    @jsii.member(jsii_name="toListLogPatterns")
    def to_list_log_patterns(self) -> "Applicationinsights":
        '''(experimental) Grants permission to list log patterns.

        Access Level: List

        https://docs.aws.amazon.com/cloudwatch/latest/APIReference/API_ListLogPatterns.html

        :stability: experimental
        '''
        return typing.cast("Applicationinsights", jsii.invoke(self, "toListLogPatterns", []))

    @jsii.member(jsii_name="toListLogPatternSets")
    def to_list_log_pattern_sets(self) -> "Applicationinsights":
        '''(experimental) Grants permission to list log pattern sets for an application.

        Access Level: List

        https://docs.aws.amazon.com/cloudwatch/latest/APIReference/API_ListLogPatternSets.html

        :stability: experimental
        '''
        return typing.cast("Applicationinsights", jsii.invoke(self, "toListLogPatternSets", []))

    @jsii.member(jsii_name="toListProblems")
    def to_list_problems(self) -> "Applicationinsights":
        '''(experimental) Grants permission to list the problems in an application.

        Access Level: List

        https://docs.aws.amazon.com/cloudwatch/latest/APIReference/API_ListProblems.html

        :stability: experimental
        '''
        return typing.cast("Applicationinsights", jsii.invoke(self, "toListProblems", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Applicationinsights":
        '''(experimental) Grants permission to list tags for the resource.

        Access Level: Read

        https://docs.aws.amazon.com/cloudwatch/latest/APIReference/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("Applicationinsights", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Applicationinsights":
        '''(experimental) Grants permission to tag a resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/cloudwatch/latest/APIReference/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("Applicationinsights", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Applicationinsights":
        '''(experimental) Grants permission to untag a resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/cloudwatch/latest/APIReference/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("Applicationinsights", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateApplication")
    def to_update_application(self) -> "Applicationinsights":
        '''(experimental) Grants permission to update an application.

        Access Level: Write

        https://docs.aws.amazon.com/cloudwatch/latest/APIReference/API_UpdateApplication.html

        :stability: experimental
        '''
        return typing.cast("Applicationinsights", jsii.invoke(self, "toUpdateApplication", []))

    @jsii.member(jsii_name="toUpdateComponent")
    def to_update_component(self) -> "Applicationinsights":
        '''(experimental) Grants permission to update a component.

        Access Level: Write

        https://docs.aws.amazon.com/cloudwatch/latest/APIReference/API_UpdateComponent.html

        :stability: experimental
        '''
        return typing.cast("Applicationinsights", jsii.invoke(self, "toUpdateComponent", []))

    @jsii.member(jsii_name="toUpdateComponentConfiguration")
    def to_update_component_configuration(self) -> "Applicationinsights":
        '''(experimental) Grants permission to update a component's configuration.

        Access Level: Write

        https://docs.aws.amazon.com/cloudwatch/latest/APIReference/API_UpdateComponentConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Applicationinsights", jsii.invoke(self, "toUpdateComponentConfiguration", []))

    @jsii.member(jsii_name="toUpdateLogPattern")
    def to_update_log_pattern(self) -> "Applicationinsights":
        '''(experimental) Grants permission to update a log pattern.

        Access Level: Write

        https://docs.aws.amazon.com/cloudwatch/latest/APIReference/API_UpdateLogPattern.html

        :stability: experimental
        '''
        return typing.cast("Applicationinsights", jsii.invoke(self, "toUpdateLogPattern", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__713e8d583cf5ebe8be45b71437687fda9d1920064981fabe291de41ce95fb986)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__426faf2c6f45265b58ce4161b0212d940256e3ac6bf9db5d94c3162c0c22e5b1)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Appmesh(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Appmesh",
):
    '''(experimental) Statement provider for service `appmesh <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsappmesh.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `appmesh <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsappmesh.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onGatewayRoute")
    def on_gateway_route(
        self,
        mesh_name: builtins.str,
        virtual_gateway_name: builtins.str,
        gateway_route_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Appmesh":
        '''(experimental) Adds a resource of type gatewayRoute to the statement.

        https://docs.aws.amazon.com/app-mesh/latest/userguide/virtual_gateways.html

        :param mesh_name: - Identifier for the meshName.
        :param virtual_gateway_name: - Identifier for the virtualGatewayName.
        :param gateway_route_name: - Identifier for the gatewayRouteName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__231190776c5b848f6e9eeb1f208546606b4cf778ce236c16e07ea4caa8c0319d)
            check_type(argname="argument mesh_name", value=mesh_name, expected_type=type_hints["mesh_name"])
            check_type(argname="argument virtual_gateway_name", value=virtual_gateway_name, expected_type=type_hints["virtual_gateway_name"])
            check_type(argname="argument gateway_route_name", value=gateway_route_name, expected_type=type_hints["gateway_route_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Appmesh", jsii.invoke(self, "onGatewayRoute", [mesh_name, virtual_gateway_name, gateway_route_name, account, region, partition]))

    @jsii.member(jsii_name="onMesh")
    def on_mesh(
        self,
        mesh_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Appmesh":
        '''(experimental) Adds a resource of type mesh to the statement.

        https://docs.aws.amazon.com/app-mesh/latest/userguide/meshes.html

        :param mesh_name: - Identifier for the meshName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__00d456e1cf4aa014ad97a81b1a2b327fecfb1783ed7b39523961eac31bfdc05f)
            check_type(argname="argument mesh_name", value=mesh_name, expected_type=type_hints["mesh_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Appmesh", jsii.invoke(self, "onMesh", [mesh_name, account, region, partition]))

    @jsii.member(jsii_name="onRoute")
    def on_route(
        self,
        mesh_name: builtins.str,
        virtual_router_name: builtins.str,
        route_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Appmesh":
        '''(experimental) Adds a resource of type route to the statement.

        https://docs.aws.amazon.com/app-mesh/latest/userguide/routes.html

        :param mesh_name: - Identifier for the meshName.
        :param virtual_router_name: - Identifier for the virtualRouterName.
        :param route_name: - Identifier for the routeName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__77071ffc2064aca8fd2c1e13899e4a69cdc694f5335e91bd515d35cc299db9cc)
            check_type(argname="argument mesh_name", value=mesh_name, expected_type=type_hints["mesh_name"])
            check_type(argname="argument virtual_router_name", value=virtual_router_name, expected_type=type_hints["virtual_router_name"])
            check_type(argname="argument route_name", value=route_name, expected_type=type_hints["route_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Appmesh", jsii.invoke(self, "onRoute", [mesh_name, virtual_router_name, route_name, account, region, partition]))

    @jsii.member(jsii_name="onVirtualGateway")
    def on_virtual_gateway(
        self,
        mesh_name: builtins.str,
        virtual_gateway_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Appmesh":
        '''(experimental) Adds a resource of type virtualGateway to the statement.

        https://docs.aws.amazon.com/app-mesh/latest/userguide/virtual_gateways.html

        :param mesh_name: - Identifier for the meshName.
        :param virtual_gateway_name: - Identifier for the virtualGatewayName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6ff71a5a4e7bea822f3ebc01e7fc5769a8ddc0695738728b63fd1f46e57a0a64)
            check_type(argname="argument mesh_name", value=mesh_name, expected_type=type_hints["mesh_name"])
            check_type(argname="argument virtual_gateway_name", value=virtual_gateway_name, expected_type=type_hints["virtual_gateway_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Appmesh", jsii.invoke(self, "onVirtualGateway", [mesh_name, virtual_gateway_name, account, region, partition]))

    @jsii.member(jsii_name="onVirtualNode")
    def on_virtual_node(
        self,
        mesh_name: builtins.str,
        virtual_node_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Appmesh":
        '''(experimental) Adds a resource of type virtualNode to the statement.

        https://docs.aws.amazon.com/app-mesh/latest/userguide/virtual_nodes.html

        :param mesh_name: - Identifier for the meshName.
        :param virtual_node_name: - Identifier for the virtualNodeName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9e2d764bf0bc4a2518a182ed9e968ef84fb3030babcb08f5bec610046ee8ac2d)
            check_type(argname="argument mesh_name", value=mesh_name, expected_type=type_hints["mesh_name"])
            check_type(argname="argument virtual_node_name", value=virtual_node_name, expected_type=type_hints["virtual_node_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Appmesh", jsii.invoke(self, "onVirtualNode", [mesh_name, virtual_node_name, account, region, partition]))

    @jsii.member(jsii_name="onVirtualRouter")
    def on_virtual_router(
        self,
        mesh_name: builtins.str,
        virtual_router_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Appmesh":
        '''(experimental) Adds a resource of type virtualRouter to the statement.

        https://docs.aws.amazon.com/app-mesh/latest/userguide/virtual_routers.html

        :param mesh_name: - Identifier for the meshName.
        :param virtual_router_name: - Identifier for the virtualRouterName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b0ebb0e66bf1fe965e5af717341693e4065fe179ab16267e287766fe21dedcef)
            check_type(argname="argument mesh_name", value=mesh_name, expected_type=type_hints["mesh_name"])
            check_type(argname="argument virtual_router_name", value=virtual_router_name, expected_type=type_hints["virtual_router_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Appmesh", jsii.invoke(self, "onVirtualRouter", [mesh_name, virtual_router_name, account, region, partition]))

    @jsii.member(jsii_name="onVirtualService")
    def on_virtual_service(
        self,
        mesh_name: builtins.str,
        virtual_service_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Appmesh":
        '''(experimental) Adds a resource of type virtualService to the statement.

        https://docs.aws.amazon.com/app-mesh/latest/userguide/virtual_services.html

        :param mesh_name: - Identifier for the meshName.
        :param virtual_service_name: - Identifier for the virtualServiceName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__effde181ecfe382881074fee9e62d1bd4ae406b6c7f3eaf60db55e8e72e04c3a)
            check_type(argname="argument mesh_name", value=mesh_name, expected_type=type_hints["mesh_name"])
            check_type(argname="argument virtual_service_name", value=virtual_service_name, expected_type=type_hints["virtual_service_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Appmesh", jsii.invoke(self, "onVirtualService", [mesh_name, virtual_service_name, account, region, partition]))

    @jsii.member(jsii_name="toCreateGatewayRoute")
    def to_create_gateway_route(self) -> "Appmesh":
        '''(experimental) Grants permission to create a gateway route that is associated with a virtual gateway.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/app-mesh/latest/APIReference/API_CreateGatewayRoute.html

        :stability: experimental
        '''
        return typing.cast("Appmesh", jsii.invoke(self, "toCreateGatewayRoute", []))

    @jsii.member(jsii_name="toCreateMesh")
    def to_create_mesh(self) -> "Appmesh":
        '''(experimental) Grants permission to create a service mesh.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/app-mesh/latest/APIReference/API_CreateMesh.html

        :stability: experimental
        '''
        return typing.cast("Appmesh", jsii.invoke(self, "toCreateMesh", []))

    @jsii.member(jsii_name="toCreateRoute")
    def to_create_route(self) -> "Appmesh":
        '''(experimental) Grants permission to create a route that is associated with a virtual router.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/app-mesh/latest/APIReference/API_CreateRoute.html

        :stability: experimental
        '''
        return typing.cast("Appmesh", jsii.invoke(self, "toCreateRoute", []))

    @jsii.member(jsii_name="toCreateVirtualGateway")
    def to_create_virtual_gateway(self) -> "Appmesh":
        '''(experimental) Grants permission to create a virtual gateway within a service mesh.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/app-mesh/latest/APIReference/API_CreateVirtualGateway.html

        :stability: experimental
        '''
        return typing.cast("Appmesh", jsii.invoke(self, "toCreateVirtualGateway", []))

    @jsii.member(jsii_name="toCreateVirtualNode")
    def to_create_virtual_node(self) -> "Appmesh":
        '''(experimental) Grants permission to create a virtual node within a service mesh.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/app-mesh/latest/APIReference/API_CreateVirtualNode.html

        :stability: experimental
        '''
        return typing.cast("Appmesh", jsii.invoke(self, "toCreateVirtualNode", []))

    @jsii.member(jsii_name="toCreateVirtualRouter")
    def to_create_virtual_router(self) -> "Appmesh":
        '''(experimental) Grants permission to create a virtual router within a service mesh.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/app-mesh/latest/APIReference/API_CreateVirtualRouter.html

        :stability: experimental
        '''
        return typing.cast("Appmesh", jsii.invoke(self, "toCreateVirtualRouter", []))

    @jsii.member(jsii_name="toCreateVirtualService")
    def to_create_virtual_service(self) -> "Appmesh":
        '''(experimental) Grants permission to create a virtual service within a service mesh.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/app-mesh/latest/APIReference/API_CreateVirtualService.html

        :stability: experimental
        '''
        return typing.cast("Appmesh", jsii.invoke(self, "toCreateVirtualService", []))

    @jsii.member(jsii_name="toDeleteGatewayRoute")
    def to_delete_gateway_route(self) -> "Appmesh":
        '''(experimental) Grants permission to delete an existing gateway route.

        Access Level: Write

        https://docs.aws.amazon.com/app-mesh/latest/APIReference/API_DeleteGatewayRoute.html

        :stability: experimental
        '''
        return typing.cast("Appmesh", jsii.invoke(self, "toDeleteGatewayRoute", []))

    @jsii.member(jsii_name="toDeleteMesh")
    def to_delete_mesh(self) -> "Appmesh":
        '''(experimental) Grants permission to delete an existing service mesh.

        Access Level: Write

        https://docs.aws.amazon.com/app-mesh/latest/APIReference/API_DeleteMesh.html

        :stability: experimental
        '''
        return typing.cast("Appmesh", jsii.invoke(self, "toDeleteMesh", []))

    @jsii.member(jsii_name="toDeleteRoute")
    def to_delete_route(self) -> "Appmesh":
        '''(experimental) Grants permission to delete an existing route.

        Access Level: Write

        https://docs.aws.amazon.com/app-mesh/latest/APIReference/API_DeleteRoute.html

        :stability: experimental
        '''
        return typing.cast("Appmesh", jsii.invoke(self, "toDeleteRoute", []))

    @jsii.member(jsii_name="toDeleteVirtualGateway")
    def to_delete_virtual_gateway(self) -> "Appmesh":
        '''(experimental) Grants permission to delete an existing virtual gateway.

        Access Level: Write

        https://docs.aws.amazon.com/app-mesh/latest/APIReference/API_DeleteVirtualGateway.html

        :stability: experimental
        '''
        return typing.cast("Appmesh", jsii.invoke(self, "toDeleteVirtualGateway", []))

    @jsii.member(jsii_name="toDeleteVirtualNode")
    def to_delete_virtual_node(self) -> "Appmesh":
        '''(experimental) Grants permission to delete an existing virtual node.

        Access Level: Write

        https://docs.aws.amazon.com/app-mesh/latest/APIReference/API_DeleteVirtualNode.html

        :stability: experimental
        '''
        return typing.cast("Appmesh", jsii.invoke(self, "toDeleteVirtualNode", []))

    @jsii.member(jsii_name="toDeleteVirtualRouter")
    def to_delete_virtual_router(self) -> "Appmesh":
        '''(experimental) Grants permission to delete an existing virtual router.

        Access Level: Write

        https://docs.aws.amazon.com/app-mesh/latest/APIReference/API_DeleteVirtualRouter.html

        :stability: experimental
        '''
        return typing.cast("Appmesh", jsii.invoke(self, "toDeleteVirtualRouter", []))

    @jsii.member(jsii_name="toDeleteVirtualService")
    def to_delete_virtual_service(self) -> "Appmesh":
        '''(experimental) Grants permission to delete an existing virtual service.

        Access Level: Write

        https://docs.aws.amazon.com/app-mesh/latest/APIReference/API_DeleteVirtualService.html

        :stability: experimental
        '''
        return typing.cast("Appmesh", jsii.invoke(self, "toDeleteVirtualService", []))

    @jsii.member(jsii_name="toDescribeGatewayRoute")
    def to_describe_gateway_route(self) -> "Appmesh":
        '''(experimental) Grants permission to describe an existing gateway route.

        Access Level: Read

        https://docs.aws.amazon.com/app-mesh/latest/APIReference/API_DescribeGatewayRoute.html

        :stability: experimental
        '''
        return typing.cast("Appmesh", jsii.invoke(self, "toDescribeGatewayRoute", []))

    @jsii.member(jsii_name="toDescribeMesh")
    def to_describe_mesh(self) -> "Appmesh":
        '''(experimental) Grants permission to describe an existing service mesh.

        Access Level: Read

        https://docs.aws.amazon.com/app-mesh/latest/APIReference/API_DescribeMesh.html

        :stability: experimental
        '''
        return typing.cast("Appmesh", jsii.invoke(self, "toDescribeMesh", []))

    @jsii.member(jsii_name="toDescribeRoute")
    def to_describe_route(self) -> "Appmesh":
        '''(experimental) Grants permission to describe an existing route.

        Access Level: Read

        https://docs.aws.amazon.com/app-mesh/latest/APIReference/API_DescribeRoute.html

        :stability: experimental
        '''
        return typing.cast("Appmesh", jsii.invoke(self, "toDescribeRoute", []))

    @jsii.member(jsii_name="toDescribeVirtualGateway")
    def to_describe_virtual_gateway(self) -> "Appmesh":
        '''(experimental) Grants permission to describe an existing virtual gateway.

        Access Level: Read

        https://docs.aws.amazon.com/app-mesh/latest/APIReference/API_DescribeVirtualGateway.html

        :stability: experimental
        '''
        return typing.cast("Appmesh", jsii.invoke(self, "toDescribeVirtualGateway", []))

    @jsii.member(jsii_name="toDescribeVirtualNode")
    def to_describe_virtual_node(self) -> "Appmesh":
        '''(experimental) Grants permission to describe an existing virtual node.

        Access Level: Read

        https://docs.aws.amazon.com/app-mesh/latest/APIReference/API_DescribeVirtualNode.html

        :stability: experimental
        '''
        return typing.cast("Appmesh", jsii.invoke(self, "toDescribeVirtualNode", []))

    @jsii.member(jsii_name="toDescribeVirtualRouter")
    def to_describe_virtual_router(self) -> "Appmesh":
        '''(experimental) Grants permission to describe an existing virtual router.

        Access Level: Read

        https://docs.aws.amazon.com/app-mesh/latest/APIReference/API_DescribeVirtualRouter.html

        :stability: experimental
        '''
        return typing.cast("Appmesh", jsii.invoke(self, "toDescribeVirtualRouter", []))

    @jsii.member(jsii_name="toDescribeVirtualService")
    def to_describe_virtual_service(self) -> "Appmesh":
        '''(experimental) Grants permission to describe an existing virtual service.

        Access Level: Read

        https://docs.aws.amazon.com/app-mesh/latest/APIReference/API_DescribeVirtualService.html

        :stability: experimental
        '''
        return typing.cast("Appmesh", jsii.invoke(self, "toDescribeVirtualService", []))

    @jsii.member(jsii_name="toListGatewayRoutes")
    def to_list_gateway_routes(self) -> "Appmesh":
        '''(experimental) Grants permission to list existing gateway routes in a service mesh.

        Access Level: List

        https://docs.aws.amazon.com/app-mesh/latest/APIReference/API_ListGatewayRoutes.html

        :stability: experimental
        '''
        return typing.cast("Appmesh", jsii.invoke(self, "toListGatewayRoutes", []))

    @jsii.member(jsii_name="toListMeshes")
    def to_list_meshes(self) -> "Appmesh":
        '''(experimental) Grants permission to list existing service meshes.

        Access Level: List

        https://docs.aws.amazon.com/app-mesh/latest/APIReference/API_ListMeshes.html

        :stability: experimental
        '''
        return typing.cast("Appmesh", jsii.invoke(self, "toListMeshes", []))

    @jsii.member(jsii_name="toListRoutes")
    def to_list_routes(self) -> "Appmesh":
        '''(experimental) Grants permission to list existing routes in a service mesh.

        Access Level: List

        https://docs.aws.amazon.com/app-mesh/latest/APIReference/API_ListRoutes.html

        :stability: experimental
        '''
        return typing.cast("Appmesh", jsii.invoke(self, "toListRoutes", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Appmesh":
        '''(experimental) Grants permission to list the tags for an App Mesh resource.

        Access Level: List

        https://docs.aws.amazon.com/app-mesh/latest/APIReference/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("Appmesh", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toListVirtualGateways")
    def to_list_virtual_gateways(self) -> "Appmesh":
        '''(experimental) Grants permission to list existing virtual gateways in a service mesh.

        Access Level: List

        https://docs.aws.amazon.com/app-mesh/latest/APIReference/API_ListVirtualGateways.html

        :stability: experimental
        '''
        return typing.cast("Appmesh", jsii.invoke(self, "toListVirtualGateways", []))

    @jsii.member(jsii_name="toListVirtualNodes")
    def to_list_virtual_nodes(self) -> "Appmesh":
        '''(experimental) Grants permission to list existing virtual nodes.

        Access Level: List

        https://docs.aws.amazon.com/app-mesh/latest/APIReference/API_ListVirtualNodes.html

        :stability: experimental
        '''
        return typing.cast("Appmesh", jsii.invoke(self, "toListVirtualNodes", []))

    @jsii.member(jsii_name="toListVirtualRouters")
    def to_list_virtual_routers(self) -> "Appmesh":
        '''(experimental) Grants permission to list existing virtual routers in a service mesh.

        Access Level: List

        https://docs.aws.amazon.com/app-mesh/latest/APIReference/API_ListVirtualRouters.html

        :stability: experimental
        '''
        return typing.cast("Appmesh", jsii.invoke(self, "toListVirtualRouters", []))

    @jsii.member(jsii_name="toListVirtualServices")
    def to_list_virtual_services(self) -> "Appmesh":
        '''(experimental) Grants permission to list existing virtual services in a service mesh.

        Access Level: List

        https://docs.aws.amazon.com/app-mesh/latest/APIReference/API_ListVirtualServices.html

        :stability: experimental
        '''
        return typing.cast("Appmesh", jsii.invoke(self, "toListVirtualServices", []))

    @jsii.member(jsii_name="toStreamAggregatedResources")
    def to_stream_aggregated_resources(self) -> "Appmesh":
        '''(experimental) Grants permission to receive streamed resources for an App Mesh endpoint (VirtualNode/VirtualGateway).

        Access Level: Read

        https://docs.aws.amazon.com/app-mesh/latest/userguide/envoy.html

        :stability: experimental
        '''
        return typing.cast("Appmesh", jsii.invoke(self, "toStreamAggregatedResources", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Appmesh":
        '''(experimental) Grants permission to tag a resource with a specified resourceArn.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/app-mesh/latest/APIReference/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("Appmesh", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Appmesh":
        '''(experimental) Grants permission to delete a tag from a resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/app-mesh/latest/APIReference/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("Appmesh", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateGatewayRoute")
    def to_update_gateway_route(self) -> "Appmesh":
        '''(experimental) Grants permission to update an existing gateway route for a specified service mesh and virtual gateway.

        Access Level: Write

        https://docs.aws.amazon.com/app-mesh/latest/APIReference/API_UpdateGatewayRoute.html

        :stability: experimental
        '''
        return typing.cast("Appmesh", jsii.invoke(self, "toUpdateGatewayRoute", []))

    @jsii.member(jsii_name="toUpdateMesh")
    def to_update_mesh(self) -> "Appmesh":
        '''(experimental) Grants permission to update an existing service mesh.

        Access Level: Write

        https://docs.aws.amazon.com/app-mesh/latest/APIReference/API_UpdateMesh.html

        :stability: experimental
        '''
        return typing.cast("Appmesh", jsii.invoke(self, "toUpdateMesh", []))

    @jsii.member(jsii_name="toUpdateRoute")
    def to_update_route(self) -> "Appmesh":
        '''(experimental) Grants permission to update an existing route for a specified service mesh and virtual router.

        Access Level: Write

        https://docs.aws.amazon.com/app-mesh/latest/APIReference/API_UpdateRoute.html

        :stability: experimental
        '''
        return typing.cast("Appmesh", jsii.invoke(self, "toUpdateRoute", []))

    @jsii.member(jsii_name="toUpdateVirtualGateway")
    def to_update_virtual_gateway(self) -> "Appmesh":
        '''(experimental) Grants permission to update an existing virtual gateway in a specified service mesh.

        Access Level: Write

        https://docs.aws.amazon.com/app-mesh/latest/APIReference/API_UpdateVirtualGateway.html

        :stability: experimental
        '''
        return typing.cast("Appmesh", jsii.invoke(self, "toUpdateVirtualGateway", []))

    @jsii.member(jsii_name="toUpdateVirtualNode")
    def to_update_virtual_node(self) -> "Appmesh":
        '''(experimental) Grants permission to update an existing virtual node in a specified service mesh.

        Access Level: Write

        https://docs.aws.amazon.com/app-mesh/latest/APIReference/API_UpdateVirtualNode.html

        :stability: experimental
        '''
        return typing.cast("Appmesh", jsii.invoke(self, "toUpdateVirtualNode", []))

    @jsii.member(jsii_name="toUpdateVirtualRouter")
    def to_update_virtual_router(self) -> "Appmesh":
        '''(experimental) Grants permission to update an existing virtual router in a specified service mesh.

        Access Level: Write

        https://docs.aws.amazon.com/app-mesh/latest/APIReference/API_UpdateVirtualRouter.html

        :stability: experimental
        '''
        return typing.cast("Appmesh", jsii.invoke(self, "toUpdateVirtualRouter", []))

    @jsii.member(jsii_name="toUpdateVirtualService")
    def to_update_virtual_service(self) -> "Appmesh":
        '''(experimental) Grants permission to update an existing virtual service in a specified service mesh.

        Access Level: Write

        https://docs.aws.amazon.com/app-mesh/latest/APIReference/API_UpdateVirtualService.html

        :stability: experimental
        '''
        return typing.cast("Appmesh", jsii.invoke(self, "toUpdateVirtualService", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7824f4f644b7a08e78e6034c7fec845fe75027c5f0582fc667f25a3a27902b3e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fd051012d1679e0b3fcf07cd5a97a20cc79ea3fef0e04cab8b5e8a2850e80ee4)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class AppmeshPreview(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.AppmeshPreview",
):
    '''(experimental) Statement provider for service `appmesh-preview <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsappmeshpreview.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `appmesh-preview <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsappmeshpreview.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onGatewayRoute")
    def on_gateway_route(
        self,
        mesh_name: builtins.str,
        virtual_gateway_name: builtins.str,
        gateway_route_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "AppmeshPreview":
        '''(experimental) Adds a resource of type gatewayRoute to the statement.

        https://docs.aws.amazon.com/app-mesh/latest/userguide/virtual_gateways.html

        :param mesh_name: - Identifier for the meshName.
        :param virtual_gateway_name: - Identifier for the virtualGatewayName.
        :param gateway_route_name: - Identifier for the gatewayRouteName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__95e493a98195ef2b7304ba19f9c142f3b5f3dd8533e2a3b52f3803e217e90957)
            check_type(argname="argument mesh_name", value=mesh_name, expected_type=type_hints["mesh_name"])
            check_type(argname="argument virtual_gateway_name", value=virtual_gateway_name, expected_type=type_hints["virtual_gateway_name"])
            check_type(argname="argument gateway_route_name", value=gateway_route_name, expected_type=type_hints["gateway_route_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("AppmeshPreview", jsii.invoke(self, "onGatewayRoute", [mesh_name, virtual_gateway_name, gateway_route_name, account, region, partition]))

    @jsii.member(jsii_name="onMesh")
    def on_mesh(
        self,
        mesh_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "AppmeshPreview":
        '''(experimental) Adds a resource of type mesh to the statement.

        https://docs.aws.amazon.com/app-mesh/latest/userguide/meshes.html

        :param mesh_name: - Identifier for the meshName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__65aa62d61b9eafaeb01b168495701d1e7da115b14b10e7cafee65314cf548305)
            check_type(argname="argument mesh_name", value=mesh_name, expected_type=type_hints["mesh_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("AppmeshPreview", jsii.invoke(self, "onMesh", [mesh_name, account, region, partition]))

    @jsii.member(jsii_name="onRoute")
    def on_route(
        self,
        mesh_name: builtins.str,
        virtual_router_name: builtins.str,
        route_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "AppmeshPreview":
        '''(experimental) Adds a resource of type route to the statement.

        https://docs.aws.amazon.com/app-mesh/latest/userguide/routes.html

        :param mesh_name: - Identifier for the meshName.
        :param virtual_router_name: - Identifier for the virtualRouterName.
        :param route_name: - Identifier for the routeName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ff570f3272da801484e29ad23006b1f9f9678b7a7c95a5874b1417e56102427c)
            check_type(argname="argument mesh_name", value=mesh_name, expected_type=type_hints["mesh_name"])
            check_type(argname="argument virtual_router_name", value=virtual_router_name, expected_type=type_hints["virtual_router_name"])
            check_type(argname="argument route_name", value=route_name, expected_type=type_hints["route_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("AppmeshPreview", jsii.invoke(self, "onRoute", [mesh_name, virtual_router_name, route_name, account, region, partition]))

    @jsii.member(jsii_name="onVirtualGateway")
    def on_virtual_gateway(
        self,
        mesh_name: builtins.str,
        virtual_gateway_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "AppmeshPreview":
        '''(experimental) Adds a resource of type virtualGateway to the statement.

        https://docs.aws.amazon.com/app-mesh/latest/userguide/virtual_gateways.html

        :param mesh_name: - Identifier for the meshName.
        :param virtual_gateway_name: - Identifier for the virtualGatewayName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8297d92aa120c47e02c1a6b82e42db65f9fa39e00c6f0ac971a342a3b6de28d6)
            check_type(argname="argument mesh_name", value=mesh_name, expected_type=type_hints["mesh_name"])
            check_type(argname="argument virtual_gateway_name", value=virtual_gateway_name, expected_type=type_hints["virtual_gateway_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("AppmeshPreview", jsii.invoke(self, "onVirtualGateway", [mesh_name, virtual_gateway_name, account, region, partition]))

    @jsii.member(jsii_name="onVirtualNode")
    def on_virtual_node(
        self,
        mesh_name: builtins.str,
        virtual_node_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "AppmeshPreview":
        '''(experimental) Adds a resource of type virtualNode to the statement.

        https://docs.aws.amazon.com/app-mesh/latest/userguide/virtual_nodes.html

        :param mesh_name: - Identifier for the meshName.
        :param virtual_node_name: - Identifier for the virtualNodeName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1c80b0cbfa1b311a14dd66128760348c52efa308bafcc832c13e797d25e32340)
            check_type(argname="argument mesh_name", value=mesh_name, expected_type=type_hints["mesh_name"])
            check_type(argname="argument virtual_node_name", value=virtual_node_name, expected_type=type_hints["virtual_node_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("AppmeshPreview", jsii.invoke(self, "onVirtualNode", [mesh_name, virtual_node_name, account, region, partition]))

    @jsii.member(jsii_name="onVirtualRouter")
    def on_virtual_router(
        self,
        mesh_name: builtins.str,
        virtual_router_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "AppmeshPreview":
        '''(experimental) Adds a resource of type virtualRouter to the statement.

        https://docs.aws.amazon.com/app-mesh/latest/userguide/virtual_routers.html

        :param mesh_name: - Identifier for the meshName.
        :param virtual_router_name: - Identifier for the virtualRouterName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__af78f582fdd78957c38b78be279e2069a84bbc2c907c1d7dfd1d9a245b9acef6)
            check_type(argname="argument mesh_name", value=mesh_name, expected_type=type_hints["mesh_name"])
            check_type(argname="argument virtual_router_name", value=virtual_router_name, expected_type=type_hints["virtual_router_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("AppmeshPreview", jsii.invoke(self, "onVirtualRouter", [mesh_name, virtual_router_name, account, region, partition]))

    @jsii.member(jsii_name="onVirtualService")
    def on_virtual_service(
        self,
        mesh_name: builtins.str,
        virtual_service_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "AppmeshPreview":
        '''(experimental) Adds a resource of type virtualService to the statement.

        https://docs.aws.amazon.com/app-mesh/latest/userguide/virtual_services.html

        :param mesh_name: - Identifier for the meshName.
        :param virtual_service_name: - Identifier for the virtualServiceName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1c1b5b7b2fbaed544271c33dc56c262de5ac8c3311314f23c2f89e4e7fbea8f2)
            check_type(argname="argument mesh_name", value=mesh_name, expected_type=type_hints["mesh_name"])
            check_type(argname="argument virtual_service_name", value=virtual_service_name, expected_type=type_hints["virtual_service_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("AppmeshPreview", jsii.invoke(self, "onVirtualService", [mesh_name, virtual_service_name, account, region, partition]))

    @jsii.member(jsii_name="toCreateGatewayRoute")
    def to_create_gateway_route(self) -> "AppmeshPreview":
        '''(experimental) Grants permission to create a gateway route that is associated with a virtual gateway.

        Access Level: Write

        https://docs.aws.amazon.com/app-mesh/latest/APIReference/API_CreateGatewayRoute.html

        :stability: experimental
        '''
        return typing.cast("AppmeshPreview", jsii.invoke(self, "toCreateGatewayRoute", []))

    @jsii.member(jsii_name="toCreateMesh")
    def to_create_mesh(self) -> "AppmeshPreview":
        '''(experimental) Grants permission to create a service mesh.

        Access Level: Write

        https://docs.aws.amazon.com/app-mesh/latest/APIReference/API_CreateMesh.html

        :stability: experimental
        '''
        return typing.cast("AppmeshPreview", jsii.invoke(self, "toCreateMesh", []))

    @jsii.member(jsii_name="toCreateRoute")
    def to_create_route(self) -> "AppmeshPreview":
        '''(experimental) Grants permission to create a route that is associated with a virtual router.

        Access Level: Write

        https://docs.aws.amazon.com/app-mesh/latest/APIReference/API_CreateRoute.html

        :stability: experimental
        '''
        return typing.cast("AppmeshPreview", jsii.invoke(self, "toCreateRoute", []))

    @jsii.member(jsii_name="toCreateVirtualGateway")
    def to_create_virtual_gateway(self) -> "AppmeshPreview":
        '''(experimental) Grants permission to create a virtual gateway within a service mesh.

        Access Level: Write

        https://docs.aws.amazon.com/app-mesh/latest/APIReference/API_CreateVirtualGateway.html

        :stability: experimental
        '''
        return typing.cast("AppmeshPreview", jsii.invoke(self, "toCreateVirtualGateway", []))

    @jsii.member(jsii_name="toCreateVirtualNode")
    def to_create_virtual_node(self) -> "AppmeshPreview":
        '''(experimental) Grants permission to create a virtual node within a service mesh.

        Access Level: Write

        https://docs.aws.amazon.com/app-mesh/latest/APIReference/API_CreateVirtualNode.html

        :stability: experimental
        '''
        return typing.cast("AppmeshPreview", jsii.invoke(self, "toCreateVirtualNode", []))

    @jsii.member(jsii_name="toCreateVirtualRouter")
    def to_create_virtual_router(self) -> "AppmeshPreview":
        '''(experimental) Grants permission to create a virtual router within a service mesh.

        Access Level: Write

        https://docs.aws.amazon.com/app-mesh/latest/APIReference/API_CreateVirtualRouter.html

        :stability: experimental
        '''
        return typing.cast("AppmeshPreview", jsii.invoke(self, "toCreateVirtualRouter", []))

    @jsii.member(jsii_name="toCreateVirtualService")
    def to_create_virtual_service(self) -> "AppmeshPreview":
        '''(experimental) Grants permission to create a virtual service within a service mesh.

        Access Level: Write

        https://docs.aws.amazon.com/app-mesh/latest/APIReference/API_CreateVirtualService.html

        :stability: experimental
        '''
        return typing.cast("AppmeshPreview", jsii.invoke(self, "toCreateVirtualService", []))

    @jsii.member(jsii_name="toDeleteGatewayRoute")
    def to_delete_gateway_route(self) -> "AppmeshPreview":
        '''(experimental) Grants permission to delete an existing gateway route.

        Access Level: Write

        https://docs.aws.amazon.com/app-mesh/latest/APIReference/API_DeleteGatewayRoute.html

        :stability: experimental
        '''
        return typing.cast("AppmeshPreview", jsii.invoke(self, "toDeleteGatewayRoute", []))

    @jsii.member(jsii_name="toDeleteMesh")
    def to_delete_mesh(self) -> "AppmeshPreview":
        '''(experimental) Grants permission to delete an existing service mesh.

        Access Level: Write

        https://docs.aws.amazon.com/app-mesh/latest/APIReference/API_DeleteMesh.html

        :stability: experimental
        '''
        return typing.cast("AppmeshPreview", jsii.invoke(self, "toDeleteMesh", []))

    @jsii.member(jsii_name="toDeleteRoute")
    def to_delete_route(self) -> "AppmeshPreview":
        '''(experimental) Grants permission to delete an existing route.

        Access Level: Write

        https://docs.aws.amazon.com/app-mesh/latest/APIReference/API_DeleteRoute.html

        :stability: experimental
        '''
        return typing.cast("AppmeshPreview", jsii.invoke(self, "toDeleteRoute", []))

    @jsii.member(jsii_name="toDeleteVirtualGateway")
    def to_delete_virtual_gateway(self) -> "AppmeshPreview":
        '''(experimental) Grants permission to delete an existing virtual gateway.

        Access Level: Write

        https://docs.aws.amazon.com/app-mesh/latest/APIReference/API_DeleteVirtualGateway.html

        :stability: experimental
        '''
        return typing.cast("AppmeshPreview", jsii.invoke(self, "toDeleteVirtualGateway", []))

    @jsii.member(jsii_name="toDeleteVirtualNode")
    def to_delete_virtual_node(self) -> "AppmeshPreview":
        '''(experimental) Grants permission to delete an existing virtual node.

        Access Level: Write

        https://docs.aws.amazon.com/app-mesh/latest/APIReference/API_DeleteVirtualNode.html

        :stability: experimental
        '''
        return typing.cast("AppmeshPreview", jsii.invoke(self, "toDeleteVirtualNode", []))

    @jsii.member(jsii_name="toDeleteVirtualRouter")
    def to_delete_virtual_router(self) -> "AppmeshPreview":
        '''(experimental) Grants permission to delete an existing virtual router.

        Access Level: Write

        https://docs.aws.amazon.com/app-mesh/latest/APIReference/API_DeleteVirtualRouter.html

        :stability: experimental
        '''
        return typing.cast("AppmeshPreview", jsii.invoke(self, "toDeleteVirtualRouter", []))

    @jsii.member(jsii_name="toDeleteVirtualService")
    def to_delete_virtual_service(self) -> "AppmeshPreview":
        '''(experimental) Grants permission to delete an existing virtual service.

        Access Level: Write

        https://docs.aws.amazon.com/app-mesh/latest/APIReference/API_DeleteVirtualService.html

        :stability: experimental
        '''
        return typing.cast("AppmeshPreview", jsii.invoke(self, "toDeleteVirtualService", []))

    @jsii.member(jsii_name="toDescribeGatewayRoute")
    def to_describe_gateway_route(self) -> "AppmeshPreview":
        '''(experimental) Grants permission to describe an existing gateway route.

        Access Level: Read

        https://docs.aws.amazon.com/app-mesh/latest/APIReference/API_DescribeGatewayRoute.html

        :stability: experimental
        '''
        return typing.cast("AppmeshPreview", jsii.invoke(self, "toDescribeGatewayRoute", []))

    @jsii.member(jsii_name="toDescribeMesh")
    def to_describe_mesh(self) -> "AppmeshPreview":
        '''(experimental) Grants permission to describe an existing service mesh.

        Access Level: Read

        https://docs.aws.amazon.com/app-mesh/latest/APIReference/API_DescribeMesh.html

        :stability: experimental
        '''
        return typing.cast("AppmeshPreview", jsii.invoke(self, "toDescribeMesh", []))

    @jsii.member(jsii_name="toDescribeRoute")
    def to_describe_route(self) -> "AppmeshPreview":
        '''(experimental) Grants permission to describe an existing route.

        Access Level: Read

        https://docs.aws.amazon.com/app-mesh/latest/APIReference/API_DescribeRoute.html

        :stability: experimental
        '''
        return typing.cast("AppmeshPreview", jsii.invoke(self, "toDescribeRoute", []))

    @jsii.member(jsii_name="toDescribeVirtualGateway")
    def to_describe_virtual_gateway(self) -> "AppmeshPreview":
        '''(experimental) Grants permission to describe an existing virtual gateway.

        Access Level: Read

        https://docs.aws.amazon.com/app-mesh/latest/APIReference/API_DescribeVirtualGateway.html

        :stability: experimental
        '''
        return typing.cast("AppmeshPreview", jsii.invoke(self, "toDescribeVirtualGateway", []))

    @jsii.member(jsii_name="toDescribeVirtualNode")
    def to_describe_virtual_node(self) -> "AppmeshPreview":
        '''(experimental) Grants permission to describe an existing virtual node.

        Access Level: Read

        https://docs.aws.amazon.com/app-mesh/latest/APIReference/API_DescribeVirtualNode.html

        :stability: experimental
        '''
        return typing.cast("AppmeshPreview", jsii.invoke(self, "toDescribeVirtualNode", []))

    @jsii.member(jsii_name="toDescribeVirtualRouter")
    def to_describe_virtual_router(self) -> "AppmeshPreview":
        '''(experimental) Grants permission to describe an existing virtual router.

        Access Level: Read

        https://docs.aws.amazon.com/app-mesh/latest/APIReference/API_DescribeVirtualRouter.html

        :stability: experimental
        '''
        return typing.cast("AppmeshPreview", jsii.invoke(self, "toDescribeVirtualRouter", []))

    @jsii.member(jsii_name="toDescribeVirtualService")
    def to_describe_virtual_service(self) -> "AppmeshPreview":
        '''(experimental) Grants permission to describe an existing virtual service.

        Access Level: Read

        https://docs.aws.amazon.com/app-mesh/latest/APIReference/API_DescribeVirtualService.html

        :stability: experimental
        '''
        return typing.cast("AppmeshPreview", jsii.invoke(self, "toDescribeVirtualService", []))

    @jsii.member(jsii_name="toListGatewayRoutes")
    def to_list_gateway_routes(self) -> "AppmeshPreview":
        '''(experimental) Grants permission to list existing gateway routes in a service mesh.

        Access Level: List

        https://docs.aws.amazon.com/app-mesh/latest/APIReference/API_ListGatewayRoutes.html

        :stability: experimental
        '''
        return typing.cast("AppmeshPreview", jsii.invoke(self, "toListGatewayRoutes", []))

    @jsii.member(jsii_name="toListMeshes")
    def to_list_meshes(self) -> "AppmeshPreview":
        '''(experimental) Grants permission to list existing service meshes.

        Access Level: List

        https://docs.aws.amazon.com/app-mesh/latest/APIReference/API_ListMeshes.html

        :stability: experimental
        '''
        return typing.cast("AppmeshPreview", jsii.invoke(self, "toListMeshes", []))

    @jsii.member(jsii_name="toListRoutes")
    def to_list_routes(self) -> "AppmeshPreview":
        '''(experimental) Grants permission to list existing routes in a service mesh.

        Access Level: List

        https://docs.aws.amazon.com/app-mesh/latest/APIReference/API_ListRoutes.html

        :stability: experimental
        '''
        return typing.cast("AppmeshPreview", jsii.invoke(self, "toListRoutes", []))

    @jsii.member(jsii_name="toListVirtualGateways")
    def to_list_virtual_gateways(self) -> "AppmeshPreview":
        '''(experimental) Grants permission to list existing virtual gateways in a service mesh.

        Access Level: List

        https://docs.aws.amazon.com/app-mesh/latest/APIReference/API_ListVirtualGateways.html

        :stability: experimental
        '''
        return typing.cast("AppmeshPreview", jsii.invoke(self, "toListVirtualGateways", []))

    @jsii.member(jsii_name="toListVirtualNodes")
    def to_list_virtual_nodes(self) -> "AppmeshPreview":
        '''(experimental) Grants permission to list existing virtual nodes.

        Access Level: List

        https://docs.aws.amazon.com/app-mesh/latest/APIReference/API_ListVirtualNodes.html

        :stability: experimental
        '''
        return typing.cast("AppmeshPreview", jsii.invoke(self, "toListVirtualNodes", []))

    @jsii.member(jsii_name="toListVirtualRouters")
    def to_list_virtual_routers(self) -> "AppmeshPreview":
        '''(experimental) Grants permission to list existing virtual routers in a service mesh.

        Access Level: List

        https://docs.aws.amazon.com/app-mesh/latest/APIReference/API_ListVirtualRouters.html

        :stability: experimental
        '''
        return typing.cast("AppmeshPreview", jsii.invoke(self, "toListVirtualRouters", []))

    @jsii.member(jsii_name="toListVirtualServices")
    def to_list_virtual_services(self) -> "AppmeshPreview":
        '''(experimental) Grants permission to list existing virtual services in a service mesh.

        Access Level: List

        https://docs.aws.amazon.com/app-mesh/latest/APIReference/API_ListVirtualServices.html

        :stability: experimental
        '''
        return typing.cast("AppmeshPreview", jsii.invoke(self, "toListVirtualServices", []))

    @jsii.member(jsii_name="toStreamAggregatedResources")
    def to_stream_aggregated_resources(self) -> "AppmeshPreview":
        '''(experimental) Grants permission to receive streamed resources for an App Mesh endpoint (VirtualNode/VirtualGateway).

        Access Level: Read

        https://docs.aws.amazon.com/app-mesh/latest/userguide/envoy.html

        :stability: experimental
        '''
        return typing.cast("AppmeshPreview", jsii.invoke(self, "toStreamAggregatedResources", []))

    @jsii.member(jsii_name="toUpdateGatewayRoute")
    def to_update_gateway_route(self) -> "AppmeshPreview":
        '''(experimental) Grants permission to update an existing gateway route for a specified service mesh and virtual gateway.

        Access Level: Write

        https://docs.aws.amazon.com/app-mesh/latest/APIReference/API_UpdateGatewayRoute.html

        :stability: experimental
        '''
        return typing.cast("AppmeshPreview", jsii.invoke(self, "toUpdateGatewayRoute", []))

    @jsii.member(jsii_name="toUpdateMesh")
    def to_update_mesh(self) -> "AppmeshPreview":
        '''(experimental) Grants permission to update an existing service mesh.

        Access Level: Write

        https://docs.aws.amazon.com/app-mesh/latest/APIReference/API_UpdateMesh.html

        :stability: experimental
        '''
        return typing.cast("AppmeshPreview", jsii.invoke(self, "toUpdateMesh", []))

    @jsii.member(jsii_name="toUpdateRoute")
    def to_update_route(self) -> "AppmeshPreview":
        '''(experimental) Grants permission to update an existing route for a specified service mesh and virtual router.

        Access Level: Write

        https://docs.aws.amazon.com/app-mesh/latest/APIReference/API_UpdateRoute.html

        :stability: experimental
        '''
        return typing.cast("AppmeshPreview", jsii.invoke(self, "toUpdateRoute", []))

    @jsii.member(jsii_name="toUpdateVirtualGateway")
    def to_update_virtual_gateway(self) -> "AppmeshPreview":
        '''(experimental) Grants permission to update an existing virtual gateway in a specified service mesh.

        Access Level: Write

        https://docs.aws.amazon.com/app-mesh/latest/APIReference/API_UpdateVirtualGateway.html

        :stability: experimental
        '''
        return typing.cast("AppmeshPreview", jsii.invoke(self, "toUpdateVirtualGateway", []))

    @jsii.member(jsii_name="toUpdateVirtualNode")
    def to_update_virtual_node(self) -> "AppmeshPreview":
        '''(experimental) Grants permission to update an existing virtual node in a specified service mesh.

        Access Level: Write

        https://docs.aws.amazon.com/app-mesh/latest/APIReference/API_UpdateVirtualNode.html

        :stability: experimental
        '''
        return typing.cast("AppmeshPreview", jsii.invoke(self, "toUpdateVirtualNode", []))

    @jsii.member(jsii_name="toUpdateVirtualRouter")
    def to_update_virtual_router(self) -> "AppmeshPreview":
        '''(experimental) Grants permission to update an existing virtual router in a specified service mesh.

        Access Level: Write

        https://docs.aws.amazon.com/app-mesh/latest/APIReference/API_UpdateVirtualRouter.html

        :stability: experimental
        '''
        return typing.cast("AppmeshPreview", jsii.invoke(self, "toUpdateVirtualRouter", []))

    @jsii.member(jsii_name="toUpdateVirtualService")
    def to_update_virtual_service(self) -> "AppmeshPreview":
        '''(experimental) Grants permission to update an existing virtual service in a specified service mesh.

        Access Level: Write

        https://docs.aws.amazon.com/app-mesh/latest/APIReference/API_UpdateVirtualService.html

        :stability: experimental
        '''
        return typing.cast("AppmeshPreview", jsii.invoke(self, "toUpdateVirtualService", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__732b05801e3cfa3b5ca8ece8e35b7c4722b0c47554a3147ee9ef347472bea928)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__98d2272136e936d02b9ed69bc41649129dc9ac33dc47fd24ed1f75c6ff9ab967)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Apprunner(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Apprunner",
):
    '''(experimental) Statement provider for service `apprunner <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsapprunner.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `apprunner <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsapprunner.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="ifAutoScalingConfigurationArn")
    def if_auto_scaling_configuration_arn(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Apprunner":
        '''(experimental) Filters access by the CreateService and UpdateService actions based on the ARN of an associated AutoScalingConfiguration resource.

        Applies to actions:

        - .toCreateService()
        - .toUpdateService()

        :param value: The value(s) to check.
        :param operator: Works with `arn operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_ARN>`_. **Default:** ``ArnLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__723606da005bb2ca8448503d4a8fd1a2085ceb8d39e8809cf70f5453ce8bb495)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Apprunner", jsii.invoke(self, "ifAutoScalingConfigurationArn", [value, operator]))

    @jsii.member(jsii_name="ifConnectionArn")
    def if_connection_arn(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Apprunner":
        '''(experimental) Filters access by the CreateService and UpdateService actions based on the ARN of an associated Connection resource.

        Applies to actions:

        - .toCreateService()
        - .toUpdateService()

        :param value: The value(s) to check.
        :param operator: Works with `arn operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_ARN>`_. **Default:** ``ArnLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__70b1aa18814c4026650b648217d549af3ba963b929d25e23e929e3bde5d34c5d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Apprunner", jsii.invoke(self, "ifConnectionArn", [value, operator]))

    @jsii.member(jsii_name="ifObservabilityConfigurationArn")
    def if_observability_configuration_arn(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Apprunner":
        '''(experimental) Filters access by the CreateService and UpdateService actions based on the ARN of an associated ObservabilityConfiguration resource.

        Applies to actions:

        - .toCreateService()
        - .toUpdateService()

        :param value: The value(s) to check.
        :param operator: Works with `arn operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_ARN>`_. **Default:** ``ArnLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__95022c2da974fee89ebae668314bcafc0ac938b822600cefa82939a13e732624)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Apprunner", jsii.invoke(self, "ifObservabilityConfigurationArn", [value, operator]))

    @jsii.member(jsii_name="ifServiceArn")
    def if_service_arn(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Apprunner":
        '''(experimental) Filters access by the CreateVpcIngressConnection action based on the ARN of an associated Service resource.

        Applies to actions:

        - .toCreateVpcIngressConnection()

        :param value: The value(s) to check.
        :param operator: Works with `arn operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_ARN>`_. **Default:** ``ArnLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e792a69d128138b2118f078a5ebd276c586020d17b894f2814767c042cd9dae8)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Apprunner", jsii.invoke(self, "ifServiceArn", [value, operator]))

    @jsii.member(jsii_name="ifVpcConnectorArn")
    def if_vpc_connector_arn(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Apprunner":
        '''(experimental) Filters access by the CreateService and UpdateService actions based on the ARN of an associated VpcConnector resource.

        Applies to actions:

        - .toCreateService()
        - .toUpdateService()

        :param value: The value(s) to check.
        :param operator: Works with `arn operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_ARN>`_. **Default:** ``ArnLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__54afc1e3bdcfb9e8f9653154f3d19f3633ddfb2f57a470f63777aa164def866b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Apprunner", jsii.invoke(self, "ifVpcConnectorArn", [value, operator]))

    @jsii.member(jsii_name="ifVpcEndpointId")
    def if_vpc_endpoint_id(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Apprunner":
        '''(experimental) Filters access by the CreateVpcIngressConnection and UpdateVpcIngressConnection actions based on the VPC Endpoint in the request.

        Applies to actions:

        - .toCreateVpcIngressConnection()
        - .toUpdateVpcIngressConnection()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9926b60b6fe196e4f37245b1fa2dcb649da140da116ab63f5043dddabbf0a6a8)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Apprunner", jsii.invoke(self, "ifVpcEndpointId", [value, operator]))

    @jsii.member(jsii_name="ifVpcId")
    def if_vpc_id(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Apprunner":
        '''(experimental) Filters access by the CreateVpcIngressConnection and UpdateVpcIngressConnection actions based on the VPC in the request.

        Applies to actions:

        - .toCreateVpcIngressConnection()
        - .toUpdateVpcIngressConnection()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__963e22b29305bd2c8e60c83678dd679bcfb31cf692c1e5dcf2c1a98615e9363e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Apprunner", jsii.invoke(self, "ifVpcId", [value, operator]))

    @jsii.member(jsii_name="onAutoscalingconfiguration")
    def on_autoscalingconfiguration(
        self,
        autoscaling_configuration_name: builtins.str,
        autoscaling_configuration_version: builtins.str,
        autoscaling_configuration_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Apprunner":
        '''(experimental) Adds a resource of type autoscalingconfiguration to the statement.

        :param autoscaling_configuration_name: - Identifier for the autoscalingConfigurationName.
        :param autoscaling_configuration_version: - Identifier for the autoscalingConfigurationVersion.
        :param autoscaling_configuration_id: - Identifier for the autoscalingConfigurationId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6c96bfbac031968e54d47051e5d7606b52c92c44e46eadd8d4e4aa8a80cb865f)
            check_type(argname="argument autoscaling_configuration_name", value=autoscaling_configuration_name, expected_type=type_hints["autoscaling_configuration_name"])
            check_type(argname="argument autoscaling_configuration_version", value=autoscaling_configuration_version, expected_type=type_hints["autoscaling_configuration_version"])
            check_type(argname="argument autoscaling_configuration_id", value=autoscaling_configuration_id, expected_type=type_hints["autoscaling_configuration_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Apprunner", jsii.invoke(self, "onAutoscalingconfiguration", [autoscaling_configuration_name, autoscaling_configuration_version, autoscaling_configuration_id, account, region, partition]))

    @jsii.member(jsii_name="onConnection")
    def on_connection(
        self,
        connection_name: builtins.str,
        connection_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Apprunner":
        '''(experimental) Adds a resource of type connection to the statement.

        :param connection_name: - Identifier for the connectionName.
        :param connection_id: - Identifier for the connectionId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__026f94f1c259001b9a347e45a3e2e5d161cdcfe988ac31fc878b51279b7ff5a5)
            check_type(argname="argument connection_name", value=connection_name, expected_type=type_hints["connection_name"])
            check_type(argname="argument connection_id", value=connection_id, expected_type=type_hints["connection_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Apprunner", jsii.invoke(self, "onConnection", [connection_name, connection_id, account, region, partition]))

    @jsii.member(jsii_name="onObservabilityconfiguration")
    def on_observabilityconfiguration(
        self,
        observability_configuration_name: builtins.str,
        observability_configuration_version: builtins.str,
        observability_configuration_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Apprunner":
        '''(experimental) Adds a resource of type observabilityconfiguration to the statement.

        :param observability_configuration_name: - Identifier for the observabilityConfigurationName.
        :param observability_configuration_version: - Identifier for the observabilityConfigurationVersion.
        :param observability_configuration_id: - Identifier for the observabilityConfigurationId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ad35ac8fc0f3f747e9fa75a0d2d493d6029051b53c6c9fe1c66731998eba5644)
            check_type(argname="argument observability_configuration_name", value=observability_configuration_name, expected_type=type_hints["observability_configuration_name"])
            check_type(argname="argument observability_configuration_version", value=observability_configuration_version, expected_type=type_hints["observability_configuration_version"])
            check_type(argname="argument observability_configuration_id", value=observability_configuration_id, expected_type=type_hints["observability_configuration_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Apprunner", jsii.invoke(self, "onObservabilityconfiguration", [observability_configuration_name, observability_configuration_version, observability_configuration_id, account, region, partition]))

    @jsii.member(jsii_name="onService")
    def on_service(
        self,
        service_name: builtins.str,
        service_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Apprunner":
        '''(experimental) Adds a resource of type service to the statement.

        :param service_name: - Identifier for the serviceName.
        :param service_id: - Identifier for the serviceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ec362f6b350e00e74e711d55791fd60156bce778dc4f54b6f34006c4244296fe)
            check_type(argname="argument service_name", value=service_name, expected_type=type_hints["service_name"])
            check_type(argname="argument service_id", value=service_id, expected_type=type_hints["service_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Apprunner", jsii.invoke(self, "onService", [service_name, service_id, account, region, partition]))

    @jsii.member(jsii_name="onVpcconnector")
    def on_vpcconnector(
        self,
        vpc_connector_name: builtins.str,
        vpc_connector_version: builtins.str,
        vpc_connector_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Apprunner":
        '''(experimental) Adds a resource of type vpcconnector to the statement.

        :param vpc_connector_name: - Identifier for the vpcConnectorName.
        :param vpc_connector_version: - Identifier for the vpcConnectorVersion.
        :param vpc_connector_id: - Identifier for the vpcConnectorId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7b3dec8e71922f5195bbca25ca53dd246ae0061209db488c2f83a9001d306755)
            check_type(argname="argument vpc_connector_name", value=vpc_connector_name, expected_type=type_hints["vpc_connector_name"])
            check_type(argname="argument vpc_connector_version", value=vpc_connector_version, expected_type=type_hints["vpc_connector_version"])
            check_type(argname="argument vpc_connector_id", value=vpc_connector_id, expected_type=type_hints["vpc_connector_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Apprunner", jsii.invoke(self, "onVpcconnector", [vpc_connector_name, vpc_connector_version, vpc_connector_id, account, region, partition]))

    @jsii.member(jsii_name="onVpcingressconnection")
    def on_vpcingressconnection(
        self,
        vpc_ingress_connection_name: builtins.str,
        vpc_ingress_connection_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Apprunner":
        '''(experimental) Adds a resource of type vpcingressconnection to the statement.

        :param vpc_ingress_connection_name: - Identifier for the vpcIngressConnectionName.
        :param vpc_ingress_connection_id: - Identifier for the vpcIngressConnectionId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__19700bc2521a766c69c28c0714a1be4924cab7d003aa4102ea481caef9483c90)
            check_type(argname="argument vpc_ingress_connection_name", value=vpc_ingress_connection_name, expected_type=type_hints["vpc_ingress_connection_name"])
            check_type(argname="argument vpc_ingress_connection_id", value=vpc_ingress_connection_id, expected_type=type_hints["vpc_ingress_connection_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Apprunner", jsii.invoke(self, "onVpcingressconnection", [vpc_ingress_connection_name, vpc_ingress_connection_id, account, region, partition]))

    @jsii.member(jsii_name="toAssociateCustomDomain")
    def to_associate_custom_domain(self) -> "Apprunner":
        '''(experimental) Grants permission to associate your own domain name with the AWS App Runner subdomain URL of your App Runner service.

        Access Level: Write

        https://docs.aws.amazon.com/apprunner/latest/api/API_AssociateCustomDomain.html

        :stability: experimental
        '''
        return typing.cast("Apprunner", jsii.invoke(self, "toAssociateCustomDomain", []))

    @jsii.member(jsii_name="toCreateAutoScalingConfiguration")
    def to_create_auto_scaling_configuration(self) -> "Apprunner":
        '''(experimental) Grants permission to create an AWS App Runner automatic scaling configuration resource.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/apprunner/latest/api/API_CreateAutoScalingConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Apprunner", jsii.invoke(self, "toCreateAutoScalingConfiguration", []))

    @jsii.member(jsii_name="toCreateConnection")
    def to_create_connection(self) -> "Apprunner":
        '''(experimental) Grants permission to create an AWS App Runner connection resource.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/apprunner/latest/api/API_CreateConnection.html

        :stability: experimental
        '''
        return typing.cast("Apprunner", jsii.invoke(self, "toCreateConnection", []))

    @jsii.member(jsii_name="toCreateObservabilityConfiguration")
    def to_create_observability_configuration(self) -> "Apprunner":
        '''(experimental) Grants permission to create an AWS App Runner observability configuration resource.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/apprunner/latest/api/API_CreateObservabilityConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Apprunner", jsii.invoke(self, "toCreateObservabilityConfiguration", []))

    @jsii.member(jsii_name="toCreateService")
    def to_create_service(self) -> "Apprunner":
        '''(experimental) Grants permission to create an AWS App Runner service resource.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifConnectionArn()
        - .ifAutoScalingConfigurationArn()
        - .ifObservabilityConfigurationArn()
        - .ifVpcConnectorArn()

        https://docs.aws.amazon.com/apprunner/latest/api/API_CreateService.html

        :stability: experimental
        '''
        return typing.cast("Apprunner", jsii.invoke(self, "toCreateService", []))

    @jsii.member(jsii_name="toCreateVpcConnector")
    def to_create_vpc_connector(self) -> "Apprunner":
        '''(experimental) Grants permission to create an AWS App Runner VPC connector resource.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/apprunner/latest/api/API_CreateVpcConnector.html

        :stability: experimental
        '''
        return typing.cast("Apprunner", jsii.invoke(self, "toCreateVpcConnector", []))

    @jsii.member(jsii_name="toCreateVpcIngressConnection")
    def to_create_vpc_ingress_connection(self) -> "Apprunner":
        '''(experimental) Grants permission to create an AWS App Runner VpcIngressConnection resource.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifServiceArn()
        - .ifVpcId()
        - .ifVpcEndpointId()

        https://docs.aws.amazon.com/apprunner/latest/api/API_CreateVpcIngressConnection.html

        :stability: experimental
        '''
        return typing.cast("Apprunner", jsii.invoke(self, "toCreateVpcIngressConnection", []))

    @jsii.member(jsii_name="toDeleteAutoScalingConfiguration")
    def to_delete_auto_scaling_configuration(self) -> "Apprunner":
        '''(experimental) Grants permission to delete an AWS App Runner automatic scaling configuration resource.

        Access Level: Write

        https://docs.aws.amazon.com/apprunner/latest/api/API_DeleteAutoScalingConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Apprunner", jsii.invoke(self, "toDeleteAutoScalingConfiguration", []))

    @jsii.member(jsii_name="toDeleteConnection")
    def to_delete_connection(self) -> "Apprunner":
        '''(experimental) Grants permission to delete an AWS App Runner connection resource.

        Access Level: Write

        https://docs.aws.amazon.com/apprunner/latest/api/API_DeleteConnection.html

        :stability: experimental
        '''
        return typing.cast("Apprunner", jsii.invoke(self, "toDeleteConnection", []))

    @jsii.member(jsii_name="toDeleteObservabilityConfiguration")
    def to_delete_observability_configuration(self) -> "Apprunner":
        '''(experimental) Grants permission to delete an AWS App Runner observability configuration resource.

        Access Level: Write

        https://docs.aws.amazon.com/apprunner/latest/api/API_DeleteObservabilityConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Apprunner", jsii.invoke(self, "toDeleteObservabilityConfiguration", []))

    @jsii.member(jsii_name="toDeleteService")
    def to_delete_service(self) -> "Apprunner":
        '''(experimental) Grants permission to delete an AWS App Runner service resource.

        Access Level: Write

        https://docs.aws.amazon.com/apprunner/latest/api/API_DeleteService.html

        :stability: experimental
        '''
        return typing.cast("Apprunner", jsii.invoke(self, "toDeleteService", []))

    @jsii.member(jsii_name="toDeleteVpcConnector")
    def to_delete_vpc_connector(self) -> "Apprunner":
        '''(experimental) Grants permission to delete an AWS App Runner VPC connector resource.

        Access Level: Write

        https://docs.aws.amazon.com/apprunner/latest/api/API_DeleteVpcConnector.html

        :stability: experimental
        '''
        return typing.cast("Apprunner", jsii.invoke(self, "toDeleteVpcConnector", []))

    @jsii.member(jsii_name="toDeleteVpcIngressConnection")
    def to_delete_vpc_ingress_connection(self) -> "Apprunner":
        '''(experimental) Grants permission to delete an AWS App Runner VpcIngressConnection resource.

        Access Level: Write

        https://docs.aws.amazon.com/apprunner/latest/api/API_DeleteVpcIngressConnection.html

        :stability: experimental
        '''
        return typing.cast("Apprunner", jsii.invoke(self, "toDeleteVpcIngressConnection", []))

    @jsii.member(jsii_name="toDescribeAutoScalingConfiguration")
    def to_describe_auto_scaling_configuration(self) -> "Apprunner":
        '''(experimental) Grants permission to retrieve the description of an AWS App Runner automatic scaling configuration resource.

        Access Level: Read

        https://docs.aws.amazon.com/apprunner/latest/api/API_DescribeAutoScalingConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Apprunner", jsii.invoke(self, "toDescribeAutoScalingConfiguration", []))

    @jsii.member(jsii_name="toDescribeCustomDomains")
    def to_describe_custom_domains(self) -> "Apprunner":
        '''(experimental) Grants permission to retrieve descriptions of custom domain names associated with an AWS App Runner service.

        Access Level: Read

        https://docs.aws.amazon.com/apprunner/latest/api/API_DescribeCustomDomains.html

        :stability: experimental
        '''
        return typing.cast("Apprunner", jsii.invoke(self, "toDescribeCustomDomains", []))

    @jsii.member(jsii_name="toDescribeObservabilityConfiguration")
    def to_describe_observability_configuration(self) -> "Apprunner":
        '''(experimental) Grants permission to retrieve the description of an AWS App Runner observability configuration resource.

        Access Level: Read

        https://docs.aws.amazon.com/apprunner/latest/api/API_DescribeObservabilityConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Apprunner", jsii.invoke(self, "toDescribeObservabilityConfiguration", []))

    @jsii.member(jsii_name="toDescribeOperation")
    def to_describe_operation(self) -> "Apprunner":
        '''(experimental) Grants permission to retrieve the description of an operation that occurred on an AWS App Runner service.

        Access Level: Read

        https://docs.aws.amazon.com/apprunner/latest/api/API_DescribeOperation.html

        :stability: experimental
        '''
        return typing.cast("Apprunner", jsii.invoke(self, "toDescribeOperation", []))

    @jsii.member(jsii_name="toDescribeService")
    def to_describe_service(self) -> "Apprunner":
        '''(experimental) Grants permission to retrieve the description of an AWS App Runner service resource.

        Access Level: Read

        https://docs.aws.amazon.com/apprunner/latest/api/API_DescribeService.html

        :stability: experimental
        '''
        return typing.cast("Apprunner", jsii.invoke(self, "toDescribeService", []))

    @jsii.member(jsii_name="toDescribeVpcConnector")
    def to_describe_vpc_connector(self) -> "Apprunner":
        '''(experimental) Grants permission to retrieve the description of an AWS App Runner VPC connector resource.

        Access Level: Read

        https://docs.aws.amazon.com/apprunner/latest/api/API_DescribeVpcConnector.html

        :stability: experimental
        '''
        return typing.cast("Apprunner", jsii.invoke(self, "toDescribeVpcConnector", []))

    @jsii.member(jsii_name="toDescribeVpcIngressConnection")
    def to_describe_vpc_ingress_connection(self) -> "Apprunner":
        '''(experimental) Grants permission to retrieve the description of an AWS App Runner VpcIngressConnection resource.

        Access Level: Read

        https://docs.aws.amazon.com/apprunner/latest/api/API_DescribeVpcIngressConnection.html

        :stability: experimental
        '''
        return typing.cast("Apprunner", jsii.invoke(self, "toDescribeVpcIngressConnection", []))

    @jsii.member(jsii_name="toDisassociateCustomDomain")
    def to_disassociate_custom_domain(self) -> "Apprunner":
        '''(experimental) Grants permission to disassociate a custom domain name from an AWS App Runner service.

        Access Level: Write

        https://docs.aws.amazon.com/apprunner/latest/api/API_DisassociateCustomDomain.html

        :stability: experimental
        '''
        return typing.cast("Apprunner", jsii.invoke(self, "toDisassociateCustomDomain", []))

    @jsii.member(jsii_name="toListAutoScalingConfigurations")
    def to_list_auto_scaling_configurations(self) -> "Apprunner":
        '''(experimental) Grants permission to retrieve a list of AWS App Runner automatic scaling configurations in your AWS account.

        Access Level: List

        https://docs.aws.amazon.com/apprunner/latest/api/API_ListAutoScalingConfigurations.html

        :stability: experimental
        '''
        return typing.cast("Apprunner", jsii.invoke(self, "toListAutoScalingConfigurations", []))

    @jsii.member(jsii_name="toListConnections")
    def to_list_connections(self) -> "Apprunner":
        '''(experimental) Grants permission to retrieve a list of AWS App Runner connections in your AWS account.

        Access Level: List

        https://docs.aws.amazon.com/apprunner/latest/api/API_ListConnections.html

        :stability: experimental
        '''
        return typing.cast("Apprunner", jsii.invoke(self, "toListConnections", []))

    @jsii.member(jsii_name="toListObservabilityConfigurations")
    def to_list_observability_configurations(self) -> "Apprunner":
        '''(experimental) Grants permission to retrieve a list of AWS App Runner observability configurations in your AWS account.

        Access Level: List

        https://docs.aws.amazon.com/apprunner/latest/api/API_ListObservabilityConfigurations.html

        :stability: experimental
        '''
        return typing.cast("Apprunner", jsii.invoke(self, "toListObservabilityConfigurations", []))

    @jsii.member(jsii_name="toListOperations")
    def to_list_operations(self) -> "Apprunner":
        '''(experimental) Grants permission to retrieve a list of operations that occurred on an AWS App Runner service resource.

        Access Level: List

        https://docs.aws.amazon.com/apprunner/latest/api/API_ListOperations.html

        :stability: experimental
        '''
        return typing.cast("Apprunner", jsii.invoke(self, "toListOperations", []))

    @jsii.member(jsii_name="toListServices")
    def to_list_services(self) -> "Apprunner":
        '''(experimental) Grants permission to retrieve a list of running AWS App Runner services in your AWS account.

        Access Level: List

        https://docs.aws.amazon.com/apprunner/latest/api/API_ListServices.html

        :stability: experimental
        '''
        return typing.cast("Apprunner", jsii.invoke(self, "toListServices", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Apprunner":
        '''(experimental) Grants permission to list tags associated with an AWS App Runner resource.

        Access Level: Read

        https://docs.aws.amazon.com/apprunner/latest/api/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("Apprunner", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toListVpcConnectors")
    def to_list_vpc_connectors(self) -> "Apprunner":
        '''(experimental) Grants permission to retrieve a list of AWS App Runner VPC connectors in your AWS account.

        Access Level: List

        https://docs.aws.amazon.com/apprunner/latest/api/API_ListVpcConnectors.html

        :stability: experimental
        '''
        return typing.cast("Apprunner", jsii.invoke(self, "toListVpcConnectors", []))

    @jsii.member(jsii_name="toListVpcIngressConnections")
    def to_list_vpc_ingress_connections(self) -> "Apprunner":
        '''(experimental) Grants permission to retrieve a list of AWS App Runner VpcIngressConnections in your AWS account.

        Access Level: List

        https://docs.aws.amazon.com/apprunner/latest/api/API_ListVpcConnections.html

        :stability: experimental
        '''
        return typing.cast("Apprunner", jsii.invoke(self, "toListVpcIngressConnections", []))

    @jsii.member(jsii_name="toPauseService")
    def to_pause_service(self) -> "Apprunner":
        '''(experimental) Grants permission to pause an active AWS App Runner service.

        Access Level: Write

        https://docs.aws.amazon.com/apprunner/latest/api/API_PauseService.html

        :stability: experimental
        '''
        return typing.cast("Apprunner", jsii.invoke(self, "toPauseService", []))

    @jsii.member(jsii_name="toResumeService")
    def to_resume_service(self) -> "Apprunner":
        '''(experimental) Grants permission to resume an active AWS App Runner service.

        Access Level: Write

        https://docs.aws.amazon.com/apprunner/latest/api/API_ResumeService.html

        :stability: experimental
        '''
        return typing.cast("Apprunner", jsii.invoke(self, "toResumeService", []))

    @jsii.member(jsii_name="toStartDeployment")
    def to_start_deployment(self) -> "Apprunner":
        '''(experimental) Grants permission to initiate a manual deployemnt to an AWS App Runner service.

        Access Level: Write

        https://docs.aws.amazon.com/apprunner/latest/api/API_StartDeployment.html

        :stability: experimental
        '''
        return typing.cast("Apprunner", jsii.invoke(self, "toStartDeployment", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Apprunner":
        '''(experimental) Grants permission to add tags to, or update tag values of, an AWS App Runner resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/apprunner/latest/api/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("Apprunner", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Apprunner":
        '''(experimental) Grants permission to remove tags from an AWS App Runner resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/apprunner/latest/api/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("Apprunner", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateService")
    def to_update_service(self) -> "Apprunner":
        '''(experimental) Grants permission to update an AWS App Runner service resource.

        Access Level: Write

        Possible conditions:

        - .ifConnectionArn()
        - .ifAutoScalingConfigurationArn()
        - .ifObservabilityConfigurationArn()
        - .ifVpcConnectorArn()

        https://docs.aws.amazon.com/apprunner/latest/api/API_UpdateService.html

        :stability: experimental
        '''
        return typing.cast("Apprunner", jsii.invoke(self, "toUpdateService", []))

    @jsii.member(jsii_name="toUpdateVpcIngressConnection")
    def to_update_vpc_ingress_connection(self) -> "Apprunner":
        '''(experimental) Grants permission to update an AWS App Runner VpcIngressConnection resource.

        Access Level: Write

        Possible conditions:

        - .ifVpcId()
        - .ifVpcEndpointId()

        https://docs.aws.amazon.com/apprunner/latest/api/API_UpdateVpcIngressConnection.html

        :stability: experimental
        '''
        return typing.cast("Apprunner", jsii.invoke(self, "toUpdateVpcIngressConnection", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__641edeee6bdac50886eeb1f06fee332e5423210d41e7057f6b45ab61c18aa9b4)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6908f18e29d3709a1df7e677584e8d1c364134af217a0bd1cfe7b977dea34e2d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Appstream(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Appstream",
):
    '''(experimental) Statement provider for service `appstream <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonappstream2.0.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `appstream <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonappstream2.0.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="ifUserId")
    def if_user_id(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Appstream":
        '''(experimental) Filters access by the ID of the AppStream 2.0 user.

        https://docs.aws.amazon.com/appstream2/latest/developerguide/external-identity-providers-setting-up-saml.html#external-identity-providers-embed-inline-policy-for-IAM-role

        Applies to actions:

        - .toStream()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9c3103744b8b286dbca5e188a0c4868b11114f24465fbbd7d59c607aae4870bb)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Appstream", jsii.invoke(self, "ifUserId", [value, operator]))

    @jsii.member(jsii_name="onAppBlock")
    def on_app_block(
        self,
        app_block_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Appstream":
        '''(experimental) Adds a resource of type app-block to the statement.

        https://docs.aws.amazon.com/appstream2/latest/developerguide/what-is-appstream.html#what-is-concepts

        :param app_block_name: - Identifier for the appBlockName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c21a1dc7d85d755bdda462d51aa4f63369a1a6f72f73517218d7d15992fa94c3)
            check_type(argname="argument app_block_name", value=app_block_name, expected_type=type_hints["app_block_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Appstream", jsii.invoke(self, "onAppBlock", [app_block_name, account, region, partition]))

    @jsii.member(jsii_name="onApplication")
    def on_application(
        self,
        application_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Appstream":
        '''(experimental) Adds a resource of type application to the statement.

        https://docs.aws.amazon.com/appstream2/latest/developerguide/what-is-appstream.html#what-is-concepts

        :param application_name: - Identifier for the applicationName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__296ab8aa7e35ebf5530cc5d540b51cd91d6e902439ec9bf9246f20fca2111837)
            check_type(argname="argument application_name", value=application_name, expected_type=type_hints["application_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Appstream", jsii.invoke(self, "onApplication", [application_name, account, region, partition]))

    @jsii.member(jsii_name="onFleet")
    def on_fleet(
        self,
        fleet_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Appstream":
        '''(experimental) Adds a resource of type fleet to the statement.

        https://docs.aws.amazon.com/appstream2/latest/developerguide/what-is-appstream.html#what-is-concepts

        :param fleet_name: - Identifier for the fleetName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fe9c947bf7064ee29b81ad14301d2bcf59bf95791c14ca0c8b147c5b8ba3e76f)
            check_type(argname="argument fleet_name", value=fleet_name, expected_type=type_hints["fleet_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Appstream", jsii.invoke(self, "onFleet", [fleet_name, account, region, partition]))

    @jsii.member(jsii_name="onImage")
    def on_image(
        self,
        image_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Appstream":
        '''(experimental) Adds a resource of type image to the statement.

        https://docs.aws.amazon.com/appstream2/latest/developerguide/what-is-appstream.html#what-is-concepts

        :param image_name: - Identifier for the imageName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a4e34b9d04809859742ad98bf03d9f7fdd4be26212803742301f6d2014959acf)
            check_type(argname="argument image_name", value=image_name, expected_type=type_hints["image_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Appstream", jsii.invoke(self, "onImage", [image_name, account, region, partition]))

    @jsii.member(jsii_name="onImageBuilder")
    def on_image_builder(
        self,
        image_builder_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Appstream":
        '''(experimental) Adds a resource of type image-builder to the statement.

        https://docs.aws.amazon.com/appstream2/latest/developerguide/what-is-appstream.html#what-is-concepts

        :param image_builder_name: - Identifier for the imageBuilderName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__35ae0922a44404aefac8dd4080fa0f029b21302e523c36c8d76d943ed501c319)
            check_type(argname="argument image_builder_name", value=image_builder_name, expected_type=type_hints["image_builder_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Appstream", jsii.invoke(self, "onImageBuilder", [image_builder_name, account, region, partition]))

    @jsii.member(jsii_name="onStack")
    def on_stack(
        self,
        stack_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Appstream":
        '''(experimental) Adds a resource of type stack to the statement.

        https://docs.aws.amazon.com/appstream2/latest/developerguide/what-is-appstream.html#what-is-concepts

        :param stack_name: - Identifier for the stackName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6cfe5fd735aa0c13c5317576f2bd9145395789f6cbef08e7c20cad2346cb56dc)
            check_type(argname="argument stack_name", value=stack_name, expected_type=type_hints["stack_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Appstream", jsii.invoke(self, "onStack", [stack_name, account, region, partition]))

    @jsii.member(jsii_name="toAssociateApplicationFleet")
    def to_associate_application_fleet(self) -> "Appstream":
        '''(experimental) Grants permission to associate the specified application with the fleet.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/appstream2/latest/APIReference/API_AssociateApplicationFleet.html

        :stability: experimental
        '''
        return typing.cast("Appstream", jsii.invoke(self, "toAssociateApplicationFleet", []))

    @jsii.member(jsii_name="toAssociateApplicationToEntitlement")
    def to_associate_application_to_entitlement(self) -> "Appstream":
        '''(experimental) Grants permission to associate the specified application to the specified entitlement.

        Access Level: Write

        https://docs.aws.amazon.com/appstream2/latest/APIReference/API_AssociateApplicationToEntitlement.html

        :stability: experimental
        '''
        return typing.cast("Appstream", jsii.invoke(self, "toAssociateApplicationToEntitlement", []))

    @jsii.member(jsii_name="toAssociateFleet")
    def to_associate_fleet(self) -> "Appstream":
        '''(experimental) Grants permission to associate the specified fleet with the specified stack.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/appstream2/latest/APIReference/API_AssociateFleet.html

        :stability: experimental
        '''
        return typing.cast("Appstream", jsii.invoke(self, "toAssociateFleet", []))

    @jsii.member(jsii_name="toBatchAssociateUserStack")
    def to_batch_associate_user_stack(self) -> "Appstream":
        '''(experimental) Grants permission to associate the specified users with the specified stacks.

        Users in a user pool cannot be assigned to stacks with fleets that are joined to an Active Directory domain

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/appstream2/latest/APIReference/API_BatchAssociateUserStack.html

        :stability: experimental
        '''
        return typing.cast("Appstream", jsii.invoke(self, "toBatchAssociateUserStack", []))

    @jsii.member(jsii_name="toBatchDisassociateUserStack")
    def to_batch_disassociate_user_stack(self) -> "Appstream":
        '''(experimental) Grants permission to disassociate the specified users from the specified stacks.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/appstream2/latest/APIReference/API_BatchDisassociateUserStack.html

        :stability: experimental
        '''
        return typing.cast("Appstream", jsii.invoke(self, "toBatchDisassociateUserStack", []))

    @jsii.member(jsii_name="toCopyImage")
    def to_copy_image(self) -> "Appstream":
        '''(experimental) Grants permission to copy the specified image within the same Region or to a new Region within the same AWS account.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/appstream2/latest/APIReference/API_CopyImage.html

        :stability: experimental
        '''
        return typing.cast("Appstream", jsii.invoke(self, "toCopyImage", []))

    @jsii.member(jsii_name="toCreateAppBlock")
    def to_create_app_block(self) -> "Appstream":
        '''(experimental) Grants permission to create an app block.

        App blocks store details about the virtual hard disk that contains the files for the application in an S3 bucket. It also stores the setup script with details about how to mount the virtual hard disk. App blocks are only supported for Elastic fleets

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsResourceTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/appstream2/latest/APIReference/API_CreateAppBlock.html

        :stability: experimental
        '''
        return typing.cast("Appstream", jsii.invoke(self, "toCreateAppBlock", []))

    @jsii.member(jsii_name="toCreateApplication")
    def to_create_application(self) -> "Appstream":
        '''(experimental) Grants permission to create an application within customer account.

        Applications store the details about how to launch applications on streaming instances. This is only supported for Elastic fleets

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsResourceTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/appstream2/latest/APIReference/API_CreateApplication.html

        :stability: experimental
        '''
        return typing.cast("Appstream", jsii.invoke(self, "toCreateApplication", []))

    @jsii.member(jsii_name="toCreateDirectoryConfig")
    def to_create_directory_config(self) -> "Appstream":
        '''(experimental) Grants permission to create a Directory Config object in AppStream 2.0. This object includes the configuration information required to join fleets and image builders to Microsoft Active Directory domains.

        Access Level: Write

        https://docs.aws.amazon.com/appstream2/latest/APIReference/API_CreateDirectoryConfig.html

        :stability: experimental
        '''
        return typing.cast("Appstream", jsii.invoke(self, "toCreateDirectoryConfig", []))

    @jsii.member(jsii_name="toCreateEntitlement")
    def to_create_entitlement(self) -> "Appstream":
        '''(experimental) Grants permission to create an entitlement to control access to applications based on user attributes.

        Access Level: Write

        https://docs.aws.amazon.com/appstream2/latest/APIReference/API_CreateEntitlement.html

        :stability: experimental
        '''
        return typing.cast("Appstream", jsii.invoke(self, "toCreateEntitlement", []))

    @jsii.member(jsii_name="toCreateFleet")
    def to_create_fleet(self) -> "Appstream":
        '''(experimental) Grants permission to create a fleet.

        A fleet is a group of streaming instances from which applications are launched and streamed to users

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/appstream2/latest/APIReference/API_CreateFleet.html

        :stability: experimental
        '''
        return typing.cast("Appstream", jsii.invoke(self, "toCreateFleet", []))

    @jsii.member(jsii_name="toCreateImageBuilder")
    def to_create_image_builder(self) -> "Appstream":
        '''(experimental) Grants permission to create an image builder.

        An image builder is a virtual machine that is used to create an image

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/appstream2/latest/APIReference/API_CreateImageBuilder.html

        :stability: experimental
        '''
        return typing.cast("Appstream", jsii.invoke(self, "toCreateImageBuilder", []))

    @jsii.member(jsii_name="toCreateImageBuilderStreamingURL")
    def to_create_image_builder_streaming_url(self) -> "Appstream":
        '''(experimental) Grants permission to create a URL to start an image builder streaming session.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/appstream2/latest/APIReference/API_CreateImageBuilderStreamingURL.html

        :stability: experimental
        '''
        return typing.cast("Appstream", jsii.invoke(self, "toCreateImageBuilderStreamingURL", []))

    @jsii.member(jsii_name="toCreateStack")
    def to_create_stack(self) -> "Appstream":
        '''(experimental) Grants permission to create a stack to start streaming applications to users.

        A stack consists of an associated fleet, user access policies, and storage configurations

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/appstream2/latest/APIReference/API_CreateStack.html

        :stability: experimental
        '''
        return typing.cast("Appstream", jsii.invoke(self, "toCreateStack", []))

    @jsii.member(jsii_name="toCreateStreamingURL")
    def to_create_streaming_url(self) -> "Appstream":
        '''(experimental) Grants permission to create a temporary URL to start an AppStream 2.0 streaming session for the specified user. A streaming URL enables application streaming to be tested without user setup.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/appstream2/latest/APIReference/API_CreateStreamingURL.html

        :stability: experimental
        '''
        return typing.cast("Appstream", jsii.invoke(self, "toCreateStreamingURL", []))

    @jsii.member(jsii_name="toCreateUpdatedImage")
    def to_create_updated_image(self) -> "Appstream":
        '''(experimental) Grants permission to update an existing image within customer account.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsResourceTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/appstream2/latest/APIReference/API_CreateUpdatedImage.html

        :stability: experimental
        '''
        return typing.cast("Appstream", jsii.invoke(self, "toCreateUpdatedImage", []))

    @jsii.member(jsii_name="toCreateUsageReportSubscription")
    def to_create_usage_report_subscription(self) -> "Appstream":
        '''(experimental) Grants permission to create a usage report subscription. Usage reports are generated daily.

        Access Level: Write

        https://docs.aws.amazon.com/appstream2/latest/APIReference/API_CreateUsageReportSubscription.html

        :stability: experimental
        '''
        return typing.cast("Appstream", jsii.invoke(self, "toCreateUsageReportSubscription", []))

    @jsii.member(jsii_name="toCreateUser")
    def to_create_user(self) -> "Appstream":
        '''(experimental) Grants permission to create a new user in the user pool.

        Access Level: Write

        https://docs.aws.amazon.com/appstream2/latest/APIReference/API_CreateUser.html

        :stability: experimental
        '''
        return typing.cast("Appstream", jsii.invoke(self, "toCreateUser", []))

    @jsii.member(jsii_name="toDeleteAppBlock")
    def to_delete_app_block(self) -> "Appstream":
        '''(experimental) Grants permission to delete the specified app block.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/appstream2/latest/APIReference/API_DeleteAppBlock.html

        :stability: experimental
        '''
        return typing.cast("Appstream", jsii.invoke(self, "toDeleteAppBlock", []))

    @jsii.member(jsii_name="toDeleteApplication")
    def to_delete_application(self) -> "Appstream":
        '''(experimental) Grants permission to delete the specified application.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/appstream2/latest/APIReference/API_DeleteApplication.html

        :stability: experimental
        '''
        return typing.cast("Appstream", jsii.invoke(self, "toDeleteApplication", []))

    @jsii.member(jsii_name="toDeleteDirectoryConfig")
    def to_delete_directory_config(self) -> "Appstream":
        '''(experimental) Grants permission to delete the specified Directory Config object from AppStream 2.0. This object includes the configuration information required to join fleets and image builders to Microsoft Active Directory domains.

        Access Level: Write

        https://docs.aws.amazon.com/appstream2/latest/APIReference/API_DeleteDirectoryConfig.html

        :stability: experimental
        '''
        return typing.cast("Appstream", jsii.invoke(self, "toDeleteDirectoryConfig", []))

    @jsii.member(jsii_name="toDeleteEntitlement")
    def to_delete_entitlement(self) -> "Appstream":
        '''(experimental) Grants permission to delete the specified entitlement.

        Access Level: Write

        https://docs.aws.amazon.com/appstream2/latest/APIReference/API_DeleteEntitlement.html

        :stability: experimental
        '''
        return typing.cast("Appstream", jsii.invoke(self, "toDeleteEntitlement", []))

    @jsii.member(jsii_name="toDeleteFleet")
    def to_delete_fleet(self) -> "Appstream":
        '''(experimental) Grants permission to delete the specified fleet.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/appstream2/latest/APIReference/API_DeleteFleet.html

        :stability: experimental
        '''
        return typing.cast("Appstream", jsii.invoke(self, "toDeleteFleet", []))

    @jsii.member(jsii_name="toDeleteImage")
    def to_delete_image(self) -> "Appstream":
        '''(experimental) Grants permission to delete the specified image. An image cannot be deleted when it is in use.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/appstream2/latest/APIReference/API_DeleteImage.html

        :stability: experimental
        '''
        return typing.cast("Appstream", jsii.invoke(self, "toDeleteImage", []))

    @jsii.member(jsii_name="toDeleteImageBuilder")
    def to_delete_image_builder(self) -> "Appstream":
        '''(experimental) Grants permission to delete the specified image builder and release capacity.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/appstream2/latest/APIReference/API_DeleteImageBuilder.html

        :stability: experimental
        '''
        return typing.cast("Appstream", jsii.invoke(self, "toDeleteImageBuilder", []))

    @jsii.member(jsii_name="toDeleteImagePermissions")
    def to_delete_image_permissions(self) -> "Appstream":
        '''(experimental) Grants permission to delete permissions for the specified private image.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/appstream2/latest/APIReference/API_DeleteImagePermissions.html

        :stability: experimental
        '''
        return typing.cast("Appstream", jsii.invoke(self, "toDeleteImagePermissions", []))

    @jsii.member(jsii_name="toDeleteStack")
    def to_delete_stack(self) -> "Appstream":
        '''(experimental) Grants permission to delete the specified stack.

        After the stack is deleted, the application streaming environment provided by the stack is no longer available to users. Also, any reservations made for application streaming sessions for the stack are released

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/appstream2/latest/APIReference/API_DeleteStack.html

        :stability: experimental
        '''
        return typing.cast("Appstream", jsii.invoke(self, "toDeleteStack", []))

    @jsii.member(jsii_name="toDeleteUsageReportSubscription")
    def to_delete_usage_report_subscription(self) -> "Appstream":
        '''(experimental) Grants permission to disable usage report generation.

        Access Level: Write

        https://docs.aws.amazon.com/appstream2/latest/APIReference/API_DeleteUsageReportSubscription.html

        :stability: experimental
        '''
        return typing.cast("Appstream", jsii.invoke(self, "toDeleteUsageReportSubscription", []))

    @jsii.member(jsii_name="toDeleteUser")
    def to_delete_user(self) -> "Appstream":
        '''(experimental) Grants permission to delete a user from the user pool.

        Access Level: Write

        https://docs.aws.amazon.com/appstream2/latest/APIReference/API_DeleteUser.html

        :stability: experimental
        '''
        return typing.cast("Appstream", jsii.invoke(self, "toDeleteUser", []))

    @jsii.member(jsii_name="toDescribeAppBlocks")
    def to_describe_app_blocks(self) -> "Appstream":
        '''(experimental) Grants permission to retrieve a list that describes one or more specified app blocks, if the app block arns are provided.

        Otherwise, all app blocks in the account are described

        Access Level: Read

        https://docs.aws.amazon.com/appstream2/latest/APIReference/API_DescribeAppBlocks.html

        :stability: experimental
        '''
        return typing.cast("Appstream", jsii.invoke(self, "toDescribeAppBlocks", []))

    @jsii.member(jsii_name="toDescribeApplicationFleetAssociations")
    def to_describe_application_fleet_associations(self) -> "Appstream":
        '''(experimental) Grants permission to retrieve the associations that are associated with the specified application or fleet.

        Access Level: Read

        https://docs.aws.amazon.com/appstream2/latest/APIReference/API_DescribeApplicationFleetAssociations.html

        :stability: experimental
        '''
        return typing.cast("Appstream", jsii.invoke(self, "toDescribeApplicationFleetAssociations", []))

    @jsii.member(jsii_name="toDescribeApplications")
    def to_describe_applications(self) -> "Appstream":
        '''(experimental) Grants permission to retrieve a list that describes one or more specified applications, if the application arns are provided.

        Otherwise, all applications in the account are described

        Access Level: Read

        https://docs.aws.amazon.com/appstream2/latest/APIReference/API_DescribeApplications.html

        :stability: experimental
        '''
        return typing.cast("Appstream", jsii.invoke(self, "toDescribeApplications", []))

    @jsii.member(jsii_name="toDescribeDirectoryConfigs")
    def to_describe_directory_configs(self) -> "Appstream":
        '''(experimental) Grants permission to retrieve a list that describes one or more specified Directory Config objects for AppStream 2.0, if the names for these objects are provided. Otherwise, all Directory Config objects in the account are described. This object includes the configuration information required to join fleets and image builders to Microsoft Active Directory domains.

        Access Level: Read

        https://docs.aws.amazon.com/appstream2/latest/APIReference/API_DescribeDirectoryConfigs.html

        :stability: experimental
        '''
        return typing.cast("Appstream", jsii.invoke(self, "toDescribeDirectoryConfigs", []))

    @jsii.member(jsii_name="toDescribeEntitlements")
    def to_describe_entitlements(self) -> "Appstream":
        '''(experimental) Grants permission to retrieve one or all entitlements for the specified stack.

        Access Level: Read

        https://docs.aws.amazon.com/appstream2/latest/APIReference/API_DescribeEntitlements.html

        :stability: experimental
        '''
        return typing.cast("Appstream", jsii.invoke(self, "toDescribeEntitlements", []))

    @jsii.member(jsii_name="toDescribeFleets")
    def to_describe_fleets(self) -> "Appstream":
        '''(experimental) Grants permission to retrieve a list that describes one or more specified fleets, if the fleet names are provided.

        Otherwise, all fleets in the account are described

        Access Level: Read

        https://docs.aws.amazon.com/appstream2/latest/APIReference/API_DescribeFleets.html

        :stability: experimental
        '''
        return typing.cast("Appstream", jsii.invoke(self, "toDescribeFleets", []))

    @jsii.member(jsii_name="toDescribeImageBuilders")
    def to_describe_image_builders(self) -> "Appstream":
        '''(experimental) Grants permission to retrieve a list that describes one or more specified image builders, if the image builder names are provided.

        Otherwise, all image builders in the account are described

        Access Level: Read

        https://docs.aws.amazon.com/appstream2/latest/APIReference/API_DescribeImageBuilders.html

        :stability: experimental
        '''
        return typing.cast("Appstream", jsii.invoke(self, "toDescribeImageBuilders", []))

    @jsii.member(jsii_name="toDescribeImagePermissions")
    def to_describe_image_permissions(self) -> "Appstream":
        '''(experimental) Grants permission to retrieve a list that describes the permissions for shared AWS account IDs on a private image that you own.

        Access Level: Read

        https://docs.aws.amazon.com/appstream2/latest/APIReference/API_DescribeImagePermissions.html

        :stability: experimental
        '''
        return typing.cast("Appstream", jsii.invoke(self, "toDescribeImagePermissions", []))

    @jsii.member(jsii_name="toDescribeImages")
    def to_describe_images(self) -> "Appstream":
        '''(experimental) Grants permission to retrieve a list that describes one or more specified images, if the image names or image ARNs are provided.

        Otherwise, all images in the account are described

        Access Level: Read

        https://docs.aws.amazon.com/appstream2/latest/APIReference/API_DescribeImages.html

        :stability: experimental
        '''
        return typing.cast("Appstream", jsii.invoke(self, "toDescribeImages", []))

    @jsii.member(jsii_name="toDescribeSessions")
    def to_describe_sessions(self) -> "Appstream":
        '''(experimental) Grants permission to retrieve a list that describes the streaming sessions for the specified stack and fleet.

        If a user ID is provided for the stack and fleet, only the streaming sessions for that user are described

        Access Level: Read

        https://docs.aws.amazon.com/appstream2/latest/APIReference/API_DescribeSessions.html

        :stability: experimental
        '''
        return typing.cast("Appstream", jsii.invoke(self, "toDescribeSessions", []))

    @jsii.member(jsii_name="toDescribeStacks")
    def to_describe_stacks(self) -> "Appstream":
        '''(experimental) Grants permission to retrieve a list that describes one or more specified stacks, if the stack names are provided.

        Otherwise, all stacks in the account are described

        Access Level: Read

        https://docs.aws.amazon.com/appstream2/latest/APIReference/API_DescribeStacks.html

        :stability: experimental
        '''
        return typing.cast("Appstream", jsii.invoke(self, "toDescribeStacks", []))

    @jsii.member(jsii_name="toDescribeUsageReportSubscriptions")
    def to_describe_usage_report_subscriptions(self) -> "Appstream":
        '''(experimental) Grants permission to retrieve a list that describes one or more usage report subscriptions.

        Access Level: Read

        https://docs.aws.amazon.com/appstream2/latest/APIReference/API_DescribeUsageReportSubscriptions.html

        :stability: experimental
        '''
        return typing.cast("Appstream", jsii.invoke(self, "toDescribeUsageReportSubscriptions", []))

    @jsii.member(jsii_name="toDescribeUsers")
    def to_describe_users(self) -> "Appstream":
        '''(experimental) Grants permission to retrieve a list that describes users in the user pool.

        Access Level: Read

        https://docs.aws.amazon.com/appstream2/latest/APIReference/API_DescribeUsers.html

        :stability: experimental
        '''
        return typing.cast("Appstream", jsii.invoke(self, "toDescribeUsers", []))

    @jsii.member(jsii_name="toDescribeUserStackAssociations")
    def to_describe_user_stack_associations(self) -> "Appstream":
        '''(experimental) Grants permission to retrieve a list that describes the UserStackAssociation objects.

        Access Level: Read

        https://docs.aws.amazon.com/appstream2/latest/APIReference/API_DescribeUserStackAssociations.html

        :stability: experimental
        '''
        return typing.cast("Appstream", jsii.invoke(self, "toDescribeUserStackAssociations", []))

    @jsii.member(jsii_name="toDisableUser")
    def to_disable_user(self) -> "Appstream":
        '''(experimental) Grants permission to disable the specified user in the user pool. This action does not delete the user.

        Access Level: Write

        https://docs.aws.amazon.com/appstream2/latest/APIReference/API_DisableUser.html

        :stability: experimental
        '''
        return typing.cast("Appstream", jsii.invoke(self, "toDisableUser", []))

    @jsii.member(jsii_name="toDisassociateApplicationFleet")
    def to_disassociate_application_fleet(self) -> "Appstream":
        '''(experimental) Grants permission to disassociate the specified application from the specified fleet.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/appstream2/latest/APIReference/API_DisassociateApplicationFleet.html

        :stability: experimental
        '''
        return typing.cast("Appstream", jsii.invoke(self, "toDisassociateApplicationFleet", []))

    @jsii.member(jsii_name="toDisassociateApplicationFromEntitlement")
    def to_disassociate_application_from_entitlement(self) -> "Appstream":
        '''(experimental) Grants permission to disassociate the specified application from the specified entitlement.

        Access Level: Write

        https://docs.aws.amazon.com/appstream2/latest/APIReference/API_DisassociateApplicationFromEntitlement.html

        :stability: experimental
        '''
        return typing.cast("Appstream", jsii.invoke(self, "toDisassociateApplicationFromEntitlement", []))

    @jsii.member(jsii_name="toDisassociateFleet")
    def to_disassociate_fleet(self) -> "Appstream":
        '''(experimental) Grants permission to disassociate the specified fleet from the specified stack.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/appstream2/latest/APIReference/API_DisassociateFleet.html

        :stability: experimental
        '''
        return typing.cast("Appstream", jsii.invoke(self, "toDisassociateFleet", []))

    @jsii.member(jsii_name="toEnableUser")
    def to_enable_user(self) -> "Appstream":
        '''(experimental) Grants permission to enable a user in the user pool.

        Access Level: Write

        https://docs.aws.amazon.com/appstream2/latest/APIReference/API_EnableUser.html

        :stability: experimental
        '''
        return typing.cast("Appstream", jsii.invoke(self, "toEnableUser", []))

    @jsii.member(jsii_name="toExpireSession")
    def to_expire_session(self) -> "Appstream":
        '''(experimental) Grants permission to immediately stop the specified streaming session.

        Access Level: Write

        https://docs.aws.amazon.com/appstream2/latest/APIReference/API_ExpireSession.html

        :stability: experimental
        '''
        return typing.cast("Appstream", jsii.invoke(self, "toExpireSession", []))

    @jsii.member(jsii_name="toListAssociatedFleets")
    def to_list_associated_fleets(self) -> "Appstream":
        '''(experimental) Grants permission to retrieve the name of the fleet that is associated with the specified stack.

        Access Level: Read

        https://docs.aws.amazon.com/appstream2/latest/APIReference/API_ListAssociatedFleets.html

        :stability: experimental
        '''
        return typing.cast("Appstream", jsii.invoke(self, "toListAssociatedFleets", []))

    @jsii.member(jsii_name="toListAssociatedStacks")
    def to_list_associated_stacks(self) -> "Appstream":
        '''(experimental) Grants permission to retrieve the name of the stack with which the specified fleet is associated.

        Access Level: Read

        https://docs.aws.amazon.com/appstream2/latest/APIReference/API_ListAssociatedStacks.html

        :stability: experimental
        '''
        return typing.cast("Appstream", jsii.invoke(self, "toListAssociatedStacks", []))

    @jsii.member(jsii_name="toListEntitledApplications")
    def to_list_entitled_applications(self) -> "Appstream":
        '''(experimental) Grants permission to retrieve the applications that are associated with the specified entitlement.

        Access Level: List

        https://docs.aws.amazon.com/appstream2/latest/APIReference/API_ListEntitledApplications.html

        :stability: experimental
        '''
        return typing.cast("Appstream", jsii.invoke(self, "toListEntitledApplications", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Appstream":
        '''(experimental) Grants permission to retrieve a list of all tags for the specified AppStream 2.0 resource. The following resources can be tagged: Image builders, images, fleets, and stacks.

        Access Level: Read

        https://docs.aws.amazon.com/appstream2/latest/APIReference/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("Appstream", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toStartFleet")
    def to_start_fleet(self) -> "Appstream":
        '''(experimental) Grants permission to start the specified fleet.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/appstream2/latest/APIReference/API_StartFleet.html

        :stability: experimental
        '''
        return typing.cast("Appstream", jsii.invoke(self, "toStartFleet", []))

    @jsii.member(jsii_name="toStartImageBuilder")
    def to_start_image_builder(self) -> "Appstream":
        '''(experimental) Grants permission to start the specified image builder.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/appstream2/latest/APIReference/API_StartImageBuilder.html

        :stability: experimental
        '''
        return typing.cast("Appstream", jsii.invoke(self, "toStartImageBuilder", []))

    @jsii.member(jsii_name="toStopFleet")
    def to_stop_fleet(self) -> "Appstream":
        '''(experimental) Grants permission to stop the specified fleet.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/appstream2/latest/APIReference/API_StopFleet.html

        :stability: experimental
        '''
        return typing.cast("Appstream", jsii.invoke(self, "toStopFleet", []))

    @jsii.member(jsii_name="toStopImageBuilder")
    def to_stop_image_builder(self) -> "Appstream":
        '''(experimental) Grants permission to stop the specified image builder.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/appstream2/latest/APIReference/API_StopImageBuilder.html

        :stability: experimental
        '''
        return typing.cast("Appstream", jsii.invoke(self, "toStopImageBuilder", []))

    @jsii.member(jsii_name="toStream")
    def to_stream(self) -> "Appstream":
        '''(experimental) Grants permission to federated users to sign in by using their existing credentials and stream applications from the specified stack.

        Access Level: Write

        Possible conditions:

        - .ifUserId()

        https://docs.aws.amazon.com/appstream2/latest/developerguide/external-identity-providers-setting-up-saml.html#external-identity-providers-embed-inline-policy-for-IAM-role

        :stability: experimental
        '''
        return typing.cast("Appstream", jsii.invoke(self, "toStream", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Appstream":
        '''(experimental) Grants permission to add or overwrite one or more tags for the specified AppStream 2.0 resource. The following resources can be tagged: Image builders, images, fleets, stacks, app blocks and applications.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/appstream2/latest/APIReference/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("Appstream", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Appstream":
        '''(experimental) Grants permission to disassociate one or more tags from the specified AppStream 2.0 resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/appstream2/latest/APIReference/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("Appstream", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateApplication")
    def to_update_application(self) -> "Appstream":
        '''(experimental) Grants permission to update the specified fields for the specified application.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/appstream2/latest/APIReference/API_UpdateApplication.html

        :stability: experimental
        '''
        return typing.cast("Appstream", jsii.invoke(self, "toUpdateApplication", []))

    @jsii.member(jsii_name="toUpdateDirectoryConfig")
    def to_update_directory_config(self) -> "Appstream":
        '''(experimental) Grants permission to update the specified Directory Config object in AppStream 2.0. This object includes the configuration information required to join fleets and image builders to Microsoft Active Directory domains.

        Access Level: Write

        https://docs.aws.amazon.com/appstream2/latest/APIReference/API_UpdateDirectoryConfig.html

        :stability: experimental
        '''
        return typing.cast("Appstream", jsii.invoke(self, "toUpdateDirectoryConfig", []))

    @jsii.member(jsii_name="toUpdateEntitlement")
    def to_update_entitlement(self) -> "Appstream":
        '''(experimental) Grants permission to update the specified fields for the specified entitlement.

        Access Level: Write

        https://docs.aws.amazon.com/appstream2/latest/APIReference/API_UpdateEntitlement.html

        :stability: experimental
        '''
        return typing.cast("Appstream", jsii.invoke(self, "toUpdateEntitlement", []))

    @jsii.member(jsii_name="toUpdateFleet")
    def to_update_fleet(self) -> "Appstream":
        '''(experimental) Grants permission to update the specified fleet.

        All attributes except the fleet name can be updated when the fleet is in the STOPPED state

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/appstream2/latest/APIReference/API_UpdateFleet.html

        :stability: experimental
        '''
        return typing.cast("Appstream", jsii.invoke(self, "toUpdateFleet", []))

    @jsii.member(jsii_name="toUpdateImagePermissions")
    def to_update_image_permissions(self) -> "Appstream":
        '''(experimental) Grants permission to add or update permissions for the specified private image.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/appstream2/latest/APIReference/API_UpdateImagePermissions.html

        :stability: experimental
        '''
        return typing.cast("Appstream", jsii.invoke(self, "toUpdateImagePermissions", []))

    @jsii.member(jsii_name="toUpdateStack")
    def to_update_stack(self) -> "Appstream":
        '''(experimental) Grants permission to update the specified fields for the specified stack.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/appstream2/latest/APIReference/API_UpdateStack.html

        :stability: experimental
        '''
        return typing.cast("Appstream", jsii.invoke(self, "toUpdateStack", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1158b42a888862e24f8331ca49b4b58e491885859f9f292b78df74b3a759243f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c9ea8cfd9733773ccd2ba74ca028cc2622be45b6e824eb7459572442333fffa5)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Appsync(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Appsync",
):
    '''(experimental) Statement provider for service `appsync <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsappsync.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `appsync <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsappsync.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onDatasource")
    def on_datasource(
        self,
        graph_qlapi_id: builtins.str,
        datasource_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Appsync":
        '''(experimental) Adds a resource of type datasource to the statement.

        https://docs.aws.amazon.com/appsync/latest/devguide/attaching-a-data-source.html

        :param graph_qlapi_id: - Identifier for the graphQLAPIId.
        :param datasource_name: - Identifier for the datasourceName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5545765636ccf7df98006000d46560520bddd699936e4f96ac6c431dd7d089a5)
            check_type(argname="argument graph_qlapi_id", value=graph_qlapi_id, expected_type=type_hints["graph_qlapi_id"])
            check_type(argname="argument datasource_name", value=datasource_name, expected_type=type_hints["datasource_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Appsync", jsii.invoke(self, "onDatasource", [graph_qlapi_id, datasource_name, account, region, partition]))

    @jsii.member(jsii_name="onDomain")
    def on_domain(
        self,
        domain_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Appsync":
        '''(experimental) Adds a resource of type domain to the statement.

        https://docs.aws.amazon.com/appsync/latest/devguide/custom-domain-name.html

        :param domain_name: - Identifier for the domainName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3c464b78c52e23cc8ed7656624e0826b0d417c8276b8e3d6154fd25cfa6b0d95)
            check_type(argname="argument domain_name", value=domain_name, expected_type=type_hints["domain_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Appsync", jsii.invoke(self, "onDomain", [domain_name, account, region, partition]))

    @jsii.member(jsii_name="onField")
    def on_field(
        self,
        graph_qlapi_id: builtins.str,
        type_name: builtins.str,
        field_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Appsync":
        '''(experimental) Adds a resource of type field to the statement.

        https://docs.aws.amazon.com/appsync/latest/devguide/configuring-resolvers.html

        :param graph_qlapi_id: - Identifier for the graphQLAPIId.
        :param type_name: - Identifier for the typeName.
        :param field_name: - Identifier for the fieldName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bd87d283796fade52f9b7c64a392e569227b8dd90aed806893df8a6b539095fe)
            check_type(argname="argument graph_qlapi_id", value=graph_qlapi_id, expected_type=type_hints["graph_qlapi_id"])
            check_type(argname="argument type_name", value=type_name, expected_type=type_hints["type_name"])
            check_type(argname="argument field_name", value=field_name, expected_type=type_hints["field_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Appsync", jsii.invoke(self, "onField", [graph_qlapi_id, type_name, field_name, account, region, partition]))

    @jsii.member(jsii_name="onFunction")
    def on_function(
        self,
        graph_qlapi_id: builtins.str,
        function_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Appsync":
        '''(experimental) Adds a resource of type function to the statement.

        https://docs.aws.amazon.com/appsync/latest/devguide/pipeline-resolvers.html

        :param graph_qlapi_id: - Identifier for the graphQLAPIId.
        :param function_id: - Identifier for the functionId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__52f6ffcdfa0c3ee3089d9ca8095d6466a480c2bd17c87feb5cb685c10d06a690)
            check_type(argname="argument graph_qlapi_id", value=graph_qlapi_id, expected_type=type_hints["graph_qlapi_id"])
            check_type(argname="argument function_id", value=function_id, expected_type=type_hints["function_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Appsync", jsii.invoke(self, "onFunction", [graph_qlapi_id, function_id, account, region, partition]))

    @jsii.member(jsii_name="onGraphqlapi")
    def on_graphqlapi(
        self,
        graph_qlapi_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Appsync":
        '''(experimental) Adds a resource of type graphqlapi to the statement.

        https://docs.aws.amazon.com/appsync/latest/devguide/designing-a-graphql-api.html

        :param graph_qlapi_id: - Identifier for the graphQLAPIId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__652cc30947f270177b163f2769ded3107a98a236c1984e08d58959735e0c47d3)
            check_type(argname="argument graph_qlapi_id", value=graph_qlapi_id, expected_type=type_hints["graph_qlapi_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Appsync", jsii.invoke(self, "onGraphqlapi", [graph_qlapi_id, account, region, partition]))

    @jsii.member(jsii_name="onType")
    def on_type(
        self,
        graph_qlapi_id: builtins.str,
        type_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Appsync":
        '''(experimental) Adds a resource of type type to the statement.

        https://docs.aws.amazon.com/appsync/latest/devguide/designing-your-schema.html#adding-a-root-query-type

        :param graph_qlapi_id: - Identifier for the graphQLAPIId.
        :param type_name: - Identifier for the typeName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3224da927b36dcb6456f5e529598a9647241036b4448b41f30114ef4e6b66231)
            check_type(argname="argument graph_qlapi_id", value=graph_qlapi_id, expected_type=type_hints["graph_qlapi_id"])
            check_type(argname="argument type_name", value=type_name, expected_type=type_hints["type_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Appsync", jsii.invoke(self, "onType", [graph_qlapi_id, type_name, account, region, partition]))

    @jsii.member(jsii_name="toAssociateApi")
    def to_associate_api(self) -> "Appsync":
        '''(experimental) Grants permission to attach a GraphQL API to a custom domain name in AppSync.

        Access Level: Write

        https://docs.aws.amazon.com/appsync/latest/APIReference/API_AssociateApi.html

        :stability: experimental
        '''
        return typing.cast("Appsync", jsii.invoke(self, "toAssociateApi", []))

    @jsii.member(jsii_name="toCreateApiCache")
    def to_create_api_cache(self) -> "Appsync":
        '''(experimental) Grants permission to create an API cache in AppSync.

        Access Level: Write

        https://docs.aws.amazon.com/appsync/latest/APIReference/API_CreateApiCache.html

        :stability: experimental
        '''
        return typing.cast("Appsync", jsii.invoke(self, "toCreateApiCache", []))

    @jsii.member(jsii_name="toCreateApiKey")
    def to_create_api_key(self) -> "Appsync":
        '''(experimental) Grants permission to create a unique key that you can distribute to clients who are executing your API.

        Access Level: Write

        https://docs.aws.amazon.com/appsync/latest/APIReference/API_CreateApiKey.html

        :stability: experimental
        '''
        return typing.cast("Appsync", jsii.invoke(self, "toCreateApiKey", []))

    @jsii.member(jsii_name="toCreateDataSource")
    def to_create_data_source(self) -> "Appsync":
        '''(experimental) Grants permission to create a data source.

        Access Level: Write

        https://docs.aws.amazon.com/appsync/latest/APIReference/API_CreateDataSource.html

        :stability: experimental
        '''
        return typing.cast("Appsync", jsii.invoke(self, "toCreateDataSource", []))

    @jsii.member(jsii_name="toCreateDomainName")
    def to_create_domain_name(self) -> "Appsync":
        '''(experimental) Grants permission to create a custom domain name in AppSync.

        Access Level: Write

        https://docs.aws.amazon.com/appsync/latest/APIReference/API_CreateDomainName.html

        :stability: experimental
        '''
        return typing.cast("Appsync", jsii.invoke(self, "toCreateDomainName", []))

    @jsii.member(jsii_name="toCreateFunction")
    def to_create_function(self) -> "Appsync":
        '''(experimental) Grants permission to create a new function.

        Access Level: Write

        https://docs.aws.amazon.com/appsync/latest/APIReference/API_CreateFunction.html

        :stability: experimental
        '''
        return typing.cast("Appsync", jsii.invoke(self, "toCreateFunction", []))

    @jsii.member(jsii_name="toCreateGraphqlApi")
    def to_create_graphql_api(self) -> "Appsync":
        '''(experimental) Grants permission to create a GraphQL API, which is the top level AppSync resource.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - iam:CreateServiceLinkedRole

        https://docs.aws.amazon.com/appsync/latest/APIReference/API_CreateGraphqlApi.html

        :stability: experimental
        '''
        return typing.cast("Appsync", jsii.invoke(self, "toCreateGraphqlApi", []))

    @jsii.member(jsii_name="toCreateResolver")
    def to_create_resolver(self) -> "Appsync":
        '''(experimental) Grants permission to create a resolver.

        A resolver converts incoming requests into a format that a data source can understand, and converts the data source's responses into GraphQL

        Access Level: Write

        https://docs.aws.amazon.com/appsync/latest/APIReference/API_CreateResolver.html

        :stability: experimental
        '''
        return typing.cast("Appsync", jsii.invoke(self, "toCreateResolver", []))

    @jsii.member(jsii_name="toCreateType")
    def to_create_type(self) -> "Appsync":
        '''(experimental) Grants permission to create a type.

        Access Level: Write

        https://docs.aws.amazon.com/appsync/latest/APIReference/API_CreateType.html

        :stability: experimental
        '''
        return typing.cast("Appsync", jsii.invoke(self, "toCreateType", []))

    @jsii.member(jsii_name="toDeleteApiCache")
    def to_delete_api_cache(self) -> "Appsync":
        '''(experimental) Grants permission to delete an API cache in AppSync.

        Access Level: Write

        https://docs.aws.amazon.com/appsync/latest/APIReference/API_DeleteApiCache.html

        :stability: experimental
        '''
        return typing.cast("Appsync", jsii.invoke(self, "toDeleteApiCache", []))

    @jsii.member(jsii_name="toDeleteApiKey")
    def to_delete_api_key(self) -> "Appsync":
        '''(experimental) Grants permission to delete an API key.

        Access Level: Write

        https://docs.aws.amazon.com/appsync/latest/APIReference/API_DeleteApiKey.html

        :stability: experimental
        '''
        return typing.cast("Appsync", jsii.invoke(self, "toDeleteApiKey", []))

    @jsii.member(jsii_name="toDeleteDataSource")
    def to_delete_data_source(self) -> "Appsync":
        '''(experimental) Grants permission to delete a data source.

        Access Level: Write

        https://docs.aws.amazon.com/appsync/latest/APIReference/API_DeleteDataSource.html

        :stability: experimental
        '''
        return typing.cast("Appsync", jsii.invoke(self, "toDeleteDataSource", []))

    @jsii.member(jsii_name="toDeleteDomainName")
    def to_delete_domain_name(self) -> "Appsync":
        '''(experimental) Grants permission to delete a custom domain name in AppSync.

        Access Level: Write

        https://docs.aws.amazon.com/appsync/latest/APIReference/API_DeleteDomainName.html

        :stability: experimental
        '''
        return typing.cast("Appsync", jsii.invoke(self, "toDeleteDomainName", []))

    @jsii.member(jsii_name="toDeleteFunction")
    def to_delete_function(self) -> "Appsync":
        '''(experimental) Grants permission to delete a function.

        Access Level: Write

        https://docs.aws.amazon.com/appsync/latest/APIReference/API_DeleteFunction.html

        :stability: experimental
        '''
        return typing.cast("Appsync", jsii.invoke(self, "toDeleteFunction", []))

    @jsii.member(jsii_name="toDeleteGraphqlApi")
    def to_delete_graphql_api(self) -> "Appsync":
        '''(experimental) Grants permission to delete a GraphQL Api. This will also clean up every AppSync resource below that API.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/appsync/latest/APIReference/API_DeleteGraphqlApi.html

        :stability: experimental
        '''
        return typing.cast("Appsync", jsii.invoke(self, "toDeleteGraphqlApi", []))

    @jsii.member(jsii_name="toDeleteResolver")
    def to_delete_resolver(self) -> "Appsync":
        '''(experimental) Grants permission to delete a resolver.

        Access Level: Write

        https://docs.aws.amazon.com/appsync/latest/APIReference/API_DeleteResolver.html

        :stability: experimental
        '''
        return typing.cast("Appsync", jsii.invoke(self, "toDeleteResolver", []))

    @jsii.member(jsii_name="toDeleteType")
    def to_delete_type(self) -> "Appsync":
        '''(experimental) Grants permission to delete a type.

        Access Level: Write

        https://docs.aws.amazon.com/appsync/latest/APIReference/API_DeleteType.html

        :stability: experimental
        '''
        return typing.cast("Appsync", jsii.invoke(self, "toDeleteType", []))

    @jsii.member(jsii_name="toDisassociateApi")
    def to_disassociate_api(self) -> "Appsync":
        '''(experimental) Grants permission to dettach a GraphQL API to a custom domain name in AppSync.

        Access Level: Write

        https://docs.aws.amazon.com/appsync/latest/APIReference/API_DisassociateApi.html

        :stability: experimental
        '''
        return typing.cast("Appsync", jsii.invoke(self, "toDisassociateApi", []))

    @jsii.member(jsii_name="toEvaluateMappingTemplate")
    def to_evaluate_mapping_template(self) -> "Appsync":
        '''(experimental) Grants permission to evaluate template mapping.

        Access Level: Read

        https://docs.aws.amazon.com/appsync/latest/APIReference/API_EvaluateMappingTemplate.html

        :stability: experimental
        '''
        return typing.cast("Appsync", jsii.invoke(self, "toEvaluateMappingTemplate", []))

    @jsii.member(jsii_name="toFlushApiCache")
    def to_flush_api_cache(self) -> "Appsync":
        '''(experimental) Grants permission to flush an API cache in AppSync.

        Access Level: Write

        https://docs.aws.amazon.com/appsync/latest/APIReference/API_FlushApiCache.html

        :stability: experimental
        '''
        return typing.cast("Appsync", jsii.invoke(self, "toFlushApiCache", []))

    @jsii.member(jsii_name="toGetApiAssociation")
    def to_get_api_association(self) -> "Appsync":
        '''(experimental) Grants permission to read custom domain name - GraphQL API association details in AppSync.

        Access Level: Read

        https://docs.aws.amazon.com/appsync/latest/APIReference/API_GetApiAssociation.html

        :stability: experimental
        '''
        return typing.cast("Appsync", jsii.invoke(self, "toGetApiAssociation", []))

    @jsii.member(jsii_name="toGetApiCache")
    def to_get_api_cache(self) -> "Appsync":
        '''(experimental) Grants permission to read information about an API cache in AppSync.

        Access Level: Read

        https://docs.aws.amazon.com/appsync/latest/APIReference/API_GetApiCache.html

        :stability: experimental
        '''
        return typing.cast("Appsync", jsii.invoke(self, "toGetApiCache", []))

    @jsii.member(jsii_name="toGetDataSource")
    def to_get_data_source(self) -> "Appsync":
        '''(experimental) Grants permission to retrieve a data source.

        Access Level: Read

        https://docs.aws.amazon.com/appsync/latest/APIReference/API_GetDataSource.html

        :stability: experimental
        '''
        return typing.cast("Appsync", jsii.invoke(self, "toGetDataSource", []))

    @jsii.member(jsii_name="toGetDomainName")
    def to_get_domain_name(self) -> "Appsync":
        '''(experimental) Grants permission to read information about a custom domain name in AppSync.

        Access Level: Read

        https://docs.aws.amazon.com/appsync/latest/APIReference/API_GetDomainName.html

        :stability: experimental
        '''
        return typing.cast("Appsync", jsii.invoke(self, "toGetDomainName", []))

    @jsii.member(jsii_name="toGetFunction")
    def to_get_function(self) -> "Appsync":
        '''(experimental) Grants permission to retrieve a function.

        Access Level: Read

        https://docs.aws.amazon.com/appsync/latest/APIReference/API_GetFunction.html

        :stability: experimental
        '''
        return typing.cast("Appsync", jsii.invoke(self, "toGetFunction", []))

    @jsii.member(jsii_name="toGetGraphqlApi")
    def to_get_graphql_api(self) -> "Appsync":
        '''(experimental) Grants permission to retrieve a GraphQL API.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/appsync/latest/APIReference/API_GetGraphqlApi.html

        :stability: experimental
        '''
        return typing.cast("Appsync", jsii.invoke(self, "toGetGraphqlApi", []))

    @jsii.member(jsii_name="toGetIntrospectionSchema")
    def to_get_introspection_schema(self) -> "Appsync":
        '''(experimental) Grants permission to retrieve the introspection schema for a GraphQL API.

        Access Level: Read

        https://docs.aws.amazon.com/appsync/latest/APIReference/API_GetIntrospectionSchema.html

        :stability: experimental
        '''
        return typing.cast("Appsync", jsii.invoke(self, "toGetIntrospectionSchema", []))

    @jsii.member(jsii_name="toGetResolver")
    def to_get_resolver(self) -> "Appsync":
        '''(experimental) Grants permission to retrieve a resolver.

        Access Level: Read

        https://docs.aws.amazon.com/appsync/latest/APIReference/API_GetResolver.html

        :stability: experimental
        '''
        return typing.cast("Appsync", jsii.invoke(self, "toGetResolver", []))

    @jsii.member(jsii_name="toGetSchemaCreationStatus")
    def to_get_schema_creation_status(self) -> "Appsync":
        '''(experimental) Grants permission to retrieve the current status of a schema creation operation.

        Access Level: Read

        https://docs.aws.amazon.com/appsync/latest/APIReference/API_GetSchemaCreationStatus.html

        :stability: experimental
        '''
        return typing.cast("Appsync", jsii.invoke(self, "toGetSchemaCreationStatus", []))

    @jsii.member(jsii_name="toGetType")
    def to_get_type(self) -> "Appsync":
        '''(experimental) Grants permission to retrieve a type.

        Access Level: Read

        https://docs.aws.amazon.com/appsync/latest/APIReference/API_GetType.html

        :stability: experimental
        '''
        return typing.cast("Appsync", jsii.invoke(self, "toGetType", []))

    @jsii.member(jsii_name="toGraphQL")
    def to_graph_ql(self) -> "Appsync":
        '''(experimental) Grants permission to send a GraphQL query to a GraphQL API.

        Access Level: Write

        https://docs.aws.amazon.com/appsync/latest/devguide/using-your-api.html

        :stability: experimental
        '''
        return typing.cast("Appsync", jsii.invoke(self, "toGraphQL", []))

    @jsii.member(jsii_name="toListApiKeys")
    def to_list_api_keys(self) -> "Appsync":
        '''(experimental) Grants permission to list the API keys for a given API.

        Access Level: List

        https://docs.aws.amazon.com/appsync/latest/APIReference/API_ListApiKeys.html

        :stability: experimental
        '''
        return typing.cast("Appsync", jsii.invoke(self, "toListApiKeys", []))

    @jsii.member(jsii_name="toListDataSources")
    def to_list_data_sources(self) -> "Appsync":
        '''(experimental) Grants permission to list the data sources for a given API.

        Access Level: List

        https://docs.aws.amazon.com/appsync/latest/APIReference/API_ListDataSources.html

        :stability: experimental
        '''
        return typing.cast("Appsync", jsii.invoke(self, "toListDataSources", []))

    @jsii.member(jsii_name="toListDomainNames")
    def to_list_domain_names(self) -> "Appsync":
        '''(experimental) Grants permission to enumerate custom domain names in AppSync.

        Access Level: List

        https://docs.aws.amazon.com/appsync/latest/APIReference/API_ListDomainNames.html

        :stability: experimental
        '''
        return typing.cast("Appsync", jsii.invoke(self, "toListDomainNames", []))

    @jsii.member(jsii_name="toListFunctions")
    def to_list_functions(self) -> "Appsync":
        '''(experimental) Grants permission to list the functions for a given API.

        Access Level: List

        https://docs.aws.amazon.com/appsync/latest/APIReference/API_ListFunctions.html

        :stability: experimental
        '''
        return typing.cast("Appsync", jsii.invoke(self, "toListFunctions", []))

    @jsii.member(jsii_name="toListGraphqlApis")
    def to_list_graphql_apis(self) -> "Appsync":
        '''(experimental) Grants permission to list GraphQL APIs.

        Access Level: List

        https://docs.aws.amazon.com/appsync/latest/APIReference/API_ListGraphqlApis.html

        :stability: experimental
        '''
        return typing.cast("Appsync", jsii.invoke(self, "toListGraphqlApis", []))

    @jsii.member(jsii_name="toListResolvers")
    def to_list_resolvers(self) -> "Appsync":
        '''(experimental) Grants permission to list the resolvers for a given API and type.

        Access Level: List

        https://docs.aws.amazon.com/appsync/latest/APIReference/API_ListResolvers.html

        :stability: experimental
        '''
        return typing.cast("Appsync", jsii.invoke(self, "toListResolvers", []))

    @jsii.member(jsii_name="toListResolversByFunction")
    def to_list_resolvers_by_function(self) -> "Appsync":
        '''(experimental) Grants permission to list the resolvers that are associated with a specific function.

        Access Level: List

        https://docs.aws.amazon.com/appsync/latest/APIReference/API_ListResolversByFunction.html

        :stability: experimental
        '''
        return typing.cast("Appsync", jsii.invoke(self, "toListResolversByFunction", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Appsync":
        '''(experimental) Grants permission to list the tags for a resource.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/appsync/latest/APIReference/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("Appsync", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toListTypes")
    def to_list_types(self) -> "Appsync":
        '''(experimental) Grants permission to list the types for a given API.

        Access Level: List

        https://docs.aws.amazon.com/appsync/latest/APIReference/API_ListTypes.html

        :stability: experimental
        '''
        return typing.cast("Appsync", jsii.invoke(self, "toListTypes", []))

    @jsii.member(jsii_name="toSetWebACL")
    def to_set_web_acl(self) -> "Appsync":
        '''(experimental) Grants permission to set a web ACL.

        Access Level: Write

        https://docs.aws.amazon.com/appsync/latest/APIReference/API_SetWebACL.html

        :stability: experimental
        '''
        return typing.cast("Appsync", jsii.invoke(self, "toSetWebACL", []))

    @jsii.member(jsii_name="toStartSchemaCreation")
    def to_start_schema_creation(self) -> "Appsync":
        '''(experimental) Grants permission to add a new schema to your GraphQL API.

        This operation is asynchronous - GetSchemaCreationStatus can show when it has completed

        Access Level: Write

        https://docs.aws.amazon.com/appsync/latest/APIReference/API_StartSchemaCreation.html

        :stability: experimental
        '''
        return typing.cast("Appsync", jsii.invoke(self, "toStartSchemaCreation", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Appsync":
        '''(experimental) Grants permission to tag a resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsResourceTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/appsync/latest/APIReference/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("Appsync", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Appsync":
        '''(experimental) Grants permission to untag a resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/appsync/latest/APIReference/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("Appsync", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateApiCache")
    def to_update_api_cache(self) -> "Appsync":
        '''(experimental) Grants permission to update an API cache in AppSync.

        Access Level: Write

        https://docs.aws.amazon.com/appsync/latest/APIReference/API_UpdateApiCache.html

        :stability: experimental
        '''
        return typing.cast("Appsync", jsii.invoke(self, "toUpdateApiCache", []))

    @jsii.member(jsii_name="toUpdateApiKey")
    def to_update_api_key(self) -> "Appsync":
        '''(experimental) Grants permission to update an API key for a given API.

        Access Level: Write

        https://docs.aws.amazon.com/appsync/latest/APIReference/API_UpdateApiKey.html

        :stability: experimental
        '''
        return typing.cast("Appsync", jsii.invoke(self, "toUpdateApiKey", []))

    @jsii.member(jsii_name="toUpdateDataSource")
    def to_update_data_source(self) -> "Appsync":
        '''(experimental) Grants permission to update a data source.

        Access Level: Write

        https://docs.aws.amazon.com/appsync/latest/APIReference/API_UpdateDataSource.html

        :stability: experimental
        '''
        return typing.cast("Appsync", jsii.invoke(self, "toUpdateDataSource", []))

    @jsii.member(jsii_name="toUpdateDomainName")
    def to_update_domain_name(self) -> "Appsync":
        '''(experimental) Grants permission to update a custom domain name in AppSync.

        Access Level: Write

        https://docs.aws.amazon.com/appsync/latest/APIReference/API_UpdateDomainName.html

        :stability: experimental
        '''
        return typing.cast("Appsync", jsii.invoke(self, "toUpdateDomainName", []))

    @jsii.member(jsii_name="toUpdateFunction")
    def to_update_function(self) -> "Appsync":
        '''(experimental) Grants permission to update an existing function.

        Access Level: Write

        https://docs.aws.amazon.com/appsync/latest/APIReference/API_UpdateFunction.html

        :stability: experimental
        '''
        return typing.cast("Appsync", jsii.invoke(self, "toUpdateFunction", []))

    @jsii.member(jsii_name="toUpdateGraphqlApi")
    def to_update_graphql_api(self) -> "Appsync":
        '''(experimental) Grants permission to update a GraphQL API.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        Dependent actions:

        - iam:CreateServiceLinkedRole

        https://docs.aws.amazon.com/appsync/latest/APIReference/API_UpdateGraphqlApi.html

        :stability: experimental
        '''
        return typing.cast("Appsync", jsii.invoke(self, "toUpdateGraphqlApi", []))

    @jsii.member(jsii_name="toUpdateResolver")
    def to_update_resolver(self) -> "Appsync":
        '''(experimental) Grants permission to update a resolver.

        Access Level: Write

        https://docs.aws.amazon.com/appsync/latest/APIReference/API_UpdateResolver.html

        :stability: experimental
        '''
        return typing.cast("Appsync", jsii.invoke(self, "toUpdateResolver", []))

    @jsii.member(jsii_name="toUpdateType")
    def to_update_type(self) -> "Appsync":
        '''(experimental) Grants permission to update a type.

        Access Level: Write

        https://docs.aws.amazon.com/appsync/latest/APIReference/API_UpdateType.html

        :stability: experimental
        '''
        return typing.cast("Appsync", jsii.invoke(self, "toUpdateType", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ae49b1bd39a751b465dfa798386ff0bf4739802fd967b2a28ba6067b6e952281)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d283339709200385967ad6a551e062409fb9539ab59ad4d113eb644fe4823ff7)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Aps(PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Aps"):
    '''(experimental) Statement provider for service `aps <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonmanagedserviceforprometheus.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `aps <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonmanagedserviceforprometheus.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onRulegroupsnamespace")
    def on_rulegroupsnamespace(
        self,
        workspace_id: builtins.str,
        namespace: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Aps":
        '''(experimental) Adds a resource of type rulegroupsnamespace to the statement.

        https://docs.aws.amazon.com/prometheus/latest/userguide/security-iam.html

        :param workspace_id: - Identifier for the workspaceId.
        :param namespace: - Identifier for the namespace.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsRequestTag() - .ifAwsResourceTag() - .ifAwsTagKeys()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7dda98093400e5c7c16e84eda1517f42dddf2973e3a546bf2e3775e3f84c1d48)
            check_type(argname="argument workspace_id", value=workspace_id, expected_type=type_hints["workspace_id"])
            check_type(argname="argument namespace", value=namespace, expected_type=type_hints["namespace"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Aps", jsii.invoke(self, "onRulegroupsnamespace", [workspace_id, namespace, account, region, partition]))

    @jsii.member(jsii_name="onWorkspace")
    def on_workspace(
        self,
        workspace_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Aps":
        '''(experimental) Adds a resource of type workspace to the statement.

        https://docs.aws.amazon.com/prometheus/latest/userguide/security-iam.html

        :param workspace_id: - Identifier for the workspaceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsRequestTag() - .ifAwsResourceTag() - .ifAwsTagKeys()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__57c461165999c190d4d73dd92dc48f574a1b261651036d94046d75420680fe9b)
            check_type(argname="argument workspace_id", value=workspace_id, expected_type=type_hints["workspace_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Aps", jsii.invoke(self, "onWorkspace", [workspace_id, account, region, partition]))

    @jsii.member(jsii_name="toCreateAlertManagerAlerts")
    def to_create_alert_manager_alerts(self) -> "Aps":
        '''(experimental) Grants permission to create alerts.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/prometheus/latest/userguide/AMP-APIReference.html#AMP-APIReference-CreateAlertManagerAlerts

        :stability: experimental
        '''
        return typing.cast("Aps", jsii.invoke(self, "toCreateAlertManagerAlerts", []))

    @jsii.member(jsii_name="toCreateAlertManagerDefinition")
    def to_create_alert_manager_definition(self) -> "Aps":
        '''(experimental) Grants permission to create an alert manager definition.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/prometheus/latest/userguide/AMP-APIReference.html#AMP-APIReference-CreateAlertManagerDefinition

        :stability: experimental
        '''
        return typing.cast("Aps", jsii.invoke(self, "toCreateAlertManagerDefinition", []))

    @jsii.member(jsii_name="toCreateLoggingConfiguration")
    def to_create_logging_configuration(self) -> "Aps":
        '''(experimental) Grants permission to create a logging configuration.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/prometheus/latest/userguide/AMP-APIReference.html#AMP-APIReference-CreateLoggingConfiguration

        :stability: experimental
        '''
        return typing.cast("Aps", jsii.invoke(self, "toCreateLoggingConfiguration", []))

    @jsii.member(jsii_name="toCreateRuleGroupsNamespace")
    def to_create_rule_groups_namespace(self) -> "Aps":
        '''(experimental) Grants permission to create a rule groups namespace.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/prometheus/latest/userguide/AMP-APIReference.html#AMP-APIReference-CreateRuleGroupsNamespace

        :stability: experimental
        '''
        return typing.cast("Aps", jsii.invoke(self, "toCreateRuleGroupsNamespace", []))

    @jsii.member(jsii_name="toCreateWorkspace")
    def to_create_workspace(self) -> "Aps":
        '''(experimental) Grants permission to create a workspace.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/prometheus/latest/userguide/AMP-APIReference.html#AMP-APIReference-CreateWorkspace

        :stability: experimental
        '''
        return typing.cast("Aps", jsii.invoke(self, "toCreateWorkspace", []))

    @jsii.member(jsii_name="toDeleteAlertManagerDefinition")
    def to_delete_alert_manager_definition(self) -> "Aps":
        '''(experimental) Grants permission to delete an alert manager definition.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/prometheus/latest/userguide/AMP-APIReference.html#AMP-APIReference-DeleteAlertManagerDefinition

        :stability: experimental
        '''
        return typing.cast("Aps", jsii.invoke(self, "toDeleteAlertManagerDefinition", []))

    @jsii.member(jsii_name="toDeleteAlertManagerSilence")
    def to_delete_alert_manager_silence(self) -> "Aps":
        '''(experimental) Grants permission to delete a silence.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/prometheus/latest/userguide/AMP-APIReference.html#AMP-APIReference-DeleteAlertManagerSilence

        :stability: experimental
        '''
        return typing.cast("Aps", jsii.invoke(self, "toDeleteAlertManagerSilence", []))

    @jsii.member(jsii_name="toDeleteLoggingConfiguration")
    def to_delete_logging_configuration(self) -> "Aps":
        '''(experimental) Grants permission to delete a logging configuration.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/prometheus/latest/userguide/AMP-APIReference.html#AMP-APIReference-DeleteLoggingConfiguration

        :stability: experimental
        '''
        return typing.cast("Aps", jsii.invoke(self, "toDeleteLoggingConfiguration", []))

    @jsii.member(jsii_name="toDeleteRuleGroupsNamespace")
    def to_delete_rule_groups_namespace(self) -> "Aps":
        '''(experimental) Grants permission to delete a rule groups namespace.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/prometheus/latest/userguide/AMP-APIReference.html#AMP-APIReference-DeleteRuleGroupsNamespace

        :stability: experimental
        '''
        return typing.cast("Aps", jsii.invoke(self, "toDeleteRuleGroupsNamespace", []))

    @jsii.member(jsii_name="toDeleteWorkspace")
    def to_delete_workspace(self) -> "Aps":
        '''(experimental) Grants permission to delete a workspace.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/prometheus/latest/userguide/AMP-APIReference.html#AMP-APIReference-DeleteWorkspace

        :stability: experimental
        '''
        return typing.cast("Aps", jsii.invoke(self, "toDeleteWorkspace", []))

    @jsii.member(jsii_name="toDescribeAlertManagerDefinition")
    def to_describe_alert_manager_definition(self) -> "Aps":
        '''(experimental) Grants permission to describe an alert manager definition.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/prometheus/latest/userguide/AMP-APIReference.html#AMP-APIReference-DescribeAlertManagerDefinition

        :stability: experimental
        '''
        return typing.cast("Aps", jsii.invoke(self, "toDescribeAlertManagerDefinition", []))

    @jsii.member(jsii_name="toDescribeLoggingConfiguration")
    def to_describe_logging_configuration(self) -> "Aps":
        '''(experimental) Grants permission to describe a logging configuration.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/prometheus/latest/userguide/AMP-APIReference.html#AMP-APIReference-DescribeLoggingConfiguration

        :stability: experimental
        '''
        return typing.cast("Aps", jsii.invoke(self, "toDescribeLoggingConfiguration", []))

    @jsii.member(jsii_name="toDescribeRuleGroupsNamespace")
    def to_describe_rule_groups_namespace(self) -> "Aps":
        '''(experimental) Grants permission to describe a rule groups namespace.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/prometheus/latest/userguide/AMP-APIReference.html#AMP-APIReference-DescribeRuleGroupsNamespace

        :stability: experimental
        '''
        return typing.cast("Aps", jsii.invoke(self, "toDescribeRuleGroupsNamespace", []))

    @jsii.member(jsii_name="toDescribeWorkspace")
    def to_describe_workspace(self) -> "Aps":
        '''(experimental) Grants permission to describe a workspace.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/prometheus/latest/userguide/AMP-APIReference.html#AMP-APIReference-DescribeWorkspace

        :stability: experimental
        '''
        return typing.cast("Aps", jsii.invoke(self, "toDescribeWorkspace", []))

    @jsii.member(jsii_name="toGetAlertManagerSilence")
    def to_get_alert_manager_silence(self) -> "Aps":
        '''(experimental) Grants permission to get a silence.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/prometheus/latest/userguide/AMP-APIReference.html#AMP-APIReference-GetAlertManagerSilence

        :stability: experimental
        '''
        return typing.cast("Aps", jsii.invoke(self, "toGetAlertManagerSilence", []))

    @jsii.member(jsii_name="toGetAlertManagerStatus")
    def to_get_alert_manager_status(self) -> "Aps":
        '''(experimental) Grants permission to get current status of an alertmanager.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/prometheus/latest/userguide/AMP-APIReference.html#AMP-APIReference-GetAlertManagerStatus

        :stability: experimental
        '''
        return typing.cast("Aps", jsii.invoke(self, "toGetAlertManagerStatus", []))

    @jsii.member(jsii_name="toGetLabels")
    def to_get_labels(self) -> "Aps":
        '''(experimental) Grants permission to retrieve AMP workspace labels.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/prometheus/latest/userguide/AMP-APIReference.html#AMP-APIReference-GetLabels

        :stability: experimental
        '''
        return typing.cast("Aps", jsii.invoke(self, "toGetLabels", []))

    @jsii.member(jsii_name="toGetMetricMetadata")
    def to_get_metric_metadata(self) -> "Aps":
        '''(experimental) Grants permission to retrieve the metadata for AMP workspace metrics.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/prometheus/latest/userguide/AMP-APIReference.html#AMP-APIReference-GetMetricMetadata

        :stability: experimental
        '''
        return typing.cast("Aps", jsii.invoke(self, "toGetMetricMetadata", []))

    @jsii.member(jsii_name="toGetSeries")
    def to_get_series(self) -> "Aps":
        '''(experimental) Grants permission to retrieve AMP workspace time series data.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/prometheus/latest/userguide/AMP-APIReference.html#AMP-APIReference-GetSeries

        :stability: experimental
        '''
        return typing.cast("Aps", jsii.invoke(self, "toGetSeries", []))

    @jsii.member(jsii_name="toListAlertManagerAlertGroups")
    def to_list_alert_manager_alert_groups(self) -> "Aps":
        '''(experimental) Grants permission to list groups.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/prometheus/latest/userguide/AMP-APIReference.html#AMP-APIReference-ListAlertManagerAlertGroups

        :stability: experimental
        '''
        return typing.cast("Aps", jsii.invoke(self, "toListAlertManagerAlertGroups", []))

    @jsii.member(jsii_name="toListAlertManagerAlerts")
    def to_list_alert_manager_alerts(self) -> "Aps":
        '''(experimental) Grants permission to list alerts.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/prometheus/latest/userguide/AMP-APIReference.html#AMP-APIReference-ListAlertManagerAlerts

        :stability: experimental
        '''
        return typing.cast("Aps", jsii.invoke(self, "toListAlertManagerAlerts", []))

    @jsii.member(jsii_name="toListAlertManagerReceivers")
    def to_list_alert_manager_receivers(self) -> "Aps":
        '''(experimental) Grants permission to list receivers.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/prometheus/latest/userguide/AMP-APIReference.html#AMP-APIReference-ListAlertManagerReceivers

        :stability: experimental
        '''
        return typing.cast("Aps", jsii.invoke(self, "toListAlertManagerReceivers", []))

    @jsii.member(jsii_name="toListAlertManagerSilences")
    def to_list_alert_manager_silences(self) -> "Aps":
        '''(experimental) Grants permission to list silences.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/prometheus/latest/userguide/AMP-APIReference.html#AMP-APIReference-ListAlertManagerSilences

        :stability: experimental
        '''
        return typing.cast("Aps", jsii.invoke(self, "toListAlertManagerSilences", []))

    @jsii.member(jsii_name="toListAlerts")
    def to_list_alerts(self) -> "Aps":
        '''(experimental) Grants permission to list active alerts.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/prometheus/latest/userguide/AMP-APIReference.html#AMP-APIReference-ListAlerts

        :stability: experimental
        '''
        return typing.cast("Aps", jsii.invoke(self, "toListAlerts", []))

    @jsii.member(jsii_name="toListRuleGroupsNamespaces")
    def to_list_rule_groups_namespaces(self) -> "Aps":
        '''(experimental) Grants permission to list rule groups namespaces.

        Access Level: List

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/prometheus/latest/userguide/AMP-APIReference.html#AMP-APIReference-ListRuleGroupsNamespaces

        :stability: experimental
        '''
        return typing.cast("Aps", jsii.invoke(self, "toListRuleGroupsNamespaces", []))

    @jsii.member(jsii_name="toListRules")
    def to_list_rules(self) -> "Aps":
        '''(experimental) Grants permission to list alerting and recording rules.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/prometheus/latest/userguide/AMP-APIReference.html#AMP-APIReference-ListRules

        :stability: experimental
        '''
        return typing.cast("Aps", jsii.invoke(self, "toListRules", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Aps":
        '''(experimental) Grants permission to list tags on an AMP resource.

        Access Level: Read

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/prometheus/latest/userguide/AMP-APIReference.html#AMP-APIReference-ListTagsForResource

        :stability: experimental
        '''
        return typing.cast("Aps", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toListWorkspaces")
    def to_list_workspaces(self) -> "Aps":
        '''(experimental) Grants permission to list workspaces.

        Access Level: List

        https://docs.aws.amazon.com/prometheus/latest/userguide/AMP-APIReference.html#AMP-APIReference-ListWorkspaces

        :stability: experimental
        '''
        return typing.cast("Aps", jsii.invoke(self, "toListWorkspaces", []))

    @jsii.member(jsii_name="toPutAlertManagerDefinition")
    def to_put_alert_manager_definition(self) -> "Aps":
        '''(experimental) Grants permission to update an alert manager definition.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/prometheus/latest/userguide/AMP-APIReference.html#AMP-APIReference-PutAlertManagerDefinition

        :stability: experimental
        '''
        return typing.cast("Aps", jsii.invoke(self, "toPutAlertManagerDefinition", []))

    @jsii.member(jsii_name="toPutAlertManagerSilences")
    def to_put_alert_manager_silences(self) -> "Aps":
        '''(experimental) Grants permission to create or update a silence.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/prometheus/latest/userguide/AMP-APIReference.html#AMP-APIReference-PutAlertManagerSilences

        :stability: experimental
        '''
        return typing.cast("Aps", jsii.invoke(self, "toPutAlertManagerSilences", []))

    @jsii.member(jsii_name="toPutRuleGroupsNamespace")
    def to_put_rule_groups_namespace(self) -> "Aps":
        '''(experimental) Grants permission to update a rule groups namespace.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/prometheus/latest/userguide/AMP-APIReference.html#AMP-APIReference-PutRuleGroupsNamespace

        :stability: experimental
        '''
        return typing.cast("Aps", jsii.invoke(self, "toPutRuleGroupsNamespace", []))

    @jsii.member(jsii_name="toQueryMetrics")
    def to_query_metrics(self) -> "Aps":
        '''(experimental) Grants permission to run a query on AMP workspace metrics.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/prometheus/latest/userguide/AMP-APIReference.html#AMP-APIReference-QueryMetrics

        :stability: experimental
        '''
        return typing.cast("Aps", jsii.invoke(self, "toQueryMetrics", []))

    @jsii.member(jsii_name="toRemoteWrite")
    def to_remote_write(self) -> "Aps":
        '''(experimental) Grants permission to perform a remote write operation to initiate the streaming of metrics to AMP workspace.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/prometheus/latest/userguide/AMP-APIReference.html#AMP-APIReference-RemoteWrite

        :stability: experimental
        '''
        return typing.cast("Aps", jsii.invoke(self, "toRemoteWrite", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Aps":
        '''(experimental) Grants permission to tag an AMP resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/prometheus/latest/userguide/AMP-APIReference.html#AMP-APIReference-TagResource

        :stability: experimental
        '''
        return typing.cast("Aps", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Aps":
        '''(experimental) Grants permission to untag an AMP resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/prometheus/latest/userguide/AMP-APIReference.html#AMP-APIReference-UntagResource

        :stability: experimental
        '''
        return typing.cast("Aps", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateLoggingConfiguration")
    def to_update_logging_configuration(self) -> "Aps":
        '''(experimental) Grants permission to update a logging configuration.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/prometheus/latest/userguide/AMP-APIReference.html#AMP-APIReference-UpdateLoggingConfiguration

        :stability: experimental
        '''
        return typing.cast("Aps", jsii.invoke(self, "toUpdateLoggingConfiguration", []))

    @jsii.member(jsii_name="toUpdateWorkspaceAlias")
    def to_update_workspace_alias(self) -> "Aps":
        '''(experimental) Grants permission to modify the alias of existing AMP workspace.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/prometheus/latest/userguide/AMP-APIReference.html#AMP-APIReference-UpdateWorkspaceAlias

        :stability: experimental
        '''
        return typing.cast("Aps", jsii.invoke(self, "toUpdateWorkspaceAlias", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__255a7421dab2d5f9969d2a11020be9739afd6330fefef6da573dd1b7c2eb7a2b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0b78ce76eadbfa87498fb4a382f9cac0bcc47a3554c45d904faf5e9c7653e1f5)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class ArcZonalShift(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.ArcZonalShift",
):
    '''(experimental) Statement provider for service `arc-zonal-shift <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonroute53applicationrecoverycontroller-zonalshift.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `arc-zonal-shift <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonroute53applicationrecoverycontroller-zonalshift.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onALB")
    def on_alb(
        self,
        load_balancer_name: builtins.str,
        load_balancer_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "ArcZonalShift":
        '''(experimental) Adds a resource of type ALB to the statement.

        https://docs.aws.amazon.com/r53recovery/latest/dg/arc-zonal-shift.resource-types.html

        :param load_balancer_name: - Identifier for the loadBalancerName.
        :param load_balancer_id: - Identifier for the loadBalancerId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4e22dc6e62aff04b91e0a83fc07d61c4816b11be9b695815d26beac5466f6382)
            check_type(argname="argument load_balancer_name", value=load_balancer_name, expected_type=type_hints["load_balancer_name"])
            check_type(argname="argument load_balancer_id", value=load_balancer_id, expected_type=type_hints["load_balancer_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("ArcZonalShift", jsii.invoke(self, "onALB", [load_balancer_name, load_balancer_id, account, region, partition]))

    @jsii.member(jsii_name="onNLB")
    def on_nlb(
        self,
        load_balancer_name: builtins.str,
        load_balancer_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "ArcZonalShift":
        '''(experimental) Adds a resource of type NLB to the statement.

        https://docs.aws.amazon.com/r53recovery/latest/dg/arc-zonal-shift.resource-types.html

        :param load_balancer_name: - Identifier for the loadBalancerName.
        :param load_balancer_id: - Identifier for the loadBalancerId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e483a3e47023ca24db30413aca9362739093f959137ab8cfc3d0be29f9ed25ed)
            check_type(argname="argument load_balancer_name", value=load_balancer_name, expected_type=type_hints["load_balancer_name"])
            check_type(argname="argument load_balancer_id", value=load_balancer_id, expected_type=type_hints["load_balancer_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("ArcZonalShift", jsii.invoke(self, "onNLB", [load_balancer_name, load_balancer_id, account, region, partition]))

    @jsii.member(jsii_name="toCancelZonalShift")
    def to_cancel_zonal_shift(self) -> "ArcZonalShift":
        '''(experimental) Grants permission to cancel an active zonal shift.

        Access Level: Write

        https://docs.aws.amazon.com/arc-zonal-shift/latest/api/API_CancelZonalShift.html

        :stability: experimental
        '''
        return typing.cast("ArcZonalShift", jsii.invoke(self, "toCancelZonalShift", []))

    @jsii.member(jsii_name="toGetManagedResource")
    def to_get_managed_resource(self) -> "ArcZonalShift":
        '''(experimental) Grants permission to get information about a managed resource.

        Access Level: Read

        https://docs.aws.amazon.com/arc-zonal-shift/latest/api/API_GetManagedResource.html

        :stability: experimental
        '''
        return typing.cast("ArcZonalShift", jsii.invoke(self, "toGetManagedResource", []))

    @jsii.member(jsii_name="toListManagedResources")
    def to_list_managed_resources(self) -> "ArcZonalShift":
        '''(experimental) Grants permission to list managed resources.

        Access Level: List

        https://docs.aws.amazon.com/arc-zonal-shift/latest/api/API_ListManagedResources.html

        :stability: experimental
        '''
        return typing.cast("ArcZonalShift", jsii.invoke(self, "toListManagedResources", []))

    @jsii.member(jsii_name="toListZonalShifts")
    def to_list_zonal_shifts(self) -> "ArcZonalShift":
        '''(experimental) Grants permission to list zonal shifts.

        Access Level: List

        https://docs.aws.amazon.com/arc-zonal-shift/latest/api/API_ListZonalShifts.html

        :stability: experimental
        '''
        return typing.cast("ArcZonalShift", jsii.invoke(self, "toListZonalShifts", []))

    @jsii.member(jsii_name="toStartZonalShift")
    def to_start_zonal_shift(self) -> "ArcZonalShift":
        '''(experimental) Grants permission to start a zonal shift.

        Access Level: Write

        https://docs.aws.amazon.com/arc-zonal-shift/latest/api/API_StartZonalShift.html

        :stability: experimental
        '''
        return typing.cast("ArcZonalShift", jsii.invoke(self, "toStartZonalShift", []))

    @jsii.member(jsii_name="toUpdateZonalShift")
    def to_update_zonal_shift(self) -> "ArcZonalShift":
        '''(experimental) Grants permission to update an existing zonal shift.

        Access Level: Write

        https://docs.aws.amazon.com/arc-zonal-shift/latest/api/API_UpdateZonalShift.html

        :stability: experimental
        '''
        return typing.cast("ArcZonalShift", jsii.invoke(self, "toUpdateZonalShift", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1a8aab5aef6ee5cecbbcae3eb50d7fe6a7b1137f14ebc0f0c03978fd4d8210d4)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b7872413ae4125b6c4b64bc888ac79acaf875742f6b4617d708e4cc8e5bc31dc)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Arsenal(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Arsenal",
):
    '''(experimental) Statement provider for service `arsenal <https://docs.aws.amazon.com/service-authorization/latest/reference/list_applicationdiscoveryarsenal.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `arsenal <https://docs.aws.amazon.com/service-authorization/latest/reference/list_applicationdiscoveryarsenal.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="toRegisterOnPremisesAgent")
    def to_register_on_premises_agent(self) -> "Arsenal":
        '''(experimental) Grants permission to register AWS provided data collectors to the Application Discovery Service.

        Access Level: Write

        https://docs.aws.amazon.com/application-discovery/latest/userguide/setting-up.html

        :stability: experimental
        '''
        return typing.cast("Arsenal", jsii.invoke(self, "toRegisterOnPremisesAgent", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a2048849b36957b0fa15793c94652c6f4bf03da3db2eb9447523d27226b654d8)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__cca6206af160a6d071447c21eba797411892c30e0650e2c0be3a9880267c760b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Artifact(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Artifact",
):
    '''(experimental) Statement provider for service `artifact <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsartifact.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `artifact <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsartifact.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onAgreement")
    def on_agreement(
        self,
        resource_name: builtins.str,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Artifact":
        '''(experimental) Adds a resource of type agreement to the statement.

        https://docs.aws.amazon.com/artifact/latest/ug/managing-agreements.html

        :param resource_name: - Identifier for the resourceName.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ebdef7b294c45db4b1c2c1b559f18f58231c682266e3529dfcbd2a6f72ab2ef6)
            check_type(argname="argument resource_name", value=resource_name, expected_type=type_hints["resource_name"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Artifact", jsii.invoke(self, "onAgreement", [resource_name, partition]))

    @jsii.member(jsii_name="onCustomerAgreement")
    def on_customer_agreement(
        self,
        resource_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Artifact":
        '''(experimental) Adds a resource of type customer-agreement to the statement.

        https://docs.aws.amazon.com/artifact/latest/ug/managing-agreements.html

        :param resource_name: - Identifier for the resourceName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b78889c197d62691954ec2572dc27accfc5684095b922dd82172974bdb355b63)
            check_type(argname="argument resource_name", value=resource_name, expected_type=type_hints["resource_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Artifact", jsii.invoke(self, "onCustomerAgreement", [resource_name, account, partition]))

    @jsii.member(jsii_name="onReport")
    def on_report(
        self,
        resource_name: builtins.str,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Artifact":
        '''(experimental) Adds a resource of type report to the statement.

        https://docs.aws.amazon.com/artifact/latest/ug/what-is-aws-artifact.html

        :param resource_name: - Identifier for the resourceName.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d877b87288a3b13c0e2f9bea58723ebd8f44a61b3846b9565124469166ae73d6)
            check_type(argname="argument resource_name", value=resource_name, expected_type=type_hints["resource_name"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Artifact", jsii.invoke(self, "onReport", [resource_name, region, partition]))

    @jsii.member(jsii_name="onReportPackage")
    def on_report_package(
        self,
        resource_name: builtins.str,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Artifact":
        '''(experimental) Adds a resource of type report-package to the statement.

        https://docs.aws.amazon.com/artifact/latest/ug/what-is-aws-artifact.html

        :param resource_name: - Identifier for the resourceName.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8e70e7d4e2e093590806a75bd4de30962077bc4175d9b36ba6af65dafca5ea98)
            check_type(argname="argument resource_name", value=resource_name, expected_type=type_hints["resource_name"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Artifact", jsii.invoke(self, "onReportPackage", [resource_name, partition]))

    @jsii.member(jsii_name="toAcceptAgreement")
    def to_accept_agreement(self) -> "Artifact":
        '''(experimental) Grants permission to accept an AWS agreement that has not yet been accepted by the customer account.

        Access Level: Write

        https://docs.aws.amazon.com/artifact/latest/ug/managing-agreements.html

        :stability: experimental
        '''
        return typing.cast("Artifact", jsii.invoke(self, "toAcceptAgreement", []))

    @jsii.member(jsii_name="toDownloadAgreement")
    def to_download_agreement(self) -> "Artifact":
        '''(experimental) Grants permission to download an AWS agreement that has not yet been accepted or a customer agreement that has been accepted by the customer account.

        Access Level: Read

        https://docs.aws.amazon.com/artifact/latest/ug/managing-agreements.html

        :stability: experimental
        '''
        return typing.cast("Artifact", jsii.invoke(self, "toDownloadAgreement", []))

    @jsii.member(jsii_name="toGet")
    def to_get(self) -> "Artifact":
        '''(experimental) Grants permission to download an AWS compliance report package.

        Access Level: Read

        https://docs.aws.amazon.com/artifact/latest/ug/getting-started.html

        :stability: experimental
        '''
        return typing.cast("Artifact", jsii.invoke(self, "toGet", []))

    @jsii.member(jsii_name="toGetReport")
    def to_get_report(self) -> "Artifact":
        '''(experimental) Grants permission to download a report.

        Access Level: Read

        https://docs.aws.amazon.com/artifact/latest/ug/getting-started.html

        :stability: experimental
        '''
        return typing.cast("Artifact", jsii.invoke(self, "toGetReport", []))

    @jsii.member(jsii_name="toGetReportMetadata")
    def to_get_report_metadata(self) -> "Artifact":
        '''(experimental) Grants permission to download metadata associated with a report.

        Access Level: Read

        https://docs.aws.amazon.com/artifact/latest/ug/getting-started.html

        :stability: experimental
        '''
        return typing.cast("Artifact", jsii.invoke(self, "toGetReportMetadata", []))

    @jsii.member(jsii_name="toGetTermForReport")
    def to_get_term_for_report(self) -> "Artifact":
        '''(experimental) Grants permission to download a term associated with a report.

        Access Level: Read

        https://docs.aws.amazon.com/artifact/latest/ug/getting-started.html

        :stability: experimental
        '''
        return typing.cast("Artifact", jsii.invoke(self, "toGetTermForReport", []))

    @jsii.member(jsii_name="toListReports")
    def to_list_reports(self) -> "Artifact":
        '''(experimental) Grants permission to list reports in your account.

        Access Level: List

        https://docs.aws.amazon.com/artifact/latest/ug/getting-started.html

        :stability: experimental
        '''
        return typing.cast("Artifact", jsii.invoke(self, "toListReports", []))

    @jsii.member(jsii_name="toTerminateAgreement")
    def to_terminate_agreement(self) -> "Artifact":
        '''(experimental) Grants permission to terminate a customer agreement that was previously accepted by the customer account.

        Access Level: Write

        https://docs.aws.amazon.com/artifact/latest/ug/managing-agreements.html

        :stability: experimental
        '''
        return typing.cast("Artifact", jsii.invoke(self, "toTerminateAgreement", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7e82817f22c32ed71499bd556342360833ce9dc38824d43716c868a485f03c03)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__152a65e65ce13144d1858e904c0e568a86ffdeb324af936700760a6106461c96)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Athena(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Athena",
):
    '''(experimental) Statement provider for service `athena <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonathena.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `athena <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonathena.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onDatacatalog")
    def on_datacatalog(
        self,
        data_catalog_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Athena":
        '''(experimental) Adds a resource of type datacatalog to the statement.

        https://docs.aws.amazon.com/athena/latest/ug/datacatalogs-example-policies.html

        :param data_catalog_name: - Identifier for the dataCatalogName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__507559939d8ff3d2d12175b6a490570d69fd0e4faf6c37cc62b6f95dfaa8f039)
            check_type(argname="argument data_catalog_name", value=data_catalog_name, expected_type=type_hints["data_catalog_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Athena", jsii.invoke(self, "onDatacatalog", [data_catalog_name, account, region, partition]))

    @jsii.member(jsii_name="onWorkgroup")
    def on_workgroup(
        self,
        work_group_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Athena":
        '''(experimental) Adds a resource of type workgroup to the statement.

        https://docs.aws.amazon.com/athena/latest/ug/example-policies-workgroup.html

        :param work_group_name: - Identifier for the workGroupName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d5b301697ed23bb32899be3d4eec7052d3108bc583ba6386cac9646d9b32bc5f)
            check_type(argname="argument work_group_name", value=work_group_name, expected_type=type_hints["work_group_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Athena", jsii.invoke(self, "onWorkgroup", [work_group_name, account, region, partition]))

    @jsii.member(jsii_name="toBatchGetNamedQuery")
    def to_batch_get_named_query(self) -> "Athena":
        '''(experimental) Grants permission to get information about one or more named queries.

        Access Level: Read

        https://docs.aws.amazon.com/athena/latest/APIReference/API_BatchGetNamedQuery.html

        :stability: experimental
        '''
        return typing.cast("Athena", jsii.invoke(self, "toBatchGetNamedQuery", []))

    @jsii.member(jsii_name="toBatchGetPreparedStatement")
    def to_batch_get_prepared_statement(self) -> "Athena":
        '''(experimental) Grants permission to get information about one or more prepared statements.

        Access Level: Read

        https://docs.aws.amazon.com/athena/latest/APIReference/API_BatchGetPreparedStatement.html

        :stability: experimental
        '''
        return typing.cast("Athena", jsii.invoke(self, "toBatchGetPreparedStatement", []))

    @jsii.member(jsii_name="toBatchGetQueryExecution")
    def to_batch_get_query_execution(self) -> "Athena":
        '''(experimental) Grants permission to get information about one or more query executions.

        Access Level: Read

        https://docs.aws.amazon.com/athena/latest/APIReference/API_BatchGetQueryExecution.html

        :stability: experimental
        '''
        return typing.cast("Athena", jsii.invoke(self, "toBatchGetQueryExecution", []))

    @jsii.member(jsii_name="toCreateDataCatalog")
    def to_create_data_catalog(self) -> "Athena":
        '''(experimental) Grants permission to create a datacatalog.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/athena/latest/APIReference/API_CreateDataCatalog.html

        :stability: experimental
        '''
        return typing.cast("Athena", jsii.invoke(self, "toCreateDataCatalog", []))

    @jsii.member(jsii_name="toCreateNamedQuery")
    def to_create_named_query(self) -> "Athena":
        '''(experimental) Grants permission to create a named query.

        Access Level: Write

        https://docs.aws.amazon.com/athena/latest/APIReference/API_CreateNamedQuery.html

        :stability: experimental
        '''
        return typing.cast("Athena", jsii.invoke(self, "toCreateNamedQuery", []))

    @jsii.member(jsii_name="toCreateNotebook")
    def to_create_notebook(self) -> "Athena":
        '''(experimental) Grants permission to create a notebook.

        Access Level: Write

        https://docs.aws.amazon.com/athena/latest/APIReference/API_CreateNotebook.html

        :stability: experimental
        '''
        return typing.cast("Athena", jsii.invoke(self, "toCreateNotebook", []))

    @jsii.member(jsii_name="toCreatePreparedStatement")
    def to_create_prepared_statement(self) -> "Athena":
        '''(experimental) Grants permission to create a prepared statement.

        Access Level: Write

        https://docs.aws.amazon.com/athena/latest/APIReference/API_CreatePreparedStatement.html

        :stability: experimental
        '''
        return typing.cast("Athena", jsii.invoke(self, "toCreatePreparedStatement", []))

    @jsii.member(jsii_name="toCreatePresignedNotebookUrl")
    def to_create_presigned_notebook_url(self) -> "Athena":
        '''(experimental) Grants permission to create a presigned notebook url.

        Access Level: Write

        https://docs.aws.amazon.com/athena/latest/APIReference/API_CreatePresignedNotebookUrl.html

        :stability: experimental
        '''
        return typing.cast("Athena", jsii.invoke(self, "toCreatePresignedNotebookUrl", []))

    @jsii.member(jsii_name="toCreateWorkGroup")
    def to_create_work_group(self) -> "Athena":
        '''(experimental) Grants permission to create a workgroup.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/athena/latest/APIReference/API_CreateWorkGroup.html

        :stability: experimental
        '''
        return typing.cast("Athena", jsii.invoke(self, "toCreateWorkGroup", []))

    @jsii.member(jsii_name="toDeleteDataCatalog")
    def to_delete_data_catalog(self) -> "Athena":
        '''(experimental) Grants permission to delete a datacatalog.

        Access Level: Write

        https://docs.aws.amazon.com/athena/latest/APIReference/API_DeleteDataCatalog.html

        :stability: experimental
        '''
        return typing.cast("Athena", jsii.invoke(self, "toDeleteDataCatalog", []))

    @jsii.member(jsii_name="toDeleteNamedQuery")
    def to_delete_named_query(self) -> "Athena":
        '''(experimental) Grants permission to delete a named query specified.

        Access Level: Write

        https://docs.aws.amazon.com/athena/latest/APIReference/API_DeleteNamedQuery.html

        :stability: experimental
        '''
        return typing.cast("Athena", jsii.invoke(self, "toDeleteNamedQuery", []))

    @jsii.member(jsii_name="toDeleteNotebook")
    def to_delete_notebook(self) -> "Athena":
        '''(experimental) Grants permission to delete a notebook.

        Access Level: Write

        https://docs.aws.amazon.com/athena/latest/APIReference/API_DeleteNotebook.html

        :stability: experimental
        '''
        return typing.cast("Athena", jsii.invoke(self, "toDeleteNotebook", []))

    @jsii.member(jsii_name="toDeletePreparedStatement")
    def to_delete_prepared_statement(self) -> "Athena":
        '''(experimental) Grants permission to delete a prepared statement specified.

        Access Level: Write

        https://docs.aws.amazon.com/athena/latest/APIReference/API_DeletePreparedStatement.html

        :stability: experimental
        '''
        return typing.cast("Athena", jsii.invoke(self, "toDeletePreparedStatement", []))

    @jsii.member(jsii_name="toDeleteWorkGroup")
    def to_delete_work_group(self) -> "Athena":
        '''(experimental) Grants permission to delete a workgroup.

        Access Level: Write

        https://docs.aws.amazon.com/athena/latest/APIReference/API_DeleteWorkGroup.html

        :stability: experimental
        '''
        return typing.cast("Athena", jsii.invoke(self, "toDeleteWorkGroup", []))

    @jsii.member(jsii_name="toExportNotebook")
    def to_export_notebook(self) -> "Athena":
        '''(experimental) Grants permission to export a notebook.

        Access Level: Write

        https://docs.aws.amazon.com/athena/latest/APIReference/API_ExportNotebook.html

        :stability: experimental
        '''
        return typing.cast("Athena", jsii.invoke(self, "toExportNotebook", []))

    @jsii.member(jsii_name="toGetCalculationExecution")
    def to_get_calculation_execution(self) -> "Athena":
        '''(experimental) Grants permission to get a calculation execution.

        Access Level: Read

        https://docs.aws.amazon.com/athena/latest/APIReference/API_GetCalculationExecution.html

        :stability: experimental
        '''
        return typing.cast("Athena", jsii.invoke(self, "toGetCalculationExecution", []))

    @jsii.member(jsii_name="toGetCalculationExecutionCode")
    def to_get_calculation_execution_code(self) -> "Athena":
        '''(experimental) Grants permission to get a calculation execution code.

        Access Level: Read

        https://docs.aws.amazon.com/athena/latest/APIReference/API_GetCalculationExecutionCode.html

        :stability: experimental
        '''
        return typing.cast("Athena", jsii.invoke(self, "toGetCalculationExecutionCode", []))

    @jsii.member(jsii_name="toGetCalculationExecutionStatus")
    def to_get_calculation_execution_status(self) -> "Athena":
        '''(experimental) Grants permission to get a calculation execution status.

        Access Level: Read

        https://docs.aws.amazon.com/athena/latest/APIReference/API_GetCalculationExecutionStatus.html

        :stability: experimental
        '''
        return typing.cast("Athena", jsii.invoke(self, "toGetCalculationExecutionStatus", []))

    @jsii.member(jsii_name="toGetDatabase")
    def to_get_database(self) -> "Athena":
        '''(experimental) Grants permission to get a database for a given datacatalog.

        Access Level: Read

        https://docs.aws.amazon.com/athena/latest/APIReference/API_GetDatabase.html

        :stability: experimental
        '''
        return typing.cast("Athena", jsii.invoke(self, "toGetDatabase", []))

    @jsii.member(jsii_name="toGetDataCatalog")
    def to_get_data_catalog(self) -> "Athena":
        '''(experimental) Grants permission to get a datacatalog.

        Access Level: Read

        https://docs.aws.amazon.com/athena/latest/APIReference/API_GetDataCatalog.html

        :stability: experimental
        '''
        return typing.cast("Athena", jsii.invoke(self, "toGetDataCatalog", []))

    @jsii.member(jsii_name="toGetNamedQuery")
    def to_get_named_query(self) -> "Athena":
        '''(experimental) Grants permission to get information about the specified named query.

        Access Level: Read

        https://docs.aws.amazon.com/athena/latest/APIReference/API_GetNamedQuery.html

        :stability: experimental
        '''
        return typing.cast("Athena", jsii.invoke(self, "toGetNamedQuery", []))

    @jsii.member(jsii_name="toGetNotebookMetadata")
    def to_get_notebook_metadata(self) -> "Athena":
        '''(experimental) Grants permission to get notebook metadata.

        Access Level: Read

        https://docs.aws.amazon.com/athena/latest/APIReference/API_GetNotebookMetadata.html

        :stability: experimental
        '''
        return typing.cast("Athena", jsii.invoke(self, "toGetNotebookMetadata", []))

    @jsii.member(jsii_name="toGetPreparedStatement")
    def to_get_prepared_statement(self) -> "Athena":
        '''(experimental) Grants permission to get information about the specified prepared statement.

        Access Level: Read

        https://docs.aws.amazon.com/athena/latest/APIReference/API_GetPreparedStatement.html

        :stability: experimental
        '''
        return typing.cast("Athena", jsii.invoke(self, "toGetPreparedStatement", []))

    @jsii.member(jsii_name="toGetQueryExecution")
    def to_get_query_execution(self) -> "Athena":
        '''(experimental) Grants permission to get information about the specified query execution.

        Access Level: Read

        https://docs.aws.amazon.com/athena/latest/APIReference/API_GetQueryExecution.html

        :stability: experimental
        '''
        return typing.cast("Athena", jsii.invoke(self, "toGetQueryExecution", []))

    @jsii.member(jsii_name="toGetQueryResults")
    def to_get_query_results(self) -> "Athena":
        '''(experimental) Grants permission to get the query results.

        Access Level: Read

        https://docs.aws.amazon.com/athena/latest/APIReference/API_GetQueryResults.html

        :stability: experimental
        '''
        return typing.cast("Athena", jsii.invoke(self, "toGetQueryResults", []))

    @jsii.member(jsii_name="toGetQueryResultsStream")
    def to_get_query_results_stream(self) -> "Athena":
        '''(experimental) Grants permission to get the query results stream.

        Access Level: Read

        https://docs.aws.amazon.com/athena/latest/ug/connect-with-previous-jdbc.html#jdbc-prev-version-policies

        :stability: experimental
        '''
        return typing.cast("Athena", jsii.invoke(self, "toGetQueryResultsStream", []))

    @jsii.member(jsii_name="toGetQueryRuntimeStatistics")
    def to_get_query_runtime_statistics(self) -> "Athena":
        '''(experimental) Grants permission to get runtime statistics for the specified query execution.

        Access Level: Read

        https://docs.aws.amazon.com/athena/latest/APIReference/API_GetQueryRuntimeStatistics.html

        :stability: experimental
        '''
        return typing.cast("Athena", jsii.invoke(self, "toGetQueryRuntimeStatistics", []))

    @jsii.member(jsii_name="toGetSession")
    def to_get_session(self) -> "Athena":
        '''(experimental) Grants permission to get a session.

        Access Level: Read

        https://docs.aws.amazon.com/athena/latest/APIReference/API_GetSession.html

        :stability: experimental
        '''
        return typing.cast("Athena", jsii.invoke(self, "toGetSession", []))

    @jsii.member(jsii_name="toGetSessionStatus")
    def to_get_session_status(self) -> "Athena":
        '''(experimental) Grants permission to get a session status.

        Access Level: Read

        https://docs.aws.amazon.com/athena/latest/APIReference/API_GetSessionStatus.html

        :stability: experimental
        '''
        return typing.cast("Athena", jsii.invoke(self, "toGetSessionStatus", []))

    @jsii.member(jsii_name="toGetTableMetadata")
    def to_get_table_metadata(self) -> "Athena":
        '''(experimental) Grants permission to get a metadata about a table for a given datacatalog.

        Access Level: Read

        https://docs.aws.amazon.com/athena/latest/APIReference/API_GetTableMetadata.html

        :stability: experimental
        '''
        return typing.cast("Athena", jsii.invoke(self, "toGetTableMetadata", []))

    @jsii.member(jsii_name="toGetWorkGroup")
    def to_get_work_group(self) -> "Athena":
        '''(experimental) Grants permission to get a workgroup.

        Access Level: Read

        https://docs.aws.amazon.com/athena/latest/APIReference/API_GetWorkGroup.html

        :stability: experimental
        '''
        return typing.cast("Athena", jsii.invoke(self, "toGetWorkGroup", []))

    @jsii.member(jsii_name="toImportNotebook")
    def to_import_notebook(self) -> "Athena":
        '''(experimental) Grants permission to import a notebook.

        Access Level: Write

        https://docs.aws.amazon.com/athena/latest/APIReference/API_ImportNotebook.html

        :stability: experimental
        '''
        return typing.cast("Athena", jsii.invoke(self, "toImportNotebook", []))

    @jsii.member(jsii_name="toListApplicationDPUSizes")
    def to_list_application_dpu_sizes(self) -> "Athena":
        '''(experimental) Grants permission to return a list of ApplicationRuntimeIds.

        Access Level: List

        https://docs.aws.amazon.com/athena/latest/APIReference/API_ListApplicationDPUSizes.html

        :stability: experimental
        '''
        return typing.cast("Athena", jsii.invoke(self, "toListApplicationDPUSizes", []))

    @jsii.member(jsii_name="toListCalculationExecutions")
    def to_list_calculation_executions(self) -> "Athena":
        '''(experimental) Grants permission to return a list of calculation executions.

        Access Level: List

        https://docs.aws.amazon.com/athena/latest/APIReference/API_ListCalculationExecutions.html

        :stability: experimental
        '''
        return typing.cast("Athena", jsii.invoke(self, "toListCalculationExecutions", []))

    @jsii.member(jsii_name="toListDatabases")
    def to_list_databases(self) -> "Athena":
        '''(experimental) Grants permission to return a list of databases for a given datacatalog.

        Access Level: List

        https://docs.aws.amazon.com/athena/latest/APIReference/API_ListDatabases.html

        :stability: experimental
        '''
        return typing.cast("Athena", jsii.invoke(self, "toListDatabases", []))

    @jsii.member(jsii_name="toListDataCatalogs")
    def to_list_data_catalogs(self) -> "Athena":
        '''(experimental) Grants permission to return a list of datacatalogs for the specified AWS account.

        Access Level: List

        https://docs.aws.amazon.com/athena/latest/APIReference/API_ListDataCatalogs.html

        :stability: experimental
        '''
        return typing.cast("Athena", jsii.invoke(self, "toListDataCatalogs", []))

    @jsii.member(jsii_name="toListEngineVersions")
    def to_list_engine_versions(self) -> "Athena":
        '''(experimental) Grants permission to return a list of athena engine versions for the specified AWS account.

        Access Level: Read

        https://docs.aws.amazon.com/athena/latest/APIReference/API_ListEngineVersions.html

        :stability: experimental
        '''
        return typing.cast("Athena", jsii.invoke(self, "toListEngineVersions", []))

    @jsii.member(jsii_name="toListExecutors")
    def to_list_executors(self) -> "Athena":
        '''(experimental) Grants permission to return a list of executors.

        Access Level: List

        https://docs.aws.amazon.com/athena/latest/APIReference/API_ListExecutors.html

        :stability: experimental
        '''
        return typing.cast("Athena", jsii.invoke(self, "toListExecutors", []))

    @jsii.member(jsii_name="toListNamedQueries")
    def to_list_named_queries(self) -> "Athena":
        '''(experimental) Grants permission to return a list of named queries in Amazon Athena for the specified AWS account.

        Access Level: List

        https://docs.aws.amazon.com/athena/latest/APIReference/API_ListNamedQueries.html

        :stability: experimental
        '''
        return typing.cast("Athena", jsii.invoke(self, "toListNamedQueries", []))

    @jsii.member(jsii_name="toListNotebookMetadata")
    def to_list_notebook_metadata(self) -> "Athena":
        '''(experimental) Grants permission to return a list of notebooks for a given workgroup.

        Access Level: List

        https://docs.aws.amazon.com/athena/latest/APIReference/API_ListNotebookMetadata.html

        :stability: experimental
        '''
        return typing.cast("Athena", jsii.invoke(self, "toListNotebookMetadata", []))

    @jsii.member(jsii_name="toListNotebookSessions")
    def to_list_notebook_sessions(self) -> "Athena":
        '''(experimental) Grants permission to return a list of sessions for a given notebook.

        Access Level: List

        https://docs.aws.amazon.com/athena/latest/APIReference/API_ListNotebookSessions.html

        :stability: experimental
        '''
        return typing.cast("Athena", jsii.invoke(self, "toListNotebookSessions", []))

    @jsii.member(jsii_name="toListPreparedStatements")
    def to_list_prepared_statements(self) -> "Athena":
        '''(experimental) Grants permission to return a list of prepared statements for the specified workgroup.

        Access Level: List

        https://docs.aws.amazon.com/athena/latest/APIReference/API_ListPreparedStatements.html

        :stability: experimental
        '''
        return typing.cast("Athena", jsii.invoke(self, "toListPreparedStatements", []))

    @jsii.member(jsii_name="toListQueryExecutions")
    def to_list_query_executions(self) -> "Athena":
        '''(experimental) Grants permission to return a list of query executions for the specified AWS account.

        Access Level: Read

        https://docs.aws.amazon.com/athena/latest/APIReference/API_ListQueryExecutions.html

        :stability: experimental
        '''
        return typing.cast("Athena", jsii.invoke(self, "toListQueryExecutions", []))

    @jsii.member(jsii_name="toListSessions")
    def to_list_sessions(self) -> "Athena":
        '''(experimental) Grants permission to return a list of sessions for a given workgroup.

        Access Level: List

        https://docs.aws.amazon.com/athena/latest/APIReference/API_ListSessions.html

        :stability: experimental
        '''
        return typing.cast("Athena", jsii.invoke(self, "toListSessions", []))

    @jsii.member(jsii_name="toListTableMetadata")
    def to_list_table_metadata(self) -> "Athena":
        '''(experimental) Grants permission to return a list of table metadata in a database for a given datacatalog.

        Access Level: Read

        https://docs.aws.amazon.com/athena/latest/APIReference/API_ListTableMetadata.html

        :stability: experimental
        '''
        return typing.cast("Athena", jsii.invoke(self, "toListTableMetadata", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Athena":
        '''(experimental) Grants permission to return a list of tags for a resource.

        Access Level: Read

        https://docs.aws.amazon.com/athena/latest/APIReference/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("Athena", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toListWorkGroups")
    def to_list_work_groups(self) -> "Athena":
        '''(experimental) Grants permission to return a list of workgroups for the specified AWS account.

        Access Level: List

        https://docs.aws.amazon.com/athena/latest/APIReference/API_ListWorkGroups.html

        :stability: experimental
        '''
        return typing.cast("Athena", jsii.invoke(self, "toListWorkGroups", []))

    @jsii.member(jsii_name="toStartCalculationExecution")
    def to_start_calculation_execution(self) -> "Athena":
        '''(experimental) Grants permission to start a calculation execution.

        Access Level: Write

        https://docs.aws.amazon.com/athena/latest/APIReference/API_StartCalculationExecution.html

        :stability: experimental
        '''
        return typing.cast("Athena", jsii.invoke(self, "toStartCalculationExecution", []))

    @jsii.member(jsii_name="toStartQueryExecution")
    def to_start_query_execution(self) -> "Athena":
        '''(experimental) Grants permission to start a query execution using an SQL query provided as a string.

        Access Level: Write

        https://docs.aws.amazon.com/athena/latest/APIReference/API_StartQueryExecution.html

        :stability: experimental
        '''
        return typing.cast("Athena", jsii.invoke(self, "toStartQueryExecution", []))

    @jsii.member(jsii_name="toStartSession")
    def to_start_session(self) -> "Athena":
        '''(experimental) Grants permission to start a session.

        Access Level: Write

        https://docs.aws.amazon.com/athena/latest/APIReference/API_StartSession.html

        :stability: experimental
        '''
        return typing.cast("Athena", jsii.invoke(self, "toStartSession", []))

    @jsii.member(jsii_name="toStopCalculationExecution")
    def to_stop_calculation_execution(self) -> "Athena":
        '''(experimental) Grants permission to stop a calculation execution.

        Access Level: Write

        https://docs.aws.amazon.com/athena/latest/APIReference/API_StopCalculationExecution.html

        :stability: experimental
        '''
        return typing.cast("Athena", jsii.invoke(self, "toStopCalculationExecution", []))

    @jsii.member(jsii_name="toStopQueryExecution")
    def to_stop_query_execution(self) -> "Athena":
        '''(experimental) Grants permission to stop the specified query execution.

        Access Level: Write

        https://docs.aws.amazon.com/athena/latest/APIReference/API_StopQueryExecution.html

        :stability: experimental
        '''
        return typing.cast("Athena", jsii.invoke(self, "toStopQueryExecution", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Athena":
        '''(experimental) Grants permission to add a tag to a resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/athena/latest/APIReference/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("Athena", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toTerminateSession")
    def to_terminate_session(self) -> "Athena":
        '''(experimental) Grants permission to terminate a session.

        Access Level: Write

        https://docs.aws.amazon.com/athena/latest/APIReference/API_TerminateSession.html

        :stability: experimental
        '''
        return typing.cast("Athena", jsii.invoke(self, "toTerminateSession", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Athena":
        '''(experimental) Grants permission to remove a tag from a resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/athena/latest/APIReference/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("Athena", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateDataCatalog")
    def to_update_data_catalog(self) -> "Athena":
        '''(experimental) Grants permission to update a datacatalog.

        Access Level: Write

        https://docs.aws.amazon.com/athena/latest/APIReference/API_UpdateDataCatalog.html

        :stability: experimental
        '''
        return typing.cast("Athena", jsii.invoke(self, "toUpdateDataCatalog", []))

    @jsii.member(jsii_name="toUpdateNamedQuery")
    def to_update_named_query(self) -> "Athena":
        '''(experimental) Grants permission to update a named query specified.

        Access Level: Write

        https://docs.aws.amazon.com/athena/latest/APIReference/API_UpdateNamedQuery.html

        :stability: experimental
        '''
        return typing.cast("Athena", jsii.invoke(self, "toUpdateNamedQuery", []))

    @jsii.member(jsii_name="toUpdateNotebook")
    def to_update_notebook(self) -> "Athena":
        '''(experimental) Grants permission to update a notebook.

        Access Level: Write

        https://docs.aws.amazon.com/athena/latest/APIReference/API_UpdateNotebook.html

        :stability: experimental
        '''
        return typing.cast("Athena", jsii.invoke(self, "toUpdateNotebook", []))

    @jsii.member(jsii_name="toUpdateNotebookMetadata")
    def to_update_notebook_metadata(self) -> "Athena":
        '''(experimental) Grants permission to update notebook metadata.

        Access Level: Write

        https://docs.aws.amazon.com/athena/latest/APIReference/API_UpdateNotebookMetadata.html

        :stability: experimental
        '''
        return typing.cast("Athena", jsii.invoke(self, "toUpdateNotebookMetadata", []))

    @jsii.member(jsii_name="toUpdatePreparedStatement")
    def to_update_prepared_statement(self) -> "Athena":
        '''(experimental) Grants permission to update a prepared statement.

        Access Level: Write

        https://docs.aws.amazon.com/athena/latest/APIReference/API_UpdatePreparedStatement.html

        :stability: experimental
        '''
        return typing.cast("Athena", jsii.invoke(self, "toUpdatePreparedStatement", []))

    @jsii.member(jsii_name="toUpdateWorkGroup")
    def to_update_work_group(self) -> "Athena":
        '''(experimental) Grants permission to update a workgroup.

        Access Level: Write

        https://docs.aws.amazon.com/athena/latest/APIReference/API_UpdateWorkGroup.html

        :stability: experimental
        '''
        return typing.cast("Athena", jsii.invoke(self, "toUpdateWorkGroup", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__185223d9842623268d27c844b190e30f0fdc3d2d6efdc9ead19d32fc560ce0fc)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__32bc5857c964bd858e634e845063afeb11a92affdd6e16b4777c9928e20b3f9b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Auditmanager(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Auditmanager",
):
    '''(experimental) Statement provider for service `auditmanager <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsauditmanager.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `auditmanager <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsauditmanager.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onAssessment")
    def on_assessment(
        self,
        assessment_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Auditmanager":
        '''(experimental) Adds a resource of type assessment to the statement.

        https://docs.aws.amazon.com/audit-manager/latest/userguide/API_Assessment.html

        :param assessment_id: - Identifier for the assessmentId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5a80fe5d938685637958643c8eba73f2821ec3c349fcf56f4b4cabe2b01b5206)
            check_type(argname="argument assessment_id", value=assessment_id, expected_type=type_hints["assessment_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Auditmanager", jsii.invoke(self, "onAssessment", [assessment_id, account, region, partition]))

    @jsii.member(jsii_name="onAssessmentControlSet")
    def on_assessment_control_set(
        self,
        assessment_id: builtins.str,
        control_set_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Auditmanager":
        '''(experimental) Adds a resource of type assessmentControlSet to the statement.

        https://docs.aws.amazon.com/audit-manager/latest/userguide/API_AssessmentControlSet.html

        :param assessment_id: - Identifier for the assessmentId.
        :param control_set_id: - Identifier for the controlSetId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__23cac78af5852756e23ff1de65d4df0e0940f12b99f7e0378a0beab246979c88)
            check_type(argname="argument assessment_id", value=assessment_id, expected_type=type_hints["assessment_id"])
            check_type(argname="argument control_set_id", value=control_set_id, expected_type=type_hints["control_set_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Auditmanager", jsii.invoke(self, "onAssessmentControlSet", [assessment_id, control_set_id, account, region, partition]))

    @jsii.member(jsii_name="onAssessmentFramework")
    def on_assessment_framework(
        self,
        assessment_framework_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Auditmanager":
        '''(experimental) Adds a resource of type assessmentFramework to the statement.

        https://docs.aws.amazon.com/audit-manager/latest/userguide/API_AssessmentFramework.html

        :param assessment_framework_id: - Identifier for the assessmentFrameworkId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8a5681ca39c9a525a992d3da2c40165b2dbe4663cc27d45b429e2e275c0ef334)
            check_type(argname="argument assessment_framework_id", value=assessment_framework_id, expected_type=type_hints["assessment_framework_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Auditmanager", jsii.invoke(self, "onAssessmentFramework", [assessment_framework_id, account, region, partition]))

    @jsii.member(jsii_name="onControl")
    def on_control(
        self,
        control_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Auditmanager":
        '''(experimental) Adds a resource of type control to the statement.

        https://docs.aws.amazon.com/audit-manager/latest/userguide/API_Control.html

        :param control_id: - Identifier for the controlId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__35bfad0b5310233dc433e73e3cf66b9611f8732ef153effb9d8fbb2ae085f553)
            check_type(argname="argument control_id", value=control_id, expected_type=type_hints["control_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Auditmanager", jsii.invoke(self, "onControl", [control_id, account, region, partition]))

    @jsii.member(jsii_name="toAssociateAssessmentReportEvidenceFolder")
    def to_associate_assessment_report_evidence_folder(self) -> "Auditmanager":
        '''(experimental) Grants permission to associate an evidence folder with an assessment report in AWS Audit Manager.

        Access Level: Write

        https://docs.aws.amazon.com/audit-manager/latest/APIReference/API_AssociateAssessmentReportEvidenceFolder.html

        :stability: experimental
        '''
        return typing.cast("Auditmanager", jsii.invoke(self, "toAssociateAssessmentReportEvidenceFolder", []))

    @jsii.member(jsii_name="toBatchAssociateAssessmentReportEvidence")
    def to_batch_associate_assessment_report_evidence(self) -> "Auditmanager":
        '''(experimental) Grants permission to associate a list of evidence to an assessment report in AWS Audit Manager.

        Access Level: Write

        https://docs.aws.amazon.com/audit-manager/latest/APIReference/API_BatchAssociateAssessmentReportEvidence.html

        :stability: experimental
        '''
        return typing.cast("Auditmanager", jsii.invoke(self, "toBatchAssociateAssessmentReportEvidence", []))

    @jsii.member(jsii_name="toBatchCreateDelegationByAssessment")
    def to_batch_create_delegation_by_assessment(self) -> "Auditmanager":
        '''(experimental) Grants permission to create delegations for an assessment in AWS Audit Manager.

        Access Level: Write

        https://docs.aws.amazon.com/audit-manager/latest/APIReference/API_BatchCreateDelegationByAssessment.html

        :stability: experimental
        '''
        return typing.cast("Auditmanager", jsii.invoke(self, "toBatchCreateDelegationByAssessment", []))

    @jsii.member(jsii_name="toBatchDeleteDelegationByAssessment")
    def to_batch_delete_delegation_by_assessment(self) -> "Auditmanager":
        '''(experimental) Grants permission to delete delegations for an assessment in AWS Audit Manager.

        Access Level: Write

        https://docs.aws.amazon.com/audit-manager/latest/APIReference/API_BatchDeleteDelegationByAssessment.html

        :stability: experimental
        '''
        return typing.cast("Auditmanager", jsii.invoke(self, "toBatchDeleteDelegationByAssessment", []))

    @jsii.member(jsii_name="toBatchDisassociateAssessmentReportEvidence")
    def to_batch_disassociate_assessment_report_evidence(self) -> "Auditmanager":
        '''(experimental) Grants permission to disassociate a list of evidence from an assessment report in AWS Audit Manager.

        Access Level: Write

        https://docs.aws.amazon.com/audit-manager/latest/APIReference/API_BatchDisassociateAssessmentReportEvidence.html

        :stability: experimental
        '''
        return typing.cast("Auditmanager", jsii.invoke(self, "toBatchDisassociateAssessmentReportEvidence", []))

    @jsii.member(jsii_name="toBatchImportEvidenceToAssessmentControl")
    def to_batch_import_evidence_to_assessment_control(self) -> "Auditmanager":
        '''(experimental) Grants permission to import a list of evidence to an assessment control in AWS Audit Manager.

        Access Level: Write

        https://docs.aws.amazon.com/audit-manager/latest/APIReference/API_BatchImportEvidenceToAssessmentControl.html

        :stability: experimental
        '''
        return typing.cast("Auditmanager", jsii.invoke(self, "toBatchImportEvidenceToAssessmentControl", []))

    @jsii.member(jsii_name="toCreateAssessment")
    def to_create_assessment(self) -> "Auditmanager":
        '''(experimental) Grants permission to create an assessment to be used with AWS Audit Manager.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/audit-manager/latest/APIReference/API_CreateAssessment.html

        :stability: experimental
        '''
        return typing.cast("Auditmanager", jsii.invoke(self, "toCreateAssessment", []))

    @jsii.member(jsii_name="toCreateAssessmentFramework")
    def to_create_assessment_framework(self) -> "Auditmanager":
        '''(experimental) Grants permission to create a framework for use in AWS Audit Manager.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/audit-manager/latest/APIReference/API_CreateAssessmentFramework.html

        :stability: experimental
        '''
        return typing.cast("Auditmanager", jsii.invoke(self, "toCreateAssessmentFramework", []))

    @jsii.member(jsii_name="toCreateAssessmentReport")
    def to_create_assessment_report(self) -> "Auditmanager":
        '''(experimental) Grants permission to create an assessment report in AWS Audit Manager.

        Access Level: Write

        https://docs.aws.amazon.com/audit-manager/latest/APIReference/API_CreateAssessmentReport.html

        :stability: experimental
        '''
        return typing.cast("Auditmanager", jsii.invoke(self, "toCreateAssessmentReport", []))

    @jsii.member(jsii_name="toCreateControl")
    def to_create_control(self) -> "Auditmanager":
        '''(experimental) Grants permission to create a control to be used in AWS Audit Manager.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/audit-manager/latest/APIReference/API_CreateControl.html

        :stability: experimental
        '''
        return typing.cast("Auditmanager", jsii.invoke(self, "toCreateControl", []))

    @jsii.member(jsii_name="toDeleteAssessment")
    def to_delete_assessment(self) -> "Auditmanager":
        '''(experimental) Grants permission to delete an assessment in AWS Audit Manager.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/audit-manager/latest/APIReference/API_DeleteAssessment.html

        :stability: experimental
        '''
        return typing.cast("Auditmanager", jsii.invoke(self, "toDeleteAssessment", []))

    @jsii.member(jsii_name="toDeleteAssessmentFramework")
    def to_delete_assessment_framework(self) -> "Auditmanager":
        '''(experimental) Grants permission to delete an assessment framework in AWS Audit Manager.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/audit-manager/latest/APIReference/API_DeleteAssessmentFramework.html

        :stability: experimental
        '''
        return typing.cast("Auditmanager", jsii.invoke(self, "toDeleteAssessmentFramework", []))

    @jsii.member(jsii_name="toDeleteAssessmentFrameworkShare")
    def to_delete_assessment_framework_share(self) -> "Auditmanager":
        '''(experimental) Grants permission to delete a share request for a custom framework in AWS Audit Manager.

        Access Level: Write

        https://docs.aws.amazon.com/audit-manager/latest/APIReference/API_DeleteAssessmentFrameworkShare.html

        :stability: experimental
        '''
        return typing.cast("Auditmanager", jsii.invoke(self, "toDeleteAssessmentFrameworkShare", []))

    @jsii.member(jsii_name="toDeleteAssessmentReport")
    def to_delete_assessment_report(self) -> "Auditmanager":
        '''(experimental) Grants permission to delete an assessment report in AWS Audit Manager.

        Access Level: Write

        https://docs.aws.amazon.com/audit-manager/latest/APIReference/API_DeleteAssessmentReport.html

        :stability: experimental
        '''
        return typing.cast("Auditmanager", jsii.invoke(self, "toDeleteAssessmentReport", []))

    @jsii.member(jsii_name="toDeleteControl")
    def to_delete_control(self) -> "Auditmanager":
        '''(experimental) Grants permission to delete a control in AWS Audit Manager.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/audit-manager/latest/APIReference/API_DeleteControl.html

        :stability: experimental
        '''
        return typing.cast("Auditmanager", jsii.invoke(self, "toDeleteControl", []))

    @jsii.member(jsii_name="toDeregisterAccount")
    def to_deregister_account(self) -> "Auditmanager":
        '''(experimental) Grants permission to deregister an account in AWS Audit Manager.

        Access Level: Write

        https://docs.aws.amazon.com/audit-manager/latest/APIReference/API_ DeregisterAccount.html

        :stability: experimental
        '''
        return typing.cast("Auditmanager", jsii.invoke(self, "toDeregisterAccount", []))

    @jsii.member(jsii_name="toDeregisterOrganizationAdminAccount")
    def to_deregister_organization_admin_account(self) -> "Auditmanager":
        '''(experimental) Grants permission to deregister the delegated administrator account for AWS Audit Manager.

        Access Level: Write

        https://docs.aws.amazon.com/audit-manager/latest/APIReference/API_DeregisterOrganizationAdminAccount.html

        :stability: experimental
        '''
        return typing.cast("Auditmanager", jsii.invoke(self, "toDeregisterOrganizationAdminAccount", []))

    @jsii.member(jsii_name="toDisassociateAssessmentReportEvidenceFolder")
    def to_disassociate_assessment_report_evidence_folder(self) -> "Auditmanager":
        '''(experimental) Grants permission to disassociate an evidence folder from an assessment report in AWS Audit Manager.

        Access Level: Write

        https://docs.aws.amazon.com/audit-manager/latest/APIReference/API_DisassociateAssessmentReportEvidenceFolder.html

        :stability: experimental
        '''
        return typing.cast("Auditmanager", jsii.invoke(self, "toDisassociateAssessmentReportEvidenceFolder", []))

    @jsii.member(jsii_name="toGetAccountStatus")
    def to_get_account_status(self) -> "Auditmanager":
        '''(experimental) Grants permission to get the status of an account in AWS Audit Manager.

        Access Level: Read

        https://docs.aws.amazon.com/audit-manager/latest/APIReference/API_GetAccountStatus.html

        :stability: experimental
        '''
        return typing.cast("Auditmanager", jsii.invoke(self, "toGetAccountStatus", []))

    @jsii.member(jsii_name="toGetAssessment")
    def to_get_assessment(self) -> "Auditmanager":
        '''(experimental) Grants permission to get an assessment created in AWS Audit Manager.

        Access Level: Read

        https://docs.aws.amazon.com/audit-manager/latest/APIReference/API_GetAssessment.html

        :stability: experimental
        '''
        return typing.cast("Auditmanager", jsii.invoke(self, "toGetAssessment", []))

    @jsii.member(jsii_name="toGetAssessmentFramework")
    def to_get_assessment_framework(self) -> "Auditmanager":
        '''(experimental) Grants permission to get an assessment framework in AWS Audit Manager.

        Access Level: Read

        https://docs.aws.amazon.com/audit-manager/latest/APIReference/API_GetAssessmentFramework.html

        :stability: experimental
        '''
        return typing.cast("Auditmanager", jsii.invoke(self, "toGetAssessmentFramework", []))

    @jsii.member(jsii_name="toGetAssessmentReportUrl")
    def to_get_assessment_report_url(self) -> "Auditmanager":
        '''(experimental) Grants permission to get the URL for an assessment report in AWS Audit Manager.

        Access Level: Read

        https://docs.aws.amazon.com/audit-manager/latest/APIReference/API_GetAssessmentReportUrl.html

        :stability: experimental
        '''
        return typing.cast("Auditmanager", jsii.invoke(self, "toGetAssessmentReportUrl", []))

    @jsii.member(jsii_name="toGetChangeLogs")
    def to_get_change_logs(self) -> "Auditmanager":
        '''(experimental) Grants permission to get changelogs for an assessment in AWS Audit Manager.

        Access Level: Read

        https://docs.aws.amazon.com/audit-manager/latest/APIReference/API_GetChangeLogs.html

        :stability: experimental
        '''
        return typing.cast("Auditmanager", jsii.invoke(self, "toGetChangeLogs", []))

    @jsii.member(jsii_name="toGetControl")
    def to_get_control(self) -> "Auditmanager":
        '''(experimental) Grants permission to get a control in AWS Audit Manager.

        Access Level: Read

        https://docs.aws.amazon.com/audit-manager/latest/APIReference/API_GetControl.html

        :stability: experimental
        '''
        return typing.cast("Auditmanager", jsii.invoke(self, "toGetControl", []))

    @jsii.member(jsii_name="toGetDelegations")
    def to_get_delegations(self) -> "Auditmanager":
        '''(experimental) Grants permission to get all delegations in AWS Audit Manager.

        Access Level: List

        https://docs.aws.amazon.com/audit-manager/latest/APIReference/API_GetDelegations.html

        :stability: experimental
        '''
        return typing.cast("Auditmanager", jsii.invoke(self, "toGetDelegations", []))

    @jsii.member(jsii_name="toGetEvidence")
    def to_get_evidence(self) -> "Auditmanager":
        '''(experimental) Grants permission to get evidence from AWS Audit Manager.

        Access Level: Read

        https://docs.aws.amazon.com/audit-manager/latest/APIReference/API_GetEvidence.html

        :stability: experimental
        '''
        return typing.cast("Auditmanager", jsii.invoke(self, "toGetEvidence", []))

    @jsii.member(jsii_name="toGetEvidenceByEvidenceFolder")
    def to_get_evidence_by_evidence_folder(self) -> "Auditmanager":
        '''(experimental) Grants permission to get all the evidence from an evidence folder in AWS Audit Manager.

        Access Level: Read

        https://docs.aws.amazon.com/audit-manager/latest/APIReference/API_GetEvidenceByEvidenceFolder.html

        :stability: experimental
        '''
        return typing.cast("Auditmanager", jsii.invoke(self, "toGetEvidenceByEvidenceFolder", []))

    @jsii.member(jsii_name="toGetEvidenceFolder")
    def to_get_evidence_folder(self) -> "Auditmanager":
        '''(experimental) Grants permission to get the evidence folder from AWS Audit Manager.

        Access Level: Read

        https://docs.aws.amazon.com/audit-manager/latest/APIReference/API_GetEvidenceFolder.html

        :stability: experimental
        '''
        return typing.cast("Auditmanager", jsii.invoke(self, "toGetEvidenceFolder", []))

    @jsii.member(jsii_name="toGetEvidenceFoldersByAssessment")
    def to_get_evidence_folders_by_assessment(self) -> "Auditmanager":
        '''(experimental) Grants permission to get the evidence folders from an assessment in AWS Audit Manager.

        Access Level: Read

        https://docs.aws.amazon.com/audit-manager/latest/APIReference/API_GetEvidenceFoldersByAssessment.html

        :stability: experimental
        '''
        return typing.cast("Auditmanager", jsii.invoke(self, "toGetEvidenceFoldersByAssessment", []))

    @jsii.member(jsii_name="toGetEvidenceFoldersByAssessmentControl")
    def to_get_evidence_folders_by_assessment_control(self) -> "Auditmanager":
        '''(experimental) Grants permission to get the evidence folders from an assessment control in AWS Audit Manager.

        Access Level: Read

        https://docs.aws.amazon.com/audit-manager/latest/APIReference/API_GetEvidenceFoldersByAssessmentControl.html

        :stability: experimental
        '''
        return typing.cast("Auditmanager", jsii.invoke(self, "toGetEvidenceFoldersByAssessmentControl", []))

    @jsii.member(jsii_name="toGetInsights")
    def to_get_insights(self) -> "Auditmanager":
        '''(experimental) Grants permission to get analytics data for all active assessments.

        Access Level: Read

        https://docs.aws.amazon.com/audit-manager/latest/APIReference/API_GetInsights.html

        :stability: experimental
        '''
        return typing.cast("Auditmanager", jsii.invoke(self, "toGetInsights", []))

    @jsii.member(jsii_name="toGetInsightsByAssessment")
    def to_get_insights_by_assessment(self) -> "Auditmanager":
        '''(experimental) Grants permission to get analytics data for a specific active assessment.

        Access Level: Read

        https://docs.aws.amazon.com/audit-manager/latest/APIReference/API_GetInsightsByAssessment.html

        :stability: experimental
        '''
        return typing.cast("Auditmanager", jsii.invoke(self, "toGetInsightsByAssessment", []))

    @jsii.member(jsii_name="toGetOrganizationAdminAccount")
    def to_get_organization_admin_account(self) -> "Auditmanager":
        '''(experimental) Grants permission to get the delegated administrator account in AWS Audit Manager.

        Access Level: Read

        https://docs.aws.amazon.com/audit-manager/latest/APIReference/API_GetOrganizationAdminAccount.html

        :stability: experimental
        '''
        return typing.cast("Auditmanager", jsii.invoke(self, "toGetOrganizationAdminAccount", []))

    @jsii.member(jsii_name="toGetServicesInScope")
    def to_get_services_in_scope(self) -> "Auditmanager":
        '''(experimental) Grants permission to get the services in scope for an assessment in AWS Audit Manager.

        Access Level: Read

        https://docs.aws.amazon.com/audit-manager/latest/APIReference/API_GetServicesInScope.html

        :stability: experimental
        '''
        return typing.cast("Auditmanager", jsii.invoke(self, "toGetServicesInScope", []))

    @jsii.member(jsii_name="toGetSettings")
    def to_get_settings(self) -> "Auditmanager":
        '''(experimental) Grants permission to get all settings configured in AWS Audit Manager.

        Access Level: Read

        https://docs.aws.amazon.com/audit-manager/latest/APIReference/API_GetSettings.html

        :stability: experimental
        '''
        return typing.cast("Auditmanager", jsii.invoke(self, "toGetSettings", []))

    @jsii.member(jsii_name="toListAssessmentControlInsightsByControlDomain")
    def to_list_assessment_control_insights_by_control_domain(self) -> "Auditmanager":
        '''(experimental) Grants permission to list analytics data for controls in a specific control domain and active assessment.

        Access Level: List

        https://docs.aws.amazon.com/audit-manager/latest/APIReference/API_ListAssessmentControlInsightsByControlDomain.html

        :stability: experimental
        '''
        return typing.cast("Auditmanager", jsii.invoke(self, "toListAssessmentControlInsightsByControlDomain", []))

    @jsii.member(jsii_name="toListAssessmentFrameworks")
    def to_list_assessment_frameworks(self) -> "Auditmanager":
        '''(experimental) Grants permission to list all assessment frameworks in AWS Audit Manager.

        Access Level: List

        https://docs.aws.amazon.com/audit-manager/latest/APIReference/API_ListAssessmentFrameworks.html

        :stability: experimental
        '''
        return typing.cast("Auditmanager", jsii.invoke(self, "toListAssessmentFrameworks", []))

    @jsii.member(jsii_name="toListAssessmentFrameworkShareRequests")
    def to_list_assessment_framework_share_requests(self) -> "Auditmanager":
        '''(experimental) Grants permission to list all sent or received share requests for custom frameworks in AWS Audit Manager.

        Access Level: List

        https://docs.aws.amazon.com/audit-manager/latest/APIReference/API_ListAssessmentFrameworkShareRequests.html

        :stability: experimental
        '''
        return typing.cast("Auditmanager", jsii.invoke(self, "toListAssessmentFrameworkShareRequests", []))

    @jsii.member(jsii_name="toListAssessmentReports")
    def to_list_assessment_reports(self) -> "Auditmanager":
        '''(experimental) Grants permission to list all assessment reports in AWS Audit Manager.

        Access Level: List

        https://docs.aws.amazon.com/audit-manager/latest/APIReference/API_ListAssessmentReports.html

        :stability: experimental
        '''
        return typing.cast("Auditmanager", jsii.invoke(self, "toListAssessmentReports", []))

    @jsii.member(jsii_name="toListAssessments")
    def to_list_assessments(self) -> "Auditmanager":
        '''(experimental) Grants permission to list all assessments in AWS Audit Manager.

        Access Level: List

        https://docs.aws.amazon.com/audit-manager/latest/APIReference/API_ListAssessments.html

        :stability: experimental
        '''
        return typing.cast("Auditmanager", jsii.invoke(self, "toListAssessments", []))

    @jsii.member(jsii_name="toListControlDomainInsights")
    def to_list_control_domain_insights(self) -> "Auditmanager":
        '''(experimental) Grants permission to list analytics data for control domains across all active assessments.

        Access Level: List

        https://docs.aws.amazon.com/audit-manager/latest/APIReference/API_ListControlDomainInsights.html

        :stability: experimental
        '''
        return typing.cast("Auditmanager", jsii.invoke(self, "toListControlDomainInsights", []))

    @jsii.member(jsii_name="toListControlDomainInsightsByAssessment")
    def to_list_control_domain_insights_by_assessment(self) -> "Auditmanager":
        '''(experimental) Grants permission to list analytics data for control domains in a specific active assessment.

        Access Level: List

        https://docs.aws.amazon.com/audit-manager/latest/APIReference/API_ListControlDomainInsightsByAssessment.html

        :stability: experimental
        '''
        return typing.cast("Auditmanager", jsii.invoke(self, "toListControlDomainInsightsByAssessment", []))

    @jsii.member(jsii_name="toListControlInsightsByControlDomain")
    def to_list_control_insights_by_control_domain(self) -> "Auditmanager":
        '''(experimental) Grants permission to list analytics data for controls in a specific control domain across all active assessments.

        Access Level: List

        https://docs.aws.amazon.com/audit-manager/latest/APIReference/API_ListControlInsightsByControlDomain.html

        :stability: experimental
        '''
        return typing.cast("Auditmanager", jsii.invoke(self, "toListControlInsightsByControlDomain", []))

    @jsii.member(jsii_name="toListControls")
    def to_list_controls(self) -> "Auditmanager":
        '''(experimental) Grants permission to list all controls in AWS Audit Manager.

        Access Level: List

        https://docs.aws.amazon.com/audit-manager/latest/APIReference/API_ListControls.html

        :stability: experimental
        '''
        return typing.cast("Auditmanager", jsii.invoke(self, "toListControls", []))

    @jsii.member(jsii_name="toListKeywordsForDataSource")
    def to_list_keywords_for_data_source(self) -> "Auditmanager":
        '''(experimental) Grants permission to list all the data source keywords in AWS Audit Manager.

        Access Level: List

        https://docs.aws.amazon.com/audit-manager/latest/APIReference/API_ListKeywordsForDataSource.html

        :stability: experimental
        '''
        return typing.cast("Auditmanager", jsii.invoke(self, "toListKeywordsForDataSource", []))

    @jsii.member(jsii_name="toListNotifications")
    def to_list_notifications(self) -> "Auditmanager":
        '''(experimental) Grants permission to list all notifications in AWS Audit Manager.

        Access Level: List

        https://docs.aws.amazon.com/audit-manager/latest/APIReference/API_ListNotifications.html

        :stability: experimental
        '''
        return typing.cast("Auditmanager", jsii.invoke(self, "toListNotifications", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Auditmanager":
        '''(experimental) Grants permission to list tags for an AWS Audit Manager resource.

        Access Level: Read

        https://docs.aws.amazon.com/audit-manager/latest/APIReference/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("Auditmanager", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toRegisterAccount")
    def to_register_account(self) -> "Auditmanager":
        '''(experimental) Grants permission to register an account in AWS Audit Manager.

        Access Level: Write

        https://docs.aws.amazon.com/audit-manager/latest/APIReference/API_RegisterAccount.html

        :stability: experimental
        '''
        return typing.cast("Auditmanager", jsii.invoke(self, "toRegisterAccount", []))

    @jsii.member(jsii_name="toRegisterOrganizationAdminAccount")
    def to_register_organization_admin_account(self) -> "Auditmanager":
        '''(experimental) Grants permission to register an account within the organization as the delegated administrator for AWS Audit Manager.

        Access Level: Write

        https://docs.aws.amazon.com/audit-manager/latest/APIReference/API_RegisterOrganizationAdminAccount.html

        :stability: experimental
        '''
        return typing.cast("Auditmanager", jsii.invoke(self, "toRegisterOrganizationAdminAccount", []))

    @jsii.member(jsii_name="toStartAssessmentFrameworkShare")
    def to_start_assessment_framework_share(self) -> "Auditmanager":
        '''(experimental) Grants permission to create a share request for a custom framework in AWS Audit Manager.

        Access Level: Write

        https://docs.aws.amazon.com/audit-manager/latest/APIReference/API_StartAssessmentFrameworkShare.html

        :stability: experimental
        '''
        return typing.cast("Auditmanager", jsii.invoke(self, "toStartAssessmentFrameworkShare", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Auditmanager":
        '''(experimental) Grants permission to tag an AWS Audit Manager resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/audit-manager/latest/APIReference/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("Auditmanager", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Auditmanager":
        '''(experimental) Grants permission to untag an AWS Audit Manager resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/audit-manager/latest/APIReference/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("Auditmanager", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateAssessment")
    def to_update_assessment(self) -> "Auditmanager":
        '''(experimental) Grants permission to update an assessment in AWS Audit Manager.

        Access Level: Write

        https://docs.aws.amazon.com/audit-manager/latest/APIReference/API_UpdateAssessment.html

        :stability: experimental
        '''
        return typing.cast("Auditmanager", jsii.invoke(self, "toUpdateAssessment", []))

    @jsii.member(jsii_name="toUpdateAssessmentControl")
    def to_update_assessment_control(self) -> "Auditmanager":
        '''(experimental) Grants permission to update an assessment control in AWS Audit Manager.

        Access Level: Write

        https://docs.aws.amazon.com/audit-manager/latest/APIReference/API_UpdateAssessmentControl.html

        :stability: experimental
        '''
        return typing.cast("Auditmanager", jsii.invoke(self, "toUpdateAssessmentControl", []))

    @jsii.member(jsii_name="toUpdateAssessmentControlSetStatus")
    def to_update_assessment_control_set_status(self) -> "Auditmanager":
        '''(experimental) Grants permission to update the status of an assessment control set in AWS Audit Manager.

        Access Level: Write

        https://docs.aws.amazon.com/audit-manager/latest/APIReference/API_UpdateAssessmentControlSetStatus.html

        :stability: experimental
        '''
        return typing.cast("Auditmanager", jsii.invoke(self, "toUpdateAssessmentControlSetStatus", []))

    @jsii.member(jsii_name="toUpdateAssessmentFramework")
    def to_update_assessment_framework(self) -> "Auditmanager":
        '''(experimental) Grants permission to update an assessment framework in AWS Audit Manager.

        Access Level: Write

        https://docs.aws.amazon.com/audit-manager/latest/APIReference/API_UpdateAssessmentFramework.html

        :stability: experimental
        '''
        return typing.cast("Auditmanager", jsii.invoke(self, "toUpdateAssessmentFramework", []))

    @jsii.member(jsii_name="toUpdateAssessmentFrameworkShare")
    def to_update_assessment_framework_share(self) -> "Auditmanager":
        '''(experimental) Grants permission to update a share request for a custom framework in AWS Audit Manager.

        Access Level: Write

        https://docs.aws.amazon.com/audit-manager/latest/APIReference/API_UpdateAssessmentFrameworkShare.html

        :stability: experimental
        '''
        return typing.cast("Auditmanager", jsii.invoke(self, "toUpdateAssessmentFrameworkShare", []))

    @jsii.member(jsii_name="toUpdateAssessmentStatus")
    def to_update_assessment_status(self) -> "Auditmanager":
        '''(experimental) Grants permission to update the status of an assessment in AWS Audit Manager.

        Access Level: Write

        https://docs.aws.amazon.com/audit-manager/latest/APIReference/API_UpdateAssessmentStatus.html

        :stability: experimental
        '''
        return typing.cast("Auditmanager", jsii.invoke(self, "toUpdateAssessmentStatus", []))

    @jsii.member(jsii_name="toUpdateControl")
    def to_update_control(self) -> "Auditmanager":
        '''(experimental) Grants permission to update a control in AWS Audit Manager.

        Access Level: Write

        https://docs.aws.amazon.com/audit-manager/latest/APIReference/API_UpdateControl.html

        :stability: experimental
        '''
        return typing.cast("Auditmanager", jsii.invoke(self, "toUpdateControl", []))

    @jsii.member(jsii_name="toUpdateSettings")
    def to_update_settings(self) -> "Auditmanager":
        '''(experimental) Grants permission to update settings in AWS Audit Manager.

        Access Level: Write

        https://docs.aws.amazon.com/audit-manager/latest/APIReference/API_UpdateSettings.html

        :stability: experimental
        '''
        return typing.cast("Auditmanager", jsii.invoke(self, "toUpdateSettings", []))

    @jsii.member(jsii_name="toValidateAssessmentReportIntegrity")
    def to_validate_assessment_report_integrity(self) -> "Auditmanager":
        '''(experimental) Grants permission to validate the integrity of an assessment report in AWS Audit Manager.

        Access Level: Read

        https://docs.aws.amazon.com/audit-manager/latest/APIReference/API_ValidateAssessmentReportIntegrity.html

        :stability: experimental
        '''
        return typing.cast("Auditmanager", jsii.invoke(self, "toValidateAssessmentReportIntegrity", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__10fa9c3f184e3091bd78eb361d453db77f55cd3148de3233b3be1006b39db425)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__53a8891f32488827dad1d4ea94d5840e4348c2734c1dd31a027e9982c2b48a0c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Autoscaling(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Autoscaling",
):
    '''(experimental) Statement provider for service `autoscaling <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonec2autoscaling.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `autoscaling <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonec2autoscaling.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="ifImageId")
    def if_image_id(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Autoscaling":
        '''(experimental) Filters access based on the AMI ID for the launch configuration.

        https://docs.aws.amazon.com/autoscaling/latest/userguide/control-access-using-iam.html#policy-auto-scaling-condition-keys

        Applies to actions:

        - .toCreateLaunchConfiguration()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__278990318e91f29a273c3e1696c9809cce7937a93c7f5297066715f2beda85d8)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Autoscaling", jsii.invoke(self, "ifImageId", [value, operator]))

    @jsii.member(jsii_name="ifInstanceType")
    def if_instance_type(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Autoscaling":
        '''(experimental) Filters access based on the instance type for the launch configuration.

        https://docs.aws.amazon.com/autoscaling/latest/userguide/control-access-using-iam.html#policy-auto-scaling-condition-keys

        Applies to actions:

        - .toCreateLaunchConfiguration()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__892a29a7afb4c5e1ec9612396ec0f1bf4ebefea1843aeebb5bd06908e952601d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Autoscaling", jsii.invoke(self, "ifInstanceType", [value, operator]))

    @jsii.member(jsii_name="ifInstanceTypes")
    def if_instance_types(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Autoscaling":
        '''(experimental) Filters access based on the instance types present as overrides to a launch template for a mixed instances policy.

        Use it to qualify which instance types can be explicitly defined in the policy

        https://docs.aws.amazon.com/autoscaling/latest/userguide/control-access-using-iam.html#policy-auto-scaling-condition-keys

        Applies to actions:

        - .toCreateAutoScalingGroup()
        - .toUpdateAutoScalingGroup()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0fd9c71f2f32efdb77f7170931c4bc6540ec76dcefe94b6ca156bef45f042ff3)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Autoscaling", jsii.invoke(self, "ifInstanceTypes", [value, operator]))

    @jsii.member(jsii_name="ifLaunchConfigurationName")
    def if_launch_configuration_name(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Autoscaling":
        '''(experimental) Filters access based on the name of a launch configuration.

        https://docs.aws.amazon.com/autoscaling/latest/userguide/control-access-using-iam.html#policy-auto-scaling-condition-keys

        Applies to actions:

        - .toCreateAutoScalingGroup()
        - .toUpdateAutoScalingGroup()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7c13382c8edbc37af107f9c21553bd1319e42e0ffc802b0bbab243309c1cca74)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Autoscaling", jsii.invoke(self, "ifLaunchConfigurationName", [value, operator]))

    @jsii.member(jsii_name="ifLaunchTemplateVersionSpecified")
    def if_launch_template_version_specified(
        self,
        value: typing.Optional[builtins.bool] = None,
    ) -> "Autoscaling":
        '''(experimental) Filters access based on whether users can specify any version of a launch template or only the Latest or Default version.

        https://docs.aws.amazon.com/autoscaling/latest/userguide/control-access-using-iam.html#policy-auto-scaling-condition-keys

        Applies to actions:

        - .toCreateAutoScalingGroup()
        - .toUpdateAutoScalingGroup()

        :param value: ``true`` or ``false``. **Default:** ``true``

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2e368837242231bc1bdb020da60e1321f40989196409c0b28a585881b6d655a3)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast("Autoscaling", jsii.invoke(self, "ifLaunchTemplateVersionSpecified", [value]))

    @jsii.member(jsii_name="ifLoadBalancerNames")
    def if_load_balancer_names(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Autoscaling":
        '''(experimental) Filters access based on the name of the load balancer.

        https://docs.aws.amazon.com/autoscaling/latest/userguide/control-access-using-iam.html#policy-auto-scaling-condition-keys

        Applies to actions:

        - .toAttachLoadBalancers()
        - .toCreateAutoScalingGroup()
        - .toDetachLoadBalancers()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__72e124d5302d01274c80196ca0b1576b7690f3f9061df79d90449370b85b6a84)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Autoscaling", jsii.invoke(self, "ifLoadBalancerNames", [value, operator]))

    @jsii.member(jsii_name="ifMaxSize")
    def if_max_size(
        self,
        value: typing.Union[jsii.Number, typing.Sequence[jsii.Number]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Autoscaling":
        '''(experimental) Filters access based on the maximum scaling size in the request.

        https://docs.aws.amazon.com/autoscaling/latest/userguide/control-access-using-iam.html#policy-auto-scaling-condition-keys

        Applies to actions:

        - .toCreateAutoScalingGroup()
        - .toPutScheduledUpdateGroupAction()
        - .toUpdateAutoScalingGroup()

        :param value: The value(s) to check.
        :param operator: Works with `numeric operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_Numeric>`_. **Default:** ``NumericEquals``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6a384b0a6d1cce6a2979517b2992910711dfef69ed5c3b89abce9389d5f6b086)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Autoscaling", jsii.invoke(self, "ifMaxSize", [value, operator]))

    @jsii.member(jsii_name="ifMetadataHttpEndpoint")
    def if_metadata_http_endpoint(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Autoscaling":
        '''(experimental) Filters access based on whether the HTTP endpoint is enabled for the instance metadata service.

        https://docs.aws.amazon.com/autoscaling/latest/userguide/control-access-using-iam.html#policy-auto-scaling-condition-keys

        Applies to actions:

        - .toCreateLaunchConfiguration()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__dfeb615a7f9708ee9081becf83bac67a1e3702cb6126c42f1e7978c173f172c0)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Autoscaling", jsii.invoke(self, "ifMetadataHttpEndpoint", [value, operator]))

    @jsii.member(jsii_name="ifMetadataHttpPutResponseHopLimit")
    def if_metadata_http_put_response_hop_limit(
        self,
        value: typing.Union[jsii.Number, typing.Sequence[jsii.Number]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Autoscaling":
        '''(experimental) Filters access based on the allowed number of hops when calling the instance metadata service.

        https://docs.aws.amazon.com/autoscaling/latest/userguide/control-access-using-iam.html#policy-auto-scaling-condition-keys

        Applies to actions:

        - .toCreateLaunchConfiguration()

        :param value: The value(s) to check.
        :param operator: Works with `numeric operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_Numeric>`_. **Default:** ``NumericEquals``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3b50ab304592ed29f7bd5909b7eb61eb3da2e2862bc0f71385b670beb8b49d29)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Autoscaling", jsii.invoke(self, "ifMetadataHttpPutResponseHopLimit", [value, operator]))

    @jsii.member(jsii_name="ifMetadataHttpTokens")
    def if_metadata_http_tokens(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Autoscaling":
        '''(experimental) Filters access based on whether tokens are required when calling the instance metadata service (optional or required).

        https://docs.aws.amazon.com/autoscaling/latest/userguide/control-access-using-iam.html#policy-auto-scaling-condition-keys

        Applies to actions:

        - .toCreateLaunchConfiguration()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3145f9d9f357fcc27091adfbe8a02843101b845f6f8ff89e2e8df929123544e1)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Autoscaling", jsii.invoke(self, "ifMetadataHttpTokens", [value, operator]))

    @jsii.member(jsii_name="ifMinSize")
    def if_min_size(
        self,
        value: typing.Union[jsii.Number, typing.Sequence[jsii.Number]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Autoscaling":
        '''(experimental) Filters access based on the minimum scaling size in the request.

        https://docs.aws.amazon.com/autoscaling/latest/userguide/control-access-using-iam.html#policy-auto-scaling-condition-keys

        Applies to actions:

        - .toCreateAutoScalingGroup()
        - .toPutScheduledUpdateGroupAction()
        - .toUpdateAutoScalingGroup()

        :param value: The value(s) to check.
        :param operator: Works with `numeric operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_Numeric>`_. **Default:** ``NumericEquals``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c0477fdb10a3c4e3ae6d59807513c434157afe485a178f085f2fa987f1093ced)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Autoscaling", jsii.invoke(self, "ifMinSize", [value, operator]))

    @jsii.member(jsii_name="ifResourceTag")
    def if_resource_tag(
        self,
        tag_key: builtins.str,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Autoscaling":
        '''(experimental) Filters access based on the tags associated with the resource.

        https://docs.aws.amazon.com/autoscaling/latest/userguide/control-access-using-iam.html#policy-auto-scaling-condition-keys

        Applies to actions:

        - .toAttachInstances()
        - .toAttachLoadBalancerTargetGroups()
        - .toAttachLoadBalancers()
        - .toBatchDeleteScheduledAction()
        - .toBatchPutScheduledUpdateGroupAction()
        - .toCancelInstanceRefresh()
        - .toCompleteLifecycleAction()
        - .toCreateAutoScalingGroup()
        - .toCreateOrUpdateTags()
        - .toDeleteAutoScalingGroup()
        - .toDeleteLifecycleHook()
        - .toDeleteNotificationConfiguration()
        - .toDeletePolicy()
        - .toDeleteScheduledAction()
        - .toDeleteTags()
        - .toDeleteWarmPool()
        - .toDetachInstances()
        - .toDetachLoadBalancerTargetGroups()
        - .toDetachLoadBalancers()
        - .toDisableMetricsCollection()
        - .toEnableMetricsCollection()
        - .toEnterStandby()
        - .toExecutePolicy()
        - .toExitStandby()
        - .toPutLifecycleHook()
        - .toPutNotificationConfiguration()
        - .toPutScalingPolicy()
        - .toPutScheduledUpdateGroupAction()
        - .toPutWarmPool()
        - .toRecordLifecycleActionHeartbeat()
        - .toResumeProcesses()
        - .toSetDesiredCapacity()
        - .toSetInstanceHealth()
        - .toSetInstanceProtection()
        - .toStartInstanceRefresh()
        - .toSuspendProcesses()
        - .toTerminateInstanceInAutoScalingGroup()
        - .toUpdateAutoScalingGroup()

        Applies to resource types:

        - autoScalingGroup

        :param tag_key: The tag key to check.
        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f734d95a06604240774bfb2249e9c3adf797744fcee3c7a119446f1fdef58343)
            check_type(argname="argument tag_key", value=tag_key, expected_type=type_hints["tag_key"])
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Autoscaling", jsii.invoke(self, "ifResourceTag", [tag_key, value, operator]))

    @jsii.member(jsii_name="ifSpotPrice")
    def if_spot_price(
        self,
        value: typing.Union[jsii.Number, typing.Sequence[jsii.Number]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Autoscaling":
        '''(experimental) Filters access based on the price for Spot Instances for the launch configuration.

        https://docs.aws.amazon.com/autoscaling/latest/userguide/control-access-using-iam.html#policy-auto-scaling-condition-keys

        Applies to actions:

        - .toCreateLaunchConfiguration()

        :param value: The value(s) to check.
        :param operator: Works with `numeric operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_Numeric>`_. **Default:** ``NumericEquals``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c2187b0d17273e71c2a020c3324135bdbec70097e39c95b8a345d8f994d95bb1)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Autoscaling", jsii.invoke(self, "ifSpotPrice", [value, operator]))

    @jsii.member(jsii_name="ifTargetGroupARNs")
    def if_target_group_ar_ns(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Autoscaling":
        '''(experimental) Filters access based on the ARN of a target group.

        https://docs.aws.amazon.com/autoscaling/latest/userguide/control-access-using-iam.html#policy-auto-scaling-condition-keys

        Applies to actions:

        - .toAttachLoadBalancerTargetGroups()
        - .toCreateAutoScalingGroup()
        - .toDetachLoadBalancerTargetGroups()

        :param value: The value(s) to check.
        :param operator: Works with `arn operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_ARN>`_. **Default:** ``ArnLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d2667d7d70d5b76c407954a43e326f168833565d687db39e6e29b9538e0cdcb8)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Autoscaling", jsii.invoke(self, "ifTargetGroupARNs", [value, operator]))

    @jsii.member(jsii_name="ifTrafficSourceIdentifiers")
    def if_traffic_source_identifiers(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Autoscaling":
        '''(experimental) Filters access based on the identifiers of the traffic sources.

        https://docs.aws.amazon.com/autoscaling/latest/userguide/control-access-using-iam.html#policy-auto-scaling-condition-keys

        Applies to actions:

        - .toCreateAutoScalingGroup()

        :param value: The value(s) to check.
        :param operator: Works with `arn operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_ARN>`_. **Default:** ``ArnLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ea572588f7285e94450052b02644855ddc0c6928fe157695e1c57449e03aa620)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Autoscaling", jsii.invoke(self, "ifTrafficSourceIdentifiers", [value, operator]))

    @jsii.member(jsii_name="ifVPCZoneIdentifiers")
    def if_vpc_zone_identifiers(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Autoscaling":
        '''(experimental) Filters access based on the identifier of a VPC zone.

        https://docs.aws.amazon.com/autoscaling/latest/userguide/control-access-using-iam.html#policy-auto-scaling-condition-keys

        Applies to actions:

        - .toCreateAutoScalingGroup()
        - .toUpdateAutoScalingGroup()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0705394887820eeaafbe4bb31c964b83bc3926764947db810492a7a716248875)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Autoscaling", jsii.invoke(self, "ifVPCZoneIdentifiers", [value, operator]))

    @jsii.member(jsii_name="onAutoScalingGroup")
    def on_auto_scaling_group(
        self,
        group_id: builtins.str,
        group_friendly_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Autoscaling":
        '''(experimental) Adds a resource of type autoScalingGroup to the statement.

        https://docs.aws.amazon.com/autoscaling/latest/userguide/control-access-using-iam.html#policy-auto-scaling-resources

        :param group_id: - Identifier for the groupId.
        :param group_friendly_name: - Identifier for the groupFriendlyName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifResourceTag() - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__02db601addd706684362faf432cf7dda84a734e16204423f492d2df332dda899)
            check_type(argname="argument group_id", value=group_id, expected_type=type_hints["group_id"])
            check_type(argname="argument group_friendly_name", value=group_friendly_name, expected_type=type_hints["group_friendly_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Autoscaling", jsii.invoke(self, "onAutoScalingGroup", [group_id, group_friendly_name, account, region, partition]))

    @jsii.member(jsii_name="onLaunchConfiguration")
    def on_launch_configuration(
        self,
        id: builtins.str,
        launch_configuration_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Autoscaling":
        '''(experimental) Adds a resource of type launchConfiguration to the statement.

        https://docs.aws.amazon.com/autoscaling/latest/userguide/control-access-using-iam.html#policy-auto-scaling-resources

        :param id: - Identifier for the id.
        :param launch_configuration_name: - Identifier for the launchConfigurationName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__387508a700ffa3efa72d018636e8d9bba745a58eb556794077739edc7c791fa0)
            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
            check_type(argname="argument launch_configuration_name", value=launch_configuration_name, expected_type=type_hints["launch_configuration_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Autoscaling", jsii.invoke(self, "onLaunchConfiguration", [id, launch_configuration_name, account, region, partition]))

    @jsii.member(jsii_name="toAttachInstances")
    def to_attach_instances(self) -> "Autoscaling":
        '''(experimental) Grants permission to attach one or more EC2 instances to the specified Auto Scaling group.

        Access Level: Write

        https://docs.aws.amazon.com/AutoScaling/latest/APIReference/API_AttachInstances.html

        :stability: experimental
        '''
        return typing.cast("Autoscaling", jsii.invoke(self, "toAttachInstances", []))

    @jsii.member(jsii_name="toAttachLoadBalancers")
    def to_attach_load_balancers(self) -> "Autoscaling":
        '''(experimental) Grants permission to attach one or more load balancers to the specified Auto Scaling group.

        Access Level: Write

        Possible conditions:

        - .ifLoadBalancerNames()

        https://docs.aws.amazon.com/AutoScaling/latest/APIReference/API_AttachLoadBalancers.html

        :stability: experimental
        '''
        return typing.cast("Autoscaling", jsii.invoke(self, "toAttachLoadBalancers", []))

    @jsii.member(jsii_name="toAttachLoadBalancerTargetGroups")
    def to_attach_load_balancer_target_groups(self) -> "Autoscaling":
        '''(experimental) Grants permission to attach one or more target groups to the specified Auto Scaling group.

        Access Level: Write

        Possible conditions:

        - .ifTargetGroupARNs()

        https://docs.aws.amazon.com/AutoScaling/latest/APIReference/API_AttachLoadBalancerTargetGroups.html

        :stability: experimental
        '''
        return typing.cast("Autoscaling", jsii.invoke(self, "toAttachLoadBalancerTargetGroups", []))

    @jsii.member(jsii_name="toBatchDeleteScheduledAction")
    def to_batch_delete_scheduled_action(self) -> "Autoscaling":
        '''(experimental) Grants permission to delete the specified scheduled actions.

        Access Level: Write

        https://docs.aws.amazon.com/AutoScaling/latest/APIReference/API_BatchDeleteScheduledAction.html

        :stability: experimental
        '''
        return typing.cast("Autoscaling", jsii.invoke(self, "toBatchDeleteScheduledAction", []))

    @jsii.member(jsii_name="toBatchPutScheduledUpdateGroupAction")
    def to_batch_put_scheduled_update_group_action(self) -> "Autoscaling":
        '''(experimental) Grants permission to create or update multiple scheduled scaling actions for an Auto Scaling group.

        Access Level: Write

        https://docs.aws.amazon.com/AutoScaling/latest/APIReference/API_BatchPutScheduledUpdateGroupAction.html

        :stability: experimental
        '''
        return typing.cast("Autoscaling", jsii.invoke(self, "toBatchPutScheduledUpdateGroupAction", []))

    @jsii.member(jsii_name="toCancelInstanceRefresh")
    def to_cancel_instance_refresh(self) -> "Autoscaling":
        '''(experimental) Grants permission to cancel an instance refresh operation in progress.

        Access Level: Write

        https://docs.aws.amazon.com/AutoScaling/latest/APIReference/API_CancelInstanceRefresh.html

        :stability: experimental
        '''
        return typing.cast("Autoscaling", jsii.invoke(self, "toCancelInstanceRefresh", []))

    @jsii.member(jsii_name="toCompleteLifecycleAction")
    def to_complete_lifecycle_action(self) -> "Autoscaling":
        '''(experimental) Grants permission to complete the lifecycle action for the specified token or instance with the specified result.

        Access Level: Write

        https://docs.aws.amazon.com/AutoScaling/latest/APIReference/API_CompleteLifecycleAction.html

        :stability: experimental
        '''
        return typing.cast("Autoscaling", jsii.invoke(self, "toCompleteLifecycleAction", []))

    @jsii.member(jsii_name="toCreateAutoScalingGroup")
    def to_create_auto_scaling_group(self) -> "Autoscaling":
        '''(experimental) Grants permission to create an Auto Scaling group with the specified name and attributes.

        Access Level: Write

        Possible conditions:

        - .ifInstanceTypes()
        - .ifLaunchConfigurationName()
        - .ifLaunchTemplateVersionSpecified()
        - .ifLoadBalancerNames()
        - .ifMaxSize()
        - .ifMinSize()
        - .ifTargetGroupARNs()
        - .ifTrafficSourceIdentifiers()
        - .ifVPCZoneIdentifiers()
        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - iam:CreateServiceLinkedRole
        - iam:PassRole

        https://docs.aws.amazon.com/AutoScaling/latest/APIReference/API_CreateAutoScalingGroup.html

        :stability: experimental
        '''
        return typing.cast("Autoscaling", jsii.invoke(self, "toCreateAutoScalingGroup", []))

    @jsii.member(jsii_name="toCreateLaunchConfiguration")
    def to_create_launch_configuration(self) -> "Autoscaling":
        '''(experimental) Grants permission to create a launch configuration.

        Access Level: Write

        Possible conditions:

        - .ifImageId()
        - .ifInstanceType()
        - .ifSpotPrice()
        - .ifMetadataHttpTokens()
        - .ifMetadataHttpPutResponseHopLimit()
        - .ifMetadataHttpEndpoint()

        https://docs.aws.amazon.com/AutoScaling/latest/APIReference/API_CreateLaunchConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Autoscaling", jsii.invoke(self, "toCreateLaunchConfiguration", []))

    @jsii.member(jsii_name="toCreateOrUpdateTags")
    def to_create_or_update_tags(self) -> "Autoscaling":
        '''(experimental) Grants permission to create or update tags for the specified Auto Scaling group.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/AutoScaling/latest/APIReference/API_CreateOrUpdateTags.html

        :stability: experimental
        '''
        return typing.cast("Autoscaling", jsii.invoke(self, "toCreateOrUpdateTags", []))

    @jsii.member(jsii_name="toDeleteAutoScalingGroup")
    def to_delete_auto_scaling_group(self) -> "Autoscaling":
        '''(experimental) Grants permission to delete the specified Auto Scaling group.

        Access Level: Write

        https://docs.aws.amazon.com/AutoScaling/latest/APIReference/API_DeleteAutoScalingGroup.html

        :stability: experimental
        '''
        return typing.cast("Autoscaling", jsii.invoke(self, "toDeleteAutoScalingGroup", []))

    @jsii.member(jsii_name="toDeleteLaunchConfiguration")
    def to_delete_launch_configuration(self) -> "Autoscaling":
        '''(experimental) Grants permission to delete the specified launch configuration.

        Access Level: Write

        https://docs.aws.amazon.com/AutoScaling/latest/APIReference/API_DeleteLaunchConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Autoscaling", jsii.invoke(self, "toDeleteLaunchConfiguration", []))

    @jsii.member(jsii_name="toDeleteLifecycleHook")
    def to_delete_lifecycle_hook(self) -> "Autoscaling":
        '''(experimental) Grants permission to deletes the specified lifecycle hook.

        Access Level: Write

        https://docs.aws.amazon.com/AutoScaling/latest/APIReference/API_DeleteLifecycleHook.html

        :stability: experimental
        '''
        return typing.cast("Autoscaling", jsii.invoke(self, "toDeleteLifecycleHook", []))

    @jsii.member(jsii_name="toDeleteNotificationConfiguration")
    def to_delete_notification_configuration(self) -> "Autoscaling":
        '''(experimental) Grants permission to delete the specified notification.

        Access Level: Write

        https://docs.aws.amazon.com/AutoScaling/latest/APIReference/API_DeleteNotificationConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Autoscaling", jsii.invoke(self, "toDeleteNotificationConfiguration", []))

    @jsii.member(jsii_name="toDeletePolicy")
    def to_delete_policy(self) -> "Autoscaling":
        '''(experimental) Grants permission to delete the specified Auto Scaling policy.

        Access Level: Write

        https://docs.aws.amazon.com/AutoScaling/latest/APIReference/API_DeletePolicy.html

        :stability: experimental
        '''
        return typing.cast("Autoscaling", jsii.invoke(self, "toDeletePolicy", []))

    @jsii.member(jsii_name="toDeleteScheduledAction")
    def to_delete_scheduled_action(self) -> "Autoscaling":
        '''(experimental) Grants permission to delete the specified scheduled action.

        Access Level: Write

        https://docs.aws.amazon.com/AutoScaling/latest/APIReference/API_DeleteScheduledAction.html

        :stability: experimental
        '''
        return typing.cast("Autoscaling", jsii.invoke(self, "toDeleteScheduledAction", []))

    @jsii.member(jsii_name="toDeleteTags")
    def to_delete_tags(self) -> "Autoscaling":
        '''(experimental) Grants permission to delete the specified tags.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/AutoScaling/latest/APIReference/API_DeleteTags.html

        :stability: experimental
        '''
        return typing.cast("Autoscaling", jsii.invoke(self, "toDeleteTags", []))

    @jsii.member(jsii_name="toDeleteWarmPool")
    def to_delete_warm_pool(self) -> "Autoscaling":
        '''(experimental) Grants permission to delete the warm pool associated with the Auto Scaling group.

        Access Level: Write

        https://docs.aws.amazon.com/AutoScaling/latest/APIReference/API_DeleteWarmPool.html

        :stability: experimental
        '''
        return typing.cast("Autoscaling", jsii.invoke(self, "toDeleteWarmPool", []))

    @jsii.member(jsii_name="toDescribeAccountLimits")
    def to_describe_account_limits(self) -> "Autoscaling":
        '''(experimental) Grants permission to describe the current Auto Scaling resource limits for your AWS account.

        Access Level: List

        https://docs.aws.amazon.com/AutoScaling/latest/APIReference/API_DescribeAccountLimits.html

        :stability: experimental
        '''
        return typing.cast("Autoscaling", jsii.invoke(self, "toDescribeAccountLimits", []))

    @jsii.member(jsii_name="toDescribeAdjustmentTypes")
    def to_describe_adjustment_types(self) -> "Autoscaling":
        '''(experimental) Grants permission to describe the policy adjustment types for use with PutScalingPolicy.

        Access Level: List

        https://docs.aws.amazon.com/AutoScaling/latest/APIReference/API_DescribeAdjustmentTypes.html

        :stability: experimental
        '''
        return typing.cast("Autoscaling", jsii.invoke(self, "toDescribeAdjustmentTypes", []))

    @jsii.member(jsii_name="toDescribeAutoScalingGroups")
    def to_describe_auto_scaling_groups(self) -> "Autoscaling":
        '''(experimental) Grants permission to describe one or more Auto Scaling groups.

        If a list of names is not provided, the call describes all Auto Scaling groups

        Access Level: List

        https://docs.aws.amazon.com/AutoScaling/latest/APIReference/API_DescribeAutoScalingGroups.html

        :stability: experimental
        '''
        return typing.cast("Autoscaling", jsii.invoke(self, "toDescribeAutoScalingGroups", []))

    @jsii.member(jsii_name="toDescribeAutoScalingInstances")
    def to_describe_auto_scaling_instances(self) -> "Autoscaling":
        '''(experimental) Grants permission to describe one or more Auto Scaling instances.

        If a list is not provided, the call describes all instances

        Access Level: List

        https://docs.aws.amazon.com/AutoScaling/latest/APIReference/API_DescribeAutoScalingInstances.html

        :stability: experimental
        '''
        return typing.cast("Autoscaling", jsii.invoke(self, "toDescribeAutoScalingInstances", []))

    @jsii.member(jsii_name="toDescribeAutoScalingNotificationTypes")
    def to_describe_auto_scaling_notification_types(self) -> "Autoscaling":
        '''(experimental) Grants permission to describe the notification types that are supported by Auto Scaling.

        Access Level: List

        https://docs.aws.amazon.com/AutoScaling/latest/APIReference/API_DescribeAutoScalingNotificationTypes.html

        :stability: experimental
        '''
        return typing.cast("Autoscaling", jsii.invoke(self, "toDescribeAutoScalingNotificationTypes", []))

    @jsii.member(jsii_name="toDescribeInstanceRefreshes")
    def to_describe_instance_refreshes(self) -> "Autoscaling":
        '''(experimental) Grants permission to describe one or more instance refreshes for an Auto Scaling group.

        Access Level: List

        https://docs.aws.amazon.com/AutoScaling/latest/APIReference/API_DescribeInstanceRefreshes.html

        :stability: experimental
        '''
        return typing.cast("Autoscaling", jsii.invoke(self, "toDescribeInstanceRefreshes", []))

    @jsii.member(jsii_name="toDescribeLaunchConfigurations")
    def to_describe_launch_configurations(self) -> "Autoscaling":
        '''(experimental) Grants permission to describe one or more launch configurations.

        If you omit the list of names, then the call describes all launch configurations

        Access Level: List

        https://docs.aws.amazon.com/AutoScaling/latest/APIReference/API_DescribeLaunchConfigurations.html

        :stability: experimental
        '''
        return typing.cast("Autoscaling", jsii.invoke(self, "toDescribeLaunchConfigurations", []))

    @jsii.member(jsii_name="toDescribeLifecycleHooks")
    def to_describe_lifecycle_hooks(self) -> "Autoscaling":
        '''(experimental) Grants permission to describe the lifecycle hooks for the specified Auto Scaling group.

        Access Level: List

        https://docs.aws.amazon.com/AutoScaling/latest/APIReference/API_DescribeLifecycleHooks.html

        :stability: experimental
        '''
        return typing.cast("Autoscaling", jsii.invoke(self, "toDescribeLifecycleHooks", []))

    @jsii.member(jsii_name="toDescribeLifecycleHookTypes")
    def to_describe_lifecycle_hook_types(self) -> "Autoscaling":
        '''(experimental) Grants permission to describe the available types of lifecycle hooks.

        Access Level: List

        https://docs.aws.amazon.com/AutoScaling/latest/APIReference/API_DescribeLifecycleHookTypes.html

        :stability: experimental
        '''
        return typing.cast("Autoscaling", jsii.invoke(self, "toDescribeLifecycleHookTypes", []))

    @jsii.member(jsii_name="toDescribeLoadBalancers")
    def to_describe_load_balancers(self) -> "Autoscaling":
        '''(experimental) Grants permission to describe the load balancers for the specified Auto Scaling group.

        Access Level: List

        https://docs.aws.amazon.com/AutoScaling/latest/APIReference/API_DescribeLoadBalancers.html

        :stability: experimental
        '''
        return typing.cast("Autoscaling", jsii.invoke(self, "toDescribeLoadBalancers", []))

    @jsii.member(jsii_name="toDescribeLoadBalancerTargetGroups")
    def to_describe_load_balancer_target_groups(self) -> "Autoscaling":
        '''(experimental) Grants permission to describe the target groups for the specified Auto Scaling group.

        Access Level: List

        https://docs.aws.amazon.com/AutoScaling/latest/APIReference/API_DescribeLoadBalancerTargetGroups.html

        :stability: experimental
        '''
        return typing.cast("Autoscaling", jsii.invoke(self, "toDescribeLoadBalancerTargetGroups", []))

    @jsii.member(jsii_name="toDescribeMetricCollectionTypes")
    def to_describe_metric_collection_types(self) -> "Autoscaling":
        '''(experimental) Grants permission to describe the available CloudWatch metrics for Auto Scaling.

        Access Level: List

        https://docs.aws.amazon.com/AutoScaling/latest/APIReference/API_DescribeMetricCollectionTypes.html

        :stability: experimental
        '''
        return typing.cast("Autoscaling", jsii.invoke(self, "toDescribeMetricCollectionTypes", []))

    @jsii.member(jsii_name="toDescribeNotificationConfigurations")
    def to_describe_notification_configurations(self) -> "Autoscaling":
        '''(experimental) Grants permission to describe the notification actions associated with the specified Auto Scaling group.

        Access Level: List

        https://docs.aws.amazon.com/AutoScaling/latest/APIReference/API_DescribeNotificationConfigurations.html

        :stability: experimental
        '''
        return typing.cast("Autoscaling", jsii.invoke(self, "toDescribeNotificationConfigurations", []))

    @jsii.member(jsii_name="toDescribePolicies")
    def to_describe_policies(self) -> "Autoscaling":
        '''(experimental) Grants permission to describe the policies for the specified Auto Scaling group.

        Access Level: List

        https://docs.aws.amazon.com/AutoScaling/latest/APIReference/API_DescribePolicies.html

        :stability: experimental
        '''
        return typing.cast("Autoscaling", jsii.invoke(self, "toDescribePolicies", []))

    @jsii.member(jsii_name="toDescribeScalingActivities")
    def to_describe_scaling_activities(self) -> "Autoscaling":
        '''(experimental) Grants permission to describe one or more scaling activities for the specified Auto Scaling group.

        Access Level: List

        https://docs.aws.amazon.com/AutoScaling/latest/APIReference/API_DescribeScalingActivities.html

        :stability: experimental
        '''
        return typing.cast("Autoscaling", jsii.invoke(self, "toDescribeScalingActivities", []))

    @jsii.member(jsii_name="toDescribeScalingProcessTypes")
    def to_describe_scaling_process_types(self) -> "Autoscaling":
        '''(experimental) Grants permission to describe the scaling process types for use with ResumeProcesses and SuspendProcesses.

        Access Level: List

        https://docs.aws.amazon.com/AutoScaling/latest/APIReference/API_DescribeScalingProcessTypes.html

        :stability: experimental
        '''
        return typing.cast("Autoscaling", jsii.invoke(self, "toDescribeScalingProcessTypes", []))

    @jsii.member(jsii_name="toDescribeScheduledActions")
    def to_describe_scheduled_actions(self) -> "Autoscaling":
        '''(experimental) Grants permission to describe the actions scheduled for your Auto Scaling group that haven't run.

        Access Level: List

        https://docs.aws.amazon.com/AutoScaling/latest/APIReference/API_DescribeScheduledActions.html

        :stability: experimental
        '''
        return typing.cast("Autoscaling", jsii.invoke(self, "toDescribeScheduledActions", []))

    @jsii.member(jsii_name="toDescribeTags")
    def to_describe_tags(self) -> "Autoscaling":
        '''(experimental) Grants permission to describe the specified tags.

        Access Level: Read

        https://docs.aws.amazon.com/AutoScaling/latest/APIReference/API_DescribeTags.html

        :stability: experimental
        '''
        return typing.cast("Autoscaling", jsii.invoke(self, "toDescribeTags", []))

    @jsii.member(jsii_name="toDescribeTerminationPolicyTypes")
    def to_describe_termination_policy_types(self) -> "Autoscaling":
        '''(experimental) Grants permission to describe the termination policies supported by Auto Scaling.

        Access Level: List

        https://docs.aws.amazon.com/AutoScaling/latest/APIReference/API_DescribeTerminationPolicyTypes.html

        :stability: experimental
        '''
        return typing.cast("Autoscaling", jsii.invoke(self, "toDescribeTerminationPolicyTypes", []))

    @jsii.member(jsii_name="toDescribeWarmPool")
    def to_describe_warm_pool(self) -> "Autoscaling":
        '''(experimental) Grants permission to describe the warm pool associated with the Auto Scaling group.

        Access Level: List

        https://docs.aws.amazon.com/AutoScaling/latest/APIReference/API_DescribeWarmPool.html

        :stability: experimental
        '''
        return typing.cast("Autoscaling", jsii.invoke(self, "toDescribeWarmPool", []))

    @jsii.member(jsii_name="toDetachInstances")
    def to_detach_instances(self) -> "Autoscaling":
        '''(experimental) Grants permission to remove one or more instances from the specified Auto Scaling group.

        Access Level: Write

        https://docs.aws.amazon.com/AutoScaling/latest/APIReference/API_DetachInstances.html

        :stability: experimental
        '''
        return typing.cast("Autoscaling", jsii.invoke(self, "toDetachInstances", []))

    @jsii.member(jsii_name="toDetachLoadBalancers")
    def to_detach_load_balancers(self) -> "Autoscaling":
        '''(experimental) Grants permission to remove one or more load balancers from the specified Auto Scaling group.

        Access Level: Write

        Possible conditions:

        - .ifLoadBalancerNames()

        https://docs.aws.amazon.com/AutoScaling/latest/APIReference/API_DetachLoadBalancers.html

        :stability: experimental
        '''
        return typing.cast("Autoscaling", jsii.invoke(self, "toDetachLoadBalancers", []))

    @jsii.member(jsii_name="toDetachLoadBalancerTargetGroups")
    def to_detach_load_balancer_target_groups(self) -> "Autoscaling":
        '''(experimental) Grants permission to detach one or more target groups from the specified Auto Scaling group.

        Access Level: Write

        Possible conditions:

        - .ifTargetGroupARNs()

        https://docs.aws.amazon.com/AutoScaling/latest/APIReference/API_DetachLoadBalancerTargetGroups.html

        :stability: experimental
        '''
        return typing.cast("Autoscaling", jsii.invoke(self, "toDetachLoadBalancerTargetGroups", []))

    @jsii.member(jsii_name="toDisableMetricsCollection")
    def to_disable_metrics_collection(self) -> "Autoscaling":
        '''(experimental) Grants permission to disable monitoring of the specified metrics for the specified Auto Scaling group.

        Access Level: Write

        https://docs.aws.amazon.com/AutoScaling/latest/APIReference/API_DisableMetricsCollection.html

        :stability: experimental
        '''
        return typing.cast("Autoscaling", jsii.invoke(self, "toDisableMetricsCollection", []))

    @jsii.member(jsii_name="toEnableMetricsCollection")
    def to_enable_metrics_collection(self) -> "Autoscaling":
        '''(experimental) Grants permission to enable monitoring of the specified metrics for the specified Auto Scaling group.

        Access Level: Write

        https://docs.aws.amazon.com/AutoScaling/latest/APIReference/API_EnableMetricsCollection.html

        :stability: experimental
        '''
        return typing.cast("Autoscaling", jsii.invoke(self, "toEnableMetricsCollection", []))

    @jsii.member(jsii_name="toEnterStandby")
    def to_enter_standby(self) -> "Autoscaling":
        '''(experimental) Grants permission to move the specified instances into Standby mode.

        Access Level: Write

        https://docs.aws.amazon.com/AutoScaling/latest/APIReference/API_EnterStandby.html

        :stability: experimental
        '''
        return typing.cast("Autoscaling", jsii.invoke(self, "toEnterStandby", []))

    @jsii.member(jsii_name="toExecutePolicy")
    def to_execute_policy(self) -> "Autoscaling":
        '''(experimental) Grants permission to execute the specified policy.

        Access Level: Write

        https://docs.aws.amazon.com/AutoScaling/latest/APIReference/API_ExecutePolicy.html

        :stability: experimental
        '''
        return typing.cast("Autoscaling", jsii.invoke(self, "toExecutePolicy", []))

    @jsii.member(jsii_name="toExitStandby")
    def to_exit_standby(self) -> "Autoscaling":
        '''(experimental) Grants permission to move the specified instances out of Standby mode.

        Access Level: Write

        https://docs.aws.amazon.com/AutoScaling/latest/APIReference/API_ExitStandby.html

        :stability: experimental
        '''
        return typing.cast("Autoscaling", jsii.invoke(self, "toExitStandby", []))

    @jsii.member(jsii_name="toGetPredictiveScalingForecast")
    def to_get_predictive_scaling_forecast(self) -> "Autoscaling":
        '''(experimental) Grants permission to retrieve the forecast data for a predictive scaling policy.

        Access Level: List

        https://docs.aws.amazon.com/AutoScaling/latest/APIReference/API_GetPredictiveScalingForecast.html

        :stability: experimental
        '''
        return typing.cast("Autoscaling", jsii.invoke(self, "toGetPredictiveScalingForecast", []))

    @jsii.member(jsii_name="toPutLifecycleHook")
    def to_put_lifecycle_hook(self) -> "Autoscaling":
        '''(experimental) Grants permission to create or update a lifecycle hook for the specified Auto Scaling Group.

        Access Level: Write

        https://docs.aws.amazon.com/AutoScaling/latest/APIReference/API_PutLifecycleHook.html

        :stability: experimental
        '''
        return typing.cast("Autoscaling", jsii.invoke(self, "toPutLifecycleHook", []))

    @jsii.member(jsii_name="toPutNotificationConfiguration")
    def to_put_notification_configuration(self) -> "Autoscaling":
        '''(experimental) Grants permission to configure an Auto Scaling group to send notifications when specified events take place.

        Access Level: Write

        https://docs.aws.amazon.com/AutoScaling/latest/APIReference/API_PutNotificationConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Autoscaling", jsii.invoke(self, "toPutNotificationConfiguration", []))

    @jsii.member(jsii_name="toPutScalingPolicy")
    def to_put_scaling_policy(self) -> "Autoscaling":
        '''(experimental) Grants permission to create or update a policy for an Auto Scaling group.

        Access Level: Write

        https://docs.aws.amazon.com/AutoScaling/latest/APIReference/API_PutScalingPolicy.html

        :stability: experimental
        '''
        return typing.cast("Autoscaling", jsii.invoke(self, "toPutScalingPolicy", []))

    @jsii.member(jsii_name="toPutScheduledUpdateGroupAction")
    def to_put_scheduled_update_group_action(self) -> "Autoscaling":
        '''(experimental) Grants permission to create or update a scheduled scaling action for an Auto Scaling group.

        Access Level: Write

        Possible conditions:

        - .ifMaxSize()
        - .ifMinSize()

        https://docs.aws.amazon.com/AutoScaling/latest/APIReference/API_PutScheduledUpdateGroupAction.html

        :stability: experimental
        '''
        return typing.cast("Autoscaling", jsii.invoke(self, "toPutScheduledUpdateGroupAction", []))

    @jsii.member(jsii_name="toPutWarmPool")
    def to_put_warm_pool(self) -> "Autoscaling":
        '''(experimental) Grants permission to create or update the warm pool associated with the specified Auto Scaling group.

        Access Level: Write

        https://docs.aws.amazon.com/AutoScaling/latest/APIReference/API_PutWarmPool.html

        :stability: experimental
        '''
        return typing.cast("Autoscaling", jsii.invoke(self, "toPutWarmPool", []))

    @jsii.member(jsii_name="toRecordLifecycleActionHeartbeat")
    def to_record_lifecycle_action_heartbeat(self) -> "Autoscaling":
        '''(experimental) Grants permission to record a heartbeat for the lifecycle action associated with the specified token or instance.

        Access Level: Write

        https://docs.aws.amazon.com/AutoScaling/latest/APIReference/API_RecordLifecycleActionHeartbeat.html

        :stability: experimental
        '''
        return typing.cast("Autoscaling", jsii.invoke(self, "toRecordLifecycleActionHeartbeat", []))

    @jsii.member(jsii_name="toResumeProcesses")
    def to_resume_processes(self) -> "Autoscaling":
        '''(experimental) Grants permission to resume the specified suspended Auto Scaling processes, or all suspended process, for the specified Auto Scaling group.

        Access Level: Write

        https://docs.aws.amazon.com/AutoScaling/latest/APIReference/API_ResumeProcesses.html

        :stability: experimental
        '''
        return typing.cast("Autoscaling", jsii.invoke(self, "toResumeProcesses", []))

    @jsii.member(jsii_name="toSetDesiredCapacity")
    def to_set_desired_capacity(self) -> "Autoscaling":
        '''(experimental) Grants permission to set the size of the specified Auto Scaling group.

        Access Level: Write

        https://docs.aws.amazon.com/AutoScaling/latest/APIReference/API_SetDesiredCapacity.html

        :stability: experimental
        '''
        return typing.cast("Autoscaling", jsii.invoke(self, "toSetDesiredCapacity", []))

    @jsii.member(jsii_name="toSetInstanceHealth")
    def to_set_instance_health(self) -> "Autoscaling":
        '''(experimental) Grants permission to set the health status of the specified instance.

        Access Level: Write

        https://docs.aws.amazon.com/AutoScaling/latest/APIReference/API_SetInstanceHealth.html

        :stability: experimental
        '''
        return typing.cast("Autoscaling", jsii.invoke(self, "toSetInstanceHealth", []))

    @jsii.member(jsii_name="toSetInstanceProtection")
    def to_set_instance_protection(self) -> "Autoscaling":
        '''(experimental) Grants permission to update the instance protection settings of the specified instances.

        Access Level: Write

        https://docs.aws.amazon.com/AutoScaling/latest/APIReference/API_SetInstanceProtection.html

        :stability: experimental
        '''
        return typing.cast("Autoscaling", jsii.invoke(self, "toSetInstanceProtection", []))

    @jsii.member(jsii_name="toStartInstanceRefresh")
    def to_start_instance_refresh(self) -> "Autoscaling":
        '''(experimental) Grants permission to start a new instance refresh operation.

        Access Level: Write

        https://docs.aws.amazon.com/AutoScaling/latest/APIReference/API_StartInstanceRefresh.html

        :stability: experimental
        '''
        return typing.cast("Autoscaling", jsii.invoke(self, "toStartInstanceRefresh", []))

    @jsii.member(jsii_name="toSuspendProcesses")
    def to_suspend_processes(self) -> "Autoscaling":
        '''(experimental) Grants permission to suspend the specified Auto Scaling processes, or all processes, for the specified Auto Scaling group.

        Access Level: Write

        https://docs.aws.amazon.com/AutoScaling/latest/APIReference/API_SuspendProcesses.html

        :stability: experimental
        '''
        return typing.cast("Autoscaling", jsii.invoke(self, "toSuspendProcesses", []))

    @jsii.member(jsii_name="toTerminateInstanceInAutoScalingGroup")
    def to_terminate_instance_in_auto_scaling_group(self) -> "Autoscaling":
        '''(experimental) Grants permission to terminate the specified instance and optionally adjust the desired group size.

        Access Level: Write

        https://docs.aws.amazon.com/AutoScaling/latest/APIReference/API_TerminateInstanceInAutoScalingGroup.html

        :stability: experimental
        '''
        return typing.cast("Autoscaling", jsii.invoke(self, "toTerminateInstanceInAutoScalingGroup", []))

    @jsii.member(jsii_name="toUpdateAutoScalingGroup")
    def to_update_auto_scaling_group(self) -> "Autoscaling":
        '''(experimental) Grants permission to update the configuration for the specified Auto Scaling group.

        Access Level: Write

        Possible conditions:

        - .ifInstanceTypes()
        - .ifLaunchConfigurationName()
        - .ifLaunchTemplateVersionSpecified()
        - .ifMaxSize()
        - .ifMinSize()
        - .ifVPCZoneIdentifiers()

        Dependent actions:

        - iam:PassRole

        https://docs.aws.amazon.com/AutoScaling/latest/APIReference/API_UpdateAutoScalingGroup.html

        :stability: experimental
        '''
        return typing.cast("Autoscaling", jsii.invoke(self, "toUpdateAutoScalingGroup", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c0f3349e591669852418d1ddf9d835b333a85570688318b42700fcd28212b6f9)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__afc7e6f92e2fb55e2c3eab7937a6134f877ed9a1e17c525d2af1d3207ccf74af)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class AutoscalingPlans(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.AutoscalingPlans",
):
    '''(experimental) Statement provider for service `autoscaling-plans <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsautoscaling.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `autoscaling-plans <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsautoscaling.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="toCreateScalingPlan")
    def to_create_scaling_plan(self) -> "AutoscalingPlans":
        '''(experimental) Creates a scaling plan.

        Access Level: Write

        https://docs.aws.amazon.com/autoscaling/plans/APIReference/API_CreateScalingPlan.html

        :stability: experimental
        '''
        return typing.cast("AutoscalingPlans", jsii.invoke(self, "toCreateScalingPlan", []))

    @jsii.member(jsii_name="toDeleteScalingPlan")
    def to_delete_scaling_plan(self) -> "AutoscalingPlans":
        '''(experimental) Deletes the specified scaling plan.

        Access Level: Write

        https://docs.aws.amazon.com/autoscaling/plans/APIReference/API_DeleteScalingPlan.html

        :stability: experimental
        '''
        return typing.cast("AutoscalingPlans", jsii.invoke(self, "toDeleteScalingPlan", []))

    @jsii.member(jsii_name="toDescribeScalingPlanResources")
    def to_describe_scaling_plan_resources(self) -> "AutoscalingPlans":
        '''(experimental) Describes the scalable resources in the specified scaling plan.

        Access Level: Read

        https://docs.aws.amazon.com/autoscaling/plans/APIReference/API_DescribeScalingPlanResources.html

        :stability: experimental
        '''
        return typing.cast("AutoscalingPlans", jsii.invoke(self, "toDescribeScalingPlanResources", []))

    @jsii.member(jsii_name="toDescribeScalingPlans")
    def to_describe_scaling_plans(self) -> "AutoscalingPlans":
        '''(experimental) Describes the specified scaling plans or all of your scaling plans.

        Access Level: Read

        https://docs.aws.amazon.com/autoscaling/plans/APIReference/API_DescribeScalingPlans.html

        :stability: experimental
        '''
        return typing.cast("AutoscalingPlans", jsii.invoke(self, "toDescribeScalingPlans", []))

    @jsii.member(jsii_name="toGetScalingPlanResourceForecastData")
    def to_get_scaling_plan_resource_forecast_data(self) -> "AutoscalingPlans":
        '''(experimental) Retrieves the forecast data for a scalable resource.

        Access Level: Read

        https://docs.aws.amazon.com/autoscaling/plans/APIReference/API_GetScalingPlanResourceForecastData.html

        :stability: experimental
        '''
        return typing.cast("AutoscalingPlans", jsii.invoke(self, "toGetScalingPlanResourceForecastData", []))

    @jsii.member(jsii_name="toUpdateScalingPlan")
    def to_update_scaling_plan(self) -> "AutoscalingPlans":
        '''(experimental) Updates a scaling plan.

        Access Level: Write

        https://docs.aws.amazon.com/autoscaling/plans/APIReference/API_UpdateScalingPlan.html

        :stability: experimental
        '''
        return typing.cast("AutoscalingPlans", jsii.invoke(self, "toUpdateScalingPlan", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ef65902f4d4bd93f1fff15c2f6d16aea8f3e702c7a117208d62c0f0f003282a8)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__322995818d414e04b92a8a81de6cf03cd2ec04ca3c0bbecabadc2b9bb5ca2c15)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class AwsCloudControlApi(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.AwsCloudControlApi",
):
    '''(experimental) Statement provider for service `aws-cloud-control-api <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awscloudcontrolapi.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `aws-cloud-control-api <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awscloudcontrolapi.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="toCancelResourceRequest")
    def to_cancel_resource_request(self) -> "AwsCloudControlApi":
        '''(experimental) Grants permission to cancel resource requests in your account.

        Access Level: Write

        https://docs.aws.amazon.com/cloudcontrolapi/latest/APIReference/API_CancelResourceRequest.html

        :stability: experimental
        '''
        return typing.cast("AwsCloudControlApi", jsii.invoke(self, "toCancelResourceRequest", []))

    @jsii.member(jsii_name="toCreateResource")
    def to_create_resource(self) -> "AwsCloudControlApi":
        '''(experimental) Grants permission to create resources in your account.

        Access Level: Write

        https://docs.aws.amazon.com/cloudcontrolapi/latest/APIReference/API_CreateResource.html

        :stability: experimental
        '''
        return typing.cast("AwsCloudControlApi", jsii.invoke(self, "toCreateResource", []))

    @jsii.member(jsii_name="toDeleteResource")
    def to_delete_resource(self) -> "AwsCloudControlApi":
        '''(experimental) Grants permission to delete resources in your account.

        Access Level: Write

        https://docs.aws.amazon.com/cloudcontrolapi/latest/APIReference/API_DeleteResource.html

        :stability: experimental
        '''
        return typing.cast("AwsCloudControlApi", jsii.invoke(self, "toDeleteResource", []))

    @jsii.member(jsii_name="toGetResource")
    def to_get_resource(self) -> "AwsCloudControlApi":
        '''(experimental) Grants permission to get resources in your account.

        Access Level: Read

        https://docs.aws.amazon.com/cloudcontrolapi/latest/APIReference/API_GetResource.html

        :stability: experimental
        '''
        return typing.cast("AwsCloudControlApi", jsii.invoke(self, "toGetResource", []))

    @jsii.member(jsii_name="toGetResourceRequestStatus")
    def to_get_resource_request_status(self) -> "AwsCloudControlApi":
        '''(experimental) Grants permission to get resource requests in your account.

        Access Level: Read

        https://docs.aws.amazon.com/cloudcontrolapi/latest/APIReference/API_GetResourceRequestStatus.html

        :stability: experimental
        '''
        return typing.cast("AwsCloudControlApi", jsii.invoke(self, "toGetResourceRequestStatus", []))

    @jsii.member(jsii_name="toListResourceRequests")
    def to_list_resource_requests(self) -> "AwsCloudControlApi":
        '''(experimental) Grants permission to list resource requests in your account.

        Access Level: Read

        https://docs.aws.amazon.com/cloudcontrolapi/latest/APIReference/API_ListResourceRequests.html

        :stability: experimental
        '''
        return typing.cast("AwsCloudControlApi", jsii.invoke(self, "toListResourceRequests", []))

    @jsii.member(jsii_name="toListResources")
    def to_list_resources(self) -> "AwsCloudControlApi":
        '''(experimental) Grants permission to list resources in your account.

        Access Level: Read

        https://docs.aws.amazon.com/cloudcontrolapi/latest/APIReference/API_ListResources.html

        :stability: experimental
        '''
        return typing.cast("AwsCloudControlApi", jsii.invoke(self, "toListResources", []))

    @jsii.member(jsii_name="toUpdateResource")
    def to_update_resource(self) -> "AwsCloudControlApi":
        '''(experimental) Grants permission to update resources in your account.

        Access Level: Write

        https://docs.aws.amazon.com/cloudcontrolapi/latest/APIReference/API_UpdateResource.html

        :stability: experimental
        '''
        return typing.cast("AwsCloudControlApi", jsii.invoke(self, "toUpdateResource", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5d6eb67c470fea38431bc53c9b199bf9a73eb7c2e29558dd39743284b68626b6)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8f7cb695503a68b699b56424a90a8dad40e84491f699f0c0aba5028fad087d99)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class AwsMarketplace(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.AwsMarketplace",
):
    '''(experimental) Statement provider for service `aws-marketplace <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsmarketplace.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `aws-marketplace <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsmarketplace.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="ifAgreementType")
    def if_agreement_type(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "AwsMarketplace":
        '''(experimental) Filters access by the type of the agreement.

        https://docs.aws.amazon.com/marketplace/latest/buyerguide/buyer-iam-users-groups-policies.html

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d7aa35b8a3bf062e514c2e76ff78c13360fb7213b8871ef9f0d5b5a2bea9bda8)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("AwsMarketplace", jsii.invoke(self, "ifAgreementType", [value, operator]))

    @jsii.member(jsii_name="ifPartyType")
    def if_party_type(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "AwsMarketplace":
        '''(experimental) Filters access by the party type of the agreement.

        https://docs.aws.amazon.com/marketplace/latest/buyerguide/buyer-iam-users-groups-policies.html

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__43218fe8506410bd23413804f2437ed3a6a10f33191e5359db1d0a3525629b6d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("AwsMarketplace", jsii.invoke(self, "ifPartyType", [value, operator]))

    @jsii.member(jsii_name="ifProductId")
    def if_product_id(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "AwsMarketplace":
        '''(experimental) Filters access by product id for AWS Marketplace RedHat OpenShift products in the RedHat console.

        Note: This condition key only applies to the RedHat console, and using it will not restrict access to products in AWS Marketplace

        https://docs.aws.amazon.com/marketplace/latest/buyerguide/buyer-iam-users-groups-policies.html

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f0635a779e59aca9ef2249f69488d6c4b2b32aa185206b1cc668ac5d01e6c682)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("AwsMarketplace", jsii.invoke(self, "ifProductId", [value, operator]))

    @jsii.member(jsii_name="toAcceptAgreementApprovalRequest")
    def to_accept_agreement_approval_request(self) -> "AwsMarketplace":
        '''(experimental) Grants permission to users to approve an incoming subscription request (for providers who provide products that require subscription verification).

        Access Level: Write

        https://docs.aws.amazon.com/marketplace/latest/buyerguide/buyer-iam-users-groups-policies.html

        :stability: experimental
        '''
        return typing.cast("AwsMarketplace", jsii.invoke(self, "toAcceptAgreementApprovalRequest", []))

    @jsii.member(jsii_name="toAcceptAgreementRequest")
    def to_accept_agreement_request(self) -> "AwsMarketplace":
        '''(experimental) Grants permission to users to accept their agreement requests. Note that this action is not applicable to Marketplace purchases.

        Access Level: Write

        https://docs.aws.amazon.com/marketplace/latest/buyerguide/buyer-iam-users-groups-policies.html

        :stability: experimental
        '''
        return typing.cast("AwsMarketplace", jsii.invoke(self, "toAcceptAgreementRequest", []))

    @jsii.member(jsii_name="toCancelAgreement")
    def to_cancel_agreement(self) -> "AwsMarketplace":
        '''(experimental) Grants permission to users to cancel their agreements. Note that this action is not applicable to Marketplace purchases.

        Access Level: Write

        https://docs.aws.amazon.com/marketplace/latest/buyerguide/buyer-iam-users-groups-policies.html

        :stability: experimental
        '''
        return typing.cast("AwsMarketplace", jsii.invoke(self, "toCancelAgreement", []))

    @jsii.member(jsii_name="toCancelAgreementRequest")
    def to_cancel_agreement_request(self) -> "AwsMarketplace":
        '''(experimental) Grants permission to users to cancel pending subscription requests for products that require subscription verification.

        Access Level: Write

        https://docs.aws.amazon.com/marketplace/latest/buyerguide/buyer-iam-users-groups-policies.html

        :stability: experimental
        '''
        return typing.cast("AwsMarketplace", jsii.invoke(self, "toCancelAgreementRequest", []))

    @jsii.member(jsii_name="toCreateAgreementRequest")
    def to_create_agreement_request(self) -> "AwsMarketplace":
        '''(experimental) Grants permission to users to create an agreement request. Note that this action is not applicable to Marketplace purchases.

        Access Level: Write

        https://docs.aws.amazon.com/marketplace/latest/buyerguide/buyer-iam-users-groups-policies.html

        :stability: experimental
        '''
        return typing.cast("AwsMarketplace", jsii.invoke(self, "toCreateAgreementRequest", []))

    @jsii.member(jsii_name="toDescribeAgreement")
    def to_describe_agreement(self) -> "AwsMarketplace":
        '''(experimental) Grants permission to users to describe the metadata about the agreement.

        Access Level: Read

        https://docs.aws.amazon.com/marketplace/latest/buyerguide/buyer-iam-users-groups-policies.html

        :stability: experimental
        '''
        return typing.cast("AwsMarketplace", jsii.invoke(self, "toDescribeAgreement", []))

    @jsii.member(jsii_name="toGetAgreementApprovalRequest")
    def to_get_agreement_approval_request(self) -> "AwsMarketplace":
        '''(experimental) Grants permission to users to view the details of their incoming subscription requests (for providers who provide products that require subscription verification).

        Access Level: Read

        https://docs.aws.amazon.com/marketplace/latest/buyerguide/buyer-iam-users-groups-policies.html

        :stability: experimental
        '''
        return typing.cast("AwsMarketplace", jsii.invoke(self, "toGetAgreementApprovalRequest", []))

    @jsii.member(jsii_name="toGetAgreementRequest")
    def to_get_agreement_request(self) -> "AwsMarketplace":
        '''(experimental) Grants permission to users to view the details of their subscription requests for data products that require subscription verification.

        Access Level: Read

        https://docs.aws.amazon.com/marketplace/latest/buyerguide/buyer-iam-users-groups-policies.html

        :stability: experimental
        '''
        return typing.cast("AwsMarketplace", jsii.invoke(self, "toGetAgreementRequest", []))

    @jsii.member(jsii_name="toGetAgreementTerms")
    def to_get_agreement_terms(self) -> "AwsMarketplace":
        '''(experimental) Grants permission to users to get a list of terms for an agreement.

        Access Level: List

        https://docs.aws.amazon.com/marketplace/latest/buyerguide/buyer-iam-users-groups-policies.html

        :stability: experimental
        '''
        return typing.cast("AwsMarketplace", jsii.invoke(self, "toGetAgreementTerms", []))

    @jsii.member(jsii_name="toListAgreementApprovalRequests")
    def to_list_agreement_approval_requests(self) -> "AwsMarketplace":
        '''(experimental) Grants permission to users to list their incoming subscription requests (for providers who provide products that require subscription verification).

        Access Level: List

        https://docs.aws.amazon.com/marketplace/latest/buyerguide/buyer-iam-users-groups-policies.html

        :stability: experimental
        '''
        return typing.cast("AwsMarketplace", jsii.invoke(self, "toListAgreementApprovalRequests", []))

    @jsii.member(jsii_name="toListAgreementRequests")
    def to_list_agreement_requests(self) -> "AwsMarketplace":
        '''(experimental) Grants permission to users to list their subscription requests for products that require subscription verification.

        Access Level: List

        https://docs.aws.amazon.com/marketplace/latest/buyerguide/buyer-iam-users-groups-policies.html

        :stability: experimental
        '''
        return typing.cast("AwsMarketplace", jsii.invoke(self, "toListAgreementRequests", []))

    @jsii.member(jsii_name="toRejectAgreementApprovalRequest")
    def to_reject_agreement_approval_request(self) -> "AwsMarketplace":
        '''(experimental) Grants permission to users to decline an incoming subscription requests (for providers who provide products that require subscription verification).

        Access Level: Write

        https://docs.aws.amazon.com/marketplace/latest/buyerguide/buyer-iam-users-groups-policies.html

        :stability: experimental
        '''
        return typing.cast("AwsMarketplace", jsii.invoke(self, "toRejectAgreementApprovalRequest", []))

    @jsii.member(jsii_name="toSearchAgreements")
    def to_search_agreements(self) -> "AwsMarketplace":
        '''(experimental) Grants permission to users to search their agreements.

        Access Level: List

        https://docs.aws.amazon.com/marketplace/latest/buyerguide/buyer-iam-users-groups-policies.html

        :stability: experimental
        '''
        return typing.cast("AwsMarketplace", jsii.invoke(self, "toSearchAgreements", []))

    @jsii.member(jsii_name="toSubscribe")
    def to_subscribe(self) -> "AwsMarketplace":
        '''(experimental) Grants permission to users to subscribe to AWS Marketplace products.

        Includes the ability to send a subscription request for products that require subscription verification. Includes the ability to enable auto-renewal for an existing subscription

        Access Level: Write

        https://docs.aws.amazon.com/marketplace/latest/buyerguide/buyer-iam-users-groups-policies.html

        :stability: experimental
        '''
        return typing.cast("AwsMarketplace", jsii.invoke(self, "toSubscribe", []))

    @jsii.member(jsii_name="toUnsubscribe")
    def to_unsubscribe(self) -> "AwsMarketplace":
        '''(experimental) Grants permission to users to remove subscriptions to AWS Marketplace products.

        Includes the ability to disable auto-renewal for an existing subscription

        Access Level: Write

        https://docs.aws.amazon.com/marketplace/latest/buyerguide/buyer-iam-users-groups-policies.html

        :stability: experimental
        '''
        return typing.cast("AwsMarketplace", jsii.invoke(self, "toUnsubscribe", []))

    @jsii.member(jsii_name="toUpdateAgreementApprovalRequest")
    def to_update_agreement_approval_request(self) -> "AwsMarketplace":
        '''(experimental) Grants permission to users to make changes to an incoming subscription request, including the ability to delete the prospective subscriber's information (for providers who provide products that require subscription verification).

        Access Level: Write

        https://docs.aws.amazon.com/marketplace/latest/buyerguide/buyer-iam-users-groups-policies.html

        :stability: experimental
        '''
        return typing.cast("AwsMarketplace", jsii.invoke(self, "toUpdateAgreementApprovalRequest", []))

    @jsii.member(jsii_name="toViewSubscriptions")
    def to_view_subscriptions(self) -> "AwsMarketplace":
        '''(experimental) Grants permission to users to see their account's subscriptions.

        Access Level: List

        https://docs.aws.amazon.com/marketplace/latest/buyerguide/buyer-iam-users-groups-policies.html

        :stability: experimental
        '''
        return typing.cast("AwsMarketplace", jsii.invoke(self, "toViewSubscriptions", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6898b15fcd3319f9f27fc06d2f9a3516d7d8d428c0f92272849a9a13fd1f4015)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8e730ffe403f5a3232e4352de625502d93f64d1311b2d3eaef2fe6f9347ffd76)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class AwsMarketplaceCatalog(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.AwsMarketplaceCatalog",
):
    '''(experimental) Statement provider for service `aws-marketplace-catalog <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsmarketplacecatalog.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `aws-marketplace-catalog <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsmarketplacecatalog.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="ifCatalogChangeType")
    def if_catalog_change_type(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "AwsMarketplaceCatalog":
        '''(experimental) Filters access by the change type in the StartChangeSet request.

        https://docs.aws.amazon.com/marketplace-catalog/latest/api-reference/api-access-control.html

        Applies to actions:

        - .toStartChangeSet()

        Applies to resource types:

        - Entity
        - ChangeSet

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7a5d7f36d2dd7aaa8b0801b900ba26ba43e269d2cd79dbcfe08b1e955719bfd6)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("AwsMarketplaceCatalog", jsii.invoke(self, "ifCatalogChangeType", [value, operator]))

    @jsii.member(jsii_name="onChangeSet")
    def on_change_set(
        self,
        catalog: builtins.str,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "AwsMarketplaceCatalog":
        '''(experimental) Adds a resource of type ChangeSet to the statement.

        https://docs.aws.amazon.com/marketplace-catalog/latest/api-reference/API_StartChangeSet.html#API_StartChangeSet_ResponseSyntax

        :param catalog: - Identifier for the catalog.
        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag() - .ifCatalogChangeType()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c049b68dd8701ed259e2996342c152088fbc278d7b6eccb56613abc1855a1069)
            check_type(argname="argument catalog", value=catalog, expected_type=type_hints["catalog"])
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("AwsMarketplaceCatalog", jsii.invoke(self, "onChangeSet", [catalog, resource_id, account, region, partition]))

    @jsii.member(jsii_name="onEntity")
    def on_entity(
        self,
        catalog: builtins.str,
        entity_type: builtins.str,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "AwsMarketplaceCatalog":
        '''(experimental) Adds a resource of type Entity to the statement.

        https://docs.aws.amazon.com/marketplace-catalog/latest/api-reference/API_DescribeEntity.html#API_DescribeEntity_ResponseSyntax

        :param catalog: - Identifier for the catalog.
        :param entity_type: - Identifier for the entityType.
        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag() - .ifCatalogChangeType()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4938a65cc69afebb9a657919cfa8ab0672116bc7da54435a113b15b924381394)
            check_type(argname="argument catalog", value=catalog, expected_type=type_hints["catalog"])
            check_type(argname="argument entity_type", value=entity_type, expected_type=type_hints["entity_type"])
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("AwsMarketplaceCatalog", jsii.invoke(self, "onEntity", [catalog, entity_type, resource_id, account, region, partition]))

    @jsii.member(jsii_name="toCancelChangeSet")
    def to_cancel_change_set(self) -> "AwsMarketplaceCatalog":
        '''(experimental) Grants permission to cancel a running change set.

        Access Level: Write

        https://docs.aws.amazon.com/marketplace-catalog/latest/api-reference/API_CancelChangeSet.html

        :stability: experimental
        '''
        return typing.cast("AwsMarketplaceCatalog", jsii.invoke(self, "toCancelChangeSet", []))

    @jsii.member(jsii_name="toCompleteTask")
    def to_complete_task(self) -> "AwsMarketplaceCatalog":
        '''(experimental) Grants permission to complete an existing task and submit the content to the associated change.

        Access Level: Write

        https://docs.aws.amazon.com/marketplace-catalog/latest/api-reference/

        :stability: experimental
        '''
        return typing.cast("AwsMarketplaceCatalog", jsii.invoke(self, "toCompleteTask", []))

    @jsii.member(jsii_name="toDescribeChangeSet")
    def to_describe_change_set(self) -> "AwsMarketplaceCatalog":
        '''(experimental) Grants permission to return the details of an existing change set.

        Access Level: Read

        https://docs.aws.amazon.com/marketplace-catalog/latest/api-reference/API_DescribeChangeSet.html

        :stability: experimental
        '''
        return typing.cast("AwsMarketplaceCatalog", jsii.invoke(self, "toDescribeChangeSet", []))

    @jsii.member(jsii_name="toDescribeEntity")
    def to_describe_entity(self) -> "AwsMarketplaceCatalog":
        '''(experimental) Grants permission to return the details of an existing entity.

        Access Level: Read

        https://docs.aws.amazon.com/marketplace-catalog/latest/api-reference/API_DescribeEntity.html

        :stability: experimental
        '''
        return typing.cast("AwsMarketplaceCatalog", jsii.invoke(self, "toDescribeEntity", []))

    @jsii.member(jsii_name="toDescribeTask")
    def to_describe_task(self) -> "AwsMarketplaceCatalog":
        '''(experimental) Grants permission to return the details of an existing task.

        Access Level: Read

        https://docs.aws.amazon.com/marketplace-catalog/latest/api-reference/

        :stability: experimental
        '''
        return typing.cast("AwsMarketplaceCatalog", jsii.invoke(self, "toDescribeTask", []))

    @jsii.member(jsii_name="toListChangeSets")
    def to_list_change_sets(self) -> "AwsMarketplaceCatalog":
        '''(experimental) Grants permission to list existing change sets.

        Access Level: List

        https://docs.aws.amazon.com/marketplace-catalog/latest/api-reference/API_ListChangeSets.html

        :stability: experimental
        '''
        return typing.cast("AwsMarketplaceCatalog", jsii.invoke(self, "toListChangeSets", []))

    @jsii.member(jsii_name="toListEntities")
    def to_list_entities(self) -> "AwsMarketplaceCatalog":
        '''(experimental) Grants permission to list existing entities.

        Access Level: List

        https://docs.aws.amazon.com/marketplace-catalog/latest/api-reference/API_ListEntities.html

        :stability: experimental
        '''
        return typing.cast("AwsMarketplaceCatalog", jsii.invoke(self, "toListEntities", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "AwsMarketplaceCatalog":
        '''(experimental) Grants permission to list tags on an existing entity or a change set.

        Access Level: Read

        https://docs.aws.amazon.com/marketplace-catalog/latest/api-reference/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("AwsMarketplaceCatalog", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toListTasks")
    def to_list_tasks(self) -> "AwsMarketplaceCatalog":
        '''(experimental) Grants permission to list existing tasks.

        Access Level: List

        https://docs.aws.amazon.com/marketplace-catalog/latest/api-reference/

        :stability: experimental
        '''
        return typing.cast("AwsMarketplaceCatalog", jsii.invoke(self, "toListTasks", []))

    @jsii.member(jsii_name="toStartChangeSet")
    def to_start_change_set(self) -> "AwsMarketplaceCatalog":
        '''(experimental) Grants permission to request a new change set (Note: resource-level permissions for this action and condition context keys for this action are only supported when used with Catalog API and are not supported when used with AWS Marketplace Management Portal).

        Access Level: Write

        Possible conditions:

        - .ifCatalogChangeType()
        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/marketplace-catalog/latest/api-reference/API_StartChangeSet.html

        :stability: experimental
        '''
        return typing.cast("AwsMarketplaceCatalog", jsii.invoke(self, "toStartChangeSet", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "AwsMarketplaceCatalog":
        '''(experimental) Grants permission to tag an existing entity or a change set.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/marketplace-catalog/latest/api-reference/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("AwsMarketplaceCatalog", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "AwsMarketplaceCatalog":
        '''(experimental) Grants permission to untag an existing entity or a change set.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/marketplace-catalog/latest/api-reference/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("AwsMarketplaceCatalog", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateTask")
    def to_update_task(self) -> "AwsMarketplaceCatalog":
        '''(experimental) Grants permission to update the contents of an existing task.

        Access Level: Write

        https://docs.aws.amazon.com/marketplace-catalog/latest/api-reference/

        :stability: experimental
        '''
        return typing.cast("AwsMarketplaceCatalog", jsii.invoke(self, "toUpdateTask", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7356e574fdf912254d7e55a34a7727513964db4ee5aa67d677cdd7917a620375)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__17aef19bb4324580e8bd58caebdab9471cbc30fd0590ad20b34ffff6b89851d2)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class AwsMarketplaceEntitlementService(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.AwsMarketplaceEntitlementService",
):
    '''(experimental) Statement provider for service `aws-marketplace-entitlement-service <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsmarketplaceentitlementservice.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `aws-marketplace-entitlement-service <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsmarketplaceentitlementservice.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="toGetEntitlements")
    def to_get_entitlements(self) -> "AwsMarketplaceEntitlementService":
        '''(experimental) Retrieves entitlement values for a given product. The results can be filtered based on customer identifier or product dimensions.

        Access Level: Read

        :stability: experimental
        '''
        return typing.cast("AwsMarketplaceEntitlementService", jsii.invoke(self, "toGetEntitlements", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__22d24ea2001c9afd33e387b16ad775fd94d8835caf2c5dac5e1c2e6c661332c9)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__906a46617ab3894109235c86d604feec815a9a216ae370e285f94cebe2a12b7f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class AwsMarketplaceImageBuildingService(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.AwsMarketplaceImageBuildingService",
):
    '''(experimental) Statement provider for service `aws-marketplace-image-building-service <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsmarketplaceimagebuildingservice.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `aws-marketplace-image-building-service <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsmarketplaceimagebuildingservice.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="toDescribeBuilds")
    def to_describe_builds(self) -> "AwsMarketplaceImageBuildingService":
        '''(experimental) Describes Image Builds identified by a build Id.

        Access Level: Read

        https://docs.aws.amazon.com/marketplace/latest/buyerguide/api-reference.html

        :stability: experimental
        '''
        return typing.cast("AwsMarketplaceImageBuildingService", jsii.invoke(self, "toDescribeBuilds", []))

    @jsii.member(jsii_name="toListBuilds")
    def to_list_builds(self) -> "AwsMarketplaceImageBuildingService":
        '''(experimental) Lists Image Builds.

        Access Level: Read

        https://docs.aws.amazon.com/marketplace/latest/buyerguide/api-reference.html

        :stability: experimental
        '''
        return typing.cast("AwsMarketplaceImageBuildingService", jsii.invoke(self, "toListBuilds", []))

    @jsii.member(jsii_name="toStartBuild")
    def to_start_build(self) -> "AwsMarketplaceImageBuildingService":
        '''(experimental) Starts an Image Build.

        Access Level: Write

        https://docs.aws.amazon.com/marketplace/latest/buyerguide/api-reference.html

        :stability: experimental
        '''
        return typing.cast("AwsMarketplaceImageBuildingService", jsii.invoke(self, "toStartBuild", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__71452fa84da4e6cfdd761ffdc45ed662fa16145c42ff039bce945033bb7f019d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__eefaee420a933ef35f82a0ead31d13f4a8cb23b1f974222d8144e951eaefb5c5)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class AwsMarketplaceManagement(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.AwsMarketplaceManagement",
):
    '''(experimental) Statement provider for service `aws-marketplace-management <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsmarketplacemanagementportal.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `aws-marketplace-management <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsmarketplacemanagementportal.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="toUploadFiles")
    def to_upload_files(self) -> "AwsMarketplaceManagement":
        '''(experimental) Allows access to the File Upload page inside the AWS Marketplace Management Portal.

        Access Level: Write

        https://docs.aws.amazon.com/marketplace/latest/userguide/detailed-management-portal-permissions.html#seller-ammp-permissions

        :stability: experimental
        '''
        return typing.cast("AwsMarketplaceManagement", jsii.invoke(self, "toUploadFiles", []))

    @jsii.member(jsii_name="toViewMarketing")
    def to_view_marketing(self) -> "AwsMarketplaceManagement":
        '''(experimental) Allows access to the Marketing page inside the AWS Marketplace Management Portal.

        Access Level: List

        https://docs.aws.amazon.com/marketplace/latest/userguide/detailed-management-portal-permissions.html#seller-ammp-permissions

        :stability: experimental
        '''
        return typing.cast("AwsMarketplaceManagement", jsii.invoke(self, "toViewMarketing", []))

    @jsii.member(jsii_name="toViewReports")
    def to_view_reports(self) -> "AwsMarketplaceManagement":
        '''(experimental) Allows access to the Reports page inside the AWS Marketplace Management Portal.

        Access Level: List

        https://docs.aws.amazon.com/marketplace/latest/userguide/detailed-management-portal-permissions.html#seller-ammp-permissions

        :stability: experimental
        '''
        return typing.cast("AwsMarketplaceManagement", jsii.invoke(self, "toViewReports", []))

    @jsii.member(jsii_name="toViewSettings")
    def to_view_settings(self) -> "AwsMarketplaceManagement":
        '''(experimental) Allows access to the Settings page inside the AWS Marketplace Management Portal.

        Access Level: List

        https://docs.aws.amazon.com/marketplace/latest/userguide/detailed-management-portal-permissions.html#seller-ammp-permissions

        :stability: experimental
        '''
        return typing.cast("AwsMarketplaceManagement", jsii.invoke(self, "toViewSettings", []))

    @jsii.member(jsii_name="toViewSupport")
    def to_view_support(self) -> "AwsMarketplaceManagement":
        '''(experimental) Allows access to the Customer Support Eligibility page inside the AWS Marketplace Management Portal.

        Access Level: List

        https://docs.aws.amazon.com/marketplace/latest/userguide/detailed-management-portal-permissions.html#seller-ammp-permissions

        :stability: experimental
        '''
        return typing.cast("AwsMarketplaceManagement", jsii.invoke(self, "toViewSupport", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fb6ce0a083a9c892675dc528a9a6681cff436c4fecfa147b0854ffac801b52eb)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9d0ee23eb56539bbca88568d40b59676545ad1742f5e7ce9d6f6ab6406a397e4)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class AwsMarketplaceMeteringService(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.AwsMarketplaceMeteringService",
):
    '''(experimental) Statement provider for service `aws-marketplace-metering-service <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsmarketplacemeteringservice.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `aws-marketplace-metering-service <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsmarketplacemeteringservice.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="toBatchMeterUsage")
    def to_batch_meter_usage(self) -> "AwsMarketplaceMeteringService":
        '''(experimental) Grants permission to post metering records for a set of customers for SaaS applications.

        Access Level: Write

        https://docs.aws.amazon.com/marketplacemetering/latest/APIReference/API_BatchMeterUsage.html

        :stability: experimental
        '''
        return typing.cast("AwsMarketplaceMeteringService", jsii.invoke(self, "toBatchMeterUsage", []))

    @jsii.member(jsii_name="toMeterUsage")
    def to_meter_usage(self) -> "AwsMarketplaceMeteringService":
        '''(experimental) Grants permission to emit metering records.

        Access Level: Write

        https://docs.aws.amazon.com/marketplacemetering/latest/APIReference/API_MeterUsage.html

        :stability: experimental
        '''
        return typing.cast("AwsMarketplaceMeteringService", jsii.invoke(self, "toMeterUsage", []))

    @jsii.member(jsii_name="toRegisterUsage")
    def to_register_usage(self) -> "AwsMarketplaceMeteringService":
        '''(experimental) Grants permission to to verify that the customer running your paid software is subscribed to your product on AWS Marketplace, enabling you to guard against unauthorized use.

        Meters software use per ECS task, per hour, with usage prorated to the second

        Access Level: Write

        https://docs.aws.amazon.com/marketplacemetering/latest/APIReference/API_RegisterUsage.html

        :stability: experimental
        '''
        return typing.cast("AwsMarketplaceMeteringService", jsii.invoke(self, "toRegisterUsage", []))

    @jsii.member(jsii_name="toResolveCustomer")
    def to_resolve_customer(self) -> "AwsMarketplaceMeteringService":
        '''(experimental) Grants permission to resolve a registration token to obtain a CustomerIdentifier and product code.

        Access Level: Write

        https://docs.aws.amazon.com/marketplacemetering/latest/APIReference/API_ResolveCustomer.html

        :stability: experimental
        '''
        return typing.cast("AwsMarketplaceMeteringService", jsii.invoke(self, "toResolveCustomer", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__99e481844360e89723553ad7b3d61cd7e01bbd0e404b1808fa2ce6ccc69c477e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__665d9c47d349e0a4707d9c754b51473d51f17c0c36e0a333062858bd3d9a7482)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class AwsMarketplacePrivate(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.AwsMarketplacePrivate",
):
    '''(experimental) Statement provider for service `aws-marketplace-private <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsmarketplaceprivatemarketplace.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `aws-marketplace-private <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsmarketplaceprivatemarketplace.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="toAssociateProductsWithPrivateMarketplace")
    def to_associate_products_with_private_marketplace(self) -> "AwsMarketplacePrivate":
        '''(experimental) Grants permission to approve a request for a product to be associated with the Private Marketplace.

        This action can be performed by any account in an AWS Organization, provided the user has permissions to do so, and the Organization's Service Control Policies allow it

        Access Level: Write

        https://docs.aws.amazon.com/marketplace/latest/buyerguide/private-marketplace.html

        :stability: experimental
        '''
        return typing.cast("AwsMarketplacePrivate", jsii.invoke(self, "toAssociateProductsWithPrivateMarketplace", []))

    @jsii.member(jsii_name="toCreatePrivateMarketplaceRequests")
    def to_create_private_marketplace_requests(self) -> "AwsMarketplacePrivate":
        '''(experimental) Grants permission to create a new request for a product or products to be associated with the Private Marketplace.

        This action can be performed by any account in an in an AWS Organization, provided the user has permissions to do so, and the Organization's Service Control Policies allow it

        Access Level: Write

        https://docs.aws.amazon.com/marketplace/latest/buyerguide/private-marketplace.html

        :stability: experimental
        '''
        return typing.cast("AwsMarketplacePrivate", jsii.invoke(self, "toCreatePrivateMarketplaceRequests", []))

    @jsii.member(jsii_name="toDescribePrivateMarketplaceRequests")
    def to_describe_private_marketplace_requests(self) -> "AwsMarketplacePrivate":
        '''(experimental) Grants permission to describe requests and associated products in the Private Marketplace.

        This action can be performed by any account in an AWS Organization, provided the user has permissions to do so, and the Organization's Service Control Policies allow it

        Access Level: List

        https://docs.aws.amazon.com/marketplace/latest/buyerguide/private-marketplace.html

        :stability: experimental
        '''
        return typing.cast("AwsMarketplacePrivate", jsii.invoke(self, "toDescribePrivateMarketplaceRequests", []))

    @jsii.member(jsii_name="toDisassociateProductsFromPrivateMarketplace")
    def to_disassociate_products_from_private_marketplace(
        self,
    ) -> "AwsMarketplacePrivate":
        '''(experimental) Grants permission to decline a request for a product to be associated with the Private Marketplace.

        This action can be performed by any account in an AWS Organization, provided the user has permissions to do so, and the Organization's Service Control Policies allow it

        Access Level: Write

        https://docs.aws.amazon.com/marketplace/latest/buyerguide/private-marketplace.html

        :stability: experimental
        '''
        return typing.cast("AwsMarketplacePrivate", jsii.invoke(self, "toDisassociateProductsFromPrivateMarketplace", []))

    @jsii.member(jsii_name="toListPrivateMarketplaceRequests")
    def to_list_private_marketplace_requests(self) -> "AwsMarketplacePrivate":
        '''(experimental) Grants permission to get a queryable list for requests and associated products in the Private Marketplace.

        This action can be performed by any account in an AWS Organization, provided the user has permissions to do so, and the Organization's Service Control Policies allow it

        Access Level: List

        https://docs.aws.amazon.com/marketplace/latest/buyerguide/private-marketplace.html

        :stability: experimental
        '''
        return typing.cast("AwsMarketplacePrivate", jsii.invoke(self, "toListPrivateMarketplaceRequests", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__50ddb15f837a02e25126e0fe48f58bff295d8bfe9bfa2d7512146328ffe1a9ca)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__34c1bfbfba8b9fc89a5119a21bfc83d1cacbcfc5cbf57a0907efd82fa93e7ced)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class AwsMarketplaceProcurementSystemsIntegration(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.AwsMarketplaceProcurementSystemsIntegration",
):
    '''(experimental) Statement provider for service `aws-marketplace-procurement-systems-integration <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsmarketplaceprocurementsystemsintegration.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `aws-marketplace-procurement-systems-integration <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsmarketplaceprocurementsystemsintegration.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="toDescribeProcurementSystemConfiguration")
    def to_describe_procurement_system_configuration(
        self,
    ) -> "AwsMarketplaceProcurementSystemsIntegration":
        '''(experimental) Describes the Procurement System integration configuration (e.g. Coupa) for the individual account, or for the entire AWS Organization if one exists. This action can only be performed by the master account if using an AWS Organization.

        Access Level: Read

        https://docs.aws.amazon.com/marketplace/latest/buyerguide/procurement-systems-integration.html

        :stability: experimental
        '''
        return typing.cast("AwsMarketplaceProcurementSystemsIntegration", jsii.invoke(self, "toDescribeProcurementSystemConfiguration", []))

    @jsii.member(jsii_name="toPutProcurementSystemConfiguration")
    def to_put_procurement_system_configuration(
        self,
    ) -> "AwsMarketplaceProcurementSystemsIntegration":
        '''(experimental) Creates or updates the Procurement System integration configuration (e.g. Coupa) for the individual account, or for the entire AWS Organization if one exists. This action can only be performed by the master account if using an AWS Organization.

        Access Level: Write

        https://docs.aws.amazon.com/marketplace/latest/buyerguide/procurement-systems-integration.html

        :stability: experimental
        '''
        return typing.cast("AwsMarketplaceProcurementSystemsIntegration", jsii.invoke(self, "toPutProcurementSystemConfiguration", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a465026fd850e62c8fe5bb1c094ff3a36d18dc90eb247c105166a5e7189ae021)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__19728bba995efcc20fc199d69ca4ab7fc105a711567e82d5733bf24ea4ab250d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class AwsMarketplaceSellerReporting(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.AwsMarketplaceSellerReporting",
):
    '''(experimental) Statement provider for service `aws-marketplace-seller-reporting <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsmarketplacesellerreporting.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `aws-marketplace-seller-reporting <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsmarketplacesellerreporting.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onSellerDashboard")
    def on_seller_dashboard(
        self,
        catalog: builtins.str,
        dashboard_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "AwsMarketplaceSellerReporting":
        '''(experimental) Adds a resource of type SellerDashboard to the statement.

        https://docs.aws.amazon.com/marketplace/latest/userguide/dashboards.html#reports-accessing

        :param catalog: - Identifier for the catalog.
        :param dashboard_name: - Identifier for the dashboardName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__00868f5e2245fe2bca77c65596c0e0130f3b76105b8caae7e621e184f5c17a4e)
            check_type(argname="argument catalog", value=catalog, expected_type=type_hints["catalog"])
            check_type(argname="argument dashboard_name", value=dashboard_name, expected_type=type_hints["dashboard_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("AwsMarketplaceSellerReporting", jsii.invoke(self, "onSellerDashboard", [catalog, dashboard_name, account, partition]))

    @jsii.member(jsii_name="toGetSellerDashboard")
    def to_get_seller_dashboard(self) -> "AwsMarketplaceSellerReporting":
        '''(experimental) Grants permission to view a seller dashboard.

        Access Level: Read

        https://docs.aws.amazon.com/marketplace/latest/userguide/dashboards.html#reports-accessing

        :stability: experimental
        '''
        return typing.cast("AwsMarketplaceSellerReporting", jsii.invoke(self, "toGetSellerDashboard", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b3d7e18aa9f1c2432c7176a6a0b66fb548f55c0f3e99eb082d68e7808480a7a2)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__78d45a5f8007235217136dcdbf5b472b8fcb41b634ec76f6b3f1f3f4bb81c9e9)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class AwsPortal(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.AwsPortal",
):
    '''(experimental) Statement provider for service `aws-portal <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsbillingconsole.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `aws-portal <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsbillingconsole.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="toModifyAccount")
    def to_modify_account(self) -> "AwsPortal":
        '''(experimental) Allow or deny IAM users permission to modify Account Settings.

        Access Level: Write

        https://docs.aws.amazon.com/awsaccountbilling/latest/aboutv2/billing-permissions-ref.html#user-permissions

        :stability: experimental
        '''
        return typing.cast("AwsPortal", jsii.invoke(self, "toModifyAccount", []))

    @jsii.member(jsii_name="toModifyBilling")
    def to_modify_billing(self) -> "AwsPortal":
        '''(experimental) Allow or deny IAM users permission to modify billing settings.

        Access Level: Write

        https://docs.aws.amazon.com/awsaccountbilling/latest/aboutv2/billing-permissions-ref.html#user-permissions

        :stability: experimental
        '''
        return typing.cast("AwsPortal", jsii.invoke(self, "toModifyBilling", []))

    @jsii.member(jsii_name="toModifyPaymentMethods")
    def to_modify_payment_methods(self) -> "AwsPortal":
        '''(experimental) Allow or deny IAM users permission to modify payment methods.

        Access Level: Write

        https://docs.aws.amazon.com/awsaccountbilling/latest/aboutv2/billing-permissions-ref.html#user-permissions

        :stability: experimental
        '''
        return typing.cast("AwsPortal", jsii.invoke(self, "toModifyPaymentMethods", []))

    @jsii.member(jsii_name="toViewAccount")
    def to_view_account(self) -> "AwsPortal":
        '''(experimental) Allow or deny IAM users permission to view account settings.

        Access Level: Read

        https://docs.aws.amazon.com/awsaccountbilling/latest/aboutv2/billing-permissions-ref.html#user-permissions

        :stability: experimental
        '''
        return typing.cast("AwsPortal", jsii.invoke(self, "toViewAccount", []))

    @jsii.member(jsii_name="toViewBilling")
    def to_view_billing(self) -> "AwsPortal":
        '''(experimental) Allow or deny IAM users permission to view billing pages in the console.

        Access Level: Read

        https://docs.aws.amazon.com/awsaccountbilling/latest/aboutv2/billing-permissions-ref.html#user-permissions

        :stability: experimental
        '''
        return typing.cast("AwsPortal", jsii.invoke(self, "toViewBilling", []))

    @jsii.member(jsii_name="toViewPaymentMethods")
    def to_view_payment_methods(self) -> "AwsPortal":
        '''(experimental) Allow or deny IAM users permission to view payment methods.

        Access Level: Read

        https://docs.aws.amazon.com/awsaccountbilling/latest/aboutv2/billing-permissions-ref.html#user-permissions

        :stability: experimental
        '''
        return typing.cast("AwsPortal", jsii.invoke(self, "toViewPaymentMethods", []))

    @jsii.member(jsii_name="toViewUsage")
    def to_view_usage(self) -> "AwsPortal":
        '''(experimental) Allow or deny IAM users permission to view AWS usage reports.

        Access Level: Read

        https://docs.aws.amazon.com/awsaccountbilling/latest/aboutv2/billing-permissions-ref.html#user-permissions

        :stability: experimental
        '''
        return typing.cast("AwsPortal", jsii.invoke(self, "toViewUsage", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__502d8eadd8fbb771fa251cda854d78ca9e1de19162f98192e79bc14c4e543238)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a722ac9bcfe1539fc65a7a9925821d59f016d8f39530c11438c8f84699676caf)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Awsconnector(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Awsconnector",
):
    '''(experimental) Statement provider for service `awsconnector <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsconnectorservice.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `awsconnector <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsconnectorservice.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="toGetConnectorHealth")
    def to_get_connector_health(self) -> "Awsconnector":
        '''(experimental) Retrieves all health metrics that were published from the Server Migration Connector.

        Access Level: Read

        https://docs.aws.amazon.com/server-migration-service/latest/userguide/prereqs.html#connector-permissions

        :stability: experimental
        '''
        return typing.cast("Awsconnector", jsii.invoke(self, "toGetConnectorHealth", []))

    @jsii.member(jsii_name="toRegisterConnector")
    def to_register_connector(self) -> "Awsconnector":
        '''(experimental) Registers AWS Connector with AWS Connector Service.

        Access Level: Write

        https://docs.aws.amazon.com/server-migration-service/latest/userguide/prereqs.html#connector-permissions

        :stability: experimental
        '''
        return typing.cast("Awsconnector", jsii.invoke(self, "toRegisterConnector", []))

    @jsii.member(jsii_name="toValidateConnectorId")
    def to_validate_connector_id(self) -> "Awsconnector":
        '''(experimental) Validates Server Migration Connector Id that was registered with AWS Connector Service.

        Access Level: Read

        https://docs.aws.amazon.com/server-migration-service/latest/userguide/prereqs.html#connector-permissions

        :stability: experimental
        '''
        return typing.cast("Awsconnector", jsii.invoke(self, "toValidateConnectorId", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__38d53b6153da45ab8b89d2502742a1240e7b581af8602a9689e1c9c704c8545c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6aa0b076b16da7a89d75b9d777b1647b37ec9979abf8a15249714ccf87207066)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Backup(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Backup",
):
    '''(experimental) Statement provider for service `backup <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsbackup.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `backup <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsbackup.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="ifChangeableForDays")
    def if_changeable_for_days(
        self,
        value: typing.Union[jsii.Number, typing.Sequence[jsii.Number]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Backup":
        '''(experimental) Filters access by the value of the ChangeableForDays parameter.

        https://docs.aws.amazon.com/aws-backup/latest/devguide/access-control.html#amazon-backup-keys

        Applies to actions:

        - .toPutBackupVaultLockConfiguration()

        :param value: The value(s) to check.
        :param operator: Works with `numeric operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_Numeric>`_. **Default:** ``NumericEquals``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2c2acc7fc033df9f4c84292992501ba366525fc84d28ad73ea14c777f78bedad)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Backup", jsii.invoke(self, "ifChangeableForDays", [value, operator]))

    @jsii.member(jsii_name="ifCopyTargetOrgPaths")
    def if_copy_target_org_paths(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Backup":
        '''(experimental) Filters access by the organization unit.

        https://docs.aws.amazon.com/aws-backup/latest/devguide/access-control.html#amazon-backup-keys

        Applies to actions:

        - .toCopyFromBackupVault()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__591e4ccdd18c0898c31a270cbae35e760e05a28a8c752e04488065f1560180e2)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Backup", jsii.invoke(self, "ifCopyTargetOrgPaths", [value, operator]))

    @jsii.member(jsii_name="ifCopyTargets")
    def if_copy_targets(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Backup":
        '''(experimental) Filters access by the ARN of an backup vault.

        https://docs.aws.amazon.com/aws-backup/latest/devguide/access-control.html#amazon-backup-keys

        Applies to actions:

        - .toCopyFromBackupVault()

        :param value: The value(s) to check.
        :param operator: Works with `arn operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_ARN>`_. **Default:** ``ArnLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__11234e47953682915339da170e8f63d8465e6bc2e18666983359986a3c35a79d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Backup", jsii.invoke(self, "ifCopyTargets", [value, operator]))

    @jsii.member(jsii_name="ifFrameworkArns")
    def if_framework_arns(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Backup":
        '''(experimental) Filters access by the Framework ARNs.

        https://docs.aws.amazon.com/aws-backup/latest/devguide/access-control.html#amazon-backup-keys

        Applies to actions:

        - .toCreateReportPlan()
        - .toUpdateReportPlan()

        :param value: The value(s) to check.
        :param operator: Works with `arn operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_ARN>`_. **Default:** ``ArnLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d42ece14d76d36c6308eaf85a395a0364ddebaef4f56b1dfdcbaebf6b862dbc0)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Backup", jsii.invoke(self, "ifFrameworkArns", [value, operator]))

    @jsii.member(jsii_name="onBackupPlan")
    def on_backup_plan(
        self,
        backup_plan_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Backup":
        '''(experimental) Adds a resource of type backupPlan to the statement.

        https://docs.aws.amazon.com/aws-backup/latest/devguide/about-backup-plans.html

        :param backup_plan_id: - Identifier for the backupPlanId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__22196c6228611590029cd23c313a5c1ddb4c4703836deec481414540bb216f73)
            check_type(argname="argument backup_plan_id", value=backup_plan_id, expected_type=type_hints["backup_plan_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Backup", jsii.invoke(self, "onBackupPlan", [backup_plan_id, account, region, partition]))

    @jsii.member(jsii_name="onBackupVault")
    def on_backup_vault(
        self,
        backup_vault_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Backup":
        '''(experimental) Adds a resource of type backupVault to the statement.

        https://docs.aws.amazon.com/aws-backup/latest/devguide/vaults.html

        :param backup_vault_name: - Identifier for the backupVaultName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6ebe347c2928071ff0b68c4457d8f34bf1f74f3c277fb1b7b6b59328a788a149)
            check_type(argname="argument backup_vault_name", value=backup_vault_name, expected_type=type_hints["backup_vault_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Backup", jsii.invoke(self, "onBackupVault", [backup_vault_name, account, region, partition]))

    @jsii.member(jsii_name="onFramework")
    def on_framework(
        self,
        framework_name: builtins.str,
        framework_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Backup":
        '''(experimental) Adds a resource of type framework to the statement.

        https://docs.aws.amazon.com/aws-backup/latest/devguide/frameworks.html

        :param framework_name: - Identifier for the frameworkName.
        :param framework_id: - Identifier for the frameworkId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__62c5d53064ec37df92f547e7314ba967c019d9527d04d255ad7b5fbd6b005777)
            check_type(argname="argument framework_name", value=framework_name, expected_type=type_hints["framework_name"])
            check_type(argname="argument framework_id", value=framework_id, expected_type=type_hints["framework_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Backup", jsii.invoke(self, "onFramework", [framework_name, framework_id, account, region, partition]))

    @jsii.member(jsii_name="onLegalHold")
    def on_legal_hold(
        self,
        legal_hold_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Backup":
        '''(experimental) Adds a resource of type legalHold to the statement.

        https://docs.aws.amazon.com/aws-backup/latest/devguide/legal-holds.html

        :param legal_hold_id: - Identifier for the legalHoldId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2eeb987ea6519c2b0362cff2bca262eccbd4b4e04f24ad9377791b1bcf5f01f6)
            check_type(argname="argument legal_hold_id", value=legal_hold_id, expected_type=type_hints["legal_hold_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Backup", jsii.invoke(self, "onLegalHold", [legal_hold_id, account, region, partition]))

    @jsii.member(jsii_name="onRecoveryPoint")
    def on_recovery_point(
        self,
        recovery_point_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Backup":
        '''(experimental) Adds a resource of type recoveryPoint to the statement.

        https://docs.aws.amazon.com/aws-backup/latest/devguide/recovery-points.html

        :param recovery_point_id: - Identifier for the recoveryPointId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__22ef8ba5478442b6fc7fc79600c885f3a6519e453058150f7d7348d77bc51857)
            check_type(argname="argument recovery_point_id", value=recovery_point_id, expected_type=type_hints["recovery_point_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Backup", jsii.invoke(self, "onRecoveryPoint", [recovery_point_id, account, region, partition]))

    @jsii.member(jsii_name="onReportPlan")
    def on_report_plan(
        self,
        report_plan_name: builtins.str,
        report_plan_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Backup":
        '''(experimental) Adds a resource of type reportPlan to the statement.

        https://docs.aws.amazon.com/aws-backup/latest/devguide/report-plans.html

        :param report_plan_name: - Identifier for the reportPlanName.
        :param report_plan_id: - Identifier for the reportPlanId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7c6385fdb691a7159620ccdf2877e7a432a29ecaa381b1d5a87ae2495a16597f)
            check_type(argname="argument report_plan_name", value=report_plan_name, expected_type=type_hints["report_plan_name"])
            check_type(argname="argument report_plan_id", value=report_plan_id, expected_type=type_hints["report_plan_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Backup", jsii.invoke(self, "onReportPlan", [report_plan_name, report_plan_id, account, region, partition]))

    @jsii.member(jsii_name="toCancelLegalHold")
    def to_cancel_legal_hold(self) -> "Backup":
        '''(experimental) Grants permission to cancel a legal hold.

        Access Level: Write

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_CancelLegalHold.html

        :stability: experimental
        '''
        return typing.cast("Backup", jsii.invoke(self, "toCancelLegalHold", []))

    @jsii.member(jsii_name="toCopyFromBackupVault")
    def to_copy_from_backup_vault(self) -> "Backup":
        '''(experimental) Grants permission to copy from a backup vault.

        Access Level: Write

        Possible conditions:

        - .ifCopyTargets()
        - .ifCopyTargetOrgPaths()

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_StartCopyJob.html

        :stability: experimental
        '''
        return typing.cast("Backup", jsii.invoke(self, "toCopyFromBackupVault", []))

    @jsii.member(jsii_name="toCopyIntoBackupVault")
    def to_copy_into_backup_vault(self) -> "Backup":
        '''(experimental) Grants permission to copy into a backup vault.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_StartCopyJob.html

        :stability: experimental
        '''
        return typing.cast("Backup", jsii.invoke(self, "toCopyIntoBackupVault", []))

    @jsii.member(jsii_name="toCreateBackupPlan")
    def to_create_backup_plan(self) -> "Backup":
        '''(experimental) Grants permission to create a new backup plan.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_CreateBackupPlan.html

        :stability: experimental
        '''
        return typing.cast("Backup", jsii.invoke(self, "toCreateBackupPlan", []))

    @jsii.member(jsii_name="toCreateBackupSelection")
    def to_create_backup_selection(self) -> "Backup":
        '''(experimental) Grants permission to create a new resource assignment in a backup plan.

        Access Level: Write

        Dependent actions:

        - iam:PassRole

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_CreateBackupSelection.html

        :stability: experimental
        '''
        return typing.cast("Backup", jsii.invoke(self, "toCreateBackupSelection", []))

    @jsii.member(jsii_name="toCreateBackupVault")
    def to_create_backup_vault(self) -> "Backup":
        '''(experimental) Grants permission to create a new backup vault.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_CreateBackupVault.html

        :stability: experimental
        '''
        return typing.cast("Backup", jsii.invoke(self, "toCreateBackupVault", []))

    @jsii.member(jsii_name="toCreateFramework")
    def to_create_framework(self) -> "Backup":
        '''(experimental) Grants permission to create a new framework.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_CreateFramework.html

        :stability: experimental
        '''
        return typing.cast("Backup", jsii.invoke(self, "toCreateFramework", []))

    @jsii.member(jsii_name="toCreateLegalHold")
    def to_create_legal_hold(self) -> "Backup":
        '''(experimental) Grants permission to create a new legal hold.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_CreateLegalHold.html

        :stability: experimental
        '''
        return typing.cast("Backup", jsii.invoke(self, "toCreateLegalHold", []))

    @jsii.member(jsii_name="toCreateReportPlan")
    def to_create_report_plan(self) -> "Backup":
        '''(experimental) Grants permission to create a new report plan.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifFrameworkArns()

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_CreateReportPlan.html

        :stability: experimental
        '''
        return typing.cast("Backup", jsii.invoke(self, "toCreateReportPlan", []))

    @jsii.member(jsii_name="toDeleteBackupPlan")
    def to_delete_backup_plan(self) -> "Backup":
        '''(experimental) Grants permission to delete a backup plan.

        Access Level: Write

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_DeleteBackupPlan.html

        :stability: experimental
        '''
        return typing.cast("Backup", jsii.invoke(self, "toDeleteBackupPlan", []))

    @jsii.member(jsii_name="toDeleteBackupSelection")
    def to_delete_backup_selection(self) -> "Backup":
        '''(experimental) Grants permission to delete a resource assignment from a backup plan.

        Access Level: Write

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_DeleteBackupSelection.html

        :stability: experimental
        '''
        return typing.cast("Backup", jsii.invoke(self, "toDeleteBackupSelection", []))

    @jsii.member(jsii_name="toDeleteBackupVault")
    def to_delete_backup_vault(self) -> "Backup":
        '''(experimental) Grants permission to delete a backup vault.

        Access Level: Write

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_DeleteBackupVault.html

        :stability: experimental
        '''
        return typing.cast("Backup", jsii.invoke(self, "toDeleteBackupVault", []))

    @jsii.member(jsii_name="toDeleteBackupVaultAccessPolicy")
    def to_delete_backup_vault_access_policy(self) -> "Backup":
        '''(experimental) Grants permission to delete backup vault access policy.

        Access Level: Permissions management

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_DeleteBackupVaultAccessPolicy.html

        :stability: experimental
        '''
        return typing.cast("Backup", jsii.invoke(self, "toDeleteBackupVaultAccessPolicy", []))

    @jsii.member(jsii_name="toDeleteBackupVaultLockConfiguration")
    def to_delete_backup_vault_lock_configuration(self) -> "Backup":
        '''(experimental) Grants permission to remove the lock configuration from a backup vault.

        Access Level: Write

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_DeleteBackupVaultLockConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Backup", jsii.invoke(self, "toDeleteBackupVaultLockConfiguration", []))

    @jsii.member(jsii_name="toDeleteBackupVaultNotifications")
    def to_delete_backup_vault_notifications(self) -> "Backup":
        '''(experimental) Grants permission to remove the notifications from a backup vault.

        Access Level: Write

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_DeleteBackupVaultNotifications.html

        :stability: experimental
        '''
        return typing.cast("Backup", jsii.invoke(self, "toDeleteBackupVaultNotifications", []))

    @jsii.member(jsii_name="toDeleteFramework")
    def to_delete_framework(self) -> "Backup":
        '''(experimental) Grants permission to delete a framework.

        Access Level: Write

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_DeleteFramework.html

        :stability: experimental
        '''
        return typing.cast("Backup", jsii.invoke(self, "toDeleteFramework", []))

    @jsii.member(jsii_name="toDeleteRecoveryPoint")
    def to_delete_recovery_point(self) -> "Backup":
        '''(experimental) Grants permission to delete a recovery point from a backup vault.

        Access Level: Write

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_DeleteRecoveryPoint.html

        :stability: experimental
        '''
        return typing.cast("Backup", jsii.invoke(self, "toDeleteRecoveryPoint", []))

    @jsii.member(jsii_name="toDeleteReportPlan")
    def to_delete_report_plan(self) -> "Backup":
        '''(experimental) Grants permission to delete a report plan.

        Access Level: Write

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_DeleteReportPlan.html

        :stability: experimental
        '''
        return typing.cast("Backup", jsii.invoke(self, "toDeleteReportPlan", []))

    @jsii.member(jsii_name="toDescribeBackupJob")
    def to_describe_backup_job(self) -> "Backup":
        '''(experimental) Grants permission to describe a backup job.

        Access Level: Read

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_DescribeBackupJob.html

        :stability: experimental
        '''
        return typing.cast("Backup", jsii.invoke(self, "toDescribeBackupJob", []))

    @jsii.member(jsii_name="toDescribeBackupVault")
    def to_describe_backup_vault(self) -> "Backup":
        '''(experimental) Grants permission to describe a new backup vault with the specified name.

        Access Level: Read

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_DescribeBackupVault.html

        :stability: experimental
        '''
        return typing.cast("Backup", jsii.invoke(self, "toDescribeBackupVault", []))

    @jsii.member(jsii_name="toDescribeCopyJob")
    def to_describe_copy_job(self) -> "Backup":
        '''(experimental) Grants permission to describe a copy job.

        Access Level: Read

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_DescribeCopyJob.html

        :stability: experimental
        '''
        return typing.cast("Backup", jsii.invoke(self, "toDescribeCopyJob", []))

    @jsii.member(jsii_name="toDescribeFramework")
    def to_describe_framework(self) -> "Backup":
        '''(experimental) Grants permission to describe a framework with the specified name.

        Access Level: Read

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_DescribeFramework.html

        :stability: experimental
        '''
        return typing.cast("Backup", jsii.invoke(self, "toDescribeFramework", []))

    @jsii.member(jsii_name="toDescribeGlobalSettings")
    def to_describe_global_settings(self) -> "Backup":
        '''(experimental) Grants permission to describe global settings.

        Access Level: Read

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_DescribeGlobalSettings.html

        :stability: experimental
        '''
        return typing.cast("Backup", jsii.invoke(self, "toDescribeGlobalSettings", []))

    @jsii.member(jsii_name="toDescribeProtectedResource")
    def to_describe_protected_resource(self) -> "Backup":
        '''(experimental) Grants permission to describe a protected resource.

        Access Level: Read

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_DescribeProtectedResource.html

        :stability: experimental
        '''
        return typing.cast("Backup", jsii.invoke(self, "toDescribeProtectedResource", []))

    @jsii.member(jsii_name="toDescribeRecoveryPoint")
    def to_describe_recovery_point(self) -> "Backup":
        '''(experimental) Grants permission to describe a recovery point.

        Access Level: Read

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_DescribeRecoveryPoint.html

        :stability: experimental
        '''
        return typing.cast("Backup", jsii.invoke(self, "toDescribeRecoveryPoint", []))

    @jsii.member(jsii_name="toDescribeRegionSettings")
    def to_describe_region_settings(self) -> "Backup":
        '''(experimental) Grants permission to describe region settings.

        Access Level: Read

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_DescribeRegionSettings.html

        :stability: experimental
        '''
        return typing.cast("Backup", jsii.invoke(self, "toDescribeRegionSettings", []))

    @jsii.member(jsii_name="toDescribeReportJob")
    def to_describe_report_job(self) -> "Backup":
        '''(experimental) Grants permission to describe a report job.

        Access Level: Read

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_DescribeReportJob.html

        :stability: experimental
        '''
        return typing.cast("Backup", jsii.invoke(self, "toDescribeReportJob", []))

    @jsii.member(jsii_name="toDescribeReportPlan")
    def to_describe_report_plan(self) -> "Backup":
        '''(experimental) Grants permission to describe a report plan with the specified name.

        Access Level: Read

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_DescribeReportPlan.html

        :stability: experimental
        '''
        return typing.cast("Backup", jsii.invoke(self, "toDescribeReportPlan", []))

    @jsii.member(jsii_name="toDescribeRestoreJob")
    def to_describe_restore_job(self) -> "Backup":
        '''(experimental) Grants permission to describe a restore job.

        Access Level: Read

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_DescribeRestoreJob.html

        :stability: experimental
        '''
        return typing.cast("Backup", jsii.invoke(self, "toDescribeRestoreJob", []))

    @jsii.member(jsii_name="toDisassociateRecoveryPoint")
    def to_disassociate_recovery_point(self) -> "Backup":
        '''(experimental) Grants permission to disassociate a recovery point from a backup vault.

        Access Level: Write

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_DisassociateRecoveryPoint.html

        :stability: experimental
        '''
        return typing.cast("Backup", jsii.invoke(self, "toDisassociateRecoveryPoint", []))

    @jsii.member(jsii_name="toDisassociateRecoveryPointFromParent")
    def to_disassociate_recovery_point_from_parent(self) -> "Backup":
        '''(experimental) Grants permission to disassociate a recovery point from its parent.

        Access Level: Write

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_DisassociateRecoveryPointFromParent.html

        :stability: experimental
        '''
        return typing.cast("Backup", jsii.invoke(self, "toDisassociateRecoveryPointFromParent", []))

    @jsii.member(jsii_name="toExportBackupPlanTemplate")
    def to_export_backup_plan_template(self) -> "Backup":
        '''(experimental) Grants permission to export a backup plan as a JSON.

        Access Level: Read

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_ExportBackupPlanTemplate.html

        :stability: experimental
        '''
        return typing.cast("Backup", jsii.invoke(self, "toExportBackupPlanTemplate", []))

    @jsii.member(jsii_name="toGetBackupPlan")
    def to_get_backup_plan(self) -> "Backup":
        '''(experimental) Grants permission to get a backup plan.

        Access Level: Read

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_GetBackupPlan.html

        :stability: experimental
        '''
        return typing.cast("Backup", jsii.invoke(self, "toGetBackupPlan", []))

    @jsii.member(jsii_name="toGetBackupPlanFromJSON")
    def to_get_backup_plan_from_json(self) -> "Backup":
        '''(experimental) Grants permission to transform a JSON to a backup plan.

        Access Level: Read

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_GetBackupPlanFromJSON.html

        :stability: experimental
        '''
        return typing.cast("Backup", jsii.invoke(self, "toGetBackupPlanFromJSON", []))

    @jsii.member(jsii_name="toGetBackupPlanFromTemplate")
    def to_get_backup_plan_from_template(self) -> "Backup":
        '''(experimental) Grants permission to transform a template to a backup plan.

        Access Level: Read

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_GetBackupPlanFromTemplate.html

        :stability: experimental
        '''
        return typing.cast("Backup", jsii.invoke(self, "toGetBackupPlanFromTemplate", []))

    @jsii.member(jsii_name="toGetBackupSelection")
    def to_get_backup_selection(self) -> "Backup":
        '''(experimental) Grants permission to get a backup plan resource assignment.

        Access Level: Read

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_GetBackupSelection.html

        :stability: experimental
        '''
        return typing.cast("Backup", jsii.invoke(self, "toGetBackupSelection", []))

    @jsii.member(jsii_name="toGetBackupVaultAccessPolicy")
    def to_get_backup_vault_access_policy(self) -> "Backup":
        '''(experimental) Grants permission to get backup vault access policy.

        Access Level: Read

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_GetBackupVaultAccessPolicy.html

        :stability: experimental
        '''
        return typing.cast("Backup", jsii.invoke(self, "toGetBackupVaultAccessPolicy", []))

    @jsii.member(jsii_name="toGetBackupVaultNotifications")
    def to_get_backup_vault_notifications(self) -> "Backup":
        '''(experimental) Grants permission to get backup vault notifications.

        Access Level: Read

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_GetBackupVaultNotifications.html

        :stability: experimental
        '''
        return typing.cast("Backup", jsii.invoke(self, "toGetBackupVaultNotifications", []))

    @jsii.member(jsii_name="toGetLegalHold")
    def to_get_legal_hold(self) -> "Backup":
        '''(experimental) Grants permission to get a legal hold.

        Access Level: Read

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_GetLegalHold.html

        :stability: experimental
        '''
        return typing.cast("Backup", jsii.invoke(self, "toGetLegalHold", []))

    @jsii.member(jsii_name="toGetRecoveryPointRestoreMetadata")
    def to_get_recovery_point_restore_metadata(self) -> "Backup":
        '''(experimental) Grants permission to get recovery point restore metadata.

        Access Level: Read

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_GetRecoveryPointRestoreMetadata.html

        :stability: experimental
        '''
        return typing.cast("Backup", jsii.invoke(self, "toGetRecoveryPointRestoreMetadata", []))

    @jsii.member(jsii_name="toGetSupportedResourceTypes")
    def to_get_supported_resource_types(self) -> "Backup":
        '''(experimental) Grants permission to get supported resource types.

        Access Level: Read

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_GetSupportedResourceTypes.html

        :stability: experimental
        '''
        return typing.cast("Backup", jsii.invoke(self, "toGetSupportedResourceTypes", []))

    @jsii.member(jsii_name="toListBackupJobs")
    def to_list_backup_jobs(self) -> "Backup":
        '''(experimental) Grants permission to list backup jobs.

        Access Level: List

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_ListBackupJobs.html

        :stability: experimental
        '''
        return typing.cast("Backup", jsii.invoke(self, "toListBackupJobs", []))

    @jsii.member(jsii_name="toListBackupPlans")
    def to_list_backup_plans(self) -> "Backup":
        '''(experimental) Grants permission to list backup plans.

        Access Level: List

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_ListBackupPlans.html

        :stability: experimental
        '''
        return typing.cast("Backup", jsii.invoke(self, "toListBackupPlans", []))

    @jsii.member(jsii_name="toListBackupPlanTemplates")
    def to_list_backup_plan_templates(self) -> "Backup":
        '''(experimental) Grants permission to list backup plan templates provided by AWS Backup.

        Access Level: List

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_ListBackupPlanTemplates.html

        :stability: experimental
        '''
        return typing.cast("Backup", jsii.invoke(self, "toListBackupPlanTemplates", []))

    @jsii.member(jsii_name="toListBackupPlanVersions")
    def to_list_backup_plan_versions(self) -> "Backup":
        '''(experimental) Grants permission to list backup plan versions.

        Access Level: List

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_ListBackupPlanVersions.html

        :stability: experimental
        '''
        return typing.cast("Backup", jsii.invoke(self, "toListBackupPlanVersions", []))

    @jsii.member(jsii_name="toListBackupSelections")
    def to_list_backup_selections(self) -> "Backup":
        '''(experimental) Grants permission to list resource assignments for a specific backup plan.

        Access Level: List

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_ListBackupSelections.html

        :stability: experimental
        '''
        return typing.cast("Backup", jsii.invoke(self, "toListBackupSelections", []))

    @jsii.member(jsii_name="toListBackupVaults")
    def to_list_backup_vaults(self) -> "Backup":
        '''(experimental) Grants permission to list backup vaults.

        Access Level: List

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_ListBackupVaults.html

        :stability: experimental
        '''
        return typing.cast("Backup", jsii.invoke(self, "toListBackupVaults", []))

    @jsii.member(jsii_name="toListCopyJobs")
    def to_list_copy_jobs(self) -> "Backup":
        '''(experimental) Grants permission to list copy jobs.

        Access Level: List

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_ListCopyJobs.html

        :stability: experimental
        '''
        return typing.cast("Backup", jsii.invoke(self, "toListCopyJobs", []))

    @jsii.member(jsii_name="toListFrameworks")
    def to_list_frameworks(self) -> "Backup":
        '''(experimental) Grants permission to list frameworks.

        Access Level: List

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_ListFrameworks.html

        :stability: experimental
        '''
        return typing.cast("Backup", jsii.invoke(self, "toListFrameworks", []))

    @jsii.member(jsii_name="toListLegalHolds")
    def to_list_legal_holds(self) -> "Backup":
        '''(experimental) Grants permission to list legal holds.

        Access Level: List

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_ListLegalHolds.html

        :stability: experimental
        '''
        return typing.cast("Backup", jsii.invoke(self, "toListLegalHolds", []))

    @jsii.member(jsii_name="toListProtectedResources")
    def to_list_protected_resources(self) -> "Backup":
        '''(experimental) Grants permission to list protected resources by AWS Backup.

        Access Level: List

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_ListProtectedResources.html

        :stability: experimental
        '''
        return typing.cast("Backup", jsii.invoke(self, "toListProtectedResources", []))

    @jsii.member(jsii_name="toListRecoveryPointsByBackupVault")
    def to_list_recovery_points_by_backup_vault(self) -> "Backup":
        '''(experimental) Grants permission to list recovery points inside a backup vault.

        Access Level: List

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_ListRecoveryPointsByBackupVault.html

        :stability: experimental
        '''
        return typing.cast("Backup", jsii.invoke(self, "toListRecoveryPointsByBackupVault", []))

    @jsii.member(jsii_name="toListRecoveryPointsByLegalHold")
    def to_list_recovery_points_by_legal_hold(self) -> "Backup":
        '''(experimental) Grants permission to list recovery points by legal hold.

        Access Level: List

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_ListRecoveryPointsByLegalHold.html

        :stability: experimental
        '''
        return typing.cast("Backup", jsii.invoke(self, "toListRecoveryPointsByLegalHold", []))

    @jsii.member(jsii_name="toListRecoveryPointsByResource")
    def to_list_recovery_points_by_resource(self) -> "Backup":
        '''(experimental) Grants permission to list recovery points for a resource.

        Access Level: List

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_ListRecoveryPointsByResource.html

        :stability: experimental
        '''
        return typing.cast("Backup", jsii.invoke(self, "toListRecoveryPointsByResource", []))

    @jsii.member(jsii_name="toListReportJobs")
    def to_list_report_jobs(self) -> "Backup":
        '''(experimental) Grants permission to list report jobs.

        Access Level: List

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_ListReportJobs.html

        :stability: experimental
        '''
        return typing.cast("Backup", jsii.invoke(self, "toListReportJobs", []))

    @jsii.member(jsii_name="toListReportPlans")
    def to_list_report_plans(self) -> "Backup":
        '''(experimental) Grants permission to list report plans.

        Access Level: List

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_ListReportPlans.html

        :stability: experimental
        '''
        return typing.cast("Backup", jsii.invoke(self, "toListReportPlans", []))

    @jsii.member(jsii_name="toListRestoreJobs")
    def to_list_restore_jobs(self) -> "Backup":
        '''(experimental) Grants permission to lists restore jobs.

        Access Level: List

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_ListRestoreJobs.html

        :stability: experimental
        '''
        return typing.cast("Backup", jsii.invoke(self, "toListRestoreJobs", []))

    @jsii.member(jsii_name="toListTags")
    def to_list_tags(self) -> "Backup":
        '''(experimental) Grants permission to list tags for a resource.

        Access Level: Read

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_ListTags.html

        :stability: experimental
        '''
        return typing.cast("Backup", jsii.invoke(self, "toListTags", []))

    @jsii.member(jsii_name="toPutBackupVaultAccessPolicy")
    def to_put_backup_vault_access_policy(self) -> "Backup":
        '''(experimental) Grants permission to add an access policy to the backup vault.

        Access Level: Permissions management

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_PutBackupVaultAccessPolicy.html

        :stability: experimental
        '''
        return typing.cast("Backup", jsii.invoke(self, "toPutBackupVaultAccessPolicy", []))

    @jsii.member(jsii_name="toPutBackupVaultLockConfiguration")
    def to_put_backup_vault_lock_configuration(self) -> "Backup":
        '''(experimental) Grants permission to add a lock configuration to the backup vault.

        Access Level: Write

        Possible conditions:

        - .ifChangeableForDays()

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_PutBackupVaultLockConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Backup", jsii.invoke(self, "toPutBackupVaultLockConfiguration", []))

    @jsii.member(jsii_name="toPutBackupVaultNotifications")
    def to_put_backup_vault_notifications(self) -> "Backup":
        '''(experimental) Grants permission to add an SNS topic to the backup vault.

        Access Level: Write

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_PutBackupVaultNotifications.html

        :stability: experimental
        '''
        return typing.cast("Backup", jsii.invoke(self, "toPutBackupVaultNotifications", []))

    @jsii.member(jsii_name="toStartBackupJob")
    def to_start_backup_job(self) -> "Backup":
        '''(experimental) Grants permission to start a new backup job.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - iam:PassRole

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_StartBackupJob.html

        :stability: experimental
        '''
        return typing.cast("Backup", jsii.invoke(self, "toStartBackupJob", []))

    @jsii.member(jsii_name="toStartCopyJob")
    def to_start_copy_job(self) -> "Backup":
        '''(experimental) Grants permission to copy a backup from a source backup vault to a destination backup vault.

        Access Level: Write

        Dependent actions:

        - iam:PassRole

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_StartCopyJob.html

        :stability: experimental
        '''
        return typing.cast("Backup", jsii.invoke(self, "toStartCopyJob", []))

    @jsii.member(jsii_name="toStartReportJob")
    def to_start_report_job(self) -> "Backup":
        '''(experimental) Grants permission to start a new report job.

        Access Level: Write

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_StartReportJob.html

        :stability: experimental
        '''
        return typing.cast("Backup", jsii.invoke(self, "toStartReportJob", []))

    @jsii.member(jsii_name="toStartRestoreJob")
    def to_start_restore_job(self) -> "Backup":
        '''(experimental) Grants permission to start a new restore job.

        Access Level: Write

        Dependent actions:

        - iam:PassRole

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_StartRestoreJob.html

        :stability: experimental
        '''
        return typing.cast("Backup", jsii.invoke(self, "toStartRestoreJob", []))

    @jsii.member(jsii_name="toStopBackupJob")
    def to_stop_backup_job(self) -> "Backup":
        '''(experimental) Grants permission to stop a backup job.

        Access Level: Write

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_StopBackupJob.html

        :stability: experimental
        '''
        return typing.cast("Backup", jsii.invoke(self, "toStopBackupJob", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Backup":
        '''(experimental) Grants permission to tag a resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("Backup", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Backup":
        '''(experimental) Grants permission to untag a resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("Backup", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateBackupPlan")
    def to_update_backup_plan(self) -> "Backup":
        '''(experimental) Grants permission to update a backup plan.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_UpdateBackupPlan.html

        :stability: experimental
        '''
        return typing.cast("Backup", jsii.invoke(self, "toUpdateBackupPlan", []))

    @jsii.member(jsii_name="toUpdateFramework")
    def to_update_framework(self) -> "Backup":
        '''(experimental) Grants permission to update a framework.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_UpdateFramework.html

        :stability: experimental
        '''
        return typing.cast("Backup", jsii.invoke(self, "toUpdateFramework", []))

    @jsii.member(jsii_name="toUpdateGlobalSettings")
    def to_update_global_settings(self) -> "Backup":
        '''(experimental) Grants permission to update the current global settings for the AWS Account.

        Access Level: Write

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_UpdateGlobalSettings.html

        :stability: experimental
        '''
        return typing.cast("Backup", jsii.invoke(self, "toUpdateGlobalSettings", []))

    @jsii.member(jsii_name="toUpdateRecoveryPointLifecycle")
    def to_update_recovery_point_lifecycle(self) -> "Backup":
        '''(experimental) Grants permission to update the lifecycle of the recovery point.

        Access Level: Write

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_UpdateRecoveryPointLifecycle.html

        :stability: experimental
        '''
        return typing.cast("Backup", jsii.invoke(self, "toUpdateRecoveryPointLifecycle", []))

    @jsii.member(jsii_name="toUpdateRegionSettings")
    def to_update_region_settings(self) -> "Backup":
        '''(experimental) Grants permission to update the current service opt-in settings for the Region.

        Access Level: Write

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_UpdateRegionSettings.html

        :stability: experimental
        '''
        return typing.cast("Backup", jsii.invoke(self, "toUpdateRegionSettings", []))

    @jsii.member(jsii_name="toUpdateReportPlan")
    def to_update_report_plan(self) -> "Backup":
        '''(experimental) Grants permission to update a report plan.

        Access Level: Write

        Possible conditions:

        - .ifFrameworkArns()

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_UpdateReportPlan.html

        :stability: experimental
        '''
        return typing.cast("Backup", jsii.invoke(self, "toUpdateReportPlan", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4e063d2e37b15ad3959368f6e55603cf4634ee57bd59cebf5c73a42ab18f6cb9)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4b3ee415575c07b2cc4e00b5a75653a01e46ae747929e624bcd5c6fa0d81b55d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class BackupGateway(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.BackupGateway",
):
    '''(experimental) Statement provider for service `backup-gateway <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsbackupgateway.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `backup-gateway <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsbackupgateway.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onGateway")
    def on_gateway(
        self,
        gateway_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "BackupGateway":
        '''(experimental) Adds a resource of type gateway to the statement.

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_BGW_Gateway.html

        :param gateway_id: - Identifier for the gatewayId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c3dffb6576961af75b2b3c1a264ea970f2c0758e9657d4f1dc209b5d6f07a085)
            check_type(argname="argument gateway_id", value=gateway_id, expected_type=type_hints["gateway_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("BackupGateway", jsii.invoke(self, "onGateway", [gateway_id, account, partition]))

    @jsii.member(jsii_name="onHypervisor")
    def on_hypervisor(
        self,
        hypervisor_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "BackupGateway":
        '''(experimental) Adds a resource of type hypervisor to the statement.

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_BGW_Hypervisor.html

        :param hypervisor_id: - Identifier for the hypervisorId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__755f9de471279bf496b72720ee44d12b3e5e95b50f2f108dac2c2f9b06dc47cc)
            check_type(argname="argument hypervisor_id", value=hypervisor_id, expected_type=type_hints["hypervisor_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("BackupGateway", jsii.invoke(self, "onHypervisor", [hypervisor_id, account, partition]))

    @jsii.member(jsii_name="onVirtualmachine")
    def on_virtualmachine(
        self,
        virtualmachine_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "BackupGateway":
        '''(experimental) Adds a resource of type virtualmachine to the statement.

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_BGW_VirtualMachine.html

        :param virtualmachine_id: - Identifier for the virtualmachineId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bec66f3180016fdb5ab8be08a73d51c34418cf907998bb65fe95c4d4ba61c292)
            check_type(argname="argument virtualmachine_id", value=virtualmachine_id, expected_type=type_hints["virtualmachine_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("BackupGateway", jsii.invoke(self, "onVirtualmachine", [virtualmachine_id, account, partition]))

    @jsii.member(jsii_name="toAssociateGatewayToServer")
    def to_associate_gateway_to_server(self) -> "BackupGateway":
        '''(experimental) Grants permission to AssociateGatewayToServer.

        Access Level: Write

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_BGW_AssociateGatewayToServer.html

        :stability: experimental
        '''
        return typing.cast("BackupGateway", jsii.invoke(self, "toAssociateGatewayToServer", []))

    @jsii.member(jsii_name="toBackup")
    def to_backup(self) -> "BackupGateway":
        '''(experimental) Grants permission to Backup.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_StartBackupJob.html

        :stability: experimental
        '''
        return typing.cast("BackupGateway", jsii.invoke(self, "toBackup", []))

    @jsii.member(jsii_name="toCreateGateway")
    def to_create_gateway(self) -> "BackupGateway":
        '''(experimental) Grants permission to to CreateGateway.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_BGW_CreateGateway.html

        :stability: experimental
        '''
        return typing.cast("BackupGateway", jsii.invoke(self, "toCreateGateway", []))

    @jsii.member(jsii_name="toDeleteGateway")
    def to_delete_gateway(self) -> "BackupGateway":
        '''(experimental) Grants permission to DeleteGateway.

        Access Level: Write

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_BGW_DeleteGateway.html

        :stability: experimental
        '''
        return typing.cast("BackupGateway", jsii.invoke(self, "toDeleteGateway", []))

    @jsii.member(jsii_name="toDeleteHypervisor")
    def to_delete_hypervisor(self) -> "BackupGateway":
        '''(experimental) Grants permission to DeleteHypervisor.

        Access Level: Write

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_BGW_DeleteHypervisor.html

        :stability: experimental
        '''
        return typing.cast("BackupGateway", jsii.invoke(self, "toDeleteHypervisor", []))

    @jsii.member(jsii_name="toDisassociateGatewayFromServer")
    def to_disassociate_gateway_from_server(self) -> "BackupGateway":
        '''(experimental) Grants permission to DisassociateGatewayFromServer.

        Access Level: Write

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_BGW_DisassociateGatewayFromServer.html

        :stability: experimental
        '''
        return typing.cast("BackupGateway", jsii.invoke(self, "toDisassociateGatewayFromServer", []))

    @jsii.member(jsii_name="toGetBandwidthRateLimitSchedule")
    def to_get_bandwidth_rate_limit_schedule(self) -> "BackupGateway":
        '''(experimental) Grants permission to GetBandwidthRateLimitSchedule.

        Access Level: Read

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_BGW_GetBandwidthRateLimitSchedule.html

        :stability: experimental
        '''
        return typing.cast("BackupGateway", jsii.invoke(self, "toGetBandwidthRateLimitSchedule", []))

    @jsii.member(jsii_name="toGetGateway")
    def to_get_gateway(self) -> "BackupGateway":
        '''(experimental) Grants permission to GetGateway.

        Access Level: Read

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_BGW_GetGateway.html

        :stability: experimental
        '''
        return typing.cast("BackupGateway", jsii.invoke(self, "toGetGateway", []))

    @jsii.member(jsii_name="toGetHypervisor")
    def to_get_hypervisor(self) -> "BackupGateway":
        '''(experimental) Grants permission to GetHypervisor.

        Access Level: Read

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_BGW_GetHypervisor.html

        :stability: experimental
        '''
        return typing.cast("BackupGateway", jsii.invoke(self, "toGetHypervisor", []))

    @jsii.member(jsii_name="toGetHypervisorPropertyMappings")
    def to_get_hypervisor_property_mappings(self) -> "BackupGateway":
        '''(experimental) Grants permission to GetHypervisorPropertyMappings.

        Access Level: Read

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_BGW_GetHypervisorPropertyMappings.html

        :stability: experimental
        '''
        return typing.cast("BackupGateway", jsii.invoke(self, "toGetHypervisorPropertyMappings", []))

    @jsii.member(jsii_name="toGetVirtualMachine")
    def to_get_virtual_machine(self) -> "BackupGateway":
        '''(experimental) Grants permission to GetVirtualMachine.

        Access Level: Read

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_BGW_GetVirtualMachine.html

        :stability: experimental
        '''
        return typing.cast("BackupGateway", jsii.invoke(self, "toGetVirtualMachine", []))

    @jsii.member(jsii_name="toImportHypervisorConfiguration")
    def to_import_hypervisor_configuration(self) -> "BackupGateway":
        '''(experimental) Grants permission to ImportHypervisorConfiguration.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_BGW_ImportHypervisorConfiguration.html

        :stability: experimental
        '''
        return typing.cast("BackupGateway", jsii.invoke(self, "toImportHypervisorConfiguration", []))

    @jsii.member(jsii_name="toListGateways")
    def to_list_gateways(self) -> "BackupGateway":
        '''(experimental) Grants permission to ListGateways.

        Access Level: Read

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_BGW_ListGateways.html

        :stability: experimental
        '''
        return typing.cast("BackupGateway", jsii.invoke(self, "toListGateways", []))

    @jsii.member(jsii_name="toListHypervisors")
    def to_list_hypervisors(self) -> "BackupGateway":
        '''(experimental) Grants permission to ListHypervisors.

        Access Level: Read

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_BGW_ListHypervisors.html

        :stability: experimental
        '''
        return typing.cast("BackupGateway", jsii.invoke(self, "toListHypervisors", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "BackupGateway":
        '''(experimental) Grants permission to ListTagsForResource.

        Access Level: Read

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_BGW_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("BackupGateway", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toListVirtualMachines")
    def to_list_virtual_machines(self) -> "BackupGateway":
        '''(experimental) Grants permission to ListVirtualMachines.

        Access Level: Read

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_BGW_ListVirtualMachines.html

        :stability: experimental
        '''
        return typing.cast("BackupGateway", jsii.invoke(self, "toListVirtualMachines", []))

    @jsii.member(jsii_name="toPutBandwidthRateLimitSchedule")
    def to_put_bandwidth_rate_limit_schedule(self) -> "BackupGateway":
        '''(experimental) Grants permission to PutBandwidthRateLimitSchedule.

        Access Level: Write

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_BGW_PutBandwidthRateLimitSchedule.html

        :stability: experimental
        '''
        return typing.cast("BackupGateway", jsii.invoke(self, "toPutBandwidthRateLimitSchedule", []))

    @jsii.member(jsii_name="toPutHypervisorPropertyMappings")
    def to_put_hypervisor_property_mappings(self) -> "BackupGateway":
        '''(experimental) Grants permission to PutHypervisorPropertyMappings.

        Access Level: Write

        Dependent actions:

        - iam:PassRole

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_BGW_PutHypervisorPropertyMappings.html

        :stability: experimental
        '''
        return typing.cast("BackupGateway", jsii.invoke(self, "toPutHypervisorPropertyMappings", []))

    @jsii.member(jsii_name="toPutMaintenanceStartTime")
    def to_put_maintenance_start_time(self) -> "BackupGateway":
        '''(experimental) Grants permission to PutMaintenanceStartTime.

        Access Level: Write

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_BGW_PutMaintenanceStartTime.html

        :stability: experimental
        '''
        return typing.cast("BackupGateway", jsii.invoke(self, "toPutMaintenanceStartTime", []))

    @jsii.member(jsii_name="toRestore")
    def to_restore(self) -> "BackupGateway":
        '''(experimental) Grants permission to Restore.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_StartRestoreJob.html

        :stability: experimental
        '''
        return typing.cast("BackupGateway", jsii.invoke(self, "toRestore", []))

    @jsii.member(jsii_name="toStartVirtualMachinesMetadataSync")
    def to_start_virtual_machines_metadata_sync(self) -> "BackupGateway":
        '''(experimental) Grants permission to StartVirtualMachinesMetadataSync.

        Access Level: Write

        Dependent actions:

        - iam:PassRole

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_BGW_StartVirtualMachinesMetadataSync.html

        :stability: experimental
        '''
        return typing.cast("BackupGateway", jsii.invoke(self, "toStartVirtualMachinesMetadataSync", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "BackupGateway":
        '''(experimental) Grants permission to TagResource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_BGW_TagResource.html

        :stability: experimental
        '''
        return typing.cast("BackupGateway", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toTestHypervisorConfiguration")
    def to_test_hypervisor_configuration(self) -> "BackupGateway":
        '''(experimental) Grants permission to TestHypervisorConfiguration.

        Access Level: Write

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_BGW_TestHypervisorConfiguration.html

        :stability: experimental
        '''
        return typing.cast("BackupGateway", jsii.invoke(self, "toTestHypervisorConfiguration", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "BackupGateway":
        '''(experimental) Grants permission to UntagResource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_BGW_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("BackupGateway", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateGatewayInformation")
    def to_update_gateway_information(self) -> "BackupGateway":
        '''(experimental) Grants permission to UpdateGatewayInformation.

        Access Level: Write

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_BGW_UpdateGatewayInformation.html

        :stability: experimental
        '''
        return typing.cast("BackupGateway", jsii.invoke(self, "toUpdateGatewayInformation", []))

    @jsii.member(jsii_name="toUpdateGatewaySoftwareNow")
    def to_update_gateway_software_now(self) -> "BackupGateway":
        '''(experimental) Grants permission to UpdateGatewaySoftwareNow.

        Access Level: Write

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_BGW_UpdateGatewaySoftwareNow.html

        :stability: experimental
        '''
        return typing.cast("BackupGateway", jsii.invoke(self, "toUpdateGatewaySoftwareNow", []))

    @jsii.member(jsii_name="toUpdateHypervisor")
    def to_update_hypervisor(self) -> "BackupGateway":
        '''(experimental) Grants permission to UpdateHypervisor.

        Access Level: Write

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_BGW_UpdateHypervisor.html

        :stability: experimental
        '''
        return typing.cast("BackupGateway", jsii.invoke(self, "toUpdateHypervisor", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__49472f9a1c8d55770bb4d6e300a37efe6f4463c6bd23244e447f89a566fe9cd7)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ffaf83eb49b998ba0e9e5e89d3ea57a70bc90fefe9d3e612b923c91197f002e0)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class BackupStorage(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.BackupStorage",
):
    '''(experimental) Statement provider for service `backup-storage <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsbackupstorage.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `backup-storage <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsbackupstorage.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="toCommitBackupJob")
    def to_commit_backup_job(self) -> "BackupStorage":
        '''(experimental) Grants permission to commit backup job.

        Access Level: Write

        https://docs.aws.amazon.com/aws-backup/latest/devguide/backup-data-transfer.html

        :stability: experimental
        '''
        return typing.cast("BackupStorage", jsii.invoke(self, "toCommitBackupJob", []))

    @jsii.member(jsii_name="toDeleteObjects")
    def to_delete_objects(self) -> "BackupStorage":
        '''(experimental) Grants permission to delete objects.

        Access Level: Write

        https://docs.aws.amazon.com/aws-backup/latest/devguide/backup-data-transfer.html

        :stability: experimental
        '''
        return typing.cast("BackupStorage", jsii.invoke(self, "toDeleteObjects", []))

    @jsii.member(jsii_name="toDescribeBackupJob")
    def to_describe_backup_job(self) -> "BackupStorage":
        '''(experimental) Grants permission to describe backup job.

        Access Level: Write

        https://docs.aws.amazon.com/aws-backup/latest/devguide/backup-data-transfer.html

        :stability: experimental
        '''
        return typing.cast("BackupStorage", jsii.invoke(self, "toDescribeBackupJob", []))

    @jsii.member(jsii_name="toGetBaseBackup")
    def to_get_base_backup(self) -> "BackupStorage":
        '''(experimental) Grants permission to get base backup.

        Access Level: Write

        https://docs.aws.amazon.com/aws-backup/latest/devguide/backup-data-transfer.html

        :stability: experimental
        '''
        return typing.cast("BackupStorage", jsii.invoke(self, "toGetBaseBackup", []))

    @jsii.member(jsii_name="toGetChunk")
    def to_get_chunk(self) -> "BackupStorage":
        '''(experimental) Grants permission to get data from a recovery point for a restore job.

        Access Level: Write

        https://docs.aws.amazon.com/aws-backup/latest/devguide/backup-data-transfer.html

        :stability: experimental
        '''
        return typing.cast("BackupStorage", jsii.invoke(self, "toGetChunk", []))

    @jsii.member(jsii_name="toGetIncrementalBaseBackup")
    def to_get_incremental_base_backup(self) -> "BackupStorage":
        '''(experimental) Grants permission to get incremental base backup.

        Access Level: Write

        https://docs.aws.amazon.com/aws-backup/latest/devguide/backup-data-transfer.html

        :stability: experimental
        '''
        return typing.cast("BackupStorage", jsii.invoke(self, "toGetIncrementalBaseBackup", []))

    @jsii.member(jsii_name="toGetObjectMetadata")
    def to_get_object_metadata(self) -> "BackupStorage":
        '''(experimental) Grants permission to get metadata from a recovery point for a restore job.

        Access Level: Write

        https://docs.aws.amazon.com/aws-backup/latest/devguide/backup-data-transfer.html

        :stability: experimental
        '''
        return typing.cast("BackupStorage", jsii.invoke(self, "toGetObjectMetadata", []))

    @jsii.member(jsii_name="toListChunks")
    def to_list_chunks(self) -> "BackupStorage":
        '''(experimental) Grants permission to list data from a recovery point for a restore job.

        Access Level: Write

        https://docs.aws.amazon.com/aws-backup/latest/devguide/backup-data-transfer.html

        :stability: experimental
        '''
        return typing.cast("BackupStorage", jsii.invoke(self, "toListChunks", []))

    @jsii.member(jsii_name="toListObjects")
    def to_list_objects(self) -> "BackupStorage":
        '''(experimental) Grants permission to list data from a recovery point for a restore job.

        Access Level: Write

        https://docs.aws.amazon.com/aws-backup/latest/devguide/backup-data-transfer.html

        :stability: experimental
        '''
        return typing.cast("BackupStorage", jsii.invoke(self, "toListObjects", []))

    @jsii.member(jsii_name="toMountCapsule")
    def to_mount_capsule(self) -> "BackupStorage":
        '''(experimental) Associates a KMS key to a backup vault.

        Access Level: Write

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_CreateBackupVault.html

        :stability: experimental
        '''
        return typing.cast("BackupStorage", jsii.invoke(self, "toMountCapsule", []))

    @jsii.member(jsii_name="toNotifyObjectComplete")
    def to_notify_object_complete(self) -> "BackupStorage":
        '''(experimental) Grants permission to mark an uploaded data as completed for a backup job.

        Access Level: Write

        https://docs.aws.amazon.com/aws-backup/latest/devguide/backup-data-transfer.html

        :stability: experimental
        '''
        return typing.cast("BackupStorage", jsii.invoke(self, "toNotifyObjectComplete", []))

    @jsii.member(jsii_name="toPutChunk")
    def to_put_chunk(self) -> "BackupStorage":
        '''(experimental) Grants permission to upload data to an AWS Backup-managed recovery point for a backup job.

        Access Level: Write

        https://docs.aws.amazon.com/aws-backup/latest/devguide/backup-data-transfer.html

        :stability: experimental
        '''
        return typing.cast("BackupStorage", jsii.invoke(self, "toPutChunk", []))

    @jsii.member(jsii_name="toPutObject")
    def to_put_object(self) -> "BackupStorage":
        '''(experimental) Grants permission to put object.

        Access Level: Write

        https://docs.aws.amazon.com/aws-backup/latest/devguide/backup-data-transfer.html

        :stability: experimental
        '''
        return typing.cast("BackupStorage", jsii.invoke(self, "toPutObject", []))

    @jsii.member(jsii_name="toStartObject")
    def to_start_object(self) -> "BackupStorage":
        '''(experimental) Grants permission to upload data to an AWS Backup-managed recovery point for a backup job.

        Access Level: Write

        https://docs.aws.amazon.com/aws-backup/latest/devguide/backup-data-transfer.html

        :stability: experimental
        '''
        return typing.cast("BackupStorage", jsii.invoke(self, "toStartObject", []))

    @jsii.member(jsii_name="toUpdateObjectComplete")
    def to_update_object_complete(self) -> "BackupStorage":
        '''(experimental) Grants permission to update object complete.

        Access Level: Write

        https://docs.aws.amazon.com/aws-backup/latest/devguide/backup-data-transfer.html

        :stability: experimental
        '''
        return typing.cast("BackupStorage", jsii.invoke(self, "toUpdateObjectComplete", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__66a561d8730993d0d290cfe41e6317f6674b9e4c3efa069a5329db4eec3c0d47)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__43513d2f912f1391a6cde87aebabfce287a599a6fbb818000c4a20b8b6088332)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Batch(PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Batch"):
    '''(experimental) Statement provider for service `batch <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsbatch.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `batch <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsbatch.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="ifAWSLogsCreateGroup")
    def if_aws_logs_create_group(
        self,
        value: typing.Optional[builtins.bool] = None,
    ) -> "Batch":
        '''(experimental) Filters access by the specified logging driver to determine whether awslogs group will be created for the logs.

        https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsbatch.html#awsbatch-policy-keys

        Applies to actions:

        - .toRegisterJobDefinition()

        :param value: ``true`` or ``false``. **Default:** ``true``

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ec9608521bfb4e2f9123449aa92c6b542bb857e26e698cc3ce15892ddd6722c2)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast("Batch", jsii.invoke(self, "ifAWSLogsCreateGroup", [value]))

    @jsii.member(jsii_name="ifAWSLogsGroup")
    def if_aws_logs_group(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Batch":
        '''(experimental) Filters access by the awslogs group where the logs are located.

        https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsbatch.html#awsbatch-policy-keys

        Applies to actions:

        - .toRegisterJobDefinition()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9476b9d5a1dcf93b8c3503fb27fa72f0e459869a5bfa434f3f254954815e58b8)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Batch", jsii.invoke(self, "ifAWSLogsGroup", [value, operator]))

    @jsii.member(jsii_name="ifAWSLogsRegion")
    def if_aws_logs_region(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Batch":
        '''(experimental) Filters access by the region where the logs are sent to.

        https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsbatch.html#awsbatch-policy-keys

        Applies to actions:

        - .toRegisterJobDefinition()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6ad5b6c0cfa86e80db9e17d5d003cd75243483b3ff123141797203ad4f645c22)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Batch", jsii.invoke(self, "ifAWSLogsRegion", [value, operator]))

    @jsii.member(jsii_name="ifAWSLogsStreamPrefix")
    def if_aws_logs_stream_prefix(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Batch":
        '''(experimental) Filters access by the awslogs log stream prefix.

        https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsbatch.html#awsbatch-policy-keys

        Applies to actions:

        - .toRegisterJobDefinition()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__35e04f90f97ef447d8c13b0355b8707e87c3dd5ce414bb04fd1d0ee489f30207)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Batch", jsii.invoke(self, "ifAWSLogsStreamPrefix", [value, operator]))

    @jsii.member(jsii_name="ifEKSImage")
    def if_eks_image(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Batch":
        '''(experimental) Filters access by the image used to start a container for an Amazon EKS job.

        https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsbatch.html#awsbatch-policy-keys

        Applies to actions:

        - .toRegisterJobDefinition()
        - .toSubmitJob()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__48d4ba5060605dfe1ffc3fc643f7429684a19621f8fb8e3b7a08e86c1f0b3b31)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Batch", jsii.invoke(self, "ifEKSImage", [value, operator]))

    @jsii.member(jsii_name="ifEKSPrivileged")
    def if_eks_privileged(
        self,
        value: typing.Optional[builtins.bool] = None,
    ) -> "Batch":
        '''(experimental) Filters access by the specified privileged parameter value that determines whether the container is given elevated privileges on the host container instance (similar to the root user) for an Amazon EKS job.

        https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsbatch.html#awsbatch-policy-keys

        Applies to actions:

        - .toRegisterJobDefinition()

        :param value: ``true`` or ``false``. **Default:** ``true``

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d6d943a26d48f2dc94c4f7fb4e78d01ac33f82c49be371755d27bd4c90e181b2)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast("Batch", jsii.invoke(self, "ifEKSPrivileged", [value]))

    @jsii.member(jsii_name="ifEKSRunAsGroup")
    def if_eks_run_as_group(
        self,
        value: typing.Union[jsii.Number, typing.Sequence[jsii.Number]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Batch":
        '''(experimental) Filters access by the specified group numeric ID (gid) used to start a container in an Amazon EKS job.

        https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsbatch.html#awsbatch-policy-keys

        Applies to actions:

        - .toRegisterJobDefinition()

        :param value: The value(s) to check.
        :param operator: Works with `numeric operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_Numeric>`_. **Default:** ``NumericEquals``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__30caa91151734bb13a426f3172d80dca4ea228911de3222794c3ede03a49f52c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Batch", jsii.invoke(self, "ifEKSRunAsGroup", [value, operator]))

    @jsii.member(jsii_name="ifEKSRunAsUser")
    def if_eks_run_as_user(
        self,
        value: typing.Union[jsii.Number, typing.Sequence[jsii.Number]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Batch":
        '''(experimental) Filters access by the specified user numeric ID (uid) used to start a a container in an Amazon EKS job.

        https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsbatch.html#awsbatch-policy-keys

        Applies to actions:

        - .toRegisterJobDefinition()

        :param value: The value(s) to check.
        :param operator: Works with `numeric operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_Numeric>`_. **Default:** ``NumericEquals``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__51b1e9737f75372c8878fe23943e3b60050f27b1efbe6ff6dc0f7e72b5ab69dc)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Batch", jsii.invoke(self, "ifEKSRunAsUser", [value, operator]))

    @jsii.member(jsii_name="ifEKSServiceAccountName")
    def if_eks_service_account_name(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Batch":
        '''(experimental) Filters access by the name of the service account used to run the pod for an Amazon EKS job.

        https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsbatch.html#awsbatch-policy-keys

        Applies to actions:

        - .toRegisterJobDefinition()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fd686527899790ffd578c3fe204cccdfb6682f4df4d63c39265359b3b2814b5a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Batch", jsii.invoke(self, "ifEKSServiceAccountName", [value, operator]))

    @jsii.member(jsii_name="ifImage")
    def if_image(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Batch":
        '''(experimental) Filters access by the image used to start a container.

        https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsbatch.html#awsbatch-policy-keys

        Applies to actions:

        - .toRegisterJobDefinition()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__94124a7e82a5eae047dafa9499726361ca368b2c6a41a264348fcc83cc41b603)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Batch", jsii.invoke(self, "ifImage", [value, operator]))

    @jsii.member(jsii_name="ifLogDriver")
    def if_log_driver(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Batch":
        '''(experimental) Filters access by the log driver used for the container.

        https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsbatch.html#awsbatch-policy-keys

        Applies to actions:

        - .toRegisterJobDefinition()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__704faf908872d9d2182c657b67e49f720915715d878863ce25ca453e50504f1b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Batch", jsii.invoke(self, "ifLogDriver", [value, operator]))

    @jsii.member(jsii_name="ifPrivileged")
    def if_privileged(self, value: typing.Optional[builtins.bool] = None) -> "Batch":
        '''(experimental) Filters access by the specified privileged parameter value that determines whether the container is given elevated privileges on the host container instance (similar to the root user).

        https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsbatch.html#awsbatch-policy-keys

        Applies to actions:

        - .toRegisterJobDefinition()

        :param value: ``true`` or ``false``. **Default:** ``true``

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0f5162223e4a689a45f3590e83d5edfad9454e6920277ce44c05eedd922b9567)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast("Batch", jsii.invoke(self, "ifPrivileged", [value]))

    @jsii.member(jsii_name="ifShareIdentifier")
    def if_share_identifier(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Batch":
        '''(experimental) Filters access by the shareIdentifier used inside submit job.

        https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsbatch.html#awsbatch-policy-keys

        Applies to actions:

        - .toSubmitJob()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__afe719b2f4d4c21e678785d2df8a6fbca5dedcda0b80bf4653d32397c8fdd90c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Batch", jsii.invoke(self, "ifShareIdentifier", [value, operator]))

    @jsii.member(jsii_name="ifUser")
    def if_user(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Batch":
        '''(experimental) Filters access by user name or numeric uid used inside the container.

        https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsbatch.html#awsbatch-policy-keys

        Applies to actions:

        - .toRegisterJobDefinition()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__427bb7a7276d77e1c768e41c0522b72f55b0c8c9822762d7afc5947e3689e77f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Batch", jsii.invoke(self, "ifUser", [value, operator]))

    @jsii.member(jsii_name="onComputeEnvironment")
    def on_compute_environment(
        self,
        compute_environment_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Batch":
        '''(experimental) Adds a resource of type compute-environment to the statement.

        https://docs.aws.amazon.com/batch/latest/userguide/compute_environments.html

        :param compute_environment_name: - Identifier for the computeEnvironmentName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__aa34b991872f8e43785b5a018c48c74229fcfa8231c985efb14b314c94d1ddf6)
            check_type(argname="argument compute_environment_name", value=compute_environment_name, expected_type=type_hints["compute_environment_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Batch", jsii.invoke(self, "onComputeEnvironment", [compute_environment_name, account, region, partition]))

    @jsii.member(jsii_name="onJob")
    def on_job(
        self,
        job_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Batch":
        '''(experimental) Adds a resource of type job to the statement.

        https://docs.aws.amazon.com/batch/latest/userguide/jobs.html

        :param job_id: - Identifier for the jobId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__77097cd25e90707a60bb38f38c580b6c14a437de96e5d108e17c4241d8f0571d)
            check_type(argname="argument job_id", value=job_id, expected_type=type_hints["job_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Batch", jsii.invoke(self, "onJob", [job_id, account, region, partition]))

    @jsii.member(jsii_name="onJobDefinition")
    def on_job_definition(
        self,
        job_definition_name: builtins.str,
        revision: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Batch":
        '''(experimental) Adds a resource of type job-definition to the statement.

        https://docs.aws.amazon.com/batch/latest/userguide/job_definitions.html

        :param job_definition_name: - Identifier for the jobDefinitionName.
        :param revision: - Identifier for the revision.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c571b170a71237b146044766b701c54667637a1cee782e55f7df35649ab1a3c8)
            check_type(argname="argument job_definition_name", value=job_definition_name, expected_type=type_hints["job_definition_name"])
            check_type(argname="argument revision", value=revision, expected_type=type_hints["revision"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Batch", jsii.invoke(self, "onJobDefinition", [job_definition_name, revision, account, region, partition]))

    @jsii.member(jsii_name="onJobQueue")
    def on_job_queue(
        self,
        job_queue_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Batch":
        '''(experimental) Adds a resource of type job-queue to the statement.

        https://docs.aws.amazon.com/batch/latest/userguide/job_queues.html

        :param job_queue_name: - Identifier for the jobQueueName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0e9c9edd7d90d7d2a7a64ae7a3f27cf8c57532f1d7211aab262fab3de015a080)
            check_type(argname="argument job_queue_name", value=job_queue_name, expected_type=type_hints["job_queue_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Batch", jsii.invoke(self, "onJobQueue", [job_queue_name, account, region, partition]))

    @jsii.member(jsii_name="onSchedulingPolicy")
    def on_scheduling_policy(
        self,
        scheduling_policy_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Batch":
        '''(experimental) Adds a resource of type scheduling-policy to the statement.

        https://docs.aws.amazon.com/batch/latest/userguide/scheduling-policies.html

        :param scheduling_policy_name: - Identifier for the schedulingPolicyName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4bbb8b8ecf4c5bb21dcc213433e86daedf32feda7af6249c9cd840c2c97d4947)
            check_type(argname="argument scheduling_policy_name", value=scheduling_policy_name, expected_type=type_hints["scheduling_policy_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Batch", jsii.invoke(self, "onSchedulingPolicy", [scheduling_policy_name, account, region, partition]))

    @jsii.member(jsii_name="toCancelJob")
    def to_cancel_job(self) -> "Batch":
        '''(experimental) Grants permission to cancel a job in an AWS Batch job queue in your account.

        Access Level: Write

        https://docs.aws.amazon.com/batch/latest/APIReference/API_CancelJob.html

        :stability: experimental
        '''
        return typing.cast("Batch", jsii.invoke(self, "toCancelJob", []))

    @jsii.member(jsii_name="toCreateComputeEnvironment")
    def to_create_compute_environment(self) -> "Batch":
        '''(experimental) Grants permission to create an AWS Batch compute environment in your account.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/batch/latest/APIReference/API_CreateComputeEnvironment.html

        :stability: experimental
        '''
        return typing.cast("Batch", jsii.invoke(self, "toCreateComputeEnvironment", []))

    @jsii.member(jsii_name="toCreateJobQueue")
    def to_create_job_queue(self) -> "Batch":
        '''(experimental) Grants permission to create an AWS Batch job queue in your account.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/batch/latest/APIReference/API_CreateJobQueue.html

        :stability: experimental
        '''
        return typing.cast("Batch", jsii.invoke(self, "toCreateJobQueue", []))

    @jsii.member(jsii_name="toCreateSchedulingPolicy")
    def to_create_scheduling_policy(self) -> "Batch":
        '''(experimental) Grants permission to create an AWS Batch scheduling policy in your account.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/batch/latest/APIReference/API_CreateSchedulingPolicy.html

        :stability: experimental
        '''
        return typing.cast("Batch", jsii.invoke(self, "toCreateSchedulingPolicy", []))

    @jsii.member(jsii_name="toDeleteComputeEnvironment")
    def to_delete_compute_environment(self) -> "Batch":
        '''(experimental) Grants permission to delete an AWS Batch compute environment in your account.

        Access Level: Write

        https://docs.aws.amazon.com/batch/latest/APIReference/API_DeleteComputeEnvironment.html

        :stability: experimental
        '''
        return typing.cast("Batch", jsii.invoke(self, "toDeleteComputeEnvironment", []))

    @jsii.member(jsii_name="toDeleteJobQueue")
    def to_delete_job_queue(self) -> "Batch":
        '''(experimental) Grants permission to delete an AWS Batch job queue in your account.

        Access Level: Write

        https://docs.aws.amazon.com/batch/latest/APIReference/API_DeleteJobQueue.html

        :stability: experimental
        '''
        return typing.cast("Batch", jsii.invoke(self, "toDeleteJobQueue", []))

    @jsii.member(jsii_name="toDeleteSchedulingPolicy")
    def to_delete_scheduling_policy(self) -> "Batch":
        '''(experimental) Grants permission to delete an AWS Batch scheduling policy in your account.

        Access Level: Write

        https://docs.aws.amazon.com/batch/latest/APIReference/API_DeleteSchedulingPolicy.html

        :stability: experimental
        '''
        return typing.cast("Batch", jsii.invoke(self, "toDeleteSchedulingPolicy", []))

    @jsii.member(jsii_name="toDeregisterJobDefinition")
    def to_deregister_job_definition(self) -> "Batch":
        '''(experimental) Grants permission to deregister an AWS Batch job definition in your account.

        Access Level: Write

        https://docs.aws.amazon.com/batch/latest/APIReference/API_DeregisterJobDefinition.html

        :stability: experimental
        '''
        return typing.cast("Batch", jsii.invoke(self, "toDeregisterJobDefinition", []))

    @jsii.member(jsii_name="toDescribeComputeEnvironments")
    def to_describe_compute_environments(self) -> "Batch":
        '''(experimental) Grants permission to describe one or more AWS Batch compute environments in your account.

        Access Level: Read

        https://docs.aws.amazon.com/batch/latest/APIReference/API_DescribeComputeEnvironments.html

        :stability: experimental
        '''
        return typing.cast("Batch", jsii.invoke(self, "toDescribeComputeEnvironments", []))

    @jsii.member(jsii_name="toDescribeJobDefinitions")
    def to_describe_job_definitions(self) -> "Batch":
        '''(experimental) Grants permission to describe one or more AWS Batch job definitions in your account.

        Access Level: Read

        https://docs.aws.amazon.com/batch/latest/APIReference/API_DescribeJobDefinitions.html

        :stability: experimental
        '''
        return typing.cast("Batch", jsii.invoke(self, "toDescribeJobDefinitions", []))

    @jsii.member(jsii_name="toDescribeJobQueues")
    def to_describe_job_queues(self) -> "Batch":
        '''(experimental) Grants permission to describe one or more AWS Batch job queues in your account.

        Access Level: Read

        https://docs.aws.amazon.com/batch/latest/APIReference/API_DescribeJobQueues.html

        :stability: experimental
        '''
        return typing.cast("Batch", jsii.invoke(self, "toDescribeJobQueues", []))

    @jsii.member(jsii_name="toDescribeJobs")
    def to_describe_jobs(self) -> "Batch":
        '''(experimental) Grants permission to describe a list of AWS Batch jobs in your account.

        Access Level: Read

        https://docs.aws.amazon.com/batch/latest/APIReference/API_DescribeJobs.html

        :stability: experimental
        '''
        return typing.cast("Batch", jsii.invoke(self, "toDescribeJobs", []))

    @jsii.member(jsii_name="toDescribeSchedulingPolicies")
    def to_describe_scheduling_policies(self) -> "Batch":
        '''(experimental) Grants permission to describe one or more AWS Batch scheduling policies in your account.

        Access Level: Read

        https://docs.aws.amazon.com/batch/latest/APIReference/API_DescribeSchedulingPolicies.html

        :stability: experimental
        '''
        return typing.cast("Batch", jsii.invoke(self, "toDescribeSchedulingPolicies", []))

    @jsii.member(jsii_name="toListJobs")
    def to_list_jobs(self) -> "Batch":
        '''(experimental) Grants permission to list jobs for a specified AWS Batch job queue in your account.

        Access Level: List

        https://docs.aws.amazon.com/batch/latest/APIReference/API_ListJobs.html

        :stability: experimental
        '''
        return typing.cast("Batch", jsii.invoke(self, "toListJobs", []))

    @jsii.member(jsii_name="toListSchedulingPolicies")
    def to_list_scheduling_policies(self) -> "Batch":
        '''(experimental) Grants permission to list AWS Batch scheduling policies in your account.

        Access Level: Read

        https://docs.aws.amazon.com/batch/latest/APIReference/API_ListSchedulingPolicies.html

        :stability: experimental
        '''
        return typing.cast("Batch", jsii.invoke(self, "toListSchedulingPolicies", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Batch":
        '''(experimental) Grants permission to list tags for an AWS Batch resource in your account.

        Access Level: Read

        https://docs.aws.amazon.com/batch/latest/APIReference/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("Batch", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toRegisterJobDefinition")
    def to_register_job_definition(self) -> "Batch":
        '''(experimental) Grants permission to register an AWS Batch job definition in your account.

        Access Level: Write

        Possible conditions:

        - .ifUser()
        - .ifPrivileged()
        - .ifImage()
        - .ifLogDriver()
        - .ifAWSLogsGroup()
        - .ifAWSLogsRegion()
        - .ifAWSLogsStreamPrefix()
        - .ifAWSLogsCreateGroup()
        - .ifEKSServiceAccountName()
        - .ifEKSImage()
        - .ifEKSRunAsUser()
        - .ifEKSRunAsGroup()
        - .ifEKSPrivileged()
        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/batch/latest/APIReference/API_RegisterJobDefinition.html

        :stability: experimental
        '''
        return typing.cast("Batch", jsii.invoke(self, "toRegisterJobDefinition", []))

    @jsii.member(jsii_name="toSubmitJob")
    def to_submit_job(self) -> "Batch":
        '''(experimental) Grants permission to submit an AWS Batch job from a job definition in your account.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifShareIdentifier()
        - .ifEKSImage()

        https://docs.aws.amazon.com/batch/latest/APIReference/API_SubmitJob.html

        :stability: experimental
        '''
        return typing.cast("Batch", jsii.invoke(self, "toSubmitJob", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Batch":
        '''(experimental) Grants permission to tag an AWS Batch resource in your account.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/batch/latest/APIReference/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("Batch", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toTerminateJob")
    def to_terminate_job(self) -> "Batch":
        '''(experimental) Grants permission to terminate a job in an AWS Batch job queue in your account.

        Access Level: Write

        https://docs.aws.amazon.com/batch/latest/APIReference/API_TerminateJob.html

        :stability: experimental
        '''
        return typing.cast("Batch", jsii.invoke(self, "toTerminateJob", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Batch":
        '''(experimental) Grants permission to untag an AWS Batch resource in your account.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/batch/latest/APIReference/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("Batch", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateComputeEnvironment")
    def to_update_compute_environment(self) -> "Batch":
        '''(experimental) Grants permission to update an AWS Batch compute environment in your account.

        Access Level: Write

        https://docs.aws.amazon.com/batch/latest/APIReference/API_UpdateComputeEnvironment.html

        :stability: experimental
        '''
        return typing.cast("Batch", jsii.invoke(self, "toUpdateComputeEnvironment", []))

    @jsii.member(jsii_name="toUpdateJobQueue")
    def to_update_job_queue(self) -> "Batch":
        '''(experimental) Grants permission to update an AWS Batch job queue in your account.

        Access Level: Write

        https://docs.aws.amazon.com/batch/latest/APIReference/API_UpdateJobQueue.html

        :stability: experimental
        '''
        return typing.cast("Batch", jsii.invoke(self, "toUpdateJobQueue", []))

    @jsii.member(jsii_name="toUpdateSchedulingPolicy")
    def to_update_scheduling_policy(self) -> "Batch":
        '''(experimental) Grants permission to update an AWS Batch scheduling policy in your account.

        Access Level: Write

        https://docs.aws.amazon.com/batch/latest/APIReference/API_UpdateSchedulingPolicy.html

        :stability: experimental
        '''
        return typing.cast("Batch", jsii.invoke(self, "toUpdateSchedulingPolicy", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c009528ec48afc716d31d35c4ca53e220cf46b8ffc692736579cd563240a4480)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__09a5c5af90f9e2c1181ddda9589e4ec0400d9ef7969643788ea89819fdb7ae9b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Billing(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Billing",
):
    '''(experimental) Statement provider for service `billing <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsbilling_.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `billing <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsbilling_.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="toListBillingViews")
    def to_list_billing_views(self) -> "Billing":
        '''(experimental) Grants permission to get billing information for your proforma billing groups.

        Access Level: Read

        https://docs.aws.amazon.com/awsaccountbilling/latest/aboutv2/billing-permissions-ref.html#user-permissions

        :stability: experimental
        '''
        return typing.cast("Billing", jsii.invoke(self, "toListBillingViews", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0a2f2fc83e05fd0378d1971a3e75b8fa04ac735b9ca58f9d13d4672df59b799c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d0bde701a5994f8113d61079fab496ec4d7916d15ca2595101ae619cf63cf936)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Billingconductor(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Billingconductor",
):
    '''(experimental) Statement provider for service `billingconductor <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsbillingconductor.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `billingconductor <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsbillingconductor.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onBillinggroup")
    def on_billinggroup(
        self,
        billing_group_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Billingconductor":
        '''(experimental) Adds a resource of type billinggroup to the statement.

        https://docs.aws.amazon.com/billingconductor/latest/userguide/understanding-abc.html

        :param billing_group_id: - Identifier for the billingGroupId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e16d948b63014dfb25de6526cabac9f825bb49d331a3337c76d331dc2f9d7ac4)
            check_type(argname="argument billing_group_id", value=billing_group_id, expected_type=type_hints["billing_group_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Billingconductor", jsii.invoke(self, "onBillinggroup", [billing_group_id, account, partition]))

    @jsii.member(jsii_name="onCustomlineitem")
    def on_customlineitem(
        self,
        custom_line_item_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Billingconductor":
        '''(experimental) Adds a resource of type customlineitem to the statement.

        https://docs.aws.amazon.com/billingconductor/latest/userguide/understanding-abc.html

        :param custom_line_item_id: - Identifier for the customLineItemId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5e82fcb645113169e0afeb52e7f94ae834fee4ed59f60631871ef336ee4b751c)
            check_type(argname="argument custom_line_item_id", value=custom_line_item_id, expected_type=type_hints["custom_line_item_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Billingconductor", jsii.invoke(self, "onCustomlineitem", [custom_line_item_id, account, partition]))

    @jsii.member(jsii_name="onPricingplan")
    def on_pricingplan(
        self,
        pricing_plan_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Billingconductor":
        '''(experimental) Adds a resource of type pricingplan to the statement.

        https://docs.aws.amazon.com/billingconductor/latest/userguide/understanding-abc.html

        :param pricing_plan_id: - Identifier for the pricingPlanId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b34320227b512212d3d385aa50d9ba0362227dec758401754d7acd09f47f416d)
            check_type(argname="argument pricing_plan_id", value=pricing_plan_id, expected_type=type_hints["pricing_plan_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Billingconductor", jsii.invoke(self, "onPricingplan", [pricing_plan_id, account, partition]))

    @jsii.member(jsii_name="onPricingrule")
    def on_pricingrule(
        self,
        pricing_rule_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Billingconductor":
        '''(experimental) Adds a resource of type pricingrule to the statement.

        https://docs.aws.amazon.com/billingconductor/latest/userguide/understanding-abc.html

        :param pricing_rule_id: - Identifier for the pricingRuleId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f46c715abf7cfce97a9ff94510217b83140c6a165a19fdbe204b81bbb09dde77)
            check_type(argname="argument pricing_rule_id", value=pricing_rule_id, expected_type=type_hints["pricing_rule_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Billingconductor", jsii.invoke(self, "onPricingrule", [pricing_rule_id, account, partition]))

    @jsii.member(jsii_name="toAssociateAccounts")
    def to_associate_accounts(self) -> "Billingconductor":
        '''(experimental) Grants permission to associate between one and 30 accounts to a billing group.

        Access Level: Write

        https://docs.aws.amazon.com/billingconductor/latest/APIReference/API_AssociateAccounts.html

        :stability: experimental
        '''
        return typing.cast("Billingconductor", jsii.invoke(self, "toAssociateAccounts", []))

    @jsii.member(jsii_name="toAssociatePricingRules")
    def to_associate_pricing_rules(self) -> "Billingconductor":
        '''(experimental) Grants permission to associate pricing rules.

        Access Level: Write

        https://docs.aws.amazon.com/billingconductor/latest/APIReference/API_AssociatePricingRules.html

        :stability: experimental
        '''
        return typing.cast("Billingconductor", jsii.invoke(self, "toAssociatePricingRules", []))

    @jsii.member(jsii_name="toBatchAssociateResourcesToCustomLineItem")
    def to_batch_associate_resources_to_custom_line_item(self) -> "Billingconductor":
        '''(experimental) Grants permission to batch associate resources to a percentage custom line item.

        Access Level: Write

        https://docs.aws.amazon.com/billingconductor/latest/APIReference/API_BatchAssociateResourcesToCustomLineItem.html

        :stability: experimental
        '''
        return typing.cast("Billingconductor", jsii.invoke(self, "toBatchAssociateResourcesToCustomLineItem", []))

    @jsii.member(jsii_name="toBatchDisassociateResourcesFromCustomLineItem")
    def to_batch_disassociate_resources_from_custom_line_item(
        self,
    ) -> "Billingconductor":
        '''(experimental) Grants permission to batch disassociate resources from a percentage custom line item.

        Access Level: Write

        https://docs.aws.amazon.com/billingconductor/latest/APIReference/API_BatchDisassociateResourcesFromCustomLineItem.html

        :stability: experimental
        '''
        return typing.cast("Billingconductor", jsii.invoke(self, "toBatchDisassociateResourcesFromCustomLineItem", []))

    @jsii.member(jsii_name="toCreateBillingGroup")
    def to_create_billing_group(self) -> "Billingconductor":
        '''(experimental) Grants permission to create a billing group.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/billingconductor/latest/APIReference/API_CreateBillingGroup.html

        :stability: experimental
        '''
        return typing.cast("Billingconductor", jsii.invoke(self, "toCreateBillingGroup", []))

    @jsii.member(jsii_name="toCreateCustomLineItem")
    def to_create_custom_line_item(self) -> "Billingconductor":
        '''(experimental) Grants permission to create a custom line item.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/billingconductor/latest/APIReference/API_CreateCustomLineItem.html

        :stability: experimental
        '''
        return typing.cast("Billingconductor", jsii.invoke(self, "toCreateCustomLineItem", []))

    @jsii.member(jsii_name="toCreatePricingPlan")
    def to_create_pricing_plan(self) -> "Billingconductor":
        '''(experimental) Grants permission to create a pricing plan.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/billingconductor/latest/APIReference/API_CreatePricingPlan.html

        :stability: experimental
        '''
        return typing.cast("Billingconductor", jsii.invoke(self, "toCreatePricingPlan", []))

    @jsii.member(jsii_name="toCreatePricingRule")
    def to_create_pricing_rule(self) -> "Billingconductor":
        '''(experimental) Grants permission to create a pricing rule.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/billingconductor/latest/APIReference/API_CreatePricingRule.html

        :stability: experimental
        '''
        return typing.cast("Billingconductor", jsii.invoke(self, "toCreatePricingRule", []))

    @jsii.member(jsii_name="toDeleteBillingGroup")
    def to_delete_billing_group(self) -> "Billingconductor":
        '''(experimental) Grants permission to delete a billing group.

        Access Level: Write

        https://docs.aws.amazon.com/billingconductor/latest/APIReference/API_DeleteBillingGroup.html

        :stability: experimental
        '''
        return typing.cast("Billingconductor", jsii.invoke(self, "toDeleteBillingGroup", []))

    @jsii.member(jsii_name="toDeleteCustomLineItem")
    def to_delete_custom_line_item(self) -> "Billingconductor":
        '''(experimental) Grants permission to delete a custom line item.

        Access Level: Write

        https://docs.aws.amazon.com/billingconductor/latest/APIReference/API_DeleteCustomLineItem.html

        :stability: experimental
        '''
        return typing.cast("Billingconductor", jsii.invoke(self, "toDeleteCustomLineItem", []))

    @jsii.member(jsii_name="toDeletePricingPlan")
    def to_delete_pricing_plan(self) -> "Billingconductor":
        '''(experimental) Grants permission to delete a pricing plan.

        Access Level: Write

        https://docs.aws.amazon.com/billingconductor/latest/APIReference/API_DeletePricingPlan.html

        :stability: experimental
        '''
        return typing.cast("Billingconductor", jsii.invoke(self, "toDeletePricingPlan", []))

    @jsii.member(jsii_name="toDeletePricingRule")
    def to_delete_pricing_rule(self) -> "Billingconductor":
        '''(experimental) Grants permission to delete a pricing rule.

        Access Level: Write

        https://docs.aws.amazon.com/billingconductor/latest/APIReference/API_DeletePricingRule.html

        :stability: experimental
        '''
        return typing.cast("Billingconductor", jsii.invoke(self, "toDeletePricingRule", []))

    @jsii.member(jsii_name="toDisassociateAccounts")
    def to_disassociate_accounts(self) -> "Billingconductor":
        '''(experimental) Grants permission to detach between one and 30 accounts from a billing group.

        Access Level: Write

        https://docs.aws.amazon.com/billingconductor/latest/APIReference/API_DisassociateAccounts.html

        :stability: experimental
        '''
        return typing.cast("Billingconductor", jsii.invoke(self, "toDisassociateAccounts", []))

    @jsii.member(jsii_name="toDisassociatePricingRules")
    def to_disassociate_pricing_rules(self) -> "Billingconductor":
        '''(experimental) Grants permission to disassociate pricing rules.

        Access Level: Write

        https://docs.aws.amazon.com/billingconductor/latest/APIReference/API_DisassociatePricingRules.html

        :stability: experimental
        '''
        return typing.cast("Billingconductor", jsii.invoke(self, "toDisassociatePricingRules", []))

    @jsii.member(jsii_name="toListAccountAssociations")
    def to_list_account_associations(self) -> "Billingconductor":
        '''(experimental) Grants permission to list the linked accounts of the payer account for the given billing period while also providing the billing group the linked accounts belong to.

        Access Level: List

        https://docs.aws.amazon.com/billingconductor/latest/APIReference/API_ListAccountAssociations.html

        :stability: experimental
        '''
        return typing.cast("Billingconductor", jsii.invoke(self, "toListAccountAssociations", []))

    @jsii.member(jsii_name="toListBillingGroupCostReports")
    def to_list_billing_group_cost_reports(self) -> "Billingconductor":
        '''(experimental) Grants permission to view the billing group cost report.

        Access Level: Read

        https://docs.aws.amazon.com/billingconductor/latest/APIReference/API_ListBillingGroupCostReports.html

        :stability: experimental
        '''
        return typing.cast("Billingconductor", jsii.invoke(self, "toListBillingGroupCostReports", []))

    @jsii.member(jsii_name="toListBillingGroups")
    def to_list_billing_groups(self) -> "Billingconductor":
        '''(experimental) Grants permission to view the details of billing groups.

        Access Level: Read

        https://docs.aws.amazon.com/billingconductor/latest/APIReference/API_ListBillingGroups.html

        :stability: experimental
        '''
        return typing.cast("Billingconductor", jsii.invoke(self, "toListBillingGroups", []))

    @jsii.member(jsii_name="toListCustomLineItems")
    def to_list_custom_line_items(self) -> "Billingconductor":
        '''(experimental) Grants permission to view custom line item details.

        Access Level: Read

        https://docs.aws.amazon.com/billingconductor/latest/APIReference/API_ListCustomLineItems.html

        :stability: experimental
        '''
        return typing.cast("Billingconductor", jsii.invoke(self, "toListCustomLineItems", []))

    @jsii.member(jsii_name="toListCustomLineItemVersions")
    def to_list_custom_line_item_versions(self) -> "Billingconductor":
        '''(experimental) Grants permission to view custom line item versions.

        Access Level: Read

        https://docs.aws.amazon.com/billingconductor/latest/APIReference/API_ListCustomLineItemVersions.html

        :stability: experimental
        '''
        return typing.cast("Billingconductor", jsii.invoke(self, "toListCustomLineItemVersions", []))

    @jsii.member(jsii_name="toListPricingPlans")
    def to_list_pricing_plans(self) -> "Billingconductor":
        '''(experimental) Grants permission to view the pricing plans details.

        Access Level: Read

        https://docs.aws.amazon.com/billingconductor/latest/APIReference/API_ListPricingPlans.html

        :stability: experimental
        '''
        return typing.cast("Billingconductor", jsii.invoke(self, "toListPricingPlans", []))

    @jsii.member(jsii_name="toListPricingPlansAssociatedWithPricingRule")
    def to_list_pricing_plans_associated_with_pricing_rule(self) -> "Billingconductor":
        '''(experimental) Grants permission to list pricing plans associated with a pricing rule.

        Access Level: List

        https://docs.aws.amazon.com/billingconductor/latest/APIReference/API_ListPricingPlansAssociatedWithPricingRule.html

        :stability: experimental
        '''
        return typing.cast("Billingconductor", jsii.invoke(self, "toListPricingPlansAssociatedWithPricingRule", []))

    @jsii.member(jsii_name="toListPricingRules")
    def to_list_pricing_rules(self) -> "Billingconductor":
        '''(experimental) Grants permission to view pricing rules details.

        Access Level: Read

        https://docs.aws.amazon.com/billingconductor/latest/APIReference/API_ListPricingRules.html

        :stability: experimental
        '''
        return typing.cast("Billingconductor", jsii.invoke(self, "toListPricingRules", []))

    @jsii.member(jsii_name="toListPricingRulesAssociatedToPricingPlan")
    def to_list_pricing_rules_associated_to_pricing_plan(self) -> "Billingconductor":
        '''(experimental) Grants permission to list pricing rules associated to a pricing plan.

        Access Level: List

        https://docs.aws.amazon.com/billingconductor/latest/APIReference/API_ListPricingRulesAssociatedToPricingPlan.html

        :stability: experimental
        '''
        return typing.cast("Billingconductor", jsii.invoke(self, "toListPricingRulesAssociatedToPricingPlan", []))

    @jsii.member(jsii_name="toListResourcesAssociatedToCustomLineItem")
    def to_list_resources_associated_to_custom_line_item(self) -> "Billingconductor":
        '''(experimental) Grants permission to list resources associated to a percentage custom line item.

        Access Level: List

        https://docs.aws.amazon.com/billingconductor/latest/APIReference/API_ListResourcesAssociatedToCustomLineItem.html

        :stability: experimental
        '''
        return typing.cast("Billingconductor", jsii.invoke(self, "toListResourcesAssociatedToCustomLineItem", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Billingconductor":
        '''(experimental) Grants permission to list tags of a resource.

        Access Level: Read

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/billingconductor/latest/APIReference/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("Billingconductor", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Billingconductor":
        '''(experimental) Grants permission to tag a resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/billingconductor/latest/APIReference/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("Billingconductor", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Billingconductor":
        '''(experimental) Grants permission to untag a resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/billingconductor/latest/APIReference/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("Billingconductor", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateBillingGroup")
    def to_update_billing_group(self) -> "Billingconductor":
        '''(experimental) Grants permission to update a billing group.

        Access Level: Write

        https://docs.aws.amazon.com/billingconductor/latest/APIReference/API_UpdateBillingGroup.html

        :stability: experimental
        '''
        return typing.cast("Billingconductor", jsii.invoke(self, "toUpdateBillingGroup", []))

    @jsii.member(jsii_name="toUpdateCustomLineItem")
    def to_update_custom_line_item(self) -> "Billingconductor":
        '''(experimental) Grants permission to update a custom line item.

        Access Level: Write

        https://docs.aws.amazon.com/billingconductor/latest/APIReference/API_UpdateCustomLineItem.html

        :stability: experimental
        '''
        return typing.cast("Billingconductor", jsii.invoke(self, "toUpdateCustomLineItem", []))

    @jsii.member(jsii_name="toUpdatePricingPlan")
    def to_update_pricing_plan(self) -> "Billingconductor":
        '''(experimental) Grants permission to update a pricing plan.

        Access Level: Write

        https://docs.aws.amazon.com/billingconductor/latest/APIReference/API_UpdatePricingPlan.html

        :stability: experimental
        '''
        return typing.cast("Billingconductor", jsii.invoke(self, "toUpdatePricingPlan", []))

    @jsii.member(jsii_name="toUpdatePricingRule")
    def to_update_pricing_rule(self) -> "Billingconductor":
        '''(experimental) Grants permission to update a pricing rule.

        Access Level: Write

        https://docs.aws.amazon.com/billingconductor/latest/APIReference/API_UpdatePricingRule.html

        :stability: experimental
        '''
        return typing.cast("Billingconductor", jsii.invoke(self, "toUpdatePricingRule", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6ad3a628e2e211e9c22f7ed65b041bbadb72793f5097babd6f5085d2781ec24f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1929a6ab19a8d8802150ba556f2c45e77103a78c1aa5e3a7b7886437a2baecb7)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Braket(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Braket",
):
    '''(experimental) Statement provider for service `braket <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonbraket.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `braket <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonbraket.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onJob")
    def on_job(
        self,
        job_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Braket":
        '''(experimental) Adds a resource of type job to the statement.

        https://docs.aws.amazon.com/braket/latest/developerguide/braket-manage-access.html#resources

        :param job_name: - Identifier for the jobName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__84ea013f7a29e531d24f2b414018258127ee867b069739d8ea59a59b4a9dd990)
            check_type(argname="argument job_name", value=job_name, expected_type=type_hints["job_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Braket", jsii.invoke(self, "onJob", [job_name, account, region, partition]))

    @jsii.member(jsii_name="onQuantumTask")
    def on_quantum_task(
        self,
        random_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Braket":
        '''(experimental) Adds a resource of type quantum-task to the statement.

        https://docs.aws.amazon.com/braket/latest/developerguide/braket-manage-access.html#resources

        :param random_id: - Identifier for the randomId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__93145b095e055102ef55d008d14cf0ff585f7a70bb4717c5f178bd97dd665526)
            check_type(argname="argument random_id", value=random_id, expected_type=type_hints["random_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Braket", jsii.invoke(self, "onQuantumTask", [random_id, account, region, partition]))

    @jsii.member(jsii_name="toCancelJob")
    def to_cancel_job(self) -> "Braket":
        '''(experimental) Grants permission to cancel a job.

        Access Level: Write

        https://docs.aws.amazon.com/braket/latest/APIReference/API_CancelJob.html

        :stability: experimental
        '''
        return typing.cast("Braket", jsii.invoke(self, "toCancelJob", []))

    @jsii.member(jsii_name="toCancelQuantumTask")
    def to_cancel_quantum_task(self) -> "Braket":
        '''(experimental) Grants permission to cancel a quantum task.

        Access Level: Write

        https://docs.aws.amazon.com/braket/latest/APIReference/API_CancelQuantumTask.html

        :stability: experimental
        '''
        return typing.cast("Braket", jsii.invoke(self, "toCancelQuantumTask", []))

    @jsii.member(jsii_name="toCreateJob")
    def to_create_job(self) -> "Braket":
        '''(experimental) Grants permission to create a job.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/braket/latest/APIReference/API_CreateJob.html

        :stability: experimental
        '''
        return typing.cast("Braket", jsii.invoke(self, "toCreateJob", []))

    @jsii.member(jsii_name="toCreateQuantumTask")
    def to_create_quantum_task(self) -> "Braket":
        '''(experimental) Grants permission to create a quantum task.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/braket/latest/APIReference/API_CreateQuantumTask.html

        :stability: experimental
        '''
        return typing.cast("Braket", jsii.invoke(self, "toCreateQuantumTask", []))

    @jsii.member(jsii_name="toGetDevice")
    def to_get_device(self) -> "Braket":
        '''(experimental) Grants permission to retrieve information about the devices available in Amazon Braket.

        Access Level: Read

        https://docs.aws.amazon.com/braket/latest/APIReference/API_GetDevice.html

        :stability: experimental
        '''
        return typing.cast("Braket", jsii.invoke(self, "toGetDevice", []))

    @jsii.member(jsii_name="toGetJob")
    def to_get_job(self) -> "Braket":
        '''(experimental) Grants permission to retrieve jobs.

        Access Level: Read

        https://docs.aws.amazon.com/braket/latest/APIReference/API_Job.html

        :stability: experimental
        '''
        return typing.cast("Braket", jsii.invoke(self, "toGetJob", []))

    @jsii.member(jsii_name="toGetQuantumTask")
    def to_get_quantum_task(self) -> "Braket":
        '''(experimental) Grants permission to retrieve quantum tasks.

        Access Level: Read

        https://docs.aws.amazon.com/braket/latest/APIReference/API_GetQuantumTask.html

        :stability: experimental
        '''
        return typing.cast("Braket", jsii.invoke(self, "toGetQuantumTask", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Braket":
        '''(experimental) Grants permission to listing the tags that have been applied to the quantum task resource or the job.

        Access Level: Read

        https://docs.aws.amazon.com/braket/latest/APIReference/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("Braket", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toSearchDevices")
    def to_search_devices(self) -> "Braket":
        '''(experimental) Grants permission to search for devices available in Amazon Braket.

        Access Level: Read

        https://docs.aws.amazon.com/braket/latest/APIReference/API_SearchDevices.html

        :stability: experimental
        '''
        return typing.cast("Braket", jsii.invoke(self, "toSearchDevices", []))

    @jsii.member(jsii_name="toSearchJobs")
    def to_search_jobs(self) -> "Braket":
        '''(experimental) Grants permission to search for jobs.

        Access Level: Read

        https://docs.aws.amazon.com/braket/latest/APIReference/API_SearchJob.html

        :stability: experimental
        '''
        return typing.cast("Braket", jsii.invoke(self, "toSearchJobs", []))

    @jsii.member(jsii_name="toSearchQuantumTasks")
    def to_search_quantum_tasks(self) -> "Braket":
        '''(experimental) Grants permission to search for quantum tasks.

        Access Level: Read

        https://docs.aws.amazon.com/braket/latest/APIReference/API_SearchQuantumTasks.html

        :stability: experimental
        '''
        return typing.cast("Braket", jsii.invoke(self, "toSearchQuantumTasks", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Braket":
        '''(experimental) Grants permission to add one or more tags to a quantum task.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/braket/latest/APIReference/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("Braket", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Braket":
        '''(experimental) Grants permission to remove one or more tags from a quantum task resource or a job.

        A tag consists of a key-value pair

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/braket/latest/APIReference/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("Braket", jsii.invoke(self, "toUntagResource", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f051de9fc20396e6425c8ca6c7c57b301d2304516a00e0b6899e5a24497fe16b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5f0a05d6245a38be5318ca9cf8e09a4961de0253a2a207021f04484b999239f0)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Budgets(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Budgets",
):
    '''(experimental) Statement provider for service `budgets <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsbudgetservice.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `budgets <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsbudgetservice.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onBudget")
    def on_budget(
        self,
        budget_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Budgets":
        '''(experimental) Adds a resource of type budget to the statement.

        https://docs.aws.amazon.com/awsaccountbilling/latest/aboutv2/budgets-managing-costs.html

        :param budget_name: - Identifier for the budgetName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3cf09fa4c3149dc8e163f254eae902d09e8a4bb605e5763664bbb2a74a572bd6)
            check_type(argname="argument budget_name", value=budget_name, expected_type=type_hints["budget_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Budgets", jsii.invoke(self, "onBudget", [budget_name, account, partition]))

    @jsii.member(jsii_name="onBudgetAction")
    def on_budget_action(
        self,
        budget_name: builtins.str,
        action_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Budgets":
        '''(experimental) Adds a resource of type budgetAction to the statement.

        https://docs.aws.amazon.com/awsaccountbilling/latest/aboutv2/budgets-managing-costs.html

        :param budget_name: - Identifier for the budgetName.
        :param action_id: - Identifier for the actionId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__87b90c80352693f239902b76c8c77adc94d2840cc89dc8bec4cf819c31719355)
            check_type(argname="argument budget_name", value=budget_name, expected_type=type_hints["budget_name"])
            check_type(argname="argument action_id", value=action_id, expected_type=type_hints["action_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Budgets", jsii.invoke(self, "onBudgetAction", [budget_name, action_id, account, partition]))

    @jsii.member(jsii_name="toCreateBudgetAction")
    def to_create_budget_action(self) -> "Budgets":
        '''(experimental) Grants permission to create and define a response that you can configure to execute once your budget has exceeded a specific budget threshold.

        Access Level: Write

        Dependent actions:

        - iam:PassRole

        https://docs.aws.amazon.com/awsaccountbilling/latest/aboutv2/billing-permissions-ref.html#user-permissions

        :stability: experimental
        '''
        return typing.cast("Budgets", jsii.invoke(self, "toCreateBudgetAction", []))

    @jsii.member(jsii_name="toDeleteBudgetAction")
    def to_delete_budget_action(self) -> "Budgets":
        '''(experimental) Grants permission to delete an action that is associated with a specific budget.

        Access Level: Write

        https://docs.aws.amazon.com/awsaccountbilling/latest/aboutv2/billing-permissions-ref.html#user-permissions

        :stability: experimental
        '''
        return typing.cast("Budgets", jsii.invoke(self, "toDeleteBudgetAction", []))

    @jsii.member(jsii_name="toDescribeBudgetAction")
    def to_describe_budget_action(self) -> "Budgets":
        '''(experimental) Grants permission to retrieve the details of a specific budget action associated with a budget.

        Access Level: Read

        https://docs.aws.amazon.com/awsaccountbilling/latest/aboutv2/billing-permissions-ref.html#user-permissions

        :stability: experimental
        '''
        return typing.cast("Budgets", jsii.invoke(self, "toDescribeBudgetAction", []))

    @jsii.member(jsii_name="toDescribeBudgetActionHistories")
    def to_describe_budget_action_histories(self) -> "Budgets":
        '''(experimental) Grants permission to retrieve a historical view of the budget actions statuses associated with a particular budget action.

        These status include statues such as 'Standby', 'Pending' and 'Executed'

        Access Level: Read

        https://docs.aws.amazon.com/awsaccountbilling/latest/aboutv2/billing-permissions-ref.html#user-permissions

        :stability: experimental
        '''
        return typing.cast("Budgets", jsii.invoke(self, "toDescribeBudgetActionHistories", []))

    @jsii.member(jsii_name="toDescribeBudgetActionsForAccount")
    def to_describe_budget_actions_for_account(self) -> "Budgets":
        '''(experimental) Grants permission to retrieve the details of all of the budget actions associated with your account.

        Access Level: Read

        https://docs.aws.amazon.com/awsaccountbilling/latest/aboutv2/billing-permissions-ref.html#user-permissions

        :stability: experimental
        '''
        return typing.cast("Budgets", jsii.invoke(self, "toDescribeBudgetActionsForAccount", []))

    @jsii.member(jsii_name="toDescribeBudgetActionsForBudget")
    def to_describe_budget_actions_for_budget(self) -> "Budgets":
        '''(experimental) Grants permission to retrieve the details of all of the budget actions associated with a budget.

        Access Level: Read

        https://docs.aws.amazon.com/awsaccountbilling/latest/aboutv2/billing-permissions-ref.html#user-permissions

        :stability: experimental
        '''
        return typing.cast("Budgets", jsii.invoke(self, "toDescribeBudgetActionsForBudget", []))

    @jsii.member(jsii_name="toExecuteBudgetAction")
    def to_execute_budget_action(self) -> "Budgets":
        '''(experimental) Grants permission to initiate a pending budget action as well as reverse a previously executed budget action.

        Access Level: Write

        https://docs.aws.amazon.com/awsaccountbilling/latest/aboutv2/billing-permissions-ref.html#user-permissions

        :stability: experimental
        '''
        return typing.cast("Budgets", jsii.invoke(self, "toExecuteBudgetAction", []))

    @jsii.member(jsii_name="toModifyBudget")
    def to_modify_budget(self) -> "Budgets":
        '''(experimental) Grants permission to modify budgets and budget details.

        Access Level: Write

        https://docs.aws.amazon.com/awsaccountbilling/latest/aboutv2/billing-permissions-ref.html#user-permissions

        :stability: experimental
        '''
        return typing.cast("Budgets", jsii.invoke(self, "toModifyBudget", []))

    @jsii.member(jsii_name="toUpdateBudgetAction")
    def to_update_budget_action(self) -> "Budgets":
        '''(experimental) Grants permission to update the details of a specific budget action associated with a budget.

        Access Level: Write

        Dependent actions:

        - iam:PassRole

        https://docs.aws.amazon.com/awsaccountbilling/latest/aboutv2/billing-permissions-ref.html#user-permissions

        :stability: experimental
        '''
        return typing.cast("Budgets", jsii.invoke(self, "toUpdateBudgetAction", []))

    @jsii.member(jsii_name="toViewBudget")
    def to_view_budget(self) -> "Budgets":
        '''(experimental) Grants permission to view budgets and budget details.

        Access Level: Read

        https://docs.aws.amazon.com/awsaccountbilling/latest/aboutv2/billing-permissions-ref.html#user-permissions

        :stability: experimental
        '''
        return typing.cast("Budgets", jsii.invoke(self, "toViewBudget", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__eee2cfb0240e5f09217ee9ae71ea0d5fae4c09b2dbdee829a0afffb46b78c690)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fbb42c903fce7bd0558a66b914ea6d8b9e0bfafaf1aaa72d2604b1737d457bfb)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Bugbust(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Bugbust",
):
    '''(experimental) Statement provider for service `bugbust <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsbugbust.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `bugbust <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsbugbust.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onEvent")
    def on_event(
        self,
        event_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Bugbust":
        '''(experimental) Adds a resource of type Event to the statement.

        https://docs.aws.amazon.com/codeguru/latest/bugbust-ug/event-managing.html

        :param event_id: - Identifier for the eventId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__80b883034db6a899b2cdf2956689aafbef46e031fc5eb9e2728d1a2d9c4ba383)
            check_type(argname="argument event_id", value=event_id, expected_type=type_hints["event_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Bugbust", jsii.invoke(self, "onEvent", [event_id, account, region, partition]))

    @jsii.member(jsii_name="toCreateEvent")
    def to_create_event(self) -> "Bugbust":
        '''(experimental) Grants permission to create a BugBust event.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        Dependent actions:

        - iam:CreateServiceLinkedRole

        https://docs.aws.amazon.com/codeguru/latest/bugbust-ug/auth-and-access-control-permissions-reference.html

        :stability: experimental
        '''
        return typing.cast("Bugbust", jsii.invoke(self, "toCreateEvent", []))

    @jsii.member(jsii_name="toEvaluateProfilingGroups")
    def to_evaluate_profiling_groups(self) -> "Bugbust":
        '''(experimental) Grants permission to evaluate checked-in profiling groups.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/codeguru/latest/bugbust-ug/auth-and-access-control-permissions-reference.html

        :stability: experimental
        '''
        return typing.cast("Bugbust", jsii.invoke(self, "toEvaluateProfilingGroups", []))

    @jsii.member(jsii_name="toGetEvent")
    def to_get_event(self) -> "Bugbust":
        '''(experimental) Grants permission to view customer details about an event.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/codeguru/latest/bugbust-ug/auth-and-access-control-permissions-reference.html

        :stability: experimental
        '''
        return typing.cast("Bugbust", jsii.invoke(self, "toGetEvent", []))

    @jsii.member(jsii_name="toGetJoinEventStatus")
    def to_get_join_event_status(self) -> "Bugbust":
        '''(experimental) Grants permission to view the status of a BugBust player's attempt to join a BugBust event.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/codeguru/latest/bugbust-ug/auth-and-access-control-permissions-reference.html

        :stability: experimental
        '''
        return typing.cast("Bugbust", jsii.invoke(self, "toGetJoinEventStatus", []))

    @jsii.member(jsii_name="toJoinEvent")
    def to_join_event(self) -> "Bugbust":
        '''(experimental) Grants permission to join an event.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/codeguru/latest/bugbust-ug/auth-and-access-control-permissions-reference.html

        :stability: experimental
        '''
        return typing.cast("Bugbust", jsii.invoke(self, "toJoinEvent", []))

    @jsii.member(jsii_name="toListBugs")
    def to_list_bugs(self) -> "Bugbust":
        '''(experimental) Grants permission to view the bugs that were imported into an event for players to work on.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()

        Dependent actions:

        - codeguru-reviewer:DescribeCodeReview
        - codeguru-reviewer:ListRecommendations

        https://docs.aws.amazon.com/codeguru/latest/bugbust-ug/auth-and-access-control-permissions-reference.html

        :stability: experimental
        '''
        return typing.cast("Bugbust", jsii.invoke(self, "toListBugs", []))

    @jsii.member(jsii_name="toListEventParticipants")
    def to_list_event_participants(self) -> "Bugbust":
        '''(experimental) Grants permission to view the participants of an event.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/codeguru/latest/bugbust-ug/auth-and-access-control-permissions-reference.html

        :stability: experimental
        '''
        return typing.cast("Bugbust", jsii.invoke(self, "toListEventParticipants", []))

    @jsii.member(jsii_name="toListEvents")
    def to_list_events(self) -> "Bugbust":
        '''(experimental) Grants permission to List BugBust events.

        Access Level: List

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/codeguru/latest/bugbust-ug/auth-and-access-control-permissions-reference.html

        :stability: experimental
        '''
        return typing.cast("Bugbust", jsii.invoke(self, "toListEvents", []))

    @jsii.member(jsii_name="toListEventScores")
    def to_list_event_scores(self) -> "Bugbust":
        '''(experimental) Grants permission to view the scores of an event's players.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/codeguru/latest/bugbust-ug/auth-and-access-control-permissions-reference.html

        :stability: experimental
        '''
        return typing.cast("Bugbust", jsii.invoke(self, "toListEventScores", []))

    @jsii.member(jsii_name="toListProfilingGroups")
    def to_list_profiling_groups(self) -> "Bugbust":
        '''(experimental) Grants permission to view the profiling groups that were imported into an event for players to work on.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/codeguru/latest/bugbust-ug/auth-and-access-control-permissions-reference.html

        :stability: experimental
        '''
        return typing.cast("Bugbust", jsii.invoke(self, "toListProfilingGroups", []))

    @jsii.member(jsii_name="toListPullRequests")
    def to_list_pull_requests(self) -> "Bugbust":
        '''(experimental) Grants permission to view the pull requests used by players to submit fixes to their claimed bugs in an event.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/codeguru/latest/bugbust-ug/auth-and-access-control-permissions-reference.html

        :stability: experimental
        '''
        return typing.cast("Bugbust", jsii.invoke(self, "toListPullRequests", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Bugbust":
        '''(experimental) Grants permission to lists tag for a Bugbust resource.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/codeguru/latest/bugbust-ug/auth-and-access-control-permissions-reference.html

        :stability: experimental
        '''
        return typing.cast("Bugbust", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Bugbust":
        '''(experimental) Grants permission to tag a Bugbust resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/codeguru/latest/bugbust-ug/auth-and-access-control-permissions-reference.html

        :stability: experimental
        '''
        return typing.cast("Bugbust", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Bugbust":
        '''(experimental) Grants permission to untag a Bugbust resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/codeguru/latest/bugbust-ug/auth-and-access-control-permissions-reference.html

        :stability: experimental
        '''
        return typing.cast("Bugbust", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateEvent")
    def to_update_event(self) -> "Bugbust":
        '''(experimental) Grants permission to update a BugBust event.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        Dependent actions:

        - codeguru-profiler:DescribeProfilingGroup
        - codeguru-profiler:ListProfilingGroups
        - codeguru-reviewer:DescribeCodeReview
        - codeguru-reviewer:ListCodeReviews
        - codeguru-reviewer:ListRecommendations
        - codeguru-reviewer:TagResource
        - codeguru-reviewer:UnTagResource

        https://docs.aws.amazon.com/codeguru/latest/bugbust-ug/auth-and-access-control-permissions-reference.html

        :stability: experimental
        '''
        return typing.cast("Bugbust", jsii.invoke(self, "toUpdateEvent", []))

    @jsii.member(jsii_name="toUpdateWorkItem")
    def to_update_work_item(self) -> "Bugbust":
        '''(experimental) Grants permission to update a work item as claimed or unclaimed (bug or profiling group).

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        Dependent actions:

        - codeguru-reviewer:ListRecommendations

        https://docs.aws.amazon.com/codeguru/latest/bugbust-ug/auth-and-access-control-permissions-reference.html

        :stability: experimental
        '''
        return typing.cast("Bugbust", jsii.invoke(self, "toUpdateWorkItem", []))

    @jsii.member(jsii_name="toUpdateWorkItemAdmin")
    def to_update_work_item_admin(self) -> "Bugbust":
        '''(experimental) Grants permission to update an event's work item (bug or profiling group).

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        Dependent actions:

        - codeguru-reviewer:ListRecommendations

        https://docs.aws.amazon.com/codeguru/latest/bugbust-ug/auth-and-access-control-permissions-reference.html

        :stability: experimental
        '''
        return typing.cast("Bugbust", jsii.invoke(self, "toUpdateWorkItemAdmin", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a1e3d42247f72fe4b57343e65585f2815ad0a89ff4864ffb538cb0252d2af2d8)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6742cdc0375bfcfcff078d766124059655d33d2d550f1e737a9cdac64d0e35f8)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Cases(PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Cases"):
    '''(experimental) Statement provider for service `cases <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonconnectcases.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `cases <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonconnectcases.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onCase")
    def on_case(
        self,
        domain_id: builtins.str,
        case_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Cases":
        '''(experimental) Adds a resource of type Case to the statement.

        https://docs.aws.amazon.com/connect/latest/adminguide/cases.html

        :param domain_id: - Identifier for the domainId.
        :param case_id: - Identifier for the caseId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__82d622e45154975ce1aa4aa653e9fa86152346816f01b43d2fb8207f064fcfda)
            check_type(argname="argument domain_id", value=domain_id, expected_type=type_hints["domain_id"])
            check_type(argname="argument case_id", value=case_id, expected_type=type_hints["case_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Cases", jsii.invoke(self, "onCase", [domain_id, case_id, account, region, partition]))

    @jsii.member(jsii_name="onDomain")
    def on_domain(
        self,
        domain_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Cases":
        '''(experimental) Adds a resource of type Domain to the statement.

        https://docs.aws.amazon.com/connect/latest/adminguide/cases.html

        :param domain_id: - Identifier for the domainId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bf71f92e40d47c6df214677fd64b38cf6d77a2cacfeac5f0e871cbd59c834c29)
            check_type(argname="argument domain_id", value=domain_id, expected_type=type_hints["domain_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Cases", jsii.invoke(self, "onDomain", [domain_id, account, region, partition]))

    @jsii.member(jsii_name="onField")
    def on_field(
        self,
        domain_id: builtins.str,
        field_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Cases":
        '''(experimental) Adds a resource of type Field to the statement.

        https://docs.aws.amazon.com/connect/latest/adminguide/case-fields.html

        :param domain_id: - Identifier for the domainId.
        :param field_id: - Identifier for the fieldId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ea71d10265f0cbbb135be272dee958a7ea811586811b851e900a583d78b9b6a4)
            check_type(argname="argument domain_id", value=domain_id, expected_type=type_hints["domain_id"])
            check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Cases", jsii.invoke(self, "onField", [domain_id, field_id, account, region, partition]))

    @jsii.member(jsii_name="onLayout")
    def on_layout(
        self,
        domain_id: builtins.str,
        layout_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Cases":
        '''(experimental) Adds a resource of type Layout to the statement.

        https://docs.aws.amazon.com/connect/latest/adminguide/case-layouts.html

        :param domain_id: - Identifier for the domainId.
        :param layout_id: - Identifier for the layoutId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a2582290581d38c8086ec3162374e449c56eb3a082af47c1a658df78dd5ab739)
            check_type(argname="argument domain_id", value=domain_id, expected_type=type_hints["domain_id"])
            check_type(argname="argument layout_id", value=layout_id, expected_type=type_hints["layout_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Cases", jsii.invoke(self, "onLayout", [domain_id, layout_id, account, region, partition]))

    @jsii.member(jsii_name="onRelatedItem")
    def on_related_item(
        self,
        domain_id: builtins.str,
        case_id: builtins.str,
        related_item_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Cases":
        '''(experimental) Adds a resource of type RelatedItem to the statement.

        https://docs.aws.amazon.com/connect/latest/adminguide/associatecontactandcase.html

        :param domain_id: - Identifier for the domainId.
        :param case_id: - Identifier for the caseId.
        :param related_item_id: - Identifier for the relatedItemId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bc3a1afb2815347be635833a7db86e8057a14d81abb152902cd520205bb0397d)
            check_type(argname="argument domain_id", value=domain_id, expected_type=type_hints["domain_id"])
            check_type(argname="argument case_id", value=case_id, expected_type=type_hints["case_id"])
            check_type(argname="argument related_item_id", value=related_item_id, expected_type=type_hints["related_item_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Cases", jsii.invoke(self, "onRelatedItem", [domain_id, case_id, related_item_id, account, region, partition]))

    @jsii.member(jsii_name="onTemplate")
    def on_template(
        self,
        domain_id: builtins.str,
        template_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Cases":
        '''(experimental) Adds a resource of type Template to the statement.

        https://docs.aws.amazon.com/connect/latest/adminguide/case-templates.html

        :param domain_id: - Identifier for the domainId.
        :param template_id: - Identifier for the templateId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3e58b8923cf71d13964825bb7a5269ec02248f2be661a3a2c4ac20cb35658994)
            check_type(argname="argument domain_id", value=domain_id, expected_type=type_hints["domain_id"])
            check_type(argname="argument template_id", value=template_id, expected_type=type_hints["template_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Cases", jsii.invoke(self, "onTemplate", [domain_id, template_id, account, region, partition]))

    @jsii.member(jsii_name="toBatchGetField")
    def to_batch_get_field(self) -> "Cases":
        '''(experimental) Grants permission to retrieve information about the fields in the case domain.

        Access Level: Read

        https://docs.aws.amazon.com/cases/latest/APIReference/API_BatchGetField.html

        :stability: experimental
        '''
        return typing.cast("Cases", jsii.invoke(self, "toBatchGetField", []))

    @jsii.member(jsii_name="toBatchPutFieldOptions")
    def to_batch_put_field_options(self) -> "Cases":
        '''(experimental) Grants permission to update the field options in the case domain.

        Access Level: Write

        https://docs.aws.amazon.com/cases/latest/APIReference/API_BatchPutFieldOptions.html

        :stability: experimental
        '''
        return typing.cast("Cases", jsii.invoke(self, "toBatchPutFieldOptions", []))

    @jsii.member(jsii_name="toCreateCase")
    def to_create_case(self) -> "Cases":
        '''(experimental) Grants permission to create a case in the case domain.

        Access Level: Write

        https://docs.aws.amazon.com/cases/latest/APIReference/API_CreateCase.html

        :stability: experimental
        '''
        return typing.cast("Cases", jsii.invoke(self, "toCreateCase", []))

    @jsii.member(jsii_name="toCreateDomain")
    def to_create_domain(self) -> "Cases":
        '''(experimental) Grants permission to create a new case domain.

        Access Level: Write

        https://docs.aws.amazon.com/cases/latest/APIReference/API_CreateDomain.html

        :stability: experimental
        '''
        return typing.cast("Cases", jsii.invoke(self, "toCreateDomain", []))

    @jsii.member(jsii_name="toCreateField")
    def to_create_field(self) -> "Cases":
        '''(experimental) Grants permission to create a field in the case domain.

        Access Level: Write

        https://docs.aws.amazon.com/cases/latest/APIReference/API_CreateField.html

        :stability: experimental
        '''
        return typing.cast("Cases", jsii.invoke(self, "toCreateField", []))

    @jsii.member(jsii_name="toCreateLayout")
    def to_create_layout(self) -> "Cases":
        '''(experimental) Grants permission to create a layout in the case domain.

        Access Level: Write

        https://docs.aws.amazon.com/cases/latest/APIReference/API_CreateLayout.html

        :stability: experimental
        '''
        return typing.cast("Cases", jsii.invoke(self, "toCreateLayout", []))

    @jsii.member(jsii_name="toCreateRelatedItem")
    def to_create_related_item(self) -> "Cases":
        '''(experimental) Grants permission to create a related item associated to a case in the case domain.

        Access Level: Write

        https://docs.aws.amazon.com/cases/latest/APIReference/API_CreateRelatedItem.html

        :stability: experimental
        '''
        return typing.cast("Cases", jsii.invoke(self, "toCreateRelatedItem", []))

    @jsii.member(jsii_name="toCreateTemplate")
    def to_create_template(self) -> "Cases":
        '''(experimental) Grants permission to create a template in the case domain.

        Access Level: Write

        https://docs.aws.amazon.com/cases/latest/APIReference/API_CreateTemplate.html

        :stability: experimental
        '''
        return typing.cast("Cases", jsii.invoke(self, "toCreateTemplate", []))

    @jsii.member(jsii_name="toGetCase")
    def to_get_case(self) -> "Cases":
        '''(experimental) Grants permission to retrieve information about a case in the case domain.

        Access Level: Read

        https://docs.aws.amazon.com/cases/latest/APIReference/API_GetCase.html

        :stability: experimental
        '''
        return typing.cast("Cases", jsii.invoke(self, "toGetCase", []))

    @jsii.member(jsii_name="toGetCaseEventConfiguration")
    def to_get_case_event_configuration(self) -> "Cases":
        '''(experimental) Grants permission to retrieve information about the case event configuraton in the case domain.

        Access Level: Read

        https://docs.aws.amazon.com/cases/latest/APIReference/API_GetCaseEventConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Cases", jsii.invoke(self, "toGetCaseEventConfiguration", []))

    @jsii.member(jsii_name="toGetDomain")
    def to_get_domain(self) -> "Cases":
        '''(experimental) Grants permission to retrieve information about the case domain.

        Access Level: Read

        https://docs.aws.amazon.com/cases/latest/APIReference/API_GetDomain.html

        :stability: experimental
        '''
        return typing.cast("Cases", jsii.invoke(self, "toGetDomain", []))

    @jsii.member(jsii_name="toGetLayout")
    def to_get_layout(self) -> "Cases":
        '''(experimental) Grants permission to retrieve information about the layout in the case domain.

        Access Level: Read

        https://docs.aws.amazon.com/cases/latest/APIReference/API_GetLayout.html

        :stability: experimental
        '''
        return typing.cast("Cases", jsii.invoke(self, "toGetLayout", []))

    @jsii.member(jsii_name="toGetTemplate")
    def to_get_template(self) -> "Cases":
        '''(experimental) Grants permission to retrieve information about the template in the case domain.

        Access Level: Read

        https://docs.aws.amazon.com/cases/latest/APIReference/API_GetTemplate.html

        :stability: experimental
        '''
        return typing.cast("Cases", jsii.invoke(self, "toGetTemplate", []))

    @jsii.member(jsii_name="toListCasesForContact")
    def to_list_cases_for_contact(self) -> "Cases":
        '''(experimental) Grants permission to list cases for a specific contact in the case domain.

        Access Level: List

        https://docs.aws.amazon.com/cases/latest/APIReference/API_ListCasesForContact.html

        :stability: experimental
        '''
        return typing.cast("Cases", jsii.invoke(self, "toListCasesForContact", []))

    @jsii.member(jsii_name="toListDomains")
    def to_list_domains(self) -> "Cases":
        '''(experimental) Grants permission to list all domains in the aws account.

        Access Level: List

        https://docs.aws.amazon.com/cases/latest/APIReference/API_ListDomains.html

        :stability: experimental
        '''
        return typing.cast("Cases", jsii.invoke(self, "toListDomains", []))

    @jsii.member(jsii_name="toListFieldOptions")
    def to_list_field_options(self) -> "Cases":
        '''(experimental) Grants permission to list field options for a single select field in the case domain.

        Access Level: List

        https://docs.aws.amazon.com/cases/latest/APIReference/API_ListFieldOptions.html

        :stability: experimental
        '''
        return typing.cast("Cases", jsii.invoke(self, "toListFieldOptions", []))

    @jsii.member(jsii_name="toListFields")
    def to_list_fields(self) -> "Cases":
        '''(experimental) Grants permission to list fields in the case domain.

        Access Level: List

        https://docs.aws.amazon.com/cases/latest/APIReference/API_ListFields.html

        :stability: experimental
        '''
        return typing.cast("Cases", jsii.invoke(self, "toListFields", []))

    @jsii.member(jsii_name="toListLayouts")
    def to_list_layouts(self) -> "Cases":
        '''(experimental) Grants permission to list layouts in the case domain.

        Access Level: List

        https://docs.aws.amazon.com/cases/latest/APIReference/API_ListLayouts.html

        :stability: experimental
        '''
        return typing.cast("Cases", jsii.invoke(self, "toListLayouts", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Cases":
        '''(experimental) Grants permission to list the tags for the specified resource.

        Access Level: Read

        https://docs.aws.amazon.com/cases/latest/APIReference/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("Cases", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toListTemplates")
    def to_list_templates(self) -> "Cases":
        '''(experimental) Grants permission to list templates in the case domain.

        Access Level: List

        https://docs.aws.amazon.com/cases/latest/APIReference/API_ListTemplates.html

        :stability: experimental
        '''
        return typing.cast("Cases", jsii.invoke(self, "toListTemplates", []))

    @jsii.member(jsii_name="toPutCaseEventConfiguration")
    def to_put_case_event_configuration(self) -> "Cases":
        '''(experimental) Grants permission to insert or update the case event configuration in the case domain.

        Access Level: Write

        https://docs.aws.amazon.com/cases/latest/APIReference/API_PutCaseEventConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Cases", jsii.invoke(self, "toPutCaseEventConfiguration", []))

    @jsii.member(jsii_name="toSearchCases")
    def to_search_cases(self) -> "Cases":
        '''(experimental) Grants permission to search for cases in the case domain.

        Access Level: Read

        https://docs.aws.amazon.com/cases/latest/APIReference/API_SearchCases.html

        :stability: experimental
        '''
        return typing.cast("Cases", jsii.invoke(self, "toSearchCases", []))

    @jsii.member(jsii_name="toSearchRelatedItems")
    def to_search_related_items(self) -> "Cases":
        '''(experimental) Grants permission to search for related items associated to the case in the case domain.

        Access Level: Read

        https://docs.aws.amazon.com/cases/latest/APIReference/API_SearchRelatedItems.html

        :stability: experimental
        '''
        return typing.cast("Cases", jsii.invoke(self, "toSearchRelatedItems", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Cases":
        '''(experimental) Grants permission to add the specified tags to the specified resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/cases/latest/APIReference/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("Cases", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Cases":
        '''(experimental) Grants permission to remove the specified tags from the specified resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/cases/latest/APIReference/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("Cases", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateCase")
    def to_update_case(self) -> "Cases":
        '''(experimental) Grants permission to update the field values on the case in the case domain.

        Access Level: Write

        https://docs.aws.amazon.com/cases/latest/APIReference/API_UpdateCase.html

        :stability: experimental
        '''
        return typing.cast("Cases", jsii.invoke(self, "toUpdateCase", []))

    @jsii.member(jsii_name="toUpdateField")
    def to_update_field(self) -> "Cases":
        '''(experimental) Grants permission to update the field in the case domain.

        Access Level: Write

        https://docs.aws.amazon.com/cases/latest/APIReference/API_UpdateField.html

        :stability: experimental
        '''
        return typing.cast("Cases", jsii.invoke(self, "toUpdateField", []))

    @jsii.member(jsii_name="toUpdateLayout")
    def to_update_layout(self) -> "Cases":
        '''(experimental) Grants permission to update the layout in the case domain.

        Access Level: Write

        https://docs.aws.amazon.com/cases/latest/APIReference/API_UpdateLayout.html

        :stability: experimental
        '''
        return typing.cast("Cases", jsii.invoke(self, "toUpdateLayout", []))

    @jsii.member(jsii_name="toUpdateTemplate")
    def to_update_template(self) -> "Cases":
        '''(experimental) Grants permission to update the template in the case domain.

        Access Level: Write

        https://docs.aws.amazon.com/cases/latest/APIReference/API_UpdateTemplate.html

        :stability: experimental
        '''
        return typing.cast("Cases", jsii.invoke(self, "toUpdateTemplate", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__26bcac8229069e1bb93ea414a885eeee80162c0bed42ab3c15bb0387fe96e9ab)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3e6c7bcf61f567de6a6e59b67acee16c533a8aae759e72f60dcbe460f2ee5286)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Cassandra(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Cassandra",
):
    '''(experimental) Statement provider for service `cassandra <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonkeyspacesforapachecassandra.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `cassandra <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonkeyspacesforapachecassandra.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onKeyspace")
    def on_keyspace(
        self,
        keyspace_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Cassandra":
        '''(experimental) Adds a resource of type keyspace to the statement.

        https://docs.aws.amazon.com/keyspaces/latest/devguide/what-is.html

        :param keyspace_name: - Identifier for the keyspaceName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4066edb86df4aef17e13389b1e69d69ffcccb40522646b2c2211757d89befd05)
            check_type(argname="argument keyspace_name", value=keyspace_name, expected_type=type_hints["keyspace_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Cassandra", jsii.invoke(self, "onKeyspace", [keyspace_name, account, region, partition]))

    @jsii.member(jsii_name="onTable")
    def on_table(
        self,
        keyspace_name: builtins.str,
        table_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Cassandra":
        '''(experimental) Adds a resource of type table to the statement.

        https://docs.aws.amazon.com/keyspaces/latest/devguide/what-is.html

        :param keyspace_name: - Identifier for the keyspaceName.
        :param table_name: - Identifier for the tableName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c75e5d9ad92e304e07b1a06f76855698f79a33d737368162a24589defa4dff4d)
            check_type(argname="argument keyspace_name", value=keyspace_name, expected_type=type_hints["keyspace_name"])
            check_type(argname="argument table_name", value=table_name, expected_type=type_hints["table_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Cassandra", jsii.invoke(self, "onTable", [keyspace_name, table_name, account, region, partition]))

    @jsii.member(jsii_name="toAlter")
    def to_alter(self) -> "Cassandra":
        '''(experimental) Grants permission to alter a keyspace or table.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/keyspaces/latest/devguide/

        :stability: experimental
        '''
        return typing.cast("Cassandra", jsii.invoke(self, "toAlter", []))

    @jsii.member(jsii_name="toCreate")
    def to_create(self) -> "Cassandra":
        '''(experimental) Grants permission to create a keyspace or table.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/keyspaces/latest/devguide/

        :stability: experimental
        '''
        return typing.cast("Cassandra", jsii.invoke(self, "toCreate", []))

    @jsii.member(jsii_name="toDrop")
    def to_drop(self) -> "Cassandra":
        '''(experimental) Grants permission to drop a keyspace or table.

        Access Level: Write

        https://docs.aws.amazon.com/keyspaces/latest/devguide/

        :stability: experimental
        '''
        return typing.cast("Cassandra", jsii.invoke(self, "toDrop", []))

    @jsii.member(jsii_name="toModify")
    def to_modify(self) -> "Cassandra":
        '''(experimental) Grants permission to INSERT, UPDATE or DELETE data in a table.

        Access Level: Write

        https://docs.aws.amazon.com/keyspaces/latest/devguide/

        :stability: experimental
        '''
        return typing.cast("Cassandra", jsii.invoke(self, "toModify", []))

    @jsii.member(jsii_name="toRestore")
    def to_restore(self) -> "Cassandra":
        '''(experimental) Grants permission to restore table from a backup.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/keyspaces/latest/devguide/

        :stability: experimental
        '''
        return typing.cast("Cassandra", jsii.invoke(self, "toRestore", []))

    @jsii.member(jsii_name="toSelect")
    def to_select(self) -> "Cassandra":
        '''(experimental) Grants permission to SELECT data from a table.

        Access Level: Read

        https://docs.aws.amazon.com/keyspaces/latest/devguide/

        :stability: experimental
        '''
        return typing.cast("Cassandra", jsii.invoke(self, "toSelect", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Cassandra":
        '''(experimental) Grants permission to tag a keyspace or table.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/keyspaces/latest/devguide/

        :stability: experimental
        '''
        return typing.cast("Cassandra", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Cassandra":
        '''(experimental) Grants permission to untag a keyspace or table.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/keyspaces/latest/devguide/

        :stability: experimental
        '''
        return typing.cast("Cassandra", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdatePartitioner")
    def to_update_partitioner(self) -> "Cassandra":
        '''(experimental) Grants permission to UPDATE the partitioner in a system table.

        Access Level: Write

        https://docs.aws.amazon.com/keyspaces/latest/devguide/

        :stability: experimental
        '''
        return typing.cast("Cassandra", jsii.invoke(self, "toUpdatePartitioner", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2b422dae5a3e099423f4ba9e48dff7d31d0b800bbf55e66a7af7132f5ba07fb9)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2b2d1c3b1c496db2f3191175c543f14578aa3522dc029eff83f33e067cef2179)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Ce(PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Ce"):
    '''(experimental) Statement provider for service `ce <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awscostexplorerservice.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `ce <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awscostexplorerservice.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onAnomalymonitor")
    def on_anomalymonitor(
        self,
        identifier: builtins.str,
        account: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Ce":
        '''(experimental) Adds a resource of type anomalymonitor to the statement.

        https://docs.aws.amazon.com/aws-cost-management/latest/APIReference/API_AnomalyMonitor.html

        :param identifier: - Identifier for the identifier.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__10a96358c45e19b6c6dba05c8bab61955c1b5b33d7348cb89d2ba2c157a40867)
            check_type(argname="argument identifier", value=identifier, expected_type=type_hints["identifier"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Ce", jsii.invoke(self, "onAnomalymonitor", [identifier, account, partition]))

    @jsii.member(jsii_name="onAnomalysubscription")
    def on_anomalysubscription(
        self,
        identifier: builtins.str,
        account: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Ce":
        '''(experimental) Adds a resource of type anomalysubscription to the statement.

        https://docs.aws.amazon.com/aws-cost-management/latest/APIReference/API_AnomalySubscription.html

        :param identifier: - Identifier for the identifier.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__26ca11dc00cc9bea3e58fc539f1ba2dde16ba943ea3016c14c7b7c87ed62094b)
            check_type(argname="argument identifier", value=identifier, expected_type=type_hints["identifier"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Ce", jsii.invoke(self, "onAnomalysubscription", [identifier, account, partition]))

    @jsii.member(jsii_name="onCostcategory")
    def on_costcategory(
        self,
        identifier: builtins.str,
        account: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Ce":
        '''(experimental) Adds a resource of type costcategory to the statement.

        https://docs.aws.amazon.com/aws-cost-management/latest/APIReference/API_CostCategory.html

        :param identifier: - Identifier for the identifier.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__36b4f7d3062d10949c846fc16402e07054c21e5e5af00e3a08d3bf59a722a5b9)
            check_type(argname="argument identifier", value=identifier, expected_type=type_hints["identifier"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Ce", jsii.invoke(self, "onCostcategory", [identifier, account, partition]))

    @jsii.member(jsii_name="toCreateAnomalyMonitor")
    def to_create_anomaly_monitor(self) -> "Ce":
        '''(experimental) Grants permission to create a new Anomaly Monitor.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/aws-cost-management/latest/APIReference/API_CreateAnomalyMonitor.html

        :stability: experimental
        '''
        return typing.cast("Ce", jsii.invoke(self, "toCreateAnomalyMonitor", []))

    @jsii.member(jsii_name="toCreateAnomalySubscription")
    def to_create_anomaly_subscription(self) -> "Ce":
        '''(experimental) Grants permission to create a new Anomaly Subscription.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/aws-cost-management/latest/APIReference/API_CreateAnomalySubscription.html

        :stability: experimental
        '''
        return typing.cast("Ce", jsii.invoke(self, "toCreateAnomalySubscription", []))

    @jsii.member(jsii_name="toCreateCostCategoryDefinition")
    def to_create_cost_category_definition(self) -> "Ce":
        '''(experimental) Grants permission to create a new Cost Category with the requested name and rules.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/aws-cost-management/latest/APIReference/API_CreateCostCategoryDefinition.html

        :stability: experimental
        '''
        return typing.cast("Ce", jsii.invoke(self, "toCreateCostCategoryDefinition", []))

    @jsii.member(jsii_name="toCreateNotificationSubscription")
    def to_create_notification_subscription(self) -> "Ce":
        '''(experimental) Grants permission to create Reservation expiration alerts.

        Access Level: Write

        https://docs.aws.amazon.com/awsaccountbilling/latest/aboutv2/billing-permissions-ref.html

        :stability: experimental
        '''
        return typing.cast("Ce", jsii.invoke(self, "toCreateNotificationSubscription", []))

    @jsii.member(jsii_name="toCreateReport")
    def to_create_report(self) -> "Ce":
        '''(experimental) Grants permission to create Cost Explorer Reports.

        Access Level: Write

        https://docs.aws.amazon.com/awsaccountbilling/latest/aboutv2/billing-permissions-ref.html

        :stability: experimental
        '''
        return typing.cast("Ce", jsii.invoke(self, "toCreateReport", []))

    @jsii.member(jsii_name="toDeleteAnomalyMonitor")
    def to_delete_anomaly_monitor(self) -> "Ce":
        '''(experimental) Grants permission to delete an Anomaly Monitor.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/aws-cost-management/latest/APIReference/API_DeleteAnomalyMonitor.html

        :stability: experimental
        '''
        return typing.cast("Ce", jsii.invoke(self, "toDeleteAnomalyMonitor", []))

    @jsii.member(jsii_name="toDeleteAnomalySubscription")
    def to_delete_anomaly_subscription(self) -> "Ce":
        '''(experimental) Grants permission to delete an Anomaly Subscription.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/aws-cost-management/latest/APIReference/API_DeleteAnomalySubscription.html

        :stability: experimental
        '''
        return typing.cast("Ce", jsii.invoke(self, "toDeleteAnomalySubscription", []))

    @jsii.member(jsii_name="toDeleteCostCategoryDefinition")
    def to_delete_cost_category_definition(self) -> "Ce":
        '''(experimental) Grants permission to delete a Cost Category.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/aws-cost-management/latest/APIReference/API_DeleteCostCategoryDefinition.html

        :stability: experimental
        '''
        return typing.cast("Ce", jsii.invoke(self, "toDeleteCostCategoryDefinition", []))

    @jsii.member(jsii_name="toDeleteNotificationSubscription")
    def to_delete_notification_subscription(self) -> "Ce":
        '''(experimental) Grants permission to delete Reservation expiration alerts.

        Access Level: Write

        https://docs.aws.amazon.com/awsaccountbilling/latest/aboutv2/billing-permissions-ref.html

        :stability: experimental
        '''
        return typing.cast("Ce", jsii.invoke(self, "toDeleteNotificationSubscription", []))

    @jsii.member(jsii_name="toDeleteReport")
    def to_delete_report(self) -> "Ce":
        '''(experimental) Grants permission to delete Cost Explorer Reports.

        Access Level: Write

        https://docs.aws.amazon.com/awsaccountbilling/latest/aboutv2/billing-permissions-ref.html

        :stability: experimental
        '''
        return typing.cast("Ce", jsii.invoke(self, "toDeleteReport", []))

    @jsii.member(jsii_name="toDescribeCostCategoryDefinition")
    def to_describe_cost_category_definition(self) -> "Ce":
        '''(experimental) Grants permission to retrieve descriptions such as the name, ARN, rules, definition, and effective dates of a Cost Category.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/aws-cost-management/latest/APIReference/API_DescribeCostCategoryDefinition.html

        :stability: experimental
        '''
        return typing.cast("Ce", jsii.invoke(self, "toDescribeCostCategoryDefinition", []))

    @jsii.member(jsii_name="toDescribeNotificationSubscription")
    def to_describe_notification_subscription(self) -> "Ce":
        '''(experimental) Grants permission to view Reservation expiration alerts.

        Access Level: Read

        https://docs.aws.amazon.com/awsaccountbilling/latest/aboutv2/billing-permissions-ref.html

        :stability: experimental
        '''
        return typing.cast("Ce", jsii.invoke(self, "toDescribeNotificationSubscription", []))

    @jsii.member(jsii_name="toDescribeReport")
    def to_describe_report(self) -> "Ce":
        '''(experimental) Grants permission to view Cost Explorer Reports page.

        Access Level: Read

        https://docs.aws.amazon.com/awsaccountbilling/latest/aboutv2/billing-permissions-ref.html

        :stability: experimental
        '''
        return typing.cast("Ce", jsii.invoke(self, "toDescribeReport", []))

    @jsii.member(jsii_name="toGetAnomalies")
    def to_get_anomalies(self) -> "Ce":
        '''(experimental) Grants permission to retrieve anomalies.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/aws-cost-management/latest/APIReference/API_GetAnomalies.html

        :stability: experimental
        '''
        return typing.cast("Ce", jsii.invoke(self, "toGetAnomalies", []))

    @jsii.member(jsii_name="toGetAnomalyMonitors")
    def to_get_anomaly_monitors(self) -> "Ce":
        '''(experimental) Grants permission to query Anomaly Monitors.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/aws-cost-management/latest/APIReference/API_GetAnomalyMonitors.html

        :stability: experimental
        '''
        return typing.cast("Ce", jsii.invoke(self, "toGetAnomalyMonitors", []))

    @jsii.member(jsii_name="toGetAnomalySubscriptions")
    def to_get_anomaly_subscriptions(self) -> "Ce":
        '''(experimental) Grants permission to query Anomaly Subscriptions.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/aws-cost-management/latest/APIReference/API_GetAnomalySubscriptions.html

        :stability: experimental
        '''
        return typing.cast("Ce", jsii.invoke(self, "toGetAnomalySubscriptions", []))

    @jsii.member(jsii_name="toGetCostAndUsage")
    def to_get_cost_and_usage(self) -> "Ce":
        '''(experimental) Grants permission to retrieve the cost and usage metrics for your account.

        Access Level: Read

        https://docs.aws.amazon.com/aws-cost-management/latest/APIReference/API_GetCostAndUsage.html

        :stability: experimental
        '''
        return typing.cast("Ce", jsii.invoke(self, "toGetCostAndUsage", []))

    @jsii.member(jsii_name="toGetCostAndUsageWithResources")
    def to_get_cost_and_usage_with_resources(self) -> "Ce":
        '''(experimental) Grants permission to retrieve the cost and usage metrics with resources for your account.

        Access Level: Read

        https://docs.aws.amazon.com/aws-cost-management/latest/APIReference/API_GetCostAndUsageWithResources.html

        :stability: experimental
        '''
        return typing.cast("Ce", jsii.invoke(self, "toGetCostAndUsageWithResources", []))

    @jsii.member(jsii_name="toGetCostCategories")
    def to_get_cost_categories(self) -> "Ce":
        '''(experimental) Grants permission to query Cost Catagory names and values for a specified time period.

        Access Level: Read

        https://docs.aws.amazon.com/aws-cost-management/latest/APIReference/API_GetCostCategories.html

        :stability: experimental
        '''
        return typing.cast("Ce", jsii.invoke(self, "toGetCostCategories", []))

    @jsii.member(jsii_name="toGetCostForecast")
    def to_get_cost_forecast(self) -> "Ce":
        '''(experimental) Grants permission to retrieve a cost forecast for a forecast time period.

        Access Level: Read

        https://docs.aws.amazon.com/aws-cost-management/latest/APIReference/API_GetCostForecast.html

        :stability: experimental
        '''
        return typing.cast("Ce", jsii.invoke(self, "toGetCostForecast", []))

    @jsii.member(jsii_name="toGetDimensionValues")
    def to_get_dimension_values(self) -> "Ce":
        '''(experimental) Grants permission to retrieve all available filter values for a filter for a period of time.

        Access Level: Read

        https://docs.aws.amazon.com/aws-cost-management/latest/APIReference/API_GetDimensionValues.html

        :stability: experimental
        '''
        return typing.cast("Ce", jsii.invoke(self, "toGetDimensionValues", []))

    @jsii.member(jsii_name="toGetPreferences")
    def to_get_preferences(self) -> "Ce":
        '''(experimental) Grants permission to view Cost Explorer Preferences page.

        Access Level: Read

        https://docs.aws.amazon.com/awsaccountbilling/latest/aboutv2/billing-permissions-ref.html

        :stability: experimental
        '''
        return typing.cast("Ce", jsii.invoke(self, "toGetPreferences", []))

    @jsii.member(jsii_name="toGetReservationCoverage")
    def to_get_reservation_coverage(self) -> "Ce":
        '''(experimental) Grants permission to retrieve the reservation coverage for your account.

        Access Level: Read

        https://docs.aws.amazon.com/aws-cost-management/latest/APIReference/API_GetReservationCoverage.html

        :stability: experimental
        '''
        return typing.cast("Ce", jsii.invoke(self, "toGetReservationCoverage", []))

    @jsii.member(jsii_name="toGetReservationPurchaseRecommendation")
    def to_get_reservation_purchase_recommendation(self) -> "Ce":
        '''(experimental) Grants permission to retrieve the reservation recommendations for your account.

        Access Level: Read

        https://docs.aws.amazon.com/aws-cost-management/latest/APIReference/API_GetReservationPurchaseRecommendation.html

        :stability: experimental
        '''
        return typing.cast("Ce", jsii.invoke(self, "toGetReservationPurchaseRecommendation", []))

    @jsii.member(jsii_name="toGetReservationUtilization")
    def to_get_reservation_utilization(self) -> "Ce":
        '''(experimental) Grants permission to retrieve the reservation utilization for your account.

        Access Level: Read

        https://docs.aws.amazon.com/aws-cost-management/latest/APIReference/API_GetReservationUtilization.html

        :stability: experimental
        '''
        return typing.cast("Ce", jsii.invoke(self, "toGetReservationUtilization", []))

    @jsii.member(jsii_name="toGetRightsizingRecommendation")
    def to_get_rightsizing_recommendation(self) -> "Ce":
        '''(experimental) Grants permission to retrieve the rightsizing recommendations for your account.

        Access Level: Read

        https://docs.aws.amazon.com/aws-cost-management/latest/APIReference/API_GetRightsizingRecommendation.html

        :stability: experimental
        '''
        return typing.cast("Ce", jsii.invoke(self, "toGetRightsizingRecommendation", []))

    @jsii.member(jsii_name="toGetSavingsPlansCoverage")
    def to_get_savings_plans_coverage(self) -> "Ce":
        '''(experimental) Grants permission to retrieve the Savings Plans coverage for your account.

        Access Level: Read

        https://docs.aws.amazon.com/aws-cost-management/latest/APIReference/API_GetSavingsPlansCoverage.html

        :stability: experimental
        '''
        return typing.cast("Ce", jsii.invoke(self, "toGetSavingsPlansCoverage", []))

    @jsii.member(jsii_name="toGetSavingsPlansPurchaseRecommendation")
    def to_get_savings_plans_purchase_recommendation(self) -> "Ce":
        '''(experimental) Grants permission to retrieve the Savings Plans recommendations for your account.

        Access Level: Read

        https://docs.aws.amazon.com/aws-cost-management/latest/APIReference/API_GetSavingsPlansPurchaseRecommendation.html

        :stability: experimental
        '''
        return typing.cast("Ce", jsii.invoke(self, "toGetSavingsPlansPurchaseRecommendation", []))

    @jsii.member(jsii_name="toGetSavingsPlansUtilization")
    def to_get_savings_plans_utilization(self) -> "Ce":
        '''(experimental) Grants permission to retrieve the Savings Plans utilization for your account.

        Access Level: Read

        https://docs.aws.amazon.com/aws-cost-management/latest/APIReference/API_GetSavingsPlansUtilization.html

        :stability: experimental
        '''
        return typing.cast("Ce", jsii.invoke(self, "toGetSavingsPlansUtilization", []))

    @jsii.member(jsii_name="toGetSavingsPlansUtilizationDetails")
    def to_get_savings_plans_utilization_details(self) -> "Ce":
        '''(experimental) Grants permission to retrieve the Savings Plans utilization details for your account.

        Access Level: Read

        https://docs.aws.amazon.com/aws-cost-management/latest/APIReference/API_GetSavingsPlansUtilizationDetails.html

        :stability: experimental
        '''
        return typing.cast("Ce", jsii.invoke(self, "toGetSavingsPlansUtilizationDetails", []))

    @jsii.member(jsii_name="toGetTags")
    def to_get_tags(self) -> "Ce":
        '''(experimental) Grants permission to query tags for a specified time period.

        Access Level: Read

        https://docs.aws.amazon.com/aws-cost-management/latest/APIReference/API_GetTags.html

        :stability: experimental
        '''
        return typing.cast("Ce", jsii.invoke(self, "toGetTags", []))

    @jsii.member(jsii_name="toGetUsageForecast")
    def to_get_usage_forecast(self) -> "Ce":
        '''(experimental) Grants permission to retrieve a usage forecast for a forecast time period.

        Access Level: Read

        https://docs.aws.amazon.com/aws-cost-management/latest/APIReference/API_GetUsageForecast.html

        :stability: experimental
        '''
        return typing.cast("Ce", jsii.invoke(self, "toGetUsageForecast", []))

    @jsii.member(jsii_name="toListCostAllocationTags")
    def to_list_cost_allocation_tags(self) -> "Ce":
        '''(experimental) Grants permission to list Cost Allocation Tags.

        Access Level: List

        https://docs.aws.amazon.com/aws-cost-management/latest/APIReference/API_ListCostAllocationTags.html

        :stability: experimental
        '''
        return typing.cast("Ce", jsii.invoke(self, "toListCostAllocationTags", []))

    @jsii.member(jsii_name="toListCostCategoryDefinitions")
    def to_list_cost_category_definitions(self) -> "Ce":
        '''(experimental) Grants permission to retrieve names, ARN, and effective dates for all Cost Categories.

        Access Level: List

        https://docs.aws.amazon.com/aws-cost-management/latest/APIReference/API_ListCostCategoryDefinitions.html

        :stability: experimental
        '''
        return typing.cast("Ce", jsii.invoke(self, "toListCostCategoryDefinitions", []))

    @jsii.member(jsii_name="toListSavingsPlansPurchaseRecommendationGeneration")
    def to_list_savings_plans_purchase_recommendation_generation(self) -> "Ce":
        '''(experimental) Grants permission to retrieve a list of your historical recommendation generations.

        Access Level: List

        https://docs.aws.amazon.com/aws-cost-management/latest/APIReference/API_ListSavingsPlansPurchaseRecommendationGeneration.html

        :stability: experimental
        '''
        return typing.cast("Ce", jsii.invoke(self, "toListSavingsPlansPurchaseRecommendationGeneration", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Ce":
        '''(experimental) Grants permission to list tags for a Cost Explorer resource.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/aws-cost-management/latest/APIReference/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("Ce", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toProvideAnomalyFeedback")
    def to_provide_anomaly_feedback(self) -> "Ce":
        '''(experimental) Grants permission to provide feedback on detected anomalies.

        Access Level: Write

        https://docs.aws.amazon.com/aws-cost-management/latest/APIReference/API_ProvideAnomalyFeedback.html

        :stability: experimental
        '''
        return typing.cast("Ce", jsii.invoke(self, "toProvideAnomalyFeedback", []))

    @jsii.member(jsii_name="toStartSavingsPlansPurchaseRecommendationGeneration")
    def to_start_savings_plans_purchase_recommendation_generation(self) -> "Ce":
        '''(experimental) Grants permission to request a Savings Plans recommendation generation.

        Access Level: Write

        https://docs.aws.amazon.com/aws-cost-management/latest/APIReference/API_StartSavingsPlansPurchaseRecommendationGeneration.html

        :stability: experimental
        '''
        return typing.cast("Ce", jsii.invoke(self, "toStartSavingsPlansPurchaseRecommendationGeneration", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Ce":
        '''(experimental) Grants permission to tag a Cost Explorer resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()
        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/aws-cost-management/latest/APIReference/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("Ce", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Ce":
        '''(experimental) Grants permission to remove tags from a Cost Explorer resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/aws-cost-management/latest/APIReference/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("Ce", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateAnomalyMonitor")
    def to_update_anomaly_monitor(self) -> "Ce":
        '''(experimental) Grants permission to update an existing Anomaly Monitor.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/aws-cost-management/latest/APIReference/API_UpdateAnomalyMonitor.html

        :stability: experimental
        '''
        return typing.cast("Ce", jsii.invoke(self, "toUpdateAnomalyMonitor", []))

    @jsii.member(jsii_name="toUpdateAnomalySubscription")
    def to_update_anomaly_subscription(self) -> "Ce":
        '''(experimental) Grants permission to update an existing Anomaly Subscription.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/aws-cost-management/latest/APIReference/API_UpdateAnomalySubscription.html

        :stability: experimental
        '''
        return typing.cast("Ce", jsii.invoke(self, "toUpdateAnomalySubscription", []))

    @jsii.member(jsii_name="toUpdateCostAllocationTagsStatus")
    def to_update_cost_allocation_tags_status(self) -> "Ce":
        '''(experimental) Grants permission to update existing Cost Allocation Tags status.

        Access Level: Write

        https://docs.aws.amazon.com/aws-cost-management/latest/APIReference/API_UpdateCostAllocationTagsStatus.html

        :stability: experimental
        '''
        return typing.cast("Ce", jsii.invoke(self, "toUpdateCostAllocationTagsStatus", []))

    @jsii.member(jsii_name="toUpdateCostCategoryDefinition")
    def to_update_cost_category_definition(self) -> "Ce":
        '''(experimental) Grants permission to update an existing Cost Category.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/aws-cost-management/latest/APIReference/API_UpdateCostCategoryDefinition.html

        :stability: experimental
        '''
        return typing.cast("Ce", jsii.invoke(self, "toUpdateCostCategoryDefinition", []))

    @jsii.member(jsii_name="toUpdateNotificationSubscription")
    def to_update_notification_subscription(self) -> "Ce":
        '''(experimental) Grants permission to update Reservation expiration alerts.

        Access Level: Write

        https://docs.aws.amazon.com/awsaccountbilling/latest/aboutv2/billing-permissions-ref.html

        :stability: experimental
        '''
        return typing.cast("Ce", jsii.invoke(self, "toUpdateNotificationSubscription", []))

    @jsii.member(jsii_name="toUpdatePreferences")
    def to_update_preferences(self) -> "Ce":
        '''(experimental) Grants permission to edit Cost Explorer Preferences page.

        Access Level: Write

        https://docs.aws.amazon.com/awsaccountbilling/latest/aboutv2/billing-permissions-ref.html

        :stability: experimental
        '''
        return typing.cast("Ce", jsii.invoke(self, "toUpdatePreferences", []))

    @jsii.member(jsii_name="toUpdateReport")
    def to_update_report(self) -> "Ce":
        '''(experimental) Grants permission to update Cost Explorer Reports.

        Access Level: Write

        https://docs.aws.amazon.com/awsaccountbilling/latest/aboutv2/billing-permissions-ref.html

        :stability: experimental
        '''
        return typing.cast("Ce", jsii.invoke(self, "toUpdateReport", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__503e3ae9a82b01bec357859604c920246d06f08bfb22b0f0bd919c699611cceb)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__53c5aaf3166ed981bedbeee841a8580b55b4530469e0c35d14669cd10857a6cc)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Chatbot(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Chatbot",
):
    '''(experimental) Statement provider for service `chatbot <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awschatbot.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `chatbot <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awschatbot.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onChatbotConfiguration")
    def on_chatbot_configuration(
        self,
        configuration_type: builtins.str,
        chatbot_configuration_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Chatbot":
        '''(experimental) Adds a resource of type ChatbotConfiguration to the statement.

        https://docs.aws.amazon.com/chatbot/latest/adminguide/what-is.html

        :param configuration_type: - Identifier for the configurationType.
        :param chatbot_configuration_name: - Identifier for the chatbotConfigurationName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ad8ca404b74979d7e2910c6b5151b8c57c0d3f328c94abae95da1911bab1c7c3)
            check_type(argname="argument configuration_type", value=configuration_type, expected_type=type_hints["configuration_type"])
            check_type(argname="argument chatbot_configuration_name", value=chatbot_configuration_name, expected_type=type_hints["chatbot_configuration_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Chatbot", jsii.invoke(self, "onChatbotConfiguration", [configuration_type, chatbot_configuration_name, account, partition]))

    @jsii.member(jsii_name="toCreateChimeWebhookConfiguration")
    def to_create_chime_webhook_configuration(self) -> "Chatbot":
        '''(experimental) Grants permission to create an AWS Chatbot Chime Webhook Configuration.

        Access Level: Write

        :stability: experimental
        '''
        return typing.cast("Chatbot", jsii.invoke(self, "toCreateChimeWebhookConfiguration", []))

    @jsii.member(jsii_name="toCreateSlackChannelConfiguration")
    def to_create_slack_channel_configuration(self) -> "Chatbot":
        '''(experimental) Grants permission to create an AWS Chatbot Slack Channel Configuration.

        Access Level: Write

        :stability: experimental
        '''
        return typing.cast("Chatbot", jsii.invoke(self, "toCreateSlackChannelConfiguration", []))

    @jsii.member(jsii_name="toDeleteChimeWebhookConfiguration")
    def to_delete_chime_webhook_configuration(self) -> "Chatbot":
        '''(experimental) Grants permission to delete an AWS Chatbot Chime Webhook Configuration.

        Access Level: Write

        :stability: experimental
        '''
        return typing.cast("Chatbot", jsii.invoke(self, "toDeleteChimeWebhookConfiguration", []))

    @jsii.member(jsii_name="toDeleteSlackChannelConfiguration")
    def to_delete_slack_channel_configuration(self) -> "Chatbot":
        '''(experimental) Grants permission to delete an AWS Chatbot Slack Channel Configuration.

        Access Level: Write

        :stability: experimental
        '''
        return typing.cast("Chatbot", jsii.invoke(self, "toDeleteSlackChannelConfiguration", []))

    @jsii.member(jsii_name="toDeleteSlackUserIdentity")
    def to_delete_slack_user_identity(self) -> "Chatbot":
        '''(experimental) Grants permission to delete an AWS Chatbot Slack User Identity.

        Access Level: Write

        :stability: experimental
        '''
        return typing.cast("Chatbot", jsii.invoke(self, "toDeleteSlackUserIdentity", []))

    @jsii.member(jsii_name="toDeleteSlackWorkspaceAuthorization")
    def to_delete_slack_workspace_authorization(self) -> "Chatbot":
        '''(experimental) Grants permission to delete the Slack workspace authorization with AWS Chatbot, associated with an AWS account.

        Access Level: Write

        :stability: experimental
        '''
        return typing.cast("Chatbot", jsii.invoke(self, "toDeleteSlackWorkspaceAuthorization", []))

    @jsii.member(jsii_name="toDescribeChimeWebhookConfigurations")
    def to_describe_chime_webhook_configurations(self) -> "Chatbot":
        '''(experimental) Grants permission to list all AWS Chatbot Chime Webhook Configurations in an AWS Account.

        Access Level: Read

        :stability: experimental
        '''
        return typing.cast("Chatbot", jsii.invoke(self, "toDescribeChimeWebhookConfigurations", []))

    @jsii.member(jsii_name="toDescribeSlackChannelConfigurations")
    def to_describe_slack_channel_configurations(self) -> "Chatbot":
        '''(experimental) Grants permission to list all AWS Chatbot Slack Channel Configurations in an AWS account.

        Access Level: Read

        :stability: experimental
        '''
        return typing.cast("Chatbot", jsii.invoke(self, "toDescribeSlackChannelConfigurations", []))

    @jsii.member(jsii_name="toDescribeSlackChannels")
    def to_describe_slack_channels(self) -> "Chatbot":
        '''(experimental) Grants permission to list all public Slack channels in the Slack workspace connected to the AWS Account onboarded with AWS Chatbot service.

        Access Level: Read

        :stability: experimental
        '''
        return typing.cast("Chatbot", jsii.invoke(self, "toDescribeSlackChannels", []))

    @jsii.member(jsii_name="toDescribeSlackUserIdentities")
    def to_describe_slack_user_identities(self) -> "Chatbot":
        '''(experimental) Grants permission to describe AWS Chatbot Slack User Identities.

        Access Level: Read

        :stability: experimental
        '''
        return typing.cast("Chatbot", jsii.invoke(self, "toDescribeSlackUserIdentities", []))

    @jsii.member(jsii_name="toDescribeSlackWorkspaces")
    def to_describe_slack_workspaces(self) -> "Chatbot":
        '''(experimental) Grants permission to list all authorized Slack workspaces connected to the AWS Account onboarded with AWS Chatbot service.

        Access Level: Read

        :stability: experimental
        '''
        return typing.cast("Chatbot", jsii.invoke(self, "toDescribeSlackWorkspaces", []))

    @jsii.member(jsii_name="toGetAccountPreferences")
    def to_get_account_preferences(self) -> "Chatbot":
        '''(experimental) Grants permission to retrieve AWS Chatbot account preferences.

        Access Level: Read

        :stability: experimental
        '''
        return typing.cast("Chatbot", jsii.invoke(self, "toGetAccountPreferences", []))

    @jsii.member(jsii_name="toGetSlackOauthParameters")
    def to_get_slack_oauth_parameters(self) -> "Chatbot":
        '''(experimental) Grants permission to generate OAuth parameters to request Slack OAuth code to be used by the AWS Chatbot service.

        Access Level: Read

        :stability: experimental
        '''
        return typing.cast("Chatbot", jsii.invoke(self, "toGetSlackOauthParameters", []))

    @jsii.member(jsii_name="toRedeemSlackOauthCode")
    def to_redeem_slack_oauth_code(self) -> "Chatbot":
        '''(experimental) Grants permission to redeem previously generated parameters with Slack API, to acquire OAuth tokens to be used by the AWS Chatbot service.

        Access Level: Write

        :stability: experimental
        '''
        return typing.cast("Chatbot", jsii.invoke(self, "toRedeemSlackOauthCode", []))

    @jsii.member(jsii_name="toUpdateAccountPreferences")
    def to_update_account_preferences(self) -> "Chatbot":
        '''(experimental) Grants permission to update AWS Chatbot account preferences.

        Access Level: Write

        :stability: experimental
        '''
        return typing.cast("Chatbot", jsii.invoke(self, "toUpdateAccountPreferences", []))

    @jsii.member(jsii_name="toUpdateChimeWebhookConfiguration")
    def to_update_chime_webhook_configuration(self) -> "Chatbot":
        '''(experimental) Grants permission to update an AWS Chatbot Chime Webhook Configuration.

        Access Level: Write

        :stability: experimental
        '''
        return typing.cast("Chatbot", jsii.invoke(self, "toUpdateChimeWebhookConfiguration", []))

    @jsii.member(jsii_name="toUpdateSlackChannelConfiguration")
    def to_update_slack_channel_configuration(self) -> "Chatbot":
        '''(experimental) Grants permission to update an AWS Chatbot Slack Channel Configuration.

        Access Level: Write

        :stability: experimental
        '''
        return typing.cast("Chatbot", jsii.invoke(self, "toUpdateSlackChannelConfiguration", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__39fde3f56bd5c31a6268e693bf519d980ee4ce7c53bea280138291944acae643)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__efe7beec108407a08bb101b931c419203668061fd6d3303b778cad23f312bd47)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Chime(PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Chime"):
    '''(experimental) Statement provider for service `chime <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonchime.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `chime <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonchime.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onAppInstance")
    def on_app_instance(
        self,
        app_instance_id: builtins.str,
        account_id: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Chime":
        '''(experimental) Adds a resource of type app-instance to the statement.

        https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_identity-chime_AppInstance.html

        :param app_instance_id: - Identifier for the appInstanceId.
        :param account_id: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__eabbe76731fc6a1165359cbceab32e2d8f6ea3a9196e26ffd0c4c5658218241e)
            check_type(argname="argument app_instance_id", value=app_instance_id, expected_type=type_hints["app_instance_id"])
            check_type(argname="argument account_id", value=account_id, expected_type=type_hints["account_id"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Chime", jsii.invoke(self, "onAppInstance", [app_instance_id, account_id, region, partition]))

    @jsii.member(jsii_name="onAppInstanceUser")
    def on_app_instance_user(
        self,
        app_instance_id: builtins.str,
        app_instance_user_id: builtins.str,
        account_id: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Chime":
        '''(experimental) Adds a resource of type app-instance-user to the statement.

        https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_identity-chime_AppInstanceUser.html

        :param app_instance_id: - Identifier for the appInstanceId.
        :param app_instance_user_id: - Identifier for the appInstanceUserId.
        :param account_id: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c2916683995def40f3fed18009d4ecf6f55377b77e90ba2b26c8f933ea5aa144)
            check_type(argname="argument app_instance_id", value=app_instance_id, expected_type=type_hints["app_instance_id"])
            check_type(argname="argument app_instance_user_id", value=app_instance_user_id, expected_type=type_hints["app_instance_user_id"])
            check_type(argname="argument account_id", value=account_id, expected_type=type_hints["account_id"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Chime", jsii.invoke(self, "onAppInstanceUser", [app_instance_id, app_instance_user_id, account_id, region, partition]))

    @jsii.member(jsii_name="onChannel")
    def on_channel(
        self,
        app_instance_id: builtins.str,
        channel_id: builtins.str,
        account_id: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Chime":
        '''(experimental) Adds a resource of type channel to the statement.

        https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_messaging-chime_Channel.html

        :param app_instance_id: - Identifier for the appInstanceId.
        :param channel_id: - Identifier for the channelId.
        :param account_id: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0322f090dbffce340a28b2ed8d1838e0c23b620c19b20b7573e73e4b3fbf1012)
            check_type(argname="argument app_instance_id", value=app_instance_id, expected_type=type_hints["app_instance_id"])
            check_type(argname="argument channel_id", value=channel_id, expected_type=type_hints["channel_id"])
            check_type(argname="argument account_id", value=account_id, expected_type=type_hints["account_id"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Chime", jsii.invoke(self, "onChannel", [app_instance_id, channel_id, account_id, region, partition]))

    @jsii.member(jsii_name="onChannelFlow")
    def on_channel_flow(
        self,
        app_instance_id: builtins.str,
        channel_flow_id: builtins.str,
        account_id: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Chime":
        '''(experimental) Adds a resource of type channel-flow to the statement.

        https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_messaging-chime_ChannelFlow.html

        :param app_instance_id: - Identifier for the appInstanceId.
        :param channel_flow_id: - Identifier for the channelFlowId.
        :param account_id: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__75f44d8b451f7ee8b37bac22923755873637cac47fbbd44d64a18e058e92a669)
            check_type(argname="argument app_instance_id", value=app_instance_id, expected_type=type_hints["app_instance_id"])
            check_type(argname="argument channel_flow_id", value=channel_flow_id, expected_type=type_hints["channel_flow_id"])
            check_type(argname="argument account_id", value=account_id, expected_type=type_hints["account_id"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Chime", jsii.invoke(self, "onChannelFlow", [app_instance_id, channel_flow_id, account_id, region, partition]))

    @jsii.member(jsii_name="onMediaPipeline")
    def on_media_pipeline(
        self,
        media_pipeline_id: builtins.str,
        account_id: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Chime":
        '''(experimental) Adds a resource of type media-pipeline to the statement.

        https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_media-pipelines-chime_MediaPipeline.html

        :param media_pipeline_id: - Identifier for the mediaPipelineId.
        :param account_id: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6a524e3e7ee3e74abdf2485e28455b8dc6f7e861a30dc84d48feb59a5ce02c57)
            check_type(argname="argument media_pipeline_id", value=media_pipeline_id, expected_type=type_hints["media_pipeline_id"])
            check_type(argname="argument account_id", value=account_id, expected_type=type_hints["account_id"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Chime", jsii.invoke(self, "onMediaPipeline", [media_pipeline_id, account_id, region, partition]))

    @jsii.member(jsii_name="onMeeting")
    def on_meeting(
        self,
        meeting_id: builtins.str,
        account_id: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Chime":
        '''(experimental) Adds a resource of type meeting to the statement.

        https://docs.aws.amazon.com/chime/latest/APIReference/API_Meeting.html

        :param meeting_id: - Identifier for the meetingId.
        :param account_id: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__88bad4e77fa476aeadf6deaa62a2f29018397cdd9b19e6e1f82d5df736600f9c)
            check_type(argname="argument meeting_id", value=meeting_id, expected_type=type_hints["meeting_id"])
            check_type(argname="argument account_id", value=account_id, expected_type=type_hints["account_id"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Chime", jsii.invoke(self, "onMeeting", [meeting_id, account_id, partition]))

    @jsii.member(jsii_name="toAcceptDelegate")
    def to_accept_delegate(self) -> "Chime":
        '''(experimental) Grants permission to accept the delegate invitation to share management of an Amazon Chime account with another AWS Account.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/ag/control-access.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toAcceptDelegate", []))

    @jsii.member(jsii_name="toActivateUsers")
    def to_activate_users(self) -> "Chime":
        '''(experimental) Grants permission to activate users in an Amazon Chime Enterprise account.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/ag/manage-access.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toActivateUsers", []))

    @jsii.member(jsii_name="toAddDomain")
    def to_add_domain(self) -> "Chime":
        '''(experimental) Grants permission to add a domain to your Amazon Chime account.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/ag/claim-domain.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toAddDomain", []))

    @jsii.member(jsii_name="toAddOrUpdateGroups")
    def to_add_or_update_groups(self) -> "Chime":
        '''(experimental) Grants permission to add new or update existing Active Directory or Okta user groups associated with your Amazon Chime Enterprise account.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/ag/manage-chime-account.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toAddOrUpdateGroups", []))

    @jsii.member(jsii_name="toAssociateChannelFlow")
    def to_associate_channel_flow(self) -> "Chime":
        '''(experimental) Grants permission to associate a flow with a channel.

        Access Level: Write

        https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_messaging-chime_AssociateChannelFlow.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toAssociateChannelFlow", []))

    @jsii.member(jsii_name="toAssociatePhoneNumbersWithVoiceConnector")
    def to_associate_phone_numbers_with_voice_connector(self) -> "Chime":
        '''(experimental) Grants permission to associate multiple phone numbers with an Amazon Chime Voice Connector.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/APIReference/API_AssociatePhoneNumbersWithVoiceConnector.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toAssociatePhoneNumbersWithVoiceConnector", []))

    @jsii.member(jsii_name="toAssociatePhoneNumbersWithVoiceConnectorGroup")
    def to_associate_phone_numbers_with_voice_connector_group(self) -> "Chime":
        '''(experimental) Grants permission to associate multiple phone numbers with an Amazon Chime Voice Connector Group.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/APIReference/API_AssociatePhoneNumbersWithVoiceConnectorGroup.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toAssociatePhoneNumbersWithVoiceConnectorGroup", []))

    @jsii.member(jsii_name="toAssociatePhoneNumberWithUser")
    def to_associate_phone_number_with_user(self) -> "Chime":
        '''(experimental) Grants permission to associate a phone number with an Amazon Chime user.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/APIReference/API_AssociatePhoneNumberWithUser.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toAssociatePhoneNumberWithUser", []))

    @jsii.member(jsii_name="toAssociateSigninDelegateGroupsWithAccount")
    def to_associate_signin_delegate_groups_with_account(self) -> "Chime":
        '''(experimental) Grants permission to associate the specified sign-in delegate groups with the specified Amazon Chime account.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/APIReference/API_AssociateSigninDelegateGroupsWithAccount.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toAssociateSigninDelegateGroupsWithAccount", []))

    @jsii.member(jsii_name="toAuthorizeDirectory")
    def to_authorize_directory(self) -> "Chime":
        '''(experimental) Grants permission to authorize an Active Directory for your Amazon Chime Enterprise account.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/ag/control-access.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toAuthorizeDirectory", []))

    @jsii.member(jsii_name="toBatchCreateAttendee")
    def to_batch_create_attendee(self) -> "Chime":
        '''(experimental) Grants permission to create new attendees for an active Amazon Chime SDK meeting.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/APIReference/API_BatchCreateAttendee.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toBatchCreateAttendee", []))

    @jsii.member(jsii_name="toBatchCreateChannelMembership")
    def to_batch_create_channel_membership(self) -> "Chime":
        '''(experimental) Grants permission to add multiple users to a channel.

        Access Level: Write

        https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_messaging-chime_BatchCreateChannelMembership.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toBatchCreateChannelMembership", []))

    @jsii.member(jsii_name="toBatchCreateRoomMembership")
    def to_batch_create_room_membership(self) -> "Chime":
        '''(experimental) Grants permission to batch add room members.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/APIReference/API_BatchCreateRoomMembership.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toBatchCreateRoomMembership", []))

    @jsii.member(jsii_name="toBatchDeletePhoneNumber")
    def to_batch_delete_phone_number(self) -> "Chime":
        '''(experimental) Grants permission to move up to 50 phone numbers to the deletion queue.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/APIReference/API_BatchDeletePhoneNumber.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toBatchDeletePhoneNumber", []))

    @jsii.member(jsii_name="toBatchSuspendUser")
    def to_batch_suspend_user(self) -> "Chime":
        '''(experimental) Grants permission to suspend up to 50 users from a Team or EnterpriseLWA Amazon Chime account.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/APIReference/API_BatchSuspendUser.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toBatchSuspendUser", []))

    @jsii.member(jsii_name="toBatchUnsuspendUser")
    def to_batch_unsuspend_user(self) -> "Chime":
        '''(experimental) Grants permission to remove the suspension from up to 50 previously suspended users for the specified Amazon Chime EnterpriseLWA account.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/APIReference/API_BatchUnsuspendUser.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toBatchUnsuspendUser", []))

    @jsii.member(jsii_name="toBatchUpdateAttendeeCapabilitiesExcept")
    def to_batch_update_attendee_capabilities_except(self) -> "Chime":
        '''(experimental) Grants permission to update AttendeeCapabilities except the capabilities listed in an ExcludedAttendeeIds table.

        Access Level: Write

        https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_meeting-chime_BatchUpdateAttendeeCapabilitiesExcept.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toBatchUpdateAttendeeCapabilitiesExcept", []))

    @jsii.member(jsii_name="toBatchUpdatePhoneNumber")
    def to_batch_update_phone_number(self) -> "Chime":
        '''(experimental) Grants permission to update phone number details within the UpdatePhoneNumberRequestItem object for up to 50 phone numbers.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/APIReference/API_BatchUpdatePhoneNumber.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toBatchUpdatePhoneNumber", []))

    @jsii.member(jsii_name="toBatchUpdateUser")
    def to_batch_update_user(self) -> "Chime":
        '''(experimental) Grants permission to update user details within the UpdateUserRequestItem object for up to 20 users for the specified Amazon Chime account.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/APIReference/API_BatchUpdateUser.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toBatchUpdateUser", []))

    @jsii.member(jsii_name="toChannelFlowCallback")
    def to_channel_flow_callback(self) -> "Chime":
        '''(experimental) Grants permission to callback for a message on a channel.

        Access Level: Write

        https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_messaging-chime_ChannelFlowCallback.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toChannelFlowCallback", []))

    @jsii.member(jsii_name="toConnect")
    def to_connect(self) -> "Chime":
        '''(experimental) Grants permission to establish a web socket connection for app instance user to the messaging session endpoint.

        Access Level: Write

        https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_messaging-chime_Connect.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toConnect", []))

    @jsii.member(jsii_name="toConnectDirectory")
    def to_connect_directory(self) -> "Chime":
        '''(experimental) Grants permission to connect an Active Directory to your Amazon Chime Enterprise account.

        Access Level: Write

        Dependent actions:

        - ds:ConnectDirectory

        https://docs.aws.amazon.com/chime/latest/ag/active_directory.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toConnectDirectory", []))

    @jsii.member(jsii_name="toCreateAccount")
    def to_create_account(self) -> "Chime":
        '''(experimental) Grants permission to create an Amazon Chime account under the administrator's AWS account.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/APIReference/API_CreateAccount.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toCreateAccount", []))

    @jsii.member(jsii_name="toCreateApiKey")
    def to_create_api_key(self) -> "Chime":
        '''(experimental) Grants permission to create a new SCIM access key for your Amazon Chime account and Okta configuration.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/ag/okta_sso.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toCreateApiKey", []))

    @jsii.member(jsii_name="toCreateAppInstance")
    def to_create_app_instance(self) -> "Chime":
        '''(experimental) Grants permission to create an app instance under the AWS account.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_identity-chime_CreateAppInstance.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toCreateAppInstance", []))

    @jsii.member(jsii_name="toCreateAppInstanceAdmin")
    def to_create_app_instance_admin(self) -> "Chime":
        '''(experimental) Grants permission to promote an AppInstanceUser to an AppInstanceAdmin.

        Access Level: Write

        https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_identity-chime_CreateAppInstanceAdmin.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toCreateAppInstanceAdmin", []))

    @jsii.member(jsii_name="toCreateAppInstanceUser")
    def to_create_app_instance_user(self) -> "Chime":
        '''(experimental) Grants permission to create a user under an Amazon Chime AppInstance.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_identity-chime_CreateAppInstanceUser.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toCreateAppInstanceUser", []))

    @jsii.member(jsii_name="toCreateAttendee")
    def to_create_attendee(self) -> "Chime":
        '''(experimental) Grants permission to create a new attendee for an active Amazon Chime SDK meeting.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/APIReference/API_CreateAttendee.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toCreateAttendee", []))

    @jsii.member(jsii_name="toCreateBot")
    def to_create_bot(self) -> "Chime":
        '''(experimental) Grants permission to create a bot for an Amazon Chime Enterprise account.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/APIReference/API_CreateBot.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toCreateBot", []))

    @jsii.member(jsii_name="toCreateCDRBucket")
    def to_create_cdr_bucket(self) -> "Chime":
        '''(experimental) Grants permission to create a new Call Detail Record S3 bucket.

        Access Level: Write

        Dependent actions:

        - s3:CreateBucket
        - s3:ListAllMyBuckets

        https://docs.aws.amazon.com/chime/latest/ag/manage-access.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toCreateCDRBucket", []))

    @jsii.member(jsii_name="toCreateChannel")
    def to_create_channel(self) -> "Chime":
        '''(experimental) Grants permission to create a channel for an app instance under the AWS account.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_messaging-chime_CreateChannel.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toCreateChannel", []))

    @jsii.member(jsii_name="toCreateChannelBan")
    def to_create_channel_ban(self) -> "Chime":
        '''(experimental) Grants permission to ban a user from a channel.

        Access Level: Write

        https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_messaging-chime_CreateChannelBan.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toCreateChannelBan", []))

    @jsii.member(jsii_name="toCreateChannelFlow")
    def to_create_channel_flow(self) -> "Chime":
        '''(experimental) Grants permission to create a channel flow for an app instance under the AWS account.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_messaging-chime_CreateChannelFlow.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toCreateChannelFlow", []))

    @jsii.member(jsii_name="toCreateChannelMembership")
    def to_create_channel_membership(self) -> "Chime":
        '''(experimental) Grants permission to add a user to a channel.

        Access Level: Write

        https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_messaging-chime_CreateChannelMembership.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toCreateChannelMembership", []))

    @jsii.member(jsii_name="toCreateChannelModerator")
    def to_create_channel_moderator(self) -> "Chime":
        '''(experimental) Grants permission to create a channel moderator.

        Access Level: Write

        https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_messaging-chime_CreateChannelModerator.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toCreateChannelModerator", []))

    @jsii.member(jsii_name="toCreateMediaCapturePipeline")
    def to_create_media_capture_pipeline(self) -> "Chime":
        '''(experimental) Grants permission to create a media capture pipeline.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        Dependent actions:

        - s3:GetBucketPolicy

        https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_media-pipelines-chime_CreateMediaCapturePipeline.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toCreateMediaCapturePipeline", []))

    @jsii.member(jsii_name="toCreateMediaConcatenationPipeline")
    def to_create_media_concatenation_pipeline(self) -> "Chime":
        '''(experimental) Grants permission to create a media concatenation pipeline.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        Dependent actions:

        - s3:GetBucketPolicy

        https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_media-pipelines-chime_CreateMediaConcatenationPipeline.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toCreateMediaConcatenationPipeline", []))

    @jsii.member(jsii_name="toCreateMediaLiveConnectorPipeline")
    def to_create_media_live_connector_pipeline(self) -> "Chime":
        '''(experimental) Grants permission to create a media live connector pipeline.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_media-pipelines-chime_CreateMediaLiveConnectorPipeline.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toCreateMediaLiveConnectorPipeline", []))

    @jsii.member(jsii_name="toCreateMeeting")
    def to_create_meeting(self) -> "Chime":
        '''(experimental) Grants permission to create a new Amazon Chime SDK meeting in the specified media Region, with no initial attendees.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/chime/latest/APIReference/API_CreateMeeting.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toCreateMeeting", []))

    @jsii.member(jsii_name="toCreateMeetingDialOut")
    def to_create_meeting_dial_out(self) -> "Chime":
        '''(experimental) Grants permission to call a phone number to join the specified Amazon Chime SDK meeting.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/APIReference/API_CreateMeetingDialOut.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toCreateMeetingDialOut", []))

    @jsii.member(jsii_name="toCreateMeetingWithAttendees")
    def to_create_meeting_with_attendees(self) -> "Chime":
        '''(experimental) Grants permission to create a new Amazon Chime SDK meeting in the specified media Region, with a set of attendees.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/chime/latest/APIReference/API_CreateMeetingWithAttendees.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toCreateMeetingWithAttendees", []))

    @jsii.member(jsii_name="toCreatePhoneNumberOrder")
    def to_create_phone_number_order(self) -> "Chime":
        '''(experimental) Grants permission to create a phone number order with the Carriers.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/APIReference/API_CreatePhoneNumberOrder.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toCreatePhoneNumberOrder", []))

    @jsii.member(jsii_name="toCreateProxySession")
    def to_create_proxy_session(self) -> "Chime":
        '''(experimental) Grants permission to create a proxy session for the specified Amazon Chime Voice Connector.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/APIReference/API_CreateProxySession.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toCreateProxySession", []))

    @jsii.member(jsii_name="toCreateRoom")
    def to_create_room(self) -> "Chime":
        '''(experimental) Grants permission to create a room.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/APIReference/API_CreateRoom.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toCreateRoom", []))

    @jsii.member(jsii_name="toCreateRoomMembership")
    def to_create_room_membership(self) -> "Chime":
        '''(experimental) Grants permission to add a room member.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/APIReference/API_CreateRoomMembership.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toCreateRoomMembership", []))

    @jsii.member(jsii_name="toCreateSipMediaApplication")
    def to_create_sip_media_application(self) -> "Chime":
        '''(experimental) Grants permission to create an Amazon Chime SIP media application under the administrator's AWS account.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/APIReference/API_CreateSipMediaApplication.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toCreateSipMediaApplication", []))

    @jsii.member(jsii_name="toCreateSipMediaApplicationCall")
    def to_create_sip_media_application_call(self) -> "Chime":
        '''(experimental) Grants permission to create outbound call for Amazon Chime SIP media application under the administrator's AWS account.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/APIReference/API_CreateSipMediaApplicationCall.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toCreateSipMediaApplicationCall", []))

    @jsii.member(jsii_name="toCreateSipRule")
    def to_create_sip_rule(self) -> "Chime":
        '''(experimental) Grants permission to create an Amazon Chime SIP rule under the administrator's AWS account.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/APIReference/API_CreateSipRule.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toCreateSipRule", []))

    @jsii.member(jsii_name="toCreateUser")
    def to_create_user(self) -> "Chime":
        '''(experimental) Grants permission to create a user under the specified Amazon Chime account.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/APIReference/API_CreateUser.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toCreateUser", []))

    @jsii.member(jsii_name="toCreateVoiceConnector")
    def to_create_voice_connector(self) -> "Chime":
        '''(experimental) Grants permission to create a Amazon Chime Voice Connector under the administrator's AWS account.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/APIReference/API_CreateVoiceConnector.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toCreateVoiceConnector", []))

    @jsii.member(jsii_name="toCreateVoiceConnectorGroup")
    def to_create_voice_connector_group(self) -> "Chime":
        '''(experimental) Grants permission to create a Amazon Chime Voice Connector Group under the administrator's AWS account.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/APIReference/API_CreateVoiceConnectorGroup.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toCreateVoiceConnectorGroup", []))

    @jsii.member(jsii_name="toDeleteAccount")
    def to_delete_account(self) -> "Chime":
        '''(experimental) Grants permission to delete the specified Amazon Chime account.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/APIReference/API_DeleteAccount.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toDeleteAccount", []))

    @jsii.member(jsii_name="toDeleteAccountOpenIdConfig")
    def to_delete_account_open_id_config(self) -> "Chime":
        '''(experimental) Grants permission to delete the OpenIdConfig attributes from your Amazon Chime account.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/ag/okta_sso.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toDeleteAccountOpenIdConfig", []))

    @jsii.member(jsii_name="toDeleteApiKey")
    def to_delete_api_key(self) -> "Chime":
        '''(experimental) Grants permission to delete the specified SCIM access key associated with your Amazon Chime account and Okta configuration.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/ag/okta_sso.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toDeleteApiKey", []))

    @jsii.member(jsii_name="toDeleteAppInstance")
    def to_delete_app_instance(self) -> "Chime":
        '''(experimental) Grants permission to delete an AppInstance.

        Access Level: Write

        https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_identity-chime_DeleteAppInstance.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toDeleteAppInstance", []))

    @jsii.member(jsii_name="toDeleteAppInstanceAdmin")
    def to_delete_app_instance_admin(self) -> "Chime":
        '''(experimental) Grants permission to demote an AppInstanceAdmin to an AppInstanceUser.

        Access Level: Write

        https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_identity-chime_DeleteAppInstanceAdmin.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toDeleteAppInstanceAdmin", []))

    @jsii.member(jsii_name="toDeleteAppInstanceStreamingConfigurations")
    def to_delete_app_instance_streaming_configurations(self) -> "Chime":
        '''(experimental) Grants permission to disable data streaming for the app instance.

        Access Level: Write

        https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_DeleteAppInstanceStreamingConfigurations.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toDeleteAppInstanceStreamingConfigurations", []))

    @jsii.member(jsii_name="toDeleteAppInstanceUser")
    def to_delete_app_instance_user(self) -> "Chime":
        '''(experimental) Grants permission to delete an AppInstanceUser.

        Access Level: Write

        https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_identity-chime_DeleteAppInstanceUser.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toDeleteAppInstanceUser", []))

    @jsii.member(jsii_name="toDeleteAttendee")
    def to_delete_attendee(self) -> "Chime":
        '''(experimental) Grants permission to delete the specified attendee from an Amazon Chime SDK meeting.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/APIReference/API_DeleteAttendee.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toDeleteAttendee", []))

    @jsii.member(jsii_name="toDeleteCDRBucket")
    def to_delete_cdr_bucket(self) -> "Chime":
        '''(experimental) Grants permission to delete a Call Detail Record S3 bucket from your Amazon Chime account.

        Access Level: Write

        Dependent actions:

        - s3:DeleteBucket

        https://docs.aws.amazon.com/chime/latest/ag/control-access.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toDeleteCDRBucket", []))

    @jsii.member(jsii_name="toDeleteChannel")
    def to_delete_channel(self) -> "Chime":
        '''(experimental) Grants permission to delete a channel.

        Access Level: Write

        https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_messaging-chime_DeleteChannel.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toDeleteChannel", []))

    @jsii.member(jsii_name="toDeleteChannelBan")
    def to_delete_channel_ban(self) -> "Chime":
        '''(experimental) Grants permission to remove a user from a channel's ban list.

        Access Level: Write

        https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_messaging-chime_DeleteChannelBan.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toDeleteChannelBan", []))

    @jsii.member(jsii_name="toDeleteChannelFlow")
    def to_delete_channel_flow(self) -> "Chime":
        '''(experimental) Grants permission to delete a channel flow.

        Access Level: Write

        https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_messaging-chime_DeleteChannelFlow.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toDeleteChannelFlow", []))

    @jsii.member(jsii_name="toDeleteChannelMembership")
    def to_delete_channel_membership(self) -> "Chime":
        '''(experimental) Grants permission to remove a member from a channel.

        Access Level: Write

        https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_messaging-chime_DeleteChannelMembership.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toDeleteChannelMembership", []))

    @jsii.member(jsii_name="toDeleteChannelMessage")
    def to_delete_channel_message(self) -> "Chime":
        '''(experimental) Grants permission to delete a channel message.

        Access Level: Write

        https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_messaging-chime_DeleteChannelMessage.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toDeleteChannelMessage", []))

    @jsii.member(jsii_name="toDeleteChannelModerator")
    def to_delete_channel_moderator(self) -> "Chime":
        '''(experimental) Grants permission to delete a channel moderator.

        Access Level: Write

        https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_messaging-chime_DeleteChannelModerator.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toDeleteChannelModerator", []))

    @jsii.member(jsii_name="toDeleteDelegate")
    def to_delete_delegate(self) -> "Chime":
        '''(experimental) Grants permission to delete delegated AWS account management from your Amazon Chime account.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/ag/control-access.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toDeleteDelegate", []))

    @jsii.member(jsii_name="toDeleteDomain")
    def to_delete_domain(self) -> "Chime":
        '''(experimental) Grants permission to delete a domain from your Amazon Chime account.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/ag/claim-domain.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toDeleteDomain", []))

    @jsii.member(jsii_name="toDeleteEventsConfiguration")
    def to_delete_events_configuration(self) -> "Chime":
        '''(experimental) Grants permission to delete an events configuration for a bot to receive outgoing events.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/APIReference/API_DeleteEventsConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toDeleteEventsConfiguration", []))

    @jsii.member(jsii_name="toDeleteGroups")
    def to_delete_groups(self) -> "Chime":
        '''(experimental) Grants permission to delete Active Directory or Okta user groups from your Amazon Chime Enterprise account.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/ag/control-access.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toDeleteGroups", []))

    @jsii.member(jsii_name="toDeleteMediaCapturePipeline")
    def to_delete_media_capture_pipeline(self) -> "Chime":
        '''(experimental) Grants permission to delete a media capture pipeline.

        Access Level: Write

        https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_media-pipelines-chime_DeleteMediaCapturePipeline.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toDeleteMediaCapturePipeline", []))

    @jsii.member(jsii_name="toDeleteMediaPipeline")
    def to_delete_media_pipeline(self) -> "Chime":
        '''(experimental) Grants permission to delete a media pipeline.

        Access Level: Write

        https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_media-pipelines-chime_DeleteMediaPipeline.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toDeleteMediaPipeline", []))

    @jsii.member(jsii_name="toDeleteMeeting")
    def to_delete_meeting(self) -> "Chime":
        '''(experimental) Grants permission to delete the specified Amazon Chime SDK meeting.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/APIReference/API_DeleteMeeting.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toDeleteMeeting", []))

    @jsii.member(jsii_name="toDeletePhoneNumber")
    def to_delete_phone_number(self) -> "Chime":
        '''(experimental) Grants permission to move a phone number to the deletion queue.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/APIReference/API_DeletePhoneNumber.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toDeletePhoneNumber", []))

    @jsii.member(jsii_name="toDeleteProxySession")
    def to_delete_proxy_session(self) -> "Chime":
        '''(experimental) Grants permission to delete a proxy session for the specified Amazon Chime Voice Connector.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/APIReference/API_DeleteProxySession.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toDeleteProxySession", []))

    @jsii.member(jsii_name="toDeleteRoom")
    def to_delete_room(self) -> "Chime":
        '''(experimental) Grants permission to delete a room.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/APIReference/API_DeleteRoom.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toDeleteRoom", []))

    @jsii.member(jsii_name="toDeleteRoomMembership")
    def to_delete_room_membership(self) -> "Chime":
        '''(experimental) Grants permission to remove a room member.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/APIReference/API_DeleteRoomMembership.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toDeleteRoomMembership", []))

    @jsii.member(jsii_name="toDeleteSipMediaApplication")
    def to_delete_sip_media_application(self) -> "Chime":
        '''(experimental) Grants permission to delete Amazon Chime SIP media application under the administrator's AWS account.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/APIReference/API_DeleteSipMediaApplication.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toDeleteSipMediaApplication", []))

    @jsii.member(jsii_name="toDeleteSipRule")
    def to_delete_sip_rule(self) -> "Chime":
        '''(experimental) Grants permission to delete Amazon Chime SIP rule under the administrator's AWS account.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/APIReference/API_DeleteSipRule.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toDeleteSipRule", []))

    @jsii.member(jsii_name="toDeleteVoiceConnector")
    def to_delete_voice_connector(self) -> "Chime":
        '''(experimental) Grants permission to delete the specified Amazon Chime Voice Connector.

        Access Level: Write

        Dependent actions:

        - logs:CreateLogDelivery
        - logs:DeleteLogDelivery
        - logs:GetLogDelivery
        - logs:ListLogDeliveries

        https://docs.aws.amazon.com/chime/latest/APIReference/API_DeleteVoiceConnector.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toDeleteVoiceConnector", []))

    @jsii.member(jsii_name="toDeleteVoiceConnectorEmergencyCallingConfiguration")
    def to_delete_voice_connector_emergency_calling_configuration(self) -> "Chime":
        '''(experimental) Grants permission to delete emergency calling configuration for the specified Amazon Chime Voice Connector.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/APIReference/API_DeleteVoiceConnectorEmergencyCallingConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toDeleteVoiceConnectorEmergencyCallingConfiguration", []))

    @jsii.member(jsii_name="toDeleteVoiceConnectorGroup")
    def to_delete_voice_connector_group(self) -> "Chime":
        '''(experimental) Grants permission to delete the specified Amazon Chime Voice Connector Group.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/APIReference/API_DeleteVoiceConnectorGroup.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toDeleteVoiceConnectorGroup", []))

    @jsii.member(jsii_name="toDeleteVoiceConnectorOrigination")
    def to_delete_voice_connector_origination(self) -> "Chime":
        '''(experimental) Grants permission to delete the origination settings for the specified Amazon Chime Voice Connector.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/APIReference/API_DeleteVoiceConnectorOrigination.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toDeleteVoiceConnectorOrigination", []))

    @jsii.member(jsii_name="toDeleteVoiceConnectorProxy")
    def to_delete_voice_connector_proxy(self) -> "Chime":
        '''(experimental) Grants permission to delete proxy configuration for the specified Amazon Chime Voice Connector.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/APIReference/API_DeleteVoiceConnectorProxy.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toDeleteVoiceConnectorProxy", []))

    @jsii.member(jsii_name="toDeleteVoiceConnectorStreamingConfiguration")
    def to_delete_voice_connector_streaming_configuration(self) -> "Chime":
        '''(experimental) Grants permission to delete streaming configuration for the specified Amazon Chime Voice Connector.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/APIReference/API_DeleteVoiceConnectorStreamingConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toDeleteVoiceConnectorStreamingConfiguration", []))

    @jsii.member(jsii_name="toDeleteVoiceConnectorTermination")
    def to_delete_voice_connector_termination(self) -> "Chime":
        '''(experimental) Grants permission to delete the termination settings for the specified Amazon Chime Voice Connector.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/APIReference/API_DeleteVoiceConnectorTermination.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toDeleteVoiceConnectorTermination", []))

    @jsii.member(jsii_name="toDeleteVoiceConnectorTerminationCredentials")
    def to_delete_voice_connector_termination_credentials(self) -> "Chime":
        '''(experimental) Grants permission to delete SIP termination credentials for the specified Amazon Chime Voice Connector.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/APIReference/API_DeleteVoiceConnectorTerminationCredentials.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toDeleteVoiceConnectorTerminationCredentials", []))

    @jsii.member(jsii_name="toDeregisterAppInstanceUserEndpoint")
    def to_deregister_app_instance_user_endpoint(self) -> "Chime":
        '''(experimental) Grants permission to deregister an endpoint for an app instance user.

        Access Level: Write

        https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_identity-chime_DeregisterAppInstanceUserEndpoint.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toDeregisterAppInstanceUserEndpoint", []))

    @jsii.member(jsii_name="toDescribeAppInstance")
    def to_describe_app_instance(self) -> "Chime":
        '''(experimental) Grants permission to get the full details of an AppInstance.

        Access Level: Read

        https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_identity-chime_DescribeAppInstance.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toDescribeAppInstance", []))

    @jsii.member(jsii_name="toDescribeAppInstanceAdmin")
    def to_describe_app_instance_admin(self) -> "Chime":
        '''(experimental) Grants permission to get the full details of an AppInstanceAdmin.

        Access Level: Read

        https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_identity-chime_DescribeAppInstanceAdmin.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toDescribeAppInstanceAdmin", []))

    @jsii.member(jsii_name="toDescribeAppInstanceUser")
    def to_describe_app_instance_user(self) -> "Chime":
        '''(experimental) Grants permission to get the full details of an AppInstanceUser.

        Access Level: Read

        https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_identity-chime_DescribeAppInstanceUser.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toDescribeAppInstanceUser", []))

    @jsii.member(jsii_name="toDescribeAppInstanceUserEndpoint")
    def to_describe_app_instance_user_endpoint(self) -> "Chime":
        '''(experimental) Grants permission to describe an endpoint registered for an app instance user.

        Access Level: Read

        https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_identity-chime_DescribeAppInstanceUserEndpoint.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toDescribeAppInstanceUserEndpoint", []))

    @jsii.member(jsii_name="toDescribeChannel")
    def to_describe_channel(self) -> "Chime":
        '''(experimental) Grants permission to get the full details of a channel.

        Access Level: Read

        https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_messaging-chime_DescribeChannel.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toDescribeChannel", []))

    @jsii.member(jsii_name="toDescribeChannelBan")
    def to_describe_channel_ban(self) -> "Chime":
        '''(experimental) Grants permission to get the full details of a channel ban.

        Access Level: Read

        https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_messaging-chime_DescribeChannelBan.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toDescribeChannelBan", []))

    @jsii.member(jsii_name="toDescribeChannelFlow")
    def to_describe_channel_flow(self) -> "Chime":
        '''(experimental) Grants permission to get the full details of a channel flow.

        Access Level: Read

        https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_messaging-chime_DescribeChannelFlow.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toDescribeChannelFlow", []))

    @jsii.member(jsii_name="toDescribeChannelMembership")
    def to_describe_channel_membership(self) -> "Chime":
        '''(experimental) Grants permission to get the full details of a channel membership.

        Access Level: Read

        https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_messaging-chime_DescribeChannelMembership.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toDescribeChannelMembership", []))

    @jsii.member(jsii_name="toDescribeChannelMembershipForAppInstanceUser")
    def to_describe_channel_membership_for_app_instance_user(self) -> "Chime":
        '''(experimental) Grants permission to get the details of a channel based on the membership of the specified AppInstanceUser.

        Access Level: Read

        https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_messaging-chime_DescribeChannelMembershipForAppInstanceUser.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toDescribeChannelMembershipForAppInstanceUser", []))

    @jsii.member(jsii_name="toDescribeChannelModeratedByAppInstanceUser")
    def to_describe_channel_moderated_by_app_instance_user(self) -> "Chime":
        '''(experimental) Grants permission to get the full details of a channel moderated by the specified AppInstanceUser.

        Access Level: Read

        https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_messaging-chime_DescribeChannelModeratedByAppInstanceUser.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toDescribeChannelModeratedByAppInstanceUser", []))

    @jsii.member(jsii_name="toDescribeChannelModerator")
    def to_describe_channel_moderator(self) -> "Chime":
        '''(experimental) Grants permission to get the full details of a single ChannelModerator.

        Access Level: Read

        https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_messaging-chime_DescribeChannelModerator.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toDescribeChannelModerator", []))

    @jsii.member(jsii_name="toDisassociateChannelFlow")
    def to_disassociate_channel_flow(self) -> "Chime":
        '''(experimental) Grants permission to disassociate a flow from a channel.

        Access Level: Write

        https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_messaging-chime_DisassociateChannelFlow.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toDisassociateChannelFlow", []))

    @jsii.member(jsii_name="toDisassociatePhoneNumberFromUser")
    def to_disassociate_phone_number_from_user(self) -> "Chime":
        '''(experimental) Grants permission to disassociate the primary provisioned number from the specified Amazon Chime user.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/APIReference/API_DisassociatePhoneNumberFromUser.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toDisassociatePhoneNumberFromUser", []))

    @jsii.member(jsii_name="toDisassociatePhoneNumbersFromVoiceConnector")
    def to_disassociate_phone_numbers_from_voice_connector(self) -> "Chime":
        '''(experimental) Grants permission to disassociate multiple phone numbers from the specified Amazon Chime Voice Connector.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/APIReference/API_DisassociatePhoneNumbersFromVoiceConnector.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toDisassociatePhoneNumbersFromVoiceConnector", []))

    @jsii.member(jsii_name="toDisassociatePhoneNumbersFromVoiceConnectorGroup")
    def to_disassociate_phone_numbers_from_voice_connector_group(self) -> "Chime":
        '''(experimental) Grants permission to disassociate multiple phone numbers from the specified Amazon Chime Voice Connector Group.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/APIReference/API_DisassociatePhoneNumbersFromVoiceConnectorGroup.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toDisassociatePhoneNumbersFromVoiceConnectorGroup", []))

    @jsii.member(jsii_name="toDisassociateSigninDelegateGroupsFromAccount")
    def to_disassociate_signin_delegate_groups_from_account(self) -> "Chime":
        '''(experimental) Grants permission to disassociate the specified sign-in delegate groups from the specified Amazon Chime account.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/APIReference/API_DisassociateSigninDelegateGroupsFromAccount.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toDisassociateSigninDelegateGroupsFromAccount", []))

    @jsii.member(jsii_name="toDisconnectDirectory")
    def to_disconnect_directory(self) -> "Chime":
        '''(experimental) Grants permission to disconnect the Active Directory from your Amazon Chime Enterprise account.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/ag/control-access.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toDisconnectDirectory", []))

    @jsii.member(jsii_name="toGetAccount")
    def to_get_account(self) -> "Chime":
        '''(experimental) Grants permission to get details for the specified Amazon Chime account.

        Access Level: Read

        https://docs.aws.amazon.com/chime/latest/APIReference/API_GetAccount.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toGetAccount", []))

    @jsii.member(jsii_name="toGetAccountResource")
    def to_get_account_resource(self) -> "Chime":
        '''(experimental) Grants permission to get details for the account resource associated with your Amazon Chime account.

        Access Level: Read

        https://docs.aws.amazon.com/chime/latest/ag/control-access.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toGetAccountResource", []))

    @jsii.member(jsii_name="toGetAccountSettings")
    def to_get_account_settings(self) -> "Chime":
        '''(experimental) Grants permission to get account settings for the specified Amazon Chime account ID.

        Access Level: Read

        https://docs.aws.amazon.com/chime/latest/APIReference/API_GetAccountSettings.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toGetAccountSettings", []))

    @jsii.member(jsii_name="toGetAccountWithOpenIdConfig")
    def to_get_account_with_open_id_config(self) -> "Chime":
        '''(experimental) Grants permission to get the account details and OpenIdConfig attributes for your Amazon Chime account.

        Access Level: Read

        https://docs.aws.amazon.com/chime/latest/ag/okta_sso.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toGetAccountWithOpenIdConfig", []))

    @jsii.member(jsii_name="toGetAppInstanceRetentionSettings")
    def to_get_app_instance_retention_settings(self) -> "Chime":
        '''(experimental) Grants permission to get retention settings for an app instance.

        Access Level: Read

        https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_identity-chime_GetAppInstanceRetentionSettings.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toGetAppInstanceRetentionSettings", []))

    @jsii.member(jsii_name="toGetAppInstanceStreamingConfigurations")
    def to_get_app_instance_streaming_configurations(self) -> "Chime":
        '''(experimental) Grants permission to get the streaming configurations for an app instance.

        Access Level: Read

        https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_GetAppInstanceStreamingConfigurations.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toGetAppInstanceStreamingConfigurations", []))

    @jsii.member(jsii_name="toGetAttendee")
    def to_get_attendee(self) -> "Chime":
        '''(experimental) Grants permission to get attendee details for a specified meeting ID and attendee ID.

        Access Level: Read

        https://docs.aws.amazon.com/chime/latest/APIReference/API_GetAttendee.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toGetAttendee", []))

    @jsii.member(jsii_name="toGetBot")
    def to_get_bot(self) -> "Chime":
        '''(experimental) Grants permission to retrieve details for the specified bot.

        Access Level: Read

        https://docs.aws.amazon.com/chime/latest/APIReference/API_GetBot.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toGetBot", []))

    @jsii.member(jsii_name="toGetCDRBucket")
    def to_get_cdr_bucket(self) -> "Chime":
        '''(experimental) Grants permission to get details of a Call Detail Record S3 bucket associated with your Amazon Chime account.

        Access Level: Read

        Dependent actions:

        - s3:GetBucketAcl
        - s3:GetBucketLocation
        - s3:GetBucketLogging
        - s3:GetBucketVersioning
        - s3:GetBucketWebsite

        https://docs.aws.amazon.com/chime/latest/ag/control-access.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toGetCDRBucket", []))

    @jsii.member(jsii_name="toGetChannelMembershipPreferences")
    def to_get_channel_membership_preferences(self) -> "Chime":
        '''(experimental) Grants permission to get the preferences for a channel membership.

        Access Level: Read

        https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_messaging-chime_GetChannelMembershipPreferences.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toGetChannelMembershipPreferences", []))

    @jsii.member(jsii_name="toGetChannelMessage")
    def to_get_channel_message(self) -> "Chime":
        '''(experimental) Grants permission to get the full details of a channel message.

        Access Level: Read

        https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_messaging-chime_GetChannelMessage.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toGetChannelMessage", []))

    @jsii.member(jsii_name="toGetChannelMessageStatus")
    def to_get_channel_message_status(self) -> "Chime":
        '''(experimental) Grants permission to get the status of a channel message.

        Access Level: Read

        https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_messaging-chime_GetChannelMessageStatus.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toGetChannelMessageStatus", []))

    @jsii.member(jsii_name="toGetDomain")
    def to_get_domain(self) -> "Chime":
        '''(experimental) Grants permission to get domain details for a domain associated with your Amazon Chime account.

        Access Level: Read

        https://docs.aws.amazon.com/chime/latest/ag/claim-domain.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toGetDomain", []))

    @jsii.member(jsii_name="toGetEventsConfiguration")
    def to_get_events_configuration(self) -> "Chime":
        '''(experimental) Grants permission to retrieve details for an events configuration for a bot to receive outgoing events.

        Access Level: Read

        https://docs.aws.amazon.com/chime/latest/APIReference/API_GetEventsConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toGetEventsConfiguration", []))

    @jsii.member(jsii_name="toGetGlobalSettings")
    def to_get_global_settings(self) -> "Chime":
        '''(experimental) Grants permission to get global settings related to Amazon Chime for the AWS account.

        Access Level: Read

        https://docs.aws.amazon.com/chime/latest/APIReference/API_GetGlobalSettings.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toGetGlobalSettings", []))

    @jsii.member(jsii_name="toGetMediaCapturePipeline")
    def to_get_media_capture_pipeline(self) -> "Chime":
        '''(experimental) Grants permission to get an existing media capture pipeline.

        Access Level: Read

        https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_media-pipelines-chime_GetMediaCapturePipeline.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toGetMediaCapturePipeline", []))

    @jsii.member(jsii_name="toGetMediaPipeline")
    def to_get_media_pipeline(self) -> "Chime":
        '''(experimental) Grants permission to get an existing media pipeline.

        Access Level: Read

        https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_media-pipelines-chime_GetMediaPipeline.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toGetMediaPipeline", []))

    @jsii.member(jsii_name="toGetMeeting")
    def to_get_meeting(self) -> "Chime":
        '''(experimental) Grants permission to get the meeting record for a specified meeting ID.

        Access Level: Read

        https://docs.aws.amazon.com/chime/latest/APIReference/API_GetMeeting.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toGetMeeting", []))

    @jsii.member(jsii_name="toGetMeetingDetail")
    def to_get_meeting_detail(self) -> "Chime":
        '''(experimental) Grants permission to get attendee, connection, and other details for a meeting.

        Access Level: Read

        https://docs.aws.amazon.com/chime/latest/ag/control-access.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toGetMeetingDetail", []))

    @jsii.member(jsii_name="toGetMessagingSessionEndpoint")
    def to_get_messaging_session_endpoint(self) -> "Chime":
        '''(experimental) Grants permission to get the endpoint for the messaging session.

        Access Level: Read

        https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_messaging-chime_GetMessagingSessionEndpoint.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toGetMessagingSessionEndpoint", []))

    @jsii.member(jsii_name="toGetPhoneNumber")
    def to_get_phone_number(self) -> "Chime":
        '''(experimental) Grants permission to get details for the specified phone number.

        Access Level: Read

        https://docs.aws.amazon.com/chime/latest/APIReference/API_GetPhoneNumber.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toGetPhoneNumber", []))

    @jsii.member(jsii_name="toGetPhoneNumberOrder")
    def to_get_phone_number_order(self) -> "Chime":
        '''(experimental) Grants permission to get details for the specified phone number order.

        Access Level: Read

        https://docs.aws.amazon.com/chime/latest/APIReference/API_GetPhoneNumberOrder.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toGetPhoneNumberOrder", []))

    @jsii.member(jsii_name="toGetPhoneNumberSettings")
    def to_get_phone_number_settings(self) -> "Chime":
        '''(experimental) Grants permission to get phone number settings related to Amazon Chime for the AWS account.

        Access Level: Read

        https://docs.aws.amazon.com/chime/latest/APIReference/API_GetPhoneNumberSettings.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toGetPhoneNumberSettings", []))

    @jsii.member(jsii_name="toGetProxySession")
    def to_get_proxy_session(self) -> "Chime":
        '''(experimental) Grants permission to get details of the specified proxy session for the specified Amazon Chime Voice Connector.

        Access Level: Read

        https://docs.aws.amazon.com/chime/latest/APIReference/API_GetProxySession.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toGetProxySession", []))

    @jsii.member(jsii_name="toGetRetentionSettings")
    def to_get_retention_settings(self) -> "Chime":
        '''(experimental) Grants permission to retrieve the retention settings for the specified Amazon Chime account.

        Access Level: Read

        https://docs.aws.amazon.com/chime/latest/APIReference/API_GetRetentionSettings.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toGetRetentionSettings", []))

    @jsii.member(jsii_name="toGetRoom")
    def to_get_room(self) -> "Chime":
        '''(experimental) Grants permission to retrieve a room.

        Access Level: Read

        https://docs.aws.amazon.com/chime/latest/APIReference/API_GetRoom.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toGetRoom", []))

    @jsii.member(jsii_name="toGetSipMediaApplication")
    def to_get_sip_media_application(self) -> "Chime":
        '''(experimental) Grants permission to get details of Amazon Chime SIP media application under the administrator's AWS account.

        Access Level: Read

        https://docs.aws.amazon.com/chime/latest/APIReference/API_GetSipMediaApplication.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toGetSipMediaApplication", []))

    @jsii.member(jsii_name="toGetSipMediaApplicationLoggingConfiguration")
    def to_get_sip_media_application_logging_configuration(self) -> "Chime":
        '''(experimental) Grants permission to get logging configuration settings for Amazon Chime SIP media application under the administrator's AWS account.

        Access Level: Read

        https://docs.aws.amazon.com/chime/latest/APIReference/API_GetSipMediaApplicationLoggingConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toGetSipMediaApplicationLoggingConfiguration", []))

    @jsii.member(jsii_name="toGetSipRule")
    def to_get_sip_rule(self) -> "Chime":
        '''(experimental) Grants permission to get details of Amazon Chime SIP rule under the administrator's AWS account.

        Access Level: Read

        https://docs.aws.amazon.com/chime/latest/APIReference/API_GetSipRule.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toGetSipRule", []))

    @jsii.member(jsii_name="toGetTelephonyLimits")
    def to_get_telephony_limits(self) -> "Chime":
        '''(experimental) Grants permission to get telephony limits for the AWS account.

        Access Level: Read

        https://docs.aws.amazon.com/chime/latest/ag/phone-numbers.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toGetTelephonyLimits", []))

    @jsii.member(jsii_name="toGetUser")
    def to_get_user(self) -> "Chime":
        '''(experimental) Grants permission to get details for the specified user ID.

        Access Level: Read

        https://docs.aws.amazon.com/chime/latest/APIReference/API_GetUser.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toGetUser", []))

    @jsii.member(jsii_name="toGetUserActivityReportData")
    def to_get_user_activity_report_data(self) -> "Chime":
        '''(experimental) Grants permission to get a summary of user activity on the user details page.

        Access Level: Read

        https://docs.aws.amazon.com/chime/latest/ag/user-details.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toGetUserActivityReportData", []))

    @jsii.member(jsii_name="toGetUserByEmail")
    def to_get_user_by_email(self) -> "Chime":
        '''(experimental) Grants permission to get user details for an Amazon Chime user based on the email address in an Amazon Chime Enterprise or Team account.

        Access Level: Read

        https://docs.aws.amazon.com/chime/latest/ag/user-details.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toGetUserByEmail", []))

    @jsii.member(jsii_name="toGetUserSettings")
    def to_get_user_settings(self) -> "Chime":
        '''(experimental) Grants permission to get user settings related to the specified Amazon Chime user.

        Access Level: Read

        https://docs.aws.amazon.com/chime/latest/APIReference/API_GetUserSettings.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toGetUserSettings", []))

    @jsii.member(jsii_name="toGetVoiceConnector")
    def to_get_voice_connector(self) -> "Chime":
        '''(experimental) Grants permission to get details for the specified Amazon Chime Voice Connector.

        Access Level: Read

        https://docs.aws.amazon.com/chime/latest/APIReference/API_GetVoiceConnector.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toGetVoiceConnector", []))

    @jsii.member(jsii_name="toGetVoiceConnectorEmergencyCallingConfiguration")
    def to_get_voice_connector_emergency_calling_configuration(self) -> "Chime":
        '''(experimental) Grants permission to get details of the emergency calling configuration for the specified Amazon Chime Voice Connector.

        Access Level: Read

        https://docs.aws.amazon.com/chime/latest/APIReference/API_GetVoiceConnectorEmergencyCallingConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toGetVoiceConnectorEmergencyCallingConfiguration", []))

    @jsii.member(jsii_name="toGetVoiceConnectorGroup")
    def to_get_voice_connector_group(self) -> "Chime":
        '''(experimental) Grants permission to get details for the specified Amazon Chime Voice Connector Group.

        Access Level: Read

        https://docs.aws.amazon.com/chime/latest/APIReference/API_GetVoiceConnectorGroup.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toGetVoiceConnectorGroup", []))

    @jsii.member(jsii_name="toGetVoiceConnectorLoggingConfiguration")
    def to_get_voice_connector_logging_configuration(self) -> "Chime":
        '''(experimental) Grants permission to get details of the logging configuration for the specified Amazon Chime Voice Connector.

        Access Level: Read

        https://docs.aws.amazon.com/chime/latest/APIReference/API_GetVoiceConnectorLoggingConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toGetVoiceConnectorLoggingConfiguration", []))

    @jsii.member(jsii_name="toGetVoiceConnectorOrigination")
    def to_get_voice_connector_origination(self) -> "Chime":
        '''(experimental) Grants permission to get details of the origination settings for the specified Amazon Chime Voice Connector.

        Access Level: Read

        https://docs.aws.amazon.com/chime/latest/APIReference/API_GetVoiceConnectorOrigination.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toGetVoiceConnectorOrigination", []))

    @jsii.member(jsii_name="toGetVoiceConnectorProxy")
    def to_get_voice_connector_proxy(self) -> "Chime":
        '''(experimental) Grants permission to get details of the proxy configuration for the specified Amazon Chime Voice Connector.

        Access Level: Read

        https://docs.aws.amazon.com/chime/latest/APIReference/API_GetVoiceConnectorProxy.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toGetVoiceConnectorProxy", []))

    @jsii.member(jsii_name="toGetVoiceConnectorStreamingConfiguration")
    def to_get_voice_connector_streaming_configuration(self) -> "Chime":
        '''(experimental) Grants permission to get details of the streaming configuration for the specified Amazon Chime Voice Connector.

        Access Level: Read

        https://docs.aws.amazon.com/chime/latest/APIReference/API_GetVoiceConnectorStreamingConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toGetVoiceConnectorStreamingConfiguration", []))

    @jsii.member(jsii_name="toGetVoiceConnectorTermination")
    def to_get_voice_connector_termination(self) -> "Chime":
        '''(experimental) Grants permission to get details of the termination settings for the specified Amazon Chime Voice Connector.

        Access Level: Read

        https://docs.aws.amazon.com/chime/latest/APIReference/API_GetVoiceConnectorTermination.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toGetVoiceConnectorTermination", []))

    @jsii.member(jsii_name="toGetVoiceConnectorTerminationHealth")
    def to_get_voice_connector_termination_health(self) -> "Chime":
        '''(experimental) Grants permission to get details of the termination health for the specified Amazon Chime Voice Connector.

        Access Level: Read

        https://docs.aws.amazon.com/chime/latest/APIReference/API_GetVoiceConnectorTerminationHealth.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toGetVoiceConnectorTerminationHealth", []))

    @jsii.member(jsii_name="toInviteDelegate")
    def to_invite_delegate(self) -> "Chime":
        '''(experimental) Grants permission to send an invitation to accept a request for AWS account delegation for an Amazon Chime account.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/ag/control-access.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toInviteDelegate", []))

    @jsii.member(jsii_name="toInviteUsers")
    def to_invite_users(self) -> "Chime":
        '''(experimental) Grants permission to invite as many as 50 users to the specified Amazon Chime account.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/APIReference/API_InviteUsers.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toInviteUsers", []))

    @jsii.member(jsii_name="toInviteUsersFromProvider")
    def to_invite_users_from_provider(self) -> "Chime":
        '''(experimental) Grants permission to invite users from a third party provider to your Amazon Chime account.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/ag/control-access.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toInviteUsersFromProvider", []))

    @jsii.member(jsii_name="toListAccounts")
    def to_list_accounts(self) -> "Chime":
        '''(experimental) Grants permission to list the Amazon Chime accounts under the administrator's AWS account.

        Access Level: List

        https://docs.aws.amazon.com/chime/latest/APIReference/API_ListAccounts.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toListAccounts", []))

    @jsii.member(jsii_name="toListAccountUsageReportData")
    def to_list_account_usage_report_data(self) -> "Chime":
        '''(experimental) Grants permission to list Amazon Chime account usage reporting data.

        Access Level: List

        https://docs.aws.amazon.com/chime/latest/ag/view-reports.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toListAccountUsageReportData", []))

    @jsii.member(jsii_name="toListApiKeys")
    def to_list_api_keys(self) -> "Chime":
        '''(experimental) Grants permission to list the SCIM access keys defined for your Amazon Chime account and Okta configuration.

        Access Level: List

        https://docs.aws.amazon.com/chime/latest/ag/okta_sso.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toListApiKeys", []))

    @jsii.member(jsii_name="toListAppInstanceAdmins")
    def to_list_app_instance_admins(self) -> "Chime":
        '''(experimental) Grants permission to list administrators in the app instance.

        Access Level: List

        https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_identity-chime_ListAppInstanceAdmins.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toListAppInstanceAdmins", []))

    @jsii.member(jsii_name="toListAppInstances")
    def to_list_app_instances(self) -> "Chime":
        '''(experimental) Grants permission to list all Amazon Chime app instances created under a single AWS account.

        Access Level: List

        https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_identity-chime_ListAppInstances.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toListAppInstances", []))

    @jsii.member(jsii_name="toListAppInstanceUserEndpoints")
    def to_list_app_instance_user_endpoints(self) -> "Chime":
        '''(experimental) Grants permission to list the endpoints registered for an app instance user.

        Access Level: List

        https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_identity-chime_ListAppInstanceUserEndpoints.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toListAppInstanceUserEndpoints", []))

    @jsii.member(jsii_name="toListAppInstanceUsers")
    def to_list_app_instance_users(self) -> "Chime":
        '''(experimental) Grants permission to list all AppInstanceUsers created under a single app instance.

        Access Level: List

        https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_identity-chime_ListAppInstanceUsers.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toListAppInstanceUsers", []))

    @jsii.member(jsii_name="toListAttendees")
    def to_list_attendees(self) -> "Chime":
        '''(experimental) Grants permission to list up to 100 attendees for a specified Amazon Chime SDK meeting.

        Access Level: List

        https://docs.aws.amazon.com/chime/latest/APIReference/API_ListAttendees.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toListAttendees", []))

    @jsii.member(jsii_name="toListAttendeeTags")
    def to_list_attendee_tags(self) -> "Chime":
        '''(experimental) Grants permission to list the tags applied to an Amazon Chime SDK attendee resource.

        Access Level: List

        https://docs.aws.amazon.com/chime/latest/APIReference/API_ListAttendeeTags.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toListAttendeeTags", []))

    @jsii.member(jsii_name="toListBots")
    def to_list_bots(self) -> "Chime":
        '''(experimental) Grants permission to list the bots associated with the administrator's Amazon Chime Enterprise account.

        Access Level: List

        https://docs.aws.amazon.com/chime/latest/APIReference/API_ListBots.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toListBots", []))

    @jsii.member(jsii_name="toListCallingRegions")
    def to_list_calling_regions(self) -> "Chime":
        '''(experimental) Grants permission to list the calling regions available for the administrator's AWS account.

        Access Level: List

        https://docs.aws.amazon.com/chime/latest/ag/phone-numbers.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toListCallingRegions", []))

    @jsii.member(jsii_name="toListCDRBucket")
    def to_list_cdr_bucket(self) -> "Chime":
        '''(experimental) Grants permission to list Call Detail Record S3 buckets.

        Access Level: List

        Dependent actions:

        - s3:ListAllMyBuckets
        - s3:ListBucket

        https://docs.aws.amazon.com/chime/latest/ag/control-access.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toListCDRBucket", []))

    @jsii.member(jsii_name="toListChannelBans")
    def to_list_channel_bans(self) -> "Chime":
        '''(experimental) Grants permission to list all the users banned from a particular channel.

        Access Level: List

        https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_messaging-chime_ListChannelBans.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toListChannelBans", []))

    @jsii.member(jsii_name="toListChannelFlows")
    def to_list_channel_flows(self) -> "Chime":
        '''(experimental) Grants permission to list all the Channel Flows created under a single Chime AppInstance.

        Access Level: List

        https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_messaging-chime_ListChannelFlows.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toListChannelFlows", []))

    @jsii.member(jsii_name="toListChannelMemberships")
    def to_list_channel_memberships(self) -> "Chime":
        '''(experimental) Grants permission to list all channel memberships in a channel.

        Access Level: List

        https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_messaging-chime_ListChannelMemberships.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toListChannelMemberships", []))

    @jsii.member(jsii_name="toListChannelMembershipsForAppInstanceUser")
    def to_list_channel_memberships_for_app_instance_user(self) -> "Chime":
        '''(experimental) Grants permission to list all channels that a particular AppInstanceUser is a part of.

        Access Level: List

        https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_messaging-chime_ListChannelMembershipsForAppInstanceUser.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toListChannelMembershipsForAppInstanceUser", []))

    @jsii.member(jsii_name="toListChannelMessages")
    def to_list_channel_messages(self) -> "Chime":
        '''(experimental) Grants permission to list all the messages in a channel.

        Access Level: Read

        https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_messaging-chime_ListChannelMessages.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toListChannelMessages", []))

    @jsii.member(jsii_name="toListChannelModerators")
    def to_list_channel_moderators(self) -> "Chime":
        '''(experimental) Grants permission to list all the moderators for a channel.

        Access Level: List

        https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_messaging-chime_ListChannelModerators.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toListChannelModerators", []))

    @jsii.member(jsii_name="toListChannels")
    def to_list_channels(self) -> "Chime":
        '''(experimental) Grants permission to list all the Channels created under a single Chime AppInstance.

        Access Level: List

        https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_messaging-chime_ListChannels.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toListChannels", []))

    @jsii.member(jsii_name="toListChannelsAssociatedWithChannelFlow")
    def to_list_channels_associated_with_channel_flow(self) -> "Chime":
        '''(experimental) Grants permission to list all the Channels associated with a single Chime Channel Flow.

        Access Level: List

        https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_messaging-chime_ListChannelsAssociatedWithChannelFlow.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toListChannelsAssociatedWithChannelFlow", []))

    @jsii.member(jsii_name="toListChannelsModeratedByAppInstanceUser")
    def to_list_channels_moderated_by_app_instance_user(self) -> "Chime":
        '''(experimental) Grants permission to list all channels moderated by an app instance user.

        Access Level: List

        https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_messaging-chime_ListChannelsModeratedByAppInstanceUser.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toListChannelsModeratedByAppInstanceUser", []))

    @jsii.member(jsii_name="toListDelegates")
    def to_list_delegates(self) -> "Chime":
        '''(experimental) Grants permission to list account delegate information associated with your Amazon Chime account.

        Access Level: List

        https://docs.aws.amazon.com/chime/latest/ag/control-access.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toListDelegates", []))

    @jsii.member(jsii_name="toListDirectories")
    def to_list_directories(self) -> "Chime":
        '''(experimental) Grants permission to list active Active Directories hosted in the Directory Service of your AWS account.

        Access Level: List

        https://docs.aws.amazon.com/chime/latest/ag/control-access.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toListDirectories", []))

    @jsii.member(jsii_name="toListDomains")
    def to_list_domains(self) -> "Chime":
        '''(experimental) Grants permission to list domains associated with your Amazon Chime account.

        Access Level: List

        https://docs.aws.amazon.com/chime/latest/ag/claim-domain.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toListDomains", []))

    @jsii.member(jsii_name="toListGroups")
    def to_list_groups(self) -> "Chime":
        '''(experimental) Grants permission to list Active Directory or Okta user groups associated with your Amazon Chime Enterprise account.

        Access Level: List

        https://docs.aws.amazon.com/chime/latest/ag/control-access.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toListGroups", []))

    @jsii.member(jsii_name="toListMediaCapturePipelines")
    def to_list_media_capture_pipelines(self) -> "Chime":
        '''(experimental) Grants permission to list media capture pipelines.

        Access Level: List

        https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_media-pipelines-chime_ListMediaCapturePipelines.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toListMediaCapturePipelines", []))

    @jsii.member(jsii_name="toListMediaPipelines")
    def to_list_media_pipelines(self) -> "Chime":
        '''(experimental) Grants permission to list media pipelines.

        Access Level: List

        https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_media-pipelines-chime_ListMediaPipelines.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toListMediaPipelines", []))

    @jsii.member(jsii_name="toListMeetingEvents")
    def to_list_meeting_events(self) -> "Chime":
        '''(experimental) Grants permission to list all events that occurred for a specified meeting.

        Access Level: List

        https://docs.aws.amazon.com/chime/latest/ag/view-reports.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toListMeetingEvents", []))

    @jsii.member(jsii_name="toListMeetings")
    def to_list_meetings(self) -> "Chime":
        '''(experimental) Grants permission to list up to 100 active Amazon Chime SDK meetings.

        Access Level: List

        https://docs.aws.amazon.com/chime/latest/APIReference/API_ListMeetings.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toListMeetings", []))

    @jsii.member(jsii_name="toListMeetingsReportData")
    def to_list_meetings_report_data(self) -> "Chime":
        '''(experimental) Grants permission to list meetings ended during the specified date range.

        Access Level: List

        https://docs.aws.amazon.com/chime/latest/ag/view-reports.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toListMeetingsReportData", []))

    @jsii.member(jsii_name="toListMeetingTags")
    def to_list_meeting_tags(self) -> "Chime":
        '''(experimental) Grants permission to list the tags applied to an Amazon Chime SDK meeting resource.

        Access Level: List

        https://docs.aws.amazon.com/chime/latest/APIReference/API_ListMeetingTags.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toListMeetingTags", []))

    @jsii.member(jsii_name="toListPhoneNumberOrders")
    def to_list_phone_number_orders(self) -> "Chime":
        '''(experimental) Grants permission to list the phone number orders under the administrator's AWS account.

        Access Level: List

        https://docs.aws.amazon.com/chime/latest/APIReference/API_ListPhoneNumberOrders.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toListPhoneNumberOrders", []))

    @jsii.member(jsii_name="toListPhoneNumbers")
    def to_list_phone_numbers(self) -> "Chime":
        '''(experimental) Grants permission to list the phone numbers under the administrator's AWS account.

        Access Level: List

        https://docs.aws.amazon.com/chime/latest/APIReference/API_ListPhoneNumbers.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toListPhoneNumbers", []))

    @jsii.member(jsii_name="toListProxySessions")
    def to_list_proxy_sessions(self) -> "Chime":
        '''(experimental) Grants permission to list proxy sessions for the specified Amazon Chime Voice Connector.

        Access Level: List

        https://docs.aws.amazon.com/chime/latest/APIReference/API_ListProxySessions.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toListProxySessions", []))

    @jsii.member(jsii_name="toListRoomMemberships")
    def to_list_room_memberships(self) -> "Chime":
        '''(experimental) Grants permission to list all room members.

        Access Level: List

        https://docs.aws.amazon.com/chime/latest/APIReference/API_ListRoomMemberships.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toListRoomMemberships", []))

    @jsii.member(jsii_name="toListRooms")
    def to_list_rooms(self) -> "Chime":
        '''(experimental) Grants permission to list rooms.

        Access Level: List

        https://docs.aws.amazon.com/chime/latest/APIReference/API_ListRooms.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toListRooms", []))

    @jsii.member(jsii_name="toListSipMediaApplications")
    def to_list_sip_media_applications(self) -> "Chime":
        '''(experimental) Grants permission to list all Amazon Chime SIP media applications under the administrator's AWS account.

        Access Level: List

        https://docs.aws.amazon.com/chime/latest/APIReference/API_ListSipMediaApplications.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toListSipMediaApplications", []))

    @jsii.member(jsii_name="toListSipRules")
    def to_list_sip_rules(self) -> "Chime":
        '''(experimental) Grants permission to list all Amazon Chime SIP rules under the administrator's AWS account.

        Access Level: List

        https://docs.aws.amazon.com/chime/latest/APIReference/API_ListSipRules.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toListSipRules", []))

    @jsii.member(jsii_name="toListSubChannels")
    def to_list_sub_channels(self) -> "Chime":
        '''(experimental) Grants permission to list all the SubChannels under a single Channel.

        Access Level: List

        https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_messaging-chime_ListSubChannels.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toListSubChannels", []))

    @jsii.member(jsii_name="toListSupportedPhoneNumberCountries")
    def to_list_supported_phone_number_countries(self) -> "Chime":
        '''(experimental) Grants permission to list the phone number countries supported by the AWS account.

        Access Level: List

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toListSupportedPhoneNumberCountries", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Chime":
        '''(experimental) Grants permission to list the tags applied to an Amazon Chime resource.

        Access Level: Read

        https://docs.aws.amazon.com/chime/latest/APIReference/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toListUsers")
    def to_list_users(self) -> "Chime":
        '''(experimental) Grants permission to list the users that belong to the specified Amazon Chime account.

        Access Level: List

        https://docs.aws.amazon.com/chime/latest/APIReference/API_ListUsers.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toListUsers", []))

    @jsii.member(jsii_name="toListVoiceConnectorGroups")
    def to_list_voice_connector_groups(self) -> "Chime":
        '''(experimental) Grants permission to list the Amazon Chime Voice Connector Groups under the administrator's AWS account.

        Access Level: List

        https://docs.aws.amazon.com/chime/latest/APIReference/API_ListVoiceConnectorGroups.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toListVoiceConnectorGroups", []))

    @jsii.member(jsii_name="toListVoiceConnectors")
    def to_list_voice_connectors(self) -> "Chime":
        '''(experimental) Grants permission to list the Amazon Chime Voice Connectors under the administrator's AWS account.

        Access Level: List

        https://docs.aws.amazon.com/chime/latest/APIReference/API_ListVoiceConnectors.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toListVoiceConnectors", []))

    @jsii.member(jsii_name="toListVoiceConnectorTerminationCredentials")
    def to_list_voice_connector_termination_credentials(self) -> "Chime":
        '''(experimental) Grants permission to list the SIP termination credentials for the specified Amazon Chime Voice Connector.

        Access Level: List

        https://docs.aws.amazon.com/chime/latest/APIReference/API_ListVoiceConnectorTerminationCredentials.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toListVoiceConnectorTerminationCredentials", []))

    @jsii.member(jsii_name="toLogoutUser")
    def to_logout_user(self) -> "Chime":
        '''(experimental) Grants permission to log out the specified user from all of the devices they are currently logged into.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/APIReference/API_LogoutUser.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toLogoutUser", []))

    @jsii.member(jsii_name="toPutAppInstanceRetentionSettings")
    def to_put_app_instance_retention_settings(self) -> "Chime":
        '''(experimental) Grants permission to enable data retention for the app instance.

        Access Level: Write

        https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_identity-chime_PutAppInstanceRetentionSettings.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toPutAppInstanceRetentionSettings", []))

    @jsii.member(jsii_name="toPutAppInstanceStreamingConfigurations")
    def to_put_app_instance_streaming_configurations(self) -> "Chime":
        '''(experimental) Grants permission to configure data streaming for the app instance.

        Access Level: Write

        https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_PutAppInstanceStreamingConfigurations.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toPutAppInstanceStreamingConfigurations", []))

    @jsii.member(jsii_name="toPutChannelMembershipPreferences")
    def to_put_channel_membership_preferences(self) -> "Chime":
        '''(experimental) Grants permission to put the preferences for a channel membership.

        Access Level: Write

        https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_messaging-chime_PutChannelMembershipPreferences.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toPutChannelMembershipPreferences", []))

    @jsii.member(jsii_name="toPutEventsConfiguration")
    def to_put_events_configuration(self) -> "Chime":
        '''(experimental) Grants permission to update details for an events configuration for a bot to receive outgoing events.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/APIReference/API_PutEventsConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toPutEventsConfiguration", []))

    @jsii.member(jsii_name="toPutRetentionSettings")
    def to_put_retention_settings(self) -> "Chime":
        '''(experimental) Grants permission to create or update retention settings for the specified Amazon Chime account.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/APIReference/API_PutRetentionSettings.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toPutRetentionSettings", []))

    @jsii.member(jsii_name="toPutSipMediaApplicationLoggingConfiguration")
    def to_put_sip_media_application_logging_configuration(self) -> "Chime":
        '''(experimental) Grants permission to update logging configuration settings for Amazon Chime SIP media application under the administrator's AWS account.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/APIReference/API_PutSipMediaApplicationLoggingConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toPutSipMediaApplicationLoggingConfiguration", []))

    @jsii.member(jsii_name="toPutVoiceConnectorEmergencyCallingConfiguration")
    def to_put_voice_connector_emergency_calling_configuration(self) -> "Chime":
        '''(experimental) Grants permission to add emergency calling configuration for the specified Amazon Chime Voice Connector.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/APIReference/API_PutVoiceConnectorEmergencyCallingConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toPutVoiceConnectorEmergencyCallingConfiguration", []))

    @jsii.member(jsii_name="toPutVoiceConnectorLoggingConfiguration")
    def to_put_voice_connector_logging_configuration(self) -> "Chime":
        '''(experimental) Grants permission to add logging configuration for the specified Amazon Chime Voice Connector.

        Access Level: Write

        Dependent actions:

        - logs:CreateLogDelivery
        - logs:CreateLogGroup
        - logs:DeleteLogDelivery
        - logs:DescribeLogGroups
        - logs:GetLogDelivery
        - logs:ListLogDeliveries

        https://docs.aws.amazon.com/chime/latest/APIReference/API_PutVoiceConnectorLoggingConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toPutVoiceConnectorLoggingConfiguration", []))

    @jsii.member(jsii_name="toPutVoiceConnectorOrigination")
    def to_put_voice_connector_origination(self) -> "Chime":
        '''(experimental) Grants permission to update the origination settings for the specified Amazon Chime Voice Connector.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/APIReference/API_PutVoiceConnectorOrigination.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toPutVoiceConnectorOrigination", []))

    @jsii.member(jsii_name="toPutVoiceConnectorProxy")
    def to_put_voice_connector_proxy(self) -> "Chime":
        '''(experimental) Grants permission to add proxy configuration for the specified Amazon Chime Voice Connector.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/APIReference/API_PutVoiceConnectorProxy.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toPutVoiceConnectorProxy", []))

    @jsii.member(jsii_name="toPutVoiceConnectorStreamingConfiguration")
    def to_put_voice_connector_streaming_configuration(self) -> "Chime":
        '''(experimental) Grants permission to add streaming configuration for the specified Amazon Chime Voice Connector.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/APIReference/API_PutVoiceConnectorStreamingConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toPutVoiceConnectorStreamingConfiguration", []))

    @jsii.member(jsii_name="toPutVoiceConnectorTermination")
    def to_put_voice_connector_termination(self) -> "Chime":
        '''(experimental) Grants permission to update the termination settings for the specified Amazon Chime Voice Connector.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/APIReference/API_PutVoiceConnectorTermination.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toPutVoiceConnectorTermination", []))

    @jsii.member(jsii_name="toPutVoiceConnectorTerminationCredentials")
    def to_put_voice_connector_termination_credentials(self) -> "Chime":
        '''(experimental) Grants permission to add SIP termination credentials for the specified Amazon Chime Voice Connector.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/APIReference/API_PutVoiceConnectorTerminationCredentials.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toPutVoiceConnectorTerminationCredentials", []))

    @jsii.member(jsii_name="toRedactChannelMessage")
    def to_redact_channel_message(self) -> "Chime":
        '''(experimental) Grants permission to redact message content.

        Access Level: Write

        https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_messaging-chime_RedactChannelMessage.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toRedactChannelMessage", []))

    @jsii.member(jsii_name="toRedactConversationMessage")
    def to_redact_conversation_message(self) -> "Chime":
        '''(experimental) Grants permission to redact the specified Chime conversation Message.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/APIReference/API_RedactConversationMessage.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toRedactConversationMessage", []))

    @jsii.member(jsii_name="toRedactRoomMessage")
    def to_redact_room_message(self) -> "Chime":
        '''(experimental) Grants permission to redacts the specified Chime room Message.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/APIReference/API_RedactRoomMessage.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toRedactRoomMessage", []))

    @jsii.member(jsii_name="toRegenerateSecurityToken")
    def to_regenerate_security_token(self) -> "Chime":
        '''(experimental) Grants permission to regenerate the security token for the specified bot.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/APIReference/API_RegenerateSecurityToken.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toRegenerateSecurityToken", []))

    @jsii.member(jsii_name="toRegisterAppInstanceUserEndpoint")
    def to_register_app_instance_user_endpoint(self) -> "Chime":
        '''(experimental) Grants permission to register an endpoint for an app instance user.

        Access Level: Write

        Dependent actions:

        - mobiletargeting:GetApp

        https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_identity-chime_RegisterAppInstanceUserEndpoint.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toRegisterAppInstanceUserEndpoint", []))

    @jsii.member(jsii_name="toRenameAccount")
    def to_rename_account(self) -> "Chime":
        '''(experimental) Grants permission to modify the account name for your Amazon Chime Enterprise or Team account.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/ag/rename-account.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toRenameAccount", []))

    @jsii.member(jsii_name="toRenewDelegate")
    def to_renew_delegate(self) -> "Chime":
        '''(experimental) Grants permission to renew the delegation request associated with an Amazon Chime account.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/ag/control-access.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toRenewDelegate", []))

    @jsii.member(jsii_name="toResetAccountResource")
    def to_reset_account_resource(self) -> "Chime":
        '''(experimental) Grants permission to reset the account resource in your Amazon Chime account.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/ag/control-access.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toResetAccountResource", []))

    @jsii.member(jsii_name="toResetPersonalPIN")
    def to_reset_personal_pin(self) -> "Chime":
        '''(experimental) Grants permission to reset the personal meeting PIN for the specified user on an Amazon Chime account.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/APIReference/API_ResetPersonalPIN.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toResetPersonalPIN", []))

    @jsii.member(jsii_name="toRestorePhoneNumber")
    def to_restore_phone_number(self) -> "Chime":
        '''(experimental) Grants permission to restore the specified phone number from the deltion queue back to the phone number inventory.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/APIReference/API_RestorePhoneNumber.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toRestorePhoneNumber", []))

    @jsii.member(jsii_name="toRetrieveDataExports")
    def to_retrieve_data_exports(self) -> "Chime":
        '''(experimental) Grants permission to download the file containing links to all user attachments returned as part of the "Request attachments" action.

        Access Level: Read

        https://docs.aws.amazon.com/chime/latest/ag/request-attachments.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toRetrieveDataExports", []))

    @jsii.member(jsii_name="toSearchAvailablePhoneNumbers")
    def to_search_available_phone_numbers(self) -> "Chime":
        '''(experimental) Grants permission to search phone numbers that can be ordered from the carrier.

        Access Level: Read

        https://docs.aws.amazon.com/chime/latest/APIReference/API_SearchAvailablePhoneNumbers.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toSearchAvailablePhoneNumbers", []))

    @jsii.member(jsii_name="toSearchChannels")
    def to_search_channels(self) -> "Chime":
        '''(experimental) Grants permission to search channels that an AppInstanceUser belongs to, or search channels across the AppInstance for an AppInstaceAdmin.

        Access Level: List

        https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_messaging-chime_SearchChannels.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toSearchChannels", []))

    @jsii.member(jsii_name="toSendChannelMessage")
    def to_send_channel_message(self) -> "Chime":
        '''(experimental) Grants permission to send a message to a particular channel that the member is a part of.

        Access Level: Write

        https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_messaging-chime_SendChannelMessage.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toSendChannelMessage", []))

    @jsii.member(jsii_name="toStartDataExport")
    def to_start_data_export(self) -> "Chime":
        '''(experimental) Grants permission to submit the "Request attachments" request.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/ag/request-attachments.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toStartDataExport", []))

    @jsii.member(jsii_name="toStartMeetingTranscription")
    def to_start_meeting_transcription(self) -> "Chime":
        '''(experimental) Grants permission to start transcription for a meeting.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/APIReference/API_StartMeetingTranscription.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toStartMeetingTranscription", []))

    @jsii.member(jsii_name="toStopMeetingTranscription")
    def to_stop_meeting_transcription(self) -> "Chime":
        '''(experimental) Grants permission to stop transcription for a meeting.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/APIReference/API_StopMeetingTranscription.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toStopMeetingTranscription", []))

    @jsii.member(jsii_name="toSubmitSupportRequest")
    def to_submit_support_request(self) -> "Chime":
        '''(experimental) Grants permission to submit a customer service support request.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/ag/chime-getting-admin-support.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toSubmitSupportRequest", []))

    @jsii.member(jsii_name="toSuspendUsers")
    def to_suspend_users(self) -> "Chime":
        '''(experimental) Grants permission to suspend users from an Amazon Chime Enterprise account.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/ag/manage-access.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toSuspendUsers", []))

    @jsii.member(jsii_name="toTagAttendee")
    def to_tag_attendee(self) -> "Chime":
        '''(experimental) Grants permission to apply the specified tags to the specified Amazon Chime SDK attendee.

        Access Level: Tagging

        https://docs.aws.amazon.com/chime/latest/APIReference/API_TagAttendee.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toTagAttendee", []))

    @jsii.member(jsii_name="toTagMeeting")
    def to_tag_meeting(self) -> "Chime":
        '''(experimental) Grants permission to apply the specified tags to the specified Amazon Chime SDK meeting.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()
        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/chime/latest/APIReference/API_TagMeeting.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toTagMeeting", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Chime":
        '''(experimental) Grants permission to apply the specified tags to the specified Amazon Chime resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()
        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/chime/latest/APIReference/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUnauthorizeDirectory")
    def to_unauthorize_directory(self) -> "Chime":
        '''(experimental) Grants permission to unauthorize an Active Directory from your Amazon Chime Enterprise account.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/ag/control-access.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toUnauthorizeDirectory", []))

    @jsii.member(jsii_name="toUntagAttendee")
    def to_untag_attendee(self) -> "Chime":
        '''(experimental) Grants permission to untag the specified tags from the specified Amazon Chime SDK attendee.

        Access Level: Tagging

        https://docs.aws.amazon.com/chime/latest/APIReference/API_UntagAttendee.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toUntagAttendee", []))

    @jsii.member(jsii_name="toUntagMeeting")
    def to_untag_meeting(self) -> "Chime":
        '''(experimental) Grants permission to untag the specified tags from the specified Amazon Chime SDK meeting.

        Access Level: Tagging

        https://docs.aws.amazon.com/chime/latest/APIReference/API_UntagMeeting.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toUntagMeeting", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Chime":
        '''(experimental) Grants permission to untag the specified tags from the specified Amazon Chime resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/chime/latest/APIReference/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateAccount")
    def to_update_account(self) -> "Chime":
        '''(experimental) Grants permission to update account details for the specified Amazon Chime account.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/APIReference/API_UpdateAccount.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toUpdateAccount", []))

    @jsii.member(jsii_name="toUpdateAccountOpenIdConfig")
    def to_update_account_open_id_config(self) -> "Chime":
        '''(experimental) Grants permission to update the OpenIdConfig attributes for your Amazon Chime account.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/ag/okta_sso.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toUpdateAccountOpenIdConfig", []))

    @jsii.member(jsii_name="toUpdateAccountResource")
    def to_update_account_resource(self) -> "Chime":
        '''(experimental) Grants permission to update the account resource in your Amazon Chime account.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/ag/control-access.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toUpdateAccountResource", []))

    @jsii.member(jsii_name="toUpdateAccountSettings")
    def to_update_account_settings(self) -> "Chime":
        '''(experimental) Grants permission to update the settings for the specified Amazon Chime account.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/APIReference/API_UpdateAccountSettings.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toUpdateAccountSettings", []))

    @jsii.member(jsii_name="toUpdateAppInstance")
    def to_update_app_instance(self) -> "Chime":
        '''(experimental) Grants permission to update AppInstance metadata.

        Access Level: Write

        https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_identity-chime_UpdateAppInstance.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toUpdateAppInstance", []))

    @jsii.member(jsii_name="toUpdateAppInstanceUser")
    def to_update_app_instance_user(self) -> "Chime":
        '''(experimental) Grants permission to update the details for an AppInstanceUser.

        Access Level: Write

        https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_identity-chime_UpdateAppInstanceUser.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toUpdateAppInstanceUser", []))

    @jsii.member(jsii_name="toUpdateAppInstanceUserEndpoint")
    def to_update_app_instance_user_endpoint(self) -> "Chime":
        '''(experimental) Grants permission to update an endpoint registered for an app instance user.

        Access Level: Write

        https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_identity-chime_UpdateAppInstanceUserEndpoint.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toUpdateAppInstanceUserEndpoint", []))

    @jsii.member(jsii_name="toUpdateAttendeeCapabilities")
    def to_update_attendee_capabilities(self) -> "Chime":
        '''(experimental) Grants permission to the capabilties that you want to update.

        Access Level: Write

        https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_meeting-chime_UpdateAttendeeCapabilities.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toUpdateAttendeeCapabilities", []))

    @jsii.member(jsii_name="toUpdateBot")
    def to_update_bot(self) -> "Chime":
        '''(experimental) Grants permission to update the status of the specified bot.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/APIReference/API_UpdateBot.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toUpdateBot", []))

    @jsii.member(jsii_name="toUpdateCDRSettings")
    def to_update_cdr_settings(self) -> "Chime":
        '''(experimental) Grants permission to update your Call Detail Record S3 bucket.

        Access Level: Write

        Dependent actions:

        - s3:CreateBucket
        - s3:DeleteBucket
        - s3:ListAllMyBuckets

        https://docs.aws.amazon.com/chime/latest/ag/control-access.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toUpdateCDRSettings", []))

    @jsii.member(jsii_name="toUpdateChannel")
    def to_update_channel(self) -> "Chime":
        '''(experimental) Grants permission to update a channel's attributes.

        Access Level: Write

        https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_messaging-chime_UpdateChannel.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toUpdateChannel", []))

    @jsii.member(jsii_name="toUpdateChannelFlow")
    def to_update_channel_flow(self) -> "Chime":
        '''(experimental) Grants permission to update a channel flow.

        Access Level: Write

        https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_messaging-chime_UpdateChannelFlow.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toUpdateChannelFlow", []))

    @jsii.member(jsii_name="toUpdateChannelMessage")
    def to_update_channel_message(self) -> "Chime":
        '''(experimental) Grants permission to update the content of a message.

        Access Level: Write

        https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_messaging-chime_UpdateChannelMessage.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toUpdateChannelMessage", []))

    @jsii.member(jsii_name="toUpdateChannelReadMarker")
    def to_update_channel_read_marker(self) -> "Chime":
        '''(experimental) Grants permission to set the timestamp to the point when a user last read messages in a channel.

        Access Level: Write

        https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_messaging-chime_UpdateChannelReadMarker.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toUpdateChannelReadMarker", []))

    @jsii.member(jsii_name="toUpdateGlobalSettings")
    def to_update_global_settings(self) -> "Chime":
        '''(experimental) Grants permission to update the global settings related to Amazon Chime for the AWS account.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/APIReference/API_UpdateGlobalSettings.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toUpdateGlobalSettings", []))

    @jsii.member(jsii_name="toUpdatePhoneNumber")
    def to_update_phone_number(self) -> "Chime":
        '''(experimental) Grants permission to update phone number details for the specified phone number.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/APIReference/API_UpdatePhoneNumber.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toUpdatePhoneNumber", []))

    @jsii.member(jsii_name="toUpdatePhoneNumberSettings")
    def to_update_phone_number_settings(self) -> "Chime":
        '''(experimental) Grants permission to update phone number settings related to Amazon Chime for the AWS account.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/APIReference/API_UpdatePhoneNumberSettings.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toUpdatePhoneNumberSettings", []))

    @jsii.member(jsii_name="toUpdateProxySession")
    def to_update_proxy_session(self) -> "Chime":
        '''(experimental) Grants permission to update a proxy session for the specified Amazon Chime Voice Connector.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/APIReference/API_UpdateProxySession.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toUpdateProxySession", []))

    @jsii.member(jsii_name="toUpdateRoom")
    def to_update_room(self) -> "Chime":
        '''(experimental) Grants permission to update a room.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/APIReference/API_UpdateRoom.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toUpdateRoom", []))

    @jsii.member(jsii_name="toUpdateRoomMembership")
    def to_update_room_membership(self) -> "Chime":
        '''(experimental) Grants permission to update room membership role.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/APIReference/API_UpdateRoomMembership.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toUpdateRoomMembership", []))

    @jsii.member(jsii_name="toUpdateSipMediaApplication")
    def to_update_sip_media_application(self) -> "Chime":
        '''(experimental) Grants permission to update properties of Amazon Chime SIP media application under the administrator's AWS account.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/APIReference/API_UpdateSipMediaApplication.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toUpdateSipMediaApplication", []))

    @jsii.member(jsii_name="toUpdateSipMediaApplicationCall")
    def to_update_sip_media_application_call(self) -> "Chime":
        '''(experimental) Grants permission to update an Amazon Chime SIP media application call under the administrator's AWS account.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/APIReference/API_UpdateSipMediaApplicationCall.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toUpdateSipMediaApplicationCall", []))

    @jsii.member(jsii_name="toUpdateSipRule")
    def to_update_sip_rule(self) -> "Chime":
        '''(experimental) Grants permission to update properties of Amazon Chime SIP rule under the administrator's AWS account.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/APIReference/API_UpdateSipRule.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toUpdateSipRule", []))

    @jsii.member(jsii_name="toUpdateSupportedLicenses")
    def to_update_supported_licenses(self) -> "Chime":
        '''(experimental) Grants permission to update the supported license tiers available for users in your Amazon Chime account.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/ag/manage-access.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toUpdateSupportedLicenses", []))

    @jsii.member(jsii_name="toUpdateUser")
    def to_update_user(self) -> "Chime":
        '''(experimental) Grants permission to update user details for a specified user ID.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/APIReference/API_UpdateUser.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toUpdateUser", []))

    @jsii.member(jsii_name="toUpdateUserLicenses")
    def to_update_user_licenses(self) -> "Chime":
        '''(experimental) Grants permission to update the licenses for your Amazon Chime users.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/ag/manage-access.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toUpdateUserLicenses", []))

    @jsii.member(jsii_name="toUpdateUserSettings")
    def to_update_user_settings(self) -> "Chime":
        '''(experimental) Grants permission to update user settings related to the specified Amazon Chime user.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/APIReference/API_UpdateUserSettings.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toUpdateUserSettings", []))

    @jsii.member(jsii_name="toUpdateVoiceConnector")
    def to_update_voice_connector(self) -> "Chime":
        '''(experimental) Grants permission to update Amazon Chime Voice Connector details for the specified Amazon Chime Voice Connector.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/APIReference/API_UpdateVoiceConnector.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toUpdateVoiceConnector", []))

    @jsii.member(jsii_name="toUpdateVoiceConnectorGroup")
    def to_update_voice_connector_group(self) -> "Chime":
        '''(experimental) Grants permission to update Amazon Chime Voice Connector Group details for the specified Amazon Chime Voice Connector Group.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/APIReference/API_UpdateVoiceConnectorGroup.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toUpdateVoiceConnectorGroup", []))

    @jsii.member(jsii_name="toValidateAccountResource")
    def to_validate_account_resource(self) -> "Chime":
        '''(experimental) Grants permission to validate the account resource in your Amazon Chime account.

        Access Level: Read

        https://docs.aws.amazon.com/chime/latest/ag/control-access.html

        :stability: experimental
        '''
        return typing.cast("Chime", jsii.invoke(self, "toValidateAccountResource", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__03463b206a0a92372dd39904dd26c63b1667516097b7bac1a3d4a7557dd0938c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e31f4812b2d3e6650f7218a86c75be77b3c6e8bf12e1fb5fb0418194ad9008d5)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Cloud9(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Cloud9",
):
    '''(experimental) Statement provider for service `cloud9 <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awscloud9.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `cloud9 <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awscloud9.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="ifEnvironmentId")
    def if_environment_id(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Cloud9":
        '''(experimental) Filters access by the AWS Cloud9 environment ID.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awscloud9.html##awscloud9-cloud9_EnvironmentId

        Applies to actions:

        - .toCreateEnvironmentMembership()
        - .toDescribeEnvironmentMemberships()
        - .toUpdateEnvironmentMembership()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3bbf9cd1c9f7ded8c418188b00406b81e85b1f02b6d0d728a4227d3e569cc59c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Cloud9", jsii.invoke(self, "ifEnvironmentId", [value, operator]))

    @jsii.member(jsii_name="ifEnvironmentName")
    def if_environment_name(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Cloud9":
        '''(experimental) Filters access by the AWS Cloud9 environment name.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awscloud9.html##awscloud9-cloud9_EnvironmentName

        Applies to actions:

        - .toCreateEnvironmentEC2()
        - .toCreateEnvironmentSSH()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0b3a7aa6ff990d99fce1880f055353111c92b519584321e0934a2facd2f32b99)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Cloud9", jsii.invoke(self, "ifEnvironmentName", [value, operator]))

    @jsii.member(jsii_name="ifInstanceType")
    def if_instance_type(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Cloud9":
        '''(experimental) Filters access by the instance type of the AWS Cloud9 environment's Amazon EC2 instance.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awscloud9.html##awscloud9-cloud9_InstanceType

        Applies to actions:

        - .toCreateEnvironmentEC2()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__627a6701e7f4aa93df956b99ea45bdfae6d07a90bfff5d2fdb772cfdbcaf9727)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Cloud9", jsii.invoke(self, "ifInstanceType", [value, operator]))

    @jsii.member(jsii_name="ifOwnerArn")
    def if_owner_arn(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Cloud9":
        '''(experimental) Filters access by the owner ARN specified.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awscloud9.html##awscloud9-cloud9_OwnerArn

        Applies to actions:

        - .toCreateEnvironmentEC2()
        - .toCreateEnvironmentSSH()

        :param value: The value(s) to check.
        :param operator: Works with `arn operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_ARN>`_. **Default:** ``ArnLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__47f332b927bf3546e9a47ed67373ee30200d2fbadb600cb82a16e4d9b9497b20)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Cloud9", jsii.invoke(self, "ifOwnerArn", [value, operator]))

    @jsii.member(jsii_name="ifPermissions")
    def if_permissions(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Cloud9":
        '''(experimental) Filters access by the type of AWS Cloud9 permissions.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awscloud9.html##awscloud9-cloud9_Permissions

        Applies to actions:

        - .toCreateEnvironmentMembership()
        - .toUpdateEnvironmentMembership()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__76d1cc2449e4fa3fb6fb19e87f20bab8b413603f229a6c5b64ed68489033e964)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Cloud9", jsii.invoke(self, "ifPermissions", [value, operator]))

    @jsii.member(jsii_name="ifSubnetId")
    def if_subnet_id(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Cloud9":
        '''(experimental) Filters access by the subnet ID that the AWS Cloud9 environment will be created in.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awscloud9.html##awscloud9-cloud9_SubnetId

        Applies to actions:

        - .toCreateEnvironmentEC2()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4a35f1e3b35b13805369057d93f3ca20aeb39678f8bce8e10231a1fafe006399)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Cloud9", jsii.invoke(self, "ifSubnetId", [value, operator]))

    @jsii.member(jsii_name="ifUserArn")
    def if_user_arn(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Cloud9":
        '''(experimental) Filters access by the user ARN specified.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awscloud9.html##awscloud9-cloud9_UserArn

        Applies to actions:

        - .toCreateEnvironmentEC2()
        - .toCreateEnvironmentMembership()
        - .toDescribeEnvironmentMemberships()
        - .toGetUserPublicKey()
        - .toUpdateEnvironmentMembership()

        :param value: The value(s) to check.
        :param operator: Works with `arn operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_ARN>`_. **Default:** ``ArnLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__cfa930c64733f654237f8c3bcd6be3f917362965b07fb6ada27a05a14a62366c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Cloud9", jsii.invoke(self, "ifUserArn", [value, operator]))

    @jsii.member(jsii_name="onEnvironment")
    def on_environment(
        self,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Cloud9":
        '''(experimental) Adds a resource of type environment to the statement.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awscloud9.html##awscloud9-environment

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ea0034fd0e0dce48b888337e2644fb599c24f72dec71a4657e4b8ad1f86ca7c5)
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Cloud9", jsii.invoke(self, "onEnvironment", [resource_id, account, region, partition]))

    @jsii.member(jsii_name="toActivateEC2Remote")
    def to_activate_ec2_remote(self) -> "Cloud9":
        '''(experimental) Grants permission to start the Amazon EC2 instance that your AWS Cloud9 IDE connects to.

        Access Level: Write

        https://docs.aws.amazon.com/cloud9/latest/user-guide/security-iam.html#auth-and-access-control-ref-matrix

        :stability: experimental
        '''
        return typing.cast("Cloud9", jsii.invoke(self, "toActivateEC2Remote", []))

    @jsii.member(jsii_name="toCreateEnvironmentEC2")
    def to_create_environment_ec2(self) -> "Cloud9":
        '''(experimental) Grants permission to create an AWS Cloud9 development environment, launches an Amazon Elastic Compute Cloud (Amazon EC2) instance, and then hosts the environment on the instance.

        Access Level: Write

        Possible conditions:

        - .ifEnvironmentName()
        - .ifInstanceType()
        - .ifSubnetId()
        - .ifUserArn()
        - .ifOwnerArn()
        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - ec2:DescribeSubnets
        - ec2:DescribeVpcs
        - iam:CreateServiceLinkedRole

        https://docs.aws.amazon.com/cloud9/latest/APIReference/API_CreateEnvironmentEC2.html

        :stability: experimental
        '''
        return typing.cast("Cloud9", jsii.invoke(self, "toCreateEnvironmentEC2", []))

    @jsii.member(jsii_name="toCreateEnvironmentMembership")
    def to_create_environment_membership(self) -> "Cloud9":
        '''(experimental) Grants permission to add an environment member to an AWS Cloud9 development environment.

        Access Level: Write

        Possible conditions:

        - .ifUserArn()
        - .ifEnvironmentId()
        - .ifPermissions()

        https://docs.aws.amazon.com/cloud9/latest/APIReference/API_CreateEnvironmentMembership.html

        :stability: experimental
        '''
        return typing.cast("Cloud9", jsii.invoke(self, "toCreateEnvironmentMembership", []))

    @jsii.member(jsii_name="toCreateEnvironmentSSH")
    def to_create_environment_ssh(self) -> "Cloud9":
        '''(experimental) Grants permission to create an AWS Cloud9 SSH development environment.

        Access Level: Write

        Possible conditions:

        - .ifEnvironmentName()
        - .ifOwnerArn()
        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/cloud9/latest/user-guide/security-iam.html#auth-and-access-control-ref-matrix

        :stability: experimental
        '''
        return typing.cast("Cloud9", jsii.invoke(self, "toCreateEnvironmentSSH", []))

    @jsii.member(jsii_name="toCreateEnvironmentToken")
    def to_create_environment_token(self) -> "Cloud9":
        '''(experimental) Grants permission to create an authentication token that allows a connection between the AWS Cloud9 IDE and the user's environment.

        Access Level: Read

        https://docs.aws.amazon.com/cloud9/latest/user-guide/security-iam.html#auth-and-access-control-ref-matrix

        :stability: experimental
        '''
        return typing.cast("Cloud9", jsii.invoke(self, "toCreateEnvironmentToken", []))

    @jsii.member(jsii_name="toDeleteEnvironment")
    def to_delete_environment(self) -> "Cloud9":
        '''(experimental) Grants permission to delete an AWS Cloud9 development environment.

        If the environment is hosted on an Amazon Elastic Compute Cloud (Amazon EC2) instance, also terminates the instance

        Access Level: Write

        Dependent actions:

        - iam:CreateServiceLinkedRole

        https://docs.aws.amazon.com/cloud9/latest/APIReference/API_DeleteEnvironment.html

        :stability: experimental
        '''
        return typing.cast("Cloud9", jsii.invoke(self, "toDeleteEnvironment", []))

    @jsii.member(jsii_name="toDeleteEnvironmentMembership")
    def to_delete_environment_membership(self) -> "Cloud9":
        '''(experimental) Grants permission to delete an environment member from an AWS Cloud9 development environment.

        Access Level: Write

        https://docs.aws.amazon.com/cloud9/latest/APIReference/API_DeleteEnvironmentMembership.html

        :stability: experimental
        '''
        return typing.cast("Cloud9", jsii.invoke(self, "toDeleteEnvironmentMembership", []))

    @jsii.member(jsii_name="toDescribeEC2Remote")
    def to_describe_ec2_remote(self) -> "Cloud9":
        '''(experimental) Grants permission to get details about the connection to the EC2 development environment, including host, user, and port.

        Access Level: Read

        https://docs.aws.amazon.com/cloud9/latest/user-guide/security-iam.html#auth-and-access-control-ref-matrix

        :stability: experimental
        '''
        return typing.cast("Cloud9", jsii.invoke(self, "toDescribeEC2Remote", []))

    @jsii.member(jsii_name="toDescribeEnvironmentMemberships")
    def to_describe_environment_memberships(self) -> "Cloud9":
        '''(experimental) Grants permission to get information about environment members for an AWS Cloud9 development environment.

        Access Level: Read

        Possible conditions:

        - .ifUserArn()
        - .ifEnvironmentId()

        https://docs.aws.amazon.com/cloud9/latest/APIReference/API_DescribeEnvironmentMemberships.html

        :stability: experimental
        '''
        return typing.cast("Cloud9", jsii.invoke(self, "toDescribeEnvironmentMemberships", []))

    @jsii.member(jsii_name="toDescribeEnvironments")
    def to_describe_environments(self) -> "Cloud9":
        '''(experimental) Grants permission to get information about AWS Cloud9 development environments.

        Access Level: Read

        https://docs.aws.amazon.com/cloud9/latest/APIReference/API_DescribeEnvironments.html

        :stability: experimental
        '''
        return typing.cast("Cloud9", jsii.invoke(self, "toDescribeEnvironments", []))

    @jsii.member(jsii_name="toDescribeEnvironmentStatus")
    def to_describe_environment_status(self) -> "Cloud9":
        '''(experimental) Grants permission to get status information for an AWS Cloud9 development environment.

        Access Level: Read

        https://docs.aws.amazon.com/cloud9/latest/APIReference/API_DescribeEnvironmentStatus.html

        :stability: experimental
        '''
        return typing.cast("Cloud9", jsii.invoke(self, "toDescribeEnvironmentStatus", []))

    @jsii.member(jsii_name="toDescribeSSHRemote")
    def to_describe_ssh_remote(self) -> "Cloud9":
        '''(experimental) Grants permission to get details about the connection to the SSH development environment, including host, user, and port.

        Access Level: Read

        https://docs.aws.amazon.com/cloud9/latest/user-guide/security-iam.html#auth-and-access-control-ref-matrix

        :stability: experimental
        '''
        return typing.cast("Cloud9", jsii.invoke(self, "toDescribeSSHRemote", []))

    @jsii.member(jsii_name="toGetEnvironmentConfig")
    def to_get_environment_config(self) -> "Cloud9":
        '''(experimental) Grants permission to get configuration information that's used to initialize the AWS Cloud9 IDE.

        Access Level: Read

        https://docs.aws.amazon.com/cloud9/latest/user-guide/security-iam.html#auth-and-access-control-ref-matrix

        :stability: experimental
        '''
        return typing.cast("Cloud9", jsii.invoke(self, "toGetEnvironmentConfig", []))

    @jsii.member(jsii_name="toGetEnvironmentSettings")
    def to_get_environment_settings(self) -> "Cloud9":
        '''(experimental) Grants permission to get the AWS Cloud9 IDE settings for a specified development environment.

        Access Level: Read

        https://docs.aws.amazon.com/cloud9/latest/user-guide/security-iam.html#auth-and-access-control-ref-matrix

        :stability: experimental
        '''
        return typing.cast("Cloud9", jsii.invoke(self, "toGetEnvironmentSettings", []))

    @jsii.member(jsii_name="toGetMembershipSettings")
    def to_get_membership_settings(self) -> "Cloud9":
        '''(experimental) Grants permission to get the AWS Cloud9 IDE settings for a specified environment member.

        Access Level: Read

        https://docs.aws.amazon.com/cloud9/latest/user-guide/security-iam.html#auth-and-access-control-ref-matrix

        :stability: experimental
        '''
        return typing.cast("Cloud9", jsii.invoke(self, "toGetMembershipSettings", []))

    @jsii.member(jsii_name="toGetUserPublicKey")
    def to_get_user_public_key(self) -> "Cloud9":
        '''(experimental) Grants permission to get the user's public SSH key, which is used by AWS Cloud9 to connect to SSH development environments.

        Access Level: Read

        Possible conditions:

        - .ifUserArn()

        https://docs.aws.amazon.com/cloud9/latest/user-guide/security-iam.html#auth-and-access-control-ref-matrix

        :stability: experimental
        '''
        return typing.cast("Cloud9", jsii.invoke(self, "toGetUserPublicKey", []))

    @jsii.member(jsii_name="toGetUserSettings")
    def to_get_user_settings(self) -> "Cloud9":
        '''(experimental) Grants permission to get the AWS Cloud9 IDE settings for a specified user.

        Access Level: Read

        https://docs.aws.amazon.com/cloud9/latest/user-guide/security-iam.html#auth-and-access-control-ref-matrix

        :stability: experimental
        '''
        return typing.cast("Cloud9", jsii.invoke(self, "toGetUserSettings", []))

    @jsii.member(jsii_name="toListEnvironments")
    def to_list_environments(self) -> "Cloud9":
        '''(experimental) Grants permission to get a list of AWS Cloud9 development environment identifiers.

        Access Level: Read

        https://docs.aws.amazon.com/cloud9/latest/APIReference/API_ListEnvironments.html

        :stability: experimental
        '''
        return typing.cast("Cloud9", jsii.invoke(self, "toListEnvironments", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Cloud9":
        '''(experimental) Grants permission to list tags for a cloud9 environment.

        Access Level: Read

        https://docs.aws.amazon.com/cloud9/latest/APIReference/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("Cloud9", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toModifyTemporaryCredentialsOnEnvironmentEC2")
    def to_modify_temporary_credentials_on_environment_ec2(self) -> "Cloud9":
        '''(experimental) Grants permission to set AWS managed temporary credentials on the Amazon EC2 instance that's used by the AWS Cloud9 integrated development environment (IDE).

        Access Level: Write

        https://docs.aws.amazon.com/cloud9/latest/user-guide/security-iam.html#auth-and-access-control-ref-matrix

        :stability: experimental
        '''
        return typing.cast("Cloud9", jsii.invoke(self, "toModifyTemporaryCredentialsOnEnvironmentEC2", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Cloud9":
        '''(experimental) Grants permission to add tags to a cloud9 environment.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/cloud9/latest/APIReference/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("Cloud9", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Cloud9":
        '''(experimental) Grants permission to remove tags from a cloud9 environment.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/cloud9/latest/APIReference/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("Cloud9", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateEnvironment")
    def to_update_environment(self) -> "Cloud9":
        '''(experimental) Grants permission to change the settings of an existing AWS Cloud9 development environment.

        Access Level: Write

        https://docs.aws.amazon.com/cloud9/latest/APIReference/API_UpdateEnvironment.html

        :stability: experimental
        '''
        return typing.cast("Cloud9", jsii.invoke(self, "toUpdateEnvironment", []))

    @jsii.member(jsii_name="toUpdateEnvironmentMembership")
    def to_update_environment_membership(self) -> "Cloud9":
        '''(experimental) Grants permission to change the settings of an existing environment member for an AWS Cloud9 development environment.

        Access Level: Write

        Possible conditions:

        - .ifUserArn()
        - .ifEnvironmentId()
        - .ifPermissions()

        https://docs.aws.amazon.com/cloud9/latest/APIReference/API_UpdateEnvironmentMembership.html

        :stability: experimental
        '''
        return typing.cast("Cloud9", jsii.invoke(self, "toUpdateEnvironmentMembership", []))

    @jsii.member(jsii_name="toUpdateEnvironmentSettings")
    def to_update_environment_settings(self) -> "Cloud9":
        '''(experimental) Grants permission to update the AWS Cloud9 IDE settings for a specified development environment.

        Access Level: Write

        https://docs.aws.amazon.com/cloud9/latest/user-guide/security-iam.html#auth-and-access-control-ref-matrix

        :stability: experimental
        '''
        return typing.cast("Cloud9", jsii.invoke(self, "toUpdateEnvironmentSettings", []))

    @jsii.member(jsii_name="toUpdateMembershipSettings")
    def to_update_membership_settings(self) -> "Cloud9":
        '''(experimental) Grants permission to update the AWS Cloud9 IDE settings for a specified environment member.

        Access Level: Write

        https://docs.aws.amazon.com/cloud9/latest/user-guide/security-iam.html#auth-and-access-control-ref-matrix

        :stability: experimental
        '''
        return typing.cast("Cloud9", jsii.invoke(self, "toUpdateMembershipSettings", []))

    @jsii.member(jsii_name="toUpdateSSHRemote")
    def to_update_ssh_remote(self) -> "Cloud9":
        '''(experimental) Grants permission to update details about the connection to the SSH development environment, including host, user, and port.

        Access Level: Write

        https://docs.aws.amazon.com/cloud9/latest/user-guide/security-iam.html#auth-and-access-control-ref-matrix

        :stability: experimental
        '''
        return typing.cast("Cloud9", jsii.invoke(self, "toUpdateSSHRemote", []))

    @jsii.member(jsii_name="toUpdateUserSettings")
    def to_update_user_settings(self) -> "Cloud9":
        '''(experimental) Grants permission to update IDE-specific settings of an AWS Cloud9 user.

        Access Level: Write

        https://docs.aws.amazon.com/cloud9/latest/user-guide/security-iam.html#auth-and-access-control-ref-matrix

        :stability: experimental
        '''
        return typing.cast("Cloud9", jsii.invoke(self, "toUpdateUserSettings", []))

    @jsii.member(jsii_name="toValidateEnvironmentName")
    def to_validate_environment_name(self) -> "Cloud9":
        '''(experimental) Grants permission to validate the environment name during the process of creating an AWS Cloud9 development environment.

        Access Level: Read

        https://docs.aws.amazon.com/cloud9/latest/user-guide/security-iam.html#auth-and-access-control-ref-matrix

        :stability: experimental
        '''
        return typing.cast("Cloud9", jsii.invoke(self, "toValidateEnvironmentName", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__216a7b6fda50e7d0219d8a323b52db8a5a67ce3923fadc1e43e2d04f531af860)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__dff1d44cfdc9bf0dece99e50c2641bf689c92b5c73acca9c4812650fd26631c5)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Clouddirectory(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Clouddirectory",
):
    '''(experimental) Statement provider for service `clouddirectory <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonclouddirectory.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `clouddirectory <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonclouddirectory.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onAppliedSchema")
    def on_applied_schema(
        self,
        directory_id: builtins.str,
        schema_name: builtins.str,
        version: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Clouddirectory":
        '''(experimental) Adds a resource of type appliedSchema to the statement.

        https://docs.aws.amazon.com/directoryservice/latest/admin-guide/cd_key_concepts.html#whatisdirectory

        :param directory_id: - Identifier for the directoryId.
        :param schema_name: - Identifier for the schemaName.
        :param version: - Identifier for the version.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2a9705755ecf2ac1ae6340785e0c5b21353217474415106f74c3c392553ef05f)
            check_type(argname="argument directory_id", value=directory_id, expected_type=type_hints["directory_id"])
            check_type(argname="argument schema_name", value=schema_name, expected_type=type_hints["schema_name"])
            check_type(argname="argument version", value=version, expected_type=type_hints["version"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Clouddirectory", jsii.invoke(self, "onAppliedSchema", [directory_id, schema_name, version, account, region, partition]))

    @jsii.member(jsii_name="onDevelopmentSchema")
    def on_development_schema(
        self,
        schema_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Clouddirectory":
        '''(experimental) Adds a resource of type developmentSchema to the statement.

        https://docs.aws.amazon.com/directoryservice/latest/admin-guide/cd_key_concepts.html#whatisdirectory

        :param schema_name: - Identifier for the schemaName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4020a9f0b1a11c3f3a78bd2d941e7ac7c2756f83cdae196df2d65eaa0f8cea06)
            check_type(argname="argument schema_name", value=schema_name, expected_type=type_hints["schema_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Clouddirectory", jsii.invoke(self, "onDevelopmentSchema", [schema_name, account, region, partition]))

    @jsii.member(jsii_name="onDirectory")
    def on_directory(
        self,
        directory_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Clouddirectory":
        '''(experimental) Adds a resource of type directory to the statement.

        https://docs.aws.amazon.com/directoryservice/latest/admin-guide/cd_key_concepts.html#whatisdirectory

        :param directory_id: - Identifier for the directoryId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__767fb02cf6fb053a24c1f61700b887cec2fac47707b94e4e2e7aab08b0fc334c)
            check_type(argname="argument directory_id", value=directory_id, expected_type=type_hints["directory_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Clouddirectory", jsii.invoke(self, "onDirectory", [directory_id, account, region, partition]))

    @jsii.member(jsii_name="onPublishedSchema")
    def on_published_schema(
        self,
        schema_name: builtins.str,
        version: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Clouddirectory":
        '''(experimental) Adds a resource of type publishedSchema to the statement.

        https://docs.aws.amazon.com/directoryservice/latest/admin-guide/cd_key_concepts.html#whatisdirectory

        :param schema_name: - Identifier for the schemaName.
        :param version: - Identifier for the version.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e04357e615b3f0b016a6aca5fe182e4cb6d275aff47c0b47b0756df781490adf)
            check_type(argname="argument schema_name", value=schema_name, expected_type=type_hints["schema_name"])
            check_type(argname="argument version", value=version, expected_type=type_hints["version"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Clouddirectory", jsii.invoke(self, "onPublishedSchema", [schema_name, version, account, region, partition]))

    @jsii.member(jsii_name="toAddFacetToObject")
    def to_add_facet_to_object(self) -> "Clouddirectory":
        '''(experimental) Grants permission to add a new Facet to an object.

        Access Level: Write

        https://docs.aws.amazon.com/directoryservice/latest/APIReference/API_AddFacetToObject.html

        :stability: experimental
        '''
        return typing.cast("Clouddirectory", jsii.invoke(self, "toAddFacetToObject", []))

    @jsii.member(jsii_name="toApplySchema")
    def to_apply_schema(self) -> "Clouddirectory":
        '''(experimental) Grants permission to copy input published schema into Directory with same name and version as that of published schema.

        Access Level: Write

        https://docs.aws.amazon.com/directoryservice/latest/APIReference/API_ApplySchema.html

        :stability: experimental
        '''
        return typing.cast("Clouddirectory", jsii.invoke(self, "toApplySchema", []))

    @jsii.member(jsii_name="toAttachObject")
    def to_attach_object(self) -> "Clouddirectory":
        '''(experimental) Grants permission to attach an existing object to another existing object.

        Access Level: Write

        https://docs.aws.amazon.com/directoryservice/latest/APIReference/API_AttachObject.html

        :stability: experimental
        '''
        return typing.cast("Clouddirectory", jsii.invoke(self, "toAttachObject", []))

    @jsii.member(jsii_name="toAttachPolicy")
    def to_attach_policy(self) -> "Clouddirectory":
        '''(experimental) Grants permission to attach a policy object to any other object.

        Access Level: Write

        https://docs.aws.amazon.com/directoryservice/latest/APIReference/API_AttachPolicy.html

        :stability: experimental
        '''
        return typing.cast("Clouddirectory", jsii.invoke(self, "toAttachPolicy", []))

    @jsii.member(jsii_name="toAttachToIndex")
    def to_attach_to_index(self) -> "Clouddirectory":
        '''(experimental) Grants permission to attach the specified object to the specified index.

        Access Level: Write

        https://docs.aws.amazon.com/directoryservice/latest/APIReference/API_AttachToIndex.html

        :stability: experimental
        '''
        return typing.cast("Clouddirectory", jsii.invoke(self, "toAttachToIndex", []))

    @jsii.member(jsii_name="toAttachTypedLink")
    def to_attach_typed_link(self) -> "Clouddirectory":
        '''(experimental) Grants permission to attach a typed link b/w a source & target object reference.

        Access Level: Write

        https://docs.aws.amazon.com/directoryservice/latest/APIReference/API_AttachTypedLink.html

        :stability: experimental
        '''
        return typing.cast("Clouddirectory", jsii.invoke(self, "toAttachTypedLink", []))

    @jsii.member(jsii_name="toBatchRead")
    def to_batch_read(self) -> "Clouddirectory":
        '''(experimental) Grants permission to perform all the read operations in a batch.

        Each individual operation inside BatchRead needs to be granted permissions explicitly

        Access Level: Read

        https://docs.aws.amazon.com/directoryservice/latest/APIReference/API_BatchRead.html

        :stability: experimental
        '''
        return typing.cast("Clouddirectory", jsii.invoke(self, "toBatchRead", []))

    @jsii.member(jsii_name="toBatchWrite")
    def to_batch_write(self) -> "Clouddirectory":
        '''(experimental) Grants permission to perform all the write operations in a batch.

        Each individual operation inside BatchWrite needs to be granted permissions explicitly

        Access Level: Write

        https://docs.aws.amazon.com/directoryservice/latest/APIReference/API_BatchWrite.html

        :stability: experimental
        '''
        return typing.cast("Clouddirectory", jsii.invoke(self, "toBatchWrite", []))

    @jsii.member(jsii_name="toCreateDirectory")
    def to_create_directory(self) -> "Clouddirectory":
        '''(experimental) Grants permission to create a Directory by copying the published schema into the directory.

        Access Level: Write

        https://docs.aws.amazon.com/directoryservice/latest/APIReference/API_CreateDirectory.html

        :stability: experimental
        '''
        return typing.cast("Clouddirectory", jsii.invoke(self, "toCreateDirectory", []))

    @jsii.member(jsii_name="toCreateFacet")
    def to_create_facet(self) -> "Clouddirectory":
        '''(experimental) Grants permission to create a new Facet in a schema.

        Access Level: Write

        https://docs.aws.amazon.com/directoryservice/latest/APIReference/API_CreateFacet.html

        :stability: experimental
        '''
        return typing.cast("Clouddirectory", jsii.invoke(self, "toCreateFacet", []))

    @jsii.member(jsii_name="toCreateIndex")
    def to_create_index(self) -> "Clouddirectory":
        '''(experimental) Grants permission to create an index object.

        Access Level: Write

        https://docs.aws.amazon.com/directoryservice/latest/APIReference/API_CreateIndex.html

        :stability: experimental
        '''
        return typing.cast("Clouddirectory", jsii.invoke(self, "toCreateIndex", []))

    @jsii.member(jsii_name="toCreateObject")
    def to_create_object(self) -> "Clouddirectory":
        '''(experimental) Grants permission to create an object in a Directory.

        Access Level: Write

        https://docs.aws.amazon.com/directoryservice/latest/APIReference/API_CreateObject.html

        :stability: experimental
        '''
        return typing.cast("Clouddirectory", jsii.invoke(self, "toCreateObject", []))

    @jsii.member(jsii_name="toCreateSchema")
    def to_create_schema(self) -> "Clouddirectory":
        '''(experimental) Grants permission to create a new schema in a development state.

        Access Level: Write

        https://docs.aws.amazon.com/directoryservice/latest/APIReference/API_CreateSchema.html

        :stability: experimental
        '''
        return typing.cast("Clouddirectory", jsii.invoke(self, "toCreateSchema", []))

    @jsii.member(jsii_name="toCreateTypedLinkFacet")
    def to_create_typed_link_facet(self) -> "Clouddirectory":
        '''(experimental) Grants permission to create a new Typed Link facet in a schema.

        Access Level: Write

        https://docs.aws.amazon.com/directoryservice/latest/APIReference/API_CreateTypedLinkFacet.html

        :stability: experimental
        '''
        return typing.cast("Clouddirectory", jsii.invoke(self, "toCreateTypedLinkFacet", []))

    @jsii.member(jsii_name="toDeleteDirectory")
    def to_delete_directory(self) -> "Clouddirectory":
        '''(experimental) Grants permission to delete a directory. Only disabled directories can be deleted.

        Access Level: Write

        https://docs.aws.amazon.com/directoryservice/latest/APIReference/API_DeleteDirectory.html

        :stability: experimental
        '''
        return typing.cast("Clouddirectory", jsii.invoke(self, "toDeleteDirectory", []))

    @jsii.member(jsii_name="toDeleteFacet")
    def to_delete_facet(self) -> "Clouddirectory":
        '''(experimental) Grants permission to delete a given Facet. All attributes and Rules associated with the facet will be deleted.

        Access Level: Write

        https://docs.aws.amazon.com/directoryservice/latest/APIReference/API_DeleteFacet.html

        :stability: experimental
        '''
        return typing.cast("Clouddirectory", jsii.invoke(self, "toDeleteFacet", []))

    @jsii.member(jsii_name="toDeleteObject")
    def to_delete_object(self) -> "Clouddirectory":
        '''(experimental) Grants permission to delete an object and its associated attributes.

        Access Level: Write

        https://docs.aws.amazon.com/directoryservice/latest/APIReference/API_DeleteObject.html

        :stability: experimental
        '''
        return typing.cast("Clouddirectory", jsii.invoke(self, "toDeleteObject", []))

    @jsii.member(jsii_name="toDeleteSchema")
    def to_delete_schema(self) -> "Clouddirectory":
        '''(experimental) Grants permission to delete a given schema.

        Access Level: Write

        https://docs.aws.amazon.com/directoryservice/latest/APIReference/API_DeleteSchema.html

        :stability: experimental
        '''
        return typing.cast("Clouddirectory", jsii.invoke(self, "toDeleteSchema", []))

    @jsii.member(jsii_name="toDeleteTypedLinkFacet")
    def to_delete_typed_link_facet(self) -> "Clouddirectory":
        '''(experimental) Grants permission to delete a given TypedLink Facet. All attributes and Rules associated with the facet will be deleted.

        Access Level: Write

        https://docs.aws.amazon.com/directoryservice/latest/APIReference/API_DeleteTypedLinkFacet.html

        :stability: experimental
        '''
        return typing.cast("Clouddirectory", jsii.invoke(self, "toDeleteTypedLinkFacet", []))

    @jsii.member(jsii_name="toDetachFromIndex")
    def to_detach_from_index(self) -> "Clouddirectory":
        '''(experimental) Grants permission to detach the specified object from the specified index.

        Access Level: Write

        https://docs.aws.amazon.com/directoryservice/latest/APIReference/API_DetachFromIndex.html

        :stability: experimental
        '''
        return typing.cast("Clouddirectory", jsii.invoke(self, "toDetachFromIndex", []))

    @jsii.member(jsii_name="toDetachObject")
    def to_detach_object(self) -> "Clouddirectory":
        '''(experimental) Grants permission to detach a given object from the parent object.

        Access Level: Write

        https://docs.aws.amazon.com/directoryservice/latest/APIReference/API_DetachObject.html

        :stability: experimental
        '''
        return typing.cast("Clouddirectory", jsii.invoke(self, "toDetachObject", []))

    @jsii.member(jsii_name="toDetachPolicy")
    def to_detach_policy(self) -> "Clouddirectory":
        '''(experimental) Grants permission to detach a policy from an object.

        Access Level: Write

        https://docs.aws.amazon.com/directoryservice/latest/APIReference/API_DetachPolicy.html

        :stability: experimental
        '''
        return typing.cast("Clouddirectory", jsii.invoke(self, "toDetachPolicy", []))

    @jsii.member(jsii_name="toDetachTypedLink")
    def to_detach_typed_link(self) -> "Clouddirectory":
        '''(experimental) Grants permission to detach a given typed link b/w given source and target object reference.

        Access Level: Write

        https://docs.aws.amazon.com/directoryservice/latest/APIReference/API_DetachTypedLink.html

        :stability: experimental
        '''
        return typing.cast("Clouddirectory", jsii.invoke(self, "toDetachTypedLink", []))

    @jsii.member(jsii_name="toDisableDirectory")
    def to_disable_directory(self) -> "Clouddirectory":
        '''(experimental) Grants permission to disable the specified directory.

        Access Level: Write

        https://docs.aws.amazon.com/directoryservice/latest/APIReference/API_DisableDirectory.html

        :stability: experimental
        '''
        return typing.cast("Clouddirectory", jsii.invoke(self, "toDisableDirectory", []))

    @jsii.member(jsii_name="toEnableDirectory")
    def to_enable_directory(self) -> "Clouddirectory":
        '''(experimental) Grants permission to enable the specified directory.

        Access Level: Write

        https://docs.aws.amazon.com/directoryservice/latest/APIReference/API_EnableDirectory.html

        :stability: experimental
        '''
        return typing.cast("Clouddirectory", jsii.invoke(self, "toEnableDirectory", []))

    @jsii.member(jsii_name="toGetAppliedSchemaVersion")
    def to_get_applied_schema_version(self) -> "Clouddirectory":
        '''(experimental) Grants permission to return current applied schema version ARN, including the minor version in use.

        Access Level: Read

        https://docs.aws.amazon.com/directoryservice/latest/APIReference/API_GetAppliedSchemaVersion.html

        :stability: experimental
        '''
        return typing.cast("Clouddirectory", jsii.invoke(self, "toGetAppliedSchemaVersion", []))

    @jsii.member(jsii_name="toGetDirectory")
    def to_get_directory(self) -> "Clouddirectory":
        '''(experimental) Grants permission to retrieve metadata about a directory.

        Access Level: Read

        https://docs.aws.amazon.com/directoryservice/latest/APIReference/API_GetDirectory.html

        :stability: experimental
        '''
        return typing.cast("Clouddirectory", jsii.invoke(self, "toGetDirectory", []))

    @jsii.member(jsii_name="toGetFacet")
    def to_get_facet(self) -> "Clouddirectory":
        '''(experimental) Grants permission to get details of the Facet, such as Facet Name, Attributes, Rules, or ObjectType.

        Access Level: Read

        https://docs.aws.amazon.com/directoryservice/latest/APIReference/API_GetFacet.html

        :stability: experimental
        '''
        return typing.cast("Clouddirectory", jsii.invoke(self, "toGetFacet", []))

    @jsii.member(jsii_name="toGetLinkAttributes")
    def to_get_link_attributes(self) -> "Clouddirectory":
        '''(experimental) Grants permission to retrieve attributes that are associated with a typed link.

        Access Level: Read

        https://docs.aws.amazon.com/directoryservice/latest/APIReference/API_GetLinkAttributes.html

        :stability: experimental
        '''
        return typing.cast("Clouddirectory", jsii.invoke(self, "toGetLinkAttributes", []))

    @jsii.member(jsii_name="toGetObjectAttributes")
    def to_get_object_attributes(self) -> "Clouddirectory":
        '''(experimental) Grants permission to retrieve attributes within a facet that are associated with an object.

        Access Level: Read

        https://docs.aws.amazon.com/directoryservice/latest/APIReference/API_GetObjectAttributes.html

        :stability: experimental
        '''
        return typing.cast("Clouddirectory", jsii.invoke(self, "toGetObjectAttributes", []))

    @jsii.member(jsii_name="toGetObjectInformation")
    def to_get_object_information(self) -> "Clouddirectory":
        '''(experimental) Grants permission to retrieve metadata about an object.

        Access Level: Read

        https://docs.aws.amazon.com/directoryservice/latest/APIReference/API_GetObjectInformation.html

        :stability: experimental
        '''
        return typing.cast("Clouddirectory", jsii.invoke(self, "toGetObjectInformation", []))

    @jsii.member(jsii_name="toGetSchemaAsJson")
    def to_get_schema_as_json(self) -> "Clouddirectory":
        '''(experimental) Grants permission to retrieve a JSON representation of the schema.

        Access Level: Read

        https://docs.aws.amazon.com/directoryservice/latest/APIReference/API_GetSchemaAsJson.html

        :stability: experimental
        '''
        return typing.cast("Clouddirectory", jsii.invoke(self, "toGetSchemaAsJson", []))

    @jsii.member(jsii_name="toGetTypedLinkFacetInformation")
    def to_get_typed_link_facet_information(self) -> "Clouddirectory":
        '''(experimental) Grants permission to return identity attributes order information associated with a given typed link facet.

        Access Level: Read

        https://docs.aws.amazon.com/directoryservice/latest/APIReference/API_GetTypedLinkFacetInformation.html

        :stability: experimental
        '''
        return typing.cast("Clouddirectory", jsii.invoke(self, "toGetTypedLinkFacetInformation", []))

    @jsii.member(jsii_name="toListAppliedSchemaArns")
    def to_list_applied_schema_arns(self) -> "Clouddirectory":
        '''(experimental) Grants permission to list schemas applied to a directory.

        Access Level: List

        https://docs.aws.amazon.com/directoryservice/latest/APIReference/API_ListAppliedSchemaArns.html

        :stability: experimental
        '''
        return typing.cast("Clouddirectory", jsii.invoke(self, "toListAppliedSchemaArns", []))

    @jsii.member(jsii_name="toListAttachedIndices")
    def to_list_attached_indices(self) -> "Clouddirectory":
        '''(experimental) Grants permission to list indices attached to an object.

        Access Level: Read

        https://docs.aws.amazon.com/directoryservice/latest/APIReference/API_ListAttachedIndices.html

        :stability: experimental
        '''
        return typing.cast("Clouddirectory", jsii.invoke(self, "toListAttachedIndices", []))

    @jsii.member(jsii_name="toListDevelopmentSchemaArns")
    def to_list_development_schema_arns(self) -> "Clouddirectory":
        '''(experimental) Grants permission to retrieve the ARNs of schemas in the development state.

        Access Level: List

        https://docs.aws.amazon.com/directoryservice/latest/APIReference/API_ListDevelopmentSchemaArns.html

        :stability: experimental
        '''
        return typing.cast("Clouddirectory", jsii.invoke(self, "toListDevelopmentSchemaArns", []))

    @jsii.member(jsii_name="toListDirectories")
    def to_list_directories(self) -> "Clouddirectory":
        '''(experimental) Grants permission to list directories created within an account.

        Access Level: List

        https://docs.aws.amazon.com/directoryservice/latest/APIReference/API_ListDirectories.html

        :stability: experimental
        '''
        return typing.cast("Clouddirectory", jsii.invoke(self, "toListDirectories", []))

    @jsii.member(jsii_name="toListFacetAttributes")
    def to_list_facet_attributes(self) -> "Clouddirectory":
        '''(experimental) Grants permission to retrieve attributes attached to the facet.

        Access Level: Read

        https://docs.aws.amazon.com/directoryservice/latest/APIReference/API_ListFacetAttributes.html

        :stability: experimental
        '''
        return typing.cast("Clouddirectory", jsii.invoke(self, "toListFacetAttributes", []))

    @jsii.member(jsii_name="toListFacetNames")
    def to_list_facet_names(self) -> "Clouddirectory":
        '''(experimental) Grants permission to retrieve the names of facets that exist in a schema.

        Access Level: Read

        https://docs.aws.amazon.com/directoryservice/latest/APIReference/API_ListFacetNames.html

        :stability: experimental
        '''
        return typing.cast("Clouddirectory", jsii.invoke(self, "toListFacetNames", []))

    @jsii.member(jsii_name="toListIncomingTypedLinks")
    def to_list_incoming_typed_links(self) -> "Clouddirectory":
        '''(experimental) Grants permission to return a paginated list of all incoming TypedLinks for a given object.

        Access Level: Read

        https://docs.aws.amazon.com/directoryservice/latest/APIReference/API_ListIncomingTypedLinks.html

        :stability: experimental
        '''
        return typing.cast("Clouddirectory", jsii.invoke(self, "toListIncomingTypedLinks", []))

    @jsii.member(jsii_name="toListIndex")
    def to_list_index(self) -> "Clouddirectory":
        '''(experimental) Grants permission to list objects attached to the specified index.

        Access Level: Read

        https://docs.aws.amazon.com/directoryservice/latest/APIReference/API_ListIndex.html

        :stability: experimental
        '''
        return typing.cast("Clouddirectory", jsii.invoke(self, "toListIndex", []))

    @jsii.member(jsii_name="toListManagedSchemaArns")
    def to_list_managed_schema_arns(self) -> "Clouddirectory":
        '''(experimental) Grants permission to list the major version families of each managed schema.

        If a major version ARN is provided as SchemaArn, the minor version revisions in that family are listed instead

        Access Level: List

        https://docs.aws.amazon.com/directoryservice/latest/APIReference/API_ListManagedSchemaArns.html

        :stability: experimental
        '''
        return typing.cast("Clouddirectory", jsii.invoke(self, "toListManagedSchemaArns", []))

    @jsii.member(jsii_name="toListObjectAttributes")
    def to_list_object_attributes(self) -> "Clouddirectory":
        '''(experimental) Grants permission to list all attributes associated with an object.

        Access Level: Read

        https://docs.aws.amazon.com/directoryservice/latest/APIReference/API_ListObjectAttributes.html

        :stability: experimental
        '''
        return typing.cast("Clouddirectory", jsii.invoke(self, "toListObjectAttributes", []))

    @jsii.member(jsii_name="toListObjectChildren")
    def to_list_object_children(self) -> "Clouddirectory":
        '''(experimental) Grants permission to return a paginated list of child objects associated with a given object.

        Access Level: Read

        https://docs.aws.amazon.com/directoryservice/latest/APIReference/API_ListObjectChildren.html

        :stability: experimental
        '''
        return typing.cast("Clouddirectory", jsii.invoke(self, "toListObjectChildren", []))

    @jsii.member(jsii_name="toListObjectParentPaths")
    def to_list_object_parent_paths(self) -> "Clouddirectory":
        '''(experimental) Grants permission to retrieve all available parent paths for any object type such as node, leaf node, policy node, and index node objects.

        Access Level: Read

        https://docs.aws.amazon.com/directoryservice/latest/APIReference/API_ListObjectParentPaths.html

        :stability: experimental
        '''
        return typing.cast("Clouddirectory", jsii.invoke(self, "toListObjectParentPaths", []))

    @jsii.member(jsii_name="toListObjectParents")
    def to_list_object_parents(self) -> "Clouddirectory":
        '''(experimental) Grants permission to list parent objects associated with a given object in pagination fashion.

        Access Level: Read

        https://docs.aws.amazon.com/directoryservice/latest/APIReference/API_ListObjectParents.html

        :stability: experimental
        '''
        return typing.cast("Clouddirectory", jsii.invoke(self, "toListObjectParents", []))

    @jsii.member(jsii_name="toListObjectPolicies")
    def to_list_object_policies(self) -> "Clouddirectory":
        '''(experimental) Grants permission to return policies attached to an object in pagination fashion.

        Access Level: Read

        https://docs.aws.amazon.com/directoryservice/latest/APIReference/API_ListObjectPolicies.html

        :stability: experimental
        '''
        return typing.cast("Clouddirectory", jsii.invoke(self, "toListObjectPolicies", []))

    @jsii.member(jsii_name="toListOutgoingTypedLinks")
    def to_list_outgoing_typed_links(self) -> "Clouddirectory":
        '''(experimental) Grants permission to return a paginated list of all outgoing TypedLinks for a given object.

        Access Level: Read

        https://docs.aws.amazon.com/directoryservice/latest/APIReference/API_ListOutgoingTypedLinks.html

        :stability: experimental
        '''
        return typing.cast("Clouddirectory", jsii.invoke(self, "toListOutgoingTypedLinks", []))

    @jsii.member(jsii_name="toListPolicyAttachments")
    def to_list_policy_attachments(self) -> "Clouddirectory":
        '''(experimental) Grants permission to return all of the ObjectIdentifiers to which a given policy is attached.

        Access Level: Read

        https://docs.aws.amazon.com/directoryservice/latest/APIReference/API_ListPolicyAttachments.html

        :stability: experimental
        '''
        return typing.cast("Clouddirectory", jsii.invoke(self, "toListPolicyAttachments", []))

    @jsii.member(jsii_name="toListPublishedSchemaArns")
    def to_list_published_schema_arns(self) -> "Clouddirectory":
        '''(experimental) Grants permission to retrieve published schema ARNs.

        Access Level: List

        https://docs.aws.amazon.com/directoryservice/latest/APIReference/API_ListPublishedSchemaArns.html

        :stability: experimental
        '''
        return typing.cast("Clouddirectory", jsii.invoke(self, "toListPublishedSchemaArns", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Clouddirectory":
        '''(experimental) Grants permission to return tags for a resource.

        Access Level: Read

        https://docs.aws.amazon.com/directoryservice/latest/APIReference/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("Clouddirectory", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toListTypedLinkFacetAttributes")
    def to_list_typed_link_facet_attributes(self) -> "Clouddirectory":
        '''(experimental) Grants permission to return a paginated list of attributes associated with typed link facet.

        Access Level: Read

        https://docs.aws.amazon.com/directoryservice/latest/APIReference/API_ListTypedLinkFacetAttributes.html

        :stability: experimental
        '''
        return typing.cast("Clouddirectory", jsii.invoke(self, "toListTypedLinkFacetAttributes", []))

    @jsii.member(jsii_name="toListTypedLinkFacetNames")
    def to_list_typed_link_facet_names(self) -> "Clouddirectory":
        '''(experimental) Grants permission to return a paginated list of typed link facet names that exist in a schema.

        Access Level: Read

        https://docs.aws.amazon.com/directoryservice/latest/APIReference/API_ListTypedLinkFacetNames.html

        :stability: experimental
        '''
        return typing.cast("Clouddirectory", jsii.invoke(self, "toListTypedLinkFacetNames", []))

    @jsii.member(jsii_name="toLookupPolicy")
    def to_lookup_policy(self) -> "Clouddirectory":
        '''(experimental) Grants permission to list all policies from the root of the Directory to the object specified.

        Access Level: Read

        https://docs.aws.amazon.com/directoryservice/latest/APIReference/API_LookupPolicy.html

        :stability: experimental
        '''
        return typing.cast("Clouddirectory", jsii.invoke(self, "toLookupPolicy", []))

    @jsii.member(jsii_name="toPublishSchema")
    def to_publish_schema(self) -> "Clouddirectory":
        '''(experimental) Grants permission to publish a development schema with a version.

        Access Level: Write

        https://docs.aws.amazon.com/directoryservice/latest/APIReference/API_PublishSchema.html

        :stability: experimental
        '''
        return typing.cast("Clouddirectory", jsii.invoke(self, "toPublishSchema", []))

    @jsii.member(jsii_name="toPutSchemaFromJson")
    def to_put_schema_from_json(self) -> "Clouddirectory":
        '''(experimental) Grants permission to update a schema using JSON upload. Only available for development schemas.

        Access Level: Write

        https://docs.aws.amazon.com/directoryservice/latest/APIReference/API_PutSchemaFromJson.html

        :stability: experimental
        '''
        return typing.cast("Clouddirectory", jsii.invoke(self, "toPutSchemaFromJson", []))

    @jsii.member(jsii_name="toRemoveFacetFromObject")
    def to_remove_facet_from_object(self) -> "Clouddirectory":
        '''(experimental) Grants permission to remove the specified facet from the specified object.

        Access Level: Write

        https://docs.aws.amazon.com/directoryservice/latest/APIReference/API_RemoveFacetFromObject.html

        :stability: experimental
        '''
        return typing.cast("Clouddirectory", jsii.invoke(self, "toRemoveFacetFromObject", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Clouddirectory":
        '''(experimental) Grants permission to add tags to a resource.

        Access Level: Tagging

        https://docs.aws.amazon.com/directoryservice/latest/APIReference/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("Clouddirectory", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Clouddirectory":
        '''(experimental) Grants permission to remove tags from a resource.

        Access Level: Tagging

        https://docs.aws.amazon.com/directoryservice/latest/APIReference/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("Clouddirectory", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateFacet")
    def to_update_facet(self) -> "Clouddirectory":
        '''(experimental) Grants permission to add/update/delete existing Attributes, Rules, or ObjectType of a Facet.

        Access Level: Write

        https://docs.aws.amazon.com/directoryservice/latest/APIReference/API_UpdateFacet.html

        :stability: experimental
        '''
        return typing.cast("Clouddirectory", jsii.invoke(self, "toUpdateFacet", []))

    @jsii.member(jsii_name="toUpdateLinkAttributes")
    def to_update_link_attributes(self) -> "Clouddirectory":
        '''(experimental) Grants permission to update a given typed link’s attributes.

        Attributes to be updated must not contribute to the typed link’s identity, as defined by its IdentityAttributeOrder

        Access Level: Write

        https://docs.aws.amazon.com/directoryservice/latest/APIReference/API_UpdateLinkAttributes.html

        :stability: experimental
        '''
        return typing.cast("Clouddirectory", jsii.invoke(self, "toUpdateLinkAttributes", []))

    @jsii.member(jsii_name="toUpdateObjectAttributes")
    def to_update_object_attributes(self) -> "Clouddirectory":
        '''(experimental) Grants permission to update a given object's attributes.

        Access Level: Write

        https://docs.aws.amazon.com/directoryservice/latest/APIReference/API_UpdateObjectAttributes.html

        :stability: experimental
        '''
        return typing.cast("Clouddirectory", jsii.invoke(self, "toUpdateObjectAttributes", []))

    @jsii.member(jsii_name="toUpdateSchema")
    def to_update_schema(self) -> "Clouddirectory":
        '''(experimental) Grants permission to update the schema name with a new name.

        Access Level: Write

        https://docs.aws.amazon.com/directoryservice/latest/APIReference/API_UpdateSchema.html

        :stability: experimental
        '''
        return typing.cast("Clouddirectory", jsii.invoke(self, "toUpdateSchema", []))

    @jsii.member(jsii_name="toUpdateTypedLinkFacet")
    def to_update_typed_link_facet(self) -> "Clouddirectory":
        '''(experimental) Grants permission to add/update/delete existing Attributes, Rules, identity attribute order of a TypedLink Facet.

        Access Level: Write

        https://docs.aws.amazon.com/directoryservice/latest/APIReference/API_UpdateTypedLinkFacet.html

        :stability: experimental
        '''
        return typing.cast("Clouddirectory", jsii.invoke(self, "toUpdateTypedLinkFacet", []))

    @jsii.member(jsii_name="toUpgradeAppliedSchema")
    def to_upgrade_applied_schema(self) -> "Clouddirectory":
        '''(experimental) Grants permission to upgrade a single directory in-place using the PublishedSchemaArn with schema updates found in MinorVersion.

        Backwards-compatible minor version upgrades are instantaneously available for readers on all objects in the directory

        Access Level: Write

        https://docs.aws.amazon.com/directoryservice/latest/APIReference/API_UpgradeAppliedSchema.html

        :stability: experimental
        '''
        return typing.cast("Clouddirectory", jsii.invoke(self, "toUpgradeAppliedSchema", []))

    @jsii.member(jsii_name="toUpgradePublishedSchema")
    def to_upgrade_published_schema(self) -> "Clouddirectory":
        '''(experimental) Grants permission to upgrade a published schema under a new minor version revision using the current contents of DevelopmentSchemaArn.

        Access Level: Write

        https://docs.aws.amazon.com/directoryservice/latest/APIReference/API_UpgradePublishedSchema.html

        :stability: experimental
        '''
        return typing.cast("Clouddirectory", jsii.invoke(self, "toUpgradePublishedSchema", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f0bc6ac737900300c0ed283505a2ee18e340993299d088143342dc3e1c76bd5a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__059fbfc88e91d02ab49d879387bf84c1c4466b13ab0f308795cc27a1b57144ea)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Cloudformation(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Cloudformation",
):
    '''(experimental) Statement provider for service `cloudformation <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awscloudformation.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `cloudformation <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awscloudformation.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="ifChangeSetName")
    def if_change_set_name(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Cloudformation":
        '''(experimental) Filters access by an AWS CloudFormation change set name.

        Use to control which change sets IAM users can execute or delete

        https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/using-iam-template.html#using-iam-template-conditions

        Applies to actions:

        - .toCreateChangeSet()
        - .toDeleteChangeSet()
        - .toDescribeChangeSet()
        - .toDescribeChangeSetHooks()
        - .toExecuteChangeSet()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fb83d8c7f52631ccc363572f6d0f76e20f584ea294345590bd29576e9240f8b9)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Cloudformation", jsii.invoke(self, "ifChangeSetName", [value, operator]))

    @jsii.member(jsii_name="ifImportResourceTypes")
    def if_import_resource_types(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Cloudformation":
        '''(experimental) Filters access by the template resource types, such as AWS::EC2::Instance.

        Use to control which resource types IAM users can work with when they want to import a resource into a stack

        https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/using-iam-template.html#using-iam-template-conditions

        Applies to actions:

        - .toCreateChangeSet()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__dac54665607aa4aef94591cc725ff81b830f5d318b1295e4b65aa21941a48c33)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Cloudformation", jsii.invoke(self, "ifImportResourceTypes", [value, operator]))

    @jsii.member(jsii_name="ifResourceTypes")
    def if_resource_types(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Cloudformation":
        '''(experimental) Filters access by the template resource types, such as AWS::EC2::Instance.

        Use to control which resource types IAM users can work with when they create or update a stack

        https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/using-iam-template.html#using-iam-template-conditions

        Applies to actions:

        - .toCreateChangeSet()
        - .toCreateStack()
        - .toUpdateStack()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9ff5c62423ea5ab7fc3e989461a96f041f1b07eee1c01787072cc8eaeb0f952b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Cloudformation", jsii.invoke(self, "ifResourceTypes", [value, operator]))

    @jsii.member(jsii_name="ifRoleArn")
    def if_role_arn(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Cloudformation":
        '''(experimental) Filters access by the ARN of an IAM service role.

        Use to control which service role IAM users can use to work with stacks or change sets

        https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/using-iam-template.html#using-iam-template-conditions

        Applies to actions:

        - .toContinueUpdateRollback()
        - .toCreateChangeSet()
        - .toCreateStack()
        - .toCreateStackSet()
        - .toDeleteStack()
        - .toRollbackStack()
        - .toUpdateStack()
        - .toUpdateStackSet()

        :param value: The value(s) to check.
        :param operator: Works with `arn operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_ARN>`_. **Default:** ``ArnLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3476f8719e3a6a3269146467162a6c4f622cccbc454caf8005e34d11c891a310)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Cloudformation", jsii.invoke(self, "ifRoleArn", [value, operator]))

    @jsii.member(jsii_name="ifStackPolicyUrl")
    def if_stack_policy_url(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Cloudformation":
        '''(experimental) Filters access by an Amazon S3 stack policy URL.

        Use to control which stack policies IAM users can associate with a stack during a create or update stack action

        https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/using-iam-template.html#using-iam-template-conditions

        Applies to actions:

        - .toCreateChangeSet()
        - .toCreateStack()
        - .toSetStackPolicy()
        - .toUpdateStack()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__57d72fff97bad35a63286f60bb7eab1a1d905d3e18be1debc6468056d900d88a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Cloudformation", jsii.invoke(self, "ifStackPolicyUrl", [value, operator]))

    @jsii.member(jsii_name="ifTargetRegion")
    def if_target_region(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Cloudformation":
        '''(experimental) Filters access by stack set target region.

        Use to control which regions IAM users can use when they create or update stack sets

        https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/using-iam-template.html#using-iam-template-conditions

        Applies to actions:

        - .toCreateStackInstances()
        - .toDeleteStackInstances()
        - .toUpdateStackInstances()
        - .toUpdateStackSet()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fbc11cd87510518bb622a8e927e12308f5a49abdba70dba9e04907fa5cc0edab)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Cloudformation", jsii.invoke(self, "ifTargetRegion", [value, operator]))

    @jsii.member(jsii_name="ifTemplateUrl")
    def if_template_url(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Cloudformation":
        '''(experimental) Filters access by an Amazon S3 template URL.

        Use to control which templates IAM users can use when they create or update stacks

        https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/using-iam-template.html#using-iam-template-conditions

        Applies to actions:

        - .toCreateChangeSet()
        - .toCreateStack()
        - .toCreateStackSet()
        - .toUpdateStack()
        - .toUpdateStackSet()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__99d6d8dbbcf232edad8fa1ec9a56725b4e02778f62ca272fb117d8132c8eb810)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Cloudformation", jsii.invoke(self, "ifTemplateUrl", [value, operator]))

    @jsii.member(jsii_name="onChangeset")
    def on_changeset(
        self,
        change_set_name: builtins.str,
        id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Cloudformation":
        '''(experimental) Adds a resource of type changeset to the statement.

        https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/cfn-whatis-concepts.html#w2ab1b5c15c11

        :param change_set_name: - Identifier for the changeSetName.
        :param id: - Identifier for the id.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2c55f20896a209a83b002e6cb3045d38297a47578422736b77bc90cde54480b0)
            check_type(argname="argument change_set_name", value=change_set_name, expected_type=type_hints["change_set_name"])
            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Cloudformation", jsii.invoke(self, "onChangeset", [change_set_name, id, account, region, partition]))

    @jsii.member(jsii_name="onStack")
    def on_stack(
        self,
        stack_name: builtins.str,
        id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Cloudformation":
        '''(experimental) Adds a resource of type stack to the statement.

        https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/cfn-whatis-concepts.html#w2ab1b5c15b9

        :param stack_name: - Identifier for the stackName.
        :param id: - Identifier for the id.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b8f0041dc90eda1397c280f66c7289c9dcb1c5a0d293130ee3d3ff4633f5752e)
            check_type(argname="argument stack_name", value=stack_name, expected_type=type_hints["stack_name"])
            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Cloudformation", jsii.invoke(self, "onStack", [stack_name, id, account, region, partition]))

    @jsii.member(jsii_name="onStackset")
    def on_stackset(
        self,
        stack_set_name: builtins.str,
        id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Cloudformation":
        '''(experimental) Adds a resource of type stackset to the statement.

        https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/stacksets-concepts.html#stacksets-concepts-stackset

        :param stack_set_name: - Identifier for the stackSetName.
        :param id: - Identifier for the id.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__65e2b0fd53c9343a81aa9634dc76f66b3b1c4cb130b0ec9f76c8d12c8a006386)
            check_type(argname="argument stack_set_name", value=stack_set_name, expected_type=type_hints["stack_set_name"])
            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Cloudformation", jsii.invoke(self, "onStackset", [stack_set_name, id, account, region, partition]))

    @jsii.member(jsii_name="onStacksetTarget")
    def on_stackset_target(
        self,
        stack_set_target: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Cloudformation":
        '''(experimental) Adds a resource of type stackset-target to the statement.

        https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/using-iam-template.html

        :param stack_set_target: - Identifier for the stackSetTarget.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__724a8c9c90918a1bdc4f63a54dfe7aef1975b3a1e6b231d95dd9fb6f1ac029c9)
            check_type(argname="argument stack_set_target", value=stack_set_target, expected_type=type_hints["stack_set_target"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Cloudformation", jsii.invoke(self, "onStacksetTarget", [stack_set_target, account, region, partition]))

    @jsii.member(jsii_name="onType")
    def on_type(
        self,
        type: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Cloudformation":
        '''(experimental) Adds a resource of type type to the statement.

        https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/using-iam-template.html

        :param type: - Identifier for the type.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c4004156fa1fbe29f91b7949fcd88585acfa0a646a35fe015eb9e6b3e21035a6)
            check_type(argname="argument type", value=type, expected_type=type_hints["type"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Cloudformation", jsii.invoke(self, "onType", [type, account, region, partition]))

    @jsii.member(jsii_name="toActivateType")
    def to_activate_type(self) -> "Cloudformation":
        '''(experimental) Grants permission to activate a public third-party extension, making it available for use in stack templates.

        Access Level: Write

        https://docs.aws.amazon.com/AWSCloudFormation/latest/APIReference/API_ActivateType.html

        :stability: experimental
        '''
        return typing.cast("Cloudformation", jsii.invoke(self, "toActivateType", []))

    @jsii.member(jsii_name="toBatchDescribeTypeConfigurations")
    def to_batch_describe_type_configurations(self) -> "Cloudformation":
        '''(experimental) Grants permission to return configuration data for the specified CloudFormation extensions.

        Access Level: Read

        https://docs.aws.amazon.com/AWSCloudFormation/latest/APIReference/API_BatchDescribeTypeConfigurations.html

        :stability: experimental
        '''
        return typing.cast("Cloudformation", jsii.invoke(self, "toBatchDescribeTypeConfigurations", []))

    @jsii.member(jsii_name="toCancelUpdateStack")
    def to_cancel_update_stack(self) -> "Cloudformation":
        '''(experimental) Grants permission to cancel an update on the specified stack.

        Access Level: Write

        https://docs.aws.amazon.com/AWSCloudFormation/latest/APIReference/API_CancelUpdateStack.html

        :stability: experimental
        '''
        return typing.cast("Cloudformation", jsii.invoke(self, "toCancelUpdateStack", []))

    @jsii.member(jsii_name="toContinueUpdateRollback")
    def to_continue_update_rollback(self) -> "Cloudformation":
        '''(experimental) Grants permission to continue rolling back a stack that is in the UPDATE_ROLLBACK_FAILED state to the UPDATE_ROLLBACK_COMPLETE state.

        Access Level: Write

        Possible conditions:

        - .ifRoleArn()

        https://docs.aws.amazon.com/AWSCloudFormation/latest/APIReference/API_ContinueUpdateRollback.html

        :stability: experimental
        '''
        return typing.cast("Cloudformation", jsii.invoke(self, "toContinueUpdateRollback", []))

    @jsii.member(jsii_name="toCreateChangeSet")
    def to_create_change_set(self) -> "Cloudformation":
        '''(experimental) Grants permission to create a list of changes for a stack.

        Access Level: Write

        Possible conditions:

        - .ifChangeSetName()
        - .ifResourceTypes()
        - .ifImportResourceTypes()
        - .ifRoleArn()
        - .ifStackPolicyUrl()
        - .ifTemplateUrl()
        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/AWSCloudFormation/latest/APIReference/API_CreateChangeSet.html

        :stability: experimental
        '''
        return typing.cast("Cloudformation", jsii.invoke(self, "toCreateChangeSet", []))

    @jsii.member(jsii_name="toCreateStack")
    def to_create_stack(self) -> "Cloudformation":
        '''(experimental) Grants permission to create a stack as specified in the template.

        Access Level: Write

        Possible conditions:

        - .ifResourceTypes()
        - .ifRoleArn()
        - .ifStackPolicyUrl()
        - .ifTemplateUrl()
        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/AWSCloudFormation/latest/APIReference/API_CreateStack.html

        :stability: experimental
        '''
        return typing.cast("Cloudformation", jsii.invoke(self, "toCreateStack", []))

    @jsii.member(jsii_name="toCreateStackInstances")
    def to_create_stack_instances(self) -> "Cloudformation":
        '''(experimental) Grants permission to create stack instances for the specified accounts, within the specified regions.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifTargetRegion()

        https://docs.aws.amazon.com/AWSCloudFormation/latest/APIReference/API_CreateStackInstances.html

        :stability: experimental
        '''
        return typing.cast("Cloudformation", jsii.invoke(self, "toCreateStackInstances", []))

    @jsii.member(jsii_name="toCreateStackSet")
    def to_create_stack_set(self) -> "Cloudformation":
        '''(experimental) Grants permission to create a stackset as specified in the template.

        Access Level: Write

        Possible conditions:

        - .ifRoleArn()
        - .ifTemplateUrl()
        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/AWSCloudFormation/latest/APIReference/API_CreateStackSet.html

        :stability: experimental
        '''
        return typing.cast("Cloudformation", jsii.invoke(self, "toCreateStackSet", []))

    @jsii.member(jsii_name="toCreateUploadBucket")
    def to_create_upload_bucket(self) -> "Cloudformation":
        '''(experimental) Grants permission to upload templates to Amazon S3 buckets.

        Used only by the AWS CloudFormation console and is not documented in the API reference

        Access Level: Write

        https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/using-iam-template.html

        :stability: experimental
        '''
        return typing.cast("Cloudformation", jsii.invoke(self, "toCreateUploadBucket", []))

    @jsii.member(jsii_name="toDeactivateType")
    def to_deactivate_type(self) -> "Cloudformation":
        '''(experimental) Grants permission to deactivate a public extension that was previously activated in this account and region.

        Access Level: Write

        https://docs.aws.amazon.com/AWSCloudFormation/latest/APIReference/API_DeactivateType.html

        :stability: experimental
        '''
        return typing.cast("Cloudformation", jsii.invoke(self, "toDeactivateType", []))

    @jsii.member(jsii_name="toDeleteChangeSet")
    def to_delete_change_set(self) -> "Cloudformation":
        '''(experimental) Grants permission to delete the specified change set.

        Deleting change sets ensures that no one executes the wrong change set

        Access Level: Write

        Possible conditions:

        - .ifChangeSetName()

        https://docs.aws.amazon.com/AWSCloudFormation/latest/APIReference/API_DeleteChangeSet.html

        :stability: experimental
        '''
        return typing.cast("Cloudformation", jsii.invoke(self, "toDeleteChangeSet", []))

    @jsii.member(jsii_name="toDeleteStack")
    def to_delete_stack(self) -> "Cloudformation":
        '''(experimental) Grants permission to delete a specified stack.

        Access Level: Write

        Possible conditions:

        - .ifRoleArn()

        https://docs.aws.amazon.com/AWSCloudFormation/latest/APIReference/API_DeleteStack.html

        :stability: experimental
        '''
        return typing.cast("Cloudformation", jsii.invoke(self, "toDeleteStack", []))

    @jsii.member(jsii_name="toDeleteStackInstances")
    def to_delete_stack_instances(self) -> "Cloudformation":
        '''(experimental) Grants permission to delete stack instances for the specified accounts, in the specified regions.

        Access Level: Write

        Possible conditions:

        - .ifTargetRegion()

        https://docs.aws.amazon.com/AWSCloudFormation/latest/APIReference/API_DeleteStackInstances.html

        :stability: experimental
        '''
        return typing.cast("Cloudformation", jsii.invoke(self, "toDeleteStackInstances", []))

    @jsii.member(jsii_name="toDeleteStackSet")
    def to_delete_stack_set(self) -> "Cloudformation":
        '''(experimental) Grants permission to delete a specified stackset.

        Access Level: Write

        https://docs.aws.amazon.com/AWSCloudFormation/latest/APIReference/API_DeleteStackSet.html

        :stability: experimental
        '''
        return typing.cast("Cloudformation", jsii.invoke(self, "toDeleteStackSet", []))

    @jsii.member(jsii_name="toDeregisterType")
    def to_deregister_type(self) -> "Cloudformation":
        '''(experimental) Grants permission to deregister an existing CloudFormation type or type version.

        Access Level: Write

        https://docs.aws.amazon.com/AWSCloudFormation/latest/APIReference/API_DeregisterType.html

        :stability: experimental
        '''
        return typing.cast("Cloudformation", jsii.invoke(self, "toDeregisterType", []))

    @jsii.member(jsii_name="toDescribeAccountLimits")
    def to_describe_account_limits(self) -> "Cloudformation":
        '''(experimental) Grants permission to retrieve your account's AWS CloudFormation limits.

        Access Level: Read

        https://docs.aws.amazon.com/AWSCloudFormation/latest/APIReference/API_DescribeAccountLimits.html

        :stability: experimental
        '''
        return typing.cast("Cloudformation", jsii.invoke(self, "toDescribeAccountLimits", []))

    @jsii.member(jsii_name="toDescribeChangeSet")
    def to_describe_change_set(self) -> "Cloudformation":
        '''(experimental) Grants permission to return the description for the specified change set.

        Access Level: Read

        Possible conditions:

        - .ifChangeSetName()

        https://docs.aws.amazon.com/AWSCloudFormation/latest/APIReference/API_DescribeChangeSet.html

        :stability: experimental
        '''
        return typing.cast("Cloudformation", jsii.invoke(self, "toDescribeChangeSet", []))

    @jsii.member(jsii_name="toDescribeChangeSetHooks")
    def to_describe_change_set_hooks(self) -> "Cloudformation":
        '''(experimental) Grants permission to return the Hook invocation information for the specified change set.

        Access Level: Read

        Possible conditions:

        - .ifChangeSetName()

        https://docs.aws.amazon.com/AWSCloudFormation/latest/APIReference/API_DescribeChangeSetHooks.html

        :stability: experimental
        '''
        return typing.cast("Cloudformation", jsii.invoke(self, "toDescribeChangeSetHooks", []))

    @jsii.member(jsii_name="toDescribePublisher")
    def to_describe_publisher(self) -> "Cloudformation":
        '''(experimental) Grants permission to return information about a CloudFormation extension publisher.

        Access Level: Read

        https://docs.aws.amazon.com/AWSCloudFormation/latest/APIReference/API_DescribePublisher.html

        :stability: experimental
        '''
        return typing.cast("Cloudformation", jsii.invoke(self, "toDescribePublisher", []))

    @jsii.member(jsii_name="toDescribeStackDriftDetectionStatus")
    def to_describe_stack_drift_detection_status(self) -> "Cloudformation":
        '''(experimental) Grants permission to return information about a stack drift detection operation.

        Access Level: Read

        https://docs.aws.amazon.com/AWSCloudFormation/latest/APIReference/API_DescribeStackDriftDetectionStatus.html

        :stability: experimental
        '''
        return typing.cast("Cloudformation", jsii.invoke(self, "toDescribeStackDriftDetectionStatus", []))

    @jsii.member(jsii_name="toDescribeStackEvents")
    def to_describe_stack_events(self) -> "Cloudformation":
        '''(experimental) Grants permission to return all stack related events for a specified stack.

        Access Level: Read

        https://docs.aws.amazon.com/AWSCloudFormation/latest/APIReference/API_DescribeStackEvents.html

        :stability: experimental
        '''
        return typing.cast("Cloudformation", jsii.invoke(self, "toDescribeStackEvents", []))

    @jsii.member(jsii_name="toDescribeStackInstance")
    def to_describe_stack_instance(self) -> "Cloudformation":
        '''(experimental) Grants permission to return the stack instance that's associated with the specified stack set, AWS account, and region.

        Access Level: Read

        https://docs.aws.amazon.com/AWSCloudFormation/latest/APIReference/API_DescribeStackInstance.html

        :stability: experimental
        '''
        return typing.cast("Cloudformation", jsii.invoke(self, "toDescribeStackInstance", []))

    @jsii.member(jsii_name="toDescribeStackResource")
    def to_describe_stack_resource(self) -> "Cloudformation":
        '''(experimental) Grants permission to return a description of the specified resource in the specified stack.

        Access Level: Read

        https://docs.aws.amazon.com/AWSCloudFormation/latest/APIReference/API_DescribeStackResource.html

        :stability: experimental
        '''
        return typing.cast("Cloudformation", jsii.invoke(self, "toDescribeStackResource", []))

    @jsii.member(jsii_name="toDescribeStackResourceDrifts")
    def to_describe_stack_resource_drifts(self) -> "Cloudformation":
        '''(experimental) Grants permission to return drift information for the resources that have been checked for drift in the specified stack.

        Access Level: Read

        https://docs.aws.amazon.com/AWSCloudFormation/latest/APIReference/API_DescribeStackResourceDrifts.html

        :stability: experimental
        '''
        return typing.cast("Cloudformation", jsii.invoke(self, "toDescribeStackResourceDrifts", []))

    @jsii.member(jsii_name="toDescribeStackResources")
    def to_describe_stack_resources(self) -> "Cloudformation":
        '''(experimental) Grants permission to return AWS resource descriptions for running and deleted stacks.

        Access Level: Read

        https://docs.aws.amazon.com/AWSCloudFormation/latest/APIReference/API_DescribeStackResources.html

        :stability: experimental
        '''
        return typing.cast("Cloudformation", jsii.invoke(self, "toDescribeStackResources", []))

    @jsii.member(jsii_name="toDescribeStacks")
    def to_describe_stacks(self) -> "Cloudformation":
        '''(experimental) Grants permission to return the description for the specified stack.

        Access Level: List

        https://docs.aws.amazon.com/AWSCloudFormation/latest/APIReference/API_DescribeStacks.html

        :stability: experimental
        '''
        return typing.cast("Cloudformation", jsii.invoke(self, "toDescribeStacks", []))

    @jsii.member(jsii_name="toDescribeStackSet")
    def to_describe_stack_set(self) -> "Cloudformation":
        '''(experimental) Grants permission to return the description of the specified stack set.

        Access Level: Read

        https://docs.aws.amazon.com/AWSCloudFormation/latest/APIReference/API_DescribeStackSet.html

        :stability: experimental
        '''
        return typing.cast("Cloudformation", jsii.invoke(self, "toDescribeStackSet", []))

    @jsii.member(jsii_name="toDescribeStackSetOperation")
    def to_describe_stack_set_operation(self) -> "Cloudformation":
        '''(experimental) Grants permission to return the description of the specified stack set operation.

        Access Level: Read

        https://docs.aws.amazon.com/AWSCloudFormation/latest/APIReference/API_DescribeStackSetOperation.html

        :stability: experimental
        '''
        return typing.cast("Cloudformation", jsii.invoke(self, "toDescribeStackSetOperation", []))

    @jsii.member(jsii_name="toDescribeType")
    def to_describe_type(self) -> "Cloudformation":
        '''(experimental) Grants permission to return information about the CloudFormation type requested.

        Access Level: Read

        https://docs.aws.amazon.com/AWSCloudFormation/latest/APIReference/API_DescribeType.html

        :stability: experimental
        '''
        return typing.cast("Cloudformation", jsii.invoke(self, "toDescribeType", []))

    @jsii.member(jsii_name="toDescribeTypeRegistration")
    def to_describe_type_registration(self) -> "Cloudformation":
        '''(experimental) Grants permission to return information about the registration process for a CloudFormation type.

        Access Level: Read

        https://docs.aws.amazon.com/AWSCloudFormation/latest/APIReference/API_DescribeTypeRegistration.html

        :stability: experimental
        '''
        return typing.cast("Cloudformation", jsii.invoke(self, "toDescribeTypeRegistration", []))

    @jsii.member(jsii_name="toDetectStackDrift")
    def to_detect_stack_drift(self) -> "Cloudformation":
        '''(experimental) Grants permission to detects whether a stack's actual configuration differs, or has drifted, from it's expected configuration, as defined in the stack template and any values specified as template parameters.

        Access Level: Read

        https://docs.aws.amazon.com/AWSCloudFormation/latest/APIReference/API_DetectStackDrift.html

        :stability: experimental
        '''
        return typing.cast("Cloudformation", jsii.invoke(self, "toDetectStackDrift", []))

    @jsii.member(jsii_name="toDetectStackResourceDrift")
    def to_detect_stack_resource_drift(self) -> "Cloudformation":
        '''(experimental) Grants permission to return information about whether a resource's actual configuration differs, or has drifted, from it's expected configuration, as defined in the stack template and any values specified as template parameters.

        Access Level: Read

        https://docs.aws.amazon.com/AWSCloudFormation/latest/APIReference/API_DetectStackResourceDrift.html

        :stability: experimental
        '''
        return typing.cast("Cloudformation", jsii.invoke(self, "toDetectStackResourceDrift", []))

    @jsii.member(jsii_name="toDetectStackSetDrift")
    def to_detect_stack_set_drift(self) -> "Cloudformation":
        '''(experimental) Grants permission to enable users to detect drift on a stack set and the stack instances that belong to that stack set.

        Access Level: Read

        https://docs.aws.amazon.com/AWSCloudFormation/latest/APIReference/API_DetectStackSetDrift.html

        :stability: experimental
        '''
        return typing.cast("Cloudformation", jsii.invoke(self, "toDetectStackSetDrift", []))

    @jsii.member(jsii_name="toEstimateTemplateCost")
    def to_estimate_template_cost(self) -> "Cloudformation":
        '''(experimental) Grants permission to return the estimated monthly cost of a template.

        Access Level: Read

        https://docs.aws.amazon.com/AWSCloudFormation/latest/APIReference/API_EstimateTemplateCost.html

        :stability: experimental
        '''
        return typing.cast("Cloudformation", jsii.invoke(self, "toEstimateTemplateCost", []))

    @jsii.member(jsii_name="toExecuteChangeSet")
    def to_execute_change_set(self) -> "Cloudformation":
        '''(experimental) Grants permission to update a stack using the input information that was provided when the specified change set was created.

        Access Level: Write

        Possible conditions:

        - .ifChangeSetName()

        https://docs.aws.amazon.com/AWSCloudFormation/latest/APIReference/API_ExecuteChangeSet.html

        :stability: experimental
        '''
        return typing.cast("Cloudformation", jsii.invoke(self, "toExecuteChangeSet", []))

    @jsii.member(jsii_name="toGetStackPolicy")
    def to_get_stack_policy(self) -> "Cloudformation":
        '''(experimental) Grants permission to return the stack policy for a specified stack.

        Access Level: Read

        https://docs.aws.amazon.com/AWSCloudFormation/latest/APIReference/API_GetStackPolicy.html

        :stability: experimental
        '''
        return typing.cast("Cloudformation", jsii.invoke(self, "toGetStackPolicy", []))

    @jsii.member(jsii_name="toGetTemplate")
    def to_get_template(self) -> "Cloudformation":
        '''(experimental) Grants permission to return the template body for a specified stack.

        Access Level: Read

        https://docs.aws.amazon.com/AWSCloudFormation/latest/APIReference/API_GetTemplate.html

        :stability: experimental
        '''
        return typing.cast("Cloudformation", jsii.invoke(self, "toGetTemplate", []))

    @jsii.member(jsii_name="toGetTemplateSummary")
    def to_get_template_summary(self) -> "Cloudformation":
        '''(experimental) Grants permission to return information about a new or existing template.

        Access Level: Read

        https://docs.aws.amazon.com/AWSCloudFormation/latest/APIReference/API_GetTemplateSummary.html

        :stability: experimental
        '''
        return typing.cast("Cloudformation", jsii.invoke(self, "toGetTemplateSummary", []))

    @jsii.member(jsii_name="toImportStacksToStackSet")
    def to_import_stacks_to_stack_set(self) -> "Cloudformation":
        '''(experimental) Grants permission to enable users to import existing stacks to a new or existing stackset.

        Access Level: Write

        https://docs.aws.amazon.com/AWSCloudFormation/latest/APIReference/API_ImportStacksToStackSet.html

        :stability: experimental
        '''
        return typing.cast("Cloudformation", jsii.invoke(self, "toImportStacksToStackSet", []))

    @jsii.member(jsii_name="toListChangeSets")
    def to_list_change_sets(self) -> "Cloudformation":
        '''(experimental) Grants permission to return the ID and status of each active change set for a stack.

        For example, AWS CloudFormation lists change sets that are in the CREATE_IN_PROGRESS or CREATE_PENDING state

        Access Level: List

        https://docs.aws.amazon.com/AWSCloudFormation/latest/APIReference/API_ListChangeSets.html

        :stability: experimental
        '''
        return typing.cast("Cloudformation", jsii.invoke(self, "toListChangeSets", []))

    @jsii.member(jsii_name="toListExports")
    def to_list_exports(self) -> "Cloudformation":
        '''(experimental) Grants permission to list all exported output values in the account and region in which you call this action.

        Access Level: List

        https://docs.aws.amazon.com/AWSCloudFormation/latest/APIReference/API_ListExports.html

        :stability: experimental
        '''
        return typing.cast("Cloudformation", jsii.invoke(self, "toListExports", []))

    @jsii.member(jsii_name="toListImports")
    def to_list_imports(self) -> "Cloudformation":
        '''(experimental) Grants permission to list all stacks that are importing an exported output value.

        Access Level: List

        https://docs.aws.amazon.com/AWSCloudFormation/latest/APIReference/API_ListImports.html

        :stability: experimental
        '''
        return typing.cast("Cloudformation", jsii.invoke(self, "toListImports", []))

    @jsii.member(jsii_name="toListStackInstances")
    def to_list_stack_instances(self) -> "Cloudformation":
        '''(experimental) Grants permission to return summary information about stack instances that are associated with the specified stack set.

        Access Level: List

        https://docs.aws.amazon.com/AWSCloudFormation/latest/APIReference/API_ListStackSets.html

        :stability: experimental
        '''
        return typing.cast("Cloudformation", jsii.invoke(self, "toListStackInstances", []))

    @jsii.member(jsii_name="toListStackResources")
    def to_list_stack_resources(self) -> "Cloudformation":
        '''(experimental) Grants permission to return descriptions of all resources of the specified stack.

        Access Level: List

        https://docs.aws.amazon.com/AWSCloudFormation/latest/APIReference/API_ListStackResources.html

        :stability: experimental
        '''
        return typing.cast("Cloudformation", jsii.invoke(self, "toListStackResources", []))

    @jsii.member(jsii_name="toListStacks")
    def to_list_stacks(self) -> "Cloudformation":
        '''(experimental) Grants permission to return the summary information for stacks whose status matches the specified StackStatusFilter.

        Access Level: List

        https://docs.aws.amazon.com/AWSCloudFormation/latest/APIReference/API_ListStacks.html

        :stability: experimental
        '''
        return typing.cast("Cloudformation", jsii.invoke(self, "toListStacks", []))

    @jsii.member(jsii_name="toListStackSetOperationResults")
    def to_list_stack_set_operation_results(self) -> "Cloudformation":
        '''(experimental) Grants permission to return summary information about the results of a stack set operation.

        Access Level: List

        https://docs.aws.amazon.com/AWSCloudFormation/latest/APIReference/API_ListStackSetOperationResults.html

        :stability: experimental
        '''
        return typing.cast("Cloudformation", jsii.invoke(self, "toListStackSetOperationResults", []))

    @jsii.member(jsii_name="toListStackSetOperations")
    def to_list_stack_set_operations(self) -> "Cloudformation":
        '''(experimental) Grants permission to return summary information about operations performed on a stack set.

        Access Level: List

        https://docs.aws.amazon.com/AWSCloudFormation/latest/APIReference/API_ListStackSetOperations.html

        :stability: experimental
        '''
        return typing.cast("Cloudformation", jsii.invoke(self, "toListStackSetOperations", []))

    @jsii.member(jsii_name="toListStackSets")
    def to_list_stack_sets(self) -> "Cloudformation":
        '''(experimental) Grants permission to return summary information about stack sets that are associated with the user.

        Access Level: List

        https://docs.aws.amazon.com/AWSCloudFormation/latest/APIReference/API_ListStackSets.html

        :stability: experimental
        '''
        return typing.cast("Cloudformation", jsii.invoke(self, "toListStackSets", []))

    @jsii.member(jsii_name="toListTypeRegistrations")
    def to_list_type_registrations(self) -> "Cloudformation":
        '''(experimental) Grants permission to list CloudFormation type registration attempts.

        Access Level: List

        https://docs.aws.amazon.com/AWSCloudFormation/latest/APIReference/API_ListTypeRegistrations.html

        :stability: experimental
        '''
        return typing.cast("Cloudformation", jsii.invoke(self, "toListTypeRegistrations", []))

    @jsii.member(jsii_name="toListTypes")
    def to_list_types(self) -> "Cloudformation":
        '''(experimental) Grants permission to list available CloudFormation types.

        Access Level: List

        https://docs.aws.amazon.com/AWSCloudFormation/latest/APIReference/API_ListTypes.html

        :stability: experimental
        '''
        return typing.cast("Cloudformation", jsii.invoke(self, "toListTypes", []))

    @jsii.member(jsii_name="toListTypeVersions")
    def to_list_type_versions(self) -> "Cloudformation":
        '''(experimental) Grants permission to list versions of a particular CloudFormation type.

        Access Level: List

        https://docs.aws.amazon.com/AWSCloudFormation/latest/APIReference/API_ListTypeVersions.html

        :stability: experimental
        '''
        return typing.cast("Cloudformation", jsii.invoke(self, "toListTypeVersions", []))

    @jsii.member(jsii_name="toPublishType")
    def to_publish_type(self) -> "Cloudformation":
        '''(experimental) Grants permission to publish the specified extension to the CloudFormation registry as a public extension in this region.

        Access Level: Write

        https://docs.aws.amazon.com/AWSCloudFormation/latest/APIReference/API_PublishType.html

        :stability: experimental
        '''
        return typing.cast("Cloudformation", jsii.invoke(self, "toPublishType", []))

    @jsii.member(jsii_name="toRecordHandlerProgress")
    def to_record_handler_progress(self) -> "Cloudformation":
        '''(experimental) Grants permission to record the handler progress.

        Access Level: Write

        https://docs.aws.amazon.com/AWSCloudFormation/latest/APIReference/API_RecordHandlerProgress.html

        :stability: experimental
        '''
        return typing.cast("Cloudformation", jsii.invoke(self, "toRecordHandlerProgress", []))

    @jsii.member(jsii_name="toRegisterPublisher")
    def to_register_publisher(self) -> "Cloudformation":
        '''(experimental) Grants permission to register account as a publisher of public extensions in the CloudFormation registry.

        Access Level: Write

        https://docs.aws.amazon.com/AWSCloudFormation/latest/APIReference/API_RegisterPublisher.html

        :stability: experimental
        '''
        return typing.cast("Cloudformation", jsii.invoke(self, "toRegisterPublisher", []))

    @jsii.member(jsii_name="toRegisterType")
    def to_register_type(self) -> "Cloudformation":
        '''(experimental) Grants permission to register a new CloudFormation type.

        Access Level: Write

        https://docs.aws.amazon.com/AWSCloudFormation/latest/APIReference/API_RegisterType.html

        :stability: experimental
        '''
        return typing.cast("Cloudformation", jsii.invoke(self, "toRegisterType", []))

    @jsii.member(jsii_name="toRollbackStack")
    def to_rollback_stack(self) -> "Cloudformation":
        '''(experimental) Grants permission to rollback the stack to the last stable state.

        Access Level: Write

        Possible conditions:

        - .ifRoleArn()

        https://docs.aws.amazon.com/AWSCloudFormation/latest/APIReference/API_RollbackStack.html

        :stability: experimental
        '''
        return typing.cast("Cloudformation", jsii.invoke(self, "toRollbackStack", []))

    @jsii.member(jsii_name="toSetStackPolicy")
    def to_set_stack_policy(self) -> "Cloudformation":
        '''(experimental) Grants permission to set a stack policy for a specified stack.

        Access Level: Permissions management

        Possible conditions:

        - .ifStackPolicyUrl()

        https://docs.aws.amazon.com/AWSCloudFormation/latest/APIReference/API_SetStackPolicy.html

        :stability: experimental
        '''
        return typing.cast("Cloudformation", jsii.invoke(self, "toSetStackPolicy", []))

    @jsii.member(jsii_name="toSetTypeConfiguration")
    def to_set_type_configuration(self) -> "Cloudformation":
        '''(experimental) Grants permission to set the configuration data for a registered CloudFormation extension, in the given account and region.

        Access Level: Write

        https://docs.aws.amazon.com/AWSCloudFormation/latest/APIReference/API_SetTypeConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Cloudformation", jsii.invoke(self, "toSetTypeConfiguration", []))

    @jsii.member(jsii_name="toSetTypeDefaultVersion")
    def to_set_type_default_version(self) -> "Cloudformation":
        '''(experimental) Grants permission to set which version of a CloudFormation type applies to CloudFormation operations.

        Access Level: Write

        https://docs.aws.amazon.com/AWSCloudFormation/latest/APIReference/API_SetTypeDefaultVersion.html

        :stability: experimental
        '''
        return typing.cast("Cloudformation", jsii.invoke(self, "toSetTypeDefaultVersion", []))

    @jsii.member(jsii_name="toSignalResource")
    def to_signal_resource(self) -> "Cloudformation":
        '''(experimental) Grants permission to send a signal to the specified resource with a success or failure status.

        Access Level: Write

        https://docs.aws.amazon.com/AWSCloudFormation/latest/APIReference/API_SignalResource.html

        :stability: experimental
        '''
        return typing.cast("Cloudformation", jsii.invoke(self, "toSignalResource", []))

    @jsii.member(jsii_name="toStopStackSetOperation")
    def to_stop_stack_set_operation(self) -> "Cloudformation":
        '''(experimental) Grants permission to stop an in-progress operation on a stack set and its associated stack instances.

        Access Level: Write

        https://docs.aws.amazon.com/AWSCloudFormation/latest/APIReference/API_StopStackSetOperation.html

        :stability: experimental
        '''
        return typing.cast("Cloudformation", jsii.invoke(self, "toStopStackSetOperation", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Cloudformation":
        '''(experimental) Grants permission to tag cloudformation resources.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/AWSCloudFormation/latest/APIReference/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("Cloudformation", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toTestType")
    def to_test_type(self) -> "Cloudformation":
        '''(experimental) Grants permission to test a registered extension to make sure it meets all necessary requirements for being published in the CloudFormation registry.

        Access Level: Write

        https://docs.aws.amazon.com/AWSCloudFormation/latest/APIReference/API_TestType.html

        :stability: experimental
        '''
        return typing.cast("Cloudformation", jsii.invoke(self, "toTestType", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Cloudformation":
        '''(experimental) Grants permission to untag cloudformation resources.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/AWSCloudFormation/latest/APIReference/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("Cloudformation", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateStack")
    def to_update_stack(self) -> "Cloudformation":
        '''(experimental) Grants permission to update a stack as specified in the template.

        Access Level: Write

        Possible conditions:

        - .ifResourceTypes()
        - .ifRoleArn()
        - .ifStackPolicyUrl()
        - .ifTemplateUrl()
        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/AWSCloudFormation/latest/APIReference/API_UpdateStack.html

        :stability: experimental
        '''
        return typing.cast("Cloudformation", jsii.invoke(self, "toUpdateStack", []))

    @jsii.member(jsii_name="toUpdateStackInstances")
    def to_update_stack_instances(self) -> "Cloudformation":
        '''(experimental) Grants permission to update the parameter values for stack instances for the specified accounts, within the specified regions.

        Access Level: Write

        Possible conditions:

        - .ifTargetRegion()

        https://docs.aws.amazon.com/AWSCloudFormation/latest/APIReference/API_UpdateStackInstances.html

        :stability: experimental
        '''
        return typing.cast("Cloudformation", jsii.invoke(self, "toUpdateStackInstances", []))

    @jsii.member(jsii_name="toUpdateStackSet")
    def to_update_stack_set(self) -> "Cloudformation":
        '''(experimental) Grants permission to update a stackset as specified in the template.

        Access Level: Write

        Possible conditions:

        - .ifRoleArn()
        - .ifTemplateUrl()
        - .ifTargetRegion()
        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/AWSCloudFormation/latest/APIReference/API_UpdateStackSet.html

        :stability: experimental
        '''
        return typing.cast("Cloudformation", jsii.invoke(self, "toUpdateStackSet", []))

    @jsii.member(jsii_name="toUpdateTerminationProtection")
    def to_update_termination_protection(self) -> "Cloudformation":
        '''(experimental) Grants permission to update termination protection for the specified stack.

        Access Level: Write

        https://docs.aws.amazon.com/AWSCloudFormation/latest/APIReference/API_UpdateTerminationProtection.html

        :stability: experimental
        '''
        return typing.cast("Cloudformation", jsii.invoke(self, "toUpdateTerminationProtection", []))

    @jsii.member(jsii_name="toValidateTemplate")
    def to_validate_template(self) -> "Cloudformation":
        '''(experimental) Grants permission to validate a specified template.

        Access Level: Read

        https://docs.aws.amazon.com/AWSCloudFormation/latest/APIReference/API_ValidateTemplate.html

        :stability: experimental
        '''
        return typing.cast("Cloudformation", jsii.invoke(self, "toValidateTemplate", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9184e7273cba65f88aba26a5872f672d613014ea7d4cf9abb495d247a1b8ff09)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__db4f6191e51bce0a3f225582b3f925e8ba7bbb6f6fde7a928b410037cf907a18)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Cloudfront(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Cloudfront",
):
    '''(experimental) Statement provider for service `cloudfront <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazoncloudfront.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `cloudfront <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazoncloudfront.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onCachePolicy")
    def on_cache_policy(
        self,
        id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Cloudfront":
        '''(experimental) Adds a resource of type cache-policy to the statement.

        https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/working-with-policies.html

        :param id: - Identifier for the id.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9e4d784fb2a6b80e510c2d261488aadae1be7e9fe5ef506a5eee1b191f45173e)
            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Cloudfront", jsii.invoke(self, "onCachePolicy", [id, account, partition]))

    @jsii.member(jsii_name="onDistribution")
    def on_distribution(
        self,
        distribution_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Cloudfront":
        '''(experimental) Adds a resource of type distribution to the statement.

        https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/distribution-working-with.html

        :param distribution_id: - Identifier for the distributionId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b6c77c529a4e253c08a8ed6b64ea7ec739fc797aaf2e4951bd562f00e4c8c140)
            check_type(argname="argument distribution_id", value=distribution_id, expected_type=type_hints["distribution_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Cloudfront", jsii.invoke(self, "onDistribution", [distribution_id, account, partition]))

    @jsii.member(jsii_name="onFieldLevelEncryptionConfig")
    def on_field_level_encryption_config(
        self,
        id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Cloudfront":
        '''(experimental) Adds a resource of type field-level-encryption-config to the statement.

        https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/field-level-encryption.html

        :param id: - Identifier for the id.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8ed98fad34a019eb5a5c2596c3a384b8984fd7783777a78d67102b5dcaffecc5)
            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Cloudfront", jsii.invoke(self, "onFieldLevelEncryptionConfig", [id, account, partition]))

    @jsii.member(jsii_name="onFieldLevelEncryptionProfile")
    def on_field_level_encryption_profile(
        self,
        id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Cloudfront":
        '''(experimental) Adds a resource of type field-level-encryption-profile to the statement.

        https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/field-level-encryption.html

        :param id: - Identifier for the id.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b64b7b54dcf0db68a02ea6609a1c1383b7f80c5aee2b6c26e0b8c746ea5a53ce)
            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Cloudfront", jsii.invoke(self, "onFieldLevelEncryptionProfile", [id, account, partition]))

    @jsii.member(jsii_name="onFunction")
    def on_function(
        self,
        name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Cloudfront":
        '''(experimental) Adds a resource of type function to the statement.

        https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/cloudfront-functions.html

        :param name: - Identifier for the name.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__cc0cfa798099c6e61971c9904731ff64c3a8615a53a0cf9abeb6fbdcd799d8ef)
            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Cloudfront", jsii.invoke(self, "onFunction", [name, account, partition]))

    @jsii.member(jsii_name="onOriginAccessControl")
    def on_origin_access_control(
        self,
        id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Cloudfront":
        '''(experimental) Adds a resource of type origin-access-control to the statement.

        https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/working-with-policies.html

        :param id: - Identifier for the id.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f56694671f143cca860b57903c974df90511ff8590d87864856ad60575eb09c8)
            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Cloudfront", jsii.invoke(self, "onOriginAccessControl", [id, account, partition]))

    @jsii.member(jsii_name="onOriginAccessIdentity")
    def on_origin_access_identity(
        self,
        id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Cloudfront":
        '''(experimental) Adds a resource of type origin-access-identity to the statement.

        https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/private-content-restricting-access-to-s3.html#private-content-restricting-access-to-s3-overview

        :param id: - Identifier for the id.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1c55995f03fc4d139afc2b7da20e6e1b48e38fd16a4b77d1a2741090bb268e37)
            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Cloudfront", jsii.invoke(self, "onOriginAccessIdentity", [id, account, partition]))

    @jsii.member(jsii_name="onOriginRequestPolicy")
    def on_origin_request_policy(
        self,
        id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Cloudfront":
        '''(experimental) Adds a resource of type origin-request-policy to the statement.

        https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/working-with-policies.html

        :param id: - Identifier for the id.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5a075dcd29df2195b898468a3119b220523f86bce5ebcb51bafcf10d8b7b7a71)
            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Cloudfront", jsii.invoke(self, "onOriginRequestPolicy", [id, account, partition]))

    @jsii.member(jsii_name="onRealtimeLogConfig")
    def on_realtime_log_config(
        self,
        name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Cloudfront":
        '''(experimental) Adds a resource of type realtime-log-config to the statement.

        https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/real-time-logs.html

        :param name: - Identifier for the name.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bbdaadf676e9bea342f99701d05f458450c63ac8441d428518a55b76951ec2d5)
            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Cloudfront", jsii.invoke(self, "onRealtimeLogConfig", [name, account, partition]))

    @jsii.member(jsii_name="onResponseHeadersPolicy")
    def on_response_headers_policy(
        self,
        id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Cloudfront":
        '''(experimental) Adds a resource of type response-headers-policy to the statement.

        https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/working-with-policies.html

        :param id: - Identifier for the id.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4127cb32d3a7fc167a9aff57e1980a378e022f4775cd13804cb3777d8bb81ba7)
            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Cloudfront", jsii.invoke(self, "onResponseHeadersPolicy", [id, account, partition]))

    @jsii.member(jsii_name="onStreamingDistribution")
    def on_streaming_distribution(
        self,
        distribution_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Cloudfront":
        '''(experimental) Adds a resource of type streaming-distribution to the statement.

        https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/distribution-working-with.html

        :param distribution_id: - Identifier for the distributionId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ea15a4e8cd4b4d73fd5ec239f67b6f748b6e1d6392ed9af926d826e4393a63c0)
            check_type(argname="argument distribution_id", value=distribution_id, expected_type=type_hints["distribution_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Cloudfront", jsii.invoke(self, "onStreamingDistribution", [distribution_id, account, partition]))

    @jsii.member(jsii_name="toAssociateAlias")
    def to_associate_alias(self) -> "Cloudfront":
        '''(experimental) Grants permission to associate an alias to a CloudFront distribution.

        Access Level: Write

        https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_AssociateAlias.html

        :stability: experimental
        '''
        return typing.cast("Cloudfront", jsii.invoke(self, "toAssociateAlias", []))

    @jsii.member(jsii_name="toCreateCachePolicy")
    def to_create_cache_policy(self) -> "Cloudfront":
        '''(experimental) Grants permission to add a new cache policy to CloudFront.

        Access Level: Write

        https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_CreateCachePolicy.html

        :stability: experimental
        '''
        return typing.cast("Cloudfront", jsii.invoke(self, "toCreateCachePolicy", []))

    @jsii.member(jsii_name="toCreateCloudFrontOriginAccessIdentity")
    def to_create_cloud_front_origin_access_identity(self) -> "Cloudfront":
        '''(experimental) Grants permission to create a new CloudFront origin access identity.

        Access Level: Write

        https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_CreateCloudFrontOriginAccessIdentity.html

        :stability: experimental
        '''
        return typing.cast("Cloudfront", jsii.invoke(self, "toCreateCloudFrontOriginAccessIdentity", []))

    @jsii.member(jsii_name="toCreateDistribution")
    def to_create_distribution(self) -> "Cloudfront":
        '''(experimental) Grants permission to create a new web distribution.

        Access Level: Write

        https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_CreateDistribution.html

        :stability: experimental
        '''
        return typing.cast("Cloudfront", jsii.invoke(self, "toCreateDistribution", []))

    @jsii.member(jsii_name="toCreateFieldLevelEncryptionConfig")
    def to_create_field_level_encryption_config(self) -> "Cloudfront":
        '''(experimental) Grants permission to create a new field-level encryption configuration.

        Access Level: Write

        https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_CreateFieldLevelEncryptionConfig.html

        :stability: experimental
        '''
        return typing.cast("Cloudfront", jsii.invoke(self, "toCreateFieldLevelEncryptionConfig", []))

    @jsii.member(jsii_name="toCreateFieldLevelEncryptionProfile")
    def to_create_field_level_encryption_profile(self) -> "Cloudfront":
        '''(experimental) Grants permission to create a field-level encryption profile.

        Access Level: Write

        https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_CreateFieldLevelEncryptionProfile.html

        :stability: experimental
        '''
        return typing.cast("Cloudfront", jsii.invoke(self, "toCreateFieldLevelEncryptionProfile", []))

    @jsii.member(jsii_name="toCreateFunction")
    def to_create_function(self) -> "Cloudfront":
        '''(experimental) Grants permission to create a CloudFront function.

        Access Level: Write

        https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_CreateFunction.html

        :stability: experimental
        '''
        return typing.cast("Cloudfront", jsii.invoke(self, "toCreateFunction", []))

    @jsii.member(jsii_name="toCreateInvalidation")
    def to_create_invalidation(self) -> "Cloudfront":
        '''(experimental) Grants permission to create a new invalidation batch request.

        Access Level: Write

        https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_CreateInvalidation.html

        :stability: experimental
        '''
        return typing.cast("Cloudfront", jsii.invoke(self, "toCreateInvalidation", []))

    @jsii.member(jsii_name="toCreateKeyGroup")
    def to_create_key_group(self) -> "Cloudfront":
        '''(experimental) Grants permission to add a new key group to CloudFront.

        Access Level: Write

        https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_CreateKeyGroup.html

        :stability: experimental
        '''
        return typing.cast("Cloudfront", jsii.invoke(self, "toCreateKeyGroup", []))

    @jsii.member(jsii_name="toCreateMonitoringSubscription")
    def to_create_monitoring_subscription(self) -> "Cloudfront":
        '''(experimental) Grants permission to enable additional CloudWatch metrics for the specified CloudFront distribution. The additional metrics incur an additional cost.

        Access Level: Write

        https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_CreateMonitoringSubscription.html

        :stability: experimental
        '''
        return typing.cast("Cloudfront", jsii.invoke(self, "toCreateMonitoringSubscription", []))

    @jsii.member(jsii_name="toCreateOriginAccessControl")
    def to_create_origin_access_control(self) -> "Cloudfront":
        '''(experimental) Grants permission to create a new origin access control.

        Access Level: Write

        https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_CreateOriginAccessControl.html

        :stability: experimental
        '''
        return typing.cast("Cloudfront", jsii.invoke(self, "toCreateOriginAccessControl", []))

    @jsii.member(jsii_name="toCreateOriginRequestPolicy")
    def to_create_origin_request_policy(self) -> "Cloudfront":
        '''(experimental) Grants permission to add a new origin request policy to CloudFront.

        Access Level: Write

        https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_CreateOriginRequestPolicy.html

        :stability: experimental
        '''
        return typing.cast("Cloudfront", jsii.invoke(self, "toCreateOriginRequestPolicy", []))

    @jsii.member(jsii_name="toCreatePublicKey")
    def to_create_public_key(self) -> "Cloudfront":
        '''(experimental) Grants permission to add a new public key to CloudFront.

        Access Level: Write

        https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_CreatePublicKey.html

        :stability: experimental
        '''
        return typing.cast("Cloudfront", jsii.invoke(self, "toCreatePublicKey", []))

    @jsii.member(jsii_name="toCreateRealtimeLogConfig")
    def to_create_realtime_log_config(self) -> "Cloudfront":
        '''(experimental) Grants permission to create a real-time log configuration.

        Access Level: Write

        https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_CreateRealtimeLogConfig.html

        :stability: experimental
        '''
        return typing.cast("Cloudfront", jsii.invoke(self, "toCreateRealtimeLogConfig", []))

    @jsii.member(jsii_name="toCreateResponseHeadersPolicy")
    def to_create_response_headers_policy(self) -> "Cloudfront":
        '''(experimental) Grants permission to add a new response headers policy to CloudFront.

        Access Level: Write

        https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_CreateResponseHeadersPolicy.html

        :stability: experimental
        '''
        return typing.cast("Cloudfront", jsii.invoke(self, "toCreateResponseHeadersPolicy", []))

    @jsii.member(jsii_name="toCreateSavingsPlan")
    def to_create_savings_plan(self) -> "Cloudfront":
        '''(experimental) Grants permission to create a new savings plan.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/cf-api-permissions-ref.html

        :stability: experimental
        '''
        return typing.cast("Cloudfront", jsii.invoke(self, "toCreateSavingsPlan", []))

    @jsii.member(jsii_name="toCreateStreamingDistribution")
    def to_create_streaming_distribution(self) -> "Cloudfront":
        '''(experimental) Grants permission to create a new RTMP distribution.

        Access Level: Write

        https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_CreateStreamingDistribution.html

        :stability: experimental
        '''
        return typing.cast("Cloudfront", jsii.invoke(self, "toCreateStreamingDistribution", []))

    @jsii.member(jsii_name="toCreateStreamingDistributionWithTags")
    def to_create_streaming_distribution_with_tags(self) -> "Cloudfront":
        '''(experimental) Grants permission to create a new RTMP distribution with tags.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_CreateStreamingDistributionWithTags.html

        :stability: experimental
        '''
        return typing.cast("Cloudfront", jsii.invoke(self, "toCreateStreamingDistributionWithTags", []))

    @jsii.member(jsii_name="toDeleteCachePolicy")
    def to_delete_cache_policy(self) -> "Cloudfront":
        '''(experimental) Grants permission to delete a cache policy.

        Access Level: Write

        https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_DeleteCachePolicy.html

        :stability: experimental
        '''
        return typing.cast("Cloudfront", jsii.invoke(self, "toDeleteCachePolicy", []))

    @jsii.member(jsii_name="toDeleteCloudFrontOriginAccessIdentity")
    def to_delete_cloud_front_origin_access_identity(self) -> "Cloudfront":
        '''(experimental) Grants permission to delete a CloudFront origin access identity.

        Access Level: Write

        https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_DeleteCloudFrontOriginAccessIdentity.html

        :stability: experimental
        '''
        return typing.cast("Cloudfront", jsii.invoke(self, "toDeleteCloudFrontOriginAccessIdentity", []))

    @jsii.member(jsii_name="toDeleteDistribution")
    def to_delete_distribution(self) -> "Cloudfront":
        '''(experimental) Grants permission to delete a web distribution.

        Access Level: Write

        https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_DeleteDistribution.html

        :stability: experimental
        '''
        return typing.cast("Cloudfront", jsii.invoke(self, "toDeleteDistribution", []))

    @jsii.member(jsii_name="toDeleteFieldLevelEncryptionConfig")
    def to_delete_field_level_encryption_config(self) -> "Cloudfront":
        '''(experimental) Grants permission to delete a field-level encryption configuration.

        Access Level: Write

        https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_DeleteFieldLevelEncryptionConfig.html

        :stability: experimental
        '''
        return typing.cast("Cloudfront", jsii.invoke(self, "toDeleteFieldLevelEncryptionConfig", []))

    @jsii.member(jsii_name="toDeleteFieldLevelEncryptionProfile")
    def to_delete_field_level_encryption_profile(self) -> "Cloudfront":
        '''(experimental) Grants permission to delete a field-level encryption profile.

        Access Level: Write

        https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_DeleteFieldLevelEncryptionProfile.html

        :stability: experimental
        '''
        return typing.cast("Cloudfront", jsii.invoke(self, "toDeleteFieldLevelEncryptionProfile", []))

    @jsii.member(jsii_name="toDeleteFunction")
    def to_delete_function(self) -> "Cloudfront":
        '''(experimental) Grants permission to delete a CloudFront function.

        Access Level: Write

        https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_DeleteFunction.html

        :stability: experimental
        '''
        return typing.cast("Cloudfront", jsii.invoke(self, "toDeleteFunction", []))

    @jsii.member(jsii_name="toDeleteKeyGroup")
    def to_delete_key_group(self) -> "Cloudfront":
        '''(experimental) Grants permission to delete a key group.

        Access Level: Write

        https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_DeleteKeyGroup.html

        :stability: experimental
        '''
        return typing.cast("Cloudfront", jsii.invoke(self, "toDeleteKeyGroup", []))

    @jsii.member(jsii_name="toDeleteMonitoringSubscription")
    def to_delete_monitoring_subscription(self) -> "Cloudfront":
        '''(experimental) Grants permission to disable additional CloudWatch metrics for the specified CloudFront distribution.

        Access Level: Write

        https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_DeleteMonitoringSubscription.html

        :stability: experimental
        '''
        return typing.cast("Cloudfront", jsii.invoke(self, "toDeleteMonitoringSubscription", []))

    @jsii.member(jsii_name="toDeleteOriginAccessControl")
    def to_delete_origin_access_control(self) -> "Cloudfront":
        '''(experimental) Grants permission to delete an origin access control.

        Access Level: Write

        https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_DeleteOriginAccessControl.html

        :stability: experimental
        '''
        return typing.cast("Cloudfront", jsii.invoke(self, "toDeleteOriginAccessControl", []))

    @jsii.member(jsii_name="toDeleteOriginRequestPolicy")
    def to_delete_origin_request_policy(self) -> "Cloudfront":
        '''(experimental) Grants permission to delete an origin request policy.

        Access Level: Write

        https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_DeleteOriginRequestPolicy.html

        :stability: experimental
        '''
        return typing.cast("Cloudfront", jsii.invoke(self, "toDeleteOriginRequestPolicy", []))

    @jsii.member(jsii_name="toDeletePublicKey")
    def to_delete_public_key(self) -> "Cloudfront":
        '''(experimental) Grants permission to delete a public key from CloudFront.

        Access Level: Write

        https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_DeletePublicKey.html

        :stability: experimental
        '''
        return typing.cast("Cloudfront", jsii.invoke(self, "toDeletePublicKey", []))

    @jsii.member(jsii_name="toDeleteRealtimeLogConfig")
    def to_delete_realtime_log_config(self) -> "Cloudfront":
        '''(experimental) Grants permission to delete a real-time log configuration.

        Access Level: Write

        https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_DeleteRealtimeLogConfig.html

        :stability: experimental
        '''
        return typing.cast("Cloudfront", jsii.invoke(self, "toDeleteRealtimeLogConfig", []))

    @jsii.member(jsii_name="toDeleteResponseHeadersPolicy")
    def to_delete_response_headers_policy(self) -> "Cloudfront":
        '''(experimental) Grants permission to delete a response headers policy.

        Access Level: Write

        https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_DeleteResponseHeadersPolicy.html

        :stability: experimental
        '''
        return typing.cast("Cloudfront", jsii.invoke(self, "toDeleteResponseHeadersPolicy", []))

    @jsii.member(jsii_name="toDeleteStreamingDistribution")
    def to_delete_streaming_distribution(self) -> "Cloudfront":
        '''(experimental) Grants permission to delete an RTMP distribution.

        Access Level: Write

        https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_DeleteStreamingDistribution.html

        :stability: experimental
        '''
        return typing.cast("Cloudfront", jsii.invoke(self, "toDeleteStreamingDistribution", []))

    @jsii.member(jsii_name="toDescribeFunction")
    def to_describe_function(self) -> "Cloudfront":
        '''(experimental) Grants permission to get a CloudFront function summary.

        Access Level: Read

        https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_DescribeFunction.html

        :stability: experimental
        '''
        return typing.cast("Cloudfront", jsii.invoke(self, "toDescribeFunction", []))

    @jsii.member(jsii_name="toGetCachePolicy")
    def to_get_cache_policy(self) -> "Cloudfront":
        '''(experimental) Grants permission to get the cache policy.

        Access Level: Read

        https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_GetCachePolicy.html

        :stability: experimental
        '''
        return typing.cast("Cloudfront", jsii.invoke(self, "toGetCachePolicy", []))

    @jsii.member(jsii_name="toGetCachePolicyConfig")
    def to_get_cache_policy_config(self) -> "Cloudfront":
        '''(experimental) Grants permission to get the cache policy configuration.

        Access Level: Read

        https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_GetCachePolicyConfig.html

        :stability: experimental
        '''
        return typing.cast("Cloudfront", jsii.invoke(self, "toGetCachePolicyConfig", []))

    @jsii.member(jsii_name="toGetCloudFrontOriginAccessIdentity")
    def to_get_cloud_front_origin_access_identity(self) -> "Cloudfront":
        '''(experimental) Grants permission to get the information about a CloudFront origin access identity.

        Access Level: Read

        https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_GetCloudFrontOriginAccessIdentity.html

        :stability: experimental
        '''
        return typing.cast("Cloudfront", jsii.invoke(self, "toGetCloudFrontOriginAccessIdentity", []))

    @jsii.member(jsii_name="toGetCloudFrontOriginAccessIdentityConfig")
    def to_get_cloud_front_origin_access_identity_config(self) -> "Cloudfront":
        '''(experimental) Grants permission to get the configuration information about a Cloudfront origin access identity.

        Access Level: Read

        https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_GetCloudFrontOriginAccessIdentityConfig.html

        :stability: experimental
        '''
        return typing.cast("Cloudfront", jsii.invoke(self, "toGetCloudFrontOriginAccessIdentityConfig", []))

    @jsii.member(jsii_name="toGetDistribution")
    def to_get_distribution(self) -> "Cloudfront":
        '''(experimental) Grants permission to get the information about a web distribution.

        Access Level: Read

        https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_GetDistribution.html

        :stability: experimental
        '''
        return typing.cast("Cloudfront", jsii.invoke(self, "toGetDistribution", []))

    @jsii.member(jsii_name="toGetDistributionConfig")
    def to_get_distribution_config(self) -> "Cloudfront":
        '''(experimental) Grants permission to get the configuration information about a distribution.

        Access Level: Read

        https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_GetDistributionConfig.html

        :stability: experimental
        '''
        return typing.cast("Cloudfront", jsii.invoke(self, "toGetDistributionConfig", []))

    @jsii.member(jsii_name="toGetFieldLevelEncryption")
    def to_get_field_level_encryption(self) -> "Cloudfront":
        '''(experimental) Grants permission to get the field-level encryption configuration information.

        Access Level: Read

        https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_GetFieldLevelEncryption.html

        :stability: experimental
        '''
        return typing.cast("Cloudfront", jsii.invoke(self, "toGetFieldLevelEncryption", []))

    @jsii.member(jsii_name="toGetFieldLevelEncryptionConfig")
    def to_get_field_level_encryption_config(self) -> "Cloudfront":
        '''(experimental) Grants permission to get the field-level encryption configuration information.

        Access Level: Read

        https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_GetFieldLevelEncryptionConfig.html

        :stability: experimental
        '''
        return typing.cast("Cloudfront", jsii.invoke(self, "toGetFieldLevelEncryptionConfig", []))

    @jsii.member(jsii_name="toGetFieldLevelEncryptionProfile")
    def to_get_field_level_encryption_profile(self) -> "Cloudfront":
        '''(experimental) Grants permission to get the field-level encryption configuration information.

        Access Level: Read

        https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_GetFieldLevelEncryptionProfile.html

        :stability: experimental
        '''
        return typing.cast("Cloudfront", jsii.invoke(self, "toGetFieldLevelEncryptionProfile", []))

    @jsii.member(jsii_name="toGetFieldLevelEncryptionProfileConfig")
    def to_get_field_level_encryption_profile_config(self) -> "Cloudfront":
        '''(experimental) Grants permission to get the field-level encryption profile configuration information.

        Access Level: Read

        https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_GetFieldLevelEncryptionProfileConfig.html

        :stability: experimental
        '''
        return typing.cast("Cloudfront", jsii.invoke(self, "toGetFieldLevelEncryptionProfileConfig", []))

    @jsii.member(jsii_name="toGetFunction")
    def to_get_function(self) -> "Cloudfront":
        '''(experimental) Grants permission to get a CloudFront function's code.

        Access Level: Read

        https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_GetFunction.html

        :stability: experimental
        '''
        return typing.cast("Cloudfront", jsii.invoke(self, "toGetFunction", []))

    @jsii.member(jsii_name="toGetInvalidation")
    def to_get_invalidation(self) -> "Cloudfront":
        '''(experimental) Grants permission to get the information about an invalidation.

        Access Level: Read

        https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_GetInvalidation.html

        :stability: experimental
        '''
        return typing.cast("Cloudfront", jsii.invoke(self, "toGetInvalidation", []))

    @jsii.member(jsii_name="toGetKeyGroup")
    def to_get_key_group(self) -> "Cloudfront":
        '''(experimental) Grants permission to get a key group.

        Access Level: Read

        https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_GetKeyGroup.html

        :stability: experimental
        '''
        return typing.cast("Cloudfront", jsii.invoke(self, "toGetKeyGroup", []))

    @jsii.member(jsii_name="toGetKeyGroupConfig")
    def to_get_key_group_config(self) -> "Cloudfront":
        '''(experimental) Grants permission to get a key group configuration.

        Access Level: Read

        https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_GetKeyGroupConfig.html

        :stability: experimental
        '''
        return typing.cast("Cloudfront", jsii.invoke(self, "toGetKeyGroupConfig", []))

    @jsii.member(jsii_name="toGetMonitoringSubscription")
    def to_get_monitoring_subscription(self) -> "Cloudfront":
        '''(experimental) Grants permission to get information about whether additional CloudWatch metrics are enabled for the specified CloudFront distribution.

        Access Level: Read

        https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_GetMonitoringSubscription.html

        :stability: experimental
        '''
        return typing.cast("Cloudfront", jsii.invoke(self, "toGetMonitoringSubscription", []))

    @jsii.member(jsii_name="toGetOriginAccessControl")
    def to_get_origin_access_control(self) -> "Cloudfront":
        '''(experimental) Grants permission to get the origin access control.

        Access Level: Read

        https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_GetOriginAccessControl.html

        :stability: experimental
        '''
        return typing.cast("Cloudfront", jsii.invoke(self, "toGetOriginAccessControl", []))

    @jsii.member(jsii_name="toGetOriginAccessControlConfig")
    def to_get_origin_access_control_config(self) -> "Cloudfront":
        '''(experimental) Grants permission to get the origin access control configuration.

        Access Level: Read

        https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_GetOriginAccessControlConfig.html

        :stability: experimental
        '''
        return typing.cast("Cloudfront", jsii.invoke(self, "toGetOriginAccessControlConfig", []))

    @jsii.member(jsii_name="toGetOriginRequestPolicy")
    def to_get_origin_request_policy(self) -> "Cloudfront":
        '''(experimental) Grants permission to get the origin request policy.

        Access Level: Read

        https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_GetOriginRequestPolicy.html

        :stability: experimental
        '''
        return typing.cast("Cloudfront", jsii.invoke(self, "toGetOriginRequestPolicy", []))

    @jsii.member(jsii_name="toGetOriginRequestPolicyConfig")
    def to_get_origin_request_policy_config(self) -> "Cloudfront":
        '''(experimental) Grants permission to get the origin request policy configuration.

        Access Level: Read

        https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_GetOriginRequestPolicyConfig.html

        :stability: experimental
        '''
        return typing.cast("Cloudfront", jsii.invoke(self, "toGetOriginRequestPolicyConfig", []))

    @jsii.member(jsii_name="toGetPublicKey")
    def to_get_public_key(self) -> "Cloudfront":
        '''(experimental) Grants permission to get the public key information.

        Access Level: Read

        https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_GetPublicKey.html

        :stability: experimental
        '''
        return typing.cast("Cloudfront", jsii.invoke(self, "toGetPublicKey", []))

    @jsii.member(jsii_name="toGetPublicKeyConfig")
    def to_get_public_key_config(self) -> "Cloudfront":
        '''(experimental) Grants permission to get the public key configuration information.

        Access Level: Read

        https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_GetPublicKeyConfig.html

        :stability: experimental
        '''
        return typing.cast("Cloudfront", jsii.invoke(self, "toGetPublicKeyConfig", []))

    @jsii.member(jsii_name="toGetRealtimeLogConfig")
    def to_get_realtime_log_config(self) -> "Cloudfront":
        '''(experimental) Grants permission to get a real-time log configuration.

        Access Level: Read

        https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_GetRealtimeLogConfig.html

        :stability: experimental
        '''
        return typing.cast("Cloudfront", jsii.invoke(self, "toGetRealtimeLogConfig", []))

    @jsii.member(jsii_name="toGetResponseHeadersPolicy")
    def to_get_response_headers_policy(self) -> "Cloudfront":
        '''(experimental) Grants permission to get the response headers policy.

        Access Level: Read

        https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_GetResponseHeadersPolicy.html

        :stability: experimental
        '''
        return typing.cast("Cloudfront", jsii.invoke(self, "toGetResponseHeadersPolicy", []))

    @jsii.member(jsii_name="toGetResponseHeadersPolicyConfig")
    def to_get_response_headers_policy_config(self) -> "Cloudfront":
        '''(experimental) Grants permission to get the response headers policy configuration.

        Access Level: Read

        https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_GetResponseHeadersPolicyConfig.html

        :stability: experimental
        '''
        return typing.cast("Cloudfront", jsii.invoke(self, "toGetResponseHeadersPolicyConfig", []))

    @jsii.member(jsii_name="toGetSavingsPlan")
    def to_get_savings_plan(self) -> "Cloudfront":
        '''(experimental) Grants permission to get a savings plan.

        Access Level: Read

        https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/cf-api-permissions-ref.html

        :stability: experimental
        '''
        return typing.cast("Cloudfront", jsii.invoke(self, "toGetSavingsPlan", []))

    @jsii.member(jsii_name="toGetStreamingDistribution")
    def to_get_streaming_distribution(self) -> "Cloudfront":
        '''(experimental) Grants permission to get the information about an RTMP distribution.

        Access Level: Read

        https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_GetStreamingDistribution.html

        :stability: experimental
        '''
        return typing.cast("Cloudfront", jsii.invoke(self, "toGetStreamingDistribution", []))

    @jsii.member(jsii_name="toGetStreamingDistributionConfig")
    def to_get_streaming_distribution_config(self) -> "Cloudfront":
        '''(experimental) Grants permission to get the configuration information about a streaming distribution.

        Access Level: Read

        https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_GetStreamingDistributionConfig.html

        :stability: experimental
        '''
        return typing.cast("Cloudfront", jsii.invoke(self, "toGetStreamingDistributionConfig", []))

    @jsii.member(jsii_name="toListCachePolicies")
    def to_list_cache_policies(self) -> "Cloudfront":
        '''(experimental) Grants permission to list all cache policies that have been created in CloudFront for this account.

        Access Level: List

        https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_ListCachePolicies.html

        :stability: experimental
        '''
        return typing.cast("Cloudfront", jsii.invoke(self, "toListCachePolicies", []))

    @jsii.member(jsii_name="toListCloudFrontOriginAccessIdentities")
    def to_list_cloud_front_origin_access_identities(self) -> "Cloudfront":
        '''(experimental) Grants permission to list your CloudFront origin access identities.

        Access Level: List

        https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_ListCloudFrontOriginAccessIdentities.html

        :stability: experimental
        '''
        return typing.cast("Cloudfront", jsii.invoke(self, "toListCloudFrontOriginAccessIdentities", []))

    @jsii.member(jsii_name="toListConflictingAliases")
    def to_list_conflicting_aliases(self) -> "Cloudfront":
        '''(experimental) Grants permission to list all aliases that conflict with the given alias in CloudFront.

        Access Level: List

        https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_ListConflictingAliases.html

        :stability: experimental
        '''
        return typing.cast("Cloudfront", jsii.invoke(self, "toListConflictingAliases", []))

    @jsii.member(jsii_name="toListDistributions")
    def to_list_distributions(self) -> "Cloudfront":
        '''(experimental) Grants permission to list the distributions associated with your AWS account.

        Access Level: List

        https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_ListDistributions.html

        :stability: experimental
        '''
        return typing.cast("Cloudfront", jsii.invoke(self, "toListDistributions", []))

    @jsii.member(jsii_name="toListDistributionsByCachePolicyId")
    def to_list_distributions_by_cache_policy_id(self) -> "Cloudfront":
        '''(experimental) Grants permission to list distribution IDs for distributions that have a cache behavior that's associated with the specified cache policy.

        Access Level: List

        https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_ListDistributionsByCachePolicyId.html

        :stability: experimental
        '''
        return typing.cast("Cloudfront", jsii.invoke(self, "toListDistributionsByCachePolicyId", []))

    @jsii.member(jsii_name="toListDistributionsByKeyGroup")
    def to_list_distributions_by_key_group(self) -> "Cloudfront":
        '''(experimental) Grants permission to list distribution IDs for distributions that have a cache behavior that's associated with the specified key group.

        Access Level: List

        https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_ListDistributionsByKeyGroup.html

        :stability: experimental
        '''
        return typing.cast("Cloudfront", jsii.invoke(self, "toListDistributionsByKeyGroup", []))

    @jsii.member(jsii_name="toListDistributionsByLambdaFunction")
    def to_list_distributions_by_lambda_function(self) -> "Cloudfront":
        '''(experimental) Grants permission to list the distributions associated a Lambda function.

        Access Level: List

        https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/cf-api-permissions-ref.html

        :stability: experimental
        '''
        return typing.cast("Cloudfront", jsii.invoke(self, "toListDistributionsByLambdaFunction", []))

    @jsii.member(jsii_name="toListDistributionsByOriginRequestPolicyId")
    def to_list_distributions_by_origin_request_policy_id(self) -> "Cloudfront":
        '''(experimental) Grants permission to list distribution IDs for distributions that have a cache behavior that's associated with the specified origin request policy.

        Access Level: List

        https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_ListDistributionsByOriginRequestPolicyId.html

        :stability: experimental
        '''
        return typing.cast("Cloudfront", jsii.invoke(self, "toListDistributionsByOriginRequestPolicyId", []))

    @jsii.member(jsii_name="toListDistributionsByRealtimeLogConfig")
    def to_list_distributions_by_realtime_log_config(self) -> "Cloudfront":
        '''(experimental) Grants permission to get a list of distributions that have a cache behavior that’s associated with the specified real-time log configuration.

        Access Level: List

        https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_ListDistributionsByRealtimeLogConfig.html

        :stability: experimental
        '''
        return typing.cast("Cloudfront", jsii.invoke(self, "toListDistributionsByRealtimeLogConfig", []))

    @jsii.member(jsii_name="toListDistributionsByResponseHeadersPolicyId")
    def to_list_distributions_by_response_headers_policy_id(self) -> "Cloudfront":
        '''(experimental) Grants permission to list distribution IDs for distributions that have a cache behavior that's associated with the specified response headers policy.

        Access Level: List

        https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_ListDistributionsByResponseHeadersPolicyId.html

        :stability: experimental
        '''
        return typing.cast("Cloudfront", jsii.invoke(self, "toListDistributionsByResponseHeadersPolicyId", []))

    @jsii.member(jsii_name="toListDistributionsByWebACLId")
    def to_list_distributions_by_web_acl_id(self) -> "Cloudfront":
        '''(experimental) Grants permission to list the distributions associated with your AWS account with given AWS WAF web ACL.

        Access Level: List

        https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_ListDistributionsByWebACLId.html

        :stability: experimental
        '''
        return typing.cast("Cloudfront", jsii.invoke(self, "toListDistributionsByWebACLId", []))

    @jsii.member(jsii_name="toListFieldLevelEncryptionConfigs")
    def to_list_field_level_encryption_configs(self) -> "Cloudfront":
        '''(experimental) Grants permission to list all field-level encryption configurations that have been created in CloudFront for this account.

        Access Level: List

        https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_ListFieldLevelEncryptionConfigs.html

        :stability: experimental
        '''
        return typing.cast("Cloudfront", jsii.invoke(self, "toListFieldLevelEncryptionConfigs", []))

    @jsii.member(jsii_name="toListFieldLevelEncryptionProfiles")
    def to_list_field_level_encryption_profiles(self) -> "Cloudfront":
        '''(experimental) Grants permission to list all field-level encryption profiles that have been created in CloudFront for this account.

        Access Level: List

        https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_ListFieldLevelEncryptionProfiles.html

        :stability: experimental
        '''
        return typing.cast("Cloudfront", jsii.invoke(self, "toListFieldLevelEncryptionProfiles", []))

    @jsii.member(jsii_name="toListFunctions")
    def to_list_functions(self) -> "Cloudfront":
        '''(experimental) Grants permission to get a list of CloudFront functions.

        Access Level: List

        https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_ListFunctions.html

        :stability: experimental
        '''
        return typing.cast("Cloudfront", jsii.invoke(self, "toListFunctions", []))

    @jsii.member(jsii_name="toListInvalidations")
    def to_list_invalidations(self) -> "Cloudfront":
        '''(experimental) Grants permission to list your invalidation batches.

        Access Level: List

        https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_ListInvalidations.html

        :stability: experimental
        '''
        return typing.cast("Cloudfront", jsii.invoke(self, "toListInvalidations", []))

    @jsii.member(jsii_name="toListKeyGroups")
    def to_list_key_groups(self) -> "Cloudfront":
        '''(experimental) Grants permission to list all key groups that have been created in CloudFront for this account.

        Access Level: List

        https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_ListKeyGroups.html

        :stability: experimental
        '''
        return typing.cast("Cloudfront", jsii.invoke(self, "toListKeyGroups", []))

    @jsii.member(jsii_name="toListOriginAccessControls")
    def to_list_origin_access_controls(self) -> "Cloudfront":
        '''(experimental) Grants permission to list all origin access controls in the account.

        Access Level: List

        https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_ListOriginAccessControls.html

        :stability: experimental
        '''
        return typing.cast("Cloudfront", jsii.invoke(self, "toListOriginAccessControls", []))

    @jsii.member(jsii_name="toListOriginRequestPolicies")
    def to_list_origin_request_policies(self) -> "Cloudfront":
        '''(experimental) Grants permission to list all origin request policies that have been created in CloudFront for this account.

        Access Level: List

        https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_ListOriginRequestPolicies.html

        :stability: experimental
        '''
        return typing.cast("Cloudfront", jsii.invoke(self, "toListOriginRequestPolicies", []))

    @jsii.member(jsii_name="toListPublicKeys")
    def to_list_public_keys(self) -> "Cloudfront":
        '''(experimental) Grants permission to list all public keys that have been added to CloudFront for this account.

        Access Level: List

        https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_ListPublicKeys.html

        :stability: experimental
        '''
        return typing.cast("Cloudfront", jsii.invoke(self, "toListPublicKeys", []))

    @jsii.member(jsii_name="toListRateCards")
    def to_list_rate_cards(self) -> "Cloudfront":
        '''(experimental) Grants permission to list CloudFront rate cards for the account.

        Access Level: List

        https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/cf-api-permissions-ref.html

        :stability: experimental
        '''
        return typing.cast("Cloudfront", jsii.invoke(self, "toListRateCards", []))

    @jsii.member(jsii_name="toListRealtimeLogConfigs")
    def to_list_realtime_log_configs(self) -> "Cloudfront":
        '''(experimental) Grants permission to get a list of real-time log configurations.

        Access Level: List

        https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_ListRealtimeLogConfigs.html

        :stability: experimental
        '''
        return typing.cast("Cloudfront", jsii.invoke(self, "toListRealtimeLogConfigs", []))

    @jsii.member(jsii_name="toListResponseHeadersPolicies")
    def to_list_response_headers_policies(self) -> "Cloudfront":
        '''(experimental) Grants permission to list all response headers policies that have been created in CloudFront for this account.

        Access Level: List

        https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_ListResponseHeadersPolicies.html

        :stability: experimental
        '''
        return typing.cast("Cloudfront", jsii.invoke(self, "toListResponseHeadersPolicies", []))

    @jsii.member(jsii_name="toListSavingsPlans")
    def to_list_savings_plans(self) -> "Cloudfront":
        '''(experimental) Grants permission to list savings plans in the account.

        Access Level: List

        https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/cf-api-permissions-ref.html

        :stability: experimental
        '''
        return typing.cast("Cloudfront", jsii.invoke(self, "toListSavingsPlans", []))

    @jsii.member(jsii_name="toListStreamingDistributions")
    def to_list_streaming_distributions(self) -> "Cloudfront":
        '''(experimental) Grants permission to list your RTMP distributions.

        Access Level: List

        https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_ListStreamingDistributions.html

        :stability: experimental
        '''
        return typing.cast("Cloudfront", jsii.invoke(self, "toListStreamingDistributions", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Cloudfront":
        '''(experimental) Grants permission to list tags for a CloudFront resource.

        Access Level: Read

        https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("Cloudfront", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toListUsages")
    def to_list_usages(self) -> "Cloudfront":
        '''(experimental) Grants permission to list CloudFront usage.

        Access Level: List

        https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/cf-api-permissions-ref.html

        :stability: experimental
        '''
        return typing.cast("Cloudfront", jsii.invoke(self, "toListUsages", []))

    @jsii.member(jsii_name="toPublishFunction")
    def to_publish_function(self) -> "Cloudfront":
        '''(experimental) Grants permission to publish a CloudFront function.

        Access Level: Write

        https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_PublishFunction.html

        :stability: experimental
        '''
        return typing.cast("Cloudfront", jsii.invoke(self, "toPublishFunction", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Cloudfront":
        '''(experimental) Grants permission to add tags to a CloudFront resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("Cloudfront", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toTestFunction")
    def to_test_function(self) -> "Cloudfront":
        '''(experimental) Grants permission to test a CloudFront function.

        Access Level: Write

        https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_TestFunction.html

        :stability: experimental
        '''
        return typing.cast("Cloudfront", jsii.invoke(self, "toTestFunction", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Cloudfront":
        '''(experimental) Grants permission to remove tags from a CloudFront resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("Cloudfront", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateCachePolicy")
    def to_update_cache_policy(self) -> "Cloudfront":
        '''(experimental) Grants permission to update a cache policy.

        Access Level: Write

        https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_UpdateCachePolicy.html

        :stability: experimental
        '''
        return typing.cast("Cloudfront", jsii.invoke(self, "toUpdateCachePolicy", []))

    @jsii.member(jsii_name="toUpdateCloudFrontOriginAccessIdentity")
    def to_update_cloud_front_origin_access_identity(self) -> "Cloudfront":
        '''(experimental) Grants permission to set the configuration for a CloudFront origin access identity.

        Access Level: Write

        https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_UpdateCloudFrontOriginAccessIdentity.html

        :stability: experimental
        '''
        return typing.cast("Cloudfront", jsii.invoke(self, "toUpdateCloudFrontOriginAccessIdentity", []))

    @jsii.member(jsii_name="toUpdateDistribution")
    def to_update_distribution(self) -> "Cloudfront":
        '''(experimental) Grants permission to update the configuration for a web distribution.

        Access Level: Write

        https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_UpdateDistribution.html

        :stability: experimental
        '''
        return typing.cast("Cloudfront", jsii.invoke(self, "toUpdateDistribution", []))

    @jsii.member(jsii_name="toUpdateFieldLevelEncryptionConfig")
    def to_update_field_level_encryption_config(self) -> "Cloudfront":
        '''(experimental) Grants permission to update a field-level encryption configuration.

        Access Level: Write

        https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_UpdateFieldLevelEncryptionConfig.html

        :stability: experimental
        '''
        return typing.cast("Cloudfront", jsii.invoke(self, "toUpdateFieldLevelEncryptionConfig", []))

    @jsii.member(jsii_name="toUpdateFieldLevelEncryptionProfile")
    def to_update_field_level_encryption_profile(self) -> "Cloudfront":
        '''(experimental) Grants permission to update a field-level encryption profile.

        Access Level: Write

        https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_UpdateFieldLevelEncryptionProfile.html

        :stability: experimental
        '''
        return typing.cast("Cloudfront", jsii.invoke(self, "toUpdateFieldLevelEncryptionProfile", []))

    @jsii.member(jsii_name="toUpdateFunction")
    def to_update_function(self) -> "Cloudfront":
        '''(experimental) Grants permission to update a CloudFront function.

        Access Level: Write

        https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_UpdateFunction.html

        :stability: experimental
        '''
        return typing.cast("Cloudfront", jsii.invoke(self, "toUpdateFunction", []))

    @jsii.member(jsii_name="toUpdateKeyGroup")
    def to_update_key_group(self) -> "Cloudfront":
        '''(experimental) Grants permission to update a key group.

        Access Level: Write

        https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_UpdateKeyGroup.html

        :stability: experimental
        '''
        return typing.cast("Cloudfront", jsii.invoke(self, "toUpdateKeyGroup", []))

    @jsii.member(jsii_name="toUpdateOriginAccessControl")
    def to_update_origin_access_control(self) -> "Cloudfront":
        '''(experimental) Grants permission to update an origin access control.

        Access Level: Write

        https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_UpdateOriginAccessControl.html

        :stability: experimental
        '''
        return typing.cast("Cloudfront", jsii.invoke(self, "toUpdateOriginAccessControl", []))

    @jsii.member(jsii_name="toUpdateOriginRequestPolicy")
    def to_update_origin_request_policy(self) -> "Cloudfront":
        '''(experimental) Grants permission to update an origin request policy.

        Access Level: Write

        https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_UpdateOriginRequestPolicy.html

        :stability: experimental
        '''
        return typing.cast("Cloudfront", jsii.invoke(self, "toUpdateOriginRequestPolicy", []))

    @jsii.member(jsii_name="toUpdatePublicKey")
    def to_update_public_key(self) -> "Cloudfront":
        '''(experimental) Grants permission to update public key information.

        Access Level: Write

        https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_UpdatePublicKey.html

        :stability: experimental
        '''
        return typing.cast("Cloudfront", jsii.invoke(self, "toUpdatePublicKey", []))

    @jsii.member(jsii_name="toUpdateRealtimeLogConfig")
    def to_update_realtime_log_config(self) -> "Cloudfront":
        '''(experimental) Grants permission to update a real-time log configuration.

        Access Level: Write

        https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_UpdateRealtimeLogConfig.html

        :stability: experimental
        '''
        return typing.cast("Cloudfront", jsii.invoke(self, "toUpdateRealtimeLogConfig", []))

    @jsii.member(jsii_name="toUpdateResponseHeadersPolicy")
    def to_update_response_headers_policy(self) -> "Cloudfront":
        '''(experimental) Grants permission to update a response headers policy.

        Access Level: Write

        https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_UpdateResponseHeadersPolicy.html

        :stability: experimental
        '''
        return typing.cast("Cloudfront", jsii.invoke(self, "toUpdateResponseHeadersPolicy", []))

    @jsii.member(jsii_name="toUpdateSavingsPlan")
    def to_update_savings_plan(self) -> "Cloudfront":
        '''(experimental) Grants permission to update a savings plan.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/cf-api-permissions-ref.html

        :stability: experimental
        '''
        return typing.cast("Cloudfront", jsii.invoke(self, "toUpdateSavingsPlan", []))

    @jsii.member(jsii_name="toUpdateStreamingDistribution")
    def to_update_streaming_distribution(self) -> "Cloudfront":
        '''(experimental) Grants permission to update the configuration for an RTMP distribution.

        Access Level: Write

        https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_UpdateStreamingDistribution.html

        :stability: experimental
        '''
        return typing.cast("Cloudfront", jsii.invoke(self, "toUpdateStreamingDistribution", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__731930ef38a36975a620fb8085ffd73a9d338a2b7cecfe734a3af1dc63887f59)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5dc4e361574402161642d2f28933be83e3a02dafd15725b8f8f32450dd052d2f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Cloudhsm(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Cloudhsm",
):
    '''(experimental) Statement provider for service `cloudhsm <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awscloudhsm.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `cloudhsm <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awscloudhsm.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onBackup")
    def on_backup(
        self,
        cloud_hsm_backup_instance_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Cloudhsm":
        '''(experimental) Adds a resource of type backup to the statement.

        https://docs.aws.amazon.com/cloudhsm/latest/userguide/backups.html

        :param cloud_hsm_backup_instance_name: - Identifier for the cloudHsmBackupInstanceName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4710a33e72efa977e90f7392500105dd26f6149560fe7561ed69e916f3e62651)
            check_type(argname="argument cloud_hsm_backup_instance_name", value=cloud_hsm_backup_instance_name, expected_type=type_hints["cloud_hsm_backup_instance_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Cloudhsm", jsii.invoke(self, "onBackup", [cloud_hsm_backup_instance_name, account, region, partition]))

    @jsii.member(jsii_name="onCluster")
    def on_cluster(
        self,
        cloud_hsm_cluster_instance_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Cloudhsm":
        '''(experimental) Adds a resource of type cluster to the statement.

        https://docs.aws.amazon.com/cloudhsm/latest/userguide/clusters.html

        :param cloud_hsm_cluster_instance_name: - Identifier for the cloudHsmClusterInstanceName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__04ce6e0d4af5ef2d48c966d32ac2077f640a7bf2dddc2d624b9d9c070b17f88a)
            check_type(argname="argument cloud_hsm_cluster_instance_name", value=cloud_hsm_cluster_instance_name, expected_type=type_hints["cloud_hsm_cluster_instance_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Cloudhsm", jsii.invoke(self, "onCluster", [cloud_hsm_cluster_instance_name, account, region, partition]))

    @jsii.member(jsii_name="toAddTagsToResource")
    def to_add_tags_to_resource(self) -> "Cloudhsm":
        '''(experimental) Adds or overwrites one or more tags for the specified AWS CloudHSM resource.

        Access Level: Tagging

        https://docs.aws.amazon.com/cloudhsm/classic/APIReference/API_AddTagsToResource.html

        :stability: experimental
        '''
        return typing.cast("Cloudhsm", jsii.invoke(self, "toAddTagsToResource", []))

    @jsii.member(jsii_name="toCopyBackupToRegion")
    def to_copy_backup_to_region(self) -> "Cloudhsm":
        '''(experimental) Creates a copy of a backup in the specified region.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/cloudhsm/latest/APIReference/API_CopyBackupToRegion.html

        :stability: experimental
        '''
        return typing.cast("Cloudhsm", jsii.invoke(self, "toCopyBackupToRegion", []))

    @jsii.member(jsii_name="toCreateCluster")
    def to_create_cluster(self) -> "Cloudhsm":
        '''(experimental) Creates a new AWS CloudHSM cluster.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/cloudhsm/latest/APIReference/API_CreateCluster.html

        :stability: experimental
        '''
        return typing.cast("Cloudhsm", jsii.invoke(self, "toCreateCluster", []))

    @jsii.member(jsii_name="toCreateHapg")
    def to_create_hapg(self) -> "Cloudhsm":
        '''(experimental) Creates a high-availability partition group.

        Access Level: Write

        https://docs.aws.amazon.com/cloudhsm/classic/APIReference/API_CreateHapg.html

        :stability: experimental
        '''
        return typing.cast("Cloudhsm", jsii.invoke(self, "toCreateHapg", []))

    @jsii.member(jsii_name="toCreateHsm")
    def to_create_hsm(self) -> "Cloudhsm":
        '''(experimental) Creates a new hardware security module (HSM) in the specified AWS CloudHSM cluster.

        Access Level: Write

        https://docs.aws.amazon.com/cloudhsm/latest/APIReference/API_CreateHsm.html

        :stability: experimental
        '''
        return typing.cast("Cloudhsm", jsii.invoke(self, "toCreateHsm", []))

    @jsii.member(jsii_name="toCreateLunaClient")
    def to_create_luna_client(self) -> "Cloudhsm":
        '''(experimental) Creates an HSM client.

        Access Level: Write

        https://docs.aws.amazon.com/cloudhsm/classic/APIReference/API_CreateLunaClient.html

        :stability: experimental
        '''
        return typing.cast("Cloudhsm", jsii.invoke(self, "toCreateLunaClient", []))

    @jsii.member(jsii_name="toDeleteBackup")
    def to_delete_backup(self) -> "Cloudhsm":
        '''(experimental) Deletes the specified CloudHSM backup.

        Access Level: Write

        https://docs.aws.amazon.com/cloudhsm/latest/APIReference/API_DeleteBackup.html

        :stability: experimental
        '''
        return typing.cast("Cloudhsm", jsii.invoke(self, "toDeleteBackup", []))

    @jsii.member(jsii_name="toDeleteCluster")
    def to_delete_cluster(self) -> "Cloudhsm":
        '''(experimental) Deletes the specified AWS CloudHSM cluster.

        Access Level: Write

        https://docs.aws.amazon.com/cloudhsm/latest/APIReference/API_DeleteCluster.html

        :stability: experimental
        '''
        return typing.cast("Cloudhsm", jsii.invoke(self, "toDeleteCluster", []))

    @jsii.member(jsii_name="toDeleteHapg")
    def to_delete_hapg(self) -> "Cloudhsm":
        '''(experimental) Deletes a high-availability partition group.

        Access Level: Write

        https://docs.aws.amazon.com/cloudhsm/classic/APIReference/API_DeleteHapg.html

        :stability: experimental
        '''
        return typing.cast("Cloudhsm", jsii.invoke(self, "toDeleteHapg", []))

    @jsii.member(jsii_name="toDeleteHsm")
    def to_delete_hsm(self) -> "Cloudhsm":
        '''(experimental) Deletes the specified HSM.

        Access Level: Write

        https://docs.aws.amazon.com/cloudhsm/latest/APIReference/API_DeleteHsm.html

        :stability: experimental
        '''
        return typing.cast("Cloudhsm", jsii.invoke(self, "toDeleteHsm", []))

    @jsii.member(jsii_name="toDeleteLunaClient")
    def to_delete_luna_client(self) -> "Cloudhsm":
        '''(experimental) Deletes a client.

        Access Level: Write

        https://docs.aws.amazon.com/cloudhsm/classic/APIReference/API_DeleteLunaClient.html

        :stability: experimental
        '''
        return typing.cast("Cloudhsm", jsii.invoke(self, "toDeleteLunaClient", []))

    @jsii.member(jsii_name="toDescribeBackups")
    def to_describe_backups(self) -> "Cloudhsm":
        '''(experimental) Gets information about backups of AWS CloudHSM clusters.

        Access Level: Read

        https://docs.aws.amazon.com/cloudhsm/latest/APIReference/API_DescribeBackups.html

        :stability: experimental
        '''
        return typing.cast("Cloudhsm", jsii.invoke(self, "toDescribeBackups", []))

    @jsii.member(jsii_name="toDescribeClusters")
    def to_describe_clusters(self) -> "Cloudhsm":
        '''(experimental) Gets information about AWS CloudHSM clusters.

        Access Level: Read

        https://docs.aws.amazon.com/cloudhsm/latest/APIReference/API_DescribeClusters.html

        :stability: experimental
        '''
        return typing.cast("Cloudhsm", jsii.invoke(self, "toDescribeClusters", []))

    @jsii.member(jsii_name="toDescribeHapg")
    def to_describe_hapg(self) -> "Cloudhsm":
        '''(experimental) Retrieves information about a high-availability partition group.

        Access Level: Read

        https://docs.aws.amazon.com/cloudhsm/classic/APIReference/API_DescribeHapg.html

        :stability: experimental
        '''
        return typing.cast("Cloudhsm", jsii.invoke(self, "toDescribeHapg", []))

    @jsii.member(jsii_name="toDescribeHsm")
    def to_describe_hsm(self) -> "Cloudhsm":
        '''(experimental) Retrieves information about an HSM. You can identify the HSM by its ARN or its serial number.

        Access Level: Read

        https://docs.aws.amazon.com/cloudhsm/classic/APIReference/API_DescribeHsm.html

        :stability: experimental
        '''
        return typing.cast("Cloudhsm", jsii.invoke(self, "toDescribeHsm", []))

    @jsii.member(jsii_name="toDescribeLunaClient")
    def to_describe_luna_client(self) -> "Cloudhsm":
        '''(experimental) Retrieves information about an HSM client.

        Access Level: Read

        https://docs.aws.amazon.com/cloudhsm/classic/APIReference/API_DescribeLunaClient.html

        :stability: experimental
        '''
        return typing.cast("Cloudhsm", jsii.invoke(self, "toDescribeLunaClient", []))

    @jsii.member(jsii_name="toGetConfig")
    def to_get_config(self) -> "Cloudhsm":
        '''(experimental) Gets the configuration files necessary to connect to all high availability partition groups the client is associated with.

        Access Level: Read

        https://docs.aws.amazon.com/cloudhsm/classic/APIReference/API_GetConfig.html

        :stability: experimental
        '''
        return typing.cast("Cloudhsm", jsii.invoke(self, "toGetConfig", []))

    @jsii.member(jsii_name="toInitializeCluster")
    def to_initialize_cluster(self) -> "Cloudhsm":
        '''(experimental) Claims an AWS CloudHSM cluster.

        Access Level: Write

        https://docs.aws.amazon.com/cloudhsm/latest/APIReference/API_InitializeCluster.html

        :stability: experimental
        '''
        return typing.cast("Cloudhsm", jsii.invoke(self, "toInitializeCluster", []))

    @jsii.member(jsii_name="toListAvailableZones")
    def to_list_available_zones(self) -> "Cloudhsm":
        '''(experimental) Lists the Availability Zones that have available AWS CloudHSM capacity.

        Access Level: List

        https://docs.aws.amazon.com/cloudhsm/classic/APIReference/API_ListAvailableZones.html

        :stability: experimental
        '''
        return typing.cast("Cloudhsm", jsii.invoke(self, "toListAvailableZones", []))

    @jsii.member(jsii_name="toListHapgs")
    def to_list_hapgs(self) -> "Cloudhsm":
        '''(experimental) Lists the high-availability partition groups for the account.

        Access Level: List

        https://docs.aws.amazon.com/cloudhsm/classic/APIReference/API_ListHapgs.html

        :stability: experimental
        '''
        return typing.cast("Cloudhsm", jsii.invoke(self, "toListHapgs", []))

    @jsii.member(jsii_name="toListHsms")
    def to_list_hsms(self) -> "Cloudhsm":
        '''(experimental) Retrieves the identifiers of all of the HSMs provisioned for the current customer.

        Access Level: List

        https://docs.aws.amazon.com/cloudhsm/classic/APIReference/API_ListHsms.html

        :stability: experimental
        '''
        return typing.cast("Cloudhsm", jsii.invoke(self, "toListHsms", []))

    @jsii.member(jsii_name="toListLunaClients")
    def to_list_luna_clients(self) -> "Cloudhsm":
        '''(experimental) Lists all of the clients.

        Access Level: List

        https://docs.aws.amazon.com/cloudhsm/classic/APIReference/API_ListLunaClients.html

        :stability: experimental
        '''
        return typing.cast("Cloudhsm", jsii.invoke(self, "toListLunaClients", []))

    @jsii.member(jsii_name="toListTags")
    def to_list_tags(self) -> "Cloudhsm":
        '''(experimental) Gets a list of tags for the specified AWS CloudHSM cluster.

        Access Level: Read

        https://docs.aws.amazon.com/cloudhsm/latest/APIReference/API_ListTags.html

        :stability: experimental
        '''
        return typing.cast("Cloudhsm", jsii.invoke(self, "toListTags", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Cloudhsm":
        '''(experimental) Returns a list of all tags for the specified AWS CloudHSM resource.

        Access Level: Read

        https://docs.aws.amazon.com/cloudhsm/classic/APIReference/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("Cloudhsm", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toModifyBackupAttributes")
    def to_modify_backup_attributes(self) -> "Cloudhsm":
        '''(experimental) Modifies attributes for AWS CloudHSM backup.

        Access Level: Write

        https://docs.aws.amazon.com/cloudhsm/latest/APIReference/API_ModifyBackupAttributes.html

        :stability: experimental
        '''
        return typing.cast("Cloudhsm", jsii.invoke(self, "toModifyBackupAttributes", []))

    @jsii.member(jsii_name="toModifyCluster")
    def to_modify_cluster(self) -> "Cloudhsm":
        '''(experimental) Modifies AWS CloudHSM cluster.

        Access Level: Write

        https://docs.aws.amazon.com/cloudhsm/latest/APIReference/API_ModifyCluster.html

        :stability: experimental
        '''
        return typing.cast("Cloudhsm", jsii.invoke(self, "toModifyCluster", []))

    @jsii.member(jsii_name="toModifyHapg")
    def to_modify_hapg(self) -> "Cloudhsm":
        '''(experimental) Modifies an existing high-availability partition group.

        Access Level: Write

        https://docs.aws.amazon.com/cloudhsm/classic/APIReference/API_ModifyHapg.html

        :stability: experimental
        '''
        return typing.cast("Cloudhsm", jsii.invoke(self, "toModifyHapg", []))

    @jsii.member(jsii_name="toModifyHsm")
    def to_modify_hsm(self) -> "Cloudhsm":
        '''(experimental) Modifies an HSM.

        Access Level: Write

        https://docs.aws.amazon.com/cloudhsm/classic/APIReference/API_ModifyHsm.html

        :stability: experimental
        '''
        return typing.cast("Cloudhsm", jsii.invoke(self, "toModifyHsm", []))

    @jsii.member(jsii_name="toModifyLunaClient")
    def to_modify_luna_client(self) -> "Cloudhsm":
        '''(experimental) Modifies the certificate used by the client.

        Access Level: Write

        https://docs.aws.amazon.com/cloudhsm/classic/APIReference/API_ModifyLunaClient.html

        :stability: experimental
        '''
        return typing.cast("Cloudhsm", jsii.invoke(self, "toModifyLunaClient", []))

    @jsii.member(jsii_name="toRemoveTagsFromResource")
    def to_remove_tags_from_resource(self) -> "Cloudhsm":
        '''(experimental) Removes one or more tags from the specified AWS CloudHSM resource.

        Access Level: Tagging

        https://docs.aws.amazon.com/cloudhsm/classic/APIReference/API_RemoveTagsFromResource.html

        :stability: experimental
        '''
        return typing.cast("Cloudhsm", jsii.invoke(self, "toRemoveTagsFromResource", []))

    @jsii.member(jsii_name="toRestoreBackup")
    def to_restore_backup(self) -> "Cloudhsm":
        '''(experimental) Restores the specified CloudHSM backup.

        Access Level: Write

        https://docs.aws.amazon.com/cloudhsm/latest/APIReference/API_RestoreBackup.html

        :stability: experimental
        '''
        return typing.cast("Cloudhsm", jsii.invoke(self, "toRestoreBackup", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Cloudhsm":
        '''(experimental) Adds or overwrites one or more tags for the specified AWS CloudHSM cluster.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/cloudhsm/latest/APIReference/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("Cloudhsm", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Cloudhsm":
        '''(experimental) Removes the specified tag or tags from the specified AWS CloudHSM cluster.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/cloudhsm/latest/APIReference/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("Cloudhsm", jsii.invoke(self, "toUntagResource", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7fe5e4eb9e2d5e19f471f14ca8c146832489bc42364b79c156cd9cdac766ecb2)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__de31d821daf26a2cbc266d554c736e094e0b2804aaff042fdd4c578102bbd802)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Cloudsearch(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Cloudsearch",
):
    '''(experimental) Statement provider for service `cloudsearch <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazoncloudsearch.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `cloudsearch <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazoncloudsearch.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onDomain")
    def on_domain(
        self,
        domain_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Cloudsearch":
        '''(experimental) Adds a resource of type domain to the statement.

        https://docs.aws.amazon.com/cloudsearch/latest/developerguide/creating-domains.html

        :param domain_name: - Identifier for the domainName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a08ee03376ead681a8e5564cef1b2a6cc85c29e88ec72e5103983247e763c847)
            check_type(argname="argument domain_name", value=domain_name, expected_type=type_hints["domain_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Cloudsearch", jsii.invoke(self, "onDomain", [domain_name, account, region, partition]))

    @jsii.member(jsii_name="toAddTags")
    def to_add_tags(self) -> "Cloudsearch":
        '''(experimental) Attaches resource tags to an Amazon CloudSearch domain.

        Access Level: Tagging

        https://docs.aws.amazon.com/cloudsearch/latest/developerguide/API_AddTags.html

        :stability: experimental
        '''
        return typing.cast("Cloudsearch", jsii.invoke(self, "toAddTags", []))

    @jsii.member(jsii_name="toBuildSuggesters")
    def to_build_suggesters(self) -> "Cloudsearch":
        '''(experimental) Indexes the search suggestions.

        Access Level: Write

        https://docs.aws.amazon.com/cloudsearch/latest/developerguide/API_BuildSuggesters.html

        :stability: experimental
        '''
        return typing.cast("Cloudsearch", jsii.invoke(self, "toBuildSuggesters", []))

    @jsii.member(jsii_name="toCreateDomain")
    def to_create_domain(self) -> "Cloudsearch":
        '''(experimental) Creates a new search domain.

        Access Level: Write

        https://docs.aws.amazon.com/cloudsearch/latest/developerguide/API_CreateDomain.html

        :stability: experimental
        '''
        return typing.cast("Cloudsearch", jsii.invoke(self, "toCreateDomain", []))

    @jsii.member(jsii_name="toDefineAnalysisScheme")
    def to_define_analysis_scheme(self) -> "Cloudsearch":
        '''(experimental) Configures an analysis scheme that can be applied to a text or text-array field to define language-specific text processing options.

        Access Level: Write

        https://docs.aws.amazon.com/cloudsearch/latest/developerguide/API_DefineAnalysisScheme.html

        :stability: experimental
        '''
        return typing.cast("Cloudsearch", jsii.invoke(self, "toDefineAnalysisScheme", []))

    @jsii.member(jsii_name="toDefineExpression")
    def to_define_expression(self) -> "Cloudsearch":
        '''(experimental) Configures an Expression for the search domain.

        Access Level: Write

        https://docs.aws.amazon.com/cloudsearch/latest/developerguide/API_DefineExpression.html

        :stability: experimental
        '''
        return typing.cast("Cloudsearch", jsii.invoke(self, "toDefineExpression", []))

    @jsii.member(jsii_name="toDefineIndexField")
    def to_define_index_field(self) -> "Cloudsearch":
        '''(experimental) Configures an IndexField for the search domain.

        Access Level: Write

        https://docs.aws.amazon.com/cloudsearch/latest/developerguide/API_DefineIndexField.html

        :stability: experimental
        '''
        return typing.cast("Cloudsearch", jsii.invoke(self, "toDefineIndexField", []))

    @jsii.member(jsii_name="toDefineSuggester")
    def to_define_suggester(self) -> "Cloudsearch":
        '''(experimental) Configures a suggester for a domain.

        Access Level: Write

        https://docs.aws.amazon.com/cloudsearch/latest/developerguide/API_DefineSuggester.html

        :stability: experimental
        '''
        return typing.cast("Cloudsearch", jsii.invoke(self, "toDefineSuggester", []))

    @jsii.member(jsii_name="toDeleteAnalysisScheme")
    def to_delete_analysis_scheme(self) -> "Cloudsearch":
        '''(experimental) Deletes an analysis scheme.

        Access Level: Write

        https://docs.aws.amazon.com/cloudsearch/latest/developerguide/API_DeleteAnalysisScheme.html

        :stability: experimental
        '''
        return typing.cast("Cloudsearch", jsii.invoke(self, "toDeleteAnalysisScheme", []))

    @jsii.member(jsii_name="toDeleteDomain")
    def to_delete_domain(self) -> "Cloudsearch":
        '''(experimental) Permanently deletes a search domain and all of its data.

        Access Level: Write

        https://docs.aws.amazon.com/cloudsearch/latest/developerguide/API_DeleteDomain.html

        :stability: experimental
        '''
        return typing.cast("Cloudsearch", jsii.invoke(self, "toDeleteDomain", []))

    @jsii.member(jsii_name="toDeleteExpression")
    def to_delete_expression(self) -> "Cloudsearch":
        '''(experimental) Removes an Expression from the search domain.

        Access Level: Write

        https://docs.aws.amazon.com/cloudsearch/latest/developerguide/API_DeleteExpression.html

        :stability: experimental
        '''
        return typing.cast("Cloudsearch", jsii.invoke(self, "toDeleteExpression", []))

    @jsii.member(jsii_name="toDeleteIndexField")
    def to_delete_index_field(self) -> "Cloudsearch":
        '''(experimental) Removes an IndexField from the search domain.

        Access Level: Write

        https://docs.aws.amazon.com/cloudsearch/latest/developerguide/API_DeleteIndexField.html

        :stability: experimental
        '''
        return typing.cast("Cloudsearch", jsii.invoke(self, "toDeleteIndexField", []))

    @jsii.member(jsii_name="toDeleteSuggester")
    def to_delete_suggester(self) -> "Cloudsearch":
        '''(experimental) Deletes a suggester.

        Access Level: Write

        https://docs.aws.amazon.com/cloudsearch/latest/developerguide/API_DeleteSuggester.html

        :stability: experimental
        '''
        return typing.cast("Cloudsearch", jsii.invoke(self, "toDeleteSuggester", []))

    @jsii.member(jsii_name="toDescribeAnalysisSchemes")
    def to_describe_analysis_schemes(self) -> "Cloudsearch":
        '''(experimental) Gets the analysis schemes configured for a domain.

        Access Level: Read

        https://docs.aws.amazon.com/cloudsearch/latest/developerguide/API_DescribeAnalysisSchemes.html

        :stability: experimental
        '''
        return typing.cast("Cloudsearch", jsii.invoke(self, "toDescribeAnalysisSchemes", []))

    @jsii.member(jsii_name="toDescribeAvailabilityOptions")
    def to_describe_availability_options(self) -> "Cloudsearch":
        '''(experimental) Gets the availability options configured for a domain.

        Access Level: Read

        https://docs.aws.amazon.com/cloudsearch/latest/developerguide/API_DescribeAvailabilityOptions.html

        :stability: experimental
        '''
        return typing.cast("Cloudsearch", jsii.invoke(self, "toDescribeAvailabilityOptions", []))

    @jsii.member(jsii_name="toDescribeDomainEndpointOptions")
    def to_describe_domain_endpoint_options(self) -> "Cloudsearch":
        '''(experimental) Gets the domain endpoint options configured for a domain.

        Access Level: Read

        https://docs.aws.amazon.com/cloudsearch/latest/developerguide/API_DescribeDomainEndpointOptions.html

        :stability: experimental
        '''
        return typing.cast("Cloudsearch", jsii.invoke(self, "toDescribeDomainEndpointOptions", []))

    @jsii.member(jsii_name="toDescribeDomains")
    def to_describe_domains(self) -> "Cloudsearch":
        '''(experimental) Gets information about the search domains owned by this account.

        Access Level: List

        https://docs.aws.amazon.com/cloudsearch/latest/developerguide/API_DescribeDomains.html

        :stability: experimental
        '''
        return typing.cast("Cloudsearch", jsii.invoke(self, "toDescribeDomains", []))

    @jsii.member(jsii_name="toDescribeExpressions")
    def to_describe_expressions(self) -> "Cloudsearch":
        '''(experimental) Gets the expressions configured for the search domain.

        Access Level: Read

        https://docs.aws.amazon.com/cloudsearch/latest/developerguide/API_DescribeExpressions.html

        :stability: experimental
        '''
        return typing.cast("Cloudsearch", jsii.invoke(self, "toDescribeExpressions", []))

    @jsii.member(jsii_name="toDescribeIndexFields")
    def to_describe_index_fields(self) -> "Cloudsearch":
        '''(experimental) Gets information about the index fields configured for the search domain.

        Access Level: Read

        https://docs.aws.amazon.com/cloudsearch/latest/developerguide/API_DescribeIndexFields.html

        :stability: experimental
        '''
        return typing.cast("Cloudsearch", jsii.invoke(self, "toDescribeIndexFields", []))

    @jsii.member(jsii_name="toDescribeScalingParameters")
    def to_describe_scaling_parameters(self) -> "Cloudsearch":
        '''(experimental) Gets the scaling parameters configured for a domain.

        Access Level: Read

        https://docs.aws.amazon.com/cloudsearch/latest/developerguide/API_DescribeScalingParameters.html

        :stability: experimental
        '''
        return typing.cast("Cloudsearch", jsii.invoke(self, "toDescribeScalingParameters", []))

    @jsii.member(jsii_name="toDescribeServiceAccessPolicies")
    def to_describe_service_access_policies(self) -> "Cloudsearch":
        '''(experimental) Gets information about the access policies that control access to the domain's document and search endpoints.

        Access Level: Read

        https://docs.aws.amazon.com/cloudsearch/latest/developerguide/API_DescribeServiceAccessPolicies.html

        :stability: experimental
        '''
        return typing.cast("Cloudsearch", jsii.invoke(self, "toDescribeServiceAccessPolicies", []))

    @jsii.member(jsii_name="toDescribeSuggesters")
    def to_describe_suggesters(self) -> "Cloudsearch":
        '''(experimental) Gets the suggesters configured for a domain.

        Access Level: Read

        https://docs.aws.amazon.com/cloudsearch/latest/developerguide/API_DescribeSuggesters.html

        :stability: experimental
        '''
        return typing.cast("Cloudsearch", jsii.invoke(self, "toDescribeSuggesters", []))

    @jsii.member(jsii_name="toDocument")
    def to_document(self) -> "Cloudsearch":
        '''(experimental) Allows access to the document service operations.

        Access Level: Write

        https://docs.aws.amazon.com/cloudsearch/latest/developerguide/configuring-access.html#cloudsearch-actions

        :stability: experimental
        '''
        return typing.cast("Cloudsearch", jsii.invoke(self, "toDocument", []))

    @jsii.member(jsii_name="toIndexDocuments")
    def to_index_documents(self) -> "Cloudsearch":
        '''(experimental) Tells the search domain to start indexing its documents using the latest indexing options.

        Access Level: Write

        https://docs.aws.amazon.com/cloudsearch/latest/developerguide/API_IndexDocuments.html

        :stability: experimental
        '''
        return typing.cast("Cloudsearch", jsii.invoke(self, "toIndexDocuments", []))

    @jsii.member(jsii_name="toListDomainNames")
    def to_list_domain_names(self) -> "Cloudsearch":
        '''(experimental) Lists all search domains owned by an account.

        Access Level: List

        https://docs.aws.amazon.com/cloudsearch/latest/developerguide/API_ListDomainNames.html

        :stability: experimental
        '''
        return typing.cast("Cloudsearch", jsii.invoke(self, "toListDomainNames", []))

    @jsii.member(jsii_name="toListTags")
    def to_list_tags(self) -> "Cloudsearch":
        '''(experimental) Displays all of the resource tags for an Amazon CloudSearch domain.

        Access Level: Read

        https://docs.aws.amazon.com/cloudsearch/latest/developerguide/API_ListTags.html

        :stability: experimental
        '''
        return typing.cast("Cloudsearch", jsii.invoke(self, "toListTags", []))

    @jsii.member(jsii_name="toRemoveTags")
    def to_remove_tags(self) -> "Cloudsearch":
        '''(experimental) Removes the specified resource tags from an Amazon ES domain.

        Access Level: Tagging

        https://docs.aws.amazon.com/cloudsearch/latest/developerguide/API_RemoveTags.html

        :stability: experimental
        '''
        return typing.cast("Cloudsearch", jsii.invoke(self, "toRemoveTags", []))

    @jsii.member(jsii_name="toSearch")
    def to_search(self) -> "Cloudsearch":
        '''(experimental) Allows access to the search operations.

        Access Level: Read

        https://docs.aws.amazon.com/cloudsearch/latest/developerguide/configuring-access.html#cloudsearch-actions

        :stability: experimental
        '''
        return typing.cast("Cloudsearch", jsii.invoke(self, "toSearch", []))

    @jsii.member(jsii_name="toSuggest")
    def to_suggest(self) -> "Cloudsearch":
        '''(experimental) Allows access to the suggest operations.

        Access Level: Read

        https://docs.aws.amazon.com/cloudsearch/latest/developerguide/configuring-access.html#cloudsearch-actions

        :stability: experimental
        '''
        return typing.cast("Cloudsearch", jsii.invoke(self, "toSuggest", []))

    @jsii.member(jsii_name="toUpdateAvailabilityOptions")
    def to_update_availability_options(self) -> "Cloudsearch":
        '''(experimental) Configures the availability options for a domain.

        Access Level: Write

        https://docs.aws.amazon.com/cloudsearch/latest/developerguide/API_UpdateAvailabilityOptions.html

        :stability: experimental
        '''
        return typing.cast("Cloudsearch", jsii.invoke(self, "toUpdateAvailabilityOptions", []))

    @jsii.member(jsii_name="toUpdateDomainEndpointOptions")
    def to_update_domain_endpoint_options(self) -> "Cloudsearch":
        '''(experimental) Configures the domain endpoint options for a domain.

        Access Level: Write

        https://docs.aws.amazon.com/cloudsearch/latest/developerguide/API_UpdateDomainEndpointOptions.html

        :stability: experimental
        '''
        return typing.cast("Cloudsearch", jsii.invoke(self, "toUpdateDomainEndpointOptions", []))

    @jsii.member(jsii_name="toUpdateScalingParameters")
    def to_update_scaling_parameters(self) -> "Cloudsearch":
        '''(experimental) Configures scaling parameters for a domain.

        Access Level: Write

        https://docs.aws.amazon.com/cloudsearch/latest/developerguide/API_UpdateScalingParameters.html

        :stability: experimental
        '''
        return typing.cast("Cloudsearch", jsii.invoke(self, "toUpdateScalingParameters", []))

    @jsii.member(jsii_name="toUpdateServiceAccessPolicies")
    def to_update_service_access_policies(self) -> "Cloudsearch":
        '''(experimental) Configures the access rules that control access to the domain's document and search endpoints.

        Access Level: Permissions management

        https://docs.aws.amazon.com/cloudsearch/latest/developerguide/API_UpdateServiceAccessPolicies.html

        :stability: experimental
        '''
        return typing.cast("Cloudsearch", jsii.invoke(self, "toUpdateServiceAccessPolicies", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3535349fff32c7d2ccc51a1c8011a249d21f2929654e4634937a617ab34603dc)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c86f070ea80315c5c7c9b0a152ff10cfe0437847940c6ad59f9ea2b32e2fbd36)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Cloudshell(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Cloudshell",
):
    '''(experimental) Statement provider for service `cloudshell <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awscloudshell.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `cloudshell <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awscloudshell.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onEnvironment")
    def on_environment(
        self,
        environment_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Cloudshell":
        '''(experimental) Adds a resource of type Environment to the statement.

        https://docs.aws.amazon.com/cloudshell/latest/userguide/sec-auth-with-identities.html#Environment

        :param environment_id: - Identifier for the environmentId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e6459b0625046edec80b7688321760b488271365c2f7218f560626a09124dcd0)
            check_type(argname="argument environment_id", value=environment_id, expected_type=type_hints["environment_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Cloudshell", jsii.invoke(self, "onEnvironment", [environment_id, account, region, partition]))

    @jsii.member(jsii_name="toCreateEnvironment")
    def to_create_environment(self) -> "Cloudshell":
        '''(experimental) Grants permissions to create a CloudShell environment.

        Access Level: Write

        https://docs.aws.amazon.com/cloudshell/latest/userguide/sec-auth-with-identities.html#CreateEnvironment

        :stability: experimental
        '''
        return typing.cast("Cloudshell", jsii.invoke(self, "toCreateEnvironment", []))

    @jsii.member(jsii_name="toCreateSession")
    def to_create_session(self) -> "Cloudshell":
        '''(experimental) Grants permissions to connect to a CloudShell environment from the AWS Management Console.

        Access Level: Write

        https://docs.aws.amazon.com/cloudshell/latest/userguide/sec-auth-with-identities.html#CreateSession

        :stability: experimental
        '''
        return typing.cast("Cloudshell", jsii.invoke(self, "toCreateSession", []))

    @jsii.member(jsii_name="toDeleteEnvironment")
    def to_delete_environment(self) -> "Cloudshell":
        '''(experimental) Grants permission to delete a CloudShell environment.

        Access Level: Write

        https://docs.aws.amazon.com/cloudshell/latest/userguide/sec-auth-with-identities.html#DeleteEnvironment

        :stability: experimental
        '''
        return typing.cast("Cloudshell", jsii.invoke(self, "toDeleteEnvironment", []))

    @jsii.member(jsii_name="toGetEnvironmentStatus")
    def to_get_environment_status(self) -> "Cloudshell":
        '''(experimental) Grants permission to read a CloudShell environment status.

        Access Level: Read

        https://docs.aws.amazon.com/cloudshell/latest/userguide/sec-auth-with-identities.html#GetEnvironmentStatus

        :stability: experimental
        '''
        return typing.cast("Cloudshell", jsii.invoke(self, "toGetEnvironmentStatus", []))

    @jsii.member(jsii_name="toGetFileDownloadUrls")
    def to_get_file_download_urls(self) -> "Cloudshell":
        '''(experimental) Grants permissions to download files from a CloudShell environment.

        Access Level: Write

        https://docs.aws.amazon.com/cloudshell/latest/userguide/sec-auth-with-identities.html#GetFileDownloadUrls

        :stability: experimental
        '''
        return typing.cast("Cloudshell", jsii.invoke(self, "toGetFileDownloadUrls", []))

    @jsii.member(jsii_name="toGetFileUploadUrls")
    def to_get_file_upload_urls(self) -> "Cloudshell":
        '''(experimental) Grants permissions to upload files to a CloudShell environment.

        Access Level: Write

        https://docs.aws.amazon.com/cloudshell/latest/userguide/sec-auth-with-identities.html#GetFileUploadUrls

        :stability: experimental
        '''
        return typing.cast("Cloudshell", jsii.invoke(self, "toGetFileUploadUrls", []))

    @jsii.member(jsii_name="toPutCredentials")
    def to_put_credentials(self) -> "Cloudshell":
        '''(experimental) Grants permissions to forward console credentials to the environment.

        Access Level: Write

        https://docs.aws.amazon.com/cloudshell/latest/userguide/sec-auth-with-identities.html#PutCredentials

        :stability: experimental
        '''
        return typing.cast("Cloudshell", jsii.invoke(self, "toPutCredentials", []))

    @jsii.member(jsii_name="toStartEnvironment")
    def to_start_environment(self) -> "Cloudshell":
        '''(experimental) Grants permission to start a stopped CloudShell environment.

        Access Level: Write

        https://docs.aws.amazon.com/cloudshell/latest/userguide/sec-auth-with-identities.html#StartEnvironment

        :stability: experimental
        '''
        return typing.cast("Cloudshell", jsii.invoke(self, "toStartEnvironment", []))

    @jsii.member(jsii_name="toStopEnvironment")
    def to_stop_environment(self) -> "Cloudshell":
        '''(experimental) Grants permission to stop a running CloudShell environment.

        Access Level: Write

        https://docs.aws.amazon.com/cloudshell/latest/userguide/sec-auth-with-identities.html#StopEnvironment

        :stability: experimental
        '''
        return typing.cast("Cloudshell", jsii.invoke(self, "toStopEnvironment", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e23741be7725ea55641b9e239c2c12964a770094c54ae3f1042365d8639eb804)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__50e27ff25a2c89279b7741b589ad6d9fe82d9cdff8935d6289784be66c4f170b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Cloudtrail(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Cloudtrail",
):
    '''(experimental) Statement provider for service `cloudtrail <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awscloudtrail.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `cloudtrail <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awscloudtrail.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onChannel")
    def on_channel(
        self,
        channel_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Cloudtrail":
        '''(experimental) Adds a resource of type channel to the statement.

        https://docs.aws.amazon.com/awscloudtrail/latest/userguide/how-cloudtrail-works.html

        :param channel_id: - Identifier for the channelId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__09d3d77d602b58278b71b2d53bfe951587bad14ec2955f824e577778c8cb2e39)
            check_type(argname="argument channel_id", value=channel_id, expected_type=type_hints["channel_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Cloudtrail", jsii.invoke(self, "onChannel", [channel_id, account, region, partition]))

    @jsii.member(jsii_name="onEventdatastore")
    def on_eventdatastore(
        self,
        event_data_store_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Cloudtrail":
        '''(experimental) Adds a resource of type eventdatastore to the statement.

        https://docs.aws.amazon.com/awscloudtrail/latest/userguide/how-cloudtrail-works.html

        :param event_data_store_id: - Identifier for the eventDataStoreId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3712bc7aee5c31905f5e6b613db87514d57f51e66a1fa5995173b54f9a9da468)
            check_type(argname="argument event_data_store_id", value=event_data_store_id, expected_type=type_hints["event_data_store_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Cloudtrail", jsii.invoke(self, "onEventdatastore", [event_data_store_id, account, region, partition]))

    @jsii.member(jsii_name="onTrail")
    def on_trail(
        self,
        trail_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Cloudtrail":
        '''(experimental) Adds a resource of type trail to the statement.

        https://docs.aws.amazon.com/awscloudtrail/latest/userguide/how-cloudtrail-works.html

        :param trail_name: - Identifier for the trailName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__423ba88f7d2b99d0765bca678ce4f81ada75fd01d2b3efc31379856803641b7e)
            check_type(argname="argument trail_name", value=trail_name, expected_type=type_hints["trail_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Cloudtrail", jsii.invoke(self, "onTrail", [trail_name, account, region, partition]))

    @jsii.member(jsii_name="toAddTags")
    def to_add_tags(self) -> "Cloudtrail":
        '''(experimental) Grants permission to add one or more tags to a trail, up to a limit of 10.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/awscloudtrail/latest/APIReference/API_AddTags.html

        :stability: experimental
        '''
        return typing.cast("Cloudtrail", jsii.invoke(self, "toAddTags", []))

    @jsii.member(jsii_name="toCancelQuery")
    def to_cancel_query(self) -> "Cloudtrail":
        '''(experimental) Grants permission to cancel a running query.

        Access Level: Write

        https://docs.aws.amazon.com/awscloudtrail/latest/APIReference/API_CancelQuery.html

        :stability: experimental
        '''
        return typing.cast("Cloudtrail", jsii.invoke(self, "toCancelQuery", []))

    @jsii.member(jsii_name="toCreateEventDataStore")
    def to_create_event_data_store(self) -> "Cloudtrail":
        '''(experimental) Grants permission to create an event data store.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/awscloudtrail/latest/APIReference/API_CreateEventDataStore.html

        :stability: experimental
        '''
        return typing.cast("Cloudtrail", jsii.invoke(self, "toCreateEventDataStore", []))

    @jsii.member(jsii_name="toCreateServiceLinkedChannel")
    def to_create_service_linked_channel(self) -> "Cloudtrail":
        '''(experimental) Grants permission to create a service-linked channel that specifies the settings for delivery of log data to an AWS service.

        Access Level: Write

        :stability: experimental
        '''
        return typing.cast("Cloudtrail", jsii.invoke(self, "toCreateServiceLinkedChannel", []))

    @jsii.member(jsii_name="toCreateTrail")
    def to_create_trail(self) -> "Cloudtrail":
        '''(experimental) Grants permission to create a trail that specifies the settings for delivery of log data to an Amazon S3 bucket.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - s3:PutObject

        https://docs.aws.amazon.com/awscloudtrail/latest/APIReference/API_CreateTrail.html

        :stability: experimental
        '''
        return typing.cast("Cloudtrail", jsii.invoke(self, "toCreateTrail", []))

    @jsii.member(jsii_name="toDeleteEventDataStore")
    def to_delete_event_data_store(self) -> "Cloudtrail":
        '''(experimental) Grants permission to delete an event data store.

        Access Level: Write

        https://docs.aws.amazon.com/awscloudtrail/latest/APIReference/API_DeleteEventDataStore.html

        :stability: experimental
        '''
        return typing.cast("Cloudtrail", jsii.invoke(self, "toDeleteEventDataStore", []))

    @jsii.member(jsii_name="toDeleteServiceLinkedChannel")
    def to_delete_service_linked_channel(self) -> "Cloudtrail":
        '''(experimental) Grants permission to delete a service-linked channel.

        Access Level: Write

        :stability: experimental
        '''
        return typing.cast("Cloudtrail", jsii.invoke(self, "toDeleteServiceLinkedChannel", []))

    @jsii.member(jsii_name="toDeleteTrail")
    def to_delete_trail(self) -> "Cloudtrail":
        '''(experimental) Grants permission to delete a trail.

        Access Level: Write

        https://docs.aws.amazon.com/awscloudtrail/latest/APIReference/API_DeleteTrail.html

        :stability: experimental
        '''
        return typing.cast("Cloudtrail", jsii.invoke(self, "toDeleteTrail", []))

    @jsii.member(jsii_name="toDeregisterOrganizationDelegatedAdmin")
    def to_deregister_organization_delegated_admin(self) -> "Cloudtrail":
        '''(experimental) Grants permission to deregister an AWS Organizations member account as a delegated administrator.

        Access Level: Write

        https://docs.aws.amazon.com/awscloudtrail/latest/APIReference/API_DeregisterOrganizationDelegatedAdmin.html

        :stability: experimental
        '''
        return typing.cast("Cloudtrail", jsii.invoke(self, "toDeregisterOrganizationDelegatedAdmin", []))

    @jsii.member(jsii_name="toDescribeQuery")
    def to_describe_query(self) -> "Cloudtrail":
        '''(experimental) Grants permission to list details for the query.

        Access Level: Read

        https://docs.aws.amazon.com/awscloudtrail/latest/APIReference/API_DescribeQuery.html

        :stability: experimental
        '''
        return typing.cast("Cloudtrail", jsii.invoke(self, "toDescribeQuery", []))

    @jsii.member(jsii_name="toDescribeTrails")
    def to_describe_trails(self) -> "Cloudtrail":
        '''(experimental) Grants permission to list settings for the trails associated with the current region for your account.

        Access Level: Read

        https://docs.aws.amazon.com/awscloudtrail/latest/APIReference/API_DescribeTrails.html

        :stability: experimental
        '''
        return typing.cast("Cloudtrail", jsii.invoke(self, "toDescribeTrails", []))

    @jsii.member(jsii_name="toGetEventDataStore")
    def to_get_event_data_store(self) -> "Cloudtrail":
        '''(experimental) Grants permission to list settings for the event data store.

        Access Level: Read

        https://docs.aws.amazon.com/awscloudtrail/latest/APIReference/API_GetEventDataStore.html

        :stability: experimental
        '''
        return typing.cast("Cloudtrail", jsii.invoke(self, "toGetEventDataStore", []))

    @jsii.member(jsii_name="toGetEventSelectors")
    def to_get_event_selectors(self) -> "Cloudtrail":
        '''(experimental) Grants permission to list settings for event selectors configured for a trail.

        Access Level: Read

        https://docs.aws.amazon.com/awscloudtrail/latest/APIReference/API_GetEventSelectors.html

        :stability: experimental
        '''
        return typing.cast("Cloudtrail", jsii.invoke(self, "toGetEventSelectors", []))

    @jsii.member(jsii_name="toGetInsightSelectors")
    def to_get_insight_selectors(self) -> "Cloudtrail":
        '''(experimental) Grants permission to list CloudTrail Insights selectors that are configured for a trail.

        Access Level: Read

        https://docs.aws.amazon.com/awscloudtrail/latest/APIReference/API_GetInsightSelectors.html

        :stability: experimental
        '''
        return typing.cast("Cloudtrail", jsii.invoke(self, "toGetInsightSelectors", []))

    @jsii.member(jsii_name="toGetQueryResults")
    def to_get_query_results(self) -> "Cloudtrail":
        '''(experimental) Grants permission to fetch results of a complete query.

        Access Level: Read

        https://docs.aws.amazon.com/awscloudtrail/latest/APIReference/API_GetQueryResults.html

        :stability: experimental
        '''
        return typing.cast("Cloudtrail", jsii.invoke(self, "toGetQueryResults", []))

    @jsii.member(jsii_name="toGetServiceLinkedChannel")
    def to_get_service_linked_channel(self) -> "Cloudtrail":
        '''(experimental) Grants permission to list settings for the service-linked channel.

        Access Level: Read

        :stability: experimental
        '''
        return typing.cast("Cloudtrail", jsii.invoke(self, "toGetServiceLinkedChannel", []))

    @jsii.member(jsii_name="toGetTrail")
    def to_get_trail(self) -> "Cloudtrail":
        '''(experimental) Grants permission to list settings for the trail.

        Access Level: Read

        https://docs.aws.amazon.com/awscloudtrail/latest/APIReference/API_GetTrail.html

        :stability: experimental
        '''
        return typing.cast("Cloudtrail", jsii.invoke(self, "toGetTrail", []))

    @jsii.member(jsii_name="toGetTrailStatus")
    def to_get_trail_status(self) -> "Cloudtrail":
        '''(experimental) Grants permission to retrieve a JSON-formatted list of information about the specified trail.

        Access Level: Read

        https://docs.aws.amazon.com/awscloudtrail/latest/APIReference/API_GetTrailStatus.html

        :stability: experimental
        '''
        return typing.cast("Cloudtrail", jsii.invoke(self, "toGetTrailStatus", []))

    @jsii.member(jsii_name="toListEventDataStores")
    def to_list_event_data_stores(self) -> "Cloudtrail":
        '''(experimental) Grants permission to list event data stores associated with the current region for your account.

        Access Level: List

        https://docs.aws.amazon.com/awscloudtrail/latest/APIReference/API_ListEventDataStores.html

        :stability: experimental
        '''
        return typing.cast("Cloudtrail", jsii.invoke(self, "toListEventDataStores", []))

    @jsii.member(jsii_name="toListPublicKeys")
    def to_list_public_keys(self) -> "Cloudtrail":
        '''(experimental) Grants permission to list the public keys whose private keys were used to sign trail digest files within a specified time range.

        Access Level: Read

        https://docs.aws.amazon.com/awscloudtrail/latest/APIReference/API_ListPublicKeys.html

        :stability: experimental
        '''
        return typing.cast("Cloudtrail", jsii.invoke(self, "toListPublicKeys", []))

    @jsii.member(jsii_name="toListQueries")
    def to_list_queries(self) -> "Cloudtrail":
        '''(experimental) Grants permission to list queries associated with an event data store.

        Access Level: List

        https://docs.aws.amazon.com/awscloudtrail/latest/APIReference/API_ListQueries.html

        :stability: experimental
        '''
        return typing.cast("Cloudtrail", jsii.invoke(self, "toListQueries", []))

    @jsii.member(jsii_name="toListServiceLinkedChannels")
    def to_list_service_linked_channels(self) -> "Cloudtrail":
        '''(experimental) Grants permission to list service-linked channels associated with the current region for a specified account.

        Access Level: List

        :stability: experimental
        '''
        return typing.cast("Cloudtrail", jsii.invoke(self, "toListServiceLinkedChannels", []))

    @jsii.member(jsii_name="toListTags")
    def to_list_tags(self) -> "Cloudtrail":
        '''(experimental) Grants permission to list the tags for trails or event data stores in the current region.

        Access Level: Read

        https://docs.aws.amazon.com/awscloudtrail/latest/APIReference/API_ListTags.html

        :stability: experimental
        '''
        return typing.cast("Cloudtrail", jsii.invoke(self, "toListTags", []))

    @jsii.member(jsii_name="toListTrails")
    def to_list_trails(self) -> "Cloudtrail":
        '''(experimental) Grants permission to list trails associated with the current region for your account.

        Access Level: List

        https://docs.aws.amazon.com/awscloudtrail/latest/APIReference/API_ListTrails.html

        :stability: experimental
        '''
        return typing.cast("Cloudtrail", jsii.invoke(self, "toListTrails", []))

    @jsii.member(jsii_name="toLookupEvents")
    def to_lookup_events(self) -> "Cloudtrail":
        '''(experimental) Grants permission to look up API activity events captured by CloudTrail that create, update, or delete resources in your account.

        Access Level: Read

        https://docs.aws.amazon.com/awscloudtrail/latest/APIReference/API_LookupEvents.html

        :stability: experimental
        '''
        return typing.cast("Cloudtrail", jsii.invoke(self, "toLookupEvents", []))

    @jsii.member(jsii_name="toPutEventSelectors")
    def to_put_event_selectors(self) -> "Cloudtrail":
        '''(experimental) Grants permission to create and update event selectors for a trail.

        Access Level: Write

        https://docs.aws.amazon.com/awscloudtrail/latest/APIReference/API_PutEventSelectors.html

        :stability: experimental
        '''
        return typing.cast("Cloudtrail", jsii.invoke(self, "toPutEventSelectors", []))

    @jsii.member(jsii_name="toPutInsightSelectors")
    def to_put_insight_selectors(self) -> "Cloudtrail":
        '''(experimental) Grants permission to create and update CloudTrail Insights selectors for a trail.

        Access Level: Write

        https://docs.aws.amazon.com/awscloudtrail/latest/APIReference/API_PutInsightSelectors.html

        :stability: experimental
        '''
        return typing.cast("Cloudtrail", jsii.invoke(self, "toPutInsightSelectors", []))

    @jsii.member(jsii_name="toRegisterOrganizationDelegatedAdmin")
    def to_register_organization_delegated_admin(self) -> "Cloudtrail":
        '''(experimental) Grants permission to register an AWS Organizations member account as a delegated administrator.

        Access Level: Write

        https://docs.aws.amazon.com/awscloudtrail/latest/APIReference/API_RegisterOrganizationDelegatedAdmin.html

        :stability: experimental
        '''
        return typing.cast("Cloudtrail", jsii.invoke(self, "toRegisterOrganizationDelegatedAdmin", []))

    @jsii.member(jsii_name="toRemoveTags")
    def to_remove_tags(self) -> "Cloudtrail":
        '''(experimental) Grants permission to remove tags from a trail.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/awscloudtrail/latest/APIReference/API_RemoveTags.html

        :stability: experimental
        '''
        return typing.cast("Cloudtrail", jsii.invoke(self, "toRemoveTags", []))

    @jsii.member(jsii_name="toRestoreEventDataStore")
    def to_restore_event_data_store(self) -> "Cloudtrail":
        '''(experimental) Grants permission to restore an event data store.

        Access Level: Write

        https://docs.aws.amazon.com/awscloudtrail/latest/APIReference/API_RestoreEventDataStore.html

        :stability: experimental
        '''
        return typing.cast("Cloudtrail", jsii.invoke(self, "toRestoreEventDataStore", []))

    @jsii.member(jsii_name="toStartLogging")
    def to_start_logging(self) -> "Cloudtrail":
        '''(experimental) Grants permission to start the recording of AWS API calls and log file delivery for a trail.

        Access Level: Write

        https://docs.aws.amazon.com/awscloudtrail/latest/APIReference/API_StartLogging.html

        :stability: experimental
        '''
        return typing.cast("Cloudtrail", jsii.invoke(self, "toStartLogging", []))

    @jsii.member(jsii_name="toStartQuery")
    def to_start_query(self) -> "Cloudtrail":
        '''(experimental) Grants permission to start a new query on a specified event data store.

        Access Level: Write

        https://docs.aws.amazon.com/awscloudtrail/latest/APIReference/API_StartQuery.html

        :stability: experimental
        '''
        return typing.cast("Cloudtrail", jsii.invoke(self, "toStartQuery", []))

    @jsii.member(jsii_name="toStopLogging")
    def to_stop_logging(self) -> "Cloudtrail":
        '''(experimental) Grants permission to stop the recording of AWS API calls and log file delivery for a trail.

        Access Level: Write

        https://docs.aws.amazon.com/awscloudtrail/latest/APIReference/API_StopLogging.html

        :stability: experimental
        '''
        return typing.cast("Cloudtrail", jsii.invoke(self, "toStopLogging", []))

    @jsii.member(jsii_name="toUpdateEventDataStore")
    def to_update_event_data_store(self) -> "Cloudtrail":
        '''(experimental) Grants permission to update an event data store.

        Access Level: Write

        https://docs.aws.amazon.com/awscloudtrail/latest/APIReference/API_UpdateEventDataStore.html

        :stability: experimental
        '''
        return typing.cast("Cloudtrail", jsii.invoke(self, "toUpdateEventDataStore", []))

    @jsii.member(jsii_name="toUpdateServiceLinkedChannel")
    def to_update_service_linked_channel(self) -> "Cloudtrail":
        '''(experimental) Grants permission to update the settings that specify delivery of log files.

        Access Level: Write

        :stability: experimental
        '''
        return typing.cast("Cloudtrail", jsii.invoke(self, "toUpdateServiceLinkedChannel", []))

    @jsii.member(jsii_name="toUpdateTrail")
    def to_update_trail(self) -> "Cloudtrail":
        '''(experimental) Grants permission to update the settings that specify delivery of log files.

        Access Level: Write

        https://docs.aws.amazon.com/awscloudtrail/latest/APIReference/API_UpdateTrail.html

        :stability: experimental
        '''
        return typing.cast("Cloudtrail", jsii.invoke(self, "toUpdateTrail", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__38c51a7b71186223fb1770d961109a77b24c409926c5416fd2477104f093d364)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a4dd0cb45161bb61a4b536d7ddbaab2bbf5ff9e40c8461eaf3cbe4bb5710aa3d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Cloudwatch(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Cloudwatch",
):
    '''(experimental) Statement provider for service `cloudwatch <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazoncloudwatch.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `cloudwatch <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazoncloudwatch.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="ifAlarmActions")
    def if_alarm_actions(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Cloudwatch":
        '''(experimental) Filters actions based on defined alarm actions.

        https://docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/iam-cw-condition-keys-alarm-actions.html

        Applies to actions:

        - .toPutCompositeAlarm()
        - .toPutMetricAlarm()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d12389b52607ac133c240445de94195de0c651e9e9dcd7c95542ad2f010d0c1f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Cloudwatch", jsii.invoke(self, "ifAlarmActions", [value, operator]))

    @jsii.member(jsii_name="ifNamespace")
    def if_namespace(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Cloudwatch":
        '''(experimental) Filters actions based on the presence of optional namespace values.

        https://docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/iam-cw-condition-keys-namespace.html

        Applies to actions:

        - .toPutMetricData()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__574ad7725ac096e99c1c1a8e1bc27afb58b7b3667a33c09a3d1cdf355ad83780)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Cloudwatch", jsii.invoke(self, "ifNamespace", [value, operator]))

    @jsii.member(jsii_name="ifRequestInsightRuleLogGroups")
    def if_request_insight_rule_log_groups(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Cloudwatch":
        '''(experimental) Filters actions based on the Log Groups specified in an Insight Rule.

        https://docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/iam-cw-condition-keys-contributor.html

        Applies to actions:

        - .toPutInsightRule()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f7336a8b8d22fedf8bc8ffe6a6ccf7d96cf7732cca9c9405015a67ea13c21ec5)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Cloudwatch", jsii.invoke(self, "ifRequestInsightRuleLogGroups", [value, operator]))

    @jsii.member(jsii_name="ifRequestManagedResourceARNs")
    def if_request_managed_resource_ar_ns(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Cloudwatch":
        '''(experimental) Filters access by the Resource ARNs specified in a managed Insight Rule.

        https://docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/iam-cw-condition-keys-contributor.html

        Applies to actions:

        - .toListManagedInsightRules()
        - .toPutManagedInsightRules()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__dbcf7628f24a2880258fb9d858fc1dcf8195c28c6dccf9679f4f6c503d3e00b5)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Cloudwatch", jsii.invoke(self, "ifRequestManagedResourceARNs", [value, operator]))

    @jsii.member(jsii_name="onAlarm")
    def on_alarm(
        self,
        alarm_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Cloudwatch":
        '''(experimental) Adds a resource of type alarm to the statement.

        https://docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/auth-and-access-control-cw.html

        :param alarm_name: - Identifier for the alarmName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__53865719977d922f1e6cea6d1bf2c125991e07b5b5e37d26af78812eb0a495c4)
            check_type(argname="argument alarm_name", value=alarm_name, expected_type=type_hints["alarm_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Cloudwatch", jsii.invoke(self, "onAlarm", [alarm_name, account, region, partition]))

    @jsii.member(jsii_name="onDashboard")
    def on_dashboard(
        self,
        dashboard_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Cloudwatch":
        '''(experimental) Adds a resource of type dashboard to the statement.

        https://docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/auth-and-access-control-cw.html

        :param dashboard_name: - Identifier for the dashboardName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c39496a0f90a36067b176f648237cef8f6ab4a8662933d1b0f10e51016a31e22)
            check_type(argname="argument dashboard_name", value=dashboard_name, expected_type=type_hints["dashboard_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Cloudwatch", jsii.invoke(self, "onDashboard", [dashboard_name, account, partition]))

    @jsii.member(jsii_name="onInsightRule")
    def on_insight_rule(
        self,
        insight_rule_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Cloudwatch":
        '''(experimental) Adds a resource of type insight-rule to the statement.

        https://docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/auth-and-access-control-cw.html

        :param insight_rule_name: - Identifier for the insightRuleName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ccf7a525b6c6019a521b0acab70ad9522e8e81804b7c391e944a1ced0e479977)
            check_type(argname="argument insight_rule_name", value=insight_rule_name, expected_type=type_hints["insight_rule_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Cloudwatch", jsii.invoke(self, "onInsightRule", [insight_rule_name, account, region, partition]))

    @jsii.member(jsii_name="onMetricStream")
    def on_metric_stream(
        self,
        metric_stream_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Cloudwatch":
        '''(experimental) Adds a resource of type metric-stream to the statement.

        https://docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/auth-and-access-control-cw.html

        :param metric_stream_name: - Identifier for the metricStreamName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__41ff616502fd3986699214e8918ccbb7f2abdc1d5d55f3bcee8b6d973b862085)
            check_type(argname="argument metric_stream_name", value=metric_stream_name, expected_type=type_hints["metric_stream_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Cloudwatch", jsii.invoke(self, "onMetricStream", [metric_stream_name, account, region, partition]))

    @jsii.member(jsii_name="toDeleteAlarms")
    def to_delete_alarms(self) -> "Cloudwatch":
        '''(experimental) Grants permission to delete a collection of alarms.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonCloudWatch/latest/APIReference/API_DeleteAlarms.html

        :stability: experimental
        '''
        return typing.cast("Cloudwatch", jsii.invoke(self, "toDeleteAlarms", []))

    @jsii.member(jsii_name="toDeleteAnomalyDetector")
    def to_delete_anomaly_detector(self) -> "Cloudwatch":
        '''(experimental) Grants permission to delete the specified anomaly detection model from your account.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonCloudWatch/latest/APIReference/API_DeleteAnomalyDetector.html

        :stability: experimental
        '''
        return typing.cast("Cloudwatch", jsii.invoke(self, "toDeleteAnomalyDetector", []))

    @jsii.member(jsii_name="toDeleteDashboards")
    def to_delete_dashboards(self) -> "Cloudwatch":
        '''(experimental) Grants permission to delete all CloudWatch dashboards that you specify.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonCloudWatch/latest/APIReference/API_DeleteDashboards.html

        :stability: experimental
        '''
        return typing.cast("Cloudwatch", jsii.invoke(self, "toDeleteDashboards", []))

    @jsii.member(jsii_name="toDeleteInsightRules")
    def to_delete_insight_rules(self) -> "Cloudwatch":
        '''(experimental) Grants permission to delete a collection of insight rules.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonCloudWatch/latest/APIReference/API_DeleteInsightRules.html

        :stability: experimental
        '''
        return typing.cast("Cloudwatch", jsii.invoke(self, "toDeleteInsightRules", []))

    @jsii.member(jsii_name="toDeleteMetricStream")
    def to_delete_metric_stream(self) -> "Cloudwatch":
        '''(experimental) Grants permission to delete the CloudWatch metric stream that you specify.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonCloudWatch/latest/APIReference/API_DeleteMetricStream.html

        :stability: experimental
        '''
        return typing.cast("Cloudwatch", jsii.invoke(self, "toDeleteMetricStream", []))

    @jsii.member(jsii_name="toDescribeAlarmHistory")
    def to_describe_alarm_history(self) -> "Cloudwatch":
        '''(experimental) Grants permission to retrieve the history for the specified alarm.

        Access Level: Read

        https://docs.aws.amazon.com/AmazonCloudWatch/latest/APIReference/API_DescribeAlarmHistory.html

        :stability: experimental
        '''
        return typing.cast("Cloudwatch", jsii.invoke(self, "toDescribeAlarmHistory", []))

    @jsii.member(jsii_name="toDescribeAlarms")
    def to_describe_alarms(self) -> "Cloudwatch":
        '''(experimental) Grants permission to describe all alarms, currently owned by the user's account.

        Access Level: Read

        https://docs.aws.amazon.com/AmazonCloudWatch/latest/APIReference/API_DescribeAlarms.html

        :stability: experimental
        '''
        return typing.cast("Cloudwatch", jsii.invoke(self, "toDescribeAlarms", []))

    @jsii.member(jsii_name="toDescribeAlarmsForMetric")
    def to_describe_alarms_for_metric(self) -> "Cloudwatch":
        '''(experimental) Grants permission to describe all alarms configured on the specified metric, currently owned by the user's account.

        Access Level: Read

        https://docs.aws.amazon.com/AmazonCloudWatch/latest/APIReference/API_DescribeAlarmsForMetric.html

        :stability: experimental
        '''
        return typing.cast("Cloudwatch", jsii.invoke(self, "toDescribeAlarmsForMetric", []))

    @jsii.member(jsii_name="toDescribeAnomalyDetectors")
    def to_describe_anomaly_detectors(self) -> "Cloudwatch":
        '''(experimental) Grants permission to list the anomaly detection models that you have created in your account.

        Access Level: Read

        https://docs.aws.amazon.com/AmazonCloudWatch/latest/APIReference/API_DescribeAnomalyDetectors.html

        :stability: experimental
        '''
        return typing.cast("Cloudwatch", jsii.invoke(self, "toDescribeAnomalyDetectors", []))

    @jsii.member(jsii_name="toDescribeInsightRules")
    def to_describe_insight_rules(self) -> "Cloudwatch":
        '''(experimental) Grants permission to describe all insight rules, currently owned by the user's account.

        Access Level: Read

        https://docs.aws.amazon.com/AmazonCloudWatch/latest/APIReference/API_DescribeInsightRules.html

        :stability: experimental
        '''
        return typing.cast("Cloudwatch", jsii.invoke(self, "toDescribeInsightRules", []))

    @jsii.member(jsii_name="toDisableAlarmActions")
    def to_disable_alarm_actions(self) -> "Cloudwatch":
        '''(experimental) Grants permission to disable actions for a collection of alarms.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonCloudWatch/latest/APIReference/API_DisableAlarmActions.html

        :stability: experimental
        '''
        return typing.cast("Cloudwatch", jsii.invoke(self, "toDisableAlarmActions", []))

    @jsii.member(jsii_name="toDisableInsightRules")
    def to_disable_insight_rules(self) -> "Cloudwatch":
        '''(experimental) Grants permission to disable a collection of insight rules.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonCloudWatch/latest/APIReference/API_DisableInsightRules.html

        :stability: experimental
        '''
        return typing.cast("Cloudwatch", jsii.invoke(self, "toDisableInsightRules", []))

    @jsii.member(jsii_name="toEnableAlarmActions")
    def to_enable_alarm_actions(self) -> "Cloudwatch":
        '''(experimental) Grants permission to enable actions for a collection of alarms.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonCloudWatch/latest/APIReference/API_EnableAlarmActions.html

        :stability: experimental
        '''
        return typing.cast("Cloudwatch", jsii.invoke(self, "toEnableAlarmActions", []))

    @jsii.member(jsii_name="toEnableInsightRules")
    def to_enable_insight_rules(self) -> "Cloudwatch":
        '''(experimental) Grants permission to enable a collection of insight rules.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonCloudWatch/latest/APIReference/API_EnableInsightRules.html

        :stability: experimental
        '''
        return typing.cast("Cloudwatch", jsii.invoke(self, "toEnableInsightRules", []))

    @jsii.member(jsii_name="toGetDashboard")
    def to_get_dashboard(self) -> "Cloudwatch":
        '''(experimental) Grants permission to display the details of the CloudWatch dashboard you specify.

        Access Level: Read

        https://docs.aws.amazon.com/AmazonCloudWatch/latest/APIReference/API_GetDashboard.html

        :stability: experimental
        '''
        return typing.cast("Cloudwatch", jsii.invoke(self, "toGetDashboard", []))

    @jsii.member(jsii_name="toGetInsightRuleReport")
    def to_get_insight_rule_report(self) -> "Cloudwatch":
        '''(experimental) Grants permission to return the top-N report of unique contributors over a time range for a given insight rule.

        Access Level: Read

        https://docs.aws.amazon.com/AmazonCloudWatch/latest/APIReference/API_GetInsightRuleReport.html

        :stability: experimental
        '''
        return typing.cast("Cloudwatch", jsii.invoke(self, "toGetInsightRuleReport", []))

    @jsii.member(jsii_name="toGetMetricData")
    def to_get_metric_data(self) -> "Cloudwatch":
        '''(experimental) Grants permission to retrieve batch amounts of CloudWatch metric data and perform metric math on retrieved data.

        Access Level: Read

        https://docs.aws.amazon.com/AmazonCloudWatch/latest/APIReference/API_GetMetricData.html

        :stability: experimental
        '''
        return typing.cast("Cloudwatch", jsii.invoke(self, "toGetMetricData", []))

    @jsii.member(jsii_name="toGetMetricStatistics")
    def to_get_metric_statistics(self) -> "Cloudwatch":
        '''(experimental) Grants permission to retrieve statistics for the specified metric.

        Access Level: Read

        https://docs.aws.amazon.com/AmazonCloudWatch/latest/APIReference/API_GetMetricStatistics.html

        :stability: experimental
        '''
        return typing.cast("Cloudwatch", jsii.invoke(self, "toGetMetricStatistics", []))

    @jsii.member(jsii_name="toGetMetricStream")
    def to_get_metric_stream(self) -> "Cloudwatch":
        '''(experimental) Grants permission to return the details of a CloudWatch metric stream.

        Access Level: Read

        https://docs.aws.amazon.com/AmazonCloudWatch/latest/APIReference/API_GetMetricStream.html

        :stability: experimental
        '''
        return typing.cast("Cloudwatch", jsii.invoke(self, "toGetMetricStream", []))

    @jsii.member(jsii_name="toGetMetricWidgetImage")
    def to_get_metric_widget_image(self) -> "Cloudwatch":
        '''(experimental) Grants permission to retrieve snapshots of metric widgets.

        Access Level: Read

        https://docs.aws.amazon.com/AmazonCloudWatch/latest/APIReference/API_GetMetricWidgetImage.html

        :stability: experimental
        '''
        return typing.cast("Cloudwatch", jsii.invoke(self, "toGetMetricWidgetImage", []))

    @jsii.member(jsii_name="toLink")
    def to_link(self) -> "Cloudwatch":
        '''(experimental) Grants permission to share CloudWatch resources with a monitoring account.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/CloudWatch-Unified-Cross-Account-Setup.html#CloudWatch-Unified-Cross-Account-Setup-permissions

        :stability: experimental
        '''
        return typing.cast("Cloudwatch", jsii.invoke(self, "toLink", []))

    @jsii.member(jsii_name="toListDashboards")
    def to_list_dashboards(self) -> "Cloudwatch":
        '''(experimental) Grants permission to return a list of all CloudWatch dashboards in your account.

        Access Level: List

        https://docs.aws.amazon.com/AmazonCloudWatch/latest/APIReference/API_ListDashboards.html

        :stability: experimental
        '''
        return typing.cast("Cloudwatch", jsii.invoke(self, "toListDashboards", []))

    @jsii.member(jsii_name="toListManagedInsightRules")
    def to_list_managed_insight_rules(self) -> "Cloudwatch":
        '''(experimental) Grants permission to list available managed Insight Rules for a given Resource ARN.

        Access Level: Read

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifRequestManagedResourceARNs()

        https://docs.aws.amazon.com/AmazonCloudWatch/latest/APIReference/API_ListManagedInsightRules.html

        :stability: experimental
        '''
        return typing.cast("Cloudwatch", jsii.invoke(self, "toListManagedInsightRules", []))

    @jsii.member(jsii_name="toListMetrics")
    def to_list_metrics(self) -> "Cloudwatch":
        '''(experimental) Grants permission to retrieve a list of valid metrics stored for the AWS account owner.

        Access Level: List

        https://docs.aws.amazon.com/AmazonCloudWatch/latest/APIReference/API_ListMetrics.html

        :stability: experimental
        '''
        return typing.cast("Cloudwatch", jsii.invoke(self, "toListMetrics", []))

    @jsii.member(jsii_name="toListMetricStreams")
    def to_list_metric_streams(self) -> "Cloudwatch":
        '''(experimental) Grants permission to return a list of all CloudWatch metric streams in your account.

        Access Level: List

        https://docs.aws.amazon.com/AmazonCloudWatch/latest/APIReference/API_ListMetricStreams.html

        :stability: experimental
        '''
        return typing.cast("Cloudwatch", jsii.invoke(self, "toListMetricStreams", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Cloudwatch":
        '''(experimental) Grants permission to list tags for an Amazon CloudWatch resource.

        Access Level: List

        https://docs.aws.amazon.com/AmazonCloudWatch/latest/APIReference/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("Cloudwatch", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toPutAnomalyDetector")
    def to_put_anomaly_detector(self) -> "Cloudwatch":
        '''(experimental) Grants permission to create or update an anomaly detection model for a CloudWatch metric.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonCloudWatch/latest/APIReference/API_PutAnomalyDetector.html

        :stability: experimental
        '''
        return typing.cast("Cloudwatch", jsii.invoke(self, "toPutAnomalyDetector", []))

    @jsii.member(jsii_name="toPutCompositeAlarm")
    def to_put_composite_alarm(self) -> "Cloudwatch":
        '''(experimental) Grants permission to create or update a composite alarm.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifAlarmActions()

        https://docs.aws.amazon.com/AmazonCloudWatch/latest/APIReference/API_PutCompositeAlarm.html

        :stability: experimental
        '''
        return typing.cast("Cloudwatch", jsii.invoke(self, "toPutCompositeAlarm", []))

    @jsii.member(jsii_name="toPutDashboard")
    def to_put_dashboard(self) -> "Cloudwatch":
        '''(experimental) Grants permission to create a CloudWatch dashboard, or update an existing dashboard if it already exists.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonCloudWatch/latest/APIReference/API_PutDashboard.html

        :stability: experimental
        '''
        return typing.cast("Cloudwatch", jsii.invoke(self, "toPutDashboard", []))

    @jsii.member(jsii_name="toPutInsightRule")
    def to_put_insight_rule(self) -> "Cloudwatch":
        '''(experimental) Grants permission to create a new insight rule or replace an existing insight rule.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifRequestInsightRuleLogGroups()

        https://docs.aws.amazon.com/AmazonCloudWatch/latest/APIReference/API_PutInsightRule.html

        :stability: experimental
        '''
        return typing.cast("Cloudwatch", jsii.invoke(self, "toPutInsightRule", []))

    @jsii.member(jsii_name="toPutManagedInsightRules")
    def to_put_managed_insight_rules(self) -> "Cloudwatch":
        '''(experimental) Grants permission to create managed Insight Rules.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifRequestManagedResourceARNs()

        https://docs.aws.amazon.com/AmazonCloudWatch/latest/APIReference/API_PutManagedInsightRules.html

        :stability: experimental
        '''
        return typing.cast("Cloudwatch", jsii.invoke(self, "toPutManagedInsightRules", []))

    @jsii.member(jsii_name="toPutMetricAlarm")
    def to_put_metric_alarm(self) -> "Cloudwatch":
        '''(experimental) Grants permission to create or update an alarm and associates it with the specified Amazon CloudWatch metric.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifAlarmActions()

        https://docs.aws.amazon.com/AmazonCloudWatch/latest/APIReference/API_PutMetricAlarm.html

        :stability: experimental
        '''
        return typing.cast("Cloudwatch", jsii.invoke(self, "toPutMetricAlarm", []))

    @jsii.member(jsii_name="toPutMetricData")
    def to_put_metric_data(self) -> "Cloudwatch":
        '''(experimental) Grants permission to publish metric data points to Amazon CloudWatch.

        Access Level: Write

        Possible conditions:

        - .ifNamespace()

        https://docs.aws.amazon.com/AmazonCloudWatch/latest/APIReference/API_PutMetricData.html

        :stability: experimental
        '''
        return typing.cast("Cloudwatch", jsii.invoke(self, "toPutMetricData", []))

    @jsii.member(jsii_name="toPutMetricStream")
    def to_put_metric_stream(self) -> "Cloudwatch":
        '''(experimental) Grants permission to create a CloudWatch metric stream, or update an existing metric stream if it already exists.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/AmazonCloudWatch/latest/APIReference/API_PutMetricStream.html

        :stability: experimental
        '''
        return typing.cast("Cloudwatch", jsii.invoke(self, "toPutMetricStream", []))

    @jsii.member(jsii_name="toSetAlarmState")
    def to_set_alarm_state(self) -> "Cloudwatch":
        '''(experimental) Grants permission to temporarily set the state of an alarm for testing purposes.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonCloudWatch/latest/APIReference/API_SetAlarmState.html

        :stability: experimental
        '''
        return typing.cast("Cloudwatch", jsii.invoke(self, "toSetAlarmState", []))

    @jsii.member(jsii_name="toStartMetricStreams")
    def to_start_metric_streams(self) -> "Cloudwatch":
        '''(experimental) Grants permission to start all CloudWatch metric streams that you specify.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonCloudWatch/latest/APIReference/API_StartMetricStreams.html

        :stability: experimental
        '''
        return typing.cast("Cloudwatch", jsii.invoke(self, "toStartMetricStreams", []))

    @jsii.member(jsii_name="toStopMetricStreams")
    def to_stop_metric_streams(self) -> "Cloudwatch":
        '''(experimental) Grants permission to stop all CloudWatch metric streams that you specify.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonCloudWatch/latest/APIReference/API_StopMetricStreams.html

        :stability: experimental
        '''
        return typing.cast("Cloudwatch", jsii.invoke(self, "toStopMetricStreams", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Cloudwatch":
        '''(experimental) Grants permission to add tags to an Amazon CloudWatch resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/AmazonCloudWatch/latest/APIReference/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("Cloudwatch", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Cloudwatch":
        '''(experimental) Grants permission to remove a tag from an Amazon CloudWatch resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/AmazonCloudWatch/latest/APIReference/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("Cloudwatch", jsii.invoke(self, "toUntagResource", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e814360a249f13fdff653347c7797cac6899f5539440f91ce6eb77fa3cde6158)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bc2ea3a90da74c28175fcf780832039af653c6be93ebb639e5e81e4c2927391a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Codeartifact(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Codeartifact",
):
    '''(experimental) Statement provider for service `codeartifact <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awscodeartifact.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `codeartifact <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awscodeartifact.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onDomain")
    def on_domain(
        self,
        domain_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Codeartifact":
        '''(experimental) Adds a resource of type domain to the statement.

        https://docs.aws.amazon.com/codeartifact/latest/ug/auth-and-access-control-iam-access-control-identity-based.html#arn-formats

        :param domain_name: - Identifier for the domainName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__575bf4f8a11dca55aeded8601929deef04d481d6c62a6e359dcf316b548d4dc9)
            check_type(argname="argument domain_name", value=domain_name, expected_type=type_hints["domain_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Codeartifact", jsii.invoke(self, "onDomain", [domain_name, account, region, partition]))

    @jsii.member(jsii_name="onPackage")
    def on_package(
        self,
        domain_name: builtins.str,
        repository_name: builtins.str,
        package_format: builtins.str,
        package_namespace: builtins.str,
        package_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Codeartifact":
        '''(experimental) Adds a resource of type package to the statement.

        https://docs.aws.amazon.com/codeartifact/latest/ug/repo-policies.html

        :param domain_name: - Identifier for the domainName.
        :param repository_name: - Identifier for the repositoryName.
        :param package_format: - Identifier for the packageFormat.
        :param package_namespace: - Identifier for the packageNamespace.
        :param package_name: - Identifier for the packageName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8c9799417925824051523aebfb370541612f2bbbfb7dcaccb4ddd5e34d9cf3ed)
            check_type(argname="argument domain_name", value=domain_name, expected_type=type_hints["domain_name"])
            check_type(argname="argument repository_name", value=repository_name, expected_type=type_hints["repository_name"])
            check_type(argname="argument package_format", value=package_format, expected_type=type_hints["package_format"])
            check_type(argname="argument package_namespace", value=package_namespace, expected_type=type_hints["package_namespace"])
            check_type(argname="argument package_name", value=package_name, expected_type=type_hints["package_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Codeartifact", jsii.invoke(self, "onPackage", [domain_name, repository_name, package_format, package_namespace, package_name, account, region, partition]))

    @jsii.member(jsii_name="onRepository")
    def on_repository(
        self,
        domain_name: builtins.str,
        repository_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Codeartifact":
        '''(experimental) Adds a resource of type repository to the statement.

        https://docs.aws.amazon.com/codeartifact/latest/ug/repo-policies.html

        :param domain_name: - Identifier for the domainName.
        :param repository_name: - Identifier for the repositoryName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f643880434c6276a03c4aab6c2da73f36d5ff15479e892b4868fc2fd4bbf3f4f)
            check_type(argname="argument domain_name", value=domain_name, expected_type=type_hints["domain_name"])
            check_type(argname="argument repository_name", value=repository_name, expected_type=type_hints["repository_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Codeartifact", jsii.invoke(self, "onRepository", [domain_name, repository_name, account, region, partition]))

    @jsii.member(jsii_name="toAssociateExternalConnection")
    def to_associate_external_connection(self) -> "Codeartifact":
        '''(experimental) Grants permission to add an external connection to a repository.

        Access Level: Write

        https://docs.aws.amazon.com/codeartifact/latest/APIReference/API_AssociateExternalConnection.html

        :stability: experimental
        '''
        return typing.cast("Codeartifact", jsii.invoke(self, "toAssociateExternalConnection", []))

    @jsii.member(jsii_name="toAssociateWithDownstreamRepository")
    def to_associate_with_downstream_repository(self) -> "Codeartifact":
        '''(experimental) Grants permission to associate an existing repository as an upstream repository to another repository.

        Access Level: Write

        https://docs.aws.amazon.com/codeartifact/latest/ug/repos-upstream.html

        :stability: experimental
        '''
        return typing.cast("Codeartifact", jsii.invoke(self, "toAssociateWithDownstreamRepository", []))

    @jsii.member(jsii_name="toCopyPackageVersions")
    def to_copy_package_versions(self) -> "Codeartifact":
        '''(experimental) Grants permission to copy package versions from one repository to another repository in the same domain.

        Access Level: Write

        https://docs.aws.amazon.com/codeartifact/latest/APIReference/API_CopyPackageVersions.html

        :stability: experimental
        '''
        return typing.cast("Codeartifact", jsii.invoke(self, "toCopyPackageVersions", []))

    @jsii.member(jsii_name="toCreateDomain")
    def to_create_domain(self) -> "Codeartifact":
        '''(experimental) Grants permission to create a new domain.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/codeartifact/latest/APIReference/API_CreateDomain.html

        :stability: experimental
        '''
        return typing.cast("Codeartifact", jsii.invoke(self, "toCreateDomain", []))

    @jsii.member(jsii_name="toCreateRepository")
    def to_create_repository(self) -> "Codeartifact":
        '''(experimental) Grants permission to create a new repository.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/codeartifact/latest/APIReference/API_CreateRepository.html

        :stability: experimental
        '''
        return typing.cast("Codeartifact", jsii.invoke(self, "toCreateRepository", []))

    @jsii.member(jsii_name="toDeleteDomain")
    def to_delete_domain(self) -> "Codeartifact":
        '''(experimental) Grants permission to delete a domain.

        Access Level: Write

        https://docs.aws.amazon.com/codeartifact/latest/APIReference/API_DeleteDomain.html

        :stability: experimental
        '''
        return typing.cast("Codeartifact", jsii.invoke(self, "toDeleteDomain", []))

    @jsii.member(jsii_name="toDeleteDomainPermissionsPolicy")
    def to_delete_domain_permissions_policy(self) -> "Codeartifact":
        '''(experimental) Grants permission to delete the resource policy set on a domain.

        Access Level: Permissions management

        https://docs.aws.amazon.com/codeartifact/latest/APIReference/API_DeleteDomainPermissionsPolicy.html

        :stability: experimental
        '''
        return typing.cast("Codeartifact", jsii.invoke(self, "toDeleteDomainPermissionsPolicy", []))

    @jsii.member(jsii_name="toDeletePackageVersions")
    def to_delete_package_versions(self) -> "Codeartifact":
        '''(experimental) Grants permission to delete package versions.

        Access Level: Write

        https://docs.aws.amazon.com/codeartifact/latest/APIReference/API_DeletePackageVersions.html

        :stability: experimental
        '''
        return typing.cast("Codeartifact", jsii.invoke(self, "toDeletePackageVersions", []))

    @jsii.member(jsii_name="toDeleteRepository")
    def to_delete_repository(self) -> "Codeartifact":
        '''(experimental) Grants permission to delete a repository.

        Access Level: Write

        https://docs.aws.amazon.com/codeartifact/latest/APIReference/API_DeleteRepository.html

        :stability: experimental
        '''
        return typing.cast("Codeartifact", jsii.invoke(self, "toDeleteRepository", []))

    @jsii.member(jsii_name="toDeleteRepositoryPermissionsPolicy")
    def to_delete_repository_permissions_policy(self) -> "Codeartifact":
        '''(experimental) Grants permission to delete the resource policy set on a repository.

        Access Level: Permissions management

        https://docs.aws.amazon.com/codeartifact/latest/APIReference/API_DeleteRepositoryPermissionsPolicy.html

        :stability: experimental
        '''
        return typing.cast("Codeartifact", jsii.invoke(self, "toDeleteRepositoryPermissionsPolicy", []))

    @jsii.member(jsii_name="toDescribeDomain")
    def to_describe_domain(self) -> "Codeartifact":
        '''(experimental) Grants permission to return information about a domain.

        Access Level: Read

        https://docs.aws.amazon.com/codeartifact/latest/APIReference/API_DescribeDomain.html

        :stability: experimental
        '''
        return typing.cast("Codeartifact", jsii.invoke(self, "toDescribeDomain", []))

    @jsii.member(jsii_name="toDescribePackage")
    def to_describe_package(self) -> "Codeartifact":
        '''(experimental) Grants permission to retrieve information about a package.

        Access Level: Read

        https://docs.aws.amazon.com/codeartifact/latest/APIReference/API_DescribePackage.html

        :stability: experimental
        '''
        return typing.cast("Codeartifact", jsii.invoke(self, "toDescribePackage", []))

    @jsii.member(jsii_name="toDescribePackageVersion")
    def to_describe_package_version(self) -> "Codeartifact":
        '''(experimental) Grants permission to return information about a package version.

        Access Level: Read

        https://docs.aws.amazon.com/codeartifact/latest/APIReference/API_DescribePackageVersion.html

        :stability: experimental
        '''
        return typing.cast("Codeartifact", jsii.invoke(self, "toDescribePackageVersion", []))

    @jsii.member(jsii_name="toDescribeRepository")
    def to_describe_repository(self) -> "Codeartifact":
        '''(experimental) Grants permission to return detailed information about a repository.

        Access Level: Read

        https://docs.aws.amazon.com/codeartifact/latest/APIReference/API_DescribeRepository.html

        :stability: experimental
        '''
        return typing.cast("Codeartifact", jsii.invoke(self, "toDescribeRepository", []))

    @jsii.member(jsii_name="toDisassociateExternalConnection")
    def to_disassociate_external_connection(self) -> "Codeartifact":
        '''(experimental) Grants permission to disassociate an external connection from a repository.

        Access Level: Write

        https://docs.aws.amazon.com/codeartifact/latest/APIReference/API_DisassociateExternalConnection.html

        :stability: experimental
        '''
        return typing.cast("Codeartifact", jsii.invoke(self, "toDisassociateExternalConnection", []))

    @jsii.member(jsii_name="toDisposePackageVersions")
    def to_dispose_package_versions(self) -> "Codeartifact":
        '''(experimental) Grants permission to set the status of package versions to Disposed and delete their assets.

        Access Level: Write

        https://docs.aws.amazon.com/codeartifact/latest/APIReference/API_DisposePackageVersions.html

        :stability: experimental
        '''
        return typing.cast("Codeartifact", jsii.invoke(self, "toDisposePackageVersions", []))

    @jsii.member(jsii_name="toGetAuthorizationToken")
    def to_get_authorization_token(self) -> "Codeartifact":
        '''(experimental) Grants permission to generate a temporary authentication token for accessing repositories in a domain.

        Access Level: Read

        https://docs.aws.amazon.com/codeartifact/latest/APIReference/API_GetAuthorizationToken.html

        :stability: experimental
        '''
        return typing.cast("Codeartifact", jsii.invoke(self, "toGetAuthorizationToken", []))

    @jsii.member(jsii_name="toGetDomainPermissionsPolicy")
    def to_get_domain_permissions_policy(self) -> "Codeartifact":
        '''(experimental) Grants permission to return a domain's resource policy.

        Access Level: Read

        https://docs.aws.amazon.com/codeartifact/latest/APIReference/API_GetDomainPermissionsPolicy.html

        :stability: experimental
        '''
        return typing.cast("Codeartifact", jsii.invoke(self, "toGetDomainPermissionsPolicy", []))

    @jsii.member(jsii_name="toGetPackageVersionAsset")
    def to_get_package_version_asset(self) -> "Codeartifact":
        '''(experimental) Grants permission to return an asset (or file) that is part of a package version.

        Access Level: Read

        https://docs.aws.amazon.com/codeartifact/latest/APIReference/API_GetPackageVersionAsset.html

        :stability: experimental
        '''
        return typing.cast("Codeartifact", jsii.invoke(self, "toGetPackageVersionAsset", []))

    @jsii.member(jsii_name="toGetPackageVersionReadme")
    def to_get_package_version_readme(self) -> "Codeartifact":
        '''(experimental) Grants permission to return a package version's readme file.

        Access Level: Read

        https://docs.aws.amazon.com/codeartifact/latest/APIReference/API_GetPackageVersionReadme.html

        :stability: experimental
        '''
        return typing.cast("Codeartifact", jsii.invoke(self, "toGetPackageVersionReadme", []))

    @jsii.member(jsii_name="toGetRepositoryEndpoint")
    def to_get_repository_endpoint(self) -> "Codeartifact":
        '''(experimental) Grants permission to return an endpoint for a repository.

        Access Level: Read

        https://docs.aws.amazon.com/codeartifact/latest/APIReference/API_GetRepositoryEndpoint.html

        :stability: experimental
        '''
        return typing.cast("Codeartifact", jsii.invoke(self, "toGetRepositoryEndpoint", []))

    @jsii.member(jsii_name="toGetRepositoryPermissionsPolicy")
    def to_get_repository_permissions_policy(self) -> "Codeartifact":
        '''(experimental) Grants permission to return a repository's resource policy.

        Access Level: Read

        https://docs.aws.amazon.com/codeartifact/latest/APIReference/API_GetRepositoryPermissionsPolicy.html

        :stability: experimental
        '''
        return typing.cast("Codeartifact", jsii.invoke(self, "toGetRepositoryPermissionsPolicy", []))

    @jsii.member(jsii_name="toListDomains")
    def to_list_domains(self) -> "Codeartifact":
        '''(experimental) Grants permission to list the domains in the current user's AWS account.

        Access Level: List

        https://docs.aws.amazon.com/codeartifact/latest/APIReference/API_ListDomains.html

        :stability: experimental
        '''
        return typing.cast("Codeartifact", jsii.invoke(self, "toListDomains", []))

    @jsii.member(jsii_name="toListPackages")
    def to_list_packages(self) -> "Codeartifact":
        '''(experimental) Grants permission to list the packages in a repository.

        Access Level: List

        https://docs.aws.amazon.com/codeartifact/latest/APIReference/API_ListPackages.html

        :stability: experimental
        '''
        return typing.cast("Codeartifact", jsii.invoke(self, "toListPackages", []))

    @jsii.member(jsii_name="toListPackageVersionAssets")
    def to_list_package_version_assets(self) -> "Codeartifact":
        '''(experimental) Grants permission to list a package version's assets.

        Access Level: List

        https://docs.aws.amazon.com/codeartifact/latest/APIReference/API_ListPackageVersionAssets.html

        :stability: experimental
        '''
        return typing.cast("Codeartifact", jsii.invoke(self, "toListPackageVersionAssets", []))

    @jsii.member(jsii_name="toListPackageVersionDependencies")
    def to_list_package_version_dependencies(self) -> "Codeartifact":
        '''(experimental) Grants permission to list the direct dependencies of a package version.

        Access Level: List

        https://docs.aws.amazon.com/codeartifact/latest/APIReference/API_ListPackageVersionDependencies.html

        :stability: experimental
        '''
        return typing.cast("Codeartifact", jsii.invoke(self, "toListPackageVersionDependencies", []))

    @jsii.member(jsii_name="toListPackageVersions")
    def to_list_package_versions(self) -> "Codeartifact":
        '''(experimental) Grants permission to list a package's versions.

        Access Level: List

        https://docs.aws.amazon.com/codeartifact/latest/APIReference/API_ListPackageVersions.html

        :stability: experimental
        '''
        return typing.cast("Codeartifact", jsii.invoke(self, "toListPackageVersions", []))

    @jsii.member(jsii_name="toListRepositories")
    def to_list_repositories(self) -> "Codeartifact":
        '''(experimental) Grants permission to list the repositories administered by the calling account.

        Access Level: List

        https://docs.aws.amazon.com/codeartifact/latest/APIReference/API_ListRepositories.html

        :stability: experimental
        '''
        return typing.cast("Codeartifact", jsii.invoke(self, "toListRepositories", []))

    @jsii.member(jsii_name="toListRepositoriesInDomain")
    def to_list_repositories_in_domain(self) -> "Codeartifact":
        '''(experimental) Grants permission to list the repositories in a domain.

        Access Level: List

        https://docs.aws.amazon.com/codeartifact/latest/APIReference/API_ListRepositoriesInDomain.html

        :stability: experimental
        '''
        return typing.cast("Codeartifact", jsii.invoke(self, "toListRepositoriesInDomain", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Codeartifact":
        '''(experimental) Grants permission to list tags for a CodeArtifact resource.

        Access Level: List

        https://docs.aws.amazon.com/codeartifact/latest/APIReference/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("Codeartifact", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toPublishPackageVersion")
    def to_publish_package_version(self) -> "Codeartifact":
        '''(experimental) Grants permission to publish assets and metadata to a repository endpoint.

        Access Level: Write

        https://docs.aws.amazon.com/codeartifact/latest/ug/repo-policies.html

        :stability: experimental
        '''
        return typing.cast("Codeartifact", jsii.invoke(self, "toPublishPackageVersion", []))

    @jsii.member(jsii_name="toPutDomainPermissionsPolicy")
    def to_put_domain_permissions_policy(self) -> "Codeartifact":
        '''(experimental) Grants permission to attach a resource policy to a domain.

        Access Level: Write

        https://docs.aws.amazon.com/codeartifact/latest/APIReference/API_PutDomainPermissionsPolicy.html

        :stability: experimental
        '''
        return typing.cast("Codeartifact", jsii.invoke(self, "toPutDomainPermissionsPolicy", []))

    @jsii.member(jsii_name="toPutPackageMetadata")
    def to_put_package_metadata(self) -> "Codeartifact":
        '''(experimental) Grants permission to add, modify or remove package metadata using a repository endpoint.

        Access Level: Write

        https://docs.aws.amazon.com/codeartifact/latest/ug/repo-policies.html

        :stability: experimental
        '''
        return typing.cast("Codeartifact", jsii.invoke(self, "toPutPackageMetadata", []))

    @jsii.member(jsii_name="toPutPackageOriginConfiguration")
    def to_put_package_origin_configuration(self) -> "Codeartifact":
        '''(experimental) Grants permission to set origin configuration for a package.

        Access Level: Write

        https://docs.aws.amazon.com/codeartifact/latest/APIReference/API_PutPackageOriginConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Codeartifact", jsii.invoke(self, "toPutPackageOriginConfiguration", []))

    @jsii.member(jsii_name="toPutRepositoryPermissionsPolicy")
    def to_put_repository_permissions_policy(self) -> "Codeartifact":
        '''(experimental) Grants permission to attach a resource policy to a repository.

        Access Level: Write

        https://docs.aws.amazon.com/codeartifact/latest/APIReference/API_PutRepositoryPermissionsPolicy.html

        :stability: experimental
        '''
        return typing.cast("Codeartifact", jsii.invoke(self, "toPutRepositoryPermissionsPolicy", []))

    @jsii.member(jsii_name="toReadFromRepository")
    def to_read_from_repository(self) -> "Codeartifact":
        '''(experimental) Grants permission to return package assets and metadata from a repository endpoint.

        Access Level: Read

        https://docs.aws.amazon.com/codeartifact/latest/ug/repo-policies.html

        :stability: experimental
        '''
        return typing.cast("Codeartifact", jsii.invoke(self, "toReadFromRepository", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Codeartifact":
        '''(experimental) Grants permission to tag a CodeArtifact resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/codeartifact/latest/APIReference/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("Codeartifact", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Codeartifact":
        '''(experimental) Grants permission to remove a tag from a CodeArtifact resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/codeartifact/latest/APIReference/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("Codeartifact", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdatePackageVersionsStatus")
    def to_update_package_versions_status(self) -> "Codeartifact":
        '''(experimental) Grants permission to modify the status of one or more versions of a package.

        Access Level: Write

        https://docs.aws.amazon.com/codeartifact/latest/APIReference/API_UpdatePackageVersionsStatus.html

        :stability: experimental
        '''
        return typing.cast("Codeartifact", jsii.invoke(self, "toUpdatePackageVersionsStatus", []))

    @jsii.member(jsii_name="toUpdateRepository")
    def to_update_repository(self) -> "Codeartifact":
        '''(experimental) Grants permission to modify the properties of a repository.

        Access Level: Write

        https://docs.aws.amazon.com/codeartifact/latest/APIReference/API_UpdateRepository.html

        :stability: experimental
        '''
        return typing.cast("Codeartifact", jsii.invoke(self, "toUpdateRepository", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6a6e041dac307408821e4e74d929c0532b0d4b41587a3a489a1e01578a6b42a8)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d108bbcf844414bea635391e480d587e9e53bfd1466b688d6a928bb9540a98a9)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Codebuild(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Codebuild",
):
    '''(experimental) Statement provider for service `codebuild <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awscodebuild.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `codebuild <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awscodebuild.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onBuild")
    def on_build(
        self,
        build_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Codebuild":
        '''(experimental) Adds a resource of type build to the statement.

        https://docs.aws.amazon.com/codebuild/latest/userguide/auth-and-access-control-iam-access-control-identity-based.html#arn-formats

        :param build_id: - Identifier for the buildId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__96f752218a68f897e12079e9ce0072a33f0e0e239440a4db976f752ba6f337f2)
            check_type(argname="argument build_id", value=build_id, expected_type=type_hints["build_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Codebuild", jsii.invoke(self, "onBuild", [build_id, account, region, partition]))

    @jsii.member(jsii_name="onBuildBatch")
    def on_build_batch(
        self,
        build_batch_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Codebuild":
        '''(experimental) Adds a resource of type build-batch to the statement.

        https://docs.aws.amazon.com/codebuild/latest/userguide/auth-and-access-control-iam-access-control-identity-based.html#arn-formats

        :param build_batch_id: - Identifier for the buildBatchId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1da8a80786167b20b28705804d63615a3045f9fc44236aab60ec3289254a645d)
            check_type(argname="argument build_batch_id", value=build_batch_id, expected_type=type_hints["build_batch_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Codebuild", jsii.invoke(self, "onBuildBatch", [build_batch_id, account, region, partition]))

    @jsii.member(jsii_name="onProject")
    def on_project(
        self,
        project_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Codebuild":
        '''(experimental) Adds a resource of type project to the statement.

        https://docs.aws.amazon.com/codebuild/latest/userguide/auth-and-access-control-iam-access-control-identity-based.html#arn-formats

        :param project_name: - Identifier for the projectName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2d4ad75a20266323bb9b3d6a9cc0c9a65e601584da67a886f5532b0dabd34b32)
            check_type(argname="argument project_name", value=project_name, expected_type=type_hints["project_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Codebuild", jsii.invoke(self, "onProject", [project_name, account, region, partition]))

    @jsii.member(jsii_name="onReport")
    def on_report(
        self,
        report_group_name: builtins.str,
        report_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Codebuild":
        '''(experimental) Adds a resource of type report to the statement.

        https://docs.aws.amazon.com/codebuild/latest/userguide/auth-and-access-control-iam-access-control-identity-based.html#arn-formats

        :param report_group_name: - Identifier for the reportGroupName.
        :param report_id: - Identifier for the reportId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__baf2995e1408b227c8cd4ae4f803a151d68f415904081ea4a0fec2d5d5bc9d79)
            check_type(argname="argument report_group_name", value=report_group_name, expected_type=type_hints["report_group_name"])
            check_type(argname="argument report_id", value=report_id, expected_type=type_hints["report_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Codebuild", jsii.invoke(self, "onReport", [report_group_name, report_id, account, region, partition]))

    @jsii.member(jsii_name="onReportGroup")
    def on_report_group(
        self,
        report_group_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Codebuild":
        '''(experimental) Adds a resource of type report-group to the statement.

        https://docs.aws.amazon.com/codebuild/latest/userguide/auth-and-access-control-iam-access-control-identity-based.html#arn-formats

        :param report_group_name: - Identifier for the reportGroupName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3d14440742e541825ad995058d6e37cd40bb24d065bf6dfd8fb91348e58d7505)
            check_type(argname="argument report_group_name", value=report_group_name, expected_type=type_hints["report_group_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Codebuild", jsii.invoke(self, "onReportGroup", [report_group_name, account, region, partition]))

    @jsii.member(jsii_name="toBatchDeleteBuilds")
    def to_batch_delete_builds(self) -> "Codebuild":
        '''(experimental) Grants permission to delete one or more builds.

        Access Level: Write

        https://docs.aws.amazon.com/codebuild/latest/APIReference/API_BatchDeleteBuilds.html

        :stability: experimental
        '''
        return typing.cast("Codebuild", jsii.invoke(self, "toBatchDeleteBuilds", []))

    @jsii.member(jsii_name="toBatchGetBuildBatches")
    def to_batch_get_build_batches(self) -> "Codebuild":
        '''(experimental) Grants permission to get information about one or more build batches.

        Access Level: Read

        https://docs.aws.amazon.com/codebuild/latest/APIReference/API_BatchGetBuildBatches.html

        :stability: experimental
        '''
        return typing.cast("Codebuild", jsii.invoke(self, "toBatchGetBuildBatches", []))

    @jsii.member(jsii_name="toBatchGetBuilds")
    def to_batch_get_builds(self) -> "Codebuild":
        '''(experimental) Grants permission to get information about one or more builds.

        Access Level: Read

        https://docs.aws.amazon.com/codebuild/latest/APIReference/API_BatchGetBuilds.html

        :stability: experimental
        '''
        return typing.cast("Codebuild", jsii.invoke(self, "toBatchGetBuilds", []))

    @jsii.member(jsii_name="toBatchGetProjects")
    def to_batch_get_projects(self) -> "Codebuild":
        '''(experimental) Grants permission to get information about one or more build projects.

        Access Level: Read

        https://docs.aws.amazon.com/codebuild/latest/APIReference/API_BatchGetProjects.html

        :stability: experimental
        '''
        return typing.cast("Codebuild", jsii.invoke(self, "toBatchGetProjects", []))

    @jsii.member(jsii_name="toBatchGetReportGroups")
    def to_batch_get_report_groups(self) -> "Codebuild":
        '''(experimental) Grants permission to return an array of ReportGroup objects that are specified by the input reportGroupArns parameter.

        Access Level: Read

        https://docs.aws.amazon.com/codebuild/latest/APIReference/API_BatchGetReportGroups.html

        :stability: experimental
        '''
        return typing.cast("Codebuild", jsii.invoke(self, "toBatchGetReportGroups", []))

    @jsii.member(jsii_name="toBatchGetReports")
    def to_batch_get_reports(self) -> "Codebuild":
        '''(experimental) Grants permission to return an array of the Report objects specified by the input reportArns parameter.

        Access Level: Read

        https://docs.aws.amazon.com/codebuild/latest/APIReference/API_BatchGetReports.html

        :stability: experimental
        '''
        return typing.cast("Codebuild", jsii.invoke(self, "toBatchGetReports", []))

    @jsii.member(jsii_name="toBatchPutCodeCoverages")
    def to_batch_put_code_coverages(self) -> "Codebuild":
        '''(experimental) Grants permission to add or update information about a report.

        Access Level: Write

        https://docs.aws.amazon.com/codebuild/latest/userguide/auth-and-access-control-iam-identity-based-access-control.html#console-policies

        :stability: experimental
        '''
        return typing.cast("Codebuild", jsii.invoke(self, "toBatchPutCodeCoverages", []))

    @jsii.member(jsii_name="toBatchPutTestCases")
    def to_batch_put_test_cases(self) -> "Codebuild":
        '''(experimental) Grants permission to add or update information about a report.

        Access Level: Write

        https://docs.aws.amazon.com/codebuild/latest/userguide/auth-and-access-control-iam-identity-based-access-control.html#console-policies

        :stability: experimental
        '''
        return typing.cast("Codebuild", jsii.invoke(self, "toBatchPutTestCases", []))

    @jsii.member(jsii_name="toCreateProject")
    def to_create_project(self) -> "Codebuild":
        '''(experimental) Grants permission to create a build project.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/codebuild/latest/APIReference/API_CreateProject.html

        :stability: experimental
        '''
        return typing.cast("Codebuild", jsii.invoke(self, "toCreateProject", []))

    @jsii.member(jsii_name="toCreateReport")
    def to_create_report(self) -> "Codebuild":
        '''(experimental) Grants permission to create a report.

        A report is created when tests specified in the buildspec file for a report groups run during the build of a project

        Access Level: Write

        https://docs.aws.amazon.com/codebuild/latest/userguide/auth-and-access-control-iam-identity-based-access-control.html#console-policies

        :stability: experimental
        '''
        return typing.cast("Codebuild", jsii.invoke(self, "toCreateReport", []))

    @jsii.member(jsii_name="toCreateReportGroup")
    def to_create_report_group(self) -> "Codebuild":
        '''(experimental) Grants permission to create a report group.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/codebuild/latest/APIReference/API_CreateReportGroup.html

        :stability: experimental
        '''
        return typing.cast("Codebuild", jsii.invoke(self, "toCreateReportGroup", []))

    @jsii.member(jsii_name="toCreateWebhook")
    def to_create_webhook(self) -> "Codebuild":
        '''(experimental) Grants permission to create webhook.

        For an existing AWS CodeBuild build project that has its source code stored in a GitHub or Bitbucket repository, enables AWS CodeBuild to start rebuilding the source code every time a code change is pushed to the repository

        Access Level: Write

        https://docs.aws.amazon.com/codebuild/latest/APIReference/API_CreateWebhook.html

        :stability: experimental
        '''
        return typing.cast("Codebuild", jsii.invoke(self, "toCreateWebhook", []))

    @jsii.member(jsii_name="toDeleteBuildBatch")
    def to_delete_build_batch(self) -> "Codebuild":
        '''(experimental) Grants permission to delete a build batch.

        Access Level: Write

        https://docs.aws.amazon.com/codebuild/latest/APIReference/API_DeleteBuildBatch.html

        :stability: experimental
        '''
        return typing.cast("Codebuild", jsii.invoke(self, "toDeleteBuildBatch", []))

    @jsii.member(jsii_name="toDeleteOAuthToken")
    def to_delete_o_auth_token(self) -> "Codebuild":
        '''(experimental) Grants permission to delete an OAuth token from a connected third-party OAuth provider.

        Only used in the AWS CodeBuild console

        Access Level: Write

        https://docs.aws.amazon.com/codebuild/latest/userguide/auth-and-access-control-iam-identity-based-access-control.html#console-policies

        :stability: experimental
        '''
        return typing.cast("Codebuild", jsii.invoke(self, "toDeleteOAuthToken", []))

    @jsii.member(jsii_name="toDeleteProject")
    def to_delete_project(self) -> "Codebuild":
        '''(experimental) Grants permission to delete a build project.

        Access Level: Write

        https://docs.aws.amazon.com/codebuild/latest/APIReference/API_DeleteProject.html

        :stability: experimental
        '''
        return typing.cast("Codebuild", jsii.invoke(self, "toDeleteProject", []))

    @jsii.member(jsii_name="toDeleteReport")
    def to_delete_report(self) -> "Codebuild":
        '''(experimental) Grants permission to delete a report.

        Access Level: Write

        https://docs.aws.amazon.com/codebuild/latest/APIReference/API_DeleteReport.html

        :stability: experimental
        '''
        return typing.cast("Codebuild", jsii.invoke(self, "toDeleteReport", []))

    @jsii.member(jsii_name="toDeleteReportGroup")
    def to_delete_report_group(self) -> "Codebuild":
        '''(experimental) Grants permission to delete a report group.

        Access Level: Write

        https://docs.aws.amazon.com/codebuild/latest/APIReference/API_DeleteReportGroup.html

        :stability: experimental
        '''
        return typing.cast("Codebuild", jsii.invoke(self, "toDeleteReportGroup", []))

    @jsii.member(jsii_name="toDeleteResourcePolicy")
    def to_delete_resource_policy(self) -> "Codebuild":
        '''(experimental) Grants permission to delete a resource policy for the associated project or report group.

        Access Level: Permissions management

        https://docs.aws.amazon.com/codebuild/latest/APIReference/API_DeleteResourcePolicy.html

        :stability: experimental
        '''
        return typing.cast("Codebuild", jsii.invoke(self, "toDeleteResourcePolicy", []))

    @jsii.member(jsii_name="toDeleteSourceCredentials")
    def to_delete_source_credentials(self) -> "Codebuild":
        '''(experimental) Grants permission to delete a set of GitHub, GitHub Enterprise, or Bitbucket source credentials.

        Access Level: Write

        https://docs.aws.amazon.com/codebuild/latest/APIReference/API_DeleteSourceCredentials.html

        :stability: experimental
        '''
        return typing.cast("Codebuild", jsii.invoke(self, "toDeleteSourceCredentials", []))

    @jsii.member(jsii_name="toDeleteWebhook")
    def to_delete_webhook(self) -> "Codebuild":
        '''(experimental) Grants permission to delete webhook.

        For an existing AWS CodeBuild build project that has its source code stored in a GitHub or Bitbucket repository, stops AWS CodeBuild from rebuilding the source code every time a code change is pushed to the repository

        Access Level: Write

        https://docs.aws.amazon.com/codebuild/latest/APIReference/API_DeleteWebhook.html

        :stability: experimental
        '''
        return typing.cast("Codebuild", jsii.invoke(self, "toDeleteWebhook", []))

    @jsii.member(jsii_name="toDescribeCodeCoverages")
    def to_describe_code_coverages(self) -> "Codebuild":
        '''(experimental) Grants permission to return an array of CodeCoverage objects.

        Access Level: Read

        https://docs.aws.amazon.com/codebuild/latest/APIReference/API_DescribeCodeCoverages.html

        :stability: experimental
        '''
        return typing.cast("Codebuild", jsii.invoke(self, "toDescribeCodeCoverages", []))

    @jsii.member(jsii_name="toDescribeTestCases")
    def to_describe_test_cases(self) -> "Codebuild":
        '''(experimental) Grants permission to return an array of TestCase objects.

        Access Level: Read

        https://docs.aws.amazon.com/codebuild/latest/APIReference/API_DescribeTestCases.html

        :stability: experimental
        '''
        return typing.cast("Codebuild", jsii.invoke(self, "toDescribeTestCases", []))

    @jsii.member(jsii_name="toGetReportGroupTrend")
    def to_get_report_group_trend(self) -> "Codebuild":
        '''(experimental) Grants permission to analyze and accumulate test report values for the test reports in the specified report group.

        Access Level: Read

        https://docs.aws.amazon.com/codebuild/latest/APIReference/API_GetReportGroupTrend.html

        :stability: experimental
        '''
        return typing.cast("Codebuild", jsii.invoke(self, "toGetReportGroupTrend", []))

    @jsii.member(jsii_name="toGetResourcePolicy")
    def to_get_resource_policy(self) -> "Codebuild":
        '''(experimental) Grants permission to return a resource policy for the specified project or report group.

        Access Level: Read

        https://docs.aws.amazon.com/codebuild/latest/APIReference/API_GetResourcePolicy.html

        :stability: experimental
        '''
        return typing.cast("Codebuild", jsii.invoke(self, "toGetResourcePolicy", []))

    @jsii.member(jsii_name="toImportSourceCredentials")
    def to_import_source_credentials(self) -> "Codebuild":
        '''(experimental) Grants permission to import the source repository credentials for an AWS CodeBuild project that has its source code stored in a GitHub, GitHub Enterprise, or Bitbucket repository.

        Access Level: Write

        https://docs.aws.amazon.com/codebuild/latest/APIReference/API_ImportSourceCredentials.html

        :stability: experimental
        '''
        return typing.cast("Codebuild", jsii.invoke(self, "toImportSourceCredentials", []))

    @jsii.member(jsii_name="toInvalidateProjectCache")
    def to_invalidate_project_cache(self) -> "Codebuild":
        '''(experimental) Grants permission to reset the cache for a project.

        Access Level: Write

        https://docs.aws.amazon.com/codebuild/latest/APIReference/API_InvalidateProjectCache.html

        :stability: experimental
        '''
        return typing.cast("Codebuild", jsii.invoke(self, "toInvalidateProjectCache", []))

    @jsii.member(jsii_name="toListBuildBatches")
    def to_list_build_batches(self) -> "Codebuild":
        '''(experimental) Grants permission to get a list of build batch IDs, with each build batch ID representing a single build batch.

        Access Level: List

        https://docs.aws.amazon.com/codebuild/latest/APIReference/API_ListBuildBatches.html

        :stability: experimental
        '''
        return typing.cast("Codebuild", jsii.invoke(self, "toListBuildBatches", []))

    @jsii.member(jsii_name="toListBuildBatchesForProject")
    def to_list_build_batches_for_project(self) -> "Codebuild":
        '''(experimental) Grants permission to get a list of build batch IDs for the specified build project, with each build batch ID representing a single build batch.

        Access Level: List

        https://docs.aws.amazon.com/codebuild/latest/APIReference/API_ListBuildBatchesForProject.html

        :stability: experimental
        '''
        return typing.cast("Codebuild", jsii.invoke(self, "toListBuildBatchesForProject", []))

    @jsii.member(jsii_name="toListBuilds")
    def to_list_builds(self) -> "Codebuild":
        '''(experimental) Grants permission to get a list of build IDs, with each build ID representing a single build.

        Access Level: List

        https://docs.aws.amazon.com/codebuild/latest/APIReference/API_ListBuilds.html

        :stability: experimental
        '''
        return typing.cast("Codebuild", jsii.invoke(self, "toListBuilds", []))

    @jsii.member(jsii_name="toListBuildsForProject")
    def to_list_builds_for_project(self) -> "Codebuild":
        '''(experimental) Grants permission to get a list of build IDs for the specified build project, with each build ID representing a single build.

        Access Level: List

        https://docs.aws.amazon.com/codebuild/latest/APIReference/API_ListBuildsForProject.html

        :stability: experimental
        '''
        return typing.cast("Codebuild", jsii.invoke(self, "toListBuildsForProject", []))

    @jsii.member(jsii_name="toListConnectedOAuthAccounts")
    def to_list_connected_o_auth_accounts(self) -> "Codebuild":
        '''(experimental) Grants permission to list connected third-party OAuth providers. Only used in the AWS CodeBuild console.

        Access Level: List

        https://docs.aws.amazon.com/codebuild/latest/userguide/auth-and-access-control-iam-identity-based-access-control.html#console-policies

        :stability: experimental
        '''
        return typing.cast("Codebuild", jsii.invoke(self, "toListConnectedOAuthAccounts", []))

    @jsii.member(jsii_name="toListCuratedEnvironmentImages")
    def to_list_curated_environment_images(self) -> "Codebuild":
        '''(experimental) Grants permission to get information about Docker images that are managed by AWS CodeBuild.

        Access Level: List

        https://docs.aws.amazon.com/codebuild/latest/APIReference/API_ListCuratedEnvironmentImages.html

        :stability: experimental
        '''
        return typing.cast("Codebuild", jsii.invoke(self, "toListCuratedEnvironmentImages", []))

    @jsii.member(jsii_name="toListProjects")
    def to_list_projects(self) -> "Codebuild":
        '''(experimental) Grants permission to get a list of build project names, with each build project name representing a single build project.

        Access Level: List

        https://docs.aws.amazon.com/codebuild/latest/APIReference/API_ListProjects.html

        :stability: experimental
        '''
        return typing.cast("Codebuild", jsii.invoke(self, "toListProjects", []))

    @jsii.member(jsii_name="toListReportGroups")
    def to_list_report_groups(self) -> "Codebuild":
        '''(experimental) Grants permission to return a list of report group ARNs. Each report group ARN represents one report group.

        Access Level: List

        https://docs.aws.amazon.com/codebuild/latest/APIReference/API_ListReportGroups.html

        :stability: experimental
        '''
        return typing.cast("Codebuild", jsii.invoke(self, "toListReportGroups", []))

    @jsii.member(jsii_name="toListReports")
    def to_list_reports(self) -> "Codebuild":
        '''(experimental) Grants permission to return a list of report ARNs. Each report ARN representing one report.

        Access Level: List

        https://docs.aws.amazon.com/codebuild/latest/APIReference/API_ListReports.html

        :stability: experimental
        '''
        return typing.cast("Codebuild", jsii.invoke(self, "toListReports", []))

    @jsii.member(jsii_name="toListReportsForReportGroup")
    def to_list_reports_for_report_group(self) -> "Codebuild":
        '''(experimental) Grants permission to return a list of report ARNs that belong to the specified report group.

        Each report ARN represents one report

        Access Level: List

        https://docs.aws.amazon.com/codebuild/latest/APIReference/API_ListReportsForReportGroup.html

        :stability: experimental
        '''
        return typing.cast("Codebuild", jsii.invoke(self, "toListReportsForReportGroup", []))

    @jsii.member(jsii_name="toListRepositories")
    def to_list_repositories(self) -> "Codebuild":
        '''(experimental) Grants permission to list source code repositories from a connected third-party OAuth provider.

        Only used in the AWS CodeBuild console

        Access Level: List

        https://docs.aws.amazon.com/codebuild/latest/userguide/auth-and-access-control-iam-identity-based-access-control.html#console-policies

        :stability: experimental
        '''
        return typing.cast("Codebuild", jsii.invoke(self, "toListRepositories", []))

    @jsii.member(jsii_name="toListSharedProjects")
    def to_list_shared_projects(self) -> "Codebuild":
        '''(experimental) Grants permission to return a list of project ARNs that have been shared with the requester.

        Each project ARN represents one project

        Access Level: List

        https://docs.aws.amazon.com/codebuild/latest/APIReference/API_ListSharedProjects.html

        :stability: experimental
        '''
        return typing.cast("Codebuild", jsii.invoke(self, "toListSharedProjects", []))

    @jsii.member(jsii_name="toListSharedReportGroups")
    def to_list_shared_report_groups(self) -> "Codebuild":
        '''(experimental) Grants permission to return a list of report group ARNs that have been shared with the requester.

        Each report group ARN represents one report group

        Access Level: List

        https://docs.aws.amazon.com/codebuild/latest/APIReference/API_ListSharedReportGroups.html

        :stability: experimental
        '''
        return typing.cast("Codebuild", jsii.invoke(self, "toListSharedReportGroups", []))

    @jsii.member(jsii_name="toListSourceCredentials")
    def to_list_source_credentials(self) -> "Codebuild":
        '''(experimental) Grants permission to return a list of SourceCredentialsInfo objects.

        Access Level: List

        https://docs.aws.amazon.com/codebuild/latest/APIReference/API_ListSourceCredentials.html

        :stability: experimental
        '''
        return typing.cast("Codebuild", jsii.invoke(self, "toListSourceCredentials", []))

    @jsii.member(jsii_name="toPersistOAuthToken")
    def to_persist_o_auth_token(self) -> "Codebuild":
        '''(experimental) Grants permission to save an OAuth token from a connected third-party OAuth provider.

        Only used in the AWS CodeBuild console

        Access Level: Write

        https://docs.aws.amazon.com/codebuild/latest/userguide/auth-and-access-control-iam-identity-based-access-control.html#console-policies

        :stability: experimental
        '''
        return typing.cast("Codebuild", jsii.invoke(self, "toPersistOAuthToken", []))

    @jsii.member(jsii_name="toPutResourcePolicy")
    def to_put_resource_policy(self) -> "Codebuild":
        '''(experimental) Grants permission to create a resource policy for the associated project or report group.

        Access Level: Permissions management

        https://docs.aws.amazon.com/codebuild/latest/APIReference/API_PutResourcePolicy.html

        :stability: experimental
        '''
        return typing.cast("Codebuild", jsii.invoke(self, "toPutResourcePolicy", []))

    @jsii.member(jsii_name="toRetryBuild")
    def to_retry_build(self) -> "Codebuild":
        '''(experimental) Grants permission to retry a build.

        Access Level: Write

        https://docs.aws.amazon.com/codebuild/latest/APIReference/API_RetryBuild.html

        :stability: experimental
        '''
        return typing.cast("Codebuild", jsii.invoke(self, "toRetryBuild", []))

    @jsii.member(jsii_name="toRetryBuildBatch")
    def to_retry_build_batch(self) -> "Codebuild":
        '''(experimental) Grants permission to retry a build batch.

        Access Level: Write

        https://docs.aws.amazon.com/codebuild/latest/APIReference/API_RetryBuildBatch.html

        :stability: experimental
        '''
        return typing.cast("Codebuild", jsii.invoke(self, "toRetryBuildBatch", []))

    @jsii.member(jsii_name="toStartBuild")
    def to_start_build(self) -> "Codebuild":
        '''(experimental) Grants permission to start running a build.

        Access Level: Write

        https://docs.aws.amazon.com/codebuild/latest/APIReference/API_StartBuild.html

        :stability: experimental
        '''
        return typing.cast("Codebuild", jsii.invoke(self, "toStartBuild", []))

    @jsii.member(jsii_name="toStartBuildBatch")
    def to_start_build_batch(self) -> "Codebuild":
        '''(experimental) Grants permission to start running a build batch.

        Access Level: Write

        https://docs.aws.amazon.com/codebuild/latest/APIReference/API_StartBuildBatch.html

        :stability: experimental
        '''
        return typing.cast("Codebuild", jsii.invoke(self, "toStartBuildBatch", []))

    @jsii.member(jsii_name="toStopBuild")
    def to_stop_build(self) -> "Codebuild":
        '''(experimental) Grants permission to attempt to stop running a build.

        Access Level: Write

        https://docs.aws.amazon.com/codebuild/latest/APIReference/API_StopBuild.html

        :stability: experimental
        '''
        return typing.cast("Codebuild", jsii.invoke(self, "toStopBuild", []))

    @jsii.member(jsii_name="toStopBuildBatch")
    def to_stop_build_batch(self) -> "Codebuild":
        '''(experimental) Grants permission to attempt to stop running a build batch.

        Access Level: Write

        https://docs.aws.amazon.com/codebuild/latest/APIReference/API_StopBuildBatch.html

        :stability: experimental
        '''
        return typing.cast("Codebuild", jsii.invoke(self, "toStopBuildBatch", []))

    @jsii.member(jsii_name="toUpdateProject")
    def to_update_project(self) -> "Codebuild":
        '''(experimental) Grants permission to change the settings of an existing build project.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/codebuild/latest/APIReference/API_UpdateProject.html

        :stability: experimental
        '''
        return typing.cast("Codebuild", jsii.invoke(self, "toUpdateProject", []))

    @jsii.member(jsii_name="toUpdateProjectVisibility")
    def to_update_project_visibility(self) -> "Codebuild":
        '''(experimental) Grants permission to change the public visibility of a project and its builds.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/codebuild/latest/APIReference/API_UpdateProjectVisibility.html

        :stability: experimental
        '''
        return typing.cast("Codebuild", jsii.invoke(self, "toUpdateProjectVisibility", []))

    @jsii.member(jsii_name="toUpdateReport")
    def to_update_report(self) -> "Codebuild":
        '''(experimental) Grants permission to update information about a report.

        Access Level: Write

        https://docs.aws.amazon.com/codebuild/latest/userguide/auth-and-access-control-iam-identity-based-access-control.html#console-policies

        :stability: experimental
        '''
        return typing.cast("Codebuild", jsii.invoke(self, "toUpdateReport", []))

    @jsii.member(jsii_name="toUpdateReportGroup")
    def to_update_report_group(self) -> "Codebuild":
        '''(experimental) Grants permission to change the settings of an existing report group.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/codebuild/latest/APIReference/API_UpdateReportGroup.html

        :stability: experimental
        '''
        return typing.cast("Codebuild", jsii.invoke(self, "toUpdateReportGroup", []))

    @jsii.member(jsii_name="toUpdateWebhook")
    def to_update_webhook(self) -> "Codebuild":
        '''(experimental) Grants permission to update the webhook associated with an AWS CodeBuild build project.

        Access Level: Write

        https://docs.aws.amazon.com/codebuild/latest/APIReference/API_UpdateWebhook.html

        :stability: experimental
        '''
        return typing.cast("Codebuild", jsii.invoke(self, "toUpdateWebhook", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__812b458698ec2091fe8adc7f6526803021561f4e4ca772a177f57c3f57f5db51)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1ed4cc794c73080a18584c58e75fb77579945fe6c92ebcf60fa27a675128a036)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Codecommit(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Codecommit",
):
    '''(experimental) Statement provider for service `codecommit <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awscodecommit.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `codecommit <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awscodecommit.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="ifReferences")
    def if_references(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Codecommit":
        '''(experimental) Filters access by Git reference to specified AWS CodeCommit actions.

        https://docs.aws.amazon.com/codecommit/latest/userguide/how-to-conditional-branch.html

        Applies to actions:

        - .toCreateBranch()
        - .toCreateCommit()
        - .toCreateUnreferencedMergeCommit()
        - .toDeleteBranch()
        - .toDeleteFile()
        - .toGetMergeCommit()
        - .toGitPush()
        - .toMergeBranchesByFastForward()
        - .toMergeBranchesBySquash()
        - .toMergeBranchesByThreeWay()
        - .toMergePullRequestByFastForward()
        - .toMergePullRequestBySquash()
        - .toMergePullRequestByThreeWay()
        - .toPutFile()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7b24cae5d29e92b597f6d7ea370fff51fe0d5bc918f93ddf5d835ec67973d168)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Codecommit", jsii.invoke(self, "ifReferences", [value, operator]))

    @jsii.member(jsii_name="onRepository")
    def on_repository(
        self,
        repository_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Codecommit":
        '''(experimental) Adds a resource of type repository to the statement.

        https://docs.aws.amazon.com/codecommit/latest/userguide/auth-and-access-control-iam-access-control-identity-based.html#arn-formats

        :param repository_name: - Identifier for the repositoryName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__039f3b40eac0f021de8ba2a7b6d358541431fcf0d3f05cef485895ed4e731a97)
            check_type(argname="argument repository_name", value=repository_name, expected_type=type_hints["repository_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Codecommit", jsii.invoke(self, "onRepository", [repository_name, account, region, partition]))

    @jsii.member(jsii_name="toAssociateApprovalRuleTemplateWithRepository")
    def to_associate_approval_rule_template_with_repository(self) -> "Codecommit":
        '''(experimental) Grants permission to associate an approval rule template with a repository.

        Access Level: Write

        https://docs.aws.amazon.com/codecommit/latest/APIReference/API_AssociateApprovalRuleTemplateWithRepository.html

        :stability: experimental
        '''
        return typing.cast("Codecommit", jsii.invoke(self, "toAssociateApprovalRuleTemplateWithRepository", []))

    @jsii.member(jsii_name="toBatchAssociateApprovalRuleTemplateWithRepositories")
    def to_batch_associate_approval_rule_template_with_repositories(
        self,
    ) -> "Codecommit":
        '''(experimental) Grants permission to associate an approval rule template with multiple repositories in a single operation.

        Access Level: Write

        https://docs.aws.amazon.com/codecommit/latest/APIReference/API_BatchAssociateApprovalRuleTemplateWithRepositories.html

        :stability: experimental
        '''
        return typing.cast("Codecommit", jsii.invoke(self, "toBatchAssociateApprovalRuleTemplateWithRepositories", []))

    @jsii.member(jsii_name="toBatchDescribeMergeConflicts")
    def to_batch_describe_merge_conflicts(self) -> "Codecommit":
        '''(experimental) Grants permission to get information about multiple merge conflicts when attempting to merge two commits using either the three-way merge or the squash merge option.

        Access Level: Read

        https://docs.aws.amazon.com/codecommit/latest/APIReference/API_BatchDescribeMergeConflicts.html

        :stability: experimental
        '''
        return typing.cast("Codecommit", jsii.invoke(self, "toBatchDescribeMergeConflicts", []))

    @jsii.member(jsii_name="toBatchDisassociateApprovalRuleTemplateFromRepositories")
    def to_batch_disassociate_approval_rule_template_from_repositories(
        self,
    ) -> "Codecommit":
        '''(experimental) Grants permission to remove the association between an approval rule template and multiple repositories in a single operation.

        Access Level: Write

        https://docs.aws.amazon.com/codecommit/latest/APIReference/API_BatchDisassociateApprovalRuleTemplateFromRepositories.html

        :stability: experimental
        '''
        return typing.cast("Codecommit", jsii.invoke(self, "toBatchDisassociateApprovalRuleTemplateFromRepositories", []))

    @jsii.member(jsii_name="toBatchGetCommits")
    def to_batch_get_commits(self) -> "Codecommit":
        '''(experimental) Grants permission to get return information about one or more commits in an AWS CodeCommit repository.

        Access Level: Read

        https://docs.aws.amazon.com/codecommit/latest/APIReference/API_BatchGetCommits.html

        :stability: experimental
        '''
        return typing.cast("Codecommit", jsii.invoke(self, "toBatchGetCommits", []))

    @jsii.member(jsii_name="toBatchGetPullRequests")
    def to_batch_get_pull_requests(self) -> "Codecommit":
        '''(experimental) Grants permission to return information about one or more pull requests in an AWS CodeCommit repository.

        Access Level: Read

        https://docs.aws.amazon.com/codecommit/latest/userguide/auth-and-access-control-permissions-reference.html#aa-pr

        :stability: experimental
        '''
        return typing.cast("Codecommit", jsii.invoke(self, "toBatchGetPullRequests", []))

    @jsii.member(jsii_name="toBatchGetRepositories")
    def to_batch_get_repositories(self) -> "Codecommit":
        '''(experimental) Grants permission to get information about multiple repositories.

        Access Level: Read

        https://docs.aws.amazon.com/codecommit/latest/APIReference/API_BatchGetRepositories.html

        :stability: experimental
        '''
        return typing.cast("Codecommit", jsii.invoke(self, "toBatchGetRepositories", []))

    @jsii.member(jsii_name="toCancelUploadArchive")
    def to_cancel_upload_archive(self) -> "Codecommit":
        '''(experimental) Grants permission to cancel the uploading of an archive to a pipeline in AWS CodePipeline.

        Access Level: Read

        https://docs.aws.amazon.com/codecommit/latest/userguide/auth-and-access-control-permissions-reference.html#aa-acp

        :stability: experimental
        '''
        return typing.cast("Codecommit", jsii.invoke(self, "toCancelUploadArchive", []))

    @jsii.member(jsii_name="toCreateApprovalRuleTemplate")
    def to_create_approval_rule_template(self) -> "Codecommit":
        '''(experimental) Grants permission to create an approval rule template that will automatically create approval rules in pull requests that match the conditions defined in the template;

        does not grant permission to create approval rules for individual pull requests

        Access Level: Write

        https://docs.aws.amazon.com/codecommit/latest/APIReference/API_CreateApprovalRuleTemplate.html

        :stability: experimental
        '''
        return typing.cast("Codecommit", jsii.invoke(self, "toCreateApprovalRuleTemplate", []))

    @jsii.member(jsii_name="toCreateBranch")
    def to_create_branch(self) -> "Codecommit":
        '''(experimental) Grants permission to create a branch in an AWS CodeCommit repository with this API;

        does not control Git create branch actions

        Access Level: Write

        Possible conditions:

        - .ifReferences()

        https://docs.aws.amazon.com/codecommit/latest/APIReference/API_CreateBranch.html

        :stability: experimental
        '''
        return typing.cast("Codecommit", jsii.invoke(self, "toCreateBranch", []))

    @jsii.member(jsii_name="toCreateCommit")
    def to_create_commit(self) -> "Codecommit":
        '''(experimental) Grants permission to add, copy, move or update single or multiple files in a branch in an AWS CodeCommit repository, and generate a commit for the changes in the specified branch.

        Access Level: Write

        Possible conditions:

        - .ifReferences()

        https://docs.aws.amazon.com/codecommit/latest/APIReference/API_CreateCommit.html

        :stability: experimental
        '''
        return typing.cast("Codecommit", jsii.invoke(self, "toCreateCommit", []))

    @jsii.member(jsii_name="toCreatePullRequest")
    def to_create_pull_request(self) -> "Codecommit":
        '''(experimental) Grants permission to create a pull request in the specified repository.

        Access Level: Write

        https://docs.aws.amazon.com/codecommit/latest/APIReference/API_CreatePullRequest.html

        :stability: experimental
        '''
        return typing.cast("Codecommit", jsii.invoke(self, "toCreatePullRequest", []))

    @jsii.member(jsii_name="toCreatePullRequestApprovalRule")
    def to_create_pull_request_approval_rule(self) -> "Codecommit":
        '''(experimental) Grants permission to create an approval rule specific to an individual pull request;

        does not grant permission to create approval rule templates

        Access Level: Write

        https://docs.aws.amazon.com/codecommit/latest/APIReference/API_CreatePullRequestApprovalRule.html

        :stability: experimental
        '''
        return typing.cast("Codecommit", jsii.invoke(self, "toCreatePullRequestApprovalRule", []))

    @jsii.member(jsii_name="toCreateRepository")
    def to_create_repository(self) -> "Codecommit":
        '''(experimental) Grants permission to create an AWS CodeCommit repository.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/codecommit/latest/APIReference/API_CreateRepository.html

        :stability: experimental
        '''
        return typing.cast("Codecommit", jsii.invoke(self, "toCreateRepository", []))

    @jsii.member(jsii_name="toCreateUnreferencedMergeCommit")
    def to_create_unreferenced_merge_commit(self) -> "Codecommit":
        '''(experimental) Grants permission to create an unreferenced commit that contains the result of merging two commits using either the three-way or the squash merge option;

        does not control Git merge actions

        Access Level: Write

        Possible conditions:

        - .ifReferences()

        https://docs.aws.amazon.com/codecommit/latest/APIReference/API_CreateUnreferencedMergeCommit.html

        :stability: experimental
        '''
        return typing.cast("Codecommit", jsii.invoke(self, "toCreateUnreferencedMergeCommit", []))

    @jsii.member(jsii_name="toDeleteApprovalRuleTemplate")
    def to_delete_approval_rule_template(self) -> "Codecommit":
        '''(experimental) Grants permission to delete an approval rule template.

        Access Level: Write

        https://docs.aws.amazon.com/codecommit/latest/APIReference/API_DeleteApprovalRuleTemplate.html

        :stability: experimental
        '''
        return typing.cast("Codecommit", jsii.invoke(self, "toDeleteApprovalRuleTemplate", []))

    @jsii.member(jsii_name="toDeleteBranch")
    def to_delete_branch(self) -> "Codecommit":
        '''(experimental) Grants permission to delete a branch in an AWS CodeCommit repository with this API;

        does not control Git delete branch actions

        Access Level: Write

        Possible conditions:

        - .ifReferences()

        https://docs.aws.amazon.com/codecommit/latest/APIReference/API_DeleteBranch.html

        :stability: experimental
        '''
        return typing.cast("Codecommit", jsii.invoke(self, "toDeleteBranch", []))

    @jsii.member(jsii_name="toDeleteCommentContent")
    def to_delete_comment_content(self) -> "Codecommit":
        '''(experimental) Grants permission to delete the content of a comment made on a change, file, or commit in a repository.

        Access Level: Write

        https://docs.aws.amazon.com/codecommit/latest/APIReference/API_DeleteCommentContent.html

        :stability: experimental
        '''
        return typing.cast("Codecommit", jsii.invoke(self, "toDeleteCommentContent", []))

    @jsii.member(jsii_name="toDeleteFile")
    def to_delete_file(self) -> "Codecommit":
        '''(experimental) Grants permission to delete a specified file from a specified branch.

        Access Level: Write

        Possible conditions:

        - .ifReferences()

        https://docs.aws.amazon.com/codecommit/latest/APIReference/API_DeleteFile.html

        :stability: experimental
        '''
        return typing.cast("Codecommit", jsii.invoke(self, "toDeleteFile", []))

    @jsii.member(jsii_name="toDeletePullRequestApprovalRule")
    def to_delete_pull_request_approval_rule(self) -> "Codecommit":
        '''(experimental) Grants permission to delete approval rule created for a pull request if the rule was not created by an approval rule template.

        Access Level: Write

        https://docs.aws.amazon.com/codecommit/latest/APIReference/API_DeletePullRequestApprovalRule.html

        :stability: experimental
        '''
        return typing.cast("Codecommit", jsii.invoke(self, "toDeletePullRequestApprovalRule", []))

    @jsii.member(jsii_name="toDeleteRepository")
    def to_delete_repository(self) -> "Codecommit":
        '''(experimental) Grants permission to delete an AWS CodeCommit repository.

        Access Level: Write

        https://docs.aws.amazon.com/codecommit/latest/APIReference/API_DeleteRepository.html

        :stability: experimental
        '''
        return typing.cast("Codecommit", jsii.invoke(self, "toDeleteRepository", []))

    @jsii.member(jsii_name="toDescribeMergeConflicts")
    def to_describe_merge_conflicts(self) -> "Codecommit":
        '''(experimental) Grants permission to get information about specific merge conflicts when attempting to merge two commits using either the three-way or the squash merge option.

        Access Level: Read

        https://docs.aws.amazon.com/codecommit/latest/APIReference/API_DescribeMergeConflicts.html

        :stability: experimental
        '''
        return typing.cast("Codecommit", jsii.invoke(self, "toDescribeMergeConflicts", []))

    @jsii.member(jsii_name="toDescribePullRequestEvents")
    def to_describe_pull_request_events(self) -> "Codecommit":
        '''(experimental) Grants permission to return information about one or more pull request events.

        Access Level: Read

        https://docs.aws.amazon.com/codecommit/latest/APIReference/API_DescribePullRequestEvents.html

        :stability: experimental
        '''
        return typing.cast("Codecommit", jsii.invoke(self, "toDescribePullRequestEvents", []))

    @jsii.member(jsii_name="toDisassociateApprovalRuleTemplateFromRepository")
    def to_disassociate_approval_rule_template_from_repository(self) -> "Codecommit":
        '''(experimental) Grants permission to remove the association between an approval rule template and a repository.

        Access Level: Write

        https://docs.aws.amazon.com/codecommit/latest/APIReference/API_DisassociateApprovalRuleTemplateFromRepository.html

        :stability: experimental
        '''
        return typing.cast("Codecommit", jsii.invoke(self, "toDisassociateApprovalRuleTemplateFromRepository", []))

    @jsii.member(jsii_name="toEvaluatePullRequestApprovalRules")
    def to_evaluate_pull_request_approval_rules(self) -> "Codecommit":
        '''(experimental) Grants permission to evaluate whether a pull request is mergable based on its current approval state and approval rule requirements.

        Access Level: Read

        https://docs.aws.amazon.com/codecommit/latest/APIReference/API_EvaluatePullRequestApprovalRules.html

        :stability: experimental
        '''
        return typing.cast("Codecommit", jsii.invoke(self, "toEvaluatePullRequestApprovalRules", []))

    @jsii.member(jsii_name="toGetApprovalRuleTemplate")
    def to_get_approval_rule_template(self) -> "Codecommit":
        '''(experimental) Grants permission to return information about an approval rule template.

        Access Level: Read

        https://docs.aws.amazon.com/codecommit/latest/APIReference/API_GetApprovalRuleTemplate.html

        :stability: experimental
        '''
        return typing.cast("Codecommit", jsii.invoke(self, "toGetApprovalRuleTemplate", []))

    @jsii.member(jsii_name="toGetBlob")
    def to_get_blob(self) -> "Codecommit":
        '''(experimental) Grants permission to view the encoded content of an individual file in an AWS CodeCommit repository from the AWS CodeCommit console.

        Access Level: Read

        https://docs.aws.amazon.com/codecommit/latest/APIReference/API_GetBlob.html

        :stability: experimental
        '''
        return typing.cast("Codecommit", jsii.invoke(self, "toGetBlob", []))

    @jsii.member(jsii_name="toGetBranch")
    def to_get_branch(self) -> "Codecommit":
        '''(experimental) Grants permission to get details about a branch in an AWS CodeCommit repository with this API;

        does not control Git branch actions

        Access Level: Read

        https://docs.aws.amazon.com/codecommit/latest/APIReference/API_GetBranch.html

        :stability: experimental
        '''
        return typing.cast("Codecommit", jsii.invoke(self, "toGetBranch", []))

    @jsii.member(jsii_name="toGetComment")
    def to_get_comment(self) -> "Codecommit":
        '''(experimental) Grants permission to get the content of a comment made on a change, file, or commit in a repository.

        Access Level: Read

        https://docs.aws.amazon.com/codecommit/latest/APIReference/API_GetComment.html

        :stability: experimental
        '''
        return typing.cast("Codecommit", jsii.invoke(self, "toGetComment", []))

    @jsii.member(jsii_name="toGetCommentReactions")
    def to_get_comment_reactions(self) -> "Codecommit":
        '''(experimental) Grants permission to get the reactions on a comment.

        Access Level: Read

        https://docs.aws.amazon.com/codecommit/latest/APIReference/API_GetCommentReactions.html

        :stability: experimental
        '''
        return typing.cast("Codecommit", jsii.invoke(self, "toGetCommentReactions", []))

    @jsii.member(jsii_name="toGetCommentsForComparedCommit")
    def to_get_comments_for_compared_commit(self) -> "Codecommit":
        '''(experimental) Grants permission to get information about comments made on the comparison between two commits.

        Access Level: Read

        https://docs.aws.amazon.com/codecommit/latest/APIReference/API_GetCommentsForComparedCommit.html

        :stability: experimental
        '''
        return typing.cast("Codecommit", jsii.invoke(self, "toGetCommentsForComparedCommit", []))

    @jsii.member(jsii_name="toGetCommentsForPullRequest")
    def to_get_comments_for_pull_request(self) -> "Codecommit":
        '''(experimental) Grants permission to get comments made on a pull request.

        Access Level: Read

        https://docs.aws.amazon.com/codecommit/latest/APIReference/API_GetCommentsForPullRequest.html

        :stability: experimental
        '''
        return typing.cast("Codecommit", jsii.invoke(self, "toGetCommentsForPullRequest", []))

    @jsii.member(jsii_name="toGetCommit")
    def to_get_commit(self) -> "Codecommit":
        '''(experimental) Grants permission to return information about a commit, including commit message and committer information, with this API;

        does not control Git log actions

        Access Level: Read

        https://docs.aws.amazon.com/codecommit/latest/APIReference/API_GetCommit.html

        :stability: experimental
        '''
        return typing.cast("Codecommit", jsii.invoke(self, "toGetCommit", []))

    @jsii.member(jsii_name="toGetCommitHistory")
    def to_get_commit_history(self) -> "Codecommit":
        '''(experimental) Grants permission to get information about the history of commits in a repository.

        Access Level: Read

        https://docs.aws.amazon.com/codecommit/latest/userguide/auth-and-access-control-permissions-reference.html#aa-code

        :stability: experimental
        '''
        return typing.cast("Codecommit", jsii.invoke(self, "toGetCommitHistory", []))

    @jsii.member(jsii_name="toGetCommitsFromMergeBase")
    def to_get_commits_from_merge_base(self) -> "Codecommit":
        '''(experimental) Grants permission to get information about the difference between commits in the context of a potential merge.

        Access Level: Read

        https://docs.aws.amazon.com/codecommit/latest/userguide/auth-and-access-control-permissions-reference.html#aa-pr

        :stability: experimental
        '''
        return typing.cast("Codecommit", jsii.invoke(self, "toGetCommitsFromMergeBase", []))

    @jsii.member(jsii_name="toGetDifferences")
    def to_get_differences(self) -> "Codecommit":
        '''(experimental) Grants permission to view information about the differences between valid commit specifiers such as a branch, tag, HEAD, commit ID, or other fully qualified reference.

        Access Level: Read

        https://docs.aws.amazon.com/codecommit/latest/APIReference/API_GetDifferences.html

        :stability: experimental
        '''
        return typing.cast("Codecommit", jsii.invoke(self, "toGetDifferences", []))

    @jsii.member(jsii_name="toGetFile")
    def to_get_file(self) -> "Codecommit":
        '''(experimental) Grants permission to return the base-64 encoded contents of a specified file and its metadata.

        Access Level: Read

        https://docs.aws.amazon.com/codecommit/latest/APIReference/API_GetFile.html

        :stability: experimental
        '''
        return typing.cast("Codecommit", jsii.invoke(self, "toGetFile", []))

    @jsii.member(jsii_name="toGetFolder")
    def to_get_folder(self) -> "Codecommit":
        '''(experimental) Grants permission to return the contents of a specified folder in a repository.

        Access Level: Read

        https://docs.aws.amazon.com/codecommit/latest/APIReference/API_GetFolder.html

        :stability: experimental
        '''
        return typing.cast("Codecommit", jsii.invoke(self, "toGetFolder", []))

    @jsii.member(jsii_name="toGetMergeCommit")
    def to_get_merge_commit(self) -> "Codecommit":
        '''(experimental) Grants permission to get information about a merge commit created by one of the merge options for pull requests that creates merge commits.

        Not all merge options create merge commits. This permission does not control Git merge actions

        Access Level: Read

        Possible conditions:

        - .ifReferences()

        https://docs.aws.amazon.com/codecommit/latest/APIReference/API_GetMergeCommit.html

        :stability: experimental
        '''
        return typing.cast("Codecommit", jsii.invoke(self, "toGetMergeCommit", []))

    @jsii.member(jsii_name="toGetMergeConflicts")
    def to_get_merge_conflicts(self) -> "Codecommit":
        '''(experimental) Grants permission to get information about merge conflicts between the before and after commit IDs for a pull request in a repository.

        Access Level: Read

        https://docs.aws.amazon.com/codecommit/latest/APIReference/API_GetMergeConflicts.html

        :stability: experimental
        '''
        return typing.cast("Codecommit", jsii.invoke(self, "toGetMergeConflicts", []))

    @jsii.member(jsii_name="toGetMergeOptions")
    def to_get_merge_options(self) -> "Codecommit":
        '''(experimental) Grants permission to get information about merge options for pull requests that can be used to merge two commits;

        does not control Git merge actions

        Access Level: Read

        https://docs.aws.amazon.com/codecommit/latest/APIReference/API_GetMergeOptions.html

        :stability: experimental
        '''
        return typing.cast("Codecommit", jsii.invoke(self, "toGetMergeOptions", []))

    @jsii.member(jsii_name="toGetObjectIdentifier")
    def to_get_object_identifier(self) -> "Codecommit":
        '''(experimental) Grants permission to resolve blobs, trees, and commits to their identifier.

        Access Level: Read

        https://docs.aws.amazon.com/codecommit/latest/userguide/auth-and-access-control-permissions-reference.html#aa-code

        :stability: experimental
        '''
        return typing.cast("Codecommit", jsii.invoke(self, "toGetObjectIdentifier", []))

    @jsii.member(jsii_name="toGetPullRequest")
    def to_get_pull_request(self) -> "Codecommit":
        '''(experimental) Grants permission to get information about a pull request in a specified repository.

        Access Level: Read

        https://docs.aws.amazon.com/codecommit/latest/APIReference/API_GetPullRequest.html

        :stability: experimental
        '''
        return typing.cast("Codecommit", jsii.invoke(self, "toGetPullRequest", []))

    @jsii.member(jsii_name="toGetPullRequestApprovalStates")
    def to_get_pull_request_approval_states(self) -> "Codecommit":
        '''(experimental) Grants permission to retrieve the current approvals on an inputted pull request.

        Access Level: Read

        https://docs.aws.amazon.com/codecommit/latest/APIReference/API_GetPullRequestApprovalStates.html

        :stability: experimental
        '''
        return typing.cast("Codecommit", jsii.invoke(self, "toGetPullRequestApprovalStates", []))

    @jsii.member(jsii_name="toGetPullRequestOverrideState")
    def to_get_pull_request_override_state(self) -> "Codecommit":
        '''(experimental) Grants permission to retrieve the current override state of a given pull request.

        Access Level: Read

        https://docs.aws.amazon.com/codecommit/latest/APIReference/API_GetPullRequestOverrideState.html

        :stability: experimental
        '''
        return typing.cast("Codecommit", jsii.invoke(self, "toGetPullRequestOverrideState", []))

    @jsii.member(jsii_name="toGetReferences")
    def to_get_references(self) -> "Codecommit":
        '''(experimental) Grants permission to get details about references in an AWS CodeCommit repository; does not control Git reference actions.

        Access Level: Read

        https://docs.aws.amazon.com/codecommit/latest/userguide/auth-and-access-control-permissions-reference.html#aa-code

        :stability: experimental
        '''
        return typing.cast("Codecommit", jsii.invoke(self, "toGetReferences", []))

    @jsii.member(jsii_name="toGetRepository")
    def to_get_repository(self) -> "Codecommit":
        '''(experimental) Grants permission to get information about an AWS CodeCommit repository.

        Access Level: Read

        https://docs.aws.amazon.com/codecommit/latest/APIReference/API_GetRepository.html

        :stability: experimental
        '''
        return typing.cast("Codecommit", jsii.invoke(self, "toGetRepository", []))

    @jsii.member(jsii_name="toGetRepositoryTriggers")
    def to_get_repository_triggers(self) -> "Codecommit":
        '''(experimental) Grants permission to get information about triggers configured for a repository.

        Access Level: Read

        https://docs.aws.amazon.com/codecommit/latest/APIReference/API_GetRepositoryTriggers.html

        :stability: experimental
        '''
        return typing.cast("Codecommit", jsii.invoke(self, "toGetRepositoryTriggers", []))

    @jsii.member(jsii_name="toGetTree")
    def to_get_tree(self) -> "Codecommit":
        '''(experimental) Grants permission to view the contents of a specified tree in an AWS CodeCommit repository from the AWS CodeCommit console.

        Access Level: Read

        https://docs.aws.amazon.com/codecommit/latest/userguide/auth-and-access-control-permissions-reference.html#aa-code

        :stability: experimental
        '''
        return typing.cast("Codecommit", jsii.invoke(self, "toGetTree", []))

    @jsii.member(jsii_name="toGetUploadArchiveStatus")
    def to_get_upload_archive_status(self) -> "Codecommit":
        '''(experimental) Grants permission to get status information about an archive upload to a pipeline in AWS CodePipeline.

        Access Level: Read

        https://docs.aws.amazon.com/codecommit/latest/userguide/auth-and-access-control-permissions-reference.html#aa-acp

        :stability: experimental
        '''
        return typing.cast("Codecommit", jsii.invoke(self, "toGetUploadArchiveStatus", []))

    @jsii.member(jsii_name="toGitPull")
    def to_git_pull(self) -> "Codecommit":
        '''(experimental) Grants permission to pull information from an AWS CodeCommit repository to a local repo.

        Access Level: Read

        https://docs.aws.amazon.com/codecommit/latest/userguide/auth-and-access-control-permissions-reference.html#aa-git

        :stability: experimental
        '''
        return typing.cast("Codecommit", jsii.invoke(self, "toGitPull", []))

    @jsii.member(jsii_name="toGitPush")
    def to_git_push(self) -> "Codecommit":
        '''(experimental) Grants permission to push information from a local repo to an AWS CodeCommit repository.

        Access Level: Write

        Possible conditions:

        - .ifReferences()

        https://docs.aws.amazon.com/codecommit/latest/userguide/auth-and-access-control-permissions-reference.html#aa-git

        :stability: experimental
        '''
        return typing.cast("Codecommit", jsii.invoke(self, "toGitPush", []))

    @jsii.member(jsii_name="toListApprovalRuleTemplates")
    def to_list_approval_rule_templates(self) -> "Codecommit":
        '''(experimental) Grants permission to list all approval rule templates in an AWS Region for the AWS account.

        Access Level: List

        https://docs.aws.amazon.com/codecommit/latest/APIReference/API_ListApprovalRuleTemplates.html

        :stability: experimental
        '''
        return typing.cast("Codecommit", jsii.invoke(self, "toListApprovalRuleTemplates", []))

    @jsii.member(jsii_name="toListAssociatedApprovalRuleTemplatesForRepository")
    def to_list_associated_approval_rule_templates_for_repository(self) -> "Codecommit":
        '''(experimental) Grants permission to list approval rule templates that are associated with a repository.

        Access Level: List

        https://docs.aws.amazon.com/codecommit/latest/APIReference/API_ListAssociatedApprovalRuleTemplatesForRepository.html

        :stability: experimental
        '''
        return typing.cast("Codecommit", jsii.invoke(self, "toListAssociatedApprovalRuleTemplatesForRepository", []))

    @jsii.member(jsii_name="toListBranches")
    def to_list_branches(self) -> "Codecommit":
        '''(experimental) Grants permission to list branches for an AWS CodeCommit repository with this API; does not control Git branch actions.

        Access Level: List

        https://docs.aws.amazon.com/codecommit/latest/APIReference/API_ListBranches.html

        :stability: experimental
        '''
        return typing.cast("Codecommit", jsii.invoke(self, "toListBranches", []))

    @jsii.member(jsii_name="toListPullRequests")
    def to_list_pull_requests(self) -> "Codecommit":
        '''(experimental) Grants permission to list pull requests for a specified repository.

        Access Level: List

        https://docs.aws.amazon.com/codecommit/latest/APIReference/API_ListPullRequests.html

        :stability: experimental
        '''
        return typing.cast("Codecommit", jsii.invoke(self, "toListPullRequests", []))

    @jsii.member(jsii_name="toListRepositories")
    def to_list_repositories(self) -> "Codecommit":
        '''(experimental) Grants permission to list information about AWS CodeCommit repositories in the current Region for your AWS account.

        Access Level: List

        https://docs.aws.amazon.com/codecommit/latest/APIReference/API_ListRepositories.html

        :stability: experimental
        '''
        return typing.cast("Codecommit", jsii.invoke(self, "toListRepositories", []))

    @jsii.member(jsii_name="toListRepositoriesForApprovalRuleTemplate")
    def to_list_repositories_for_approval_rule_template(self) -> "Codecommit":
        '''(experimental) Grants permission to list repositories that are associated with an approval rule template.

        Access Level: List

        https://docs.aws.amazon.com/codecommit/latest/APIReference/API_ListRepositoriesForApprovalRuleTemplate.html

        :stability: experimental
        '''
        return typing.cast("Codecommit", jsii.invoke(self, "toListRepositoriesForApprovalRuleTemplate", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Codecommit":
        '''(experimental) Grants permission to list the resource attached to a CodeCommit resource ARN.

        Access Level: List

        https://docs.aws.amazon.com/codecommit/latest/APIReference/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("Codecommit", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toMergeBranchesByFastForward")
    def to_merge_branches_by_fast_forward(self) -> "Codecommit":
        '''(experimental) Grants permission to merge two commits into the specified destination branch using the fast-forward merge option.

        Access Level: Write

        Possible conditions:

        - .ifReferences()

        https://docs.aws.amazon.com/codecommit/latest/APIReference/API_MergeBranchesByFastForward.html

        :stability: experimental
        '''
        return typing.cast("Codecommit", jsii.invoke(self, "toMergeBranchesByFastForward", []))

    @jsii.member(jsii_name="toMergeBranchesBySquash")
    def to_merge_branches_by_squash(self) -> "Codecommit":
        '''(experimental) Grants permission to merge two commits into the specified destination branch using the squash merge option.

        Access Level: Write

        Possible conditions:

        - .ifReferences()

        https://docs.aws.amazon.com/codecommit/latest/APIReference/API_MergeBranchesBySquash.html

        :stability: experimental
        '''
        return typing.cast("Codecommit", jsii.invoke(self, "toMergeBranchesBySquash", []))

    @jsii.member(jsii_name="toMergeBranchesByThreeWay")
    def to_merge_branches_by_three_way(self) -> "Codecommit":
        '''(experimental) Grants permission to merge two commits into the specified destination branch using the three-way merge option.

        Access Level: Write

        Possible conditions:

        - .ifReferences()

        https://docs.aws.amazon.com/codecommit/latest/APIReference/API_MergeBranchesByThreeWay.html

        :stability: experimental
        '''
        return typing.cast("Codecommit", jsii.invoke(self, "toMergeBranchesByThreeWay", []))

    @jsii.member(jsii_name="toMergePullRequestByFastForward")
    def to_merge_pull_request_by_fast_forward(self) -> "Codecommit":
        '''(experimental) Grants permission to close a pull request and attempt to merge it into the specified destination branch for that pull request at the specified commit using the fast-forward merge option.

        Access Level: Write

        Possible conditions:

        - .ifReferences()

        https://docs.aws.amazon.com/codecommit/latest/APIReference/API_MergePullRequestByFastForward.html

        :stability: experimental
        '''
        return typing.cast("Codecommit", jsii.invoke(self, "toMergePullRequestByFastForward", []))

    @jsii.member(jsii_name="toMergePullRequestBySquash")
    def to_merge_pull_request_by_squash(self) -> "Codecommit":
        '''(experimental) Grants permission to close a pull request and attempt to merge it into the specified destination branch for that pull request at the specified commit using the squash merge option.

        Access Level: Write

        Possible conditions:

        - .ifReferences()

        https://docs.aws.amazon.com/codecommit/latest/APIReference/API_MergePullRequestBySquash.html

        :stability: experimental
        '''
        return typing.cast("Codecommit", jsii.invoke(self, "toMergePullRequestBySquash", []))

    @jsii.member(jsii_name="toMergePullRequestByThreeWay")
    def to_merge_pull_request_by_three_way(self) -> "Codecommit":
        '''(experimental) Grants permission to close a pull request and attempt to merge it into the specified destination branch for that pull request at the specified commit using the three-way merge option.

        Access Level: Write

        Possible conditions:

        - .ifReferences()

        https://docs.aws.amazon.com/codecommit/latest/APIReference/API_MergePullRequestByThreeWay.html

        :stability: experimental
        '''
        return typing.cast("Codecommit", jsii.invoke(self, "toMergePullRequestByThreeWay", []))

    @jsii.member(jsii_name="toOverridePullRequestApprovalRules")
    def to_override_pull_request_approval_rules(self) -> "Codecommit":
        '''(experimental) Grants permission to override all approval rules for a pull request, including approval rules created by a template.

        Access Level: Write

        https://docs.aws.amazon.com/codecommit/latest/APIReference/API_OverridePullRequestApprovalRules.html

        :stability: experimental
        '''
        return typing.cast("Codecommit", jsii.invoke(self, "toOverridePullRequestApprovalRules", []))

    @jsii.member(jsii_name="toPostCommentForComparedCommit")
    def to_post_comment_for_compared_commit(self) -> "Codecommit":
        '''(experimental) Grants permission to post a comment on the comparison between two commits.

        Access Level: Write

        https://docs.aws.amazon.com/codecommit/latest/APIReference/API_PostCommentForComparedCommit.html

        :stability: experimental
        '''
        return typing.cast("Codecommit", jsii.invoke(self, "toPostCommentForComparedCommit", []))

    @jsii.member(jsii_name="toPostCommentForPullRequest")
    def to_post_comment_for_pull_request(self) -> "Codecommit":
        '''(experimental) Grants permission to post a comment on a pull request.

        Access Level: Write

        https://docs.aws.amazon.com/codecommit/latest/APIReference/API_PostCommentForPullRequest.html

        :stability: experimental
        '''
        return typing.cast("Codecommit", jsii.invoke(self, "toPostCommentForPullRequest", []))

    @jsii.member(jsii_name="toPostCommentReply")
    def to_post_comment_reply(self) -> "Codecommit":
        '''(experimental) Grants permission to post a comment in reply to a comment on a comparison between commits or a pull request.

        Access Level: Write

        https://docs.aws.amazon.com/codecommit/latest/APIReference/API_PostCommentReply.html

        :stability: experimental
        '''
        return typing.cast("Codecommit", jsii.invoke(self, "toPostCommentReply", []))

    @jsii.member(jsii_name="toPutCommentReaction")
    def to_put_comment_reaction(self) -> "Codecommit":
        '''(experimental) Grants permission to post a reaction on a comment.

        Access Level: Write

        https://docs.aws.amazon.com/codecommit/latest/APIReference/API_PutCommentReaction.html

        :stability: experimental
        '''
        return typing.cast("Codecommit", jsii.invoke(self, "toPutCommentReaction", []))

    @jsii.member(jsii_name="toPutFile")
    def to_put_file(self) -> "Codecommit":
        '''(experimental) Grants permission to add or update a file in a branch in an AWS CodeCommit repository, and generate a commit for the addition in the specified branch.

        Access Level: Write

        Possible conditions:

        - .ifReferences()

        https://docs.aws.amazon.com/codecommit/latest/APIReference/API_PutFile.html

        :stability: experimental
        '''
        return typing.cast("Codecommit", jsii.invoke(self, "toPutFile", []))

    @jsii.member(jsii_name="toPutRepositoryTriggers")
    def to_put_repository_triggers(self) -> "Codecommit":
        '''(experimental) Grants permission to create, update, or delete triggers for a repository.

        Access Level: Write

        https://docs.aws.amazon.com/codecommit/latest/APIReference/API_PutRepositoryTriggers.html

        :stability: experimental
        '''
        return typing.cast("Codecommit", jsii.invoke(self, "toPutRepositoryTriggers", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Codecommit":
        '''(experimental) Grants permission to attach resource tags to a CodeCommit resource ARN.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsResourceTag()
        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/codecommit/latest/APIReference/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("Codecommit", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toTestRepositoryTriggers")
    def to_test_repository_triggers(self) -> "Codecommit":
        '''(experimental) Grants permission to test the functionality of repository triggers by sending information to the trigger target.

        Access Level: Write

        https://docs.aws.amazon.com/codecommit/latest/APIReference/API_TestRepositoryTriggers.html

        :stability: experimental
        '''
        return typing.cast("Codecommit", jsii.invoke(self, "toTestRepositoryTriggers", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Codecommit":
        '''(experimental) Grants permission to disassociate resource tags from a CodeCommit resource ARN.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/codecommit/latest/APIReference/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("Codecommit", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateApprovalRuleTemplateContent")
    def to_update_approval_rule_template_content(self) -> "Codecommit":
        '''(experimental) Grants permission to update the content of approval rule templates;

        does not grant permission to update content of approval rules created specifically for pull requests

        Access Level: Write

        https://docs.aws.amazon.com/codecommit/latest/APIReference/API_UpdateApprovalRuleTemplateContent.html

        :stability: experimental
        '''
        return typing.cast("Codecommit", jsii.invoke(self, "toUpdateApprovalRuleTemplateContent", []))

    @jsii.member(jsii_name="toUpdateApprovalRuleTemplateDescription")
    def to_update_approval_rule_template_description(self) -> "Codecommit":
        '''(experimental) Grants permission to update the description of approval rule templates.

        Access Level: Write

        https://docs.aws.amazon.com/codecommit/latest/APIReference/API_UpdateApprovalRuleTemplateDescription.html

        :stability: experimental
        '''
        return typing.cast("Codecommit", jsii.invoke(self, "toUpdateApprovalRuleTemplateDescription", []))

    @jsii.member(jsii_name="toUpdateApprovalRuleTemplateName")
    def to_update_approval_rule_template_name(self) -> "Codecommit":
        '''(experimental) Grants permission to update the name of approval rule templates.

        Access Level: Write

        https://docs.aws.amazon.com/codecommit/latest/APIReference/API_UpdateApprovalRuleTemplateName.html

        :stability: experimental
        '''
        return typing.cast("Codecommit", jsii.invoke(self, "toUpdateApprovalRuleTemplateName", []))

    @jsii.member(jsii_name="toUpdateComment")
    def to_update_comment(self) -> "Codecommit":
        '''(experimental) Grants permission to update the contents of a comment if the identity matches the identity used to create the comment.

        Access Level: Write

        https://docs.aws.amazon.com/codecommit/latest/APIReference/API_UpdateComment.html

        :stability: experimental
        '''
        return typing.cast("Codecommit", jsii.invoke(self, "toUpdateComment", []))

    @jsii.member(jsii_name="toUpdateDefaultBranch")
    def to_update_default_branch(self) -> "Codecommit":
        '''(experimental) Grants permission to change the default branch in an AWS CodeCommit repository.

        Access Level: Write

        https://docs.aws.amazon.com/codecommit/latest/APIReference/API_UpdateDefaultBranch.html

        :stability: experimental
        '''
        return typing.cast("Codecommit", jsii.invoke(self, "toUpdateDefaultBranch", []))

    @jsii.member(jsii_name="toUpdatePullRequestApprovalRuleContent")
    def to_update_pull_request_approval_rule_content(self) -> "Codecommit":
        '''(experimental) Grants permission to update the content for approval rules created for a specific pull requests;

        does not grant permission to update approval rule content for rules created with an approval rule template

        Access Level: Write

        https://docs.aws.amazon.com/codecommit/latest/APIReference/API_UpdatePullRequestApprovalRuleContent.html

        :stability: experimental
        '''
        return typing.cast("Codecommit", jsii.invoke(self, "toUpdatePullRequestApprovalRuleContent", []))

    @jsii.member(jsii_name="toUpdatePullRequestApprovalState")
    def to_update_pull_request_approval_state(self) -> "Codecommit":
        '''(experimental) Grants permission to update the approval state for pull requests.

        Access Level: Write

        https://docs.aws.amazon.com/codecommit/latest/APIReference/API_UpdatePullRequestApprovalState.html

        :stability: experimental
        '''
        return typing.cast("Codecommit", jsii.invoke(self, "toUpdatePullRequestApprovalState", []))

    @jsii.member(jsii_name="toUpdatePullRequestDescription")
    def to_update_pull_request_description(self) -> "Codecommit":
        '''(experimental) Grants permission to update the description of a pull request.

        Access Level: Write

        https://docs.aws.amazon.com/codecommit/latest/APIReference/API_UpdatePullRequestDescription.html

        :stability: experimental
        '''
        return typing.cast("Codecommit", jsii.invoke(self, "toUpdatePullRequestDescription", []))

    @jsii.member(jsii_name="toUpdatePullRequestStatus")
    def to_update_pull_request_status(self) -> "Codecommit":
        '''(experimental) Grants permission to update the status of a pull request.

        Access Level: Write

        https://docs.aws.amazon.com/codecommit/latest/APIReference/API_UpdatePullRequestStatus.html

        :stability: experimental
        '''
        return typing.cast("Codecommit", jsii.invoke(self, "toUpdatePullRequestStatus", []))

    @jsii.member(jsii_name="toUpdatePullRequestTitle")
    def to_update_pull_request_title(self) -> "Codecommit":
        '''(experimental) Grants permission to update the title of a pull request.

        Access Level: Write

        https://docs.aws.amazon.com/codecommit/latest/APIReference/API_UpdatePullRequestTitle.html

        :stability: experimental
        '''
        return typing.cast("Codecommit", jsii.invoke(self, "toUpdatePullRequestTitle", []))

    @jsii.member(jsii_name="toUpdateRepositoryDescription")
    def to_update_repository_description(self) -> "Codecommit":
        '''(experimental) Grants permission to change the description of an AWS CodeCommit repository.

        Access Level: Write

        https://docs.aws.amazon.com/codecommit/latest/APIReference/API_UpdateRepositoryDescription.html

        :stability: experimental
        '''
        return typing.cast("Codecommit", jsii.invoke(self, "toUpdateRepositoryDescription", []))

    @jsii.member(jsii_name="toUpdateRepositoryName")
    def to_update_repository_name(self) -> "Codecommit":
        '''(experimental) Grants permission to change the name of an AWS CodeCommit repository.

        Access Level: Write

        https://docs.aws.amazon.com/codecommit/latest/APIReference/API_UpdateRepositoryName.html

        :stability: experimental
        '''
        return typing.cast("Codecommit", jsii.invoke(self, "toUpdateRepositoryName", []))

    @jsii.member(jsii_name="toUploadArchive")
    def to_upload_archive(self) -> "Codecommit":
        '''(experimental) Grants permission to the service role for AWS CodePipeline to upload repository changes into a pipeline.

        Access Level: Write

        https://docs.aws.amazon.com/codecommit/latest/userguide/auth-and-access-control-permissions-reference.html#aa-acp

        :stability: experimental
        '''
        return typing.cast("Codecommit", jsii.invoke(self, "toUploadArchive", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__69a901675f5f1bf9fe9a9cb6114c10df4fd9144526b1a1a5c5ee10d778e210a7)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ff039d4660d3a014930db7a0aabce9b830ec23aba94ab7995334a79b272aafb9)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Codedeploy(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Codedeploy",
):
    '''(experimental) Statement provider for service `codedeploy <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awscodedeploy.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `codedeploy <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awscodedeploy.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onApplication")
    def on_application(
        self,
        application_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Codedeploy":
        '''(experimental) Adds a resource of type application to the statement.

        https://docs.aws.amazon.com/codedeploy/latest/userguide/auth-and-access-control-permissions-reference.html

        :param application_name: - Identifier for the applicationName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__438f46fc8f863a04359afe8fc30fec91a0a314b73ad471aa54a358a5ec401dd2)
            check_type(argname="argument application_name", value=application_name, expected_type=type_hints["application_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Codedeploy", jsii.invoke(self, "onApplication", [application_name, account, region, partition]))

    @jsii.member(jsii_name="onDeploymentconfig")
    def on_deploymentconfig(
        self,
        deployment_configuration_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Codedeploy":
        '''(experimental) Adds a resource of type deploymentconfig to the statement.

        https://docs.aws.amazon.com/codedeploy/latest/userguide/auth-and-access-control-permissions-reference.html

        :param deployment_configuration_name: - Identifier for the deploymentConfigurationName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a08db0be98fbcb0d8c08d87bac1ac398b63986ddad3ee8a47ff88efa7e1b8066)
            check_type(argname="argument deployment_configuration_name", value=deployment_configuration_name, expected_type=type_hints["deployment_configuration_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Codedeploy", jsii.invoke(self, "onDeploymentconfig", [deployment_configuration_name, account, region, partition]))

    @jsii.member(jsii_name="onDeploymentgroup")
    def on_deploymentgroup(
        self,
        application_name: builtins.str,
        deployment_group_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Codedeploy":
        '''(experimental) Adds a resource of type deploymentgroup to the statement.

        https://docs.aws.amazon.com/codedeploy/latest/userguide/auth-and-access-control-permissions-reference.html

        :param application_name: - Identifier for the applicationName.
        :param deployment_group_name: - Identifier for the deploymentGroupName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5ee41f7b649527a04171be1f7a3885f83468fecfe511c8702600b8440b2ab78c)
            check_type(argname="argument application_name", value=application_name, expected_type=type_hints["application_name"])
            check_type(argname="argument deployment_group_name", value=deployment_group_name, expected_type=type_hints["deployment_group_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Codedeploy", jsii.invoke(self, "onDeploymentgroup", [application_name, deployment_group_name, account, region, partition]))

    @jsii.member(jsii_name="onInstance")
    def on_instance(
        self,
        instance_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Codedeploy":
        '''(experimental) Adds a resource of type instance to the statement.

        https://docs.aws.amazon.com/codedeploy/latest/userguide/auth-and-access-control-permissions-reference.html

        :param instance_name: - Identifier for the instanceName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__cc5e0e96a490141b0ae3e803bbd98bfe69cfebb49c7ab1d09e7d3ed3f7508bee)
            check_type(argname="argument instance_name", value=instance_name, expected_type=type_hints["instance_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Codedeploy", jsii.invoke(self, "onInstance", [instance_name, account, region, partition]))

    @jsii.member(jsii_name="toAddTagsToOnPremisesInstances")
    def to_add_tags_to_on_premises_instances(self) -> "Codedeploy":
        '''(experimental) Grants permission to add tags to one or more on-premises instances.

        Access Level: Tagging

        https://docs.aws.amazon.com/codedeploy/latest/APIReference/API_AddTagsToOnPremisesInstances.html

        :stability: experimental
        '''
        return typing.cast("Codedeploy", jsii.invoke(self, "toAddTagsToOnPremisesInstances", []))

    @jsii.member(jsii_name="toBatchGetApplicationRevisions")
    def to_batch_get_application_revisions(self) -> "Codedeploy":
        '''(experimental) Grants permission to get information about one or more application revisions.

        Access Level: Read

        https://docs.aws.amazon.com/codedeploy/latest/APIReference/API_BatchGetApplicationRevisions.html

        :stability: experimental
        '''
        return typing.cast("Codedeploy", jsii.invoke(self, "toBatchGetApplicationRevisions", []))

    @jsii.member(jsii_name="toBatchGetApplications")
    def to_batch_get_applications(self) -> "Codedeploy":
        '''(experimental) Grants permission to get information about multiple applications associated with the IAM user.

        Access Level: Read

        https://docs.aws.amazon.com/codedeploy/latest/APIReference/API_BatchGetApplications.html

        :stability: experimental
        '''
        return typing.cast("Codedeploy", jsii.invoke(self, "toBatchGetApplications", []))

    @jsii.member(jsii_name="toBatchGetDeploymentGroups")
    def to_batch_get_deployment_groups(self) -> "Codedeploy":
        '''(experimental) Grants permission to get information about one or more deployment groups.

        Access Level: Read

        https://docs.aws.amazon.com/codedeploy/latest/APIReference/API_BatchGetDeploymentGroups.html

        :stability: experimental
        '''
        return typing.cast("Codedeploy", jsii.invoke(self, "toBatchGetDeploymentGroups", []))

    @jsii.member(jsii_name="toBatchGetDeploymentInstances")
    def to_batch_get_deployment_instances(self) -> "Codedeploy":
        '''(experimental) Grants permission to get information about one or more instance that are part of a deployment group.

        Access Level: Read

        https://docs.aws.amazon.com/codedeploy/latest/APIReference/API_BatchGetDeploymentInstances.html

        :stability: experimental
        '''
        return typing.cast("Codedeploy", jsii.invoke(self, "toBatchGetDeploymentInstances", []))

    @jsii.member(jsii_name="toBatchGetDeployments")
    def to_batch_get_deployments(self) -> "Codedeploy":
        '''(experimental) Grants permission to get information about multiple deployments associated with the IAM user.

        Access Level: Read

        https://docs.aws.amazon.com/codedeploy/latest/APIReference/API_BatchGetDeployments.html

        :stability: experimental
        '''
        return typing.cast("Codedeploy", jsii.invoke(self, "toBatchGetDeployments", []))

    @jsii.member(jsii_name="toBatchGetDeploymentTargets")
    def to_batch_get_deployment_targets(self) -> "Codedeploy":
        '''(experimental) Grants permission to return an array of one or more targets associated with a deployment.

        This method works with all compute types and should be used instead of the deprecated BatchGetDeploymentInstances. The maximum number of targets that can be returned is 25

        Access Level: Read

        https://docs.aws.amazon.com/codedeploy/latest/APIReference/API_BatchGetDeploymentTargets.html

        :stability: experimental
        '''
        return typing.cast("Codedeploy", jsii.invoke(self, "toBatchGetDeploymentTargets", []))

    @jsii.member(jsii_name="toBatchGetOnPremisesInstances")
    def to_batch_get_on_premises_instances(self) -> "Codedeploy":
        '''(experimental) Grants permission to get information about one or more on-premises instances.

        Access Level: Read

        https://docs.aws.amazon.com/codedeploy/latest/APIReference/API_BatchGetOnPremisesInstances.html

        :stability: experimental
        '''
        return typing.cast("Codedeploy", jsii.invoke(self, "toBatchGetOnPremisesInstances", []))

    @jsii.member(jsii_name="toContinueDeployment")
    def to_continue_deployment(self) -> "Codedeploy":
        '''(experimental) Grants permission to start the process of rerouting traffic from instances in the original environment to instances in thereplacement environment without waiting for a specified wait time to elapse.

        Access Level: Write

        https://docs.aws.amazon.com/codedeploy/latest/APIReference/API_ContinueDeployment.html

        :stability: experimental
        '''
        return typing.cast("Codedeploy", jsii.invoke(self, "toContinueDeployment", []))

    @jsii.member(jsii_name="toCreateApplication")
    def to_create_application(self) -> "Codedeploy":
        '''(experimental) Grants permission to create an application associated with the IAM user.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/codedeploy/latest/APIReference/API_CreateApplication.html

        :stability: experimental
        '''
        return typing.cast("Codedeploy", jsii.invoke(self, "toCreateApplication", []))

    @jsii.member(jsii_name="toCreateCloudFormationDeployment")
    def to_create_cloud_formation_deployment(self) -> "Codedeploy":
        '''(experimental) Grants permission to create CloudFormation deployment to cooperate ochestration for a CloudFormation stack update.

        Access Level: Write

        :stability: experimental
        '''
        return typing.cast("Codedeploy", jsii.invoke(self, "toCreateCloudFormationDeployment", []))

    @jsii.member(jsii_name="toCreateDeployment")
    def to_create_deployment(self) -> "Codedeploy":
        '''(experimental) Grants permission to create a deployment for an application associated with the IAM user.

        Access Level: Write

        https://docs.aws.amazon.com/codedeploy/latest/APIReference/API_CreateDeployment.html

        :stability: experimental
        '''
        return typing.cast("Codedeploy", jsii.invoke(self, "toCreateDeployment", []))

    @jsii.member(jsii_name="toCreateDeploymentConfig")
    def to_create_deployment_config(self) -> "Codedeploy":
        '''(experimental) Grants permission to create a custom deployment configuration associated with the IAM user.

        Access Level: Write

        https://docs.aws.amazon.com/codedeploy/latest/APIReference/API_CreateDeploymentConfig.html

        :stability: experimental
        '''
        return typing.cast("Codedeploy", jsii.invoke(self, "toCreateDeploymentConfig", []))

    @jsii.member(jsii_name="toCreateDeploymentGroup")
    def to_create_deployment_group(self) -> "Codedeploy":
        '''(experimental) Grants permission to create a deployment group for an application associated with the IAM user.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/codedeploy/latest/APIReference/API_CreateDeploymentGroup.html

        :stability: experimental
        '''
        return typing.cast("Codedeploy", jsii.invoke(self, "toCreateDeploymentGroup", []))

    @jsii.member(jsii_name="toDeleteApplication")
    def to_delete_application(self) -> "Codedeploy":
        '''(experimental) Grants permission to delete an application associated with the IAM user.

        Access Level: Write

        https://docs.aws.amazon.com/codedeploy/latest/APIReference/API_DeleteApplication.html

        :stability: experimental
        '''
        return typing.cast("Codedeploy", jsii.invoke(self, "toDeleteApplication", []))

    @jsii.member(jsii_name="toDeleteDeploymentConfig")
    def to_delete_deployment_config(self) -> "Codedeploy":
        '''(experimental) Grants permission to delete a custom deployment configuration associated with the IAM user.

        Access Level: Write

        https://docs.aws.amazon.com/codedeploy/latest/APIReference/API_DeleteDeploymentConfig.html

        :stability: experimental
        '''
        return typing.cast("Codedeploy", jsii.invoke(self, "toDeleteDeploymentConfig", []))

    @jsii.member(jsii_name="toDeleteDeploymentGroup")
    def to_delete_deployment_group(self) -> "Codedeploy":
        '''(experimental) Grants permission to delete a deployment group for an application associated with the IAM user.

        Access Level: Write

        https://docs.aws.amazon.com/codedeploy/latest/APIReference/API_DeleteDeploymentGroup.html

        :stability: experimental
        '''
        return typing.cast("Codedeploy", jsii.invoke(self, "toDeleteDeploymentGroup", []))

    @jsii.member(jsii_name="toDeleteGitHubAccountToken")
    def to_delete_git_hub_account_token(self) -> "Codedeploy":
        '''(experimental) Grants permission to delete a GitHub account connection.

        Access Level: Write

        https://docs.aws.amazon.com/codedeploy/latest/APIReference/API_DeleteGitHubAccountToken.html

        :stability: experimental
        '''
        return typing.cast("Codedeploy", jsii.invoke(self, "toDeleteGitHubAccountToken", []))

    @jsii.member(jsii_name="toDeleteResourcesByExternalId")
    def to_delete_resources_by_external_id(self) -> "Codedeploy":
        '''(experimental) Grants permission to delete resources associated with the given external Id.

        Access Level: Write

        https://docs.aws.amazon.com/codedeploy/latest/APIReference/API_DeleteResourcesByExternalId.html

        :stability: experimental
        '''
        return typing.cast("Codedeploy", jsii.invoke(self, "toDeleteResourcesByExternalId", []))

    @jsii.member(jsii_name="toDeregisterOnPremisesInstance")
    def to_deregister_on_premises_instance(self) -> "Codedeploy":
        '''(experimental) Grants permission to deregister an on-premises instance.

        Access Level: Write

        https://docs.aws.amazon.com/codedeploy/latest/APIReference/API_DeregisterOnPremisesInstance.html

        :stability: experimental
        '''
        return typing.cast("Codedeploy", jsii.invoke(self, "toDeregisterOnPremisesInstance", []))

    @jsii.member(jsii_name="toGetApplication")
    def to_get_application(self) -> "Codedeploy":
        '''(experimental) Grants permission to get information about a single application associated with the IAM user.

        Access Level: List

        https://docs.aws.amazon.com/codedeploy/latest/APIReference/API_GetApplication.html

        :stability: experimental
        '''
        return typing.cast("Codedeploy", jsii.invoke(self, "toGetApplication", []))

    @jsii.member(jsii_name="toGetApplicationRevision")
    def to_get_application_revision(self) -> "Codedeploy":
        '''(experimental) Grants permission to get information about a single application revision for an application associated with the IAM user.

        Access Level: List

        https://docs.aws.amazon.com/codedeploy/latest/APIReference/API_GetApplicationRevision.html

        :stability: experimental
        '''
        return typing.cast("Codedeploy", jsii.invoke(self, "toGetApplicationRevision", []))

    @jsii.member(jsii_name="toGetDeployment")
    def to_get_deployment(self) -> "Codedeploy":
        '''(experimental) Grants permission to get information about a single deployment to a deployment group for an application associated with the IAM user.

        Access Level: List

        https://docs.aws.amazon.com/codedeploy/latest/APIReference/API_GetDeployment.html

        :stability: experimental
        '''
        return typing.cast("Codedeploy", jsii.invoke(self, "toGetDeployment", []))

    @jsii.member(jsii_name="toGetDeploymentConfig")
    def to_get_deployment_config(self) -> "Codedeploy":
        '''(experimental) Grants permission to get information about a single deployment configuration associated with the IAM user.

        Access Level: List

        https://docs.aws.amazon.com/codedeploy/latest/APIReference/API_GetDeploymentConfig.html

        :stability: experimental
        '''
        return typing.cast("Codedeploy", jsii.invoke(self, "toGetDeploymentConfig", []))

    @jsii.member(jsii_name="toGetDeploymentGroup")
    def to_get_deployment_group(self) -> "Codedeploy":
        '''(experimental) Grants permission to get information about a single deployment group for an application associated with the IAM user.

        Access Level: List

        https://docs.aws.amazon.com/codedeploy/latest/APIReference/API_GetDeploymentGroup.html

        :stability: experimental
        '''
        return typing.cast("Codedeploy", jsii.invoke(self, "toGetDeploymentGroup", []))

    @jsii.member(jsii_name="toGetDeploymentInstance")
    def to_get_deployment_instance(self) -> "Codedeploy":
        '''(experimental) Grants permission to get information about a single instance in a deployment associated with the IAM user.

        Access Level: List

        https://docs.aws.amazon.com/codedeploy/latest/APIReference/API_GetDeploymentInstance.html

        :stability: experimental
        '''
        return typing.cast("Codedeploy", jsii.invoke(self, "toGetDeploymentInstance", []))

    @jsii.member(jsii_name="toGetDeploymentTarget")
    def to_get_deployment_target(self) -> "Codedeploy":
        '''(experimental) Grants permission to return information about a deployment target.

        Access Level: Read

        https://docs.aws.amazon.com/codedeploy/latest/APIReference/API_GetDeploymentTarget.html

        :stability: experimental
        '''
        return typing.cast("Codedeploy", jsii.invoke(self, "toGetDeploymentTarget", []))

    @jsii.member(jsii_name="toGetOnPremisesInstance")
    def to_get_on_premises_instance(self) -> "Codedeploy":
        '''(experimental) Grants permission to get information about a single on-premises instance.

        Access Level: List

        https://docs.aws.amazon.com/codedeploy/latest/APIReference/API_GetOnPremisesInstance.html

        :stability: experimental
        '''
        return typing.cast("Codedeploy", jsii.invoke(self, "toGetOnPremisesInstance", []))

    @jsii.member(jsii_name="toListApplicationRevisions")
    def to_list_application_revisions(self) -> "Codedeploy":
        '''(experimental) Grants permission to get information about all application revisions for an application associated with the IAM user.

        Access Level: List

        https://docs.aws.amazon.com/codedeploy/latest/APIReference/API_ListApplicationRevisions.html

        :stability: experimental
        '''
        return typing.cast("Codedeploy", jsii.invoke(self, "toListApplicationRevisions", []))

    @jsii.member(jsii_name="toListApplications")
    def to_list_applications(self) -> "Codedeploy":
        '''(experimental) Grants permission to get information about all applications associated with the IAM user.

        Access Level: List

        https://docs.aws.amazon.com/codedeploy/latest/APIReference/API_ListApplications.html

        :stability: experimental
        '''
        return typing.cast("Codedeploy", jsii.invoke(self, "toListApplications", []))

    @jsii.member(jsii_name="toListDeploymentConfigs")
    def to_list_deployment_configs(self) -> "Codedeploy":
        '''(experimental) Grants permission to get information about all deployment configurations associated with the IAM user.

        Access Level: List

        https://docs.aws.amazon.com/codedeploy/latest/APIReference/API_ListDeploymentConfigs.html

        :stability: experimental
        '''
        return typing.cast("Codedeploy", jsii.invoke(self, "toListDeploymentConfigs", []))

    @jsii.member(jsii_name="toListDeploymentGroups")
    def to_list_deployment_groups(self) -> "Codedeploy":
        '''(experimental) Grants permission to get information about all deployment groups for an application associated with the IAM user.

        Access Level: List

        https://docs.aws.amazon.com/codedeploy/latest/APIReference/API_ListDeploymentGroups.html

        :stability: experimental
        '''
        return typing.cast("Codedeploy", jsii.invoke(self, "toListDeploymentGroups", []))

    @jsii.member(jsii_name="toListDeploymentInstances")
    def to_list_deployment_instances(self) -> "Codedeploy":
        '''(experimental) Grants permission to get information about all instances in a deployment associated with the IAM user.

        Access Level: List

        https://docs.aws.amazon.com/codedeploy/latest/APIReference/API_ListDeploymentInstances.html

        :stability: experimental
        '''
        return typing.cast("Codedeploy", jsii.invoke(self, "toListDeploymentInstances", []))

    @jsii.member(jsii_name="toListDeployments")
    def to_list_deployments(self) -> "Codedeploy":
        '''(experimental) Grants permission to get information about all deployments to a deployment group associated with the IAM user, or to get all deployments associated with the IAM user.

        Access Level: List

        https://docs.aws.amazon.com/codedeploy/latest/APIReference/API_ListDeployments.html

        :stability: experimental
        '''
        return typing.cast("Codedeploy", jsii.invoke(self, "toListDeployments", []))

    @jsii.member(jsii_name="toListDeploymentTargets")
    def to_list_deployment_targets(self) -> "Codedeploy":
        '''(experimental) Grants permission to return an array of target IDs that are associated a deployment.

        Access Level: List

        https://docs.aws.amazon.com/codedeploy/latest/APIReference/API_ListDeploymentTargets.html

        :stability: experimental
        '''
        return typing.cast("Codedeploy", jsii.invoke(self, "toListDeploymentTargets", []))

    @jsii.member(jsii_name="toListGitHubAccountTokenNames")
    def to_list_git_hub_account_token_names(self) -> "Codedeploy":
        '''(experimental) Grants permission to list the names of stored connections to GitHub accounts.

        Access Level: List

        https://docs.aws.amazon.com/codedeploy/latest/APIReference/API_ListGitHubAccountTokenNames.html

        :stability: experimental
        '''
        return typing.cast("Codedeploy", jsii.invoke(self, "toListGitHubAccountTokenNames", []))

    @jsii.member(jsii_name="toListOnPremisesInstances")
    def to_list_on_premises_instances(self) -> "Codedeploy":
        '''(experimental) Grants permission to get a list of one or more on-premises instance names.

        Access Level: List

        https://docs.aws.amazon.com/codedeploy/latest/APIReference/API_ListOnPremisesInstances.html

        :stability: experimental
        '''
        return typing.cast("Codedeploy", jsii.invoke(self, "toListOnPremisesInstances", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Codedeploy":
        '''(experimental) Grants permission to return a list of tags for the resource identified by a specified ARN.

        Tags are used to organize and categorize your CodeDeploy resources

        Access Level: List

        https://docs.aws.amazon.com/codedeploy/latest/APIReference/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("Codedeploy", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toPutLifecycleEventHookExecutionStatus")
    def to_put_lifecycle_event_hook_execution_status(self) -> "Codedeploy":
        '''(experimental) Grants permission to notify a lifecycle event hook execution status for associated deployment with the IAM user.

        Access Level: Write

        https://docs.aws.amazon.com/codedeploy/latest/APIReference/API_PutLifecycleEventHookExecutionStatus.html

        :stability: experimental
        '''
        return typing.cast("Codedeploy", jsii.invoke(self, "toPutLifecycleEventHookExecutionStatus", []))

    @jsii.member(jsii_name="toRegisterApplicationRevision")
    def to_register_application_revision(self) -> "Codedeploy":
        '''(experimental) Grants permission to register information about an application revision for an application associated with the IAM user.

        Access Level: Write

        https://docs.aws.amazon.com/codedeploy/latest/APIReference/API_RegisterApplicationRevision.html

        :stability: experimental
        '''
        return typing.cast("Codedeploy", jsii.invoke(self, "toRegisterApplicationRevision", []))

    @jsii.member(jsii_name="toRegisterOnPremisesInstance")
    def to_register_on_premises_instance(self) -> "Codedeploy":
        '''(experimental) Grants permission to register an on-premises instance.

        Access Level: Write

        https://docs.aws.amazon.com/codedeploy/latest/APIReference/API_RegisterOnPremisesInstance.html

        :stability: experimental
        '''
        return typing.cast("Codedeploy", jsii.invoke(self, "toRegisterOnPremisesInstance", []))

    @jsii.member(jsii_name="toRemoveTagsFromOnPremisesInstances")
    def to_remove_tags_from_on_premises_instances(self) -> "Codedeploy":
        '''(experimental) Grants permission to remove tags from one or more on-premises instances.

        Access Level: Tagging

        https://docs.aws.amazon.com/codedeploy/latest/APIReference/API_RemoveTagsFromOnPremisesInstances.html

        :stability: experimental
        '''
        return typing.cast("Codedeploy", jsii.invoke(self, "toRemoveTagsFromOnPremisesInstances", []))

    @jsii.member(jsii_name="toSkipWaitTimeForInstanceTermination")
    def to_skip_wait_time_for_instance_termination(self) -> "Codedeploy":
        '''(experimental) Grants permission to override any specified wait time and starts terminating instances immediately after the traffic routing is complete.

        This action applies to blue-green deployments only

        Access Level: Write

        https://docs.aws.amazon.com/codedeploy/latest/APIReference/API_SkipWaitTimeForInstanceTermination.html

        :stability: experimental
        '''
        return typing.cast("Codedeploy", jsii.invoke(self, "toSkipWaitTimeForInstanceTermination", []))

    @jsii.member(jsii_name="toStopDeployment")
    def to_stop_deployment(self) -> "Codedeploy":
        '''(experimental) Grants permission to stop a deployment.

        Access Level: Write

        https://docs.aws.amazon.com/codedeploy/latest/APIReference/API_StopDeployment.html

        :stability: experimental
        '''
        return typing.cast("Codedeploy", jsii.invoke(self, "toStopDeployment", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Codedeploy":
        '''(experimental) Grants permission to associate the list of tags in the input Tags parameter with the resource identified by the ResourceArn input parameter.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/codedeploy/latest/APIReference/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("Codedeploy", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Codedeploy":
        '''(experimental) Grants permission to disassociate a resource from a list of tags.

        The resource is identified by the ResourceArn input parameter. The tags are identfied by the list of keys in the TagKeys input parameter

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/codedeploy/latest/APIReference/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("Codedeploy", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateApplication")
    def to_update_application(self) -> "Codedeploy":
        '''(experimental) Grants permission to update an application.

        Access Level: Write

        https://docs.aws.amazon.com/codedeploy/latest/APIReference/API_UpdateApplication.html

        :stability: experimental
        '''
        return typing.cast("Codedeploy", jsii.invoke(self, "toUpdateApplication", []))

    @jsii.member(jsii_name="toUpdateDeploymentGroup")
    def to_update_deployment_group(self) -> "Codedeploy":
        '''(experimental) Grants permission to change information about a single deployment group for an application associated with the IAM user.

        Access Level: Write

        https://docs.aws.amazon.com/codedeploy/latest/APIReference/API_UpdateDeploymentGroup.html

        :stability: experimental
        '''
        return typing.cast("Codedeploy", jsii.invoke(self, "toUpdateDeploymentGroup", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ce485a74c1273a00d2f180d313e367f9b3748ca90dc0d4a6f51557f2304bea8e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b0b560d854eb570daa461f59c964952a86db8ef8234fdedcc0259ab219bf712c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class CodedeployCommandsSecure(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.CodedeployCommandsSecure",
):
    '''(experimental) Statement provider for service `codedeploy-commands-secure <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awscodedeploysecurehostcommandsservice.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `codedeploy-commands-secure <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awscodedeploysecurehostcommandsservice.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="toGetDeploymentSpecification")
    def to_get_deployment_specification(self) -> "CodedeployCommandsSecure":
        '''(experimental) Grants permission to get deployment specification.

        Access Level: Read

        https://docs.aws.amazon.com/codedeploy/latest/userguide/vpc-endpoints.html#vpc-codedeploy-agent-configuration

        :stability: experimental
        '''
        return typing.cast("CodedeployCommandsSecure", jsii.invoke(self, "toGetDeploymentSpecification", []))

    @jsii.member(jsii_name="toPollHostCommand")
    def to_poll_host_command(self) -> "CodedeployCommandsSecure":
        '''(experimental) Grants permission to request host agent commands.

        Access Level: Read

        https://docs.aws.amazon.com/codedeploy/latest/userguide/vpc-endpoints.html#vpc-codedeploy-agent-configuration

        :stability: experimental
        '''
        return typing.cast("CodedeployCommandsSecure", jsii.invoke(self, "toPollHostCommand", []))

    @jsii.member(jsii_name="toPutHostCommandAcknowledgement")
    def to_put_host_command_acknowledgement(self) -> "CodedeployCommandsSecure":
        '''(experimental) Grants permission to mark host agent commands acknowledged.

        Access Level: Write

        https://docs.aws.amazon.com/codedeploy/latest/userguide/vpc-endpoints.html#vpc-codedeploy-agent-configuration

        :stability: experimental
        '''
        return typing.cast("CodedeployCommandsSecure", jsii.invoke(self, "toPutHostCommandAcknowledgement", []))

    @jsii.member(jsii_name="toPutHostCommandComplete")
    def to_put_host_command_complete(self) -> "CodedeployCommandsSecure":
        '''(experimental) Grants permission to mark host agent commands completed.

        Access Level: Write

        https://docs.aws.amazon.com/codedeploy/latest/userguide/vpc-endpoints.html#vpc-codedeploy-agent-configuration

        :stability: experimental
        '''
        return typing.cast("CodedeployCommandsSecure", jsii.invoke(self, "toPutHostCommandComplete", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bf319c277cf7e4ef46a93336a39d06546a815f124bad4f20e5903b0d1a037648)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7fc77303c722731700bf3bbf4dbc900a31211e62e392149eb46938c5eb864e0b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Codeguru(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Codeguru",
):
    '''(experimental) Statement provider for service `codeguru <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazoncodeguru.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `codeguru <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazoncodeguru.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="toGetCodeGuruFreeTrialSummary")
    def to_get_code_guru_free_trial_summary(self) -> "Codeguru":
        '''(experimental) Grants permission to get free trial summary for the CodeGuru service which includes expiration date.

        Access Level: Read

        https://docs.aws.amazon.com/codeguru/latest/profiler-api/API_GetCodeGuruFreeTrialSummary.html

        :stability: experimental
        '''
        return typing.cast("Codeguru", jsii.invoke(self, "toGetCodeGuruFreeTrialSummary", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0778e7910c102bfae9100d746ccd1232263edaa72d4eeae6043575ba6dd29ac2)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5d613fd5852bffeb049447381908a5a783dc70daa4948e42d519acc5fdb5b0b8)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class CodeguruProfiler(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.CodeguruProfiler",
):
    '''(experimental) Statement provider for service `codeguru-profiler <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazoncodeguruprofiler.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `codeguru-profiler <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazoncodeguruprofiler.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onProfilingGroup")
    def on_profiling_group(
        self,
        profiling_group_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "CodeguruProfiler":
        '''(experimental) Adds a resource of type ProfilingGroup to the statement.

        https://docs.aws.amazon.com/codeguru/latest/profiler-ug/working-with-profiling-groups.html

        :param profiling_group_name: - Identifier for the profilingGroupName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4e32670c274d55e3610ae8daea99ebb6b8ab9d8303893334d0d7c94cabaca21d)
            check_type(argname="argument profiling_group_name", value=profiling_group_name, expected_type=type_hints["profiling_group_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("CodeguruProfiler", jsii.invoke(self, "onProfilingGroup", [profiling_group_name, account, region, partition]))

    @jsii.member(jsii_name="toAddNotificationChannels")
    def to_add_notification_channels(self) -> "CodeguruProfiler":
        '''(experimental) Grants permission to add up to 2 topic ARNs of existing AWS SNS topics to publish notifications.

        Access Level: Write

        https://docs.aws.amazon.com/codeguru/latest/profiler-api/API_AddNotificationChannels.html

        :stability: experimental
        '''
        return typing.cast("CodeguruProfiler", jsii.invoke(self, "toAddNotificationChannels", []))

    @jsii.member(jsii_name="toBatchGetFrameMetricData")
    def to_batch_get_frame_metric_data(self) -> "CodeguruProfiler":
        '''(experimental) Grants permission to get the frame metric data for a Profiling Group.

        Access Level: List

        https://docs.aws.amazon.com/codeguru/latest/profiler-api/API_BatchGetFrameMetricData.html

        :stability: experimental
        '''
        return typing.cast("CodeguruProfiler", jsii.invoke(self, "toBatchGetFrameMetricData", []))

    @jsii.member(jsii_name="toConfigureAgent")
    def to_configure_agent(self) -> "CodeguruProfiler":
        '''(experimental) Grants permission to register with the orchestration service and retrieve profiling configuration information, used by agents.

        Access Level: Write

        https://docs.aws.amazon.com/codeguru/latest/profiler-api/API_ConfigureAgent.html

        :stability: experimental
        '''
        return typing.cast("CodeguruProfiler", jsii.invoke(self, "toConfigureAgent", []))

    @jsii.member(jsii_name="toCreateProfilingGroup")
    def to_create_profiling_group(self) -> "CodeguruProfiler":
        '''(experimental) Grants permission to create a profiling group.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/codeguru/latest/profiler-api/API_CreateProfilingGroup.html

        :stability: experimental
        '''
        return typing.cast("CodeguruProfiler", jsii.invoke(self, "toCreateProfilingGroup", []))

    @jsii.member(jsii_name="toDeleteProfilingGroup")
    def to_delete_profiling_group(self) -> "CodeguruProfiler":
        '''(experimental) Grants permission to delete a profiling group.

        Access Level: Write

        https://docs.aws.amazon.com/codeguru/latest/profiler-api/API_DeleteProfilingGroup.html

        :stability: experimental
        '''
        return typing.cast("CodeguruProfiler", jsii.invoke(self, "toDeleteProfilingGroup", []))

    @jsii.member(jsii_name="toDescribeProfilingGroup")
    def to_describe_profiling_group(self) -> "CodeguruProfiler":
        '''(experimental) Grants permission to describe a profiling group.

        Access Level: Read

        https://docs.aws.amazon.com/codeguru/latest/profiler-api/API_DescribeProfilingGroup.html

        :stability: experimental
        '''
        return typing.cast("CodeguruProfiler", jsii.invoke(self, "toDescribeProfilingGroup", []))

    @jsii.member(jsii_name="toGetFindingsReportAccountSummary")
    def to_get_findings_report_account_summary(self) -> "CodeguruProfiler":
        '''(experimental) Grants permission to get a summary of recent recommendations for each profiling group in the account.

        Access Level: Read

        https://docs.aws.amazon.com/codeguru/latest/profiler-api/API_GetFindingsReportAccountSummary.html

        :stability: experimental
        '''
        return typing.cast("CodeguruProfiler", jsii.invoke(self, "toGetFindingsReportAccountSummary", []))

    @jsii.member(jsii_name="toGetNotificationConfiguration")
    def to_get_notification_configuration(self) -> "CodeguruProfiler":
        '''(experimental) Grants permission to get the notification configuration.

        Access Level: Read

        https://docs.aws.amazon.com/codeguru/latest/profiler-api/API_GetNotificationConfiguration.html

        :stability: experimental
        '''
        return typing.cast("CodeguruProfiler", jsii.invoke(self, "toGetNotificationConfiguration", []))

    @jsii.member(jsii_name="toGetPolicy")
    def to_get_policy(self) -> "CodeguruProfiler":
        '''(experimental) Grants permission to get the resource policy associated with the specified Profiling Group.

        Access Level: Read

        https://docs.aws.amazon.com/codeguru/latest/profiler-api/API_GetPolicy.html

        :stability: experimental
        '''
        return typing.cast("CodeguruProfiler", jsii.invoke(self, "toGetPolicy", []))

    @jsii.member(jsii_name="toGetProfile")
    def to_get_profile(self) -> "CodeguruProfiler":
        '''(experimental) Grants permission to get aggregated profiles for a specific profiling group.

        Access Level: Read

        https://docs.aws.amazon.com/codeguru/latest/profiler-api/API_GetProfile.html

        :stability: experimental
        '''
        return typing.cast("CodeguruProfiler", jsii.invoke(self, "toGetProfile", []))

    @jsii.member(jsii_name="toGetRecommendations")
    def to_get_recommendations(self) -> "CodeguruProfiler":
        '''(experimental) Grants permission to get recommendations.

        Access Level: Read

        https://docs.aws.amazon.com/codeguru/latest/profiler-api/API_GetRecommendations.html

        :stability: experimental
        '''
        return typing.cast("CodeguruProfiler", jsii.invoke(self, "toGetRecommendations", []))

    @jsii.member(jsii_name="toListFindingsReports")
    def to_list_findings_reports(self) -> "CodeguruProfiler":
        '''(experimental) Grants permission to list the available recommendations reports for a specific profiling group.

        Access Level: List

        https://docs.aws.amazon.com/codeguru/latest/profiler-api/API_ListFindingsReports.html

        :stability: experimental
        '''
        return typing.cast("CodeguruProfiler", jsii.invoke(self, "toListFindingsReports", []))

    @jsii.member(jsii_name="toListProfileTimes")
    def to_list_profile_times(self) -> "CodeguruProfiler":
        '''(experimental) Grants permission to list the start times of the available aggregated profiles for a specific profiling group.

        Access Level: List

        https://docs.aws.amazon.com/codeguru/latest/profiler-api/API_ListProfileTimes.html

        :stability: experimental
        '''
        return typing.cast("CodeguruProfiler", jsii.invoke(self, "toListProfileTimes", []))

    @jsii.member(jsii_name="toListProfilingGroups")
    def to_list_profiling_groups(self) -> "CodeguruProfiler":
        '''(experimental) Grants permission to list profiling groups in the account.

        Access Level: List

        https://docs.aws.amazon.com/codeguru/latest/profiler-api/API_ListProfilingGroups.html

        :stability: experimental
        '''
        return typing.cast("CodeguruProfiler", jsii.invoke(self, "toListProfilingGroups", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "CodeguruProfiler":
        '''(experimental) Grants permission to list tags for a Profiling Group.

        Access Level: List

        https://docs.aws.amazon.com/codeguru/latest/profiler-api/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("CodeguruProfiler", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toPostAgentProfile")
    def to_post_agent_profile(self) -> "CodeguruProfiler":
        '''(experimental) Grants permission to submit a profile collected by an agent belonging to a specific profiling group for aggregation.

        Access Level: Write

        https://docs.aws.amazon.com/codeguru/latest/profiler-api/API_PostAgentProfile.html

        :stability: experimental
        '''
        return typing.cast("CodeguruProfiler", jsii.invoke(self, "toPostAgentProfile", []))

    @jsii.member(jsii_name="toPutPermission")
    def to_put_permission(self) -> "CodeguruProfiler":
        '''(experimental) Grants permission to update the list of principals allowed for an action group in the resource policy associated with the specified Profiling Group.

        Access Level: Permissions management

        https://docs.aws.amazon.com/codeguru/latest/profiler-api/API_PutPermission.html

        :stability: experimental
        '''
        return typing.cast("CodeguruProfiler", jsii.invoke(self, "toPutPermission", []))

    @jsii.member(jsii_name="toRemoveNotificationChannel")
    def to_remove_notification_channel(self) -> "CodeguruProfiler":
        '''(experimental) Grants permission to delete an already configured SNStopic arn from the notification configuration.

        Access Level: Write

        https://docs.aws.amazon.com/codeguru/latest/profiler-api/API_RemoveNotificationChannel.html

        :stability: experimental
        '''
        return typing.cast("CodeguruProfiler", jsii.invoke(self, "toRemoveNotificationChannel", []))

    @jsii.member(jsii_name="toRemovePermission")
    def to_remove_permission(self) -> "CodeguruProfiler":
        '''(experimental) Grants permission to remove the permission of specified Action Group from the resource policy associated with the specified Profiling Group.

        Access Level: Permissions management

        https://docs.aws.amazon.com/codeguru/latest/profiler-api/API_RemovePermission.html

        :stability: experimental
        '''
        return typing.cast("CodeguruProfiler", jsii.invoke(self, "toRemovePermission", []))

    @jsii.member(jsii_name="toSubmitFeedback")
    def to_submit_feedback(self) -> "CodeguruProfiler":
        '''(experimental) Grants permission to submit user feedback for useful or non useful anomaly.

        Access Level: Write

        https://docs.aws.amazon.com/codeguru/latest/profiler-api/API_SubmitFeedback.html

        :stability: experimental
        '''
        return typing.cast("CodeguruProfiler", jsii.invoke(self, "toSubmitFeedback", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "CodeguruProfiler":
        '''(experimental) Grants permission to add or overwrite tags to a Profiling Group.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/codeguru/latest/profiler-api/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("CodeguruProfiler", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "CodeguruProfiler":
        '''(experimental) Grants permission to remove tags from a Profiling Group.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/codeguru/latest/profiler-api/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("CodeguruProfiler", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateProfilingGroup")
    def to_update_profiling_group(self) -> "CodeguruProfiler":
        '''(experimental) Grants permission to update a specific profiling group.

        Access Level: Write

        https://docs.aws.amazon.com/codeguru/latest/profiler-api/API_UpdateProfilingGroup.html

        :stability: experimental
        '''
        return typing.cast("CodeguruProfiler", jsii.invoke(self, "toUpdateProfilingGroup", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__48bb09de23a2ae7241fa60f5f6b3c5abb3a711ee0c85b3212f3afb67884ad35b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ebc5817fc8504d689e582476af1edb99127077ca58919d68bd0b6a179c93d792)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class CodeguruReviewer(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.CodeguruReviewer",
):
    '''(experimental) Statement provider for service `codeguru-reviewer <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazoncodegurureviewer.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `codeguru-reviewer <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazoncodegurureviewer.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onAssociation")
    def on_association(
        self,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "CodeguruReviewer":
        '''(experimental) Adds a resource of type association to the statement.

        https://docs.aws.amazon.com/codeguru/latest/reviewer-ug/working-with-repositories.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__297d2d438c20fb6d15f7fd4edf0acad339dd3d38008cf8719c16028ca8ffca44)
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("CodeguruReviewer", jsii.invoke(self, "onAssociation", [resource_id, account, region, partition]))

    @jsii.member(jsii_name="onCodereview")
    def on_codereview(
        self,
        code_review_uuid: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "CodeguruReviewer":
        '''(experimental) Adds a resource of type codereview to the statement.

        https://docs.aws.amazon.com/codeguru/latest/reviewer-ug/code-reviews.html

        :param code_review_uuid: - Identifier for the codeReviewUuid.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0f166cb14aad729b0d636f3c0d4da10d2657aa6b57ec31f52bb3e6083eff3280)
            check_type(argname="argument code_review_uuid", value=code_review_uuid, expected_type=type_hints["code_review_uuid"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("CodeguruReviewer", jsii.invoke(self, "onCodereview", [code_review_uuid, account, region, partition]))

    @jsii.member(jsii_name="toAssociateRepository")
    def to_associate_repository(self) -> "CodeguruReviewer":
        '''(experimental) Grants permission to associates a repository with Amazon CodeGuru Reviewer.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - codecommit:GetRepository
        - codecommit:ListRepositories
        - codecommit:TagResource
        - codestar-connections:PassConnection
        - events:PutRule
        - events:PutTargets
        - iam:CreateServiceLinkedRole
        - s3:CreateBucket
        - s3:ListBucket
        - s3:PutBucketPolicy
        - s3:PutLifecycleConfiguration

        https://docs.aws.amazon.com/codeguru/latest/reviewer-api/API_AssociateRepository.html

        :stability: experimental
        '''
        return typing.cast("CodeguruReviewer", jsii.invoke(self, "toAssociateRepository", []))

    @jsii.member(jsii_name="toCreateCodeReview")
    def to_create_code_review(self) -> "CodeguruReviewer":
        '''(experimental) Grants permission to create a code review.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        Dependent actions:

        - s3:GetObject

        https://docs.aws.amazon.com/codeguru/latest/reviewer-api/API_CreateCodeReview.html

        :stability: experimental
        '''
        return typing.cast("CodeguruReviewer", jsii.invoke(self, "toCreateCodeReview", []))

    @jsii.member(jsii_name="toCreateConnectionToken")
    def to_create_connection_token(self) -> "CodeguruReviewer":
        '''(experimental) Grants permission to perform webbased oauth handshake for 3rd party providers.

        Access Level: Read

        https://docs.aws.amazon.com/codeguru/latest/reviewer-api/Welcome.html

        :stability: experimental
        '''
        return typing.cast("CodeguruReviewer", jsii.invoke(self, "toCreateConnectionToken", []))

    @jsii.member(jsii_name="toDescribeCodeReview")
    def to_describe_code_review(self) -> "CodeguruReviewer":
        '''(experimental) Grants permission to describe a code review.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/codeguru/latest/reviewer-api/API_DescribeCodeReview.html

        :stability: experimental
        '''
        return typing.cast("CodeguruReviewer", jsii.invoke(self, "toDescribeCodeReview", []))

    @jsii.member(jsii_name="toDescribeRecommendationFeedback")
    def to_describe_recommendation_feedback(self) -> "CodeguruReviewer":
        '''(experimental) Grants permission to describe a recommendation feedback on a code review.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/codeguru/latest/reviewer-api/API_DescribeRecommendationFeedback.html

        :stability: experimental
        '''
        return typing.cast("CodeguruReviewer", jsii.invoke(self, "toDescribeRecommendationFeedback", []))

    @jsii.member(jsii_name="toDescribeRepositoryAssociation")
    def to_describe_repository_association(self) -> "CodeguruReviewer":
        '''(experimental) Grants permission to describe a repository association.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/codeguru/latest/reviewer-api/API_DescribeRepositoryAssociation.html

        :stability: experimental
        '''
        return typing.cast("CodeguruReviewer", jsii.invoke(self, "toDescribeRepositoryAssociation", []))

    @jsii.member(jsii_name="toDisassociateRepository")
    def to_disassociate_repository(self) -> "CodeguruReviewer":
        '''(experimental) Grants permission to disassociate a repository with Amazon CodeGuru Reviewer.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        Dependent actions:

        - codecommit:UntagResource
        - events:DeleteRule
        - events:RemoveTargets

        https://docs.aws.amazon.com/codeguru/latest/reviewer-api/API_DisassociateRepository.html

        :stability: experimental
        '''
        return typing.cast("CodeguruReviewer", jsii.invoke(self, "toDisassociateRepository", []))

    @jsii.member(jsii_name="toGetMetricsData")
    def to_get_metrics_data(self) -> "CodeguruReviewer":
        '''(experimental) Grants permission to view pull request metrics in console.

        Access Level: Read

        https://docs.aws.amazon.com/codeguru/latest/reviewer-api/Welcome.html

        :stability: experimental
        '''
        return typing.cast("CodeguruReviewer", jsii.invoke(self, "toGetMetricsData", []))

    @jsii.member(jsii_name="toListCodeReviews")
    def to_list_code_reviews(self) -> "CodeguruReviewer":
        '''(experimental) Grants permission to list summary of code reviews.

        Access Level: List

        https://docs.aws.amazon.com/codeguru/latest/reviewer-api/API_ListCodeReviews.html

        :stability: experimental
        '''
        return typing.cast("CodeguruReviewer", jsii.invoke(self, "toListCodeReviews", []))

    @jsii.member(jsii_name="toListRecommendationFeedback")
    def to_list_recommendation_feedback(self) -> "CodeguruReviewer":
        '''(experimental) Grants permission to list summary of recommendation feedback on a code review.

        Access Level: List

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/codeguru/latest/reviewer-api/API_ListRecommendationFeedback.html

        :stability: experimental
        '''
        return typing.cast("CodeguruReviewer", jsii.invoke(self, "toListRecommendationFeedback", []))

    @jsii.member(jsii_name="toListRecommendations")
    def to_list_recommendations(self) -> "CodeguruReviewer":
        '''(experimental) Grants permission to list summary of recommendations on a code review.

        Access Level: List

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/codeguru/latest/reviewer-api/API_ListRecommendations.html

        :stability: experimental
        '''
        return typing.cast("CodeguruReviewer", jsii.invoke(self, "toListRecommendations", []))

    @jsii.member(jsii_name="toListRepositoryAssociations")
    def to_list_repository_associations(self) -> "CodeguruReviewer":
        '''(experimental) Grants permission to list summary of repository associations.

        Access Level: List

        https://docs.aws.amazon.com/codeguru/latest/reviewer-api/API_ListRepositoryAssociations.html

        :stability: experimental
        '''
        return typing.cast("CodeguruReviewer", jsii.invoke(self, "toListRepositoryAssociations", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "CodeguruReviewer":
        '''(experimental) Grants permission to list the resource attached to a associated repository ARN.

        Access Level: List

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/codeguru/latest/reviewer-api/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("CodeguruReviewer", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toListThirdPartyRepositories")
    def to_list_third_party_repositories(self) -> "CodeguruReviewer":
        '''(experimental) Grants permission to list 3rd party providers repositories in console.

        Access Level: Read

        https://docs.aws.amazon.com/codeguru/latest/reviewer-api/Welcome.html

        :stability: experimental
        '''
        return typing.cast("CodeguruReviewer", jsii.invoke(self, "toListThirdPartyRepositories", []))

    @jsii.member(jsii_name="toPutRecommendationFeedback")
    def to_put_recommendation_feedback(self) -> "CodeguruReviewer":
        '''(experimental) Grants permission to put feedback for a recommendation on a code review.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/codeguru/latest/reviewer-api/API_PutRecommendationFeedback.html

        :stability: experimental
        '''
        return typing.cast("CodeguruReviewer", jsii.invoke(self, "toPutRecommendationFeedback", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "CodeguruReviewer":
        '''(experimental) Grants permission to attach resource tags to an associated repository ARN.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/codeguru/latest/reviewer-api/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("CodeguruReviewer", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUnTagResource")
    def to_un_tag_resource(self) -> "CodeguruReviewer":
        '''(experimental) Grants permission to disassociate resource tags from an associated repository ARN.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/codeguru/latest/reviewer-api/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("CodeguruReviewer", jsii.invoke(self, "toUnTagResource", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2b964bc72936b3938b10e060d8149832a889702eeb65049700edc0162dd6fc7e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2bb9802ff1318d9219c55f607a5b78747eca6a6d1d6e8f98534b8747c43b36e8)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Codepipeline(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Codepipeline",
):
    '''(experimental) Statement provider for service `codepipeline <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awscodepipeline.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `codepipeline <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awscodepipeline.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onAction")
    def on_action(
        self,
        pipeline_name: builtins.str,
        stage_name: builtins.str,
        action_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Codepipeline":
        '''(experimental) Adds a resource of type action to the statement.

        https://docs.aws.amazon.com/codepipeline/latest/userguide/iam-access-control-identity-based.html#ACP_ARN_Format

        :param pipeline_name: - Identifier for the pipelineName.
        :param stage_name: - Identifier for the stageName.
        :param action_name: - Identifier for the actionName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__56a6fa6c6ca1d37c54fda72a748da4beee59f86fd75102e0b7681e53d9f1d1a3)
            check_type(argname="argument pipeline_name", value=pipeline_name, expected_type=type_hints["pipeline_name"])
            check_type(argname="argument stage_name", value=stage_name, expected_type=type_hints["stage_name"])
            check_type(argname="argument action_name", value=action_name, expected_type=type_hints["action_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Codepipeline", jsii.invoke(self, "onAction", [pipeline_name, stage_name, action_name, account, region, partition]))

    @jsii.member(jsii_name="onActiontype")
    def on_actiontype(
        self,
        owner: builtins.str,
        category: builtins.str,
        provider: builtins.str,
        version: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Codepipeline":
        '''(experimental) Adds a resource of type actiontype to the statement.

        https://docs.aws.amazon.com/codepipeline/latest/userguide/iam-access-control-identity-based.html#ACP_ARN_Format

        :param owner: - Identifier for the owner.
        :param category: - Identifier for the category.
        :param provider: - Identifier for the provider.
        :param version: - Identifier for the version.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1c48868a4052f22e91d9247114e1f12f2861b752457a32481af3ce3da2d81ea5)
            check_type(argname="argument owner", value=owner, expected_type=type_hints["owner"])
            check_type(argname="argument category", value=category, expected_type=type_hints["category"])
            check_type(argname="argument provider", value=provider, expected_type=type_hints["provider"])
            check_type(argname="argument version", value=version, expected_type=type_hints["version"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Codepipeline", jsii.invoke(self, "onActiontype", [owner, category, provider, version, account, region, partition]))

    @jsii.member(jsii_name="onPipeline")
    def on_pipeline(
        self,
        pipeline_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Codepipeline":
        '''(experimental) Adds a resource of type pipeline to the statement.

        https://docs.aws.amazon.com/codepipeline/latest/userguide/iam-access-control-identity-based.html#ACP_ARN_Format

        :param pipeline_name: - Identifier for the pipelineName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__79ed5b5985da9bb5c197ace67db98669cf27afe5becdaf3b3e5b66319b4f09a3)
            check_type(argname="argument pipeline_name", value=pipeline_name, expected_type=type_hints["pipeline_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Codepipeline", jsii.invoke(self, "onPipeline", [pipeline_name, account, region, partition]))

    @jsii.member(jsii_name="onStage")
    def on_stage(
        self,
        pipeline_name: builtins.str,
        stage_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Codepipeline":
        '''(experimental) Adds a resource of type stage to the statement.

        https://docs.aws.amazon.com/codepipeline/latest/userguide/iam-access-control-identity-based.html#ACP_ARN_Format

        :param pipeline_name: - Identifier for the pipelineName.
        :param stage_name: - Identifier for the stageName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fa324a22003a9b66b71037e86a90218aaf57c8b0061b95a95c9f43207a3c03f7)
            check_type(argname="argument pipeline_name", value=pipeline_name, expected_type=type_hints["pipeline_name"])
            check_type(argname="argument stage_name", value=stage_name, expected_type=type_hints["stage_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Codepipeline", jsii.invoke(self, "onStage", [pipeline_name, stage_name, account, region, partition]))

    @jsii.member(jsii_name="onWebhook")
    def on_webhook(
        self,
        webhook_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Codepipeline":
        '''(experimental) Adds a resource of type webhook to the statement.

        https://docs.aws.amazon.com/codepipeline/latest/userguide/iam-access-control-identity-based.html#ACP_ARN_Format

        :param webhook_name: - Identifier for the webhookName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__35d96c6f67496a0e6ebe8db7151cc8093e67e900fce682ebc5ff106f34455022)
            check_type(argname="argument webhook_name", value=webhook_name, expected_type=type_hints["webhook_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Codepipeline", jsii.invoke(self, "onWebhook", [webhook_name, account, region, partition]))

    @jsii.member(jsii_name="toAcknowledgeJob")
    def to_acknowledge_job(self) -> "Codepipeline":
        '''(experimental) Grants permission to view information about a specified job and whether that job has been received by the job worker.

        Access Level: Write

        https://docs.aws.amazon.com/codepipeline/latest/APIReference/API_AcknowledgeJob.html

        :stability: experimental
        '''
        return typing.cast("Codepipeline", jsii.invoke(self, "toAcknowledgeJob", []))

    @jsii.member(jsii_name="toAcknowledgeThirdPartyJob")
    def to_acknowledge_third_party_job(self) -> "Codepipeline":
        '''(experimental) Grants permission to confirm that a job worker has received the specified job (partner actions only).

        Access Level: Write

        https://docs.aws.amazon.com/codepipeline/latest/APIReference/API_AcknowledgeThirdPartyJob.html

        :stability: experimental
        '''
        return typing.cast("Codepipeline", jsii.invoke(self, "toAcknowledgeThirdPartyJob", []))

    @jsii.member(jsii_name="toCreateCustomActionType")
    def to_create_custom_action_type(self) -> "Codepipeline":
        '''(experimental) Grants permission to create a custom action that you can use in the pipelines associated with your AWS account.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/codepipeline/latest/APIReference/API_CreateCustomActionType.html

        :stability: experimental
        '''
        return typing.cast("Codepipeline", jsii.invoke(self, "toCreateCustomActionType", []))

    @jsii.member(jsii_name="toCreatePipeline")
    def to_create_pipeline(self) -> "Codepipeline":
        '''(experimental) Grants permission to create a uniquely named pipeline.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/codepipeline/latest/APIReference/API_CreatePipeline.html

        :stability: experimental
        '''
        return typing.cast("Codepipeline", jsii.invoke(self, "toCreatePipeline", []))

    @jsii.member(jsii_name="toDeleteCustomActionType")
    def to_delete_custom_action_type(self) -> "Codepipeline":
        '''(experimental) Grants permission to delete a custom action.

        Access Level: Write

        https://docs.aws.amazon.com/codepipeline/latest/APIReference/API_DeleteCustomActionType.html

        :stability: experimental
        '''
        return typing.cast("Codepipeline", jsii.invoke(self, "toDeleteCustomActionType", []))

    @jsii.member(jsii_name="toDeletePipeline")
    def to_delete_pipeline(self) -> "Codepipeline":
        '''(experimental) Grants permission to delete a specified pipeline.

        Access Level: Write

        https://docs.aws.amazon.com/codepipeline/latest/APIReference/API_DeletePipeline.html

        :stability: experimental
        '''
        return typing.cast("Codepipeline", jsii.invoke(self, "toDeletePipeline", []))

    @jsii.member(jsii_name="toDeleteWebhook")
    def to_delete_webhook(self) -> "Codepipeline":
        '''(experimental) Grants permission to delete a specified webhook.

        Access Level: Write

        https://docs.aws.amazon.com/codepipeline/latest/APIReference/API_DeleteWebhook.html

        :stability: experimental
        '''
        return typing.cast("Codepipeline", jsii.invoke(self, "toDeleteWebhook", []))

    @jsii.member(jsii_name="toDeregisterWebhookWithThirdParty")
    def to_deregister_webhook_with_third_party(self) -> "Codepipeline":
        '''(experimental) Grants permission to remove the registration of a webhook with the third party specified in its configuration.

        Access Level: Write

        https://docs.aws.amazon.com/codepipeline/latest/APIReference/API_DeregisterWebhookWithThirdParty.html

        :stability: experimental
        '''
        return typing.cast("Codepipeline", jsii.invoke(self, "toDeregisterWebhookWithThirdParty", []))

    @jsii.member(jsii_name="toDisableStageTransition")
    def to_disable_stage_transition(self) -> "Codepipeline":
        '''(experimental) Grants permission to prevent revisions from transitioning to the next stage in a pipeline.

        Access Level: Write

        https://docs.aws.amazon.com/codepipeline/latest/APIReference/API_DisableStageTransition.html

        :stability: experimental
        '''
        return typing.cast("Codepipeline", jsii.invoke(self, "toDisableStageTransition", []))

    @jsii.member(jsii_name="toEnableStageTransition")
    def to_enable_stage_transition(self) -> "Codepipeline":
        '''(experimental) Grants permission to allow revisions to transition to the next stage in a pipeline.

        Access Level: Write

        https://docs.aws.amazon.com/codepipeline/latest/APIReference/API_EnableStageTransition.html

        :stability: experimental
        '''
        return typing.cast("Codepipeline", jsii.invoke(self, "toEnableStageTransition", []))

    @jsii.member(jsii_name="toGetActionType")
    def to_get_action_type(self) -> "Codepipeline":
        '''(experimental) Grants permission to view information about an action type.

        Access Level: Read

        https://docs.aws.amazon.com/codepipeline/latest/APIReference/API_GetActionType.html

        :stability: experimental
        '''
        return typing.cast("Codepipeline", jsii.invoke(self, "toGetActionType", []))

    @jsii.member(jsii_name="toGetJobDetails")
    def to_get_job_details(self) -> "Codepipeline":
        '''(experimental) Grants permission to view information about a job (custom actions only).

        Access Level: Read

        https://docs.aws.amazon.com/codepipeline/latest/APIReference/API_GetJobDetails.html

        :stability: experimental
        '''
        return typing.cast("Codepipeline", jsii.invoke(self, "toGetJobDetails", []))

    @jsii.member(jsii_name="toGetPipeline")
    def to_get_pipeline(self) -> "Codepipeline":
        '''(experimental) Grants permission to retrieve information about a pipeline structure.

        Access Level: Read

        https://docs.aws.amazon.com/codepipeline/latest/APIReference/API_GetPipeline.html

        :stability: experimental
        '''
        return typing.cast("Codepipeline", jsii.invoke(self, "toGetPipeline", []))

    @jsii.member(jsii_name="toGetPipelineExecution")
    def to_get_pipeline_execution(self) -> "Codepipeline":
        '''(experimental) Grants permission to view information about an execution of a pipeline, including details about artifacts, the pipeline execution ID, and the name, version, and status of the pipeline.

        Access Level: Read

        https://docs.aws.amazon.com/codepipeline/latest/APIReference/API_GetPipelineExecution.html

        :stability: experimental
        '''
        return typing.cast("Codepipeline", jsii.invoke(self, "toGetPipelineExecution", []))

    @jsii.member(jsii_name="toGetPipelineState")
    def to_get_pipeline_state(self) -> "Codepipeline":
        '''(experimental) Grants permission to view information about the current state of the stages and actions of a pipeline.

        Access Level: Read

        https://docs.aws.amazon.com/codepipeline/latest/APIReference/API_GetPipelineState.html

        :stability: experimental
        '''
        return typing.cast("Codepipeline", jsii.invoke(self, "toGetPipelineState", []))

    @jsii.member(jsii_name="toGetThirdPartyJobDetails")
    def to_get_third_party_job_details(self) -> "Codepipeline":
        '''(experimental) Grants permission to view the details of a job for a third-party action (partner actions only).

        Access Level: Read

        https://docs.aws.amazon.com/codepipeline/latest/APIReference/API_GetThirdPartyJobDetails.html

        :stability: experimental
        '''
        return typing.cast("Codepipeline", jsii.invoke(self, "toGetThirdPartyJobDetails", []))

    @jsii.member(jsii_name="toListActionExecutions")
    def to_list_action_executions(self) -> "Codepipeline":
        '''(experimental) Grants permission to list the action executions that have occurred in a pipeline.

        Access Level: Read

        https://docs.aws.amazon.com/codepipeline/latest/APIReference/API_ListActionExecutions.html

        :stability: experimental
        '''
        return typing.cast("Codepipeline", jsii.invoke(self, "toListActionExecutions", []))

    @jsii.member(jsii_name="toListActionTypes")
    def to_list_action_types(self) -> "Codepipeline":
        '''(experimental) Grants permission to list a summary of all the action types available for pipelines in your account.

        Access Level: Read

        https://docs.aws.amazon.com/codepipeline/latest/APIReference/API_ListActionTypes.html

        :stability: experimental
        '''
        return typing.cast("Codepipeline", jsii.invoke(self, "toListActionTypes", []))

    @jsii.member(jsii_name="toListPipelineExecutions")
    def to_list_pipeline_executions(self) -> "Codepipeline":
        '''(experimental) Grants permission to list a summary of the most recent executions for a pipeline.

        Access Level: List

        https://docs.aws.amazon.com/codepipeline/latest/APIReference/API_ListPipelineExecutions.html

        :stability: experimental
        '''
        return typing.cast("Codepipeline", jsii.invoke(self, "toListPipelineExecutions", []))

    @jsii.member(jsii_name="toListPipelines")
    def to_list_pipelines(self) -> "Codepipeline":
        '''(experimental) Grants permission to list a summary of all the pipelines associated with your AWS account.

        Access Level: List

        https://docs.aws.amazon.com/codepipeline/latest/APIReference/API_ListPipelines.html

        :stability: experimental
        '''
        return typing.cast("Codepipeline", jsii.invoke(self, "toListPipelines", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Codepipeline":
        '''(experimental) Grants permission to list tags for a CodePipeline resource.

        Access Level: Read

        https://docs.aws.amazon.com/codepipeline/latest/APIReference/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("Codepipeline", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toListWebhooks")
    def to_list_webhooks(self) -> "Codepipeline":
        '''(experimental) Grants permission to list all of the webhooks associated with your AWS account.

        Access Level: List

        https://docs.aws.amazon.com/codepipeline/latest/APIReference/API_ListWebhooks.html

        :stability: experimental
        '''
        return typing.cast("Codepipeline", jsii.invoke(self, "toListWebhooks", []))

    @jsii.member(jsii_name="toPollForJobs")
    def to_poll_for_jobs(self) -> "Codepipeline":
        '''(experimental) Grants permission to view information about any jobs for CodePipeline to act on.

        Access Level: Write

        https://docs.aws.amazon.com/codepipeline/latest/APIReference/API_PollForJobs.html

        :stability: experimental
        '''
        return typing.cast("Codepipeline", jsii.invoke(self, "toPollForJobs", []))

    @jsii.member(jsii_name="toPollForThirdPartyJobs")
    def to_poll_for_third_party_jobs(self) -> "Codepipeline":
        '''(experimental) Grants permission to determine whether there are any third-party jobs for a job worker to act on (partner actions only).

        Access Level: Write

        https://docs.aws.amazon.com/codepipeline/latest/APIReference/API_PollForThirdPartyJobs.html

        :stability: experimental
        '''
        return typing.cast("Codepipeline", jsii.invoke(self, "toPollForThirdPartyJobs", []))

    @jsii.member(jsii_name="toPutActionRevision")
    def to_put_action_revision(self) -> "Codepipeline":
        '''(experimental) Grants permission to edit actions in a pipeline.

        Access Level: Write

        https://docs.aws.amazon.com/codepipeline/latest/APIReference/API_PutActionRevision.html

        :stability: experimental
        '''
        return typing.cast("Codepipeline", jsii.invoke(self, "toPutActionRevision", []))

    @jsii.member(jsii_name="toPutApprovalResult")
    def to_put_approval_result(self) -> "Codepipeline":
        '''(experimental) Grants permission to provide a response (Approved or Rejected) to a manual approval request in CodePipeline.

        Access Level: Write

        https://docs.aws.amazon.com/codepipeline/latest/APIReference/API_PutApprovalResult.html

        :stability: experimental
        '''
        return typing.cast("Codepipeline", jsii.invoke(self, "toPutApprovalResult", []))

    @jsii.member(jsii_name="toPutJobFailureResult")
    def to_put_job_failure_result(self) -> "Codepipeline":
        '''(experimental) Grants permission to represent the failure of a job as returned to the pipeline by a job worker (custom actions only).

        Access Level: Write

        https://docs.aws.amazon.com/codepipeline/latest/APIReference/API_PutJobFailureResult.html

        :stability: experimental
        '''
        return typing.cast("Codepipeline", jsii.invoke(self, "toPutJobFailureResult", []))

    @jsii.member(jsii_name="toPutJobSuccessResult")
    def to_put_job_success_result(self) -> "Codepipeline":
        '''(experimental) Grants permission to represent the success of a job as returned to the pipeline by a job worker (custom actions only).

        Access Level: Write

        https://docs.aws.amazon.com/codepipeline/latest/APIReference/API_PutJobSuccessResult.html

        :stability: experimental
        '''
        return typing.cast("Codepipeline", jsii.invoke(self, "toPutJobSuccessResult", []))

    @jsii.member(jsii_name="toPutThirdPartyJobFailureResult")
    def to_put_third_party_job_failure_result(self) -> "Codepipeline":
        '''(experimental) Grants permission to represent the failure of a third-party job as returned to the pipeline by a job worker (partner actions only).

        Access Level: Write

        https://docs.aws.amazon.com/codepipeline/latest/APIReference/API_PutThirdPartyJobFailureResult.html

        :stability: experimental
        '''
        return typing.cast("Codepipeline", jsii.invoke(self, "toPutThirdPartyJobFailureResult", []))

    @jsii.member(jsii_name="toPutThirdPartyJobSuccessResult")
    def to_put_third_party_job_success_result(self) -> "Codepipeline":
        '''(experimental) Grants permission to represent the success of a third-party job as returned to the pipeline by a job worker (partner actions only).

        Access Level: Write

        https://docs.aws.amazon.com/codepipeline/latest/APIReference/API_PutThirdPartyJobSuccessResult.html

        :stability: experimental
        '''
        return typing.cast("Codepipeline", jsii.invoke(self, "toPutThirdPartyJobSuccessResult", []))

    @jsii.member(jsii_name="toPutWebhook")
    def to_put_webhook(self) -> "Codepipeline":
        '''(experimental) Grants permission to create or update a webhook.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/codepipeline/latest/APIReference/API_PutWebhook.html

        :stability: experimental
        '''
        return typing.cast("Codepipeline", jsii.invoke(self, "toPutWebhook", []))

    @jsii.member(jsii_name="toRegisterWebhookWithThirdParty")
    def to_register_webhook_with_third_party(self) -> "Codepipeline":
        '''(experimental) Grants permission to register a webhook with the third party specified in its configuration.

        Access Level: Write

        https://docs.aws.amazon.com/codepipeline/latest/APIReference/API_RegisterWebhookWithThirdParty.html

        :stability: experimental
        '''
        return typing.cast("Codepipeline", jsii.invoke(self, "toRegisterWebhookWithThirdParty", []))

    @jsii.member(jsii_name="toRetryStageExecution")
    def to_retry_stage_execution(self) -> "Codepipeline":
        '''(experimental) Grants permission to resume the pipeline execution by retrying the last failed actions in a stage.

        Access Level: Write

        https://docs.aws.amazon.com/codepipeline/latest/APIReference/API_RetryStageExecution.html

        :stability: experimental
        '''
        return typing.cast("Codepipeline", jsii.invoke(self, "toRetryStageExecution", []))

    @jsii.member(jsii_name="toStartPipelineExecution")
    def to_start_pipeline_execution(self) -> "Codepipeline":
        '''(experimental) Grants permission to run the most recent revision through the pipeline.

        Access Level: Write

        https://docs.aws.amazon.com/codepipeline/latest/APIReference/API_StartPipelineExecution.html

        :stability: experimental
        '''
        return typing.cast("Codepipeline", jsii.invoke(self, "toStartPipelineExecution", []))

    @jsii.member(jsii_name="toStopPipelineExecution")
    def to_stop_pipeline_execution(self) -> "Codepipeline":
        '''(experimental) Grants permission to stop an in-progress pipeline execution.

        Access Level: Write

        https://docs.aws.amazon.com/codepipeline/latest/APIReference/API_StopPipelineExecution.html

        :stability: experimental
        '''
        return typing.cast("Codepipeline", jsii.invoke(self, "toStopPipelineExecution", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Codepipeline":
        '''(experimental) Grants permission to tag a CodePipeline resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/codepipeline/latest/APIReference/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("Codepipeline", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Codepipeline":
        '''(experimental) Grants permission to remove a tag from a CodePipeline resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/codepipeline/latest/APIReference/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("Codepipeline", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateActionType")
    def to_update_action_type(self) -> "Codepipeline":
        '''(experimental) Grants permission to update an action type.

        Access Level: Write

        https://docs.aws.amazon.com/codepipeline/latest/APIReference/API_UpdateActionType.html

        :stability: experimental
        '''
        return typing.cast("Codepipeline", jsii.invoke(self, "toUpdateActionType", []))

    @jsii.member(jsii_name="toUpdatePipeline")
    def to_update_pipeline(self) -> "Codepipeline":
        '''(experimental) Grants permission to update a pipeline with changes to the structure of the pipeline.

        Access Level: Write

        https://docs.aws.amazon.com/codepipeline/latest/APIReference/API_UpdatePipeline.html

        :stability: experimental
        '''
        return typing.cast("Codepipeline", jsii.invoke(self, "toUpdatePipeline", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f07b4b4e1e637a04c153b9de57d8afdd037e9dabf9a6c0cfd9a28585ae9fe5ae)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1a7a47fc32a152d29d42b5a686627dc9b1ce88990eaff26542483cbe5debc937)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Codestar(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Codestar",
):
    '''(experimental) Statement provider for service `codestar <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awscodestar.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `codestar <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awscodestar.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="ifIamResourceTag")
    def if_iam_resource_tag(
        self,
        tag_key: builtins.str,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Codestar":
        '''(experimental) Filters access by actions based on tag-value associated with the resource.

        Applies to resource types:

        - user

        :param tag_key: The tag key to check.
        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d7d370140309a4be9c838d397a9491c1284be18df5f8cf4b615986ca39974729)
            check_type(argname="argument tag_key", value=tag_key, expected_type=type_hints["tag_key"])
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Codestar", jsii.invoke(self, "ifIamResourceTag", [tag_key, value, operator]))

    @jsii.member(jsii_name="onProject")
    def on_project(
        self,
        project_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Codestar":
        '''(experimental) Adds a resource of type project to the statement.

        https://docs.aws.amazon.com/codestar/latest/userguide/working-with-projects.html

        :param project_id: - Identifier for the projectId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__33a28dd7dd37325a48ead9d402a3c3a5dd24abc76528d2ffd807975aeef5da52)
            check_type(argname="argument project_id", value=project_id, expected_type=type_hints["project_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Codestar", jsii.invoke(self, "onProject", [project_id, account, region, partition]))

    @jsii.member(jsii_name="onUser")
    def on_user(
        self,
        user_name_with_path: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Codestar":
        '''(experimental) Adds a resource of type user to the statement.

        https://docs.aws.amazon.com/codestar/latest/userguide/working-with-user-info.html

        :param user_name_with_path: - Identifier for the userNameWithPath.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifIamResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__42c01ffd53771e3248f5c26421439e2ebe8857bca865aba621591c69abb6522a)
            check_type(argname="argument user_name_with_path", value=user_name_with_path, expected_type=type_hints["user_name_with_path"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Codestar", jsii.invoke(self, "onUser", [user_name_with_path, account, region, partition]))

    @jsii.member(jsii_name="toAssociateTeamMember")
    def to_associate_team_member(self) -> "Codestar":
        '''(experimental) Grants permission to add a user to the team for an AWS CodeStar project.

        Access Level: Permissions management

        https://docs.aws.amazon.com/codestar/latest/APIReference/API_AssociateTeamMember.html

        :stability: experimental
        '''
        return typing.cast("Codestar", jsii.invoke(self, "toAssociateTeamMember", []))

    @jsii.member(jsii_name="toCreateProject")
    def to_create_project(self) -> "Codestar":
        '''(experimental) Grants permission to create a project with minimal structure, customer policies, and no resources.

        Access Level: Permissions management

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/codestar/latest/APIReference/API_CreateProject.html

        :stability: experimental
        '''
        return typing.cast("Codestar", jsii.invoke(self, "toCreateProject", []))

    @jsii.member(jsii_name="toCreateUserProfile")
    def to_create_user_profile(self) -> "Codestar":
        '''(experimental) Grants permission to create a profile for a user that includes user preferences, display name, and email.

        Access Level: Write

        https://docs.aws.amazon.com/codestar/latest/APIReference/API_CreateUserProfile.html

        :stability: experimental
        '''
        return typing.cast("Codestar", jsii.invoke(self, "toCreateUserProfile", []))

    @jsii.member(jsii_name="toDeleteExtendedAccess")
    def to_delete_extended_access(self) -> "Codestar":
        '''(experimental) Grants permission to extended delete APIs.

        Access Level: Write

        :stability: experimental
        '''
        return typing.cast("Codestar", jsii.invoke(self, "toDeleteExtendedAccess", []))

    @jsii.member(jsii_name="toDeleteProject")
    def to_delete_project(self) -> "Codestar":
        '''(experimental) Grants permission to delete a project, including project resources.

        Does not delete users associated with the project, but does delete the IAM roles that allowed access to the project

        Access Level: Permissions management

        https://docs.aws.amazon.com/codestar/latest/APIReference/API_DeleteProject.html

        :stability: experimental
        '''
        return typing.cast("Codestar", jsii.invoke(self, "toDeleteProject", []))

    @jsii.member(jsii_name="toDeleteUserProfile")
    def to_delete_user_profile(self) -> "Codestar":
        '''(experimental) Grants permission to delete a user profile in AWS CodeStar, including all personal preference data associated with that profile, such as display name and email address.

        It does not delete the history of that user, for example the history of commits made by that user

        Access Level: Write

        https://docs.aws.amazon.com/codestar/latest/APIReference/API_DeleteUserProfile.html

        :stability: experimental
        '''
        return typing.cast("Codestar", jsii.invoke(self, "toDeleteUserProfile", []))

    @jsii.member(jsii_name="toDescribeProject")
    def to_describe_project(self) -> "Codestar":
        '''(experimental) Grants permission to describe a project and its resources.

        Access Level: Read

        https://docs.aws.amazon.com/codestar/latest/APIReference/API_DescribeProject.html

        :stability: experimental
        '''
        return typing.cast("Codestar", jsii.invoke(self, "toDescribeProject", []))

    @jsii.member(jsii_name="toDescribeUserProfile")
    def to_describe_user_profile(self) -> "Codestar":
        '''(experimental) Grants permission to describe a user in AWS CodeStar and the user attributes across all projects.

        Access Level: Read

        https://docs.aws.amazon.com/codestar/latest/APIReference/API_DescribeUserProfile.html

        :stability: experimental
        '''
        return typing.cast("Codestar", jsii.invoke(self, "toDescribeUserProfile", []))

    @jsii.member(jsii_name="toDisassociateTeamMember")
    def to_disassociate_team_member(self) -> "Codestar":
        '''(experimental) Grants permission to remove a user from a project.

        Removing a user from a project also removes the IAM policies from that user that allowed access to the project and its resources

        Access Level: Permissions management

        https://docs.aws.amazon.com/codestar/latest/APIReference/API_DisassociateTeamMember.html

        :stability: experimental
        '''
        return typing.cast("Codestar", jsii.invoke(self, "toDisassociateTeamMember", []))

    @jsii.member(jsii_name="toGetExtendedAccess")
    def to_get_extended_access(self) -> "Codestar":
        '''(experimental) Grants permission to extended read APIs.

        Access Level: Read

        :stability: experimental
        '''
        return typing.cast("Codestar", jsii.invoke(self, "toGetExtendedAccess", []))

    @jsii.member(jsii_name="toListProjects")
    def to_list_projects(self) -> "Codestar":
        '''(experimental) Grants permission to list all projects in CodeStar associated with your AWS account.

        Access Level: List

        https://docs.aws.amazon.com/codestar/latest/APIReference/API_ListProjects.html

        :stability: experimental
        '''
        return typing.cast("Codestar", jsii.invoke(self, "toListProjects", []))

    @jsii.member(jsii_name="toListResources")
    def to_list_resources(self) -> "Codestar":
        '''(experimental) Grants permission to list all resources associated with a project in CodeStar.

        Access Level: List

        https://docs.aws.amazon.com/codestar/latest/APIReference/API_ListResources.html

        :stability: experimental
        '''
        return typing.cast("Codestar", jsii.invoke(self, "toListResources", []))

    @jsii.member(jsii_name="toListTagsForProject")
    def to_list_tags_for_project(self) -> "Codestar":
        '''(experimental) Grants permission to list the tags associated with a project in CodeStar.

        Access Level: List

        https://docs.aws.amazon.com/codestar/latest/APIReference/API_ListTagsForProject.html

        :stability: experimental
        '''
        return typing.cast("Codestar", jsii.invoke(self, "toListTagsForProject", []))

    @jsii.member(jsii_name="toListTeamMembers")
    def to_list_team_members(self) -> "Codestar":
        '''(experimental) Grants permission to list all team members associated with a project.

        Access Level: List

        https://docs.aws.amazon.com/codestar/latest/APIReference/API_ListTeamMembers.html

        :stability: experimental
        '''
        return typing.cast("Codestar", jsii.invoke(self, "toListTeamMembers", []))

    @jsii.member(jsii_name="toListUserProfiles")
    def to_list_user_profiles(self) -> "Codestar":
        '''(experimental) Grants permission to list user profiles in AWS CodeStar.

        Access Level: List

        https://docs.aws.amazon.com/codestar/latest/APIReference/API_ListUserProfiles.html

        :stability: experimental
        '''
        return typing.cast("Codestar", jsii.invoke(self, "toListUserProfiles", []))

    @jsii.member(jsii_name="toPutExtendedAccess")
    def to_put_extended_access(self) -> "Codestar":
        '''(experimental) Grants permission to extended write APIs.

        Access Level: Write

        :stability: experimental
        '''
        return typing.cast("Codestar", jsii.invoke(self, "toPutExtendedAccess", []))

    @jsii.member(jsii_name="toTagProject")
    def to_tag_project(self) -> "Codestar":
        '''(experimental) Grants permission to add tags to a project in CodeStar.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/codestar/latest/APIReference/API_TagProject.html

        :stability: experimental
        '''
        return typing.cast("Codestar", jsii.invoke(self, "toTagProject", []))

    @jsii.member(jsii_name="toUntagProject")
    def to_untag_project(self) -> "Codestar":
        '''(experimental) Grants permission to remove tags from a project in CodeStar.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/codestar/latest/APIReference/API_UntagProject.html

        :stability: experimental
        '''
        return typing.cast("Codestar", jsii.invoke(self, "toUntagProject", []))

    @jsii.member(jsii_name="toUpdateProject")
    def to_update_project(self) -> "Codestar":
        '''(experimental) Grants permission to update a project in CodeStar.

        Access Level: Write

        https://docs.aws.amazon.com/codestar/latest/APIReference/API_UpdateProject.html

        :stability: experimental
        '''
        return typing.cast("Codestar", jsii.invoke(self, "toUpdateProject", []))

    @jsii.member(jsii_name="toUpdateTeamMember")
    def to_update_team_member(self) -> "Codestar":
        '''(experimental) Grants permission to update team member attributes within a CodeStar project.

        Access Level: Permissions management

        https://docs.aws.amazon.com/codestar/latest/APIReference/API_UpdateTeamMember.html

        :stability: experimental
        '''
        return typing.cast("Codestar", jsii.invoke(self, "toUpdateTeamMember", []))

    @jsii.member(jsii_name="toUpdateUserProfile")
    def to_update_user_profile(self) -> "Codestar":
        '''(experimental) Grants permission to update a profile for a user that includes user preferences, display name, and email.

        Access Level: Write

        https://docs.aws.amazon.com/codestar/latest/APIReference/API_UpdateUserProfile.html

        :stability: experimental
        '''
        return typing.cast("Codestar", jsii.invoke(self, "toUpdateUserProfile", []))

    @jsii.member(jsii_name="toVerifyServiceRole")
    def to_verify_service_role(self) -> "Codestar":
        '''(experimental) Grants permission to verify whether the AWS CodeStar service role exists in the customer's account.

        Access Level: List

        :stability: experimental
        '''
        return typing.cast("Codestar", jsii.invoke(self, "toVerifyServiceRole", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__61166551349ad76ce5bd850ccbd765a30a9bf58e54ce4b0ce67501de00a5b7d9)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c8d9c8503331671a20048e183c255bd6590a3e1365ac9264ae747aaa7db1a931)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class CodestarConnections(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.CodestarConnections",
):
    '''(experimental) Statement provider for service `codestar-connections <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awscodestarconnections.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `codestar-connections <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awscodestarconnections.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="ifBranchName")
    def if_branch_name(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "CodestarConnections":
        '''(experimental) Filters access by the branch name that is passed in the request.

        Applies only to UseConnection requests for access to a specific repository branch

        https://docs.aws.amazon.com/dtconsole/latest/userguide/security-iam.html#permissions-reference-connections-use

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fd2858d6519143bd6fb4a9fc7edc3457ab1a583faf5b33947fdf40eb43872b7a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("CodestarConnections", jsii.invoke(self, "ifBranchName", [value, operator]))

    @jsii.member(jsii_name="ifFullRepositoryId")
    def if_full_repository_id(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "CodestarConnections":
        '''(experimental) Filters access by the repository that is passed in the request.

        Applies only to UseConnection requests for access to a specific repository

        https://docs.aws.amazon.com/dtconsole/latest/userguide/security-iam.html#permissions-reference-connections-use

        Applies to actions:

        - .toUseConnection()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8a4e224d126186081a89302b159abb9c60a4b8f3dea19b1f0737d29215a760f6)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("CodestarConnections", jsii.invoke(self, "ifFullRepositoryId", [value, operator]))

    @jsii.member(jsii_name="ifHostArn")
    def if_host_arn(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "CodestarConnections":
        '''(experimental) Filters access by the host resource associated with the connection used in the request.

        https://docs.aws.amazon.com/dtconsole/latest/userguide/security-iam.html#permissions-reference-connections-hosts

        Applies to actions:

        - .toRegisterAppCode()
        - .toStartAppRegistrationHandshake()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3cc9753c5ff1ef582b0187d8b85e03ff0ce19be3fa295b6831cf547af7adf12b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("CodestarConnections", jsii.invoke(self, "ifHostArn", [value, operator]))

    @jsii.member(jsii_name="ifInstallationId")
    def if_installation_id(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "CodestarConnections":
        '''(experimental) Filters access by the third-party ID (such as the Bitbucket App installation ID for CodeStar Connections) that is used to update a Connection.

        Allows you to restrict which third-party App installations can be used to make a Connection

        https://docs.aws.amazon.com/dtconsole/latest/userguide/security-iam.html#permissions-reference-connections-handshake

        Applies to actions:

        - .toUpdateConnectionInstallation()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bc9bdbc287fbdf7f18f4082eae991462934d73cf71af1113f6f51acebe7f0115)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("CodestarConnections", jsii.invoke(self, "ifInstallationId", [value, operator]))

    @jsii.member(jsii_name="ifOwnerId")
    def if_owner_id(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "CodestarConnections":
        '''(experimental) Filters access by the owner of the third-party repository.

        Applies only to UseConnection requests for access to repositories owned by a specific user

        https://docs.aws.amazon.com/dtconsole/latest/userguide/security-iam.html#permissions-reference-connections-use

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__62d19c8ea6e5e18d00111edea3d1ee3ccd2910833430982028e47492f2ffead5)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("CodestarConnections", jsii.invoke(self, "ifOwnerId", [value, operator]))

    @jsii.member(jsii_name="ifPassedToService")
    def if_passed_to_service(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "CodestarConnections":
        '''(experimental) Filters access by the service to which the principal is allowed to pass a Connection.

        https://docs.aws.amazon.com/dtconsole/latest/userguide/security-iam.html#permissions-reference-connections-passconnection

        Applies to actions:

        - .toPassConnection()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4d46d400dc98484b1d8d0620232cb3e07eb0876fb7c975c7f2f3b44406f5d5e7)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("CodestarConnections", jsii.invoke(self, "ifPassedToService", [value, operator]))

    @jsii.member(jsii_name="ifProviderAction")
    def if_provider_action(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "CodestarConnections":
        '''(experimental) Filters access by the provider action in a UseConnection request such as ListRepositories. See documentation for all valid values.

        https://docs.aws.amazon.com/dtconsole/latest/userguide/security-iam.html#permissions-reference-connections-access

        Applies to actions:

        - .toUseConnection()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__743768bb3b9a85dd1bdb3a2a6641b80c8ad0da86b926b521cd46035fd44a77df)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("CodestarConnections", jsii.invoke(self, "ifProviderAction", [value, operator]))

    @jsii.member(jsii_name="ifProviderPermissionsRequired")
    def if_provider_permissions_required(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "CodestarConnections":
        '''(experimental) Filters access by the write permissions of a provider action in a UseConnection request.

        Valid types include read_only and read_write

        https://docs.aws.amazon.com/dtconsole/latest/userguide/security-iam.html#permissions-reference-connections-use

        Applies to actions:

        - .toUseConnection()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8455d2d0e92e4f8d4d69c9610b01a527949e4641bc88d520e7bb2efd9fe30c6d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("CodestarConnections", jsii.invoke(self, "ifProviderPermissionsRequired", [value, operator]))

    @jsii.member(jsii_name="ifProviderType")
    def if_provider_type(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "CodestarConnections":
        '''(experimental) Filters access by the type of third-party provider passed in the request.

        https://docs.aws.amazon.com/dtconsole/latest/userguide/security-iam.html#permissions-reference-connections-managing

        Applies to actions:

        - .toCreateConnection()
        - .toCreateHost()
        - .toGetIndividualAccessToken()
        - .toGetInstallationUrl()
        - .toStartOAuthHandshake()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__145add1dc34fb47eab0225a096105beea101675deb064aa0dd7c505904c23d02)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("CodestarConnections", jsii.invoke(self, "ifProviderType", [value, operator]))

    @jsii.member(jsii_name="ifProviderTypeFilter")
    def if_provider_type_filter(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "CodestarConnections":
        '''(experimental) Filters access by the type of third-party provider used to filter results.

        https://docs.aws.amazon.com/dtconsole/latest/userguide/security-iam.html#permissions-reference-connections-managing

        Applies to actions:

        - .toListConnections()
        - .toListHosts()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fb25ac304b230e4e12f655608be1eb0020ff053f46f7f92c6c3ca3fccfdae7f7)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("CodestarConnections", jsii.invoke(self, "ifProviderTypeFilter", [value, operator]))

    @jsii.member(jsii_name="ifRepositoryName")
    def if_repository_name(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "CodestarConnections":
        '''(experimental) Filters access by the repository name that is passed in the request.

        Applies only to UseConnection requests for creating new repositories

        https://docs.aws.amazon.com/dtconsole/latest/userguide/security-iam.html#permissions-reference-connections-use

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__63f131d2c232d365265ad8a2b09bd6577f540b394ff7e876f4dae68e119e3d49)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("CodestarConnections", jsii.invoke(self, "ifRepositoryName", [value, operator]))

    @jsii.member(jsii_name="onConnection")
    def on_connection(
        self,
        connection_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "CodestarConnections":
        '''(experimental) Adds a resource of type Connection to the statement.

        https://docs.aws.amazon.com/dtconsole/latest/userguide/connections.html

        :param connection_id: - Identifier for the connectionId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__46eb233d8c1a1eb9ee9c060eb9c3d05d463f9ea637e644c42a20ab29c6d09145)
            check_type(argname="argument connection_id", value=connection_id, expected_type=type_hints["connection_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("CodestarConnections", jsii.invoke(self, "onConnection", [connection_id, account, region, partition]))

    @jsii.member(jsii_name="onHost")
    def on_host(
        self,
        host_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "CodestarConnections":
        '''(experimental) Adds a resource of type Host to the statement.

        https://docs.aws.amazon.com/dtconsole/latest/userguide/connections-hosts.html

        :param host_id: - Identifier for the hostId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__cfef3705d0266472ce518cd0a0aa7bbb78fec8f8c27764e4b27c2bb9a439fb3f)
            check_type(argname="argument host_id", value=host_id, expected_type=type_hints["host_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("CodestarConnections", jsii.invoke(self, "onHost", [host_id, account, region, partition]))

    @jsii.member(jsii_name="toCreateConnection")
    def to_create_connection(self) -> "CodestarConnections":
        '''(experimental) Grants permission to create a Connection resource.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifProviderType()

        https://docs.aws.amazon.com/codestar-connections/latest/APIReference/API_CreateConnection.html

        :stability: experimental
        '''
        return typing.cast("CodestarConnections", jsii.invoke(self, "toCreateConnection", []))

    @jsii.member(jsii_name="toCreateHost")
    def to_create_host(self) -> "CodestarConnections":
        '''(experimental) Grants permission to create a host resource.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifProviderType()

        https://docs.aws.amazon.com/codestar-connections/latest/APIReference/API_CreateHost.html

        :stability: experimental
        '''
        return typing.cast("CodestarConnections", jsii.invoke(self, "toCreateHost", []))

    @jsii.member(jsii_name="toDeleteConnection")
    def to_delete_connection(self) -> "CodestarConnections":
        '''(experimental) Grants permission to delete a Connection resource.

        Access Level: Write

        https://docs.aws.amazon.com/codestar-connections/latest/APIReference/API_DeleteConnection.html

        :stability: experimental
        '''
        return typing.cast("CodestarConnections", jsii.invoke(self, "toDeleteConnection", []))

    @jsii.member(jsii_name="toDeleteHost")
    def to_delete_host(self) -> "CodestarConnections":
        '''(experimental) Grants permission to delete a host resource.

        Access Level: Write

        https://docs.aws.amazon.com/codestar-connections/latest/APIReference/API_DeleteHost.html

        :stability: experimental
        '''
        return typing.cast("CodestarConnections", jsii.invoke(self, "toDeleteHost", []))

    @jsii.member(jsii_name="toGetConnection")
    def to_get_connection(self) -> "CodestarConnections":
        '''(experimental) Grants permission to get details about a Connection resource.

        Access Level: Read

        https://docs.aws.amazon.com/codestar-connections/latest/APIReference/API_GetConnection.html

        :stability: experimental
        '''
        return typing.cast("CodestarConnections", jsii.invoke(self, "toGetConnection", []))

    @jsii.member(jsii_name="toGetHost")
    def to_get_host(self) -> "CodestarConnections":
        '''(experimental) Grants permission to get details about a host resource.

        Access Level: Read

        https://docs.aws.amazon.com/codestar-connections/latest/APIReference/API_GetHost.html

        :stability: experimental
        '''
        return typing.cast("CodestarConnections", jsii.invoke(self, "toGetHost", []))

    @jsii.member(jsii_name="toGetIndividualAccessToken")
    def to_get_individual_access_token(self) -> "CodestarConnections":
        '''(experimental) Grants permission to associate a third party, such as a Bitbucket App installation, with a Connection.

        Access Level: Read

        Possible conditions:

        - .ifProviderType()

        Dependent actions:

        - codestar-connections:StartOAuthHandshake

        https://docs.aws.amazon.com/dtconsole/latest/userguide/security-iam.html#permissions-reference-connections-handshake

        :stability: experimental
        '''
        return typing.cast("CodestarConnections", jsii.invoke(self, "toGetIndividualAccessToken", []))

    @jsii.member(jsii_name="toGetInstallationUrl")
    def to_get_installation_url(self) -> "CodestarConnections":
        '''(experimental) Grants permission to associate a third party, such as a Bitbucket App installation, with a Connection.

        Access Level: Read

        Possible conditions:

        - .ifProviderType()

        https://docs.aws.amazon.com/dtconsole/latest/userguide/security-iam.html#permissions-reference-connections-handshake

        :stability: experimental
        '''
        return typing.cast("CodestarConnections", jsii.invoke(self, "toGetInstallationUrl", []))

    @jsii.member(jsii_name="toListConnections")
    def to_list_connections(self) -> "CodestarConnections":
        '''(experimental) Grants permission to list Connection resources.

        Access Level: List

        Possible conditions:

        - .ifProviderTypeFilter()

        https://docs.aws.amazon.com/codestar-connections/latest/APIReference/API_ListConnections.html

        :stability: experimental
        '''
        return typing.cast("CodestarConnections", jsii.invoke(self, "toListConnections", []))

    @jsii.member(jsii_name="toListHosts")
    def to_list_hosts(self) -> "CodestarConnections":
        '''(experimental) Grants permission to list host resources.

        Access Level: List

        Possible conditions:

        - .ifProviderTypeFilter()

        https://docs.aws.amazon.com/codestar-connections/latest/APIReference/API_ListHosts.html

        :stability: experimental
        '''
        return typing.cast("CodestarConnections", jsii.invoke(self, "toListHosts", []))

    @jsii.member(jsii_name="toListInstallationTargets")
    def to_list_installation_targets(self) -> "CodestarConnections":
        '''(experimental) Grants permission to associate a third party, such as a Bitbucket App installation, with a Connection.

        Access Level: List

        Dependent actions:

        - codestar-connections:GetIndividualAccessToken
        - codestar-connections:StartOAuthHandshake

        https://docs.aws.amazon.com/dtconsole/latest/userguide/security-iam.html#permissions-reference-connections-handshake

        :stability: experimental
        '''
        return typing.cast("CodestarConnections", jsii.invoke(self, "toListInstallationTargets", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "CodestarConnections":
        '''(experimental) Gets the set of key-value pairs that are used to manage the resource.

        Access Level: List

        https://docs.aws.amazon.com/codestar-connections/latest/APIReference/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("CodestarConnections", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toPassConnection")
    def to_pass_connection(self) -> "CodestarConnections":
        '''(experimental) Grants permission to pass a Connection resource to an AWS service that accepts a Connection ARN as input, such as codepipeline:CreatePipeline.

        Access Level: Read

        Possible conditions:

        - .ifPassedToService()

        https://docs.aws.amazon.com/dtconsole/latest/userguide/security-iam.html#permissions-reference-connections-passconnection

        :stability: experimental
        '''
        return typing.cast("CodestarConnections", jsii.invoke(self, "toPassConnection", []))

    @jsii.member(jsii_name="toRegisterAppCode")
    def to_register_app_code(self) -> "CodestarConnections":
        '''(experimental) Grants permission to associate a third party server, such as a GitHub Enterprise Server instance, with a Host.

        Access Level: Read

        Possible conditions:

        - .ifHostArn()

        https://docs.aws.amazon.com/dtconsole/latest/userguide/security-iam.html#connections-permissions-actions-host-registration

        :stability: experimental
        '''
        return typing.cast("CodestarConnections", jsii.invoke(self, "toRegisterAppCode", []))

    @jsii.member(jsii_name="toStartAppRegistrationHandshake")
    def to_start_app_registration_handshake(self) -> "CodestarConnections":
        '''(experimental) Grants permission to associate a third party server, such as a GitHub Enterprise Server instance, with a Host.

        Access Level: Read

        Possible conditions:

        - .ifHostArn()

        https://docs.aws.amazon.com/dtconsole/latest/userguide/security-iam.html#connections-permissions-actions-host-registration

        :stability: experimental
        '''
        return typing.cast("CodestarConnections", jsii.invoke(self, "toStartAppRegistrationHandshake", []))

    @jsii.member(jsii_name="toStartOAuthHandshake")
    def to_start_o_auth_handshake(self) -> "CodestarConnections":
        '''(experimental) Grants permission to associate a third party, such as a Bitbucket App installation, with a Connection.

        Access Level: Read

        Possible conditions:

        - .ifProviderType()

        https://docs.aws.amazon.com/dtconsole/latest/userguide/security-iam.html#permissions-reference-connections-handshake

        :stability: experimental
        '''
        return typing.cast("CodestarConnections", jsii.invoke(self, "toStartOAuthHandshake", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "CodestarConnections":
        '''(experimental) Adds to or modifies the tags of the given resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/codestar-connections/latest/APIReference/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("CodestarConnections", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "CodestarConnections":
        '''(experimental) Removes tags from an AWS resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/codestar-connections/latest/APIReference/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("CodestarConnections", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateConnectionInstallation")
    def to_update_connection_installation(self) -> "CodestarConnections":
        '''(experimental) Grants permission to update a Connection resource with an installation of the CodeStar Connections App.

        Access Level: Write

        Possible conditions:

        - .ifInstallationId()

        Dependent actions:

        - codestar-connections:GetIndividualAccessToken
        - codestar-connections:GetInstallationUrl
        - codestar-connections:ListInstallationTargets
        - codestar-connections:StartOAuthHandshake

        https://docs.aws.amazon.com/dtconsole/latest/userguide/security-iam.html#permissions-reference-connections-handshake

        :stability: experimental
        '''
        return typing.cast("CodestarConnections", jsii.invoke(self, "toUpdateConnectionInstallation", []))

    @jsii.member(jsii_name="toUpdateHost")
    def to_update_host(self) -> "CodestarConnections":
        '''(experimental) Grants permission to update a host resource.

        Access Level: Write

        https://docs.aws.amazon.com/codestar-connections/latest/APIReference/API_UpdateHost.html

        :stability: experimental
        '''
        return typing.cast("CodestarConnections", jsii.invoke(self, "toUpdateHost", []))

    @jsii.member(jsii_name="toUseConnection")
    def to_use_connection(self) -> "CodestarConnections":
        '''(experimental) Grants permission to use a Connection resource to call provider actions.

        Access Level: Read

        Possible conditions:

        - .ifFullRepositoryId()
        - .ifProviderAction()
        - .ifProviderPermissionsRequired()

        https://docs.aws.amazon.com/dtconsole/latest/userguide/security-iam.html#permissions-reference-connections-use

        :stability: experimental
        '''
        return typing.cast("CodestarConnections", jsii.invoke(self, "toUseConnection", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1200489d4924afb972456bd81d719eb7469d2d6ebf0ba96655e129f1a41f7db9)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d201537289fd7b1a20725169850a9f73abbcdd649f92abf96e0b749416f90935)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class CodestarNotifications(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.CodestarNotifications",
):
    '''(experimental) Statement provider for service `codestar-notifications <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awscodestarnotifications.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `codestar-notifications <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awscodestarnotifications.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="ifNotificationsForResource")
    def if_notifications_for_resource(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "CodestarNotifications":
        '''(experimental) Filters access based on the ARN of the resource for which notifications are configured.

        https://docs.aws.amazon.com/codestar-notifications/latest/userguide/security_iam_id-based-policy-examples.html

        Applies to actions:

        - .toCreateNotificationRule()
        - .toDeleteNotificationRule()
        - .toDescribeNotificationRule()
        - .toSubscribe()
        - .toUnsubscribe()
        - .toUpdateNotificationRule()

        :param value: The value(s) to check.
        :param operator: Works with `arn operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_ARN>`_. **Default:** ``ArnLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__15e3bfc15a2fb0a72d2e04cd93a0601c92fa9792f97df0567f9d574201c2df0f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("CodestarNotifications", jsii.invoke(self, "ifNotificationsForResource", [value, operator]))

    @jsii.member(jsii_name="onNotificationrule")
    def on_notificationrule(
        self,
        notification_rule_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "CodestarNotifications":
        '''(experimental) Adds a resource of type notificationrule to the statement.

        https://docs.aws.amazon.com/codestar-notifications/latest/userguide/security_iam_service-with-iam.html

        :param notification_rule_id: - Identifier for the notificationRuleId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__70644ca165a196b0b2468b545e8cd81b71a3ee8a879c99fb659ced9f336e1865)
            check_type(argname="argument notification_rule_id", value=notification_rule_id, expected_type=type_hints["notification_rule_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("CodestarNotifications", jsii.invoke(self, "onNotificationrule", [notification_rule_id, account, region, partition]))

    @jsii.member(jsii_name="toCreateNotificationRule")
    def to_create_notification_rule(self) -> "CodestarNotifications":
        '''(experimental) Grants permission to create a notification rule for a resource.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifNotificationsForResource()

        https://docs.aws.amazon.com/codestar-notifications/latest/APIReference/API_CreateNotificationRule.html

        :stability: experimental
        '''
        return typing.cast("CodestarNotifications", jsii.invoke(self, "toCreateNotificationRule", []))

    @jsii.member(jsii_name="toDeleteNotificationRule")
    def to_delete_notification_rule(self) -> "CodestarNotifications":
        '''(experimental) Grants permission to delete a notification rule for a resource.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()
        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifNotificationsForResource()

        https://docs.aws.amazon.com/codestar-notifications/latest/APIReference/API_DeleteNotificationRule.html

        :stability: experimental
        '''
        return typing.cast("CodestarNotifications", jsii.invoke(self, "toDeleteNotificationRule", []))

    @jsii.member(jsii_name="toDeleteTarget")
    def to_delete_target(self) -> "CodestarNotifications":
        '''(experimental) Grants permission to delete a target for a notification rule.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/codestar-notifications/latest/APIReference/API_DeleteTarget.html

        :stability: experimental
        '''
        return typing.cast("CodestarNotifications", jsii.invoke(self, "toDeleteTarget", []))

    @jsii.member(jsii_name="toDescribeNotificationRule")
    def to_describe_notification_rule(self) -> "CodestarNotifications":
        '''(experimental) Grants permission to get information about a notification rule.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()
        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifNotificationsForResource()

        https://docs.aws.amazon.com/codestar-notifications/latest/APIReference/API_DescribeNotificationRule.html

        :stability: experimental
        '''
        return typing.cast("CodestarNotifications", jsii.invoke(self, "toDescribeNotificationRule", []))

    @jsii.member(jsii_name="toListEventTypes")
    def to_list_event_types(self) -> "CodestarNotifications":
        '''(experimental) Grants permission to list notifications event types.

        Access Level: List

        https://docs.aws.amazon.com/codestar-notifications/latest/APIReference/API_ListEventTypes.html

        :stability: experimental
        '''
        return typing.cast("CodestarNotifications", jsii.invoke(self, "toListEventTypes", []))

    @jsii.member(jsii_name="toListNotificationRules")
    def to_list_notification_rules(self) -> "CodestarNotifications":
        '''(experimental) Grants permission to list notification rules in an AWS account.

        Access Level: List

        https://docs.aws.amazon.com/codestar-notifications/latest/APIReference/API_ListNotificationRules.html

        :stability: experimental
        '''
        return typing.cast("CodestarNotifications", jsii.invoke(self, "toListNotificationRules", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "CodestarNotifications":
        '''(experimental) Grants permission to list the tags attached to a notification rule resource ARN.

        Access Level: List

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/codestar-notifications/latest/APIReference/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("CodestarNotifications", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toListTargets")
    def to_list_targets(self) -> "CodestarNotifications":
        '''(experimental) Grants permission to list the notification rule targets for an AWS account.

        Access Level: List

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/codestar-notifications/latest/APIReference/API_ListTargets.html

        :stability: experimental
        '''
        return typing.cast("CodestarNotifications", jsii.invoke(self, "toListTargets", []))

    @jsii.member(jsii_name="toSubscribe")
    def to_subscribe(self) -> "CodestarNotifications":
        '''(experimental) Grants permission to create an association between a notification rule and an Amazon SNS topic.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()
        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifNotificationsForResource()

        https://docs.aws.amazon.com/codestar-notifications/latest/APIReference/API_Subscribe.html

        :stability: experimental
        '''
        return typing.cast("CodestarNotifications", jsii.invoke(self, "toSubscribe", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "CodestarNotifications":
        '''(experimental) Grants permission to attach resource tags to a notification rule resource ARN.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsResourceTag()
        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/codestar-notifications/latest/APIReference/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("CodestarNotifications", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUnsubscribe")
    def to_unsubscribe(self) -> "CodestarNotifications":
        '''(experimental) Grants permission to remove an association between a notification rule and an Amazon SNS topic.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()
        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifNotificationsForResource()

        https://docs.aws.amazon.com/codestar-notifications/latest/APIReference/API_Unsubscribe.html

        :stability: experimental
        '''
        return typing.cast("CodestarNotifications", jsii.invoke(self, "toUnsubscribe", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "CodestarNotifications":
        '''(experimental) Grants permission to disassociate resource tags from a notification rule resource ARN.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/codestar-notifications/latest/APIReference/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("CodestarNotifications", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateNotificationRule")
    def to_update_notification_rule(self) -> "CodestarNotifications":
        '''(experimental) Grants permission to change a notification rule for a resource.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()
        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifNotificationsForResource()

        https://docs.aws.amazon.com/codestar-notifications/latest/APIReference/API_UpdateNotificationRule.html

        :stability: experimental
        '''
        return typing.cast("CodestarNotifications", jsii.invoke(self, "toUpdateNotificationRule", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__75ca99649a6305827bc38f4b823c3e97eb179087a94fac52494b3e57a7773abc)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__dbf368fb13beb651b4fe022869606e09194be0f8b30ee45131ce691cc992bfb6)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Codewhisperer(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Codewhisperer",
):
    '''(experimental) Statement provider for service `codewhisperer <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazoncodewhisperer.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `codewhisperer <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazoncodewhisperer.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onProfile")
    def on_profile(
        self,
        identifier: builtins.str,
        account: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Codewhisperer":
        '''(experimental) Adds a resource of type profile to the statement.

        https://docs.aws.amazon.com/codewhisperer/latest/dg/profile.html

        :param identifier: - Identifier for the identifier.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__670d43fb24604c3a782f78dddf9e688442ef50c023d2fb03cadbd50648855d55)
            check_type(argname="argument identifier", value=identifier, expected_type=type_hints["identifier"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Codewhisperer", jsii.invoke(self, "onProfile", [identifier, account, partition]))

    @jsii.member(jsii_name="toCreateProfile")
    def to_create_profile(self) -> "Codewhisperer":
        '''(experimental) Grants permission to invoke CreateProfile on CodeWhisperer.

        Access Level: Write

        https://docs.aws.amazon.com/codewhisperer/latest/dg/API_CreateProfile.html

        :stability: experimental
        '''
        return typing.cast("Codewhisperer", jsii.invoke(self, "toCreateProfile", []))

    @jsii.member(jsii_name="toGenerateRecommendations")
    def to_generate_recommendations(self) -> "Codewhisperer":
        '''(experimental) Grants permission to invoke GenerateRecommendations on CodeWhisperer.

        Access Level: Read

        https://docs.aws.amazon.com/codewhisperer/latest/dg/API_GenerateRecommendations.html

        :stability: experimental
        '''
        return typing.cast("Codewhisperer", jsii.invoke(self, "toGenerateRecommendations", []))

    @jsii.member(jsii_name="toListProfiles")
    def to_list_profiles(self) -> "Codewhisperer":
        '''(experimental) Grants permission to invoke ListProfiles on CodeWhisperer.

        Access Level: List

        https://docs.aws.amazon.com/codewhisperer/latest/dg/API_ListProfiles.html

        :stability: experimental
        '''
        return typing.cast("Codewhisperer", jsii.invoke(self, "toListProfiles", []))

    @jsii.member(jsii_name="toUpdateProfile")
    def to_update_profile(self) -> "Codewhisperer":
        '''(experimental) Grants permission to invoke UpdateProfile on CodeWhisperer.

        Access Level: Write

        https://docs.aws.amazon.com/codewhisperer/latest/dg/API_UpdateProfile.html

        :stability: experimental
        '''
        return typing.cast("Codewhisperer", jsii.invoke(self, "toUpdateProfile", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2829404fd4d6b127846161d39b62137be8db997ffe1aff5b89f1690b4191ccee)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__441120fe1657203fe4e4098db175f623c06a7cf9fda077e186ef87cff21a6077)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class CognitoIdentity(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.CognitoIdentity",
):
    '''(experimental) Statement provider for service `cognito-identity <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazoncognitoidentity.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `cognito-identity <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazoncognitoidentity.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onIdentitypool")
    def on_identitypool(
        self,
        identity_pool_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "CognitoIdentity":
        '''(experimental) Adds a resource of type identitypool to the statement.

        https://docs.aws.amazon.com/cognito/latest/developerguide/identity-pools.html

        :param identity_pool_id: - Identifier for the identityPoolId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ff1d2dc2873d9582b5ecfe40fb681915f505c9d8c2fd5747c8765084de2c8388)
            check_type(argname="argument identity_pool_id", value=identity_pool_id, expected_type=type_hints["identity_pool_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("CognitoIdentity", jsii.invoke(self, "onIdentitypool", [identity_pool_id, account, region, partition]))

    @jsii.member(jsii_name="toCreateIdentityPool")
    def to_create_identity_pool(self) -> "CognitoIdentity":
        '''(experimental) Grants permission to create a new identity pool.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/cognitoidentity/latest/APIReference/API_CreateIdentityPool.html

        :stability: experimental
        '''
        return typing.cast("CognitoIdentity", jsii.invoke(self, "toCreateIdentityPool", []))

    @jsii.member(jsii_name="toDeleteIdentities")
    def to_delete_identities(self) -> "CognitoIdentity":
        '''(experimental) Grants permission to delete identities from an identity pool.

        You can specify a list of 1-60 identities that you want to delete

        Access Level: Write

        https://docs.aws.amazon.com/cognitoidentity/latest/APIReference/API_DeleteIdentities.html

        :stability: experimental
        '''
        return typing.cast("CognitoIdentity", jsii.invoke(self, "toDeleteIdentities", []))

    @jsii.member(jsii_name="toDeleteIdentityPool")
    def to_delete_identity_pool(self) -> "CognitoIdentity":
        '''(experimental) Grants permission to delete a user pool.

        Once a pool is deleted, users will not be able to authenticate with the pool

        Access Level: Write

        https://docs.aws.amazon.com/cognitoidentity/latest/APIReference/API_DeleteIdentityPool.html

        :stability: experimental
        '''
        return typing.cast("CognitoIdentity", jsii.invoke(self, "toDeleteIdentityPool", []))

    @jsii.member(jsii_name="toDescribeIdentity")
    def to_describe_identity(self) -> "CognitoIdentity":
        '''(experimental) Grants permission to return metadata related to the given identity, including when the identity was created and any associated linked logins.

        Access Level: Read

        https://docs.aws.amazon.com/cognitoidentity/latest/APIReference/API_DescribeIdentity.html

        :stability: experimental
        '''
        return typing.cast("CognitoIdentity", jsii.invoke(self, "toDescribeIdentity", []))

    @jsii.member(jsii_name="toDescribeIdentityPool")
    def to_describe_identity_pool(self) -> "CognitoIdentity":
        '''(experimental) Grants permission to get details about a particular identity pool, including the pool name, ID description, creation date, and current number of users.

        Access Level: Read

        https://docs.aws.amazon.com/cognitoidentity/latest/APIReference/API_DescribeIdentityPool.html

        :stability: experimental
        '''
        return typing.cast("CognitoIdentity", jsii.invoke(self, "toDescribeIdentityPool", []))

    @jsii.member(jsii_name="toGetCredentialsForIdentity")
    def to_get_credentials_for_identity(self) -> "CognitoIdentity":
        '''(experimental) Grants permission to return credentials for the provided identity ID.

        Access Level: Read

        https://docs.aws.amazon.com/cognitoidentity/latest/APIReference/API_GetCredentialsForIdentity.html

        :stability: experimental
        '''
        return typing.cast("CognitoIdentity", jsii.invoke(self, "toGetCredentialsForIdentity", []))

    @jsii.member(jsii_name="toGetId")
    def to_get_id(self) -> "CognitoIdentity":
        '''(experimental) Grants permission to generate (or retrieve) a Cognito ID. Supplying multiple logins will create an implicit linked account.

        Access Level: Write

        https://docs.aws.amazon.com/cognitoidentity/latest/APIReference/API_GetId.html

        :stability: experimental
        '''
        return typing.cast("CognitoIdentity", jsii.invoke(self, "toGetId", []))

    @jsii.member(jsii_name="toGetIdentityPoolRoles")
    def to_get_identity_pool_roles(self) -> "CognitoIdentity":
        '''(experimental) Grants permission to get the roles for an identity pool.

        Access Level: Read

        https://docs.aws.amazon.com/cognitoidentity/latest/APIReference/API_GetIdentityPoolRoles.html

        :stability: experimental
        '''
        return typing.cast("CognitoIdentity", jsii.invoke(self, "toGetIdentityPoolRoles", []))

    @jsii.member(jsii_name="toGetOpenIdToken")
    def to_get_open_id_token(self) -> "CognitoIdentity":
        '''(experimental) Grants permission to get an OpenID token, using a known Cognito ID.

        Access Level: Read

        https://docs.aws.amazon.com/cognitoidentity/latest/APIReference/API_GetOpenIdToken.html

        :stability: experimental
        '''
        return typing.cast("CognitoIdentity", jsii.invoke(self, "toGetOpenIdToken", []))

    @jsii.member(jsii_name="toGetOpenIdTokenForDeveloperIdentity")
    def to_get_open_id_token_for_developer_identity(self) -> "CognitoIdentity":
        '''(experimental) Grants permission to register (or retrieve) a Cognito IdentityId and an OpenID Connect token for a user authenticated by your backend authentication process.

        Access Level: Read

        https://docs.aws.amazon.com/cognitoidentity/latest/APIReference/API_GetOpenIdTokenForDeveloperIdentity.html

        :stability: experimental
        '''
        return typing.cast("CognitoIdentity", jsii.invoke(self, "toGetOpenIdTokenForDeveloperIdentity", []))

    @jsii.member(jsii_name="toGetPrincipalTagAttributeMap")
    def to_get_principal_tag_attribute_map(self) -> "CognitoIdentity":
        '''(experimental) Grants permission to get the principal tags for an identity pool and provider.

        Access Level: Read

        https://docs.aws.amazon.com/cognitoidentity/latest/APIReference/API_GetPrincipalTagAttributeMap.html

        :stability: experimental
        '''
        return typing.cast("CognitoIdentity", jsii.invoke(self, "toGetPrincipalTagAttributeMap", []))

    @jsii.member(jsii_name="toListIdentities")
    def to_list_identities(self) -> "CognitoIdentity":
        '''(experimental) Grants permission to list the identities in an identity pool.

        Access Level: List

        https://docs.aws.amazon.com/cognitoidentity/latest/APIReference/API_ListIdentities.html

        :stability: experimental
        '''
        return typing.cast("CognitoIdentity", jsii.invoke(self, "toListIdentities", []))

    @jsii.member(jsii_name="toListIdentityPools")
    def to_list_identity_pools(self) -> "CognitoIdentity":
        '''(experimental) Grants permission to list all of the Cognito identity pools registered for your account.

        Access Level: List

        https://docs.aws.amazon.com/cognitoidentity/latest/APIReference/API_ListIdentityPools.html

        :stability: experimental
        '''
        return typing.cast("CognitoIdentity", jsii.invoke(self, "toListIdentityPools", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "CognitoIdentity":
        '''(experimental) Grants permission to list the tags that are assigned to an Amazon Cognito identity pool.

        Access Level: Read

        https://docs.aws.amazon.com/cognitoidentity/latest/APIReference/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("CognitoIdentity", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toLookupDeveloperIdentity")
    def to_lookup_developer_identity(self) -> "CognitoIdentity":
        '''(experimental) Grants permission to retrieve the IdentityId associated with a DeveloperUserIdentifier or the list of DeveloperUserIdentifiers associated with an IdentityId for an existing identity.

        Access Level: Read

        https://docs.aws.amazon.com/cognitoidentity/latest/APIReference/API_LookupDeveloperIdentity.html

        :stability: experimental
        '''
        return typing.cast("CognitoIdentity", jsii.invoke(self, "toLookupDeveloperIdentity", []))

    @jsii.member(jsii_name="toMergeDeveloperIdentities")
    def to_merge_developer_identities(self) -> "CognitoIdentity":
        '''(experimental) Grants permission to merge two users having different IdentityIds, existing in the same identity pool, and identified by the same developer provider.

        Access Level: Write

        https://docs.aws.amazon.com/cognitoidentity/latest/APIReference/API_MergeDeveloperIdentities.html

        :stability: experimental
        '''
        return typing.cast("CognitoIdentity", jsii.invoke(self, "toMergeDeveloperIdentities", []))

    @jsii.member(jsii_name="toSetIdentityPoolRoles")
    def to_set_identity_pool_roles(self) -> "CognitoIdentity":
        '''(experimental) Grants permission to set the roles for an identity pool.

        These roles are used when making calls to GetCredentialsForIdentity action

        Access Level: Write

        https://docs.aws.amazon.com/cognitoidentity/latest/APIReference/API_SetIdentityPoolRoles.html

        :stability: experimental
        '''
        return typing.cast("CognitoIdentity", jsii.invoke(self, "toSetIdentityPoolRoles", []))

    @jsii.member(jsii_name="toSetPrincipalTagAttributeMap")
    def to_set_principal_tag_attribute_map(self) -> "CognitoIdentity":
        '''(experimental) Grants permission to set the principal tags for an identity pool and provider.

        These tags are used when making calls to GetOpenIdToken action

        Access Level: Write

        https://docs.aws.amazon.com/cognitoidentity/latest/APIReference/API_SetPrincipalTagAttributeMap.html

        :stability: experimental
        '''
        return typing.cast("CognitoIdentity", jsii.invoke(self, "toSetPrincipalTagAttributeMap", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "CognitoIdentity":
        '''(experimental) Grants permission to assign a set of tags to an Amazon Cognito identity pool.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/cognitoidentity/latest/APIReference/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("CognitoIdentity", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUnlinkDeveloperIdentity")
    def to_unlink_developer_identity(self) -> "CognitoIdentity":
        '''(experimental) Grants permission to unlink a DeveloperUserIdentifier from an existing identity.

        Access Level: Write

        https://docs.aws.amazon.com/cognitoidentity/latest/APIReference/API_UnlinkDeveloperIdentity.html

        :stability: experimental
        '''
        return typing.cast("CognitoIdentity", jsii.invoke(self, "toUnlinkDeveloperIdentity", []))

    @jsii.member(jsii_name="toUnlinkIdentity")
    def to_unlink_identity(self) -> "CognitoIdentity":
        '''(experimental) Grants permission to unlink a federated identity from an existing account.

        Access Level: Write

        https://docs.aws.amazon.com/cognitoidentity/latest/APIReference/API_UnlinkIdentity.html

        :stability: experimental
        '''
        return typing.cast("CognitoIdentity", jsii.invoke(self, "toUnlinkIdentity", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "CognitoIdentity":
        '''(experimental) Grants permission to remove the specified tags from an Amazon Cognito identity pool.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/cognitoidentity/latest/APIReference/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("CognitoIdentity", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateIdentityPool")
    def to_update_identity_pool(self) -> "CognitoIdentity":
        '''(experimental) Grants permission to update an identity pool.

        Access Level: Write

        https://docs.aws.amazon.com/cognitoidentity/latest/APIReference/API_UpdateIdentityPool.html

        :stability: experimental
        '''
        return typing.cast("CognitoIdentity", jsii.invoke(self, "toUpdateIdentityPool", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ad2d4bbca6159eeadc8af44202bd1105f3d22f5bec3ba29a9cfd3cd66bf45c2c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8f5633bc4875449d67a071919581620028500b33f962a8df44fa2a3a6a542cad)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class CognitoIdp(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.CognitoIdp",
):
    '''(experimental) Statement provider for service `cognito-idp <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazoncognitouserpools.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `cognito-idp <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazoncognitouserpools.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onUserpool")
    def on_userpool(
        self,
        user_pool_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "CognitoIdp":
        '''(experimental) Adds a resource of type userpool to the statement.

        https://docs.aws.amazon.com/cognito/latest/developerguide/cognito-user-identity-pools.html

        :param user_pool_id: - Identifier for the userPoolId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0776706c1c7e78c912cb9160515116504039ce5c7f95b76a6c8e451b941b7151)
            check_type(argname="argument user_pool_id", value=user_pool_id, expected_type=type_hints["user_pool_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("CognitoIdp", jsii.invoke(self, "onUserpool", [user_pool_id, account, region, partition]))

    @jsii.member(jsii_name="onWebacl")
    def on_webacl(
        self,
        scope: builtins.str,
        name: builtins.str,
        id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "CognitoIdp":
        '''(experimental) Adds a resource of type webacl to the statement.

        https://docs.aws.amazon.com/cognito/latest/developerguide/user-pool-waf.html

        :param scope: - Identifier for the scope.
        :param name: - Identifier for the name.
        :param id: - Identifier for the id.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8bdc8fdf1d6b73d7d4ee292ecd4bfa1edb693f92ed9744eb6dbf689fdc9a409e)
            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("CognitoIdp", jsii.invoke(self, "onWebacl", [scope, name, id, account, region, partition]))

    @jsii.member(jsii_name="toAddCustomAttributes")
    def to_add_custom_attributes(self) -> "CognitoIdp":
        '''(experimental) Grants permission to add user attributes to the user pool schema.

        Access Level: Write

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_AddCustomAttributes.html

        :stability: experimental
        '''
        return typing.cast("CognitoIdp", jsii.invoke(self, "toAddCustomAttributes", []))

    @jsii.member(jsii_name="toAdminAddUserToGroup")
    def to_admin_add_user_to_group(self) -> "CognitoIdp":
        '''(experimental) Grants permission to add any user to any group.

        Access Level: Write

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_AdminAddUserToGroup.html

        :stability: experimental
        '''
        return typing.cast("CognitoIdp", jsii.invoke(self, "toAdminAddUserToGroup", []))

    @jsii.member(jsii_name="toAdminConfirmSignUp")
    def to_admin_confirm_sign_up(self) -> "CognitoIdp":
        '''(experimental) Grants permission to confirm any user's registration without a confirmation code.

        Access Level: Write

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_AdminConfirmSignUp.html

        :stability: experimental
        '''
        return typing.cast("CognitoIdp", jsii.invoke(self, "toAdminConfirmSignUp", []))

    @jsii.member(jsii_name="toAdminCreateUser")
    def to_admin_create_user(self) -> "CognitoIdp":
        '''(experimental) Grants permission to create new users and send welcome messages via email or SMS.

        Access Level: Write

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_AdminCreateUser.html

        :stability: experimental
        '''
        return typing.cast("CognitoIdp", jsii.invoke(self, "toAdminCreateUser", []))

    @jsii.member(jsii_name="toAdminDeleteUser")
    def to_admin_delete_user(self) -> "CognitoIdp":
        '''(experimental) Grants permission to delete any user.

        Access Level: Write

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_AdminDeleteUser.html

        :stability: experimental
        '''
        return typing.cast("CognitoIdp", jsii.invoke(self, "toAdminDeleteUser", []))

    @jsii.member(jsii_name="toAdminDeleteUserAttributes")
    def to_admin_delete_user_attributes(self) -> "CognitoIdp":
        '''(experimental) Grants permission to delete attributes from any user.

        Access Level: Write

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_AdminDeleteUserAttributes.html

        :stability: experimental
        '''
        return typing.cast("CognitoIdp", jsii.invoke(self, "toAdminDeleteUserAttributes", []))

    @jsii.member(jsii_name="toAdminDisableProviderForUser")
    def to_admin_disable_provider_for_user(self) -> "CognitoIdp":
        '''(experimental) Grants permission to unlink any user pool user from a third-party identity provider (IdP) user.

        Access Level: Write

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_AdminDisableProviderForUser.html

        :stability: experimental
        '''
        return typing.cast("CognitoIdp", jsii.invoke(self, "toAdminDisableProviderForUser", []))

    @jsii.member(jsii_name="toAdminDisableUser")
    def to_admin_disable_user(self) -> "CognitoIdp":
        '''(experimental) Grants permission to deactivate any user.

        Access Level: Write

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_AdminDisableUser.html

        :stability: experimental
        '''
        return typing.cast("CognitoIdp", jsii.invoke(self, "toAdminDisableUser", []))

    @jsii.member(jsii_name="toAdminEnableUser")
    def to_admin_enable_user(self) -> "CognitoIdp":
        '''(experimental) Grants permission to activate any user.

        Access Level: Write

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_AdminEnableUser.html

        :stability: experimental
        '''
        return typing.cast("CognitoIdp", jsii.invoke(self, "toAdminEnableUser", []))

    @jsii.member(jsii_name="toAdminForgetDevice")
    def to_admin_forget_device(self) -> "CognitoIdp":
        '''(experimental) Grants permission to deregister any user's devices.

        Access Level: Write

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_AdminForgetDevice.html

        :stability: experimental
        '''
        return typing.cast("CognitoIdp", jsii.invoke(self, "toAdminForgetDevice", []))

    @jsii.member(jsii_name="toAdminGetDevice")
    def to_admin_get_device(self) -> "CognitoIdp":
        '''(experimental) Grants permission to get information about any user's devices.

        Access Level: Read

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_AdminGetDevice.html

        :stability: experimental
        '''
        return typing.cast("CognitoIdp", jsii.invoke(self, "toAdminGetDevice", []))

    @jsii.member(jsii_name="toAdminGetUser")
    def to_admin_get_user(self) -> "CognitoIdp":
        '''(experimental) Grants permission to look up any user by user name.

        Access Level: Read

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_AdminGetUser.html

        :stability: experimental
        '''
        return typing.cast("CognitoIdp", jsii.invoke(self, "toAdminGetUser", []))

    @jsii.member(jsii_name="toAdminInitiateAuth")
    def to_admin_initiate_auth(self) -> "CognitoIdp":
        '''(experimental) Grants permission to authenticate any user.

        Access Level: Write

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_AdminInitiateAuth.html

        :stability: experimental
        '''
        return typing.cast("CognitoIdp", jsii.invoke(self, "toAdminInitiateAuth", []))

    @jsii.member(jsii_name="toAdminLinkProviderForUser")
    def to_admin_link_provider_for_user(self) -> "CognitoIdp":
        '''(experimental) Grants permission to link any user pool user to a third-party IdP user.

        Access Level: Write

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_AdminLinkProviderForUser.html

        :stability: experimental
        '''
        return typing.cast("CognitoIdp", jsii.invoke(self, "toAdminLinkProviderForUser", []))

    @jsii.member(jsii_name="toAdminListDevices")
    def to_admin_list_devices(self) -> "CognitoIdp":
        '''(experimental) Grants permission to list any user's remembered devices.

        Access Level: List

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_AdminListDevices.html

        :stability: experimental
        '''
        return typing.cast("CognitoIdp", jsii.invoke(self, "toAdminListDevices", []))

    @jsii.member(jsii_name="toAdminListGroupsForUser")
    def to_admin_list_groups_for_user(self) -> "CognitoIdp":
        '''(experimental) Grants permission to list the groups that any user belongs to.

        Access Level: List

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_AdminListGroupsForUser.html

        :stability: experimental
        '''
        return typing.cast("CognitoIdp", jsii.invoke(self, "toAdminListGroupsForUser", []))

    @jsii.member(jsii_name="toAdminListUserAuthEvents")
    def to_admin_list_user_auth_events(self) -> "CognitoIdp":
        '''(experimental) Grants permission to lists sign-in events for any user.

        Access Level: Read

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_AdminListUserAuthEvents.html

        :stability: experimental
        '''
        return typing.cast("CognitoIdp", jsii.invoke(self, "toAdminListUserAuthEvents", []))

    @jsii.member(jsii_name="toAdminRemoveUserFromGroup")
    def to_admin_remove_user_from_group(self) -> "CognitoIdp":
        '''(experimental) Grants permission to remove any user from any group.

        Access Level: Write

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_AdminRemoveUserFromGroup.html

        :stability: experimental
        '''
        return typing.cast("CognitoIdp", jsii.invoke(self, "toAdminRemoveUserFromGroup", []))

    @jsii.member(jsii_name="toAdminResetUserPassword")
    def to_admin_reset_user_password(self) -> "CognitoIdp":
        '''(experimental) Grants permission to reset any user's password.

        Access Level: Write

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_AdminResetUserPassword.html

        :stability: experimental
        '''
        return typing.cast("CognitoIdp", jsii.invoke(self, "toAdminResetUserPassword", []))

    @jsii.member(jsii_name="toAdminRespondToAuthChallenge")
    def to_admin_respond_to_auth_challenge(self) -> "CognitoIdp":
        '''(experimental) Grants permission to respond to an authentication challenge during the authentication of any user.

        Access Level: Write

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_AdminRespondToAuthChallenge.html

        :stability: experimental
        '''
        return typing.cast("CognitoIdp", jsii.invoke(self, "toAdminRespondToAuthChallenge", []))

    @jsii.member(jsii_name="toAdminSetUserMFAPreference")
    def to_admin_set_user_mfa_preference(self) -> "CognitoIdp":
        '''(experimental) Grants permission to set any user's preferred MFA method.

        Access Level: Write

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_AdminSetUserMFAPreference.html

        :stability: experimental
        '''
        return typing.cast("CognitoIdp", jsii.invoke(self, "toAdminSetUserMFAPreference", []))

    @jsii.member(jsii_name="toAdminSetUserPassword")
    def to_admin_set_user_password(self) -> "CognitoIdp":
        '''(experimental) Grants permission to set any user's password.

        Access Level: Write

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_AdminSetUserPassword.html

        :stability: experimental
        '''
        return typing.cast("CognitoIdp", jsii.invoke(self, "toAdminSetUserPassword", []))

    @jsii.member(jsii_name="toAdminSetUserSettings")
    def to_admin_set_user_settings(self) -> "CognitoIdp":
        '''(experimental) Grants permission to set user settings for any user.

        Access Level: Write

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_AdminSetUserSettings.html

        :stability: experimental
        '''
        return typing.cast("CognitoIdp", jsii.invoke(self, "toAdminSetUserSettings", []))

    @jsii.member(jsii_name="toAdminUpdateAuthEventFeedback")
    def to_admin_update_auth_event_feedback(self) -> "CognitoIdp":
        '''(experimental) Grants permission to update advanced security feedback for any user's authentication event.

        Access Level: Write

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_AdminUpdateAuthEventFeedback.html

        :stability: experimental
        '''
        return typing.cast("CognitoIdp", jsii.invoke(self, "toAdminUpdateAuthEventFeedback", []))

    @jsii.member(jsii_name="toAdminUpdateDeviceStatus")
    def to_admin_update_device_status(self) -> "CognitoIdp":
        '''(experimental) Grants permission to update the status of any user's remembered devices.

        Access Level: Write

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_AdminUpdateDeviceStatus.html

        :stability: experimental
        '''
        return typing.cast("CognitoIdp", jsii.invoke(self, "toAdminUpdateDeviceStatus", []))

    @jsii.member(jsii_name="toAdminUpdateUserAttributes")
    def to_admin_update_user_attributes(self) -> "CognitoIdp":
        '''(experimental) Grants permission to updates any user's standard or custom attributes.

        Access Level: Write

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_AdminUpdateUserAttributes.html

        :stability: experimental
        '''
        return typing.cast("CognitoIdp", jsii.invoke(self, "toAdminUpdateUserAttributes", []))

    @jsii.member(jsii_name="toAdminUserGlobalSignOut")
    def to_admin_user_global_sign_out(self) -> "CognitoIdp":
        '''(experimental) Grants permission to sign out any user from all sessions.

        Access Level: Write

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_AdminUserGlobalSignOut.html

        :stability: experimental
        '''
        return typing.cast("CognitoIdp", jsii.invoke(self, "toAdminUserGlobalSignOut", []))

    @jsii.member(jsii_name="toAssociateSoftwareToken")
    def to_associate_software_token(self) -> "CognitoIdp":
        '''(experimental) Returns a unique generated shared secret key code for the user account.

        Access Level: Write

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_AssociateSoftwareToken.html

        :stability: experimental
        '''
        return typing.cast("CognitoIdp", jsii.invoke(self, "toAssociateSoftwareToken", []))

    @jsii.member(jsii_name="toAssociateWebACL")
    def to_associate_web_acl(self) -> "CognitoIdp":
        '''(experimental) Grants permission to associate the user pool with an AWS WAF web ACL.

        Access Level: Write

        :stability: experimental
        '''
        return typing.cast("CognitoIdp", jsii.invoke(self, "toAssociateWebACL", []))

    @jsii.member(jsii_name="toChangePassword")
    def to_change_password(self) -> "CognitoIdp":
        '''(experimental) Changes the password for a specified user in a user pool.

        Access Level: Write

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_ChangePassword.html

        :stability: experimental
        '''
        return typing.cast("CognitoIdp", jsii.invoke(self, "toChangePassword", []))

    @jsii.member(jsii_name="toConfirmDevice")
    def to_confirm_device(self) -> "CognitoIdp":
        '''(experimental) Confirms tracking of the device. This API call is the call that begins device tracking.

        Access Level: Write

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_ConfirmDevice.html

        :stability: experimental
        '''
        return typing.cast("CognitoIdp", jsii.invoke(self, "toConfirmDevice", []))

    @jsii.member(jsii_name="toConfirmForgotPassword")
    def to_confirm_forgot_password(self) -> "CognitoIdp":
        '''(experimental) Allows a user to enter a confirmation code to reset a forgotten password.

        Access Level: Write

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_ConfirmForgotPassword.html

        :stability: experimental
        '''
        return typing.cast("CognitoIdp", jsii.invoke(self, "toConfirmForgotPassword", []))

    @jsii.member(jsii_name="toConfirmSignUp")
    def to_confirm_sign_up(self) -> "CognitoIdp":
        '''(experimental) Confirms registration of a user and handles the existing alias from a previous user.

        Access Level: Write

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_ConfirmSignUp.html

        :stability: experimental
        '''
        return typing.cast("CognitoIdp", jsii.invoke(self, "toConfirmSignUp", []))

    @jsii.member(jsii_name="toCreateGroup")
    def to_create_group(self) -> "CognitoIdp":
        '''(experimental) Grants permission to create new user pool groups.

        Access Level: Write

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_CreateGroup.html

        :stability: experimental
        '''
        return typing.cast("CognitoIdp", jsii.invoke(self, "toCreateGroup", []))

    @jsii.member(jsii_name="toCreateIdentityProvider")
    def to_create_identity_provider(self) -> "CognitoIdp":
        '''(experimental) Grants permission to add identity providers to user pools.

        Access Level: Write

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_CreateIdentityProvider.html

        :stability: experimental
        '''
        return typing.cast("CognitoIdp", jsii.invoke(self, "toCreateIdentityProvider", []))

    @jsii.member(jsii_name="toCreateResourceServer")
    def to_create_resource_server(self) -> "CognitoIdp":
        '''(experimental) Grants permission to create and configure scopes for OAuth 2.0 resource servers.

        Access Level: Write

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_CreateResourceServer.html

        :stability: experimental
        '''
        return typing.cast("CognitoIdp", jsii.invoke(self, "toCreateResourceServer", []))

    @jsii.member(jsii_name="toCreateUserImportJob")
    def to_create_user_import_job(self) -> "CognitoIdp":
        '''(experimental) Grants permission to create user CSV import jobs.

        Access Level: Write

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_CreateUserImportJob.html

        :stability: experimental
        '''
        return typing.cast("CognitoIdp", jsii.invoke(self, "toCreateUserImportJob", []))

    @jsii.member(jsii_name="toCreateUserPool")
    def to_create_user_pool(self) -> "CognitoIdp":
        '''(experimental) Grants permission to create and set password policy for user pools.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_CreateUserPool.html

        :stability: experimental
        '''
        return typing.cast("CognitoIdp", jsii.invoke(self, "toCreateUserPool", []))

    @jsii.member(jsii_name="toCreateUserPoolClient")
    def to_create_user_pool_client(self) -> "CognitoIdp":
        '''(experimental) Grants permission to create user pool app clients.

        Access Level: Write

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_CreateUserPoolClient.html

        :stability: experimental
        '''
        return typing.cast("CognitoIdp", jsii.invoke(self, "toCreateUserPoolClient", []))

    @jsii.member(jsii_name="toCreateUserPoolDomain")
    def to_create_user_pool_domain(self) -> "CognitoIdp":
        '''(experimental) Grants permission to add user pool domains.

        Access Level: Write

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_CreateUserPoolDomain.html

        :stability: experimental
        '''
        return typing.cast("CognitoIdp", jsii.invoke(self, "toCreateUserPoolDomain", []))

    @jsii.member(jsii_name="toDeleteGroup")
    def to_delete_group(self) -> "CognitoIdp":
        '''(experimental) Grants permission to delete any empty user pool group.

        Access Level: Write

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_DeleteGroup.html

        :stability: experimental
        '''
        return typing.cast("CognitoIdp", jsii.invoke(self, "toDeleteGroup", []))

    @jsii.member(jsii_name="toDeleteIdentityProvider")
    def to_delete_identity_provider(self) -> "CognitoIdp":
        '''(experimental) Grants permission to delete any identity provider from user pools.

        Access Level: Write

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_DeleteIdentityProvider.html

        :stability: experimental
        '''
        return typing.cast("CognitoIdp", jsii.invoke(self, "toDeleteIdentityProvider", []))

    @jsii.member(jsii_name="toDeleteResourceServer")
    def to_delete_resource_server(self) -> "CognitoIdp":
        '''(experimental) Grants permission to delete any OAuth 2.0 resource server from user pools.

        Access Level: Write

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_DeleteResourceServer.html

        :stability: experimental
        '''
        return typing.cast("CognitoIdp", jsii.invoke(self, "toDeleteResourceServer", []))

    @jsii.member(jsii_name="toDeleteUser")
    def to_delete_user(self) -> "CognitoIdp":
        '''(experimental) Allows a user to delete one's self.

        Access Level: Write

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_DeleteUser.html

        :stability: experimental
        '''
        return typing.cast("CognitoIdp", jsii.invoke(self, "toDeleteUser", []))

    @jsii.member(jsii_name="toDeleteUserAttributes")
    def to_delete_user_attributes(self) -> "CognitoIdp":
        '''(experimental) Deletes the attributes for a user.

        Access Level: Write

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_DeleteUserAttributes.html

        :stability: experimental
        '''
        return typing.cast("CognitoIdp", jsii.invoke(self, "toDeleteUserAttributes", []))

    @jsii.member(jsii_name="toDeleteUserPool")
    def to_delete_user_pool(self) -> "CognitoIdp":
        '''(experimental) Grants permission to delete user pools.

        Access Level: Write

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_DeleteUserPool.html

        :stability: experimental
        '''
        return typing.cast("CognitoIdp", jsii.invoke(self, "toDeleteUserPool", []))

    @jsii.member(jsii_name="toDeleteUserPoolClient")
    def to_delete_user_pool_client(self) -> "CognitoIdp":
        '''(experimental) Grants permission to delete any user pool app client.

        Access Level: Write

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_DeleteUserPoolClient.html

        :stability: experimental
        '''
        return typing.cast("CognitoIdp", jsii.invoke(self, "toDeleteUserPoolClient", []))

    @jsii.member(jsii_name="toDeleteUserPoolDomain")
    def to_delete_user_pool_domain(self) -> "CognitoIdp":
        '''(experimental) Grants permission to delete any user pool domain.

        Access Level: Write

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_DeleteUserPoolDomain.html

        :stability: experimental
        '''
        return typing.cast("CognitoIdp", jsii.invoke(self, "toDeleteUserPoolDomain", []))

    @jsii.member(jsii_name="toDescribeIdentityProvider")
    def to_describe_identity_provider(self) -> "CognitoIdp":
        '''(experimental) Grants permission to describe any user pool identity provider.

        Access Level: Read

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_DescribeIdentityProvider.html

        :stability: experimental
        '''
        return typing.cast("CognitoIdp", jsii.invoke(self, "toDescribeIdentityProvider", []))

    @jsii.member(jsii_name="toDescribeResourceServer")
    def to_describe_resource_server(self) -> "CognitoIdp":
        '''(experimental) Grants permission to describe any OAuth 2.0 resource server.

        Access Level: Read

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_DescribeResourceServer.html

        :stability: experimental
        '''
        return typing.cast("CognitoIdp", jsii.invoke(self, "toDescribeResourceServer", []))

    @jsii.member(jsii_name="toDescribeRiskConfiguration")
    def to_describe_risk_configuration(self) -> "CognitoIdp":
        '''(experimental) Grants permission to describe the risk configuration settings of user pools and app clients.

        Access Level: Read

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_DescribeRiskConfiguration.html

        :stability: experimental
        '''
        return typing.cast("CognitoIdp", jsii.invoke(self, "toDescribeRiskConfiguration", []))

    @jsii.member(jsii_name="toDescribeUserImportJob")
    def to_describe_user_import_job(self) -> "CognitoIdp":
        '''(experimental) Grants permission to describe any user import job.

        Access Level: Read

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_DescribeUserImportJob.html

        :stability: experimental
        '''
        return typing.cast("CognitoIdp", jsii.invoke(self, "toDescribeUserImportJob", []))

    @jsii.member(jsii_name="toDescribeUserPool")
    def to_describe_user_pool(self) -> "CognitoIdp":
        '''(experimental) Grants permission to describe user pools.

        Access Level: Read

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_DescribeUserPool.html

        :stability: experimental
        '''
        return typing.cast("CognitoIdp", jsii.invoke(self, "toDescribeUserPool", []))

    @jsii.member(jsii_name="toDescribeUserPoolClient")
    def to_describe_user_pool_client(self) -> "CognitoIdp":
        '''(experimental) Grants permission to describe any user pool app client.

        Access Level: Read

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_DescribeUserPoolClient.html

        :stability: experimental
        '''
        return typing.cast("CognitoIdp", jsii.invoke(self, "toDescribeUserPoolClient", []))

    @jsii.member(jsii_name="toDescribeUserPoolDomain")
    def to_describe_user_pool_domain(self) -> "CognitoIdp":
        '''(experimental) Grants permission to describe any user pool domain.

        Access Level: Read

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_DescribeUserPoolDomain.html

        :stability: experimental
        '''
        return typing.cast("CognitoIdp", jsii.invoke(self, "toDescribeUserPoolDomain", []))

    @jsii.member(jsii_name="toDisassociateWebACL")
    def to_disassociate_web_acl(self) -> "CognitoIdp":
        '''(experimental) Grants permission to disassociate the user pool with an AWS WAF web ACL.

        Access Level: Write

        :stability: experimental
        '''
        return typing.cast("CognitoIdp", jsii.invoke(self, "toDisassociateWebACL", []))

    @jsii.member(jsii_name="toForgetDevice")
    def to_forget_device(self) -> "CognitoIdp":
        '''(experimental) Forgets the specified device.

        Access Level: Write

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_ForgetDevice.html

        :stability: experimental
        '''
        return typing.cast("CognitoIdp", jsii.invoke(self, "toForgetDevice", []))

    @jsii.member(jsii_name="toForgotPassword")
    def to_forgot_password(self) -> "CognitoIdp":
        '''(experimental) Calling this API causes a message to be sent to the end user with a confirmation code that is required to change the user's password.

        Access Level: Write

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_ForgotPassword.html

        :stability: experimental
        '''
        return typing.cast("CognitoIdp", jsii.invoke(self, "toForgotPassword", []))

    @jsii.member(jsii_name="toGetCSVHeader")
    def to_get_csv_header(self) -> "CognitoIdp":
        '''(experimental) Grants permission to generate headers for a user import .csv file.

        Access Level: Read

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_GetCSVHeader.html

        :stability: experimental
        '''
        return typing.cast("CognitoIdp", jsii.invoke(self, "toGetCSVHeader", []))

    @jsii.member(jsii_name="toGetDevice")
    def to_get_device(self) -> "CognitoIdp":
        '''(experimental) Gets the device.

        Access Level: Read

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_GetDevice.html

        :stability: experimental
        '''
        return typing.cast("CognitoIdp", jsii.invoke(self, "toGetDevice", []))

    @jsii.member(jsii_name="toGetGroup")
    def to_get_group(self) -> "CognitoIdp":
        '''(experimental) Grants permission to describe a user pool group.

        Access Level: Read

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_GetGroup.html

        :stability: experimental
        '''
        return typing.cast("CognitoIdp", jsii.invoke(self, "toGetGroup", []))

    @jsii.member(jsii_name="toGetIdentityProviderByIdentifier")
    def to_get_identity_provider_by_identifier(self) -> "CognitoIdp":
        '''(experimental) Grants permission to correlate a user pool IdP identifier to the IdP Name.

        Access Level: Read

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_GetIdentityProviderByIdentifier.html

        :stability: experimental
        '''
        return typing.cast("CognitoIdp", jsii.invoke(self, "toGetIdentityProviderByIdentifier", []))

    @jsii.member(jsii_name="toGetSigningCertificate")
    def to_get_signing_certificate(self) -> "CognitoIdp":
        '''(experimental) Grants permission to look up signing certificates for user pools.

        Access Level: Read

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_GetSigningCertificate.html

        :stability: experimental
        '''
        return typing.cast("CognitoIdp", jsii.invoke(self, "toGetSigningCertificate", []))

    @jsii.member(jsii_name="toGetUICustomization")
    def to_get_ui_customization(self) -> "CognitoIdp":
        '''(experimental) Grants permission to get UI customization information for the hosted UI of any app client.

        Access Level: Read

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_GetUICustomization.html

        :stability: experimental
        '''
        return typing.cast("CognitoIdp", jsii.invoke(self, "toGetUICustomization", []))

    @jsii.member(jsii_name="toGetUser")
    def to_get_user(self) -> "CognitoIdp":
        '''(experimental) Gets the user attributes and metadata for a user.

        Access Level: Read

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_GetUser.html

        :stability: experimental
        '''
        return typing.cast("CognitoIdp", jsii.invoke(self, "toGetUser", []))

    @jsii.member(jsii_name="toGetUserAttributeVerificationCode")
    def to_get_user_attribute_verification_code(self) -> "CognitoIdp":
        '''(experimental) Gets the user attribute verification code for the specified attribute name.

        Access Level: Read

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_GetUserAttributeVerificationCode.html

        :stability: experimental
        '''
        return typing.cast("CognitoIdp", jsii.invoke(self, "toGetUserAttributeVerificationCode", []))

    @jsii.member(jsii_name="toGetUserPoolMfaConfig")
    def to_get_user_pool_mfa_config(self) -> "CognitoIdp":
        '''(experimental) Grants permission to look up the MFA configuration of user pools.

        Access Level: Read

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_GetUserPoolMfaConfig.html

        :stability: experimental
        '''
        return typing.cast("CognitoIdp", jsii.invoke(self, "toGetUserPoolMfaConfig", []))

    @jsii.member(jsii_name="toGetWebACLForResource")
    def to_get_web_acl_for_resource(self) -> "CognitoIdp":
        '''(experimental) Grants permission to get the AWS WAF web ACL that is associated with an Amazon Cognito user pool.

        Access Level: Read

        :stability: experimental
        '''
        return typing.cast("CognitoIdp", jsii.invoke(self, "toGetWebACLForResource", []))

    @jsii.member(jsii_name="toGlobalSignOut")
    def to_global_sign_out(self) -> "CognitoIdp":
        '''(experimental) Signs out users from all devices.

        Access Level: Write

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_GlobalSignOut.html

        :stability: experimental
        '''
        return typing.cast("CognitoIdp", jsii.invoke(self, "toGlobalSignOut", []))

    @jsii.member(jsii_name="toInitiateAuth")
    def to_initiate_auth(self) -> "CognitoIdp":
        '''(experimental) Initiates the authentication flow.

        Access Level: Write

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_InitiateAuth.html

        :stability: experimental
        '''
        return typing.cast("CognitoIdp", jsii.invoke(self, "toInitiateAuth", []))

    @jsii.member(jsii_name="toListDevices")
    def to_list_devices(self) -> "CognitoIdp":
        '''(experimental) Lists the devices.

        Access Level: List

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_ListDevices.html

        :stability: experimental
        '''
        return typing.cast("CognitoIdp", jsii.invoke(self, "toListDevices", []))

    @jsii.member(jsii_name="toListGroups")
    def to_list_groups(self) -> "CognitoIdp":
        '''(experimental) Grants permission to list all groups in user pools.

        Access Level: List

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_ListGroups.html

        :stability: experimental
        '''
        return typing.cast("CognitoIdp", jsii.invoke(self, "toListGroups", []))

    @jsii.member(jsii_name="toListIdentityProviders")
    def to_list_identity_providers(self) -> "CognitoIdp":
        '''(experimental) Grants permission to list all identity providers in user pools.

        Access Level: List

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_ListIdentityProviders.html

        :stability: experimental
        '''
        return typing.cast("CognitoIdp", jsii.invoke(self, "toListIdentityProviders", []))

    @jsii.member(jsii_name="toListResourceServers")
    def to_list_resource_servers(self) -> "CognitoIdp":
        '''(experimental) Grants permission to list all resource servers in user pools.

        Access Level: List

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_ListResourceServers.html

        :stability: experimental
        '''
        return typing.cast("CognitoIdp", jsii.invoke(self, "toListResourceServers", []))

    @jsii.member(jsii_name="toListResourcesForWebACL")
    def to_list_resources_for_web_acl(self) -> "CognitoIdp":
        '''(experimental) Grants permission to list the user pools that are associated with an AWS WAF web ACL.

        Access Level: List

        :stability: experimental
        '''
        return typing.cast("CognitoIdp", jsii.invoke(self, "toListResourcesForWebACL", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "CognitoIdp":
        '''(experimental) Grants permission to list the tags that are assigned to an Amazon Cognito user pool.

        Access Level: List

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("CognitoIdp", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toListUserImportJobs")
    def to_list_user_import_jobs(self) -> "CognitoIdp":
        '''(experimental) Grants permission to list all user import jobs.

        Access Level: List

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_ListUserImportJobs.html

        :stability: experimental
        '''
        return typing.cast("CognitoIdp", jsii.invoke(self, "toListUserImportJobs", []))

    @jsii.member(jsii_name="toListUserPoolClients")
    def to_list_user_pool_clients(self) -> "CognitoIdp":
        '''(experimental) Grants permission to list all app clients in user pools.

        Access Level: List

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_ListUserPoolClients.html

        :stability: experimental
        '''
        return typing.cast("CognitoIdp", jsii.invoke(self, "toListUserPoolClients", []))

    @jsii.member(jsii_name="toListUserPools")
    def to_list_user_pools(self) -> "CognitoIdp":
        '''(experimental) Grants permission to list all user pools.

        Access Level: List

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_ListUserPools.html

        :stability: experimental
        '''
        return typing.cast("CognitoIdp", jsii.invoke(self, "toListUserPools", []))

    @jsii.member(jsii_name="toListUsers")
    def to_list_users(self) -> "CognitoIdp":
        '''(experimental) Grants permission to list all user pool users.

        Access Level: List

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_ListUsers.html

        :stability: experimental
        '''
        return typing.cast("CognitoIdp", jsii.invoke(self, "toListUsers", []))

    @jsii.member(jsii_name="toListUsersInGroup")
    def to_list_users_in_group(self) -> "CognitoIdp":
        '''(experimental) Grants permission to list the users in any group.

        Access Level: List

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_ListUsersInGroup.html

        :stability: experimental
        '''
        return typing.cast("CognitoIdp", jsii.invoke(self, "toListUsersInGroup", []))

    @jsii.member(jsii_name="toResendConfirmationCode")
    def to_resend_confirmation_code(self) -> "CognitoIdp":
        '''(experimental) Resends the confirmation (for confirmation of registration) to a specific user in the user pool.

        Access Level: Write

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_ResendConfirmationCode.html

        :stability: experimental
        '''
        return typing.cast("CognitoIdp", jsii.invoke(self, "toResendConfirmationCode", []))

    @jsii.member(jsii_name="toRespondToAuthChallenge")
    def to_respond_to_auth_challenge(self) -> "CognitoIdp":
        '''(experimental) Responds to the authentication challenge.

        Access Level: Write

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_RespondToAuthChallenge.html

        :stability: experimental
        '''
        return typing.cast("CognitoIdp", jsii.invoke(self, "toRespondToAuthChallenge", []))

    @jsii.member(jsii_name="toRevokeToken")
    def to_revoke_token(self) -> "CognitoIdp":
        '''(experimental) Revokes all of the access tokens generated by the specified refresh token.

        Access Level: Write

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_RevokeToken.html

        :stability: experimental
        '''
        return typing.cast("CognitoIdp", jsii.invoke(self, "toRevokeToken", []))

    @jsii.member(jsii_name="toSetRiskConfiguration")
    def to_set_risk_configuration(self) -> "CognitoIdp":
        '''(experimental) Grants permission to set risk configuration for user pools and app clients.

        Access Level: Write

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_SetRiskConfiguration.html

        :stability: experimental
        '''
        return typing.cast("CognitoIdp", jsii.invoke(self, "toSetRiskConfiguration", []))

    @jsii.member(jsii_name="toSetUICustomization")
    def to_set_ui_customization(self) -> "CognitoIdp":
        '''(experimental) Grants permission to customize the hosted UI for any app client.

        Access Level: Write

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_SetUICustomization.html

        :stability: experimental
        '''
        return typing.cast("CognitoIdp", jsii.invoke(self, "toSetUICustomization", []))

    @jsii.member(jsii_name="toSetUserMFAPreference")
    def to_set_user_mfa_preference(self) -> "CognitoIdp":
        '''(experimental) Sets MFA preference for the user in the userpool.

        Access Level: Write

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_SetUserMFAPreference.html

        :stability: experimental
        '''
        return typing.cast("CognitoIdp", jsii.invoke(self, "toSetUserMFAPreference", []))

    @jsii.member(jsii_name="toSetUserPoolMfaConfig")
    def to_set_user_pool_mfa_config(self) -> "CognitoIdp":
        '''(experimental) Grants permission to set user pool MFA configuration.

        Access Level: Write

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_SetUserPoolMfaConfig.html

        :stability: experimental
        '''
        return typing.cast("CognitoIdp", jsii.invoke(self, "toSetUserPoolMfaConfig", []))

    @jsii.member(jsii_name="toSetUserSettings")
    def to_set_user_settings(self) -> "CognitoIdp":
        '''(experimental) Sets the user settings like multi-factor authentication (MFA).

        Access Level: Write

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_SetUserSettings.html

        :stability: experimental
        '''
        return typing.cast("CognitoIdp", jsii.invoke(self, "toSetUserSettings", []))

    @jsii.member(jsii_name="toSignUp")
    def to_sign_up(self) -> "CognitoIdp":
        '''(experimental) Registers the user in the specified user pool and creates a user name, password, and user attributes.

        Access Level: Write

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_SignUp.html

        :stability: experimental
        '''
        return typing.cast("CognitoIdp", jsii.invoke(self, "toSignUp", []))

    @jsii.member(jsii_name="toStartUserImportJob")
    def to_start_user_import_job(self) -> "CognitoIdp":
        '''(experimental) Grants permission to start any user import job.

        Access Level: Write

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_StartUserImportJob.html

        :stability: experimental
        '''
        return typing.cast("CognitoIdp", jsii.invoke(self, "toStartUserImportJob", []))

    @jsii.member(jsii_name="toStopUserImportJob")
    def to_stop_user_import_job(self) -> "CognitoIdp":
        '''(experimental) Grants permission to stop any user import job.

        Access Level: Write

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_StopUserImportJob.html

        :stability: experimental
        '''
        return typing.cast("CognitoIdp", jsii.invoke(self, "toStopUserImportJob", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "CognitoIdp":
        '''(experimental) Grants permission to tag a user pool.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("CognitoIdp", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "CognitoIdp":
        '''(experimental) Grants permission to untag a user pool.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("CognitoIdp", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateAuthEventFeedback")
    def to_update_auth_event_feedback(self) -> "CognitoIdp":
        '''(experimental) Updates the feedback for the user authentication event.

        Access Level: Write

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_UpdateAuthEventFeedback.html

        :stability: experimental
        '''
        return typing.cast("CognitoIdp", jsii.invoke(self, "toUpdateAuthEventFeedback", []))

    @jsii.member(jsii_name="toUpdateDeviceStatus")
    def to_update_device_status(self) -> "CognitoIdp":
        '''(experimental) Updates the device status.

        Access Level: Write

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_UpdateDeviceStatus.html

        :stability: experimental
        '''
        return typing.cast("CognitoIdp", jsii.invoke(self, "toUpdateDeviceStatus", []))

    @jsii.member(jsii_name="toUpdateGroup")
    def to_update_group(self) -> "CognitoIdp":
        '''(experimental) Grants permission to update the configuration of any group.

        Access Level: Write

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_UpdateGroup.html

        :stability: experimental
        '''
        return typing.cast("CognitoIdp", jsii.invoke(self, "toUpdateGroup", []))

    @jsii.member(jsii_name="toUpdateIdentityProvider")
    def to_update_identity_provider(self) -> "CognitoIdp":
        '''(experimental) Grants permission to update the configuration of any user pool IdP.

        Access Level: Write

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_UpdateIdentityProvider.html

        :stability: experimental
        '''
        return typing.cast("CognitoIdp", jsii.invoke(self, "toUpdateIdentityProvider", []))

    @jsii.member(jsii_name="toUpdateResourceServer")
    def to_update_resource_server(self) -> "CognitoIdp":
        '''(experimental) Grants permission to update the configuration of any OAuth 2.0 resource server.

        Access Level: Write

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_UpdateResourceServer.html

        :stability: experimental
        '''
        return typing.cast("CognitoIdp", jsii.invoke(self, "toUpdateResourceServer", []))

    @jsii.member(jsii_name="toUpdateUserAttributes")
    def to_update_user_attributes(self) -> "CognitoIdp":
        '''(experimental) Allows a user to update a specific attribute (one at a time).

        Access Level: Write

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_UpdateUserAttributes.html

        :stability: experimental
        '''
        return typing.cast("CognitoIdp", jsii.invoke(self, "toUpdateUserAttributes", []))

    @jsii.member(jsii_name="toUpdateUserPool")
    def to_update_user_pool(self) -> "CognitoIdp":
        '''(experimental) Grants permission to updates the configuration of user pools.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_UpdateUserPool.html

        :stability: experimental
        '''
        return typing.cast("CognitoIdp", jsii.invoke(self, "toUpdateUserPool", []))

    @jsii.member(jsii_name="toUpdateUserPoolClient")
    def to_update_user_pool_client(self) -> "CognitoIdp":
        '''(experimental) Grants permission to update any user pool client.

        Access Level: Write

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_UpdateUserPoolClient.html

        :stability: experimental
        '''
        return typing.cast("CognitoIdp", jsii.invoke(self, "toUpdateUserPoolClient", []))

    @jsii.member(jsii_name="toUpdateUserPoolDomain")
    def to_update_user_pool_domain(self) -> "CognitoIdp":
        '''(experimental) Grants permission to replace the certificate for any custom domain.

        Access Level: Write

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_UpdateUserPoolDomain.html

        :stability: experimental
        '''
        return typing.cast("CognitoIdp", jsii.invoke(self, "toUpdateUserPoolDomain", []))

    @jsii.member(jsii_name="toVerifySoftwareToken")
    def to_verify_software_token(self) -> "CognitoIdp":
        '''(experimental) Registers a user's entered TOTP code and mark the user's software token MFA status as verified if successful.

        Access Level: Write

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_VerifySoftwareToken.html

        :stability: experimental
        '''
        return typing.cast("CognitoIdp", jsii.invoke(self, "toVerifySoftwareToken", []))

    @jsii.member(jsii_name="toVerifyUserAttribute")
    def to_verify_user_attribute(self) -> "CognitoIdp":
        '''(experimental) Verifies a user attribute using a one time verification code.

        Access Level: Write

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_VerifyUserAttribute.html

        :stability: experimental
        '''
        return typing.cast("CognitoIdp", jsii.invoke(self, "toVerifyUserAttribute", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ff92fb03172194d667c0bcfb721a3851e53aa78ec73cf0da5e7e8685aa48f178)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7570963ec7740e5ea8923e2c4332a28ce8f6086074e2e18e8a8b21cc999d1672)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class CognitoSync(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.CognitoSync",
):
    '''(experimental) Statement provider for service `cognito-sync <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazoncognitosync.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `cognito-sync <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazoncognitosync.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onDataset")
    def on_dataset(
        self,
        identity_pool_id: builtins.str,
        identity_id: builtins.str,
        dataset_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "CognitoSync":
        '''(experimental) Adds a resource of type dataset to the statement.

        https://docs.aws.amazon.com/cognito/latest/developerguide/synchronizing-data.html#understanding-datasets

        :param identity_pool_id: - Identifier for the identityPoolId.
        :param identity_id: - Identifier for the identityId.
        :param dataset_name: - Identifier for the datasetName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__090fce3876ac3cf2e4c6706a231f004012e15562c8f51997e53a30814d2a95e7)
            check_type(argname="argument identity_pool_id", value=identity_pool_id, expected_type=type_hints["identity_pool_id"])
            check_type(argname="argument identity_id", value=identity_id, expected_type=type_hints["identity_id"])
            check_type(argname="argument dataset_name", value=dataset_name, expected_type=type_hints["dataset_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("CognitoSync", jsii.invoke(self, "onDataset", [identity_pool_id, identity_id, dataset_name, account, region, partition]))

    @jsii.member(jsii_name="onIdentity")
    def on_identity(
        self,
        identity_pool_id: builtins.str,
        identity_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "CognitoSync":
        '''(experimental) Adds a resource of type identity to the statement.

        https://docs.aws.amazon.com/cognito/latest/developerguide/identity-pools.html#authenticated-and-unauthenticated-identities

        :param identity_pool_id: - Identifier for the identityPoolId.
        :param identity_id: - Identifier for the identityId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5e5e5e4e0e288b1178573996a4993def746b1bbeb3e2912778219fa5485473df)
            check_type(argname="argument identity_pool_id", value=identity_pool_id, expected_type=type_hints["identity_pool_id"])
            check_type(argname="argument identity_id", value=identity_id, expected_type=type_hints["identity_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("CognitoSync", jsii.invoke(self, "onIdentity", [identity_pool_id, identity_id, account, region, partition]))

    @jsii.member(jsii_name="onIdentitypool")
    def on_identitypool(
        self,
        identity_pool_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "CognitoSync":
        '''(experimental) Adds a resource of type identitypool to the statement.

        https://docs.aws.amazon.com/cognito/latest/developerguide/identity-pools.html

        :param identity_pool_id: - Identifier for the identityPoolId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__cc3d3f2240765b3a07e12df32a2db4757cdaef21f6159ec1897c078bf1876f3d)
            check_type(argname="argument identity_pool_id", value=identity_pool_id, expected_type=type_hints["identity_pool_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("CognitoSync", jsii.invoke(self, "onIdentitypool", [identity_pool_id, account, region, partition]))

    @jsii.member(jsii_name="toBulkPublish")
    def to_bulk_publish(self) -> "CognitoSync":
        '''(experimental) Grants permission to initiate a bulk publish of all existing datasets for an Identity Pool to the configured stream.

        Access Level: Write

        https://docs.aws.amazon.com/cognitosync/latest/APIReference/API_BulkPublish.html

        :stability: experimental
        '''
        return typing.cast("CognitoSync", jsii.invoke(self, "toBulkPublish", []))

    @jsii.member(jsii_name="toDeleteDataset")
    def to_delete_dataset(self) -> "CognitoSync":
        '''(experimental) Grants permission to delete a specific dataset.

        Access Level: Write

        https://docs.aws.amazon.com/cognitosync/latest/APIReference/API_DeleteDataset.html

        :stability: experimental
        '''
        return typing.cast("CognitoSync", jsii.invoke(self, "toDeleteDataset", []))

    @jsii.member(jsii_name="toDescribeDataset")
    def to_describe_dataset(self) -> "CognitoSync":
        '''(experimental) Grants permission to get metadata about a dataset by identity and dataset name.

        Access Level: Read

        https://docs.aws.amazon.com/cognitosync/latest/APIReference/API_DescribeDataset.html

        :stability: experimental
        '''
        return typing.cast("CognitoSync", jsii.invoke(self, "toDescribeDataset", []))

    @jsii.member(jsii_name="toDescribeIdentityPoolUsage")
    def to_describe_identity_pool_usage(self) -> "CognitoSync":
        '''(experimental) Grants permission to get usage details (for example, data storage) about a particular identity pool.

        Access Level: Read

        https://docs.aws.amazon.com/cognitosync/latest/APIReference/API_DescribeIdentityPoolUsage.html

        :stability: experimental
        '''
        return typing.cast("CognitoSync", jsii.invoke(self, "toDescribeIdentityPoolUsage", []))

    @jsii.member(jsii_name="toDescribeIdentityUsage")
    def to_describe_identity_usage(self) -> "CognitoSync":
        '''(experimental) Grants permission to get usage information for an identity, including number of datasets and data usage.

        Access Level: Read

        https://docs.aws.amazon.com/cognitosync/latest/APIReference/API_DescribeIdentityUsage.html

        :stability: experimental
        '''
        return typing.cast("CognitoSync", jsii.invoke(self, "toDescribeIdentityUsage", []))

    @jsii.member(jsii_name="toGetBulkPublishDetails")
    def to_get_bulk_publish_details(self) -> "CognitoSync":
        '''(experimental) Grants permission to get the status of the last BulkPublish operation for an identity pool.

        Access Level: Read

        https://docs.aws.amazon.com/cognitosync/latest/APIReference/API_GetBulkPublishDetails.html

        :stability: experimental
        '''
        return typing.cast("CognitoSync", jsii.invoke(self, "toGetBulkPublishDetails", []))

    @jsii.member(jsii_name="toGetCognitoEvents")
    def to_get_cognito_events(self) -> "CognitoSync":
        '''(experimental) Grants permission to get the events and the corresponding Lambda functions associated with an identity pool.

        Access Level: Read

        https://docs.aws.amazon.com/cognitosync/latest/APIReference/API_GetCognitoEvents.html

        :stability: experimental
        '''
        return typing.cast("CognitoSync", jsii.invoke(self, "toGetCognitoEvents", []))

    @jsii.member(jsii_name="toGetIdentityPoolConfiguration")
    def to_get_identity_pool_configuration(self) -> "CognitoSync":
        '''(experimental) Grants permission to get the configuration settings of an identity pool.

        Access Level: Read

        https://docs.aws.amazon.com/cognitosync/latest/APIReference/API_GetIdentityPoolConfiguration.html

        :stability: experimental
        '''
        return typing.cast("CognitoSync", jsii.invoke(self, "toGetIdentityPoolConfiguration", []))

    @jsii.member(jsii_name="toListDatasets")
    def to_list_datasets(self) -> "CognitoSync":
        '''(experimental) Grants permission to list datasets for an identity.

        Access Level: List

        https://docs.aws.amazon.com/cognitosync/latest/APIReference/API_ListDatasets.html

        :stability: experimental
        '''
        return typing.cast("CognitoSync", jsii.invoke(self, "toListDatasets", []))

    @jsii.member(jsii_name="toListIdentityPoolUsage")
    def to_list_identity_pool_usage(self) -> "CognitoSync":
        '''(experimental) Grants permission to get a list of identity pools registered with Cognito.

        Access Level: Read

        https://docs.aws.amazon.com/cognitosync/latest/APIReference/API_ListIdentityPoolUsage.html

        :stability: experimental
        '''
        return typing.cast("CognitoSync", jsii.invoke(self, "toListIdentityPoolUsage", []))

    @jsii.member(jsii_name="toListRecords")
    def to_list_records(self) -> "CognitoSync":
        '''(experimental) Grants permission to get paginated records, optionally changed after a particular sync count for a dataset and identity.

        Access Level: Read

        https://docs.aws.amazon.com/cognitosync/latest/APIReference/API_ListRecords.html

        :stability: experimental
        '''
        return typing.cast("CognitoSync", jsii.invoke(self, "toListRecords", []))

    @jsii.member(jsii_name="toQueryRecords")
    def to_query_records(self) -> "CognitoSync":
        '''(experimental) Grants permission to query records.

        Access Level: Read

        :stability: experimental
        '''
        return typing.cast("CognitoSync", jsii.invoke(self, "toQueryRecords", []))

    @jsii.member(jsii_name="toRegisterDevice")
    def to_register_device(self) -> "CognitoSync":
        '''(experimental) Grants permission to register a device to receive push sync notifications.

        Access Level: Write

        https://docs.aws.amazon.com/cognitosync/latest/APIReference/API_RegisterDevice.html

        :stability: experimental
        '''
        return typing.cast("CognitoSync", jsii.invoke(self, "toRegisterDevice", []))

    @jsii.member(jsii_name="toSetCognitoEvents")
    def to_set_cognito_events(self) -> "CognitoSync":
        '''(experimental) Grants permission to set the AWS Lambda function for a given event type for an identity pool.

        Access Level: Write

        https://docs.aws.amazon.com/cognitosync/latest/APIReference/API_SetCognitoEvents.html

        :stability: experimental
        '''
        return typing.cast("CognitoSync", jsii.invoke(self, "toSetCognitoEvents", []))

    @jsii.member(jsii_name="toSetDatasetConfiguration")
    def to_set_dataset_configuration(self) -> "CognitoSync":
        '''(experimental) Grants permission to configure datasets.

        Access Level: Write

        :stability: experimental
        '''
        return typing.cast("CognitoSync", jsii.invoke(self, "toSetDatasetConfiguration", []))

    @jsii.member(jsii_name="toSetIdentityPoolConfiguration")
    def to_set_identity_pool_configuration(self) -> "CognitoSync":
        '''(experimental) Grants permission to set the necessary configuration for push sync.

        Access Level: Write

        https://docs.aws.amazon.com/cognitosync/latest/APIReference/API_SetIdentityPoolConfiguration.html

        :stability: experimental
        '''
        return typing.cast("CognitoSync", jsii.invoke(self, "toSetIdentityPoolConfiguration", []))

    @jsii.member(jsii_name="toSubscribeToDataset")
    def to_subscribe_to_dataset(self) -> "CognitoSync":
        '''(experimental) Grants permission to subscribe to receive notifications when a dataset is modified by another device.

        Access Level: Write

        https://docs.aws.amazon.com/cognitosync/latest/APIReference/API_SubscribeToDataset.html

        :stability: experimental
        '''
        return typing.cast("CognitoSync", jsii.invoke(self, "toSubscribeToDataset", []))

    @jsii.member(jsii_name="toUnsubscribeFromDataset")
    def to_unsubscribe_from_dataset(self) -> "CognitoSync":
        '''(experimental) Grants permission to unsubscribe from receiving notifications when a dataset is modified by another device.

        Access Level: Write

        https://docs.aws.amazon.com/cognitosync/latest/APIReference/API_UnsubscribeFromDataset.html

        :stability: experimental
        '''
        return typing.cast("CognitoSync", jsii.invoke(self, "toUnsubscribeFromDataset", []))

    @jsii.member(jsii_name="toUpdateRecords")
    def to_update_records(self) -> "CognitoSync":
        '''(experimental) Grants permission to post updates to records and add and delete records for a dataset and user.

        Access Level: Write

        https://docs.aws.amazon.com/cognitosync/latest/APIReference/API_UpdateRecords.html

        :stability: experimental
        '''
        return typing.cast("CognitoSync", jsii.invoke(self, "toUpdateRecords", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bb134a25d0cc4700ffe9f67a9bd6330f8282d7e751a58f82785b827785cf5ec5)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7ab637a91db007cd383e86e65bc322ba2adcd93a90e04f282e5614f7f0599719)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Comprehend(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Comprehend",
):
    '''(experimental) Statement provider for service `comprehend <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazoncomprehend.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `comprehend <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazoncomprehend.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="ifModelKmsKey")
    def if_model_kms_key(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Comprehend":
        '''(experimental) Filters access by the model KMS key associated with the resource in the request.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazoncomprehend.html#amazoncomprehend-policy-keys

        Applies to actions:

        - .toCreateDocumentClassifier()
        - .toCreateEntityRecognizer()
        - .toImportModel()

        :param value: The value(s) to check.
        :param operator: Works with `arn operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_ARN>`_. **Default:** ``ArnLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8fd7bffa0dce989c15e269d0b05f5f9cb5b30ec543458961989ad07fc3217f24)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Comprehend", jsii.invoke(self, "ifModelKmsKey", [value, operator]))

    @jsii.member(jsii_name="ifOutputKmsKey")
    def if_output_kms_key(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Comprehend":
        '''(experimental) Filters access by the output KMS key associated with the resource in the request.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazoncomprehend.html#amazoncomprehend-policy-keys

        Applies to actions:

        - .toCreateDocumentClassifier()
        - .toStartDocumentClassificationJob()
        - .toStartDominantLanguageDetectionJob()
        - .toStartEntitiesDetectionJob()
        - .toStartEventsDetectionJob()
        - .toStartKeyPhrasesDetectionJob()
        - .toStartPiiEntitiesDetectionJob()
        - .toStartSentimentDetectionJob()
        - .toStartTargetedSentimentDetectionJob()
        - .toStartTopicsDetectionJob()

        :param value: The value(s) to check.
        :param operator: Works with `arn operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_ARN>`_. **Default:** ``ArnLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__dfae30fb140af96c49337eef9673e3e140e802394fa88986c97d670cc593c016)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Comprehend", jsii.invoke(self, "ifOutputKmsKey", [value, operator]))

    @jsii.member(jsii_name="ifVolumeKmsKey")
    def if_volume_kms_key(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Comprehend":
        '''(experimental) Filters access by the volume KMS key associated with the resource in the request.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazoncomprehend.html#amazoncomprehend-policy-keys

        Applies to actions:

        - .toCreateDocumentClassifier()
        - .toCreateEntityRecognizer()
        - .toStartDocumentClassificationJob()
        - .toStartDominantLanguageDetectionJob()
        - .toStartEntitiesDetectionJob()
        - .toStartKeyPhrasesDetectionJob()
        - .toStartSentimentDetectionJob()
        - .toStartTargetedSentimentDetectionJob()
        - .toStartTopicsDetectionJob()

        :param value: The value(s) to check.
        :param operator: Works with `arn operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_ARN>`_. **Default:** ``ArnLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__00378d348ea924dfbb6a8354ac95d0d8912e202b2b97eb0a82b626e38fcc8e53)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Comprehend", jsii.invoke(self, "ifVolumeKmsKey", [value, operator]))

    @jsii.member(jsii_name="ifVpcSecurityGroupIds")
    def if_vpc_security_group_ids(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Comprehend":
        '''(experimental) Filters access by the list of all VPC security group ids associated with the resource in the request.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazoncomprehend.html#amazoncomprehend-policy-keys

        Applies to actions:

        - .toCreateDocumentClassifier()
        - .toCreateEntityRecognizer()
        - .toStartDocumentClassificationJob()
        - .toStartDominantLanguageDetectionJob()
        - .toStartEntitiesDetectionJob()
        - .toStartKeyPhrasesDetectionJob()
        - .toStartSentimentDetectionJob()
        - .toStartTargetedSentimentDetectionJob()
        - .toStartTopicsDetectionJob()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fac4abd5cf69daebb243e74c1c41b1a300ad26283d9fbd1d078dd713042c9fbe)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Comprehend", jsii.invoke(self, "ifVpcSecurityGroupIds", [value, operator]))

    @jsii.member(jsii_name="ifVpcSubnets")
    def if_vpc_subnets(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Comprehend":
        '''(experimental) Filters access by the list of all VPC subnets associated with the resource in the request.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazoncomprehend.html#amazoncomprehend-policy-keys

        Applies to actions:

        - .toCreateDocumentClassifier()
        - .toCreateEntityRecognizer()
        - .toStartDocumentClassificationJob()
        - .toStartDominantLanguageDetectionJob()
        - .toStartEntitiesDetectionJob()
        - .toStartKeyPhrasesDetectionJob()
        - .toStartSentimentDetectionJob()
        - .toStartTargetedSentimentDetectionJob()
        - .toStartTopicsDetectionJob()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a15ff468b9ffcd1e9894785085847cd0f4763c1c17fe8e94a0d501f92ee8ac3b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Comprehend", jsii.invoke(self, "ifVpcSubnets", [value, operator]))

    @jsii.member(jsii_name="onDocumentClassificationJob")
    def on_document_classification_job(
        self,
        job_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Comprehend":
        '''(experimental) Adds a resource of type document-classification-job to the statement.

        https://docs.aws.amazon.com/comprehend/latest/dg/API_StartDocumentClassificationJob.html

        :param job_id: - Identifier for the jobId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__35b568acca2c70800e63d9f9ecb5fe6f29e6dedfe9f9a1ae7e9c28804f95d595)
            check_type(argname="argument job_id", value=job_id, expected_type=type_hints["job_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Comprehend", jsii.invoke(self, "onDocumentClassificationJob", [job_id, account, region, partition]))

    @jsii.member(jsii_name="onDocumentClassifier")
    def on_document_classifier(
        self,
        document_classifier_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Comprehend":
        '''(experimental) Adds a resource of type document-classifier to the statement.

        https://docs.aws.amazon.com/comprehend/latest/dg/how-document-classification-training.html

        :param document_classifier_name: - Identifier for the documentClassifierName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__567958365f80a5120730c0cec8cec37e41d6c09f05410a4d69879c1f866e7ea9)
            check_type(argname="argument document_classifier_name", value=document_classifier_name, expected_type=type_hints["document_classifier_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Comprehend", jsii.invoke(self, "onDocumentClassifier", [document_classifier_name, account, region, partition]))

    @jsii.member(jsii_name="onDocumentClassifierEndpoint")
    def on_document_classifier_endpoint(
        self,
        document_classifier_endpoint_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Comprehend":
        '''(experimental) Adds a resource of type document-classifier-endpoint to the statement.

        https://docs.aws.amazon.com/comprehend/latest/dg/custom-realtime-analysis.html

        :param document_classifier_endpoint_name: - Identifier for the documentClassifierEndpointName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__41e682ea5f9070cea55827b27a76d156078ca0bf9f2e8ee5f3d0050fa0b587bb)
            check_type(argname="argument document_classifier_endpoint_name", value=document_classifier_endpoint_name, expected_type=type_hints["document_classifier_endpoint_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Comprehend", jsii.invoke(self, "onDocumentClassifierEndpoint", [document_classifier_endpoint_name, account, region, partition]))

    @jsii.member(jsii_name="onDominantLanguageDetectionJob")
    def on_dominant_language_detection_job(
        self,
        job_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Comprehend":
        '''(experimental) Adds a resource of type dominant-language-detection-job to the statement.

        https://docs.aws.amazon.com/comprehend/latest/dg/API_StartDominantLanguageDetectionJob.html

        :param job_id: - Identifier for the jobId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bfa1990ba67e883e0fd291bd82bf4a28f6b466cbe785ce559de7e110feee6368)
            check_type(argname="argument job_id", value=job_id, expected_type=type_hints["job_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Comprehend", jsii.invoke(self, "onDominantLanguageDetectionJob", [job_id, account, region, partition]))

    @jsii.member(jsii_name="onEntitiesDetectionJob")
    def on_entities_detection_job(
        self,
        job_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Comprehend":
        '''(experimental) Adds a resource of type entities-detection-job to the statement.

        https://docs.aws.amazon.com/comprehend/latest/dg/API_StartEntitiesDetectionJob.html

        :param job_id: - Identifier for the jobId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__99618a15b9d41d6979cf20d9f53b6f26fb46c3cc9adba8625c6f742040c256e6)
            check_type(argname="argument job_id", value=job_id, expected_type=type_hints["job_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Comprehend", jsii.invoke(self, "onEntitiesDetectionJob", [job_id, account, region, partition]))

    @jsii.member(jsii_name="onEntityRecognizer")
    def on_entity_recognizer(
        self,
        entity_recognizer_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Comprehend":
        '''(experimental) Adds a resource of type entity-recognizer to the statement.

        https://docs.aws.amazon.com/comprehend/latest/dg/training-recognizers.html

        :param entity_recognizer_name: - Identifier for the entityRecognizerName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8f835863b7872133d31997a3153cdd17556a88d354f745b23f519851abbbde36)
            check_type(argname="argument entity_recognizer_name", value=entity_recognizer_name, expected_type=type_hints["entity_recognizer_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Comprehend", jsii.invoke(self, "onEntityRecognizer", [entity_recognizer_name, account, region, partition]))

    @jsii.member(jsii_name="onEntityRecognizerEndpoint")
    def on_entity_recognizer_endpoint(
        self,
        entity_recognizer_endpoint_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Comprehend":
        '''(experimental) Adds a resource of type entity-recognizer-endpoint to the statement.

        https://docs.aws.amazon.com/comprehend/latest/dg/custom-realtime-analysis.html

        :param entity_recognizer_endpoint_name: - Identifier for the entityRecognizerEndpointName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__255256f0a6b80c249a34cc29708214f3d57be1e575d612dc600c9785b30bc66b)
            check_type(argname="argument entity_recognizer_endpoint_name", value=entity_recognizer_endpoint_name, expected_type=type_hints["entity_recognizer_endpoint_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Comprehend", jsii.invoke(self, "onEntityRecognizerEndpoint", [entity_recognizer_endpoint_name, account, region, partition]))

    @jsii.member(jsii_name="onEventsDetectionJob")
    def on_events_detection_job(
        self,
        job_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Comprehend":
        '''(experimental) Adds a resource of type events-detection-job to the statement.

        https://docs.aws.amazon.com/comprehend/latest/dg/API_StartEventsDetectionJob.html

        :param job_id: - Identifier for the jobId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8f424fe983f350c8d6c3f2f81ea72a04627b311be759311438eb6b4d510a7990)
            check_type(argname="argument job_id", value=job_id, expected_type=type_hints["job_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Comprehend", jsii.invoke(self, "onEventsDetectionJob", [job_id, account, region, partition]))

    @jsii.member(jsii_name="onKeyPhrasesDetectionJob")
    def on_key_phrases_detection_job(
        self,
        job_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Comprehend":
        '''(experimental) Adds a resource of type key-phrases-detection-job to the statement.

        https://docs.aws.amazon.com/comprehend/latest/dg/API_StartKeyPhrasesDetectionJob.html

        :param job_id: - Identifier for the jobId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__910a577a94598644d24909f72a0284a7c6736e91477a70a1b2ade4842f3ec026)
            check_type(argname="argument job_id", value=job_id, expected_type=type_hints["job_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Comprehend", jsii.invoke(self, "onKeyPhrasesDetectionJob", [job_id, account, region, partition]))

    @jsii.member(jsii_name="onPiiEntitiesDetectionJob")
    def on_pii_entities_detection_job(
        self,
        job_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Comprehend":
        '''(experimental) Adds a resource of type pii-entities-detection-job to the statement.

        https://docs.aws.amazon.com/comprehend/latest/dg/API_StartPiiEntitiesDetectionJob.html

        :param job_id: - Identifier for the jobId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f259ae364fe74ac73132be82baacebf7bb9bcdd7e10c9d6900a66b1cc0b13cb7)
            check_type(argname="argument job_id", value=job_id, expected_type=type_hints["job_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Comprehend", jsii.invoke(self, "onPiiEntitiesDetectionJob", [job_id, account, region, partition]))

    @jsii.member(jsii_name="onSentimentDetectionJob")
    def on_sentiment_detection_job(
        self,
        job_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Comprehend":
        '''(experimental) Adds a resource of type sentiment-detection-job to the statement.

        https://docs.aws.amazon.com/comprehend/latest/dg/API_StartSentimentDetectionJob.html

        :param job_id: - Identifier for the jobId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7f0e00a59709e16099a1d5de8345a39d1a2b97ae3a7ee27cb4eb292175fabfe9)
            check_type(argname="argument job_id", value=job_id, expected_type=type_hints["job_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Comprehend", jsii.invoke(self, "onSentimentDetectionJob", [job_id, account, region, partition]))

    @jsii.member(jsii_name="onTargetedSentimentDetectionJob")
    def on_targeted_sentiment_detection_job(
        self,
        job_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Comprehend":
        '''(experimental) Adds a resource of type targeted-sentiment-detection-job to the statement.

        https://docs.aws.amazon.com/comprehend/latest/dg/API_StartTargetedSentimentDetectionJob.html

        :param job_id: - Identifier for the jobId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a33142198af20ff9f0571a94ccb8d1c76465d47708fe13622ccd5e64b12ac0e7)
            check_type(argname="argument job_id", value=job_id, expected_type=type_hints["job_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Comprehend", jsii.invoke(self, "onTargetedSentimentDetectionJob", [job_id, account, region, partition]))

    @jsii.member(jsii_name="onTopicsDetectionJob")
    def on_topics_detection_job(
        self,
        job_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Comprehend":
        '''(experimental) Adds a resource of type topics-detection-job to the statement.

        https://docs.aws.amazon.com/comprehend/latest/dg/API_StartTopicsDetectionJob.html

        :param job_id: - Identifier for the jobId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ab2a91cfec135bb27c70f53be66062a069fe75487205f24ece0b1b800661f55f)
            check_type(argname="argument job_id", value=job_id, expected_type=type_hints["job_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Comprehend", jsii.invoke(self, "onTopicsDetectionJob", [job_id, account, region, partition]))

    @jsii.member(jsii_name="toBatchDetectDominantLanguage")
    def to_batch_detect_dominant_language(self) -> "Comprehend":
        '''(experimental) Grants permission to detect the language or languages present in the list of text documents.

        Access Level: Read

        https://docs.aws.amazon.com/comprehend/latest/dg/API_BatchDetectDominantLanguage.html

        :stability: experimental
        '''
        return typing.cast("Comprehend", jsii.invoke(self, "toBatchDetectDominantLanguage", []))

    @jsii.member(jsii_name="toBatchDetectEntities")
    def to_batch_detect_entities(self) -> "Comprehend":
        '''(experimental) Grants permission to detect the named entities ("People", "Places", "Locations", etc) within the given list of text documents.

        Access Level: Read

        https://docs.aws.amazon.com/comprehend/latest/dg/API_BatchDetectEntities.html

        :stability: experimental
        '''
        return typing.cast("Comprehend", jsii.invoke(self, "toBatchDetectEntities", []))

    @jsii.member(jsii_name="toBatchDetectKeyPhrases")
    def to_batch_detect_key_phrases(self) -> "Comprehend":
        '''(experimental) Grants permission to detect the phrases in the list of text documents that are most indicative of the content.

        Access Level: Read

        https://docs.aws.amazon.com/comprehend/latest/dg/API_BatchDetectKeyPhrases.html

        :stability: experimental
        '''
        return typing.cast("Comprehend", jsii.invoke(self, "toBatchDetectKeyPhrases", []))

    @jsii.member(jsii_name="toBatchDetectSentiment")
    def to_batch_detect_sentiment(self) -> "Comprehend":
        '''(experimental) Grants permission to detect the sentiment of a text in the list of documents (Positive, Negative, Neutral, or Mixed).

        Access Level: Read

        https://docs.aws.amazon.com/comprehend/latest/dg/API_BatchDetectSentiment.html

        :stability: experimental
        '''
        return typing.cast("Comprehend", jsii.invoke(self, "toBatchDetectSentiment", []))

    @jsii.member(jsii_name="toBatchDetectSyntax")
    def to_batch_detect_syntax(self) -> "Comprehend":
        '''(experimental) Grants permission to detect syntactic information (like Part of Speech, Tokens) in a list of text documents.

        Access Level: Read

        https://docs.aws.amazon.com/comprehend/latest/dg/API_BatchDetectSyntax.html

        :stability: experimental
        '''
        return typing.cast("Comprehend", jsii.invoke(self, "toBatchDetectSyntax", []))

    @jsii.member(jsii_name="toBatchDetectTargetedSentiment")
    def to_batch_detect_targeted_sentiment(self) -> "Comprehend":
        '''(experimental) Grants permission to detect the sentiments associated with specific entities (such as brands or products) within the given list of text documents.

        Access Level: Read

        https://docs.aws.amazon.com/comprehend/latest/dg/API_BatchDetectTargetedSentiment.html

        :stability: experimental
        '''
        return typing.cast("Comprehend", jsii.invoke(self, "toBatchDetectTargetedSentiment", []))

    @jsii.member(jsii_name="toClassifyDocument")
    def to_classify_document(self) -> "Comprehend":
        '''(experimental) Grants permission to create a new document classification request to analyze a single document in real-time, using a previously created and trained custom model and an endpoint.

        Access Level: Read

        https://docs.aws.amazon.com/comprehend/latest/dg/API_ClassifyDocument.html

        :stability: experimental
        '''
        return typing.cast("Comprehend", jsii.invoke(self, "toClassifyDocument", []))

    @jsii.member(jsii_name="toContainsPiiEntities")
    def to_contains_pii_entities(self) -> "Comprehend":
        '''(experimental) Grants permission to classify the personally identifiable information within given documents in real-time.

        Access Level: Read

        https://docs.aws.amazon.com/comprehend/latest/dg/API_ContainsPiiEntities.html

        :stability: experimental
        '''
        return typing.cast("Comprehend", jsii.invoke(self, "toContainsPiiEntities", []))

    @jsii.member(jsii_name="toCreateDocumentClassifier")
    def to_create_document_classifier(self) -> "Comprehend":
        '''(experimental) Grants permission to create a new document classifier that you can use to categorize documents.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifVolumeKmsKey()
        - .ifModelKmsKey()
        - .ifOutputKmsKey()
        - .ifVpcSecurityGroupIds()
        - .ifVpcSubnets()

        https://docs.aws.amazon.com/comprehend/latest/dg/API_CreateDocumentClassifier.html

        :stability: experimental
        '''
        return typing.cast("Comprehend", jsii.invoke(self, "toCreateDocumentClassifier", []))

    @jsii.member(jsii_name="toCreateEndpoint")
    def to_create_endpoint(self) -> "Comprehend":
        '''(experimental) Grants permission to create a model-specific endpoint for synchronous inference for a previously trained custom model.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/comprehend/latest/dg/API_CreateEndpoint.html

        :stability: experimental
        '''
        return typing.cast("Comprehend", jsii.invoke(self, "toCreateEndpoint", []))

    @jsii.member(jsii_name="toCreateEntityRecognizer")
    def to_create_entity_recognizer(self) -> "Comprehend":
        '''(experimental) Grants permission to create an entity recognizer using submitted files.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifVolumeKmsKey()
        - .ifModelKmsKey()
        - .ifVpcSecurityGroupIds()
        - .ifVpcSubnets()

        https://docs.aws.amazon.com/comprehend/latest/dg/API_CreateEntityRecognizer.html

        :stability: experimental
        '''
        return typing.cast("Comprehend", jsii.invoke(self, "toCreateEntityRecognizer", []))

    @jsii.member(jsii_name="toDeleteDocumentClassifier")
    def to_delete_document_classifier(self) -> "Comprehend":
        '''(experimental) Grants permission to delete a previously created document classifier.

        Access Level: Write

        https://docs.aws.amazon.com/comprehend/latest/dg/API_DeleteDocumentClassifier.html

        :stability: experimental
        '''
        return typing.cast("Comprehend", jsii.invoke(self, "toDeleteDocumentClassifier", []))

    @jsii.member(jsii_name="toDeleteEndpoint")
    def to_delete_endpoint(self) -> "Comprehend":
        '''(experimental) Grants permission to delete a model-specific endpoint for a previously-trained custom model.

        All endpoints must be deleted in order for the model to be deleted

        Access Level: Write

        https://docs.aws.amazon.com/comprehend/latest/dg/API_DeleteEndpoint.html

        :stability: experimental
        '''
        return typing.cast("Comprehend", jsii.invoke(self, "toDeleteEndpoint", []))

    @jsii.member(jsii_name="toDeleteEntityRecognizer")
    def to_delete_entity_recognizer(self) -> "Comprehend":
        '''(experimental) Grants permission to delete a submitted entity recognizer.

        Access Level: Write

        https://docs.aws.amazon.com/comprehend/latest/dg/API_DeleteEntityRecognizer.html

        :stability: experimental
        '''
        return typing.cast("Comprehend", jsii.invoke(self, "toDeleteEntityRecognizer", []))

    @jsii.member(jsii_name="toDeleteResourcePolicy")
    def to_delete_resource_policy(self) -> "Comprehend":
        '''(experimental) Grants permission to remove policy on resource.

        Access Level: Write

        https://docs.aws.amazon.com/comprehend/latest/dg/API_DeleteResourcePolicy.html

        :stability: experimental
        '''
        return typing.cast("Comprehend", jsii.invoke(self, "toDeleteResourcePolicy", []))

    @jsii.member(jsii_name="toDescribeDocumentClassificationJob")
    def to_describe_document_classification_job(self) -> "Comprehend":
        '''(experimental) Grants permission to get the properties associated with a document classification job.

        Access Level: Read

        https://docs.aws.amazon.com/comprehend/latest/dg/API_DescribeDocumentClassificationJob.html

        :stability: experimental
        '''
        return typing.cast("Comprehend", jsii.invoke(self, "toDescribeDocumentClassificationJob", []))

    @jsii.member(jsii_name="toDescribeDocumentClassifier")
    def to_describe_document_classifier(self) -> "Comprehend":
        '''(experimental) Grants permission to get the properties associated with a document classifier.

        Access Level: Read

        https://docs.aws.amazon.com/comprehend/latest/dg/API_DescribeDocumentClassifier.html

        :stability: experimental
        '''
        return typing.cast("Comprehend", jsii.invoke(self, "toDescribeDocumentClassifier", []))

    @jsii.member(jsii_name="toDescribeDominantLanguageDetectionJob")
    def to_describe_dominant_language_detection_job(self) -> "Comprehend":
        '''(experimental) Grants permission to get the properties associated with a dominant language detection job.

        Access Level: Read

        https://docs.aws.amazon.com/comprehend/latest/dg/API_DescribeDominantLanguageDetectionJob.html

        :stability: experimental
        '''
        return typing.cast("Comprehend", jsii.invoke(self, "toDescribeDominantLanguageDetectionJob", []))

    @jsii.member(jsii_name="toDescribeEndpoint")
    def to_describe_endpoint(self) -> "Comprehend":
        '''(experimental) Grants permission to get the properties associated with a specific endpoint.

        Use this operation to get the status of an endpoint

        Access Level: Read

        https://docs.aws.amazon.com/comprehend/latest/dg/API_DescribeEndpoint.html

        :stability: experimental
        '''
        return typing.cast("Comprehend", jsii.invoke(self, "toDescribeEndpoint", []))

    @jsii.member(jsii_name="toDescribeEntitiesDetectionJob")
    def to_describe_entities_detection_job(self) -> "Comprehend":
        '''(experimental) Grants permission to get the properties associated with an entities detection job.

        Access Level: Read

        https://docs.aws.amazon.com/comprehend/latest/dg/API_DescribeEntitiesDetectionJob.html

        :stability: experimental
        '''
        return typing.cast("Comprehend", jsii.invoke(self, "toDescribeEntitiesDetectionJob", []))

    @jsii.member(jsii_name="toDescribeEntityRecognizer")
    def to_describe_entity_recognizer(self) -> "Comprehend":
        '''(experimental) Grants permission to provide details about an entity recognizer including status, S3 buckets containing training data, recognizer metadata, metrics, and so on.

        Access Level: Read

        https://docs.aws.amazon.com/comprehend/latest/dg/API_DescribeEntityRecognizer.html

        :stability: experimental
        '''
        return typing.cast("Comprehend", jsii.invoke(self, "toDescribeEntityRecognizer", []))

    @jsii.member(jsii_name="toDescribeEventsDetectionJob")
    def to_describe_events_detection_job(self) -> "Comprehend":
        '''(experimental) Grants permission to get the properties associated with an Events detection job.

        Access Level: Read

        https://docs.aws.amazon.com/comprehend/latest/dg/API_DescribeEventsDetectionJob.html

        :stability: experimental
        '''
        return typing.cast("Comprehend", jsii.invoke(self, "toDescribeEventsDetectionJob", []))

    @jsii.member(jsii_name="toDescribeKeyPhrasesDetectionJob")
    def to_describe_key_phrases_detection_job(self) -> "Comprehend":
        '''(experimental) Grants permission to get the properties associated with a key phrases detection job.

        Access Level: Read

        https://docs.aws.amazon.com/comprehend/latest/dg/API_DescribeKeyPhrasesDetectionJob.html

        :stability: experimental
        '''
        return typing.cast("Comprehend", jsii.invoke(self, "toDescribeKeyPhrasesDetectionJob", []))

    @jsii.member(jsii_name="toDescribePiiEntitiesDetectionJob")
    def to_describe_pii_entities_detection_job(self) -> "Comprehend":
        '''(experimental) Grants permission to get the properties associated with a PII entities detection job.

        Access Level: Read

        https://docs.aws.amazon.com/comprehend/latest/dg/API_DescribePiiEntitiesDetectionJob.html

        :stability: experimental
        '''
        return typing.cast("Comprehend", jsii.invoke(self, "toDescribePiiEntitiesDetectionJob", []))

    @jsii.member(jsii_name="toDescribeResourcePolicy")
    def to_describe_resource_policy(self) -> "Comprehend":
        '''(experimental) Grants permission to read attached policy on resource.

        Access Level: Read

        https://docs.aws.amazon.com/comprehend/latest/dg/API_DescribeResourcePolicy.html

        :stability: experimental
        '''
        return typing.cast("Comprehend", jsii.invoke(self, "toDescribeResourcePolicy", []))

    @jsii.member(jsii_name="toDescribeSentimentDetectionJob")
    def to_describe_sentiment_detection_job(self) -> "Comprehend":
        '''(experimental) Grants permission to get the properties associated with a sentiment detection job.

        Access Level: Read

        https://docs.aws.amazon.com/comprehend/latest/dg/API_DescribeSentimentDetectionJob.html

        :stability: experimental
        '''
        return typing.cast("Comprehend", jsii.invoke(self, "toDescribeSentimentDetectionJob", []))

    @jsii.member(jsii_name="toDescribeTargetedSentimentDetectionJob")
    def to_describe_targeted_sentiment_detection_job(self) -> "Comprehend":
        '''(experimental) Grants permission to get the properties associated with a targeted sentiment detection job.

        Access Level: Read

        https://docs.aws.amazon.com/comprehend/latest/dg/API_DescribeTargetedSentimentDetectionJob.html

        :stability: experimental
        '''
        return typing.cast("Comprehend", jsii.invoke(self, "toDescribeTargetedSentimentDetectionJob", []))

    @jsii.member(jsii_name="toDescribeTopicsDetectionJob")
    def to_describe_topics_detection_job(self) -> "Comprehend":
        '''(experimental) Grants permission to get the properties associated with a topic detection job.

        Access Level: Read

        https://docs.aws.amazon.com/comprehend/latest/dg/API_DescribeTopicsDetectionJob.html

        :stability: experimental
        '''
        return typing.cast("Comprehend", jsii.invoke(self, "toDescribeTopicsDetectionJob", []))

    @jsii.member(jsii_name="toDetectDominantLanguage")
    def to_detect_dominant_language(self) -> "Comprehend":
        '''(experimental) Grants permission to detect the language or languages present in the text.

        Access Level: Read

        https://docs.aws.amazon.com/comprehend/latest/dg/API_DetectDominantLanguage.html

        :stability: experimental
        '''
        return typing.cast("Comprehend", jsii.invoke(self, "toDetectDominantLanguage", []))

    @jsii.member(jsii_name="toDetectEntities")
    def to_detect_entities(self) -> "Comprehend":
        '''(experimental) Grants permission to detect the named entities ("People", "Places", "Locations", etc) within the given text document.

        Access Level: Read

        https://docs.aws.amazon.com/comprehend/latest/dg/API_DetectEntities.html

        :stability: experimental
        '''
        return typing.cast("Comprehend", jsii.invoke(self, "toDetectEntities", []))

    @jsii.member(jsii_name="toDetectKeyPhrases")
    def to_detect_key_phrases(self) -> "Comprehend":
        '''(experimental) Grants permission to detect the phrases in the text that are most indicative of the content.

        Access Level: Read

        https://docs.aws.amazon.com/comprehend/latest/dg/API_DetectKeyPhrases.html

        :stability: experimental
        '''
        return typing.cast("Comprehend", jsii.invoke(self, "toDetectKeyPhrases", []))

    @jsii.member(jsii_name="toDetectPiiEntities")
    def to_detect_pii_entities(self) -> "Comprehend":
        '''(experimental) Grants permission to detect the personally identifiable information entities ("Name", "SSN", "PIN", etc) within the given text document.

        Access Level: Read

        https://docs.aws.amazon.com/comprehend/latest/dg/API_DetectPiiEntities.html

        :stability: experimental
        '''
        return typing.cast("Comprehend", jsii.invoke(self, "toDetectPiiEntities", []))

    @jsii.member(jsii_name="toDetectSentiment")
    def to_detect_sentiment(self) -> "Comprehend":
        '''(experimental) Grants permission to detect the sentiment of a text in a document (Positive, Negative, Neutral, or Mixed).

        Access Level: Read

        https://docs.aws.amazon.com/comprehend/latest/dg/API_DetectSentiment.html

        :stability: experimental
        '''
        return typing.cast("Comprehend", jsii.invoke(self, "toDetectSentiment", []))

    @jsii.member(jsii_name="toDetectSyntax")
    def to_detect_syntax(self) -> "Comprehend":
        '''(experimental) Grants permission to detect syntactic information (like Part of Speech, Tokens) in a text document.

        Access Level: Read

        https://docs.aws.amazon.com/comprehend/latest/dg/API_DetectSyntax.html

        :stability: experimental
        '''
        return typing.cast("Comprehend", jsii.invoke(self, "toDetectSyntax", []))

    @jsii.member(jsii_name="toDetectTargetedSentiment")
    def to_detect_targeted_sentiment(self) -> "Comprehend":
        '''(experimental) Grants permission to detect the sentiments associated with specific entities (such as brands or products) in a document.

        Access Level: Read

        https://docs.aws.amazon.com/comprehend/latest/dg/API_DetectTargetedSentiment.html

        :stability: experimental
        '''
        return typing.cast("Comprehend", jsii.invoke(self, "toDetectTargetedSentiment", []))

    @jsii.member(jsii_name="toImportModel")
    def to_import_model(self) -> "Comprehend":
        '''(experimental) Grants permission to import a trained Comprehend model.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifModelKmsKey()

        https://docs.aws.amazon.com/comprehend/latest/dg/API_ImportModel.html

        :stability: experimental
        '''
        return typing.cast("Comprehend", jsii.invoke(self, "toImportModel", []))

    @jsii.member(jsii_name="toListDocumentClassificationJobs")
    def to_list_document_classification_jobs(self) -> "Comprehend":
        '''(experimental) Grants permission to get a list of the document classification jobs that you have submitted.

        Access Level: Read

        https://docs.aws.amazon.com/comprehend/latest/dg/API_ListDocumentClassificationJobs.html

        :stability: experimental
        '''
        return typing.cast("Comprehend", jsii.invoke(self, "toListDocumentClassificationJobs", []))

    @jsii.member(jsii_name="toListDocumentClassifiers")
    def to_list_document_classifiers(self) -> "Comprehend":
        '''(experimental) Grants permission to get a list of the document classifiers that you have created.

        Access Level: Read

        https://docs.aws.amazon.com/comprehend/latest/dg/API_ListDocumentClassifiers.html

        :stability: experimental
        '''
        return typing.cast("Comprehend", jsii.invoke(self, "toListDocumentClassifiers", []))

    @jsii.member(jsii_name="toListDocumentClassifierSummaries")
    def to_list_document_classifier_summaries(self) -> "Comprehend":
        '''(experimental) Grants permission to get a list of summaries of the document classifiers that you have created.

        Access Level: Read

        https://docs.aws.amazon.com/comprehend/latest/dg/API_ListDocumentClassifierSummaries.html

        :stability: experimental
        '''
        return typing.cast("Comprehend", jsii.invoke(self, "toListDocumentClassifierSummaries", []))

    @jsii.member(jsii_name="toListDominantLanguageDetectionJobs")
    def to_list_dominant_language_detection_jobs(self) -> "Comprehend":
        '''(experimental) Grants permission to get a list of the dominant language detection jobs that you have submitted.

        Access Level: Read

        https://docs.aws.amazon.com/comprehend/latest/dg/API_ListDominantLanguageDetectionJobs.html

        :stability: experimental
        '''
        return typing.cast("Comprehend", jsii.invoke(self, "toListDominantLanguageDetectionJobs", []))

    @jsii.member(jsii_name="toListEndpoints")
    def to_list_endpoints(self) -> "Comprehend":
        '''(experimental) Grants permission to get a list of all existing endpoints that you've created.

        Access Level: Read

        https://docs.aws.amazon.com/comprehend/latest/dg/API_ListEndpoints.html

        :stability: experimental
        '''
        return typing.cast("Comprehend", jsii.invoke(self, "toListEndpoints", []))

    @jsii.member(jsii_name="toListEntitiesDetectionJobs")
    def to_list_entities_detection_jobs(self) -> "Comprehend":
        '''(experimental) Grants permission to get a list of the entity detection jobs that you have submitted.

        Access Level: Read

        https://docs.aws.amazon.com/comprehend/latest/dg/API_ListEntitiesDetectionJobs.html

        :stability: experimental
        '''
        return typing.cast("Comprehend", jsii.invoke(self, "toListEntitiesDetectionJobs", []))

    @jsii.member(jsii_name="toListEntityRecognizers")
    def to_list_entity_recognizers(self) -> "Comprehend":
        '''(experimental) Grants permission to get a list of the properties of all entity recognizers that you created, including recognizers currently in training.

        Access Level: Read

        https://docs.aws.amazon.com/comprehend/latest/dg/API_ListEntityRecognizers.html

        :stability: experimental
        '''
        return typing.cast("Comprehend", jsii.invoke(self, "toListEntityRecognizers", []))

    @jsii.member(jsii_name="toListEntityRecognizerSummaries")
    def to_list_entity_recognizer_summaries(self) -> "Comprehend":
        '''(experimental) Grants permission to get a list of summaries for the entity recognizers that you have created.

        Access Level: Read

        https://docs.aws.amazon.com/comprehend/latest/dg/API_ListEntityRecognizerSummaries.html

        :stability: experimental
        '''
        return typing.cast("Comprehend", jsii.invoke(self, "toListEntityRecognizerSummaries", []))

    @jsii.member(jsii_name="toListEventsDetectionJobs")
    def to_list_events_detection_jobs(self) -> "Comprehend":
        '''(experimental) Grants permission to get a list of Events detection jobs that you have submitted.

        Access Level: Read

        https://docs.aws.amazon.com/comprehend/latest/dg/API_ListEventsDetectionJobs.html

        :stability: experimental
        '''
        return typing.cast("Comprehend", jsii.invoke(self, "toListEventsDetectionJobs", []))

    @jsii.member(jsii_name="toListKeyPhrasesDetectionJobs")
    def to_list_key_phrases_detection_jobs(self) -> "Comprehend":
        '''(experimental) Grants permission to get a list of key phrase detection jobs that you have submitted.

        Access Level: Read

        https://docs.aws.amazon.com/comprehend/latest/dg/API_ListKeyPhrasesDetectionJobs.html

        :stability: experimental
        '''
        return typing.cast("Comprehend", jsii.invoke(self, "toListKeyPhrasesDetectionJobs", []))

    @jsii.member(jsii_name="toListPiiEntitiesDetectionJobs")
    def to_list_pii_entities_detection_jobs(self) -> "Comprehend":
        '''(experimental) Grants permission to get a list of PII entities detection jobs that you have submitted.

        Access Level: Read

        https://docs.aws.amazon.com/comprehend/latest/dg/API_ListPiiEntitiesDetectionJobs.html

        :stability: experimental
        '''
        return typing.cast("Comprehend", jsii.invoke(self, "toListPiiEntitiesDetectionJobs", []))

    @jsii.member(jsii_name="toListSentimentDetectionJobs")
    def to_list_sentiment_detection_jobs(self) -> "Comprehend":
        '''(experimental) Grants permission to get a list of sentiment detection jobs that you have submitted.

        Access Level: Read

        https://docs.aws.amazon.com/comprehend/latest/dg/API_ListSentimentDetectionJobs.html

        :stability: experimental
        '''
        return typing.cast("Comprehend", jsii.invoke(self, "toListSentimentDetectionJobs", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Comprehend":
        '''(experimental) Grants permission to list tags for a resource.

        Access Level: Read

        https://docs.aws.amazon.com/comprehend/latest/dg/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("Comprehend", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toListTargetedSentimentDetectionJobs")
    def to_list_targeted_sentiment_detection_jobs(self) -> "Comprehend":
        '''(experimental) Grants permission to get a list of targeted sentiment detection jobs that you have submitted.

        Access Level: Read

        https://docs.aws.amazon.com/comprehend/latest/dg/API_ListTargetedSentimentDetectionJobs.html

        :stability: experimental
        '''
        return typing.cast("Comprehend", jsii.invoke(self, "toListTargetedSentimentDetectionJobs", []))

    @jsii.member(jsii_name="toListTopicsDetectionJobs")
    def to_list_topics_detection_jobs(self) -> "Comprehend":
        '''(experimental) Grants permission to get a list of the topic detection jobs that you have submitted.

        Access Level: Read

        https://docs.aws.amazon.com/comprehend/latest/dg/API_ListTopicsDetectionJobs.html

        :stability: experimental
        '''
        return typing.cast("Comprehend", jsii.invoke(self, "toListTopicsDetectionJobs", []))

    @jsii.member(jsii_name="toPutResourcePolicy")
    def to_put_resource_policy(self) -> "Comprehend":
        '''(experimental) Grants permission to attach policy to resource.

        Access Level: Write

        https://docs.aws.amazon.com/comprehend/latest/dg/API_PutResourcePolicy.html

        :stability: experimental
        '''
        return typing.cast("Comprehend", jsii.invoke(self, "toPutResourcePolicy", []))

    @jsii.member(jsii_name="toStartDocumentClassificationJob")
    def to_start_document_classification_job(self) -> "Comprehend":
        '''(experimental) Grants permission to start an asynchronous document classification job.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifVolumeKmsKey()
        - .ifOutputKmsKey()
        - .ifVpcSecurityGroupIds()
        - .ifVpcSubnets()

        https://docs.aws.amazon.com/comprehend/latest/dg/API_StartDocumentClassificationJob.html

        :stability: experimental
        '''
        return typing.cast("Comprehend", jsii.invoke(self, "toStartDocumentClassificationJob", []))

    @jsii.member(jsii_name="toStartDominantLanguageDetectionJob")
    def to_start_dominant_language_detection_job(self) -> "Comprehend":
        '''(experimental) Grants permission to start an asynchronous dominant language detection job for a collection of documents.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifVolumeKmsKey()
        - .ifOutputKmsKey()
        - .ifVpcSecurityGroupIds()
        - .ifVpcSubnets()

        https://docs.aws.amazon.com/comprehend/latest/dg/API_StartDominantLanguageDetectionJob.html

        :stability: experimental
        '''
        return typing.cast("Comprehend", jsii.invoke(self, "toStartDominantLanguageDetectionJob", []))

    @jsii.member(jsii_name="toStartEntitiesDetectionJob")
    def to_start_entities_detection_job(self) -> "Comprehend":
        '''(experimental) Grants permission to start an asynchronous entity detection job for a collection of documents.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifVolumeKmsKey()
        - .ifOutputKmsKey()
        - .ifVpcSecurityGroupIds()
        - .ifVpcSubnets()

        https://docs.aws.amazon.com/comprehend/latest/dg/API_StartEntitiesDetectionJob.html

        :stability: experimental
        '''
        return typing.cast("Comprehend", jsii.invoke(self, "toStartEntitiesDetectionJob", []))

    @jsii.member(jsii_name="toStartEventsDetectionJob")
    def to_start_events_detection_job(self) -> "Comprehend":
        '''(experimental) Grants permission to start an asynchronous Events detection job for a collection of documents.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifOutputKmsKey()

        https://docs.aws.amazon.com/comprehend/latest/dg/API_StartEventsDetectionJob.html

        :stability: experimental
        '''
        return typing.cast("Comprehend", jsii.invoke(self, "toStartEventsDetectionJob", []))

    @jsii.member(jsii_name="toStartKeyPhrasesDetectionJob")
    def to_start_key_phrases_detection_job(self) -> "Comprehend":
        '''(experimental) Grants permission to start an asynchronous key phrase detection job for a collection of documents.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifVolumeKmsKey()
        - .ifOutputKmsKey()
        - .ifVpcSecurityGroupIds()
        - .ifVpcSubnets()

        https://docs.aws.amazon.com/comprehend/latest/dg/API_StartKeyPhrasesDetectionJob.html

        :stability: experimental
        '''
        return typing.cast("Comprehend", jsii.invoke(self, "toStartKeyPhrasesDetectionJob", []))

    @jsii.member(jsii_name="toStartPiiEntitiesDetectionJob")
    def to_start_pii_entities_detection_job(self) -> "Comprehend":
        '''(experimental) Grants permission to start an asynchronous PII entities detection job for a collection of documents.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifOutputKmsKey()

        https://docs.aws.amazon.com/comprehend/latest/dg/API_StartPiiEntitiesDetectionJob.html

        :stability: experimental
        '''
        return typing.cast("Comprehend", jsii.invoke(self, "toStartPiiEntitiesDetectionJob", []))

    @jsii.member(jsii_name="toStartSentimentDetectionJob")
    def to_start_sentiment_detection_job(self) -> "Comprehend":
        '''(experimental) Grants permission to start an asynchronous sentiment detection job for a collection of documents.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifVolumeKmsKey()
        - .ifOutputKmsKey()
        - .ifVpcSecurityGroupIds()
        - .ifVpcSubnets()

        https://docs.aws.amazon.com/comprehend/latest/dg/API_StartSentimentDetectionJob.html

        :stability: experimental
        '''
        return typing.cast("Comprehend", jsii.invoke(self, "toStartSentimentDetectionJob", []))

    @jsii.member(jsii_name="toStartTargetedSentimentDetectionJob")
    def to_start_targeted_sentiment_detection_job(self) -> "Comprehend":
        '''(experimental) Grants permission to start an asynchronous targeted sentiment detection job for a collection of documents.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifVolumeKmsKey()
        - .ifOutputKmsKey()
        - .ifVpcSecurityGroupIds()
        - .ifVpcSubnets()

        https://docs.aws.amazon.com/comprehend/latest/dg/API_StartTargetedSentimentDetectionJob.html

        :stability: experimental
        '''
        return typing.cast("Comprehend", jsii.invoke(self, "toStartTargetedSentimentDetectionJob", []))

    @jsii.member(jsii_name="toStartTopicsDetectionJob")
    def to_start_topics_detection_job(self) -> "Comprehend":
        '''(experimental) Grants permission to start an asynchronous job to detect the most common topics in the collection of documents and the phrases associated with each topic.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifVolumeKmsKey()
        - .ifOutputKmsKey()
        - .ifVpcSecurityGroupIds()
        - .ifVpcSubnets()

        https://docs.aws.amazon.com/comprehend/latest/dg/API_StartTopicsDetectionJob.html

        :stability: experimental
        '''
        return typing.cast("Comprehend", jsii.invoke(self, "toStartTopicsDetectionJob", []))

    @jsii.member(jsii_name="toStopDominantLanguageDetectionJob")
    def to_stop_dominant_language_detection_job(self) -> "Comprehend":
        '''(experimental) Grants permission to stop a dominant language detection job.

        Access Level: Write

        https://docs.aws.amazon.com/comprehend/latest/dg/API_StopDominantLanguageDetectionJob.html

        :stability: experimental
        '''
        return typing.cast("Comprehend", jsii.invoke(self, "toStopDominantLanguageDetectionJob", []))

    @jsii.member(jsii_name="toStopEntitiesDetectionJob")
    def to_stop_entities_detection_job(self) -> "Comprehend":
        '''(experimental) Grants permission to stop an entity detection job.

        Access Level: Write

        https://docs.aws.amazon.com/comprehend/latest/dg/API_StopEntitiesDetectionJob.html

        :stability: experimental
        '''
        return typing.cast("Comprehend", jsii.invoke(self, "toStopEntitiesDetectionJob", []))

    @jsii.member(jsii_name="toStopEventsDetectionJob")
    def to_stop_events_detection_job(self) -> "Comprehend":
        '''(experimental) Grants permission to stop an Events detection job.

        Access Level: Write

        https://docs.aws.amazon.com/comprehend/latest/dg/API_StopEventsDetectionJob.html

        :stability: experimental
        '''
        return typing.cast("Comprehend", jsii.invoke(self, "toStopEventsDetectionJob", []))

    @jsii.member(jsii_name="toStopKeyPhrasesDetectionJob")
    def to_stop_key_phrases_detection_job(self) -> "Comprehend":
        '''(experimental) Grants permission to stop a key phrase detection job.

        Access Level: Write

        https://docs.aws.amazon.com/comprehend/latest/dg/API_StopKeyPhrasesDetectionJob.html

        :stability: experimental
        '''
        return typing.cast("Comprehend", jsii.invoke(self, "toStopKeyPhrasesDetectionJob", []))

    @jsii.member(jsii_name="toStopPiiEntitiesDetectionJob")
    def to_stop_pii_entities_detection_job(self) -> "Comprehend":
        '''(experimental) Grants permission to stop a PII entities detection job.

        Access Level: Write

        https://docs.aws.amazon.com/comprehend/latest/dg/API_StopPiiEntitiesDetectionJob.html

        :stability: experimental
        '''
        return typing.cast("Comprehend", jsii.invoke(self, "toStopPiiEntitiesDetectionJob", []))

    @jsii.member(jsii_name="toStopSentimentDetectionJob")
    def to_stop_sentiment_detection_job(self) -> "Comprehend":
        '''(experimental) Grants permission to stop a sentiment detection job.

        Access Level: Write

        https://docs.aws.amazon.com/comprehend/latest/dg/API_StopSentimentDetectionJob.html

        :stability: experimental
        '''
        return typing.cast("Comprehend", jsii.invoke(self, "toStopSentimentDetectionJob", []))

    @jsii.member(jsii_name="toStopTargetedSentimentDetectionJob")
    def to_stop_targeted_sentiment_detection_job(self) -> "Comprehend":
        '''(experimental) Grants permission to stop a targeted sentiment detection job.

        Access Level: Write

        https://docs.aws.amazon.com/comprehend/latest/dg/API_StopTargetedSentimentDetectionJob.html

        :stability: experimental
        '''
        return typing.cast("Comprehend", jsii.invoke(self, "toStopTargetedSentimentDetectionJob", []))

    @jsii.member(jsii_name="toStopTrainingDocumentClassifier")
    def to_stop_training_document_classifier(self) -> "Comprehend":
        '''(experimental) Grants permission to stop a previously created document classifier training job.

        Access Level: Write

        https://docs.aws.amazon.com/comprehend/latest/dg/API_StopTrainingDocumentClassifier.html

        :stability: experimental
        '''
        return typing.cast("Comprehend", jsii.invoke(self, "toStopTrainingDocumentClassifier", []))

    @jsii.member(jsii_name="toStopTrainingEntityRecognizer")
    def to_stop_training_entity_recognizer(self) -> "Comprehend":
        '''(experimental) Grants permission to stop a previously created entity recognizer training job.

        Access Level: Write

        https://docs.aws.amazon.com/comprehend/latest/dg/API_StopTrainingEntityRecognizer.html

        :stability: experimental
        '''
        return typing.cast("Comprehend", jsii.invoke(self, "toStopTrainingEntityRecognizer", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Comprehend":
        '''(experimental) Grants permission to tag a resource with given key value pairs.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/comprehend/latest/dg/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("Comprehend", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Comprehend":
        '''(experimental) Grants permission to untag a resource with given key.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/comprehend/latest/dg/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("Comprehend", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateEndpoint")
    def to_update_endpoint(self) -> "Comprehend":
        '''(experimental) Grants permission to update information about the specified endpoint.

        Access Level: Write

        https://docs.aws.amazon.com/comprehend/latest/dg/API_UpdateEndpoint.html

        :stability: experimental
        '''
        return typing.cast("Comprehend", jsii.invoke(self, "toUpdateEndpoint", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__df3ef050dde28806456fec3654a79d21cf09c8c7dd25955e96475216a6f95550)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c308046e51f4269d4d87e49f534b029140f372008c68561de6e9cfffce8c531a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Comprehendmedical(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Comprehendmedical",
):
    '''(experimental) Statement provider for service `comprehendmedical <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazoncomprehendmedical.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `comprehendmedical <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazoncomprehendmedical.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="toDescribeEntitiesDetectionV2Job")
    def to_describe_entities_detection_v2_job(self) -> "Comprehendmedical":
        '''(experimental) Grants permission to describe the properties of a medical entity detection job that you have submitted.

        Access Level: Read

        https://docs.aws.amazon.com/comprehend-medical/latest/dev/API_medical_DescribeEntitiesDetectionV2Job.html

        :stability: experimental
        '''
        return typing.cast("Comprehendmedical", jsii.invoke(self, "toDescribeEntitiesDetectionV2Job", []))

    @jsii.member(jsii_name="toDescribeICD10CMInferenceJob")
    def to_describe_icd10_cm_inference_job(self) -> "Comprehendmedical":
        '''(experimental) Grants permission to describe the properties of an ICD-10-CM linking job that you have submitted.

        Access Level: Read

        https://docs.aws.amazon.com/comprehend-medical/latest/dev/API_medical_DescribeICD10CMInferenceJob.html

        :stability: experimental
        '''
        return typing.cast("Comprehendmedical", jsii.invoke(self, "toDescribeICD10CMInferenceJob", []))

    @jsii.member(jsii_name="toDescribePHIDetectionJob")
    def to_describe_phi_detection_job(self) -> "Comprehendmedical":
        '''(experimental) Grants permission to describe the properties of a PHI entity detection job that you have submitted.

        Access Level: Read

        https://docs.aws.amazon.com/comprehend-medical/latest/dev/API_medical_DescribePHIDetectionJob.html

        :stability: experimental
        '''
        return typing.cast("Comprehendmedical", jsii.invoke(self, "toDescribePHIDetectionJob", []))

    @jsii.member(jsii_name="toDescribeRxNormInferenceJob")
    def to_describe_rx_norm_inference_job(self) -> "Comprehendmedical":
        '''(experimental) Grants permission to describe the properties of an RxNorm linking job that you have submitted.

        Access Level: Read

        https://docs.aws.amazon.com/comprehend-medical/latest/dev/API_medical_DescribeRxNormInferenceJob.html

        :stability: experimental
        '''
        return typing.cast("Comprehendmedical", jsii.invoke(self, "toDescribeRxNormInferenceJob", []))

    @jsii.member(jsii_name="toDescribeSNOMEDCTInferenceJob")
    def to_describe_snomedct_inference_job(self) -> "Comprehendmedical":
        '''(experimental) Grants permission to describe the properties of a SNOMED-CT linking job that you have submitted.

        Access Level: Read

        https://docs.aws.amazon.com/comprehend-medical/latest/dev/API_medical_DescribeSNOMEDCTInferenceJob.html

        :stability: experimental
        '''
        return typing.cast("Comprehendmedical", jsii.invoke(self, "toDescribeSNOMEDCTInferenceJob", []))

    @jsii.member(jsii_name="toDetectEntitiesV2")
    def to_detect_entities_v2(self) -> "Comprehendmedical":
        '''(experimental) Grants permission to detect the named medical entities, and their relationships and traits within the given text document.

        Access Level: Read

        https://docs.aws.amazon.com/comprehend-medical/latest/dev/API_medical_DetectEntitiesV2.html

        :stability: experimental
        '''
        return typing.cast("Comprehendmedical", jsii.invoke(self, "toDetectEntitiesV2", []))

    @jsii.member(jsii_name="toDetectPHI")
    def to_detect_phi(self) -> "Comprehendmedical":
        '''(experimental) Grants permission to detect the protected health information (PHI) entities within the given text document.

        Access Level: Read

        https://docs.aws.amazon.com/comprehend-medical/latest/dev/API_medical_DetectPHI.html

        :stability: experimental
        '''
        return typing.cast("Comprehendmedical", jsii.invoke(self, "toDetectPHI", []))

    @jsii.member(jsii_name="toInferICD10CM")
    def to_infer_icd10_cm(self) -> "Comprehendmedical":
        '''(experimental) Grants permission to detect the medical condition entities within the given text document and link them to ICD-10-CM codes.

        Access Level: Read

        https://docs.aws.amazon.com/comprehend-medical/latest/dev/API_medical_InferICD10CM.html

        :stability: experimental
        '''
        return typing.cast("Comprehendmedical", jsii.invoke(self, "toInferICD10CM", []))

    @jsii.member(jsii_name="toInferRxNorm")
    def to_infer_rx_norm(self) -> "Comprehendmedical":
        '''(experimental) Grants permission to detect the medication entities within the given text document and link them to RxCUI concept identifiers from the National Library of Medicine RxNorm database.

        Access Level: Read

        https://docs.aws.amazon.com/comprehend-medical/latest/dev/API_medical_InferRxNorm.html

        :stability: experimental
        '''
        return typing.cast("Comprehendmedical", jsii.invoke(self, "toInferRxNorm", []))

    @jsii.member(jsii_name="toInferSNOMEDCT")
    def to_infer_snomedct(self) -> "Comprehendmedical":
        '''(experimental) Grants permission to detect the medical condition, anatomy, and test, treatment, and procedure entities within the given text document and link them to SNOMED-CT codes.

        Access Level: Read

        https://docs.aws.amazon.com/comprehend-medical/latest/dev/API_medical_InferSNOMEDCT.html

        :stability: experimental
        '''
        return typing.cast("Comprehendmedical", jsii.invoke(self, "toInferSNOMEDCT", []))

    @jsii.member(jsii_name="toListEntitiesDetectionV2Jobs")
    def to_list_entities_detection_v2_jobs(self) -> "Comprehendmedical":
        '''(experimental) Grants permission to list the medical entity detection jobs that you have submitted.

        Access Level: Read

        https://docs.aws.amazon.com/comprehend-medical/latest/dev/API_medical_ListEntitiesDetectionV2Jobs.html

        :stability: experimental
        '''
        return typing.cast("Comprehendmedical", jsii.invoke(self, "toListEntitiesDetectionV2Jobs", []))

    @jsii.member(jsii_name="toListICD10CMInferenceJobs")
    def to_list_icd10_cm_inference_jobs(self) -> "Comprehendmedical":
        '''(experimental) Grants permission to list the ICD-10-CM linking jobs that you have submitted.

        Access Level: Read

        https://docs.aws.amazon.com/comprehend-medical/latest/dev/API_medical_ListICD10CMInferenceJobs.html

        :stability: experimental
        '''
        return typing.cast("Comprehendmedical", jsii.invoke(self, "toListICD10CMInferenceJobs", []))

    @jsii.member(jsii_name="toListPHIDetectionJobs")
    def to_list_phi_detection_jobs(self) -> "Comprehendmedical":
        '''(experimental) Grants permission to list the PHI entity detection jobs that you have submitted.

        Access Level: Read

        https://docs.aws.amazon.com/comprehend-medical/latest/dev/API_medical_ListPHIDetectionJobs.html

        :stability: experimental
        '''
        return typing.cast("Comprehendmedical", jsii.invoke(self, "toListPHIDetectionJobs", []))

    @jsii.member(jsii_name="toListRxNormInferenceJobs")
    def to_list_rx_norm_inference_jobs(self) -> "Comprehendmedical":
        '''(experimental) Grants permission to list the RxNorm linking jobs that you have submitted.

        Access Level: Read

        https://docs.aws.amazon.com/comprehend-medical/latest/dev/API_medical_ListRxNormInferenceJobs.html

        :stability: experimental
        '''
        return typing.cast("Comprehendmedical", jsii.invoke(self, "toListRxNormInferenceJobs", []))

    @jsii.member(jsii_name="toListSNOMEDCTInferenceJobs")
    def to_list_snomedct_inference_jobs(self) -> "Comprehendmedical":
        '''(experimental) Grants permission to list the SNOMED-CT linking jobs that you have submitted.

        Access Level: Read

        https://docs.aws.amazon.com/comprehend-medical/latest/dev/API_medical_ListSNOMEDCTInferenceJobs.html

        :stability: experimental
        '''
        return typing.cast("Comprehendmedical", jsii.invoke(self, "toListSNOMEDCTInferenceJobs", []))

    @jsii.member(jsii_name="toStartEntitiesDetectionV2Job")
    def to_start_entities_detection_v2_job(self) -> "Comprehendmedical":
        '''(experimental) Grants permission to start an asynchronous medical entity detection job for a collection of documents.

        Access Level: Write

        https://docs.aws.amazon.com/comprehend-medical/latest/dev/API_medical_StartEntitiesDetectionV2Job.html

        :stability: experimental
        '''
        return typing.cast("Comprehendmedical", jsii.invoke(self, "toStartEntitiesDetectionV2Job", []))

    @jsii.member(jsii_name="toStartICD10CMInferenceJob")
    def to_start_icd10_cm_inference_job(self) -> "Comprehendmedical":
        '''(experimental) Grants permission to start an asynchronous ICD-10-CM linking job for a collection of documents.

        Access Level: Write

        https://docs.aws.amazon.com/comprehend-medical/latest/dev/API_medical_StartICD10CMInferenceJob.html

        :stability: experimental
        '''
        return typing.cast("Comprehendmedical", jsii.invoke(self, "toStartICD10CMInferenceJob", []))

    @jsii.member(jsii_name="toStartPHIDetectionJob")
    def to_start_phi_detection_job(self) -> "Comprehendmedical":
        '''(experimental) Grants permission to start an asynchronous PHI entity detection job for a collection of documents.

        Access Level: Write

        https://docs.aws.amazon.com/comprehend-medical/latest/dev/API_medical_StartPHIDetectionJob.html

        :stability: experimental
        '''
        return typing.cast("Comprehendmedical", jsii.invoke(self, "toStartPHIDetectionJob", []))

    @jsii.member(jsii_name="toStartRxNormInferenceJob")
    def to_start_rx_norm_inference_job(self) -> "Comprehendmedical":
        '''(experimental) Grants permission to start an asynchronous RxNorm linking job for a collection of documents.

        Access Level: Write

        https://docs.aws.amazon.com/comprehend-medical/latest/dev/API_medical_StartRxNormInferenceJob.html

        :stability: experimental
        '''
        return typing.cast("Comprehendmedical", jsii.invoke(self, "toStartRxNormInferenceJob", []))

    @jsii.member(jsii_name="toStartSNOMEDCTInferenceJob")
    def to_start_snomedct_inference_job(self) -> "Comprehendmedical":
        '''(experimental) Grants permission to start an asynchronous SNOMED-CT linking job for a collection of documents.

        Access Level: Write

        https://docs.aws.amazon.com/comprehend-medical/latest/dev/API_medical_StartSNOMEDCTInferenceJob.html

        :stability: experimental
        '''
        return typing.cast("Comprehendmedical", jsii.invoke(self, "toStartSNOMEDCTInferenceJob", []))

    @jsii.member(jsii_name="toStopEntitiesDetectionV2Job")
    def to_stop_entities_detection_v2_job(self) -> "Comprehendmedical":
        '''(experimental) Grants permission to stop a medical entity detection job.

        Access Level: Write

        https://docs.aws.amazon.com/comprehend-medical/latest/dev/API_medical_StopEntitiesDetectionV2Job.html

        :stability: experimental
        '''
        return typing.cast("Comprehendmedical", jsii.invoke(self, "toStopEntitiesDetectionV2Job", []))

    @jsii.member(jsii_name="toStopICD10CMInferenceJob")
    def to_stop_icd10_cm_inference_job(self) -> "Comprehendmedical":
        '''(experimental) Grants permission to stop an ICD-10-CM linking job.

        Access Level: Write

        https://docs.aws.amazon.com/comprehend-medical/latest/dev/API_medical_StopICD10CMInferenceJob.html

        :stability: experimental
        '''
        return typing.cast("Comprehendmedical", jsii.invoke(self, "toStopICD10CMInferenceJob", []))

    @jsii.member(jsii_name="toStopPHIDetectionJob")
    def to_stop_phi_detection_job(self) -> "Comprehendmedical":
        '''(experimental) Grants permission to stop a PHI entity detection job.

        Access Level: Write

        https://docs.aws.amazon.com/comprehend-medical/latest/dev/API_medical_StopPHIDetectionJob.html

        :stability: experimental
        '''
        return typing.cast("Comprehendmedical", jsii.invoke(self, "toStopPHIDetectionJob", []))

    @jsii.member(jsii_name="toStopRxNormInferenceJob")
    def to_stop_rx_norm_inference_job(self) -> "Comprehendmedical":
        '''(experimental) Grants permission to stop an RxNorm linking job.

        Access Level: Write

        https://docs.aws.amazon.com/comprehend-medical/latest/dev/API_medical_StopRxNormInferenceJob.html

        :stability: experimental
        '''
        return typing.cast("Comprehendmedical", jsii.invoke(self, "toStopRxNormInferenceJob", []))

    @jsii.member(jsii_name="toStopSNOMEDCTInferenceJob")
    def to_stop_snomedct_inference_job(self) -> "Comprehendmedical":
        '''(experimental) Grants permission to stop a SNOMED-CT linking job.

        Access Level: Write

        https://docs.aws.amazon.com/comprehend-medical/latest/dev/API_medical_StopSNOMEDCTInferenceJob.html

        :stability: experimental
        '''
        return typing.cast("Comprehendmedical", jsii.invoke(self, "toStopSNOMEDCTInferenceJob", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7ec4aa90167650c7d17201b63948eaf91439e3f6f842b847245125ac99dbed29)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__776a349256b9d112cba90b7f65063ccd5ba9d7f53cfba870847dff235a36098c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class ComputeOptimizer(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.ComputeOptimizer",
):
    '''(experimental) Statement provider for service `compute-optimizer <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awscomputeoptimizer.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `compute-optimizer <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awscomputeoptimizer.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="ifResourceType")
    def if_resource_type(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "ComputeOptimizer":
        '''(experimental) Filters access by the resource type.

        https://docs.aws.amazon.com/compute-optimizer/latest/ug/security-iam.html

        Applies to actions:

        - .toDeleteRecommendationPreferences()
        - .toGetEffectiveRecommendationPreferences()
        - .toGetRecommendationPreferences()
        - .toPutRecommendationPreferences()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0f9e9f94831d6ec9c34cfe5483e419cd2ea3b0e104efcf504ba243a89be26016)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("ComputeOptimizer", jsii.invoke(self, "ifResourceType", [value, operator]))

    @jsii.member(jsii_name="toDeleteRecommendationPreferences")
    def to_delete_recommendation_preferences(self) -> "ComputeOptimizer":
        '''(experimental) Grants permission to delete recommendation preferences.

        Access Level: Write

        Possible conditions:

        - .ifResourceType()

        Dependent actions:

        - autoscaling:DescribeAutoScalingGroups
        - ec2:DescribeInstances

        https://docs.aws.amazon.com/compute-optimizer/latest/APIReference/API_DeleteRecommendationPreferences.html

        :stability: experimental
        '''
        return typing.cast("ComputeOptimizer", jsii.invoke(self, "toDeleteRecommendationPreferences", []))

    @jsii.member(jsii_name="toDescribeRecommendationExportJobs")
    def to_describe_recommendation_export_jobs(self) -> "ComputeOptimizer":
        '''(experimental) Grants permission to view the status of recommendation export jobs.

        Access Level: List

        https://docs.aws.amazon.com/compute-optimizer/latest/APIReference/API_DescribeRecommendationExportJobs.html

        :stability: experimental
        '''
        return typing.cast("ComputeOptimizer", jsii.invoke(self, "toDescribeRecommendationExportJobs", []))

    @jsii.member(jsii_name="toExportAutoScalingGroupRecommendations")
    def to_export_auto_scaling_group_recommendations(self) -> "ComputeOptimizer":
        '''(experimental) Grants permission to export AutoScaling group recommendations to S3 for the provided accounts.

        Access Level: Write

        Dependent actions:

        - autoscaling:DescribeAutoScalingGroups
        - compute-optimizer:GetAutoScalingGroupRecommendations

        https://docs.aws.amazon.com/compute-optimizer/latest/APIReference/API_ExportAutoScalingGroupRecommendations.html

        :stability: experimental
        '''
        return typing.cast("ComputeOptimizer", jsii.invoke(self, "toExportAutoScalingGroupRecommendations", []))

    @jsii.member(jsii_name="toExportEBSVolumeRecommendations")
    def to_export_ebs_volume_recommendations(self) -> "ComputeOptimizer":
        '''(experimental) Grants permission to export EBS volume recommendations to S3 for the provided accounts.

        Access Level: Write

        Dependent actions:

        - compute-optimizer:GetEBSVolumeRecommendations
        - ec2:DescribeVolumes

        https://docs.aws.amazon.com/compute-optimizer/latest/APIReference/API_ExportEBSVolumeRecommendations.html

        :stability: experimental
        '''
        return typing.cast("ComputeOptimizer", jsii.invoke(self, "toExportEBSVolumeRecommendations", []))

    @jsii.member(jsii_name="toExportEC2InstanceRecommendations")
    def to_export_ec2_instance_recommendations(self) -> "ComputeOptimizer":
        '''(experimental) Grants permission to export EC2 instance recommendations to S3 for the provided accounts.

        Access Level: Write

        Dependent actions:

        - compute-optimizer:GetEC2InstanceRecommendations
        - ec2:DescribeInstances

        https://docs.aws.amazon.com/compute-optimizer/latest/APIReference/API_ExportEC2InstanceRecommendations.html

        :stability: experimental
        '''
        return typing.cast("ComputeOptimizer", jsii.invoke(self, "toExportEC2InstanceRecommendations", []))

    @jsii.member(jsii_name="toExportLambdaFunctionRecommendations")
    def to_export_lambda_function_recommendations(self) -> "ComputeOptimizer":
        '''(experimental) Grants permission to export Lambda function recommendations to S3 for the provided accounts.

        Access Level: Write

        Dependent actions:

        - compute-optimizer:GetLambdaFunctionRecommendations
        - lambda:ListFunctions
        - lambda:ListProvisionedConcurrencyConfigs

        https://docs.aws.amazon.com/compute-optimizer/latest/APIReference/API_ExportLambdaFunctionRecommendations.html

        :stability: experimental
        '''
        return typing.cast("ComputeOptimizer", jsii.invoke(self, "toExportLambdaFunctionRecommendations", []))

    @jsii.member(jsii_name="toGetAutoScalingGroupRecommendations")
    def to_get_auto_scaling_group_recommendations(self) -> "ComputeOptimizer":
        '''(experimental) Grants permission to get recommendations for the provided AutoScaling groups.

        Access Level: List

        Dependent actions:

        - autoscaling:DescribeAutoScalingGroups

        https://docs.aws.amazon.com/compute-optimizer/latest/APIReference/API_GetAutoScalingGroupRecommendations.html

        :stability: experimental
        '''
        return typing.cast("ComputeOptimizer", jsii.invoke(self, "toGetAutoScalingGroupRecommendations", []))

    @jsii.member(jsii_name="toGetEBSVolumeRecommendations")
    def to_get_ebs_volume_recommendations(self) -> "ComputeOptimizer":
        '''(experimental) Grants permission to get recommendations for the provided EBS volumes.

        Access Level: List

        Dependent actions:

        - ec2:DescribeVolumes

        https://docs.aws.amazon.com/compute-optimizer/latest/APIReference/API_GetEBSVolumeRecommendations.html

        :stability: experimental
        '''
        return typing.cast("ComputeOptimizer", jsii.invoke(self, "toGetEBSVolumeRecommendations", []))

    @jsii.member(jsii_name="toGetEC2InstanceRecommendations")
    def to_get_ec2_instance_recommendations(self) -> "ComputeOptimizer":
        '''(experimental) Grants permission to get recommendations for the provided EC2 instances.

        Access Level: List

        Dependent actions:

        - ec2:DescribeInstances

        https://docs.aws.amazon.com/compute-optimizer/latest/APIReference/API_GetEC2InstanceRecommendations.html

        :stability: experimental
        '''
        return typing.cast("ComputeOptimizer", jsii.invoke(self, "toGetEC2InstanceRecommendations", []))

    @jsii.member(jsii_name="toGetEC2RecommendationProjectedMetrics")
    def to_get_ec2_recommendation_projected_metrics(self) -> "ComputeOptimizer":
        '''(experimental) Grants permission to get the recommendation projected metrics of the specified instance.

        Access Level: List

        Dependent actions:

        - ec2:DescribeInstances

        https://docs.aws.amazon.com/compute-optimizer/latest/APIReference/API_GetEC2RecommendationProjectedMetrics.html

        :stability: experimental
        '''
        return typing.cast("ComputeOptimizer", jsii.invoke(self, "toGetEC2RecommendationProjectedMetrics", []))

    @jsii.member(jsii_name="toGetEffectiveRecommendationPreferences")
    def to_get_effective_recommendation_preferences(self) -> "ComputeOptimizer":
        '''(experimental) Grants permission to get recommendation preferences that are in effect.

        Access Level: Read

        Possible conditions:

        - .ifResourceType()

        Dependent actions:

        - autoscaling:DescribeAutoScalingGroups
        - autoscaling:DescribeAutoScalingInstances
        - ec2:DescribeInstances

        https://docs.aws.amazon.com/compute-optimizer/latest/APIReference/API_GetEffectiveRecommendationPreferences.html

        :stability: experimental
        '''
        return typing.cast("ComputeOptimizer", jsii.invoke(self, "toGetEffectiveRecommendationPreferences", []))

    @jsii.member(jsii_name="toGetEnrollmentStatus")
    def to_get_enrollment_status(self) -> "ComputeOptimizer":
        '''(experimental) Grants permission to get the enrollment status for the specified account.

        Access Level: List

        https://docs.aws.amazon.com/compute-optimizer/latest/APIReference/API_GetEnrollmentStatus.html

        :stability: experimental
        '''
        return typing.cast("ComputeOptimizer", jsii.invoke(self, "toGetEnrollmentStatus", []))

    @jsii.member(jsii_name="toGetEnrollmentStatusesForOrganization")
    def to_get_enrollment_statuses_for_organization(self) -> "ComputeOptimizer":
        '''(experimental) Grants permission to get the enrollment statuses for member accounts of the organization.

        Access Level: List

        https://docs.aws.amazon.com/compute-optimizer/latest/APIReference/API_GetEnrollmentStatusesForOrganization.html

        :stability: experimental
        '''
        return typing.cast("ComputeOptimizer", jsii.invoke(self, "toGetEnrollmentStatusesForOrganization", []))

    @jsii.member(jsii_name="toGetLambdaFunctionRecommendations")
    def to_get_lambda_function_recommendations(self) -> "ComputeOptimizer":
        '''(experimental) Grants permission to get recommendations for the provided Lambda functions.

        Access Level: List

        Dependent actions:

        - lambda:ListFunctions
        - lambda:ListProvisionedConcurrencyConfigs

        https://docs.aws.amazon.com/compute-optimizer/latest/APIReference/API_GetLambdaFunctionRecommendations.html

        :stability: experimental
        '''
        return typing.cast("ComputeOptimizer", jsii.invoke(self, "toGetLambdaFunctionRecommendations", []))

    @jsii.member(jsii_name="toGetRecommendationPreferences")
    def to_get_recommendation_preferences(self) -> "ComputeOptimizer":
        '''(experimental) Grants permission to get recommendation preferences.

        Access Level: Read

        Possible conditions:

        - .ifResourceType()

        https://docs.aws.amazon.com/compute-optimizer/latest/APIReference/API_GetRecommendationPreferences.html

        :stability: experimental
        '''
        return typing.cast("ComputeOptimizer", jsii.invoke(self, "toGetRecommendationPreferences", []))

    @jsii.member(jsii_name="toGetRecommendationSummaries")
    def to_get_recommendation_summaries(self) -> "ComputeOptimizer":
        '''(experimental) Grants permission to get the recommendation summaries for the specified account(s).

        Access Level: List

        https://docs.aws.amazon.com/compute-optimizer/latest/APIReference/API_GetRecommendationSummaries.html

        :stability: experimental
        '''
        return typing.cast("ComputeOptimizer", jsii.invoke(self, "toGetRecommendationSummaries", []))

    @jsii.member(jsii_name="toPutRecommendationPreferences")
    def to_put_recommendation_preferences(self) -> "ComputeOptimizer":
        '''(experimental) Grants permission to put recommendation preferences.

        Access Level: Write

        Possible conditions:

        - .ifResourceType()

        Dependent actions:

        - autoscaling:DescribeAutoScalingGroups
        - autoscaling:DescribeAutoScalingInstances
        - ec2:DescribeInstances

        https://docs.aws.amazon.com/compute-optimizer/latest/APIReference/API_PutRecommendationPreferences.html

        :stability: experimental
        '''
        return typing.cast("ComputeOptimizer", jsii.invoke(self, "toPutRecommendationPreferences", []))

    @jsii.member(jsii_name="toUpdateEnrollmentStatus")
    def to_update_enrollment_status(self) -> "ComputeOptimizer":
        '''(experimental) Grants permission to update the enrollment status.

        Access Level: Write

        https://docs.aws.amazon.com/compute-optimizer/latest/APIReference/API_UpdateEnrollmentStatus.html

        :stability: experimental
        '''
        return typing.cast("ComputeOptimizer", jsii.invoke(self, "toUpdateEnrollmentStatus", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__53fc38943c86f12b2cc70a05dbfbe8b6ec2d5c4a700087ec46e0e6e9527152a3)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__199e167c66b6ec03647c2e46758b4945373012f23932c48b072cfa1046333fb5)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Config(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Config",
):
    '''(experimental) Statement provider for service `config <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsconfig.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `config <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsconfig.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onAggregationAuthorization")
    def on_aggregation_authorization(
        self,
        aggregator_account: builtins.str,
        aggregator_region: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Config":
        '''(experimental) Adds a resource of type AggregationAuthorization to the statement.

        https://docs.aws.amazon.com/config/latest/APIReference/API_AggregationAuthorization.html

        :param aggregator_account: - Identifier for the aggregatorAccount.
        :param aggregator_region: - Identifier for the aggregatorRegion.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2daf6c4464d123183f72700b0405dd061424d372c619b7d2c6841d8fcd736959)
            check_type(argname="argument aggregator_account", value=aggregator_account, expected_type=type_hints["aggregator_account"])
            check_type(argname="argument aggregator_region", value=aggregator_region, expected_type=type_hints["aggregator_region"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Config", jsii.invoke(self, "onAggregationAuthorization", [aggregator_account, aggregator_region, account, region, partition]))

    @jsii.member(jsii_name="onConfigRule")
    def on_config_rule(
        self,
        config_rule_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Config":
        '''(experimental) Adds a resource of type ConfigRule to the statement.

        https://docs.aws.amazon.com/config/latest/APIReference/API_ConfigRule.html

        :param config_rule_id: - Identifier for the configRuleId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__57beb2901f06145c3534a65f07498bf75f9d9025c03e0be9d7f766d4f4ea0c8a)
            check_type(argname="argument config_rule_id", value=config_rule_id, expected_type=type_hints["config_rule_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Config", jsii.invoke(self, "onConfigRule", [config_rule_id, account, region, partition]))

    @jsii.member(jsii_name="onConfigurationAggregator")
    def on_configuration_aggregator(
        self,
        aggregator_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Config":
        '''(experimental) Adds a resource of type ConfigurationAggregator to the statement.

        https://docs.aws.amazon.com/config/latest/APIReference/API_ConfigurationAggregator.html

        :param aggregator_id: - Identifier for the aggregatorId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__35d051a7d6f9eaf2c9223120b1f5cebc0ca1a561187c577972ef598b110009eb)
            check_type(argname="argument aggregator_id", value=aggregator_id, expected_type=type_hints["aggregator_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Config", jsii.invoke(self, "onConfigurationAggregator", [aggregator_id, account, region, partition]))

    @jsii.member(jsii_name="onConformancePack")
    def on_conformance_pack(
        self,
        conformance_pack_name: builtins.str,
        conformance_pack_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Config":
        '''(experimental) Adds a resource of type ConformancePack to the statement.

        https://docs.aws.amazon.com/config/latest/APIReference/API_ConformancePack.html

        :param conformance_pack_name: - Identifier for the conformancePackName.
        :param conformance_pack_id: - Identifier for the conformancePackId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8dbdb87e5b92fb421bb98e482007d957ccac3ca0241c65a0a4add40950867a21)
            check_type(argname="argument conformance_pack_name", value=conformance_pack_name, expected_type=type_hints["conformance_pack_name"])
            check_type(argname="argument conformance_pack_id", value=conformance_pack_id, expected_type=type_hints["conformance_pack_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Config", jsii.invoke(self, "onConformancePack", [conformance_pack_name, conformance_pack_id, account, region, partition]))

    @jsii.member(jsii_name="onOrganizationConfigRule")
    def on_organization_config_rule(
        self,
        organization_config_rule_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Config":
        '''(experimental) Adds a resource of type OrganizationConfigRule to the statement.

        https://docs.aws.amazon.com/config/latest/APIReference/API_OrganizationConfigRule.html

        :param organization_config_rule_id: - Identifier for the organizationConfigRuleId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__dd23e3bf647197477656ecbf1a42fd327f94664563f2f854309c63407a8e5ff7)
            check_type(argname="argument organization_config_rule_id", value=organization_config_rule_id, expected_type=type_hints["organization_config_rule_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Config", jsii.invoke(self, "onOrganizationConfigRule", [organization_config_rule_id, account, region, partition]))

    @jsii.member(jsii_name="onOrganizationConformancePack")
    def on_organization_conformance_pack(
        self,
        organization_conformance_pack_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Config":
        '''(experimental) Adds a resource of type OrganizationConformancePack to the statement.

        https://docs.aws.amazon.com/config/latest/APIReference/API_OrganizationConformancePack.html

        :param organization_conformance_pack_id: - Identifier for the organizationConformancePackId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d4af087c31893e8eae4c07449dea2414f79a19ffb95e0a5fc93d789ce7a01742)
            check_type(argname="argument organization_conformance_pack_id", value=organization_conformance_pack_id, expected_type=type_hints["organization_conformance_pack_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Config", jsii.invoke(self, "onOrganizationConformancePack", [organization_conformance_pack_id, account, region, partition]))

    @jsii.member(jsii_name="onRemediationConfiguration")
    def on_remediation_configuration(
        self,
        remediation_configuration_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Config":
        '''(experimental) Adds a resource of type RemediationConfiguration to the statement.

        https://docs.aws.amazon.com/config/latest/APIReference/API_RemediationConfiguration.html

        :param remediation_configuration_id: - Identifier for the remediationConfigurationId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__db30b4995c49c9de000ae598865bf9fb982c7e072018273ff41be9b2a2becb7d)
            check_type(argname="argument remediation_configuration_id", value=remediation_configuration_id, expected_type=type_hints["remediation_configuration_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Config", jsii.invoke(self, "onRemediationConfiguration", [remediation_configuration_id, account, region, partition]))

    @jsii.member(jsii_name="onStoredQuery")
    def on_stored_query(
        self,
        stored_query_name: builtins.str,
        stored_query_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Config":
        '''(experimental) Adds a resource of type StoredQuery to the statement.

        https://docs.aws.amazon.com/config/latest/APIReference/API_StoredQuery.html

        :param stored_query_name: - Identifier for the storedQueryName.
        :param stored_query_id: - Identifier for the storedQueryId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__856c932461fac121852105182ccdacc3e7380dbae7a26dab21da009aeef4f3fa)
            check_type(argname="argument stored_query_name", value=stored_query_name, expected_type=type_hints["stored_query_name"])
            check_type(argname="argument stored_query_id", value=stored_query_id, expected_type=type_hints["stored_query_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Config", jsii.invoke(self, "onStoredQuery", [stored_query_name, stored_query_id, account, region, partition]))

    @jsii.member(jsii_name="toBatchGetAggregateResourceConfig")
    def to_batch_get_aggregate_resource_config(self) -> "Config":
        '''(experimental) Grants permission to return the current configuration items for resources that are present in your AWS Config aggregator.

        Access Level: Read

        https://docs.aws.amazon.com/config/latest/APIReference/API_BatchGetAggregateResourceConfig.html

        :stability: experimental
        '''
        return typing.cast("Config", jsii.invoke(self, "toBatchGetAggregateResourceConfig", []))

    @jsii.member(jsii_name="toBatchGetResourceConfig")
    def to_batch_get_resource_config(self) -> "Config":
        '''(experimental) Grants permission to return the current configuration for one or more requested resources.

        Access Level: Read

        https://docs.aws.amazon.com/config/latest/APIReference/API_BatchGetResourceConfig.html

        :stability: experimental
        '''
        return typing.cast("Config", jsii.invoke(self, "toBatchGetResourceConfig", []))

    @jsii.member(jsii_name="toDeleteAggregationAuthorization")
    def to_delete_aggregation_authorization(self) -> "Config":
        '''(experimental) Grants permission to delete the authorization granted to the specified configuration aggregator account in a specified region.

        Access Level: Write

        https://docs.aws.amazon.com/config/latest/APIReference/API_DeleteAggregationAuthorization.html

        :stability: experimental
        '''
        return typing.cast("Config", jsii.invoke(self, "toDeleteAggregationAuthorization", []))

    @jsii.member(jsii_name="toDeleteConfigRule")
    def to_delete_config_rule(self) -> "Config":
        '''(experimental) Grants permission to delete the specified AWS Config rule and all of its evaluation results.

        Access Level: Write

        https://docs.aws.amazon.com/config/latest/APIReference/API_DeleteConfigRule.html

        :stability: experimental
        '''
        return typing.cast("Config", jsii.invoke(self, "toDeleteConfigRule", []))

    @jsii.member(jsii_name="toDeleteConfigurationAggregator")
    def to_delete_configuration_aggregator(self) -> "Config":
        '''(experimental) Grants permission to delete the specified configuration aggregator and the aggregated data associated with the aggregator.

        Access Level: Write

        https://docs.aws.amazon.com/config/latest/APIReference/API_DeleteConfigurationAggregator.html

        :stability: experimental
        '''
        return typing.cast("Config", jsii.invoke(self, "toDeleteConfigurationAggregator", []))

    @jsii.member(jsii_name="toDeleteConfigurationRecorder")
    def to_delete_configuration_recorder(self) -> "Config":
        '''(experimental) Grants permission to delete the configuration recorder.

        Access Level: Write

        https://docs.aws.amazon.com/config/latest/APIReference/API_DeleteConfigurationRecorder.html

        :stability: experimental
        '''
        return typing.cast("Config", jsii.invoke(self, "toDeleteConfigurationRecorder", []))

    @jsii.member(jsii_name="toDeleteConformancePack")
    def to_delete_conformance_pack(self) -> "Config":
        '''(experimental) Grants permission to delete the specified conformance pack and all the AWS Config rules and all evaluation results within that conformance pack.

        Access Level: Write

        https://docs.aws.amazon.com/config/latest/APIReference/API_DeleteConformancePack.html

        :stability: experimental
        '''
        return typing.cast("Config", jsii.invoke(self, "toDeleteConformancePack", []))

    @jsii.member(jsii_name="toDeleteDeliveryChannel")
    def to_delete_delivery_channel(self) -> "Config":
        '''(experimental) Grants permission to delete the delivery channel.

        Access Level: Write

        https://docs.aws.amazon.com/config/latest/APIReference/API_DeleteDeliveryChannel.html

        :stability: experimental
        '''
        return typing.cast("Config", jsii.invoke(self, "toDeleteDeliveryChannel", []))

    @jsii.member(jsii_name="toDeleteEvaluationResults")
    def to_delete_evaluation_results(self) -> "Config":
        '''(experimental) Grants permission to delete the evaluation results for the specified Config rule.

        Access Level: Write

        https://docs.aws.amazon.com/config/latest/APIReference/API_DeleteEvaluationResults.html

        :stability: experimental
        '''
        return typing.cast("Config", jsii.invoke(self, "toDeleteEvaluationResults", []))

    @jsii.member(jsii_name="toDeleteOrganizationConfigRule")
    def to_delete_organization_config_rule(self) -> "Config":
        '''(experimental) Grants permission to delete the specified organization config rule and all of its evaluation results from all member accounts in that organization.

        Access Level: Write

        https://docs.aws.amazon.com/config/latest/APIReference/API_DeleteOrganizationConfigRule.html

        :stability: experimental
        '''
        return typing.cast("Config", jsii.invoke(self, "toDeleteOrganizationConfigRule", []))

    @jsii.member(jsii_name="toDeleteOrganizationConformancePack")
    def to_delete_organization_conformance_pack(self) -> "Config":
        '''(experimental) Grants permission to delete the specified organization conformance pack and all of its evaluation results from all member accounts in that organization.

        Access Level: Write

        https://docs.aws.amazon.com/config/latest/APIReference/API_DeleteOrganizationConformancePack.html

        :stability: experimental
        '''
        return typing.cast("Config", jsii.invoke(self, "toDeleteOrganizationConformancePack", []))

    @jsii.member(jsii_name="toDeletePendingAggregationRequest")
    def to_delete_pending_aggregation_request(self) -> "Config":
        '''(experimental) Grants permission to delete pending authorization requests for a specified aggregator account in a specified region.

        Access Level: Write

        https://docs.aws.amazon.com/config/latest/APIReference/API_DeletePendingAggregationRequest.html

        :stability: experimental
        '''
        return typing.cast("Config", jsii.invoke(self, "toDeletePendingAggregationRequest", []))

    @jsii.member(jsii_name="toDeleteRemediationConfiguration")
    def to_delete_remediation_configuration(self) -> "Config":
        '''(experimental) Grants permission to delete the remediation configuration.

        Access Level: Write

        https://docs.aws.amazon.com/config/latest/APIReference/API_DeleteRemediationConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Config", jsii.invoke(self, "toDeleteRemediationConfiguration", []))

    @jsii.member(jsii_name="toDeleteRemediationExceptions")
    def to_delete_remediation_exceptions(self) -> "Config":
        '''(experimental) Grants permission to delete one or more remediation exceptions for specific resource keys for a specific AWS Config Rule.

        Access Level: Write

        https://docs.aws.amazon.com/config/latest/APIReference/API_DeleteRemediationExceptions.html

        :stability: experimental
        '''
        return typing.cast("Config", jsii.invoke(self, "toDeleteRemediationExceptions", []))

    @jsii.member(jsii_name="toDeleteResourceConfig")
    def to_delete_resource_config(self) -> "Config":
        '''(experimental) Grants permission to record the configuration state for a custom resource that has been deleted.

        Access Level: Write

        https://docs.aws.amazon.com/config/latest/APIReference/API_DeleteResourceConfig.html

        :stability: experimental
        '''
        return typing.cast("Config", jsii.invoke(self, "toDeleteResourceConfig", []))

    @jsii.member(jsii_name="toDeleteRetentionConfiguration")
    def to_delete_retention_configuration(self) -> "Config":
        '''(experimental) Grants permission to delete the retention configuration.

        Access Level: Write

        https://docs.aws.amazon.com/config/latest/APIReference/API_DeleteRetentionConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Config", jsii.invoke(self, "toDeleteRetentionConfiguration", []))

    @jsii.member(jsii_name="toDeleteStoredQuery")
    def to_delete_stored_query(self) -> "Config":
        '''(experimental) Grants permission to delete the stored query for an AWS account in an AWS Region.

        Access Level: Write

        https://docs.aws.amazon.com/config/latest/APIReference/API_DeleteStoredQuery.html

        :stability: experimental
        '''
        return typing.cast("Config", jsii.invoke(self, "toDeleteStoredQuery", []))

    @jsii.member(jsii_name="toDeliverConfigSnapshot")
    def to_deliver_config_snapshot(self) -> "Config":
        '''(experimental) Grants permission to schedule delivery of a configuration snapshot to the Amazon S3 bucket in the specified delivery channel.

        Access Level: Read

        https://docs.aws.amazon.com/config/latest/APIReference/API_DeliverConfigSnapshot.html

        :stability: experimental
        '''
        return typing.cast("Config", jsii.invoke(self, "toDeliverConfigSnapshot", []))

    @jsii.member(jsii_name="toDescribeAggregateComplianceByConfigRules")
    def to_describe_aggregate_compliance_by_config_rules(self) -> "Config":
        '''(experimental) Grants permission to return a list of compliant and noncompliant rules with the number of resources for compliant and noncompliant rules.

        Access Level: Read

        https://docs.aws.amazon.com/config/latest/APIReference/API_DescribeAggregateComplianceByConfigRules.html

        :stability: experimental
        '''
        return typing.cast("Config", jsii.invoke(self, "toDescribeAggregateComplianceByConfigRules", []))

    @jsii.member(jsii_name="toDescribeAggregateComplianceByConformancePacks")
    def to_describe_aggregate_compliance_by_conformance_packs(self) -> "Config":
        '''(experimental) Grants permission to return a list of compliant and noncompliant conformance packs along with count of compliant, non-compliant and total rules within each conformance pack.

        Access Level: Read

        https://docs.aws.amazon.com/config/latest/APIReference/API_DescribeAggregateComplianceByConformancePacks.html

        :stability: experimental
        '''
        return typing.cast("Config", jsii.invoke(self, "toDescribeAggregateComplianceByConformancePacks", []))

    @jsii.member(jsii_name="toDescribeAggregationAuthorizations")
    def to_describe_aggregation_authorizations(self) -> "Config":
        '''(experimental) Grants permission to return a list of authorizations granted to various aggregator accounts and regions.

        Access Level: List

        https://docs.aws.amazon.com/config/latest/APIReference/API_DescribeAggregationAuthorizations.html

        :stability: experimental
        '''
        return typing.cast("Config", jsii.invoke(self, "toDescribeAggregationAuthorizations", []))

    @jsii.member(jsii_name="toDescribeComplianceByConfigRule")
    def to_describe_compliance_by_config_rule(self) -> "Config":
        '''(experimental) Grants permission to indicate whether the specified AWS Config rules are compliant.

        Access Level: Read

        https://docs.aws.amazon.com/config/latest/APIReference/API_DescribeComplianceByConfigRule.html

        :stability: experimental
        '''
        return typing.cast("Config", jsii.invoke(self, "toDescribeComplianceByConfigRule", []))

    @jsii.member(jsii_name="toDescribeComplianceByResource")
    def to_describe_compliance_by_resource(self) -> "Config":
        '''(experimental) Grants permission to indicate whether the specified AWS resources are compliant.

        Access Level: Read

        https://docs.aws.amazon.com/config/latest/APIReference/API_DescribeComplianceByResource.html

        :stability: experimental
        '''
        return typing.cast("Config", jsii.invoke(self, "toDescribeComplianceByResource", []))

    @jsii.member(jsii_name="toDescribeConfigRuleEvaluationStatus")
    def to_describe_config_rule_evaluation_status(self) -> "Config":
        '''(experimental) Grants permission to return status information for each of your AWS managed Config rules.

        Access Level: Read

        https://docs.aws.amazon.com/config/latest/APIReference/API_DescribeConfigRuleEvaluationStatus.html

        :stability: experimental
        '''
        return typing.cast("Config", jsii.invoke(self, "toDescribeConfigRuleEvaluationStatus", []))

    @jsii.member(jsii_name="toDescribeConfigRules")
    def to_describe_config_rules(self) -> "Config":
        '''(experimental) Grants permission to return details about your AWS Config rules.

        Access Level: List

        https://docs.aws.amazon.com/config/latest/APIReference/API_DescribeConfigRules.html

        :stability: experimental
        '''
        return typing.cast("Config", jsii.invoke(self, "toDescribeConfigRules", []))

    @jsii.member(jsii_name="toDescribeConfigurationAggregators")
    def to_describe_configuration_aggregators(self) -> "Config":
        '''(experimental) Grants permission to return the details of one or more configuration aggregators.

        Access Level: List

        https://docs.aws.amazon.com/config/latest/APIReference/API_DescribeConfigurationAggregators.html

        :stability: experimental
        '''
        return typing.cast("Config", jsii.invoke(self, "toDescribeConfigurationAggregators", []))

    @jsii.member(jsii_name="toDescribeConfigurationAggregatorSourcesStatus")
    def to_describe_configuration_aggregator_sources_status(self) -> "Config":
        '''(experimental) Grants permission to return status information for sources within an aggregator.

        Access Level: Read

        https://docs.aws.amazon.com/config/latest/APIReference/API_DescribeConfigurationAggregatorSourcesStatus.html

        :stability: experimental
        '''
        return typing.cast("Config", jsii.invoke(self, "toDescribeConfigurationAggregatorSourcesStatus", []))

    @jsii.member(jsii_name="toDescribeConfigurationRecorders")
    def to_describe_configuration_recorders(self) -> "Config":
        '''(experimental) Grants permission to return the names of one or more specified configuration recorders.

        Access Level: List

        https://docs.aws.amazon.com/config/latest/APIReference/API_DescribeConfigurationRecorders.html

        :stability: experimental
        '''
        return typing.cast("Config", jsii.invoke(self, "toDescribeConfigurationRecorders", []))

    @jsii.member(jsii_name="toDescribeConfigurationRecorderStatus")
    def to_describe_configuration_recorder_status(self) -> "Config":
        '''(experimental) Grants permission to return the current status of the specified configuration recorder.

        Access Level: Read

        https://docs.aws.amazon.com/config/latest/APIReference/API_DescribeConfigurationRecorderStatus.html

        :stability: experimental
        '''
        return typing.cast("Config", jsii.invoke(self, "toDescribeConfigurationRecorderStatus", []))

    @jsii.member(jsii_name="toDescribeConformancePackCompliance")
    def to_describe_conformance_pack_compliance(self) -> "Config":
        '''(experimental) Grants permission to return compliance information for each rule in that conformance pack.

        Access Level: Read

        https://docs.aws.amazon.com/config/latest/APIReference/API_DescribeConformancePackCompliance.html

        :stability: experimental
        '''
        return typing.cast("Config", jsii.invoke(self, "toDescribeConformancePackCompliance", []))

    @jsii.member(jsii_name="toDescribeConformancePacks")
    def to_describe_conformance_packs(self) -> "Config":
        '''(experimental) Grants permission to return a list of one or more conformance packs.

        Access Level: List

        https://docs.aws.amazon.com/config/latest/APIReference/API_DescribeConformancePacks.html

        :stability: experimental
        '''
        return typing.cast("Config", jsii.invoke(self, "toDescribeConformancePacks", []))

    @jsii.member(jsii_name="toDescribeConformancePackStatus")
    def to_describe_conformance_pack_status(self) -> "Config":
        '''(experimental) Grants permission to provide one or more conformance packs deployment status.

        Access Level: Read

        https://docs.aws.amazon.com/config/latest/APIReference/API_DescribeConformancePackStatus.html

        :stability: experimental
        '''
        return typing.cast("Config", jsii.invoke(self, "toDescribeConformancePackStatus", []))

    @jsii.member(jsii_name="toDescribeDeliveryChannels")
    def to_describe_delivery_channels(self) -> "Config":
        '''(experimental) Grants permission to return details about the specified delivery channel.

        Access Level: List

        https://docs.aws.amazon.com/config/latest/APIReference/API_DescribeDeliveryChannels.html

        :stability: experimental
        '''
        return typing.cast("Config", jsii.invoke(self, "toDescribeDeliveryChannels", []))

    @jsii.member(jsii_name="toDescribeDeliveryChannelStatus")
    def to_describe_delivery_channel_status(self) -> "Config":
        '''(experimental) Grants permission to return the current status of the specified delivery channel.

        Access Level: Read

        https://docs.aws.amazon.com/config/latest/APIReference/API_DescribeDeliveryChannelStatus.html

        :stability: experimental
        '''
        return typing.cast("Config", jsii.invoke(self, "toDescribeDeliveryChannelStatus", []))

    @jsii.member(jsii_name="toDescribeOrganizationConfigRules")
    def to_describe_organization_config_rules(self) -> "Config":
        '''(experimental) Grants permission to return a list of organization config rules.

        Access Level: List

        https://docs.aws.amazon.com/config/latest/APIReference/API_DescribeOrganizationConfigRules.html

        :stability: experimental
        '''
        return typing.cast("Config", jsii.invoke(self, "toDescribeOrganizationConfigRules", []))

    @jsii.member(jsii_name="toDescribeOrganizationConfigRuleStatuses")
    def to_describe_organization_config_rule_statuses(self) -> "Config":
        '''(experimental) Grants permission to provide organization config rule deployment status for an organization.

        Access Level: Read

        https://docs.aws.amazon.com/config/latest/APIReference/API_DescribeOrganizationConfigRuleStatuses.html

        :stability: experimental
        '''
        return typing.cast("Config", jsii.invoke(self, "toDescribeOrganizationConfigRuleStatuses", []))

    @jsii.member(jsii_name="toDescribeOrganizationConformancePacks")
    def to_describe_organization_conformance_packs(self) -> "Config":
        '''(experimental) Grants permission to return a list of organization conformance packs.

        Access Level: List

        https://docs.aws.amazon.com/config/latest/APIReference/API_DescribeOrganizationConformancePacks.html

        :stability: experimental
        '''
        return typing.cast("Config", jsii.invoke(self, "toDescribeOrganizationConformancePacks", []))

    @jsii.member(jsii_name="toDescribeOrganizationConformancePackStatuses")
    def to_describe_organization_conformance_pack_statuses(self) -> "Config":
        '''(experimental) Grants permission to provide organization conformance pack deployment status for an organization.

        Access Level: Read

        https://docs.aws.amazon.com/config/latest/APIReference/API_DescribeOrganizationConformancePackStatuses.html

        :stability: experimental
        '''
        return typing.cast("Config", jsii.invoke(self, "toDescribeOrganizationConformancePackStatuses", []))

    @jsii.member(jsii_name="toDescribePendingAggregationRequests")
    def to_describe_pending_aggregation_requests(self) -> "Config":
        '''(experimental) Grants permission to return a list of all pending aggregation requests.

        Access Level: List

        https://docs.aws.amazon.com/config/latest/APIReference/API_DescribePendingAggregationRequests.html

        :stability: experimental
        '''
        return typing.cast("Config", jsii.invoke(self, "toDescribePendingAggregationRequests", []))

    @jsii.member(jsii_name="toDescribeRemediationConfigurations")
    def to_describe_remediation_configurations(self) -> "Config":
        '''(experimental) Grants permission to return the details of one or more remediation configurations.

        Access Level: List

        https://docs.aws.amazon.com/config/latest/APIReference/API_DescribeRemediationConfigurations.html

        :stability: experimental
        '''
        return typing.cast("Config", jsii.invoke(self, "toDescribeRemediationConfigurations", []))

    @jsii.member(jsii_name="toDescribeRemediationExceptions")
    def to_describe_remediation_exceptions(self) -> "Config":
        '''(experimental) Grants permission to return the details of one or more remediation exceptions.

        Access Level: List

        https://docs.aws.amazon.com/config/latest/APIReference/API_DescribeRemediationExceptions.html

        :stability: experimental
        '''
        return typing.cast("Config", jsii.invoke(self, "toDescribeRemediationExceptions", []))

    @jsii.member(jsii_name="toDescribeRemediationExecutionStatus")
    def to_describe_remediation_execution_status(self) -> "Config":
        '''(experimental) Grants permission to provide a detailed view of a Remediation Execution for a set of resources including state, timestamps and any error messages for steps that have failed.

        Access Level: Read

        https://docs.aws.amazon.com/config/latest/APIReference/API_DescribeRemediationExecutionStatus.html

        :stability: experimental
        '''
        return typing.cast("Config", jsii.invoke(self, "toDescribeRemediationExecutionStatus", []))

    @jsii.member(jsii_name="toDescribeRetentionConfigurations")
    def to_describe_retention_configurations(self) -> "Config":
        '''(experimental) Grants permission to return the details of one or more retention configurations.

        Access Level: List

        https://docs.aws.amazon.com/config/latest/APIReference/API_DescribeRetentionConfigurations.html

        :stability: experimental
        '''
        return typing.cast("Config", jsii.invoke(self, "toDescribeRetentionConfigurations", []))

    @jsii.member(jsii_name="toGetAggregateComplianceDetailsByConfigRule")
    def to_get_aggregate_compliance_details_by_config_rule(self) -> "Config":
        '''(experimental) Grants permission to return the evaluation results for the specified AWS Config rule for a specific resource in a rule.

        Access Level: Read

        https://docs.aws.amazon.com/config/latest/APIReference/API_GetAggregateComplianceDetailsByConfigRule.html

        :stability: experimental
        '''
        return typing.cast("Config", jsii.invoke(self, "toGetAggregateComplianceDetailsByConfigRule", []))

    @jsii.member(jsii_name="toGetAggregateConfigRuleComplianceSummary")
    def to_get_aggregate_config_rule_compliance_summary(self) -> "Config":
        '''(experimental) Grants permission to return the number of compliant and noncompliant rules for one or more accounts and regions in an aggregator.

        Access Level: Read

        https://docs.aws.amazon.com/config/latest/APIReference/API_GetAggregateConfigRuleComplianceSummary.html

        :stability: experimental
        '''
        return typing.cast("Config", jsii.invoke(self, "toGetAggregateConfigRuleComplianceSummary", []))

    @jsii.member(jsii_name="toGetAggregateConformancePackComplianceSummary")
    def to_get_aggregate_conformance_pack_compliance_summary(self) -> "Config":
        '''(experimental) Grants permission to return the number of compliant and noncompliant conformance packs for one or more accounts and regions in an aggregator.

        Access Level: Read

        https://docs.aws.amazon.com/config/latest/APIReference/API_GetAggregateConformancePackComplianceSummary.html

        :stability: experimental
        '''
        return typing.cast("Config", jsii.invoke(self, "toGetAggregateConformancePackComplianceSummary", []))

    @jsii.member(jsii_name="toGetAggregateDiscoveredResourceCounts")
    def to_get_aggregate_discovered_resource_counts(self) -> "Config":
        '''(experimental) Grants permission to return the resource counts across accounts and regions that are present in your AWS Config aggregator.

        Access Level: Read

        https://docs.aws.amazon.com/config/latest/APIReference/API_GetAggregateDiscoveredResourceCounts.html

        :stability: experimental
        '''
        return typing.cast("Config", jsii.invoke(self, "toGetAggregateDiscoveredResourceCounts", []))

    @jsii.member(jsii_name="toGetAggregateResourceConfig")
    def to_get_aggregate_resource_config(self) -> "Config":
        '''(experimental) Grants permission to return configuration item that is aggregated for your specific resource in a specific source account and region.

        Access Level: Read

        https://docs.aws.amazon.com/config/latest/APIReference/API_GetAggregateResourceConfig.html

        :stability: experimental
        '''
        return typing.cast("Config", jsii.invoke(self, "toGetAggregateResourceConfig", []))

    @jsii.member(jsii_name="toGetComplianceDetailsByConfigRule")
    def to_get_compliance_details_by_config_rule(self) -> "Config":
        '''(experimental) Grants permission to return the evaluation results for the specified AWS Config rule.

        Access Level: Read

        https://docs.aws.amazon.com/config/latest/APIReference/API_GetComplianceDetailsByConfigRule.html

        :stability: experimental
        '''
        return typing.cast("Config", jsii.invoke(self, "toGetComplianceDetailsByConfigRule", []))

    @jsii.member(jsii_name="toGetComplianceDetailsByResource")
    def to_get_compliance_details_by_resource(self) -> "Config":
        '''(experimental) Grants permission to return the evaluation results for the specified AWS resource.

        Access Level: Read

        https://docs.aws.amazon.com/config/latest/APIReference/API_GetComplianceDetailsByResource.html

        :stability: experimental
        '''
        return typing.cast("Config", jsii.invoke(self, "toGetComplianceDetailsByResource", []))

    @jsii.member(jsii_name="toGetComplianceSummaryByConfigRule")
    def to_get_compliance_summary_by_config_rule(self) -> "Config":
        '''(experimental) Grants permission to return the number of AWS Config rules that are compliant and noncompliant, up to a maximum of 25 for each.

        Access Level: Read

        https://docs.aws.amazon.com/config/latest/APIReference/API_GetComplianceSummaryByConfigRule.html

        :stability: experimental
        '''
        return typing.cast("Config", jsii.invoke(self, "toGetComplianceSummaryByConfigRule", []))

    @jsii.member(jsii_name="toGetComplianceSummaryByResourceType")
    def to_get_compliance_summary_by_resource_type(self) -> "Config":
        '''(experimental) Grants permission to return the number of resources that are compliant and the number that are noncompliant.

        Access Level: Read

        https://docs.aws.amazon.com/config/latest/APIReference/API_GetComplianceSummaryByResourceType.html

        :stability: experimental
        '''
        return typing.cast("Config", jsii.invoke(self, "toGetComplianceSummaryByResourceType", []))

    @jsii.member(jsii_name="toGetConformancePackComplianceDetails")
    def to_get_conformance_pack_compliance_details(self) -> "Config":
        '''(experimental) Grants permission to return compliance details of a conformance pack for all AWS resources that are monitered by conformance pack.

        Access Level: Read

        https://docs.aws.amazon.com/config/latest/APIReference/API_GetConformancePackComplianceDetails.html

        :stability: experimental
        '''
        return typing.cast("Config", jsii.invoke(self, "toGetConformancePackComplianceDetails", []))

    @jsii.member(jsii_name="toGetConformancePackComplianceSummary")
    def to_get_conformance_pack_compliance_summary(self) -> "Config":
        '''(experimental) Grants permission to provide compliance summary for one or more conformance packs.

        Access Level: Read

        https://docs.aws.amazon.com/config/latest/APIReference/API_GetConformancePackComplianceSummary.html

        :stability: experimental
        '''
        return typing.cast("Config", jsii.invoke(self, "toGetConformancePackComplianceSummary", []))

    @jsii.member(jsii_name="toGetCustomRulePolicy")
    def to_get_custom_rule_policy(self) -> "Config":
        '''(experimental) Grants permission to return the policy definition containing the logic for your AWS Config Custom Policy rule.

        Access Level: Read

        https://docs.aws.amazon.com/config/latest/APIReference/API_GetCustomRulePolicy.html

        :stability: experimental
        '''
        return typing.cast("Config", jsii.invoke(self, "toGetCustomRulePolicy", []))

    @jsii.member(jsii_name="toGetDiscoveredResourceCounts")
    def to_get_discovered_resource_counts(self) -> "Config":
        '''(experimental) Grants permission to return the resource types, the number of each resource type, and the total number of resources that AWS Config is recording in this region for your AWS account.

        Access Level: Read

        https://docs.aws.amazon.com/config/latest/APIReference/API_GetDiscoveredResourceCounts.html

        :stability: experimental
        '''
        return typing.cast("Config", jsii.invoke(self, "toGetDiscoveredResourceCounts", []))

    @jsii.member(jsii_name="toGetOrganizationConfigRuleDetailedStatus")
    def to_get_organization_config_rule_detailed_status(self) -> "Config":
        '''(experimental) Grants permission to return detailed status for each member account within an organization for a given organization config rule.

        Access Level: Read

        https://docs.aws.amazon.com/config/latest/APIReference/API_GetOrganizationConfigRuleDetailedStatus.html

        :stability: experimental
        '''
        return typing.cast("Config", jsii.invoke(self, "toGetOrganizationConfigRuleDetailedStatus", []))

    @jsii.member(jsii_name="toGetOrganizationConformancePackDetailedStatus")
    def to_get_organization_conformance_pack_detailed_status(self) -> "Config":
        '''(experimental) Grants permission to return detailed status for each member account within an organization for a given organization conformance pack.

        Access Level: Read

        https://docs.aws.amazon.com/config/latest/APIReference/API_GetOrganizationConformancePackDetailedStatus.html

        :stability: experimental
        '''
        return typing.cast("Config", jsii.invoke(self, "toGetOrganizationConformancePackDetailedStatus", []))

    @jsii.member(jsii_name="toGetOrganizationCustomRulePolicy")
    def to_get_organization_custom_rule_policy(self) -> "Config":
        '''(experimental) Grants permission to return the policy definition containing the logic for your organization AWS Config Custom Policy rule.

        Access Level: Read

        https://docs.aws.amazon.com/config/latest/APIReference/API_GetOrganizationCustomRulePolicy.html

        :stability: experimental
        '''
        return typing.cast("Config", jsii.invoke(self, "toGetOrganizationCustomRulePolicy", []))

    @jsii.member(jsii_name="toGetResourceConfigHistory")
    def to_get_resource_config_history(self) -> "Config":
        '''(experimental) Grants permission to return a list of configuration items for the specified resource.

        Access Level: Read

        https://docs.aws.amazon.com/config/latest/APIReference/API_GetResourceConfigHistory.html

        :stability: experimental
        '''
        return typing.cast("Config", jsii.invoke(self, "toGetResourceConfigHistory", []))

    @jsii.member(jsii_name="toGetStoredQuery")
    def to_get_stored_query(self) -> "Config":
        '''(experimental) Grants permission to return the details of a specific stored query.

        Access Level: Read

        https://docs.aws.amazon.com/config/latest/APIReference/API_GetStoredQuery.html

        :stability: experimental
        '''
        return typing.cast("Config", jsii.invoke(self, "toGetStoredQuery", []))

    @jsii.member(jsii_name="toListAggregateDiscoveredResources")
    def to_list_aggregate_discovered_resources(self) -> "Config":
        '''(experimental) Grants permission to accept a resource type and returns a list of resource identifiers that are aggregated for a specific resource type across accounts and regions.

        Access Level: List

        https://docs.aws.amazon.com/config/latest/APIReference/API_ListAggregateDiscoveredResources.html

        :stability: experimental
        '''
        return typing.cast("Config", jsii.invoke(self, "toListAggregateDiscoveredResources", []))

    @jsii.member(jsii_name="toListConformancePackComplianceScores")
    def to_list_conformance_pack_compliance_scores(self) -> "Config":
        '''(experimental) Grants permission to return the percentage of compliant rule-resource combinations in a conformance pack compared to the number of total possible rule-resource combinations.

        Access Level: List

        https://docs.aws.amazon.com/config/latest/APIReference/API_ListConformancePackComplianceScores.html

        :stability: experimental
        '''
        return typing.cast("Config", jsii.invoke(self, "toListConformancePackComplianceScores", []))

    @jsii.member(jsii_name="toListDiscoveredResources")
    def to_list_discovered_resources(self) -> "Config":
        '''(experimental) Grants permission to accept a resource type and returns a list of resource identifiers for the resources of that type.

        Access Level: List

        https://docs.aws.amazon.com/config/latest/APIReference/API_ListDiscoveredResources.html

        :stability: experimental
        '''
        return typing.cast("Config", jsii.invoke(self, "toListDiscoveredResources", []))

    @jsii.member(jsii_name="toListStoredQueries")
    def to_list_stored_queries(self) -> "Config":
        '''(experimental) Grants permission to list the stored queries for an AWS account in an AWS Region.

        Access Level: List

        https://docs.aws.amazon.com/config/latest/APIReference/API_ListStoredQueries.html

        :stability: experimental
        '''
        return typing.cast("Config", jsii.invoke(self, "toListStoredQueries", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Config":
        '''(experimental) Grants permission to list the tags for AWS Config resource.

        Access Level: Read

        https://docs.aws.amazon.com/config/latest/APIReference/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("Config", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toPutAggregationAuthorization")
    def to_put_aggregation_authorization(self) -> "Config":
        '''(experimental) Grants permission to authorize the aggregator account and region to collect data from the source account and region.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/config/latest/APIReference/API_PutAggregationAuthorization.html

        :stability: experimental
        '''
        return typing.cast("Config", jsii.invoke(self, "toPutAggregationAuthorization", []))

    @jsii.member(jsii_name="toPutConfigRule")
    def to_put_config_rule(self) -> "Config":
        '''(experimental) Grants permission to add or update an AWS Config rule for evaluating whether your AWS resources comply with your desired configurations.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/config/latest/APIReference/API_PutConfigRule.html

        :stability: experimental
        '''
        return typing.cast("Config", jsii.invoke(self, "toPutConfigRule", []))

    @jsii.member(jsii_name="toPutConfigurationAggregator")
    def to_put_configuration_aggregator(self) -> "Config":
        '''(experimental) Grants permission to create and update the configuration aggregator with the selected source accounts and regions.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - iam:PassRole
        - organizations:EnableAWSServiceAccess
        - organizations:ListDelegatedAdministrators

        https://docs.aws.amazon.com/config/latest/APIReference/API_PutConfigurationAggregator.html

        :stability: experimental
        '''
        return typing.cast("Config", jsii.invoke(self, "toPutConfigurationAggregator", []))

    @jsii.member(jsii_name="toPutConfigurationRecorder")
    def to_put_configuration_recorder(self) -> "Config":
        '''(experimental) Grants permission to create a new configuration recorder to record the selected resource configurations.

        Access Level: Write

        https://docs.aws.amazon.com/config/latest/APIReference/API_PutConfigurationRecorder.html

        :stability: experimental
        '''
        return typing.cast("Config", jsii.invoke(self, "toPutConfigurationRecorder", []))

    @jsii.member(jsii_name="toPutConformancePack")
    def to_put_conformance_pack(self) -> "Config":
        '''(experimental) Grants permission to create or update a conformance pack.

        Access Level: Write

        Dependent actions:

        - iam:CreateServiceLinkedRole
        - iam:PassRole
        - s3:GetObject
        - s3:ListBucket
        - ssm:GetDocument

        https://docs.aws.amazon.com/config/latest/APIReference/API_PutConformancePack.html

        :stability: experimental
        '''
        return typing.cast("Config", jsii.invoke(self, "toPutConformancePack", []))

    @jsii.member(jsii_name="toPutDeliveryChannel")
    def to_put_delivery_channel(self) -> "Config":
        '''(experimental) Grants permission to create a delivery channel object to deliver configuration information to an Amazon S3 bucket and Amazon SNS topic.

        Access Level: Write

        https://docs.aws.amazon.com/config/latest/APIReference/API_PutDeliveryChannel.html

        :stability: experimental
        '''
        return typing.cast("Config", jsii.invoke(self, "toPutDeliveryChannel", []))

    @jsii.member(jsii_name="toPutEvaluations")
    def to_put_evaluations(self) -> "Config":
        '''(experimental) Grants permission to be used by an AWS Lambda function to deliver evaluation results to AWS Config.

        Access Level: Write

        https://docs.aws.amazon.com/config/latest/APIReference/API_PutEvaluations.html

        :stability: experimental
        '''
        return typing.cast("Config", jsii.invoke(self, "toPutEvaluations", []))

    @jsii.member(jsii_name="toPutExternalEvaluation")
    def to_put_external_evaluation(self) -> "Config":
        '''(experimental) Grants permission to deliver evaluation result to AWS Config.

        Access Level: Write

        https://docs.aws.amazon.com/config/latest/APIReference/API_PutExternalEvaluation.html

        :stability: experimental
        '''
        return typing.cast("Config", jsii.invoke(self, "toPutExternalEvaluation", []))

    @jsii.member(jsii_name="toPutOrganizationConfigRule")
    def to_put_organization_config_rule(self) -> "Config":
        '''(experimental) Grants permission to add or update organization config rule for your entire organization evaluating whether your AWS resources comply with your desired configurations.

        Access Level: Write

        Dependent actions:

        - iam:CreateServiceLinkedRole
        - iam:PassRole
        - organizations:EnableAWSServiceAccess
        - organizations:ListDelegatedAdministrators

        https://docs.aws.amazon.com/config/latest/APIReference/API_PutOrganizationConfigRule.html

        :stability: experimental
        '''
        return typing.cast("Config", jsii.invoke(self, "toPutOrganizationConfigRule", []))

    @jsii.member(jsii_name="toPutOrganizationConformancePack")
    def to_put_organization_conformance_pack(self) -> "Config":
        '''(experimental) Grants permission to add or update organization conformance pack for your entire organization evaluating whether your AWS resources comply with your desired configurations.

        Access Level: Write

        Dependent actions:

        - iam:CreateServiceLinkedRole
        - iam:PassRole
        - organizations:EnableAWSServiceAccess
        - organizations:ListDelegatedAdministrators
        - s3:GetObject

        https://docs.aws.amazon.com/config/latest/APIReference/API_PutOrganizationConformancePack.html

        :stability: experimental
        '''
        return typing.cast("Config", jsii.invoke(self, "toPutOrganizationConformancePack", []))

    @jsii.member(jsii_name="toPutRemediationConfigurations")
    def to_put_remediation_configurations(self) -> "Config":
        '''(experimental) Grants permission to add or update the remediation configuration with a specific AWS Config rule with the selected target or action.

        Access Level: Write

        Dependent actions:

        - iam:PassRole

        https://docs.aws.amazon.com/config/latest/APIReference/API_PutRemediationConfigurations.html

        :stability: experimental
        '''
        return typing.cast("Config", jsii.invoke(self, "toPutRemediationConfigurations", []))

    @jsii.member(jsii_name="toPutRemediationExceptions")
    def to_put_remediation_exceptions(self) -> "Config":
        '''(experimental) Grants permission to add or update remediation exceptions for specific resources for a specific AWS Config rule.

        Access Level: Write

        https://docs.aws.amazon.com/config/latest/APIReference/API_PutRemediationExceptions.html

        :stability: experimental
        '''
        return typing.cast("Config", jsii.invoke(self, "toPutRemediationExceptions", []))

    @jsii.member(jsii_name="toPutResourceConfig")
    def to_put_resource_config(self) -> "Config":
        '''(experimental) Grants permission to record the configuration state for the resource provided in the request.

        Access Level: Write

        https://docs.aws.amazon.com/config/latest/APIReference/API_PutResourceConfig.html

        :stability: experimental
        '''
        return typing.cast("Config", jsii.invoke(self, "toPutResourceConfig", []))

    @jsii.member(jsii_name="toPutRetentionConfiguration")
    def to_put_retention_configuration(self) -> "Config":
        '''(experimental) Grants permission to create and update the retention configuration with details about retention period (number of days) that AWS Config stores your historical information.

        Access Level: Write

        https://docs.aws.amazon.com/config/latest/APIReference/API_PutRetentionConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Config", jsii.invoke(self, "toPutRetentionConfiguration", []))

    @jsii.member(jsii_name="toPutStoredQuery")
    def to_put_stored_query(self) -> "Config":
        '''(experimental) Grants permission to save a new query or updates an existing saved query.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/config/latest/APIReference/API_PutStoredQuery.html

        :stability: experimental
        '''
        return typing.cast("Config", jsii.invoke(self, "toPutStoredQuery", []))

    @jsii.member(jsii_name="toSelectAggregateResourceConfig")
    def to_select_aggregate_resource_config(self) -> "Config":
        '''(experimental) Grants permission to accept a structured query language (SQL) SELECT command and an aggregator to query configuration state of AWS resources across multiple accounts and regions, performs the corresponding search, and returns resource configurations matching the properties.

        Access Level: Read

        https://docs.aws.amazon.com/config/latest/APIReference/API_SelectAggregateResourceConfig.html

        :stability: experimental
        '''
        return typing.cast("Config", jsii.invoke(self, "toSelectAggregateResourceConfig", []))

    @jsii.member(jsii_name="toSelectResourceConfig")
    def to_select_resource_config(self) -> "Config":
        '''(experimental) Grants permission to accept a structured query language (SQL) SELECT command, performs the corresponding search, and returns resource configurations matching the properties.

        Access Level: Read

        https://docs.aws.amazon.com/config/latest/APIReference/API_SelectResourceConfig.html

        :stability: experimental
        '''
        return typing.cast("Config", jsii.invoke(self, "toSelectResourceConfig", []))

    @jsii.member(jsii_name="toStartConfigRulesEvaluation")
    def to_start_config_rules_evaluation(self) -> "Config":
        '''(experimental) Grants permission to evaluate your resources against the specified Config rules.

        Access Level: Write

        https://docs.aws.amazon.com/config/latest/APIReference/API_StartConfigRulesEvaluation.html

        :stability: experimental
        '''
        return typing.cast("Config", jsii.invoke(self, "toStartConfigRulesEvaluation", []))

    @jsii.member(jsii_name="toStartConfigurationRecorder")
    def to_start_configuration_recorder(self) -> "Config":
        '''(experimental) Grants permission to start recording configurations of the AWS resources you have selected to record in your AWS account.

        Access Level: Write

        https://docs.aws.amazon.com/config/latest/APIReference/API_StartConfigurationRecorder.html

        :stability: experimental
        '''
        return typing.cast("Config", jsii.invoke(self, "toStartConfigurationRecorder", []))

    @jsii.member(jsii_name="toStartRemediationExecution")
    def to_start_remediation_execution(self) -> "Config":
        '''(experimental) Grants permission to run an on-demand remediation for the specified AWS Config rules against the last known remediation configuration.

        Access Level: Write

        Dependent actions:

        - iam:PassRole

        https://docs.aws.amazon.com/config/latest/APIReference/API_StartRemediationExecution.html

        :stability: experimental
        '''
        return typing.cast("Config", jsii.invoke(self, "toStartRemediationExecution", []))

    @jsii.member(jsii_name="toStopConfigurationRecorder")
    def to_stop_configuration_recorder(self) -> "Config":
        '''(experimental) Grants permission to stop recording configurations of the AWS resources you have selected to record in your AWS account.

        Access Level: Write

        https://docs.aws.amazon.com/config/latest/APIReference/API_StopConfigurationRecorder.html

        :stability: experimental
        '''
        return typing.cast("Config", jsii.invoke(self, "toStopConfigurationRecorder", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Config":
        '''(experimental) Grants permission to associate the specified tags to a resource with the specified resourceArn.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/config/latest/APIReference/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("Config", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Config":
        '''(experimental) Grants permission to delete specified tags from a resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/config/latest/APIReference/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("Config", jsii.invoke(self, "toUntagResource", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__408d7597a8d7efc58ff0b646af71b433ffecb8bacd1c22a9198f0873a4ceb069)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e6f73dbf78f04b7763c2bc8f5a04eaed7483170fc6f1f2f224f0110dcde66a8f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Connect(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Connect",
):
    '''(experimental) Statement provider for service `connect <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonconnect.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `connect <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonconnect.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="ifAttributeType")
    def if_attribute_type(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Connect":
        '''(experimental) Filters access by the attribute type of the Amazon Connect instance.

        https://docs.aws.amazon.com/connect/latest/adminguide/security_iam_service-with-iam.html

        Applies to actions:

        - .toDescribeInstanceAttribute()
        - .toUpdateInstanceAttribute()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8a4a2000fb1513ca9b70534fb954fe170e22c49c53a0cbbf38e8db6b5dad1285)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Connect", jsii.invoke(self, "ifAttributeType", [value, operator]))

    @jsii.member(jsii_name="ifInstanceId")
    def if_instance_id(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Connect":
        '''(experimental) Filters access by restricting federation into specified Amazon Connect instances.

        https://docs.aws.amazon.com/connect/latest/adminguide/security_iam_service-with-iam.html

        Applies to actions:

        - .toAssociateApprovedOrigin()
        - .toAssociateBot()
        - .toAssociateDefaultVocabulary()
        - .toAssociateInstanceStorageConfig()
        - .toAssociateLambdaFunction()
        - .toAssociateLexBot()
        - .toAssociatePhoneNumberContactFlow()
        - .toAssociateQueueQuickConnects()
        - .toAssociateRoutingProfileQueues()
        - .toAssociateSecurityKey()
        - .toBatchAssociateAnalyticsDataSet()
        - .toBatchDisassociateAnalyticsDataSet()
        - .toCreateAgentStatus()
        - .toCreateContactFlow()
        - .toCreateContactFlowModule()
        - .toCreateHoursOfOperation()
        - .toCreateIntegrationAssociation()
        - .toCreateQueue()
        - .toCreateQuickConnect()
        - .toCreateRoutingProfile()
        - .toCreateRule()
        - .toCreateSecurityProfile()
        - .toCreateTrafficDistributionGroup()
        - .toCreateUseCase()
        - .toCreateUser()
        - .toCreateUserHierarchyGroup()
        - .toCreateVocabulary()
        - .toDeleteContactFlow()
        - .toDeleteContactFlowModule()
        - .toDeleteHoursOfOperation()
        - .toDeleteInstance()
        - .toDeleteIntegrationAssociation()
        - .toDeleteQuickConnect()
        - .toDeleteRule()
        - .toDeleteSecurityProfile()
        - .toDeleteTaskTemplate()
        - .toDeleteUseCase()
        - .toDeleteUser()
        - .toDeleteUserHierarchyGroup()
        - .toDeleteVocabulary()
        - .toDescribeAgentStatus()
        - .toDescribeContact()
        - .toDescribeContactFlow()
        - .toDescribeContactFlowModule()
        - .toDescribeForecastingPlanningSchedulingIntegration()
        - .toDescribeHoursOfOperation()
        - .toDescribeInstance()
        - .toDescribeInstanceAttribute()
        - .toDescribeInstanceStorageConfig()
        - .toDescribeQueue()
        - .toDescribeQuickConnect()
        - .toDescribeRoutingProfile()
        - .toDescribeRule()
        - .toDescribeSecurityProfile()
        - .toDescribeUser()
        - .toDescribeUserHierarchyGroup()
        - .toDescribeUserHierarchyStructure()
        - .toDescribeVocabulary()
        - .toDisassociateApprovedOrigin()
        - .toDisassociateBot()
        - .toDisassociateInstanceStorageConfig()
        - .toDisassociateLambdaFunction()
        - .toDisassociateLexBot()
        - .toDisassociatePhoneNumberContactFlow()
        - .toDisassociateQueueQuickConnects()
        - .toDisassociateRoutingProfileQueues()
        - .toDisassociateSecurityKey()
        - .toDismissUserContact()
        - .toGetContactAttributes()
        - .toGetCurrentMetricData()
        - .toGetCurrentUserData()
        - .toGetFederationToken()
        - .toGetMetricData()
        - .toGetTaskTemplate()
        - .toListApprovedOrigins()
        - .toListBots()
        - .toListContactReferences()
        - .toListDefaultVocabularies()
        - .toListHoursOfOperations()
        - .toListInstanceAttributes()
        - .toListInstanceStorageConfigs()
        - .toListIntegrationAssociations()
        - .toListLambdaFunctions()
        - .toListLexBots()
        - .toListPrompts()
        - .toListQueueQuickConnects()
        - .toListRoutingProfileQueues()
        - .toListRoutingProfiles()
        - .toListRule()
        - .toListSecurityKeys()
        - .toListSecurityProfilePermissions()
        - .toListSecurityProfiles()
        - .toListUseCases()
        - .toListUserHierarchyGroups()
        - .toListUsers()
        - .toMonitorContact()
        - .toPutUserStatus()
        - .toSearchQueues()
        - .toSearchRoutingProfiles()
        - .toSearchSecurityProfiles()
        - .toSearchUsers()
        - .toSearchVocabularies()
        - .toStartForecastingPlanningSchedulingIntegration()
        - .toStartTaskContact()
        - .toStopContact()
        - .toStopForecastingPlanningSchedulingIntegration()
        - .toTransferContact()
        - .toUpdateAgentStatus()
        - .toUpdateContact()
        - .toUpdateContactAttributes()
        - .toUpdateContactFlowContent()
        - .toUpdateContactFlowMetadata()
        - .toUpdateContactFlowModuleContent()
        - .toUpdateContactFlowModuleMetadata()
        - .toUpdateContactFlowName()
        - .toUpdateContactSchedule()
        - .toUpdateHoursOfOperation()
        - .toUpdateInstanceAttribute()
        - .toUpdateInstanceStorageConfig()
        - .toUpdateQueueHoursOfOperation()
        - .toUpdateQueueMaxContacts()
        - .toUpdateQueueName()
        - .toUpdateQueueOutboundCallerConfig()
        - .toUpdateQueueStatus()
        - .toUpdateQuickConnectConfig()
        - .toUpdateQuickConnectName()
        - .toUpdateRoutingProfileConcurrency()
        - .toUpdateRoutingProfileDefaultOutboundQueue()
        - .toUpdateRoutingProfileName()
        - .toUpdateRoutingProfileQueues()
        - .toUpdateRule()
        - .toUpdateSecurityProfile()
        - .toUpdateTaskTemplate()
        - .toUpdateUserHierarchy()
        - .toUpdateUserHierarchyGroupName()
        - .toUpdateUserHierarchyStructure()
        - .toUpdateUserIdentityInfo()
        - .toUpdateUserPhoneConfig()
        - .toUpdateUserRoutingProfile()
        - .toUpdateUserSecurityProfiles()
        - .toUpdatedescribeContent()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__84c80c2830e4b613e21ac12e0b505ccc29eb363f0ad531c56234fb64f9ea67c7)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Connect", jsii.invoke(self, "ifInstanceId", [value, operator]))

    @jsii.member(jsii_name="ifMonitorCapabilities")
    def if_monitor_capabilities(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Connect":
        '''(experimental) Filters access by restricting the monitor capabilities of the user in the request.

        https://docs.aws.amazon.com/connect/latest/adminguide/security_iam_service-with-iam.html

        Applies to actions:

        - .toMonitorContact()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0e2d5943d68bf8042aa1d94675d04a81e4e3d8d4e3e786a656700034a1cd49b2)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Connect", jsii.invoke(self, "ifMonitorCapabilities", [value, operator]))

    @jsii.member(jsii_name="ifSearchTag")
    def if_search_tag(
        self,
        tag_key: builtins.str,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Connect":
        '''(experimental) Filters access by TagFilter condition passed in the search request.

        https://docs.aws.amazon.com/connect/latest/adminguide/security_iam_service-with-iam.html

        Applies to actions:

        - .toSearchQueues()
        - .toSearchRoutingProfiles()
        - .toSearchSecurityProfiles()
        - .toSearchUsers()

        :param tag_key: The tag key to check.
        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1d08a082cdbe8e3163093026acb68a5931f24186416d2c7178c705d535a7f900)
            check_type(argname="argument tag_key", value=tag_key, expected_type=type_hints["tag_key"])
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Connect", jsii.invoke(self, "ifSearchTag", [tag_key, value, operator]))

    @jsii.member(jsii_name="ifStorageResourceType")
    def if_storage_resource_type(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Connect":
        '''(experimental) Filters access by restricting the storage resource type of the Amazon Connect instance storage configuration.

        https://docs.aws.amazon.com/connect/latest/adminguide/security_iam_service-with-iam.html

        Applies to actions:

        - .toAssociateInstanceStorageConfig()
        - .toDescribeInstanceStorageConfig()
        - .toDisassociateInstanceStorageConfig()
        - .toUpdateInstanceStorageConfig()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e2ad9f807e7b42f90d4582a7ec93131b220252f54a1989092c64a6549b9c5e4e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Connect", jsii.invoke(self, "ifStorageResourceType", [value, operator]))

    @jsii.member(jsii_name="onAgentStatus")
    def on_agent_status(
        self,
        instance_id: builtins.str,
        agent_status_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Connect":
        '''(experimental) Adds a resource of type agent-status to the statement.

        https://docs.aws.amazon.com/connect/latest/adminguide/metrics-agent-status.html

        :param instance_id: - Identifier for the instanceId.
        :param agent_status_id: - Identifier for the agentStatusId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b19b26e1e2d23c01038fc8bdbffeee08aad1212e39e0aae2ecdf7e037ddf0c31)
            check_type(argname="argument instance_id", value=instance_id, expected_type=type_hints["instance_id"])
            check_type(argname="argument agent_status_id", value=agent_status_id, expected_type=type_hints["agent_status_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Connect", jsii.invoke(self, "onAgentStatus", [instance_id, agent_status_id, account, region, partition]))

    @jsii.member(jsii_name="onContact")
    def on_contact(
        self,
        instance_id: builtins.str,
        contact_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Connect":
        '''(experimental) Adds a resource of type contact to the statement.

        https://docs.aws.amazon.com/connect/latest/adminguide/connect-contact-attributes.html

        :param instance_id: - Identifier for the instanceId.
        :param contact_id: - Identifier for the contactId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__24ba8d4a0f71518fbb9a2412eef5ea776a78f25d1253f1d997557fac50d3723a)
            check_type(argname="argument instance_id", value=instance_id, expected_type=type_hints["instance_id"])
            check_type(argname="argument contact_id", value=contact_id, expected_type=type_hints["contact_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Connect", jsii.invoke(self, "onContact", [instance_id, contact_id, account, region, partition]))

    @jsii.member(jsii_name="onContactFlow")
    def on_contact_flow(
        self,
        instance_id: builtins.str,
        contact_flow_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Connect":
        '''(experimental) Adds a resource of type contact-flow to the statement.

        https://docs.aws.amazon.com/connect/latest/adminguide/connect-contact-flows.html

        :param instance_id: - Identifier for the instanceId.
        :param contact_flow_id: - Identifier for the contactFlowId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__dfa4e79596f69c8032106a6d3c3276d5f31a2a57fd156c37c551abf9d8141598)
            check_type(argname="argument instance_id", value=instance_id, expected_type=type_hints["instance_id"])
            check_type(argname="argument contact_flow_id", value=contact_flow_id, expected_type=type_hints["contact_flow_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Connect", jsii.invoke(self, "onContactFlow", [instance_id, contact_flow_id, account, region, partition]))

    @jsii.member(jsii_name="onContactFlowModule")
    def on_contact_flow_module(
        self,
        instance_id: builtins.str,
        contact_flow_module_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Connect":
        '''(experimental) Adds a resource of type contact-flow-module to the statement.

        https://docs.aws.amazon.com/connect/latest/adminguide/contact-flow-modules.html

        :param instance_id: - Identifier for the instanceId.
        :param contact_flow_module_id: - Identifier for the contactFlowModuleId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__cad59033dfa59314e51c77e45b87cbd7a81fc4481952f1e392631ebf67941c84)
            check_type(argname="argument instance_id", value=instance_id, expected_type=type_hints["instance_id"])
            check_type(argname="argument contact_flow_module_id", value=contact_flow_module_id, expected_type=type_hints["contact_flow_module_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Connect", jsii.invoke(self, "onContactFlowModule", [instance_id, contact_flow_module_id, account, region, partition]))

    @jsii.member(jsii_name="onHierarchyGroup")
    def on_hierarchy_group(
        self,
        instance_id: builtins.str,
        hierarchy_group_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Connect":
        '''(experimental) Adds a resource of type hierarchy-group to the statement.

        https://docs.aws.amazon.com/connect/latest/adminguide/agent-hierarchy.html

        :param instance_id: - Identifier for the instanceId.
        :param hierarchy_group_id: - Identifier for the hierarchyGroupId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f9ed16d32bca8c54b91ebef0d84fe4caf6b1be388d5b9a20b6b69ac6eceefc34)
            check_type(argname="argument instance_id", value=instance_id, expected_type=type_hints["instance_id"])
            check_type(argname="argument hierarchy_group_id", value=hierarchy_group_id, expected_type=type_hints["hierarchy_group_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Connect", jsii.invoke(self, "onHierarchyGroup", [instance_id, hierarchy_group_id, account, region, partition]))

    @jsii.member(jsii_name="onHoursOfOperation")
    def on_hours_of_operation(
        self,
        instance_id: builtins.str,
        hours_of_operation_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Connect":
        '''(experimental) Adds a resource of type hours-of-operation to the statement.

        https://docs.aws.amazon.com/connect/latest/adminguide/set-hours-operation.html

        :param instance_id: - Identifier for the instanceId.
        :param hours_of_operation_id: - Identifier for the hoursOfOperationId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0e23b68686695568c9fd1bee0406acb7bd1f97ed6ac0ae815925ece488862651)
            check_type(argname="argument instance_id", value=instance_id, expected_type=type_hints["instance_id"])
            check_type(argname="argument hours_of_operation_id", value=hours_of_operation_id, expected_type=type_hints["hours_of_operation_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Connect", jsii.invoke(self, "onHoursOfOperation", [instance_id, hours_of_operation_id, account, region, partition]))

    @jsii.member(jsii_name="onInstance")
    def on_instance(
        self,
        instance_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Connect":
        '''(experimental) Adds a resource of type instance to the statement.

        https://docs.aws.amazon.com/connect/latest/adminguide/amazon-connect-instances.html

        :param instance_id: - Identifier for the instanceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__65cb9ad017d793a46f25746964e385d8276acd0b501e093f0674a4a2b70e54da)
            check_type(argname="argument instance_id", value=instance_id, expected_type=type_hints["instance_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Connect", jsii.invoke(self, "onInstance", [instance_id, account, region, partition]))

    @jsii.member(jsii_name="onIntegrationAssociation")
    def on_integration_association(
        self,
        instance_id: builtins.str,
        integration_association_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Connect":
        '''(experimental) Adds a resource of type integration-association to the statement.

        https://docs.aws.amazon.com/connect/latest/adminguide/API_IntegrationAssociationSummary.html

        :param instance_id: - Identifier for the instanceId.
        :param integration_association_id: - Identifier for the integrationAssociationId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bf0293de7b155b422209b61f6304206a8c6a9cb24b6b17b110b3ceafe00a8d3e)
            check_type(argname="argument instance_id", value=instance_id, expected_type=type_hints["instance_id"])
            check_type(argname="argument integration_association_id", value=integration_association_id, expected_type=type_hints["integration_association_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Connect", jsii.invoke(self, "onIntegrationAssociation", [instance_id, integration_association_id, account, region, partition]))

    @jsii.member(jsii_name="onLegacyPhoneNumber")
    def on_legacy_phone_number(
        self,
        instance_id: builtins.str,
        phone_number_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Connect":
        '''(experimental) Adds a resource of type legacy-phone-number to the statement.

        https://docs.aws.amazon.com/connect/latest/adminguide/contact-center-phone-number.html

        :param instance_id: - Identifier for the instanceId.
        :param phone_number_id: - Identifier for the phoneNumberId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a6f3bfd1e99902b6bf562a9831aba3729c3b4db031acdb4f40c4859d1cf9419b)
            check_type(argname="argument instance_id", value=instance_id, expected_type=type_hints["instance_id"])
            check_type(argname="argument phone_number_id", value=phone_number_id, expected_type=type_hints["phone_number_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Connect", jsii.invoke(self, "onLegacyPhoneNumber", [instance_id, phone_number_id, account, region, partition]))

    @jsii.member(jsii_name="onPhoneNumber")
    def on_phone_number(
        self,
        phone_number_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Connect":
        '''(experimental) Adds a resource of type phone-number to the statement.

        https://docs.aws.amazon.com/connect/latest/adminguide/contact-center-phone-number.html

        :param phone_number_id: - Identifier for the phoneNumberId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bb25bf0b48dcb43f51bca689afc931451ad8cdb7878c1e67853f93d6ac564ed7)
            check_type(argname="argument phone_number_id", value=phone_number_id, expected_type=type_hints["phone_number_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Connect", jsii.invoke(self, "onPhoneNumber", [phone_number_id, account, region, partition]))

    @jsii.member(jsii_name="onQueue")
    def on_queue(
        self,
        instance_id: builtins.str,
        queue_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Connect":
        '''(experimental) Adds a resource of type queue to the statement.

        https://docs.aws.amazon.com/connect/latest/adminguide/create-queue.html

        :param instance_id: - Identifier for the instanceId.
        :param queue_id: - Identifier for the queueId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__072da95ebb15860d5faff9117bb1ff144b9f46bfe405c19d473af8ab15464ee2)
            check_type(argname="argument instance_id", value=instance_id, expected_type=type_hints["instance_id"])
            check_type(argname="argument queue_id", value=queue_id, expected_type=type_hints["queue_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Connect", jsii.invoke(self, "onQueue", [instance_id, queue_id, account, region, partition]))

    @jsii.member(jsii_name="onQuickConnect")
    def on_quick_connect(
        self,
        instance_id: builtins.str,
        quick_connect_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Connect":
        '''(experimental) Adds a resource of type quick-connect to the statement.

        https://docs.aws.amazon.com/connect/latest/adminguide/quick-connects.html

        :param instance_id: - Identifier for the instanceId.
        :param quick_connect_id: - Identifier for the quickConnectId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d904ae66717d00bfc7cda4014ac0b166058b56477984d24507157eac106da4e5)
            check_type(argname="argument instance_id", value=instance_id, expected_type=type_hints["instance_id"])
            check_type(argname="argument quick_connect_id", value=quick_connect_id, expected_type=type_hints["quick_connect_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Connect", jsii.invoke(self, "onQuickConnect", [instance_id, quick_connect_id, account, region, partition]))

    @jsii.member(jsii_name="onRoutingProfile")
    def on_routing_profile(
        self,
        instance_id: builtins.str,
        routing_profile_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Connect":
        '''(experimental) Adds a resource of type routing-profile to the statement.

        https://docs.aws.amazon.com/connect/latest/adminguide/routing-profiles.html

        :param instance_id: - Identifier for the instanceId.
        :param routing_profile_id: - Identifier for the routingProfileId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1b145835cd708dabf8e3d5ce0db002f27dc249cf6511e45c4d03d13899a71083)
            check_type(argname="argument instance_id", value=instance_id, expected_type=type_hints["instance_id"])
            check_type(argname="argument routing_profile_id", value=routing_profile_id, expected_type=type_hints["routing_profile_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Connect", jsii.invoke(self, "onRoutingProfile", [instance_id, routing_profile_id, account, region, partition]))

    @jsii.member(jsii_name="onRule")
    def on_rule(
        self,
        instance_id: builtins.str,
        rule_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Connect":
        '''(experimental) Adds a resource of type rule to the statement.

        https://docs.aws.amazon.com/connect/latest/adminguide/connect-rules.html

        :param instance_id: - Identifier for the instanceId.
        :param rule_id: - Identifier for the ruleId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f5000a96ca8c16eb2a6eb9e6cbd34c776dd2f2dda611d10fb3f821ef07af0bbc)
            check_type(argname="argument instance_id", value=instance_id, expected_type=type_hints["instance_id"])
            check_type(argname="argument rule_id", value=rule_id, expected_type=type_hints["rule_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Connect", jsii.invoke(self, "onRule", [instance_id, rule_id, account, region, partition]))

    @jsii.member(jsii_name="onSecurityProfile")
    def on_security_profile(
        self,
        instance_id: builtins.str,
        security_profile_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Connect":
        '''(experimental) Adds a resource of type security-profile to the statement.

        https://docs.aws.amazon.com/connect/latest/adminguide/connect-security-profiles.html

        :param instance_id: - Identifier for the instanceId.
        :param security_profile_id: - Identifier for the securityProfileId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__72a7572ab32f886885a43988a6a931042a58b3e0629280082feb9a8b1e1ff1e1)
            check_type(argname="argument instance_id", value=instance_id, expected_type=type_hints["instance_id"])
            check_type(argname="argument security_profile_id", value=security_profile_id, expected_type=type_hints["security_profile_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Connect", jsii.invoke(self, "onSecurityProfile", [instance_id, security_profile_id, account, region, partition]))

    @jsii.member(jsii_name="onTaskTemplate")
    def on_task_template(
        self,
        instance_id: builtins.str,
        task_template_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Connect":
        '''(experimental) Adds a resource of type task-template to the statement.

        https://docs.aws.amazon.com/connect/latest/adminguide/task-templates.html

        :param instance_id: - Identifier for the instanceId.
        :param task_template_id: - Identifier for the taskTemplateId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__70caa2b8f36f6453de1c49a7358fc34617fc97db79f84b5b9272ee95943c657f)
            check_type(argname="argument instance_id", value=instance_id, expected_type=type_hints["instance_id"])
            check_type(argname="argument task_template_id", value=task_template_id, expected_type=type_hints["task_template_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Connect", jsii.invoke(self, "onTaskTemplate", [instance_id, task_template_id, account, region, partition]))

    @jsii.member(jsii_name="onTrafficDistributionGroup")
    def on_traffic_distribution_group(
        self,
        traffic_distribution_group_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Connect":
        '''(experimental) Adds a resource of type traffic-distribution-group to the statement.

        https://docs.aws.amazon.com/connect/latest/adminguide/traffic-distribution-groups.html

        :param traffic_distribution_group_id: - Identifier for the trafficDistributionGroupId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ba7b0bcebea1b7f801fced8bd4e4e6457fa1d10e72b9b938374a77fada81d24c)
            check_type(argname="argument traffic_distribution_group_id", value=traffic_distribution_group_id, expected_type=type_hints["traffic_distribution_group_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Connect", jsii.invoke(self, "onTrafficDistributionGroup", [traffic_distribution_group_id, account, region, partition]))

    @jsii.member(jsii_name="onUseCase")
    def on_use_case(
        self,
        instance_id: builtins.str,
        use_case_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Connect":
        '''(experimental) Adds a resource of type use-case to the statement.

        https://docs.aws.amazon.com/connect/latest/adminguide/API_UseCase.html

        :param instance_id: - Identifier for the instanceId.
        :param use_case_id: - Identifier for the useCaseId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__51c58b80323340bcefebfceeb3d30a9f8eaffefb6d81e1a509cf11ce840fb74f)
            check_type(argname="argument instance_id", value=instance_id, expected_type=type_hints["instance_id"])
            check_type(argname="argument use_case_id", value=use_case_id, expected_type=type_hints["use_case_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Connect", jsii.invoke(self, "onUseCase", [instance_id, use_case_id, account, region, partition]))

    @jsii.member(jsii_name="onUser")
    def on_user(
        self,
        instance_id: builtins.str,
        user_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Connect":
        '''(experimental) Adds a resource of type user to the statement.

        https://docs.aws.amazon.com/connect/latest/adminguide/connect-agents.html

        :param instance_id: - Identifier for the instanceId.
        :param user_id: - Identifier for the userId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3d0c1155d9166a1899a6c81efdf21f960b8779b9cf163fc44bb94ca5687dc759)
            check_type(argname="argument instance_id", value=instance_id, expected_type=type_hints["instance_id"])
            check_type(argname="argument user_id", value=user_id, expected_type=type_hints["user_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Connect", jsii.invoke(self, "onUser", [instance_id, user_id, account, region, partition]))

    @jsii.member(jsii_name="onVocabulary")
    def on_vocabulary(
        self,
        instance_id: builtins.str,
        vocabulary_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Connect":
        '''(experimental) Adds a resource of type vocabulary to the statement.

        https://docs.aws.amazon.com/connect/latest/adminguide/API_Vocabulary.html

        :param instance_id: - Identifier for the instanceId.
        :param vocabulary_id: - Identifier for the vocabularyId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ae552b15a125610dbabc9f2d66c61303484e9d653a3315a231b1e85c58a6f550)
            check_type(argname="argument instance_id", value=instance_id, expected_type=type_hints["instance_id"])
            check_type(argname="argument vocabulary_id", value=vocabulary_id, expected_type=type_hints["vocabulary_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Connect", jsii.invoke(self, "onVocabulary", [instance_id, vocabulary_id, account, region, partition]))

    @jsii.member(jsii_name="onWildcardAgentStatus")
    def on_wildcard_agent_status(
        self,
        instance_id: builtins.str,
        resource_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Connect":
        '''(experimental) Adds a resource of type wildcard-agent-status to the statement.

        https://docs.aws.amazon.com/connect/latest/adminguide/metrics-agent-status.html

        :param instance_id: - Identifier for the instanceId.
        :param resource_name: - Identifier for the resourceName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0f21692b737fd0367ac1792f83c9bfa99f8c1432e063312f6fbed62dc2ac771d)
            check_type(argname="argument instance_id", value=instance_id, expected_type=type_hints["instance_id"])
            check_type(argname="argument resource_name", value=resource_name, expected_type=type_hints["resource_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Connect", jsii.invoke(self, "onWildcardAgentStatus", [instance_id, resource_name, account, region, partition]))

    @jsii.member(jsii_name="onWildcardContactFlow")
    def on_wildcard_contact_flow(
        self,
        instance_id: builtins.str,
        resource_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Connect":
        '''(experimental) Adds a resource of type wildcard-contact-flow to the statement.

        https://docs.aws.amazon.com/connect/latest/adminguide/connect-contact-flows.html

        :param instance_id: - Identifier for the instanceId.
        :param resource_name: - Identifier for the resourceName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0ef3dc8a7f592f4d469c5e7e6b7f1a707ee647617470e01e23e71e4bb04d1753)
            check_type(argname="argument instance_id", value=instance_id, expected_type=type_hints["instance_id"])
            check_type(argname="argument resource_name", value=resource_name, expected_type=type_hints["resource_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Connect", jsii.invoke(self, "onWildcardContactFlow", [instance_id, resource_name, account, region, partition]))

    @jsii.member(jsii_name="onWildcardLegacyPhoneNumber")
    def on_wildcard_legacy_phone_number(
        self,
        instance_id: builtins.str,
        resource_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Connect":
        '''(experimental) Adds a resource of type wildcard-legacy-phone-number to the statement.

        https://docs.aws.amazon.com/connect/latest/adminguide/contact-center-phone-number.html

        :param instance_id: - Identifier for the instanceId.
        :param resource_name: - Identifier for the resourceName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2c81542869090fc436baa1e5e739712b265bf2c15e88091ebfd7cb5c7937dd89)
            check_type(argname="argument instance_id", value=instance_id, expected_type=type_hints["instance_id"])
            check_type(argname="argument resource_name", value=resource_name, expected_type=type_hints["resource_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Connect", jsii.invoke(self, "onWildcardLegacyPhoneNumber", [instance_id, resource_name, account, region, partition]))

    @jsii.member(jsii_name="onWildcardPhoneNumber")
    def on_wildcard_phone_number(
        self,
        resource_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Connect":
        '''(experimental) Adds a resource of type wildcard-phone-number to the statement.

        https://docs.aws.amazon.com/connect/latest/adminguide/contact-center-phone-number.html

        :param resource_name: - Identifier for the resourceName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b57acb93481dd8d1f0f58dc7a48ff11ef997d3f6dbb3c425adfbb74dce6df06f)
            check_type(argname="argument resource_name", value=resource_name, expected_type=type_hints["resource_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Connect", jsii.invoke(self, "onWildcardPhoneNumber", [resource_name, account, region, partition]))

    @jsii.member(jsii_name="onWildcardQueue")
    def on_wildcard_queue(
        self,
        instance_id: builtins.str,
        resource_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Connect":
        '''(experimental) Adds a resource of type wildcard-queue to the statement.

        https://docs.aws.amazon.com/connect/latest/adminguide/create-queue.html

        :param instance_id: - Identifier for the instanceId.
        :param resource_name: - Identifier for the resourceName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__725e367ed502b68e7111f5d6867ac41456f1aaf5d6af80e6115dfc830dfd2904)
            check_type(argname="argument instance_id", value=instance_id, expected_type=type_hints["instance_id"])
            check_type(argname="argument resource_name", value=resource_name, expected_type=type_hints["resource_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Connect", jsii.invoke(self, "onWildcardQueue", [instance_id, resource_name, account, region, partition]))

    @jsii.member(jsii_name="onWildcardQuickConnect")
    def on_wildcard_quick_connect(
        self,
        instance_id: builtins.str,
        resource_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Connect":
        '''(experimental) Adds a resource of type wildcard-quick-connect to the statement.

        https://docs.aws.amazon.com/connect/latest/adminguide/quick-connects.html

        :param instance_id: - Identifier for the instanceId.
        :param resource_name: - Identifier for the resourceName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__639f929016257dbec3ed6e3a89e66091350a8304521956dee289a19dd2c17ba7)
            check_type(argname="argument instance_id", value=instance_id, expected_type=type_hints["instance_id"])
            check_type(argname="argument resource_name", value=resource_name, expected_type=type_hints["resource_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Connect", jsii.invoke(self, "onWildcardQuickConnect", [instance_id, resource_name, account, region, partition]))

    @jsii.member(jsii_name="toAssociateApprovedOrigin")
    def to_associate_approved_origin(self) -> "Connect":
        '''(experimental) Grants permission to associate approved origin for an existing Amazon Connect instance.

        Access Level: Write

        Possible conditions:

        - .ifInstanceId()

        https://docs.aws.amazon.com/console/connect/amazon-connect-console/grant-instance-permissions

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toAssociateApprovedOrigin", []))

    @jsii.member(jsii_name="toAssociateBot")
    def to_associate_bot(self) -> "Connect":
        '''(experimental) Grants permission to associate a Lex bot for an existing Amazon Connect instance.

        Access Level: Write

        Possible conditions:

        - .ifInstanceId()

        Dependent actions:

        - iam:AttachRolePolicy
        - iam:CreateServiceLinkedRole
        - iam:PutRolePolicy
        - lex:CreateResourcePolicy
        - lex:DescribeBotAlias
        - lex:GetBot
        - lex:UpdateResourcePolicy

        https://docs.aws.amazon.com/console/connect/amazon-connect-console/grant-instance-permissions

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toAssociateBot", []))

    @jsii.member(jsii_name="toAssociateCustomerProfilesDomain")
    def to_associate_customer_profiles_domain(self) -> "Connect":
        '''(experimental) Grants permission to associate a Customer Profiles domain for an existing Amazon Connect instance.

        Access Level: Write

        Dependent actions:

        - iam:AttachRolePolicy
        - iam:CreateServiceLinkedRole
        - iam:PutRolePolicy
        - profile:GetDomain

        https://docs.aws.amazon.com/console/connect/amazon-connect-console/grant-instance-permissions

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toAssociateCustomerProfilesDomain", []))

    @jsii.member(jsii_name="toAssociateDefaultVocabulary")
    def to_associate_default_vocabulary(self) -> "Connect":
        '''(experimental) Grants permission to default vocabulary for an existing Amazon Connect instance.

        Access Level: Write

        Possible conditions:

        - .ifInstanceId()

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toAssociateDefaultVocabulary", []))

    @jsii.member(jsii_name="toAssociateInstanceStorageConfig")
    def to_associate_instance_storage_config(self) -> "Connect":
        '''(experimental) Grants permission to associate instance storage for an existing Amazon Connect instance.

        Access Level: Write

        Possible conditions:

        - .ifStorageResourceType()
        - .ifInstanceId()

        Dependent actions:

        - ds:DescribeDirectories
        - firehose:DescribeDeliveryStream
        - iam:AttachRolePolicy
        - iam:CreateServiceLinkedRole
        - iam:PutRolePolicy
        - kinesis:DescribeStream
        - kms:CreateGrant
        - kms:DescribeKey
        - s3:GetBucketAcl
        - s3:GetBucketLocation

        https://docs.aws.amazon.com/console/connect/amazon-connect-console/grant-instance-permissions

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toAssociateInstanceStorageConfig", []))

    @jsii.member(jsii_name="toAssociateLambdaFunction")
    def to_associate_lambda_function(self) -> "Connect":
        '''(experimental) Grants permission to associate a Lambda function for an existing Amazon Connect instance.

        Access Level: Write

        Possible conditions:

        - .ifInstanceId()

        Dependent actions:

        - lambda:AddPermission

        https://docs.aws.amazon.com/console/connect/amazon-connect-console/grant-instance-permissions

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toAssociateLambdaFunction", []))

    @jsii.member(jsii_name="toAssociateLexBot")
    def to_associate_lex_bot(self) -> "Connect":
        '''(experimental) Grants permission to associate a Lex bot for an existing Amazon Connect instance.

        Access Level: Write

        Possible conditions:

        - .ifInstanceId()

        Dependent actions:

        - iam:AttachRolePolicy
        - iam:CreateServiceLinkedRole
        - iam:PutRolePolicy
        - lex:GetBot

        https://docs.aws.amazon.com/console/connect/amazon-connect-console/grant-instance-permissions

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toAssociateLexBot", []))

    @jsii.member(jsii_name="toAssociatePhoneNumberContactFlow")
    def to_associate_phone_number_contact_flow(self) -> "Connect":
        '''(experimental) Grants permission to associate contact flow resources to phone number resources in an Amazon Connect instance.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()
        - .ifInstanceId()

        https://docs.aws.amazon.com/connect/latest/APIReference/API_AssociatePhoneNumberContactFlow.html

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toAssociatePhoneNumberContactFlow", []))

    @jsii.member(jsii_name="toAssociateQueueQuickConnects")
    def to_associate_queue_quick_connects(self) -> "Connect":
        '''(experimental) Grants permission to associate quick connects with a queue in an Amazon Connect instance.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()
        - .ifInstanceId()

        https://docs.aws.amazon.com/connect/latest/APIReference/API_AssociateQueueQuickConnects.html

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toAssociateQueueQuickConnects", []))

    @jsii.member(jsii_name="toAssociateRoutingProfileQueues")
    def to_associate_routing_profile_queues(self) -> "Connect":
        '''(experimental) Grants permission to associate queues with a routing profile in an Amazon Connect instance.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()
        - .ifInstanceId()

        https://docs.aws.amazon.com/connect/latest/APIReference/API_AssociateRoutingProfileQueues.html

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toAssociateRoutingProfileQueues", []))

    @jsii.member(jsii_name="toAssociateSecurityKey")
    def to_associate_security_key(self) -> "Connect":
        '''(experimental) Grants permission to associate a security key for an existing Amazon Connect instance.

        Access Level: Write

        Possible conditions:

        - .ifInstanceId()

        https://docs.aws.amazon.com/console/connect/amazon-connect-console/grant-instance-permissions

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toAssociateSecurityKey", []))

    @jsii.member(jsii_name="toBatchAssociateAnalyticsDataSet")
    def to_batch_associate_analytics_data_set(self) -> "Connect":
        '''(experimental) Grants permission to grant access and to associate the datasets with the specified AWS account.

        Access Level: Write

        Possible conditions:

        - .ifInstanceId()

        https://docs.aws.amazon.com/connect/latest/adminguide/optimization-apis.html

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toBatchAssociateAnalyticsDataSet", []))

    @jsii.member(jsii_name="toBatchDisassociateAnalyticsDataSet")
    def to_batch_disassociate_analytics_data_set(self) -> "Connect":
        '''(experimental) Grants permission to revoke access and to disassociate the datasets with the specified AWS account.

        Access Level: Write

        Possible conditions:

        - .ifInstanceId()

        https://docs.aws.amazon.com/connect/latest/adminguide/optimization-apis.html

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toBatchDisassociateAnalyticsDataSet", []))

    @jsii.member(jsii_name="toClaimPhoneNumber")
    def to_claim_phone_number(self) -> "Connect":
        '''(experimental) Grants permission to claim phone number resources in an Amazon Connect instance or traffic distribution group.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/connect/latest/APIReference/API_ClaimPhoneNumber.html

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toClaimPhoneNumber", []))

    @jsii.member(jsii_name="toCreateAgentStatus")
    def to_create_agent_status(self) -> "Connect":
        '''(experimental) Grants permission to create agent status in an Amazon Connect instance.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifInstanceId()

        https://docs.aws.amazon.com/connect/latest/APIReference/API_CreateAgentStatus.html

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toCreateAgentStatus", []))

    @jsii.member(jsii_name="toCreateContactFlow")
    def to_create_contact_flow(self) -> "Connect":
        '''(experimental) Grants permission to create a contact flow in an Amazon Connect instance.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifInstanceId()

        https://docs.aws.amazon.com/connect/latest/APIReference/API_CreateContactFlow.html

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toCreateContactFlow", []))

    @jsii.member(jsii_name="toCreateContactFlowModule")
    def to_create_contact_flow_module(self) -> "Connect":
        '''(experimental) Grants permission to create a contact flow module in an Amazon Connect instance.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifInstanceId()

        https://docs.aws.amazon.com/connect/latest/APIReference/API_CreateContactFlowModule.html

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toCreateContactFlowModule", []))

    @jsii.member(jsii_name="toCreateHoursOfOperation")
    def to_create_hours_of_operation(self) -> "Connect":
        '''(experimental) Grants permission to create hours of operation in an Amazon Connect instance.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifInstanceId()

        https://docs.aws.amazon.com/connect/latest/APIReference/API_CreateHoursOfOperation.html

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toCreateHoursOfOperation", []))

    @jsii.member(jsii_name="toCreateInstance")
    def to_create_instance(self) -> "Connect":
        '''(experimental) Grants permission to create a new Amazon Connect instance.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - ds:AuthorizeApplication
        - ds:CheckAlias
        - ds:CreateAlias
        - ds:CreateDirectory
        - ds:CreateIdentityPoolDirectory
        - ds:DeleteDirectory
        - ds:DescribeDirectories
        - ds:UnauthorizeApplication
        - iam:AttachRolePolicy
        - iam:CreateServiceLinkedRole
        - iam:PutRolePolicy

        https://docs.aws.amazon.com/console/connect/amazon-connect-console/grant-instance-permissions

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toCreateInstance", []))

    @jsii.member(jsii_name="toCreateIntegrationAssociation")
    def to_create_integration_association(self) -> "Connect":
        '''(experimental) Grants permission to create an integration association with an Amazon Connect instance.

        Access Level: Write

        Possible conditions:

        - .ifInstanceId()
        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - app-integrations:CreateEventIntegrationAssociation
        - cases:GetDomain
        - connect:DescribeInstance
        - ds:DescribeDirectories
        - events:PutRule
        - events:PutTargets
        - iam:AttachRolePolicy
        - iam:CreateServiceLinkedRole
        - iam:PutRolePolicy
        - mobiletargeting:GetApp
        - voiceid:DescribeDomain
        - wisdom:GetAssistant
        - wisdom:GetKnowledgeBase

        https://docs.aws.amazon.com/connect/latest/APIReference/API_CreateIntegrationAssociation.html

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toCreateIntegrationAssociation", []))

    @jsii.member(jsii_name="toCreateQueue")
    def to_create_queue(self) -> "Connect":
        '''(experimental) Grants permission to create a queue in an Amazon Connect instance.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifInstanceId()

        https://docs.aws.amazon.com/connect/latest/APIReference/API_CreateQueue.html

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toCreateQueue", []))

    @jsii.member(jsii_name="toCreateQuickConnect")
    def to_create_quick_connect(self) -> "Connect":
        '''(experimental) Grants permission to create a quick connect in an Amazon Connect instance.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifInstanceId()

        https://docs.aws.amazon.com/connect/latest/APIReference/API_CreateQuickConnect.html

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toCreateQuickConnect", []))

    @jsii.member(jsii_name="toCreateRoutingProfile")
    def to_create_routing_profile(self) -> "Connect":
        '''(experimental) Grants permission to create a routing profile in an Amazon Connect instance.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifInstanceId()

        https://docs.aws.amazon.com/connect/latest/APIReference/API_CreateRoutingProfile.html

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toCreateRoutingProfile", []))

    @jsii.member(jsii_name="toCreateRule")
    def to_create_rule(self) -> "Connect":
        '''(experimental) Grants permission to create a rule in an Amazon Connect instance.

        Access Level: Write

        Possible conditions:

        - .ifInstanceId()

        https://docs.aws.amazon.com/connect/latest/APIReference/API_CreateRule.html

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toCreateRule", []))

    @jsii.member(jsii_name="toCreateSecurityProfile")
    def to_create_security_profile(self) -> "Connect":
        '''(experimental) Grants permission to create a security profile for the specified Amazon Connect instance.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifInstanceId()

        https://docs.aws.amazon.com/connect/latest/APIReference/API_CreateSecurityProfile.html

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toCreateSecurityProfile", []))

    @jsii.member(jsii_name="toCreateTaskTemplate")
    def to_create_task_template(self) -> "Connect":
        '''(experimental) Grants permission to create a task template in an Amazon Connect instance.

        Access Level: Write

        https://docs.aws.amazon.com/connect/latest/APIReference/API_CreateTaskTemplate.html

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toCreateTaskTemplate", []))

    @jsii.member(jsii_name="toCreateTrafficDistributionGroup")
    def to_create_traffic_distribution_group(self) -> "Connect":
        '''(experimental) Grants permission to create a traffic distribution group.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifInstanceId()

        https://docs.aws.amazon.com/connect/latest/APIReference/API_CreateTrafficDistributionGroup.html

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toCreateTrafficDistributionGroup", []))

    @jsii.member(jsii_name="toCreateUseCase")
    def to_create_use_case(self) -> "Connect":
        '''(experimental) Grants permission to create a use case for an integration association.

        Access Level: Write

        Possible conditions:

        - .ifInstanceId()
        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - connect:DescribeInstance
        - ds:DescribeDirectories

        https://docs.aws.amazon.com/connect/latest/APIReference/API_CreateUseCase.html

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toCreateUseCase", []))

    @jsii.member(jsii_name="toCreateUser")
    def to_create_user(self) -> "Connect":
        '''(experimental) Grants permission to create a user for the specified Amazon Connect instance.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifInstanceId()

        https://docs.aws.amazon.com/connect/latest/APIReference/API_CreateUser.html

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toCreateUser", []))

    @jsii.member(jsii_name="toCreateUserHierarchyGroup")
    def to_create_user_hierarchy_group(self) -> "Connect":
        '''(experimental) Grants permission to create a user hierarchy group in an Amazon Connect instance.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifInstanceId()

        https://docs.aws.amazon.com/connect/latest/APIReference/API_CreateUserHierarchyGroup.html

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toCreateUserHierarchyGroup", []))

    @jsii.member(jsii_name="toCreateVocabulary")
    def to_create_vocabulary(self) -> "Connect":
        '''(experimental) Grants permission to create a vocabulary in an Amazon Connect instance.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifInstanceId()

        https://docs.aws.amazon.com/connect/latest/APIReference/API_CreateVocabulary.html

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toCreateVocabulary", []))

    @jsii.member(jsii_name="toDeleteContactFlow")
    def to_delete_contact_flow(self) -> "Connect":
        '''(experimental) Grants permission to delete a contact flow in an Amazon Connect instance.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()
        - .ifInstanceId()

        https://docs.aws.amazon.com/connect/latest/APIReference/API_DeleteContactFlow.html

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toDeleteContactFlow", []))

    @jsii.member(jsii_name="toDeleteContactFlowModule")
    def to_delete_contact_flow_module(self) -> "Connect":
        '''(experimental) Grants permission to delete a contact flow module in an Amazon Connect instance.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()
        - .ifInstanceId()

        https://docs.aws.amazon.com/connect/latest/APIReference/API_DeleteContactFlowModule.html

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toDeleteContactFlowModule", []))

    @jsii.member(jsii_name="toDeleteHoursOfOperation")
    def to_delete_hours_of_operation(self) -> "Connect":
        '''(experimental) Grants permission to delete hours of operation in an Amazon Connect instance.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()
        - .ifInstanceId()

        https://docs.aws.amazon.com/connect/latest/APIReference/API_DeleteHoursOfOperation.html

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toDeleteHoursOfOperation", []))

    @jsii.member(jsii_name="toDeleteInstance")
    def to_delete_instance(self) -> "Connect":
        '''(experimental) Grants permission to delete an Amazon Connect instance.

        When you remove an instance, the link to an existing AWS directory is also removed

        Access Level: Write

        Possible conditions:

        - .ifInstanceId()
        - .ifAwsResourceTag()

        Dependent actions:

        - ds:DeleteDirectory
        - ds:DescribeDirectories
        - ds:UnauthorizeApplication

        https://docs.aws.amazon.com/console/connect/amazon-connect-console/grant-instance-permissions

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toDeleteInstance", []))

    @jsii.member(jsii_name="toDeleteIntegrationAssociation")
    def to_delete_integration_association(self) -> "Connect":
        '''(experimental) Grants permission to delete an integration association from an Amazon Connect instance.

        The association must not have any use cases associated with it

        Access Level: Write

        Possible conditions:

        - .ifInstanceId()

        Dependent actions:

        - app-integrations:DeleteEventIntegrationAssociation
        - connect:DescribeInstance
        - ds:DescribeDirectories
        - events:DeleteRule
        - events:ListTargetsByRule
        - events:RemoveTargets

        https://docs.aws.amazon.com/connect/latest/APIReference/API_DeleteIntegrationAssociation.html

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toDeleteIntegrationAssociation", []))

    @jsii.member(jsii_name="toDeleteQuickConnect")
    def to_delete_quick_connect(self) -> "Connect":
        '''(experimental) Grants permission to delete a quick connect in an Amazon Connect instance.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()
        - .ifInstanceId()

        https://docs.aws.amazon.com/connect/latest/APIReference/API_DeleteQuickConnect.html

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toDeleteQuickConnect", []))

    @jsii.member(jsii_name="toDeleteRule")
    def to_delete_rule(self) -> "Connect":
        '''(experimental) Grants permission to delete a rule in an Amazon Connect instance.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()
        - .ifInstanceId()

        https://docs.aws.amazon.com/connect/latest/APIReference/API_DeleteRule.html

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toDeleteRule", []))

    @jsii.member(jsii_name="toDeleteSecurityProfile")
    def to_delete_security_profile(self) -> "Connect":
        '''(experimental) Grants permission to delete a security profile in an Amazon Connect instance.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()
        - .ifInstanceId()

        https://docs.aws.amazon.com/connect/latest/APIReference/API_DeleteSecurityProfile.html

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toDeleteSecurityProfile", []))

    @jsii.member(jsii_name="toDeleteTaskTemplate")
    def to_delete_task_template(self) -> "Connect":
        '''(experimental) Grants permission to delete a task template in an Amazon Connect instance.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()
        - .ifInstanceId()

        https://docs.aws.amazon.com/connect/latest/APIReference/API_DeleteTaskTemplate.html

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toDeleteTaskTemplate", []))

    @jsii.member(jsii_name="toDeleteTrafficDistributionGroup")
    def to_delete_traffic_distribution_group(self) -> "Connect":
        '''(experimental) Grants permission to delete a traffic distribution group.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/connect/latest/APIReference/API_DeleteTrafficDistributionGroup.html

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toDeleteTrafficDistributionGroup", []))

    @jsii.member(jsii_name="toDeleteUseCase")
    def to_delete_use_case(self) -> "Connect":
        '''(experimental) Grants permission to delete a use case from an integration association.

        Access Level: Write

        Possible conditions:

        - .ifInstanceId()

        Dependent actions:

        - connect:DescribeInstance
        - ds:DescribeDirectories

        https://docs.aws.amazon.com/connect/latest/APIReference/API_DeleteUseCase.html

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toDeleteUseCase", []))

    @jsii.member(jsii_name="toDeleteUser")
    def to_delete_user(self) -> "Connect":
        '''(experimental) Grants permission to delete a user in an Amazon Connect instance.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()
        - .ifInstanceId()

        https://docs.aws.amazon.com/connect/latest/APIReference/API_DeleteUser.html

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toDeleteUser", []))

    @jsii.member(jsii_name="toDeleteUserHierarchyGroup")
    def to_delete_user_hierarchy_group(self) -> "Connect":
        '''(experimental) Grants permission to delete a user hierarchy group in an Amazon Connect instance.

        Access Level: Write

        Possible conditions:

        - .ifInstanceId()

        https://docs.aws.amazon.com/connect/latest/APIReference/API_DeleteUserHierarchyGroup.html

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toDeleteUserHierarchyGroup", []))

    @jsii.member(jsii_name="toDeleteVocabulary")
    def to_delete_vocabulary(self) -> "Connect":
        '''(experimental) Grants permission to delete a vocabulary in an Amazon Connect instance.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()
        - .ifInstanceId()

        https://docs.aws.amazon.com/connect/latest/APIReference/API_DeleteVocabulary.html

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toDeleteVocabulary", []))

    @jsii.member(jsii_name="toDescribeAgentStatus")
    def to_describe_agent_status(self) -> "Connect":
        '''(experimental) Grants permission to describe agent status in an Amazon Connect instance.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()
        - .ifInstanceId()

        https://docs.aws.amazon.com/connect/latest/APIReference/API_DescribeAgentStatus.html

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toDescribeAgentStatus", []))

    @jsii.member(jsii_name="toDescribeContact")
    def to_describe_contact(self) -> "Connect":
        '''(experimental) Grants permission to describe a contact in an Amazon Connect instance.

        Access Level: Read

        Possible conditions:

        - .ifInstanceId()

        https://docs.aws.amazon.com/connect/latest/APIReference/API_DescribeContact.html

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toDescribeContact", []))

    @jsii.member(jsii_name="toDescribeContactFlow")
    def to_describe_contact_flow(self) -> "Connect":
        '''(experimental) Grants permission to describe a contact flow in an Amazon Connect instance.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()
        - .ifInstanceId()

        https://docs.aws.amazon.com/connect/latest/APIReference/API_DescribeContactFlow.html

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toDescribeContactFlow", []))

    @jsii.member(jsii_name="toDescribeContactFlowModule")
    def to_describe_contact_flow_module(self) -> "Connect":
        '''(experimental) Grants permission to describe a contact flow module in an Amazon Connect instance.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()
        - .ifInstanceId()

        https://docs.aws.amazon.com/connect/latest/APIReference/API_DescribeContactFlowModule.html

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toDescribeContactFlowModule", []))

    @jsii.member(jsii_name="toDescribeForecastingPlanningSchedulingIntegration")
    def to_describe_forecasting_planning_scheduling_integration(self) -> "Connect":
        '''(experimental) Grants permission to describe the status of forecasting, planning, and scheduling integration on an Amazon Connect instance.

        Access Level: Read

        Possible conditions:

        - .ifInstanceId()

        https://docs.aws.amazon.com/connect/latest/adminguide/optimization-apis.html

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toDescribeForecastingPlanningSchedulingIntegration", []))

    @jsii.member(jsii_name="toDescribeHoursOfOperation")
    def to_describe_hours_of_operation(self) -> "Connect":
        '''(experimental) Grants permission to describe hours of operation in an Amazon Connect instance.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()
        - .ifInstanceId()

        https://docs.aws.amazon.com/connect/latest/APIReference/API_DescribeHoursOfOperation.html

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toDescribeHoursOfOperation", []))

    @jsii.member(jsii_name="toDescribeInstance")
    def to_describe_instance(self) -> "Connect":
        '''(experimental) Grants permission to view details of an Amazon Connect instance and is also required to create an instance.

        Access Level: Read

        Possible conditions:

        - .ifInstanceId()
        - .ifAwsResourceTag()

        Dependent actions:

        - ds:DescribeDirectories

        https://docs.aws.amazon.com/console/connect/amazon-connect-console/grant-instance-permissions

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toDescribeInstance", []))

    @jsii.member(jsii_name="toDescribeInstanceAttribute")
    def to_describe_instance_attribute(self) -> "Connect":
        '''(experimental) Grants permission to view the attribute details of an existing Amazon Connect instance.

        Access Level: Read

        Possible conditions:

        - .ifAttributeType()
        - .ifInstanceId()

        https://docs.aws.amazon.com/console/connect/amazon-connect-console/grant-instance-permissions

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toDescribeInstanceAttribute", []))

    @jsii.member(jsii_name="toDescribeInstanceStorageConfig")
    def to_describe_instance_storage_config(self) -> "Connect":
        '''(experimental) Grants permission to view the instance storage configuration for an existing Amazon Connect instance.

        Access Level: Read

        Possible conditions:

        - .ifStorageResourceType()
        - .ifInstanceId()

        https://docs.aws.amazon.com/console/connect/amazon-connect-console/grant-instance-permissions

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toDescribeInstanceStorageConfig", []))

    @jsii.member(jsii_name="toDescribePhoneNumber")
    def to_describe_phone_number(self) -> "Connect":
        '''(experimental) Grants permission to describe phone number resources in an Amazon Connect instance or traffic distribution group.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/connect/latest/APIReference/API_DescribePhoneNumber.html

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toDescribePhoneNumber", []))

    @jsii.member(jsii_name="toDescribeQueue")
    def to_describe_queue(self) -> "Connect":
        '''(experimental) Grants permission to describe a queue in an Amazon Connect instance.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()
        - .ifInstanceId()

        https://docs.aws.amazon.com/connect/latest/APIReference/API_DescribeQueue.html

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toDescribeQueue", []))

    @jsii.member(jsii_name="toDescribeQuickConnect")
    def to_describe_quick_connect(self) -> "Connect":
        '''(experimental) Grants permission to describe a quick connect in an Amazon Connect instance.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()
        - .ifInstanceId()

        https://docs.aws.amazon.com/connect/latest/APIReference/API_DescribeQuickConnect.html

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toDescribeQuickConnect", []))

    @jsii.member(jsii_name="toDescribeRoutingProfile")
    def to_describe_routing_profile(self) -> "Connect":
        '''(experimental) Grants permission to describe a routing profile in an Amazon Connect instance.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()
        - .ifInstanceId()

        https://docs.aws.amazon.com/connect/latest/APIReference/API_DescribeRoutingProfile.html

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toDescribeRoutingProfile", []))

    @jsii.member(jsii_name="toDescribeRule")
    def to_describe_rule(self) -> "Connect":
        '''(experimental) Grants permission to describe a rule in an Amazon Connect instance.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()
        - .ifInstanceId()

        https://docs.aws.amazon.com/connect/latest/APIReference/API_DescribeRule.html

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toDescribeRule", []))

    @jsii.member(jsii_name="toDescribeSecurityProfile")
    def to_describe_security_profile(self) -> "Connect":
        '''(experimental) Grants permission to describe a security profile in an Amazon Connect instance.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()
        - .ifInstanceId()

        https://docs.aws.amazon.com/connect/latest/APIReference/API_DescribeSecurityProfile.html

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toDescribeSecurityProfile", []))

    @jsii.member(jsii_name="toDescribeTrafficDistributionGroup")
    def to_describe_traffic_distribution_group(self) -> "Connect":
        '''(experimental) Grants permission to describe a traffic distribution group.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/connect/latest/APIReference/API_DescribeTrafficDistributionGroup.html

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toDescribeTrafficDistributionGroup", []))

    @jsii.member(jsii_name="toDescribeUser")
    def to_describe_user(self) -> "Connect":
        '''(experimental) Grants permission to describe a user in an Amazon Connect instance.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()
        - .ifInstanceId()

        https://docs.aws.amazon.com/connect/latest/APIReference/API_DescribeUser.html

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toDescribeUser", []))

    @jsii.member(jsii_name="toDescribeUserHierarchyGroup")
    def to_describe_user_hierarchy_group(self) -> "Connect":
        '''(experimental) Grants permission to describe a hierarchy group for an Amazon Connect instance.

        Access Level: Read

        Possible conditions:

        - .ifInstanceId()

        https://docs.aws.amazon.com/connect/latest/APIReference/API_DescribeUserHierarchyGroup.html

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toDescribeUserHierarchyGroup", []))

    @jsii.member(jsii_name="toDescribeUserHierarchyStructure")
    def to_describe_user_hierarchy_structure(self) -> "Connect":
        '''(experimental) Grants permission to describe the hierarchy structure for an Amazon Connect instance.

        Access Level: Read

        Possible conditions:

        - .ifInstanceId()

        https://docs.aws.amazon.com/connect/latest/APIReference/API_DescribeUserHierarchyStructure.html

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toDescribeUserHierarchyStructure", []))

    @jsii.member(jsii_name="toDescribeVocabulary")
    def to_describe_vocabulary(self) -> "Connect":
        '''(experimental) Grants permission to describe a vocabulary in an Amazon Connect instance.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()
        - .ifInstanceId()

        https://docs.aws.amazon.com/connect/latest/APIReference/API_DescribeVocabulary.html

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toDescribeVocabulary", []))

    @jsii.member(jsii_name="toDisassociateApprovedOrigin")
    def to_disassociate_approved_origin(self) -> "Connect":
        '''(experimental) Grants permission to disassociate approved origin for an existing Amazon Connect instance.

        Access Level: Write

        Possible conditions:

        - .ifInstanceId()

        https://docs.aws.amazon.com/console/connect/amazon-connect-console/grant-instance-permissions

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toDisassociateApprovedOrigin", []))

    @jsii.member(jsii_name="toDisassociateBot")
    def to_disassociate_bot(self) -> "Connect":
        '''(experimental) Grants permission to disassociate a Lex bot for an existing Amazon Connect instance.

        Access Level: Write

        Possible conditions:

        - .ifInstanceId()

        Dependent actions:

        - iam:AttachRolePolicy
        - iam:CreateServiceLinkedRole
        - iam:PutRolePolicy
        - lex:DeleteResourcePolicy
        - lex:UpdateResourcePolicy

        https://docs.aws.amazon.com/console/connect/amazon-connect-console/grant-instance-permissions

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toDisassociateBot", []))

    @jsii.member(jsii_name="toDisassociateCustomerProfilesDomain")
    def to_disassociate_customer_profiles_domain(self) -> "Connect":
        '''(experimental) Grants permission to disassociate a Customer Profiles domain for an existing Amazon Connect instance.

        Access Level: Write

        Dependent actions:

        - iam:AttachRolePolicy
        - iam:DeleteRolePolicy
        - iam:DetachRolePolicy
        - iam:GetPolicy
        - iam:GetPolicyVersion
        - iam:GetRolePolicy

        https://docs.aws.amazon.com/console/connect/amazon-connect-console/grant-instance-permissions

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toDisassociateCustomerProfilesDomain", []))

    @jsii.member(jsii_name="toDisassociateInstanceStorageConfig")
    def to_disassociate_instance_storage_config(self) -> "Connect":
        '''(experimental) Grants permission to disassociate instance storage for an existing Amazon Connect instance.

        Access Level: Write

        Possible conditions:

        - .ifStorageResourceType()
        - .ifInstanceId()

        https://docs.aws.amazon.com/console/connect/amazon-connect-console/grant-instance-permissions

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toDisassociateInstanceStorageConfig", []))

    @jsii.member(jsii_name="toDisassociateLambdaFunction")
    def to_disassociate_lambda_function(self) -> "Connect":
        '''(experimental) Grants permission to disassociate a Lambda function for an existing Amazon Connect instance.

        Access Level: Write

        Possible conditions:

        - .ifInstanceId()

        Dependent actions:

        - lambda:RemovePermission

        https://docs.aws.amazon.com/console/connect/amazon-connect-console/grant-instance-permissions

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toDisassociateLambdaFunction", []))

    @jsii.member(jsii_name="toDisassociateLexBot")
    def to_disassociate_lex_bot(self) -> "Connect":
        '''(experimental) Grants permission to disassociate a Lex bot for an existing Amazon Connect instance.

        Access Level: Write

        Possible conditions:

        - .ifInstanceId()

        Dependent actions:

        - iam:AttachRolePolicy
        - iam:CreateServiceLinkedRole
        - iam:PutRolePolicy

        https://docs.aws.amazon.com/console/connect/amazon-connect-console/grant-instance-permissions

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toDisassociateLexBot", []))

    @jsii.member(jsii_name="toDisassociatePhoneNumberContactFlow")
    def to_disassociate_phone_number_contact_flow(self) -> "Connect":
        '''(experimental) Grants permission to disassociate contact flow resources from phone number resources in an Amazon Connect instance.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()
        - .ifInstanceId()

        https://docs.aws.amazon.com/connect/latest/APIReference/API_DisassociatePhoneNumberContactFlow.html

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toDisassociatePhoneNumberContactFlow", []))

    @jsii.member(jsii_name="toDisassociateQueueQuickConnects")
    def to_disassociate_queue_quick_connects(self) -> "Connect":
        '''(experimental) Grants permission to disassociate quick connects from a queue in an Amazon Connect instance.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()
        - .ifInstanceId()

        https://docs.aws.amazon.com/connect/latest/APIReference/API_DisassociateQueueQuickConnects.html

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toDisassociateQueueQuickConnects", []))

    @jsii.member(jsii_name="toDisassociateRoutingProfileQueues")
    def to_disassociate_routing_profile_queues(self) -> "Connect":
        '''(experimental) Grants permission to disassociate queues from a routing profile in an Amazon Connect instance.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()
        - .ifInstanceId()

        https://docs.aws.amazon.com/connect/latest/APIReference/API_DisassociateRoutingProfileQueues.html

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toDisassociateRoutingProfileQueues", []))

    @jsii.member(jsii_name="toDisassociateSecurityKey")
    def to_disassociate_security_key(self) -> "Connect":
        '''(experimental) Grants permission to disassociate the security key for an existing Amazon Connect instance.

        Access Level: Write

        Possible conditions:

        - .ifInstanceId()

        https://docs.aws.amazon.com/console/connect/amazon-connect-console/grant-instance-permissions

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toDisassociateSecurityKey", []))

    @jsii.member(jsii_name="toDismissUserContact")
    def to_dismiss_user_contact(self) -> "Connect":
        '''(experimental) Grants permission to dismiss terminated Contact from Agent CCP.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()
        - .ifInstanceId()

        https://docs.aws.amazon.com/connect/latest/APIReference/API_DismissUserContact.html

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toDismissUserContact", []))

    @jsii.member(jsii_name="toGetContactAttributes")
    def to_get_contact_attributes(self) -> "Connect":
        '''(experimental) Grants permission to retrieve the contact attributes for the specified contact.

        Access Level: Read

        Possible conditions:

        - .ifInstanceId()

        https://docs.aws.amazon.com/connect/latest/APIReference/API_GetContactAttributes.html

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toGetContactAttributes", []))

    @jsii.member(jsii_name="toGetCurrentMetricData")
    def to_get_current_metric_data(self) -> "Connect":
        '''(experimental) Grants permission to retrieve current metric data for the queues in an Amazon Connect instance.

        Access Level: Read

        Possible conditions:

        - .ifInstanceId()

        https://docs.aws.amazon.com/connect/latest/APIReference/API_GetCurrentMetricData.html

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toGetCurrentMetricData", []))

    @jsii.member(jsii_name="toGetCurrentUserData")
    def to_get_current_user_data(self) -> "Connect":
        '''(experimental) Grants permission to retrieve current user data in an Amazon Connect instance.

        Access Level: Read

        Possible conditions:

        - .ifInstanceId()

        https://docs.aws.amazon.com/connect/latest/APIReference/API_GetCurrentUserData.html

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toGetCurrentUserData", []))

    @jsii.member(jsii_name="toGetFederationToken")
    def to_get_federation_token(self) -> "Connect":
        '''(experimental) Grants permission to federate into an Amazon Connect instance when using SAML-based authentication for identity management.

        Access Level: Read

        Possible conditions:

        - .ifInstanceId()

        https://docs.aws.amazon.com/connect/latest/APIReference/API_GetFederationToken.html

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toGetFederationToken", []))

    @jsii.member(jsii_name="toGetFederationTokens")
    def to_get_federation_tokens(self) -> "Connect":
        '''(experimental) Grants permission to federate into an Amazon Connect instance (Log in for emergency access functionality in the Amazon Connect console).

        Access Level: Write

        Dependent actions:

        - connect:DescribeInstance
        - connect:ListInstances
        - ds:DescribeDirectories

        https://docs.aws.amazon.com/connect/latest/APIReference/emergency-admin-login.html

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toGetFederationTokens", []))

    @jsii.member(jsii_name="toGetMetricData")
    def to_get_metric_data(self) -> "Connect":
        '''(experimental) Grants permission to retrieve historical metric data for queues in an Amazon Connect instance.

        Access Level: Read

        Possible conditions:

        - .ifInstanceId()

        https://docs.aws.amazon.com/connect/latest/APIReference/API_GetMetricData.html

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toGetMetricData", []))

    @jsii.member(jsii_name="toGetTaskTemplate")
    def to_get_task_template(self) -> "Connect":
        '''(experimental) Grants permission to get details about specified task template in an Amazon Connect instance.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()
        - .ifInstanceId()

        https://docs.aws.amazon.com/connect/latest/APIReference/API_GetTaskTemplate.html

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toGetTaskTemplate", []))

    @jsii.member(jsii_name="toGetTrafficDistribution")
    def to_get_traffic_distribution(self) -> "Connect":
        '''(experimental) Grants permission to read traffic distribution for a traffic distribution group.

        Access Level: List

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/connect/latest/APIReference/API_GetTrafficDistribution.html

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toGetTrafficDistribution", []))

    @jsii.member(jsii_name="toListAgentStatuses")
    def to_list_agent_statuses(self) -> "Connect":
        '''(experimental) Grants permission to list agent statuses in an Amazon Connect instance.

        Access Level: List

        https://docs.aws.amazon.com/connect/latest/APIReference/API_ListAgentStatuses.html

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toListAgentStatuses", []))

    @jsii.member(jsii_name="toListApprovedOrigins")
    def to_list_approved_origins(self) -> "Connect":
        '''(experimental) Grants permission to view approved origins of an existing Amazon Connect instance.

        Access Level: List

        Possible conditions:

        - .ifInstanceId()

        https://docs.aws.amazon.com/console/connect/amazon-connect-console/grant-instance-permissions

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toListApprovedOrigins", []))

    @jsii.member(jsii_name="toListBots")
    def to_list_bots(self) -> "Connect":
        '''(experimental) Grants permission to view the Lex bots of an existing Amazon Connect instance.

        Access Level: List

        Possible conditions:

        - .ifInstanceId()

        https://docs.aws.amazon.com/console/connect/amazon-connect-console/grant-instance-permissions

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toListBots", []))

    @jsii.member(jsii_name="toListContactFlowModules")
    def to_list_contact_flow_modules(self) -> "Connect":
        '''(experimental) Grants permission to list contact flow module resources in an Amazon Connect instance.

        Access Level: List

        https://docs.aws.amazon.com/connect/latest/APIReference/API_ListContactFlowModules.html

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toListContactFlowModules", []))

    @jsii.member(jsii_name="toListContactFlows")
    def to_list_contact_flows(self) -> "Connect":
        '''(experimental) Grants permission to list contact flow resources in an Amazon Connect instance.

        Access Level: List

        https://docs.aws.amazon.com/connect/latest/APIReference/API_ListContactFlows.html

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toListContactFlows", []))

    @jsii.member(jsii_name="toListContactReferences")
    def to_list_contact_references(self) -> "Connect":
        '''(experimental) Grants permission to list references associated with a contact in an Amazon Connect instance.

        Access Level: List

        Possible conditions:

        - .ifInstanceId()

        https://docs.aws.amazon.com/connect/latest/APIReference/API_ListContactReferences.html

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toListContactReferences", []))

    @jsii.member(jsii_name="toListDefaultVocabularies")
    def to_list_default_vocabularies(self) -> "Connect":
        '''(experimental) Grants permission to list default vocabularies associated with a Amazon Connect instance.

        Access Level: List

        Possible conditions:

        - .ifInstanceId()

        https://docs.aws.amazon.com/connect/latest/APIReference/API_ListDefaultVocabularies.html

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toListDefaultVocabularies", []))

    @jsii.member(jsii_name="toListHoursOfOperations")
    def to_list_hours_of_operations(self) -> "Connect":
        '''(experimental) Grants permission to list hours of operation resources in an Amazon Connect instance.

        Access Level: List

        Possible conditions:

        - .ifInstanceId()

        https://docs.aws.amazon.com/connect/latest/APIReference/API_ListHoursOfOperations.html

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toListHoursOfOperations", []))

    @jsii.member(jsii_name="toListInstanceAttributes")
    def to_list_instance_attributes(self) -> "Connect":
        '''(experimental) Grants permission to view the attributes of an existing Amazon Connect instance.

        Access Level: List

        Possible conditions:

        - .ifInstanceId()

        https://docs.aws.amazon.com/console/connect/amazon-connect-console/grant-instance-permissions

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toListInstanceAttributes", []))

    @jsii.member(jsii_name="toListInstances")
    def to_list_instances(self) -> "Connect":
        '''(experimental) Grants permission to view the Amazon Connect instances associated with an AWS account.

        Access Level: List

        Dependent actions:

        - ds:DescribeDirectories

        https://docs.aws.amazon.com/console/connect/amazon-connect-console/grant-instance-permissions

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toListInstances", []))

    @jsii.member(jsii_name="toListInstanceStorageConfigs")
    def to_list_instance_storage_configs(self) -> "Connect":
        '''(experimental) Grants permission to view storage configurations of an existing Amazon Connect instance.

        Access Level: List

        Possible conditions:

        - .ifInstanceId()

        https://docs.aws.amazon.com/console/connect/amazon-connect-console/grant-instance-permissions

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toListInstanceStorageConfigs", []))

    @jsii.member(jsii_name="toListIntegrationAssociations")
    def to_list_integration_associations(self) -> "Connect":
        '''(experimental) Grants permission to list summary information about the integration associations for the specified Amazon Connect instance.

        Access Level: List

        Possible conditions:

        - .ifInstanceId()

        Dependent actions:

        - connect:DescribeInstance
        - ds:DescribeDirectories

        https://docs.aws.amazon.com/connect/latest/APIReference/API_ListIntegrationAssociations.html

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toListIntegrationAssociations", []))

    @jsii.member(jsii_name="toListLambdaFunctions")
    def to_list_lambda_functions(self) -> "Connect":
        '''(experimental) Grants permission to view the Lambda functions of an existing Amazon Connect instance.

        Access Level: List

        Possible conditions:

        - .ifInstanceId()

        https://docs.aws.amazon.com/console/connect/amazon-connect-console/grant-instance-permissions

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toListLambdaFunctions", []))

    @jsii.member(jsii_name="toListLexBots")
    def to_list_lex_bots(self) -> "Connect":
        '''(experimental) Grants permission to view the Lex bots of an existing Amazon Connect instance.

        Access Level: List

        Possible conditions:

        - .ifInstanceId()

        https://docs.aws.amazon.com/console/connect/amazon-connect-console/grant-instance-permissions

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toListLexBots", []))

    @jsii.member(jsii_name="toListPhoneNumbers")
    def to_list_phone_numbers(self) -> "Connect":
        '''(experimental) Grants permission to list phone number resources in an Amazon Connect instance.

        Access Level: List

        https://docs.aws.amazon.com/connect/latest/APIReference/API_ListPhoneNumbers.html

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toListPhoneNumbers", []))

    @jsii.member(jsii_name="toListPhoneNumbersV2")
    def to_list_phone_numbers_v2(self) -> "Connect":
        '''(experimental) Grants permission to list phone number resources in an Amazon Connect instance.

        Access Level: List

        https://docs.aws.amazon.com/connect/latest/APIReference/API_ListPhoneNumbersV2.html

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toListPhoneNumbersV2", []))

    @jsii.member(jsii_name="toListPrompts")
    def to_list_prompts(self) -> "Connect":
        '''(experimental) Grants permission to list prompt resources in an Amazon Connect instance.

        Access Level: List

        Possible conditions:

        - .ifInstanceId()

        https://docs.aws.amazon.com/connect/latest/APIReference/API_ListPrompts.html

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toListPrompts", []))

    @jsii.member(jsii_name="toListQueueQuickConnects")
    def to_list_queue_quick_connects(self) -> "Connect":
        '''(experimental) Grants permission to list quick connect resources in a queue in an Amazon Connect instance.

        Access Level: List

        Possible conditions:

        - .ifAwsResourceTag()
        - .ifInstanceId()

        https://docs.aws.amazon.com/connect/latest/APIReference/API_ListQueueQuickConnects.html

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toListQueueQuickConnects", []))

    @jsii.member(jsii_name="toListQueues")
    def to_list_queues(self) -> "Connect":
        '''(experimental) Grants permission to list queue resources in an Amazon Connect instance.

        Access Level: List

        https://docs.aws.amazon.com/connect/latest/APIReference/API_ListQueues.html

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toListQueues", []))

    @jsii.member(jsii_name="toListQuickConnects")
    def to_list_quick_connects(self) -> "Connect":
        '''(experimental) Grants permission to list quick connect resources in an Amazon Connect instance.

        Access Level: List

        https://docs.aws.amazon.com/connect/latest/APIReference/API_ListQuickConnects.html

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toListQuickConnects", []))

    @jsii.member(jsii_name="toListRealtimeContactAnalysisSegments")
    def to_list_realtime_contact_analysis_segments(self) -> "Connect":
        '''(experimental) Grants permission to list the analysis segments for a real-time analysis session.

        Access Level: Read

        https://docs.aws.amazon.com/contact-lens/latest/APIReference/API_ListRealtimeContactAnalysisSegments.html

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toListRealtimeContactAnalysisSegments", []))

    @jsii.member(jsii_name="toListRoutingProfileQueues")
    def to_list_routing_profile_queues(self) -> "Connect":
        '''(experimental) Grants permission to list queue resources in a routing profile in an Amazon Connect instance.

        Access Level: List

        Possible conditions:

        - .ifAwsResourceTag()
        - .ifInstanceId()

        https://docs.aws.amazon.com/connect/latest/APIReference/API_ListRoutingProfileQueues.html

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toListRoutingProfileQueues", []))

    @jsii.member(jsii_name="toListRoutingProfiles")
    def to_list_routing_profiles(self) -> "Connect":
        '''(experimental) Grants permission to list routing profile resources in an Amazon Connect instance.

        Access Level: List

        Possible conditions:

        - .ifInstanceId()

        https://docs.aws.amazon.com/connect/latest/APIReference/API_ListRoutingProfiles.html

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toListRoutingProfiles", []))

    @jsii.member(jsii_name="toListRule")
    def to_list_rule(self) -> "Connect":
        '''(experimental) Grants permission to list rules associated with a Amazon Connect instance.

        Access Level: List

        Possible conditions:

        - .ifInstanceId()

        https://docs.aws.amazon.com/connect/latest/APIReference/API_ListRules.html

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toListRule", []))

    @jsii.member(jsii_name="toListSecurityKeys")
    def to_list_security_keys(self) -> "Connect":
        '''(experimental) Grants permission to view the security keys of an existing Amazon Connect instance.

        Access Level: List

        Possible conditions:

        - .ifInstanceId()

        https://docs.aws.amazon.com/console/connect/amazon-connect-console/grant-instance-permissions

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toListSecurityKeys", []))

    @jsii.member(jsii_name="toListSecurityProfilePermissions")
    def to_list_security_profile_permissions(self) -> "Connect":
        '''(experimental) Grants permission to list permissions associated with security profile in an Amazon Connect instance.

        Access Level: List

        Possible conditions:

        - .ifAwsResourceTag()
        - .ifInstanceId()

        https://docs.aws.amazon.com/connect/latest/APIReference/API_ListSecurityProfilePermissions.html

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toListSecurityProfilePermissions", []))

    @jsii.member(jsii_name="toListSecurityProfiles")
    def to_list_security_profiles(self) -> "Connect":
        '''(experimental) Grants permission to list security profile resources in an Amazon Connect instance.

        Access Level: List

        Possible conditions:

        - .ifInstanceId()

        https://docs.aws.amazon.com/connect/latest/APIReference/API_ListSecurityProfiles.html

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toListSecurityProfiles", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Connect":
        '''(experimental) Grants permission to list tags for an Amazon Connect resource.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/connect/latest/APIReference/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toListTaskTemplates")
    def to_list_task_templates(self) -> "Connect":
        '''(experimental) Grants permission to list task template resources in an Amazon Connect instance.

        Access Level: List

        https://docs.aws.amazon.com/connect/latest/APIReference/API_ListTaskTemplates.html

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toListTaskTemplates", []))

    @jsii.member(jsii_name="toListTrafficDistributionGroups")
    def to_list_traffic_distribution_groups(self) -> "Connect":
        '''(experimental) Grants permission to list traffic distribution groups.

        Access Level: List

        https://docs.aws.amazon.com/connect/latest/APIReference/API_ListTrafficDistributionGroups.html

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toListTrafficDistributionGroups", []))

    @jsii.member(jsii_name="toListUseCases")
    def to_list_use_cases(self) -> "Connect":
        '''(experimental) Grants permission to list the use cases of an integration association.

        Access Level: List

        Possible conditions:

        - .ifInstanceId()

        Dependent actions:

        - connect:DescribeInstance
        - ds:DescribeDirectories

        https://docs.aws.amazon.com/connect/latest/APIReference/API_ListUseCases.html

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toListUseCases", []))

    @jsii.member(jsii_name="toListUserHierarchyGroups")
    def to_list_user_hierarchy_groups(self) -> "Connect":
        '''(experimental) Grants permission to list the hierarchy group resources in an Amazon Connect instance.

        Access Level: List

        Possible conditions:

        - .ifInstanceId()

        https://docs.aws.amazon.com/connect/latest/APIReference/API_ListUserHierarchyGroups.html

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toListUserHierarchyGroups", []))

    @jsii.member(jsii_name="toListUsers")
    def to_list_users(self) -> "Connect":
        '''(experimental) Grants permission to list user resources in an Amazon Connect instance.

        Access Level: List

        Possible conditions:

        - .ifInstanceId()

        https://docs.aws.amazon.com/connect/latest/APIReference/API_ListUsers.html

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toListUsers", []))

    @jsii.member(jsii_name="toMonitorContact")
    def to_monitor_contact(self) -> "Connect":
        '''(experimental) Grants permission to monitor an ongoing contact.

        Access Level: Write

        Possible conditions:

        - .ifMonitorCapabilities()
        - .ifAwsResourceTag()
        - .ifInstanceId()

        https://docs.aws.amazon.com/connect/latest/APIReference/API_MonitorContact.html

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toMonitorContact", []))

    @jsii.member(jsii_name="toPutUserStatus")
    def to_put_user_status(self) -> "Connect":
        '''(experimental) Grants permission to switch User Status in an Amazon Connect instance.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()
        - .ifInstanceId()

        https://docs.aws.amazon.com/connect/latest/APIReference/API_PutUserStatus.html

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toPutUserStatus", []))

    @jsii.member(jsii_name="toReleasePhoneNumber")
    def to_release_phone_number(self) -> "Connect":
        '''(experimental) Grants permission to release phone number resources in an Amazon Connect instance.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/connect/latest/APIReference/API_ReleasePhoneNumber.html

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toReleasePhoneNumber", []))

    @jsii.member(jsii_name="toReplicateInstance")
    def to_replicate_instance(self) -> "Connect":
        '''(experimental) Grants permission to create a replica of an Amazon Connect instance.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - ds:AuthorizeApplication
        - ds:CheckAlias
        - ds:CreateAlias
        - ds:CreateDirectory
        - ds:CreateIdentityPoolDirectory
        - ds:DeleteDirectory
        - ds:DescribeDirectories
        - ds:UnauthorizeApplication
        - iam:AttachRolePolicy
        - iam:CreateServiceLinkedRole
        - iam:PutRolePolicy

        https://docs.aws.amazon.com/console/connect/amazon-connect-console/grant-instance-permissions

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toReplicateInstance", []))

    @jsii.member(jsii_name="toResumeContactRecording")
    def to_resume_contact_recording(self) -> "Connect":
        '''(experimental) Grants permission to resume recording for the specified contact.

        Access Level: Write

        https://docs.aws.amazon.com/connect/latest/APIReference/API_ResumeContactRecording.html

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toResumeContactRecording", []))

    @jsii.member(jsii_name="toSearchAvailablePhoneNumbers")
    def to_search_available_phone_numbers(self) -> "Connect":
        '''(experimental) Grants permission to search phone number resources in an Amazon Connect instance or traffic distribution group.

        Access Level: List

        https://docs.aws.amazon.com/connect/latest/APIReference/API_SearchAvailablePhoneNumbers.html

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toSearchAvailablePhoneNumbers", []))

    @jsii.member(jsii_name="toSearchQueues")
    def to_search_queues(self) -> "Connect":
        '''(experimental) Grants permission to search queue resources in an Amazon Connect instance.

        Access Level: Read

        Possible conditions:

        - .ifInstanceId()
        - .ifSearchTag()

        Dependent actions:

        - connect:DescribeQueue

        https://docs.aws.amazon.com/connect/latest/APIReference/API_SearchQueues.html

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toSearchQueues", []))

    @jsii.member(jsii_name="toSearchRoutingProfiles")
    def to_search_routing_profiles(self) -> "Connect":
        '''(experimental) Grants permission to search routing profile resources in an Amazon Connect instance.

        Access Level: Read

        Possible conditions:

        - .ifInstanceId()
        - .ifSearchTag()

        Dependent actions:

        - connect:DescribeRoutingProfile

        https://docs.aws.amazon.com/connect/latest/APIReference/API_SearchRoutingProfiles.html

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toSearchRoutingProfiles", []))

    @jsii.member(jsii_name="toSearchSecurityProfiles")
    def to_search_security_profiles(self) -> "Connect":
        '''(experimental) Grants permission to search security profile resources in an Amazon Connect instance.

        Access Level: Read

        Possible conditions:

        - .ifInstanceId()
        - .ifSearchTag()

        Dependent actions:

        - connect:DescribeSecurityProfile

        https://docs.aws.amazon.com/connect/latest/APIReference/API_SearchSecurityProfiles.html

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toSearchSecurityProfiles", []))

    @jsii.member(jsii_name="toSearchUsers")
    def to_search_users(self) -> "Connect":
        '''(experimental) Grants permission to search user resources in an Amazon Connect instance.

        Access Level: Read

        Possible conditions:

        - .ifInstanceId()
        - .ifSearchTag()

        Dependent actions:

        - connect:DescribeUser

        https://docs.aws.amazon.com/connect/latest/APIReference/API_SearchUsers.html

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toSearchUsers", []))

    @jsii.member(jsii_name="toSearchVocabularies")
    def to_search_vocabularies(self) -> "Connect":
        '''(experimental) Grants permission to search vocabularies in a Amazon Connect instance.

        Access Level: List

        Possible conditions:

        - .ifInstanceId()

        https://docs.aws.amazon.com/connect/latest/APIReference/API_SearchVocabularies.html

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toSearchVocabularies", []))

    @jsii.member(jsii_name="toStartChatContact")
    def to_start_chat_contact(self) -> "Connect":
        '''(experimental) Grants permission to initiate a chat using the Amazon Connect API.

        Access Level: Write

        https://docs.aws.amazon.com/connect/latest/APIReference/API_StartChatContact.html

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toStartChatContact", []))

    @jsii.member(jsii_name="toStartContactRecording")
    def to_start_contact_recording(self) -> "Connect":
        '''(experimental) Grants permission to start recording for the specified contact.

        Access Level: Write

        https://docs.aws.amazon.com/connect/latest/APIReference/API_StartContactRecording.html

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toStartContactRecording", []))

    @jsii.member(jsii_name="toStartContactStreaming")
    def to_start_contact_streaming(self) -> "Connect":
        '''(experimental) Grants permission to start chat streaming using the Amazon Connect API.

        Access Level: Write

        https://docs.aws.amazon.com/connect/latest/APIReference/API_StartContactStreaming.html

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toStartContactStreaming", []))

    @jsii.member(jsii_name="toStartForecastingPlanningSchedulingIntegration")
    def to_start_forecasting_planning_scheduling_integration(self) -> "Connect":
        '''(experimental) Grants permission to enable forecasting, planning, and scheduling integration on an Amazon Connect instance.

        Access Level: Write

        Possible conditions:

        - .ifInstanceId()

        https://docs.aws.amazon.com/connect/latest/adminguide/optimization-apis.html

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toStartForecastingPlanningSchedulingIntegration", []))

    @jsii.member(jsii_name="toStartOutboundVoiceContact")
    def to_start_outbound_voice_contact(self) -> "Connect":
        '''(experimental) Grants permission to initiate outbound calls using the Amazon Connect API.

        Access Level: Write

        https://docs.aws.amazon.com/connect/latest/APIReference/API_StartOutboundVoiceContact.html

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toStartOutboundVoiceContact", []))

    @jsii.member(jsii_name="toStartTaskContact")
    def to_start_task_contact(self) -> "Connect":
        '''(experimental) Grants permission to initiate a task using the Amazon Connect API.

        Access Level: Write

        Possible conditions:

        - .ifInstanceId()

        https://docs.aws.amazon.com/connect/latest/APIReference/API_StartTaskContact.html

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toStartTaskContact", []))

    @jsii.member(jsii_name="toStopContact")
    def to_stop_contact(self) -> "Connect":
        '''(experimental) Grants permission to stop contacts that were initiated using the Amazon Connect API.

        If you use this operation on an active contact the contact ends, even if the agent is active on a call with a customer

        Access Level: Write

        Possible conditions:

        - .ifInstanceId()

        https://docs.aws.amazon.com/connect/latest/APIReference/API_StopContact.html

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toStopContact", []))

    @jsii.member(jsii_name="toStopContactRecording")
    def to_stop_contact_recording(self) -> "Connect":
        '''(experimental) Grants permission to stop recording for the specified contact.

        Access Level: Write

        https://docs.aws.amazon.com/connect/latest/APIReference/API_StopContactRecording.html

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toStopContactRecording", []))

    @jsii.member(jsii_name="toStopContactStreaming")
    def to_stop_contact_streaming(self) -> "Connect":
        '''(experimental) Grants permission to stop chat streaming using the Amazon Connect API.

        Access Level: Write

        https://docs.aws.amazon.com/connect/latest/APIReference/API_StopContactStreaming.html

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toStopContactStreaming", []))

    @jsii.member(jsii_name="toStopForecastingPlanningSchedulingIntegration")
    def to_stop_forecasting_planning_scheduling_integration(self) -> "Connect":
        '''(experimental) Grants permission to disable forecasting, planning, and scheduling integration on an Amazon Connect instance.

        Access Level: Write

        Possible conditions:

        - .ifInstanceId()

        https://docs.aws.amazon.com/connect/latest/adminguide/optimization-apis.html

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toStopForecastingPlanningSchedulingIntegration", []))

    @jsii.member(jsii_name="toSuspendContactRecording")
    def to_suspend_contact_recording(self) -> "Connect":
        '''(experimental) Grants permission to suspend recording for the specified contact.

        Access Level: Write

        https://docs.aws.amazon.com/connect/latest/APIReference/API_SuspendContactRecording.html

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toSuspendContactRecording", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Connect":
        '''(experimental) Grants permission to tag an Amazon Connect resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/connect/latest/APIReference/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toTransferContact")
    def to_transfer_contact(self) -> "Connect":
        '''(experimental) Grants permission to transfer the contact to another queue or agent.

        Access Level: Write

        Possible conditions:

        - .ifInstanceId()

        https://docs.aws.amazon.com/connect/latest/APIReference/API_TransferContact.html

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toTransferContact", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Connect":
        '''(experimental) Grants permission to untag an Amazon Connect resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/connect/latest/APIReference/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateAgentStatus")
    def to_update_agent_status(self) -> "Connect":
        '''(experimental) Grants permission to update agent status in an Amazon Connect instance.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()
        - .ifInstanceId()

        https://docs.aws.amazon.com/connect/latest/APIReference/API_UpdateAgentStatus.html

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toUpdateAgentStatus", []))

    @jsii.member(jsii_name="toUpdateContact")
    def to_update_contact(self) -> "Connect":
        '''(experimental) Grants permission to update a contact in an Amazon Connect instance.

        Access Level: Write

        Possible conditions:

        - .ifInstanceId()

        https://docs.aws.amazon.com/connect/latest/APIReference/API_UpdateContact.html

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toUpdateContact", []))

    @jsii.member(jsii_name="toUpdateContactAttributes")
    def to_update_contact_attributes(self) -> "Connect":
        '''(experimental) Grants permission to create or update the contact attributes associated with the specified contact.

        Access Level: Write

        Possible conditions:

        - .ifInstanceId()

        https://docs.aws.amazon.com/connect/latest/APIReference/API_UpdateContactAttributes.html

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toUpdateContactAttributes", []))

    @jsii.member(jsii_name="toUpdateContactFlowContent")
    def to_update_contact_flow_content(self) -> "Connect":
        '''(experimental) Grants permission to update contact flow content in an Amazon Connect instance.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()
        - .ifInstanceId()

        https://docs.aws.amazon.com/connect/latest/APIReference/API_UpdateContactFlowContent.html

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toUpdateContactFlowContent", []))

    @jsii.member(jsii_name="toUpdateContactFlowMetadata")
    def to_update_contact_flow_metadata(self) -> "Connect":
        '''(experimental) Grants permission to update the metadata of a contact flow in an Amazon Connect instance.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()
        - .ifInstanceId()

        https://docs.aws.amazon.com/connect/latest/APIReference/API_UpdateContactFlowMetadata.html

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toUpdateContactFlowMetadata", []))

    @jsii.member(jsii_name="toUpdateContactFlowModuleContent")
    def to_update_contact_flow_module_content(self) -> "Connect":
        '''(experimental) Grants permission to update contact flow module content in an Amazon Connect instance.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()
        - .ifInstanceId()

        https://docs.aws.amazon.com/connect/latest/APIReference/API_UpdateContactFlowModuleContent.html

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toUpdateContactFlowModuleContent", []))

    @jsii.member(jsii_name="toUpdateContactFlowModuleMetadata")
    def to_update_contact_flow_module_metadata(self) -> "Connect":
        '''(experimental) Grants permission to update the metadata of a contact flow module in an Amazon Connect instance.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()
        - .ifInstanceId()

        https://docs.aws.amazon.com/connect/latest/APIReference/API_UpdateContactFlowModuleMetadata.html

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toUpdateContactFlowModuleMetadata", []))

    @jsii.member(jsii_name="toUpdateContactFlowName")
    def to_update_contact_flow_name(self) -> "Connect":
        '''(experimental) Grants permission to update the name and description of a contact flow in an Amazon Connect instance.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()
        - .ifInstanceId()

        https://docs.aws.amazon.com/connect/latest/APIReference/API_UpdateContactFlowName.html

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toUpdateContactFlowName", []))

    @jsii.member(jsii_name="toUpdateContactSchedule")
    def to_update_contact_schedule(self) -> "Connect":
        '''(experimental) Grants permission to update the schedule of a contact that is already scheduled in an Amazon Connect instance.

        Access Level: Write

        Possible conditions:

        - .ifInstanceId()

        https://docs.aws.amazon.com/connect/latest/APIReference/API_UpdateContactSchedule.html

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toUpdateContactSchedule", []))

    @jsii.member(jsii_name="toUpdatedescribeContent")
    def to_updatedescribe_content(self) -> "Connect":
        '''(experimental) Grants permission to update contact flow module content in an Amazon Connect instance.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()
        - .ifInstanceId()

        https://docs.aws.amazon.com/connect/latest/APIReference/API_UpdatedescribeContent.html

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toUpdatedescribeContent", []))

    @jsii.member(jsii_name="toUpdateHoursOfOperation")
    def to_update_hours_of_operation(self) -> "Connect":
        '''(experimental) Grants permission to update hours of operation in an Amazon Connect instance.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()
        - .ifInstanceId()

        https://docs.aws.amazon.com/connect/latest/APIReference/API_UpdateHoursOfOperation.html

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toUpdateHoursOfOperation", []))

    @jsii.member(jsii_name="toUpdateInstanceAttribute")
    def to_update_instance_attribute(self) -> "Connect":
        '''(experimental) Grants permission to update the attribute for an existing Amazon Connect instance.

        Access Level: Write

        Possible conditions:

        - .ifAttributeType()
        - .ifInstanceId()

        Dependent actions:

        - ds:DescribeDirectories
        - iam:AttachRolePolicy
        - iam:CreateServiceLinkedRole
        - iam:PutRolePolicy
        - logs:CreateLogGroup

        https://docs.aws.amazon.com/console/connect/amazon-connect-console/grant-instance-permissions

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toUpdateInstanceAttribute", []))

    @jsii.member(jsii_name="toUpdateInstanceStorageConfig")
    def to_update_instance_storage_config(self) -> "Connect":
        '''(experimental) Grants permission to update the storage configuration for an existing Amazon Connect instance.

        Access Level: Write

        Possible conditions:

        - .ifStorageResourceType()
        - .ifInstanceId()

        Dependent actions:

        - ds:DescribeDirectories
        - firehose:DescribeDeliveryStream
        - iam:AttachRolePolicy
        - iam:CreateServiceLinkedRole
        - iam:PutRolePolicy
        - kinesis:DescribeStream
        - kms:CreateGrant
        - kms:DescribeKey
        - s3:GetBucketAcl
        - s3:GetBucketLocation

        https://docs.aws.amazon.com/console/connect/amazon-connect-console/grant-instance-permissions

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toUpdateInstanceStorageConfig", []))

    @jsii.member(jsii_name="toUpdatePhoneNumber")
    def to_update_phone_number(self) -> "Connect":
        '''(experimental) Grants permission to update phone number resources in an Amazon Connect instance or traffic distribution group.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/connect/latest/APIReference/API_UpdatePhoneNumber.html

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toUpdatePhoneNumber", []))

    @jsii.member(jsii_name="toUpdateQueueHoursOfOperation")
    def to_update_queue_hours_of_operation(self) -> "Connect":
        '''(experimental) Grants permission to update queue hours of operation in an Amazon Connect instance.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()
        - .ifInstanceId()

        https://docs.aws.amazon.com/connect/latest/APIReference/API_UpdateQueueHoursOfOperation.html

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toUpdateQueueHoursOfOperation", []))

    @jsii.member(jsii_name="toUpdateQueueMaxContacts")
    def to_update_queue_max_contacts(self) -> "Connect":
        '''(experimental) Grants permission to update queue capacity in an Amazon Connect instance.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()
        - .ifInstanceId()

        https://docs.aws.amazon.com/connect/latest/APIReference/API_UpdateQueueMaxContacts.html

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toUpdateQueueMaxContacts", []))

    @jsii.member(jsii_name="toUpdateQueueName")
    def to_update_queue_name(self) -> "Connect":
        '''(experimental) Grants permission to update a queue name and description in an Amazon Connect instance.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()
        - .ifInstanceId()

        https://docs.aws.amazon.com/connect/latest/APIReference/API_UpdateQueueName.html

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toUpdateQueueName", []))

    @jsii.member(jsii_name="toUpdateQueueOutboundCallerConfig")
    def to_update_queue_outbound_caller_config(self) -> "Connect":
        '''(experimental) Grants permission to update queue outbound caller config in an Amazon Connect instance.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()
        - .ifInstanceId()

        https://docs.aws.amazon.com/connect/latest/APIReference/API_UpdateQueueOutboundCallerConfig.html

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toUpdateQueueOutboundCallerConfig", []))

    @jsii.member(jsii_name="toUpdateQueueStatus")
    def to_update_queue_status(self) -> "Connect":
        '''(experimental) Grants permission to update queue status in an Amazon Connect instance.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()
        - .ifInstanceId()

        https://docs.aws.amazon.com/connect/latest/APIReference/API_UpdateQueueStatus.html

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toUpdateQueueStatus", []))

    @jsii.member(jsii_name="toUpdateQuickConnectConfig")
    def to_update_quick_connect_config(self) -> "Connect":
        '''(experimental) Grants permission to update the configuration of a quick connect in an Amazon Connect instance.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()
        - .ifInstanceId()

        https://docs.aws.amazon.com/connect/latest/APIReference/API_UpdateQuickConnectConfig.html

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toUpdateQuickConnectConfig", []))

    @jsii.member(jsii_name="toUpdateQuickConnectName")
    def to_update_quick_connect_name(self) -> "Connect":
        '''(experimental) Grants permission to update a quick connect name and description in an Amazon Connect instance.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()
        - .ifInstanceId()

        https://docs.aws.amazon.com/connect/latest/APIReference/API_UpdateQuickConnectName.html

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toUpdateQuickConnectName", []))

    @jsii.member(jsii_name="toUpdateRoutingProfileConcurrency")
    def to_update_routing_profile_concurrency(self) -> "Connect":
        '''(experimental) Grants permission to update the concurrency in a routing profile in an Amazon Connect instance.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()
        - .ifInstanceId()

        https://docs.aws.amazon.com/connect/latest/APIReference/API_UpdateRoutingProfileConcurrency.html

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toUpdateRoutingProfileConcurrency", []))

    @jsii.member(jsii_name="toUpdateRoutingProfileDefaultOutboundQueue")
    def to_update_routing_profile_default_outbound_queue(self) -> "Connect":
        '''(experimental) Grants permission to update the outbound queue in a routing profile in an Amazon Connect instance.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()
        - .ifInstanceId()

        https://docs.aws.amazon.com/connect/latest/APIReference/API_UpdateRoutingProfileDefaultOutboundQueue.html

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toUpdateRoutingProfileDefaultOutboundQueue", []))

    @jsii.member(jsii_name="toUpdateRoutingProfileName")
    def to_update_routing_profile_name(self) -> "Connect":
        '''(experimental) Grants permission to update a routing profile name and description in an Amazon Connect instance.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()
        - .ifInstanceId()

        https://docs.aws.amazon.com/connect/latest/APIReference/API_UpdateRoutingProfileName.html

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toUpdateRoutingProfileName", []))

    @jsii.member(jsii_name="toUpdateRoutingProfileQueues")
    def to_update_routing_profile_queues(self) -> "Connect":
        '''(experimental) Grants permission to update the queues in routing profile in an Amazon Connect instance.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()
        - .ifInstanceId()

        https://docs.aws.amazon.com/connect/latest/APIReference/API_UpdateRoutingProfileQueues.html

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toUpdateRoutingProfileQueues", []))

    @jsii.member(jsii_name="toUpdateRule")
    def to_update_rule(self) -> "Connect":
        '''(experimental) Grants permission to update a rule for an existing Amazon Connect instance.

        Access Level: Write

        Possible conditions:

        - .ifInstanceId()

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toUpdateRule", []))

    @jsii.member(jsii_name="toUpdateSecurityProfile")
    def to_update_security_profile(self) -> "Connect":
        '''(experimental) Grants permission to update a security profile group for a user in an Amazon Connect instance.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()
        - .ifInstanceId()

        https://docs.aws.amazon.com/connect/latest/APIReference/API_UpdateSecurityProfile.html

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toUpdateSecurityProfile", []))

    @jsii.member(jsii_name="toUpdateTaskTemplate")
    def to_update_task_template(self) -> "Connect":
        '''(experimental) Grants permission to update task template belonging to a Amazon Connect instance.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()
        - .ifInstanceId()

        https://docs.aws.amazon.com/connect/latest/APIReference/API_UpdateTaskTemplate.html

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toUpdateTaskTemplate", []))

    @jsii.member(jsii_name="toUpdateTrafficDistribution")
    def to_update_traffic_distribution(self) -> "Connect":
        '''(experimental) Grants permission to update traffic distribution for a traffic distribution group.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/connect/latest/APIReference/API_UpdateTrafficDistribution.html

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toUpdateTrafficDistribution", []))

    @jsii.member(jsii_name="toUpdateUserHierarchy")
    def to_update_user_hierarchy(self) -> "Connect":
        '''(experimental) Grants permission to update a hierarchy group for a user in an Amazon Connect instance.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()
        - .ifInstanceId()

        https://docs.aws.amazon.com/connect/latest/APIReference/API_UpdateUserHierarchy.html

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toUpdateUserHierarchy", []))

    @jsii.member(jsii_name="toUpdateUserHierarchyGroupName")
    def to_update_user_hierarchy_group_name(self) -> "Connect":
        '''(experimental) Grants permission to update a user hierarchy group name in an Amazon Connect instance.

        Access Level: Write

        Possible conditions:

        - .ifInstanceId()

        https://docs.aws.amazon.com/connect/latest/APIReference/API_UpdateUserHierarchyGroupName.html

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toUpdateUserHierarchyGroupName", []))

    @jsii.member(jsii_name="toUpdateUserHierarchyStructure")
    def to_update_user_hierarchy_structure(self) -> "Connect":
        '''(experimental) Grants permission to update user hierarchy structure in an Amazon Connect instance.

        Access Level: Write

        Possible conditions:

        - .ifInstanceId()

        https://docs.aws.amazon.com/connect/latest/APIReference/API_UpdateUserHierarchyStructure.html

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toUpdateUserHierarchyStructure", []))

    @jsii.member(jsii_name="toUpdateUserIdentityInfo")
    def to_update_user_identity_info(self) -> "Connect":
        '''(experimental) Grants permission to update identity information for a user in an Amazon Connect instance.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()
        - .ifInstanceId()

        https://docs.aws.amazon.com/connect/latest/APIReference/API_UpdateUserIdentityInfo.html

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toUpdateUserIdentityInfo", []))

    @jsii.member(jsii_name="toUpdateUserPhoneConfig")
    def to_update_user_phone_config(self) -> "Connect":
        '''(experimental) Grants permission to update phone configuration settings for a user in an Amazon Connect instance.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()
        - .ifInstanceId()

        https://docs.aws.amazon.com/connect/latest/APIReference/API_UpdateUserPhoneConfig.html

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toUpdateUserPhoneConfig", []))

    @jsii.member(jsii_name="toUpdateUserRoutingProfile")
    def to_update_user_routing_profile(self) -> "Connect":
        '''(experimental) Grants permission to update a routing profile for a user in an Amazon Connect instance.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()
        - .ifInstanceId()

        https://docs.aws.amazon.com/connect/latest/APIReference/API_UpdateUserRoutingProfile.html

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toUpdateUserRoutingProfile", []))

    @jsii.member(jsii_name="toUpdateUserSecurityProfiles")
    def to_update_user_security_profiles(self) -> "Connect":
        '''(experimental) Grants permission to update security profiles for a user in an Amazon Connect instance.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()
        - .ifInstanceId()

        https://docs.aws.amazon.com/connect/latest/APIReference/API_UpdateUserSecurityProfiles.html

        :stability: experimental
        '''
        return typing.cast("Connect", jsii.invoke(self, "toUpdateUserSecurityProfiles", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5d17653bb18d9ea73eef210150a2c7778f0c6f9f79e89551a53a430bf0363fc1)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__86d5500ff6d2851e435169e686660b061243ac70bf45b9ab405a424fca61fbca)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class ConnectCampaigns(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.ConnectCampaigns",
):
    '''(experimental) Statement provider for service `connect-campaigns <https://docs.aws.amazon.com/service-authorization/latest/reference/list_high-volumeoutboundcommunications.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `connect-campaigns <https://docs.aws.amazon.com/service-authorization/latest/reference/list_high-volumeoutboundcommunications.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onCampaign")
    def on_campaign(
        self,
        campaign_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "ConnectCampaigns":
        '''(experimental) Adds a resource of type campaign to the statement.

        https://docs.aws.amazon.com/connect/latest/adminguide/enable-high-volume-outbound-communications.html

        :param campaign_id: - Identifier for the campaignId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6abf64ddf0e73bcaa240571e030297c519c0350e41c6187ff3d2ac152318ba50)
            check_type(argname="argument campaign_id", value=campaign_id, expected_type=type_hints["campaign_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("ConnectCampaigns", jsii.invoke(self, "onCampaign", [campaign_id, account, region, partition]))

    @jsii.member(jsii_name="toCreateCampaign")
    def to_create_campaign(self) -> "ConnectCampaigns":
        '''(experimental) Grants permission to create a campaign.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/connect/latest/adminguide/enable-high-volume-outbound-communications.html

        :stability: experimental
        '''
        return typing.cast("ConnectCampaigns", jsii.invoke(self, "toCreateCampaign", []))

    @jsii.member(jsii_name="toDeleteCampaign")
    def to_delete_campaign(self) -> "ConnectCampaigns":
        '''(experimental) Grants permission to delete a campaign.

        Access Level: Write

        https://docs.aws.amazon.com/connect/latest/adminguide/enable-high-volume-outbound-communications.html

        :stability: experimental
        '''
        return typing.cast("ConnectCampaigns", jsii.invoke(self, "toDeleteCampaign", []))

    @jsii.member(jsii_name="toDeleteConnectInstanceConfig")
    def to_delete_connect_instance_config(self) -> "ConnectCampaigns":
        '''(experimental) Grants permission to remove configuration information for an Amazon Connect instance.

        Access Level: Write

        https://docs.aws.amazon.com/connect/latest/adminguide/enable-high-volume-outbound-communications.html

        :stability: experimental
        '''
        return typing.cast("ConnectCampaigns", jsii.invoke(self, "toDeleteConnectInstanceConfig", []))

    @jsii.member(jsii_name="toDeleteInstanceOnboardingJob")
    def to_delete_instance_onboarding_job(self) -> "ConnectCampaigns":
        '''(experimental) Grants permission to remove onboarding job for an Amazon Connect instance.

        Access Level: Write

        https://docs.aws.amazon.com/connect/latest/adminguide/enable-high-volume-outbound-communications.html

        :stability: experimental
        '''
        return typing.cast("ConnectCampaigns", jsii.invoke(self, "toDeleteInstanceOnboardingJob", []))

    @jsii.member(jsii_name="toDescribeCampaign")
    def to_describe_campaign(self) -> "ConnectCampaigns":
        '''(experimental) Grants permission to describe a specific campaign.

        Access Level: Read

        Possible conditions:

        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/connect/latest/adminguide/enable-high-volume-outbound-communications.html

        :stability: experimental
        '''
        return typing.cast("ConnectCampaigns", jsii.invoke(self, "toDescribeCampaign", []))

    @jsii.member(jsii_name="toGetCampaignState")
    def to_get_campaign_state(self) -> "ConnectCampaigns":
        '''(experimental) Grants permission to get state of a campaign.

        Access Level: Read

        Possible conditions:

        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/connect/latest/adminguide/enable-high-volume-outbound-communications.html

        :stability: experimental
        '''
        return typing.cast("ConnectCampaigns", jsii.invoke(self, "toGetCampaignState", []))

    @jsii.member(jsii_name="toGetCampaignStateBatch")
    def to_get_campaign_state_batch(self) -> "ConnectCampaigns":
        '''(experimental) Grants permission to get state of campaigns.

        Access Level: Read

        Possible conditions:

        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/connect/latest/adminguide/enable-high-volume-outbound-communications.html

        :stability: experimental
        '''
        return typing.cast("ConnectCampaigns", jsii.invoke(self, "toGetCampaignStateBatch", []))

    @jsii.member(jsii_name="toGetConnectInstanceConfig")
    def to_get_connect_instance_config(self) -> "ConnectCampaigns":
        '''(experimental) Grants permission to get configuration information for an Amazon Connect instance.

        Access Level: Read

        https://docs.aws.amazon.com/connect/latest/adminguide/enable-high-volume-outbound-communications.html

        :stability: experimental
        '''
        return typing.cast("ConnectCampaigns", jsii.invoke(self, "toGetConnectInstanceConfig", []))

    @jsii.member(jsii_name="toGetInstanceOnboardingJobStatus")
    def to_get_instance_onboarding_job_status(self) -> "ConnectCampaigns":
        '''(experimental) Grants permission to get onboarding job status for an Amazon Connect instance.

        Access Level: Read

        https://docs.aws.amazon.com/connect/latest/adminguide/enable-high-volume-outbound-communications.html

        :stability: experimental
        '''
        return typing.cast("ConnectCampaigns", jsii.invoke(self, "toGetInstanceOnboardingJobStatus", []))

    @jsii.member(jsii_name="toListCampaigns")
    def to_list_campaigns(self) -> "ConnectCampaigns":
        '''(experimental) Grants permission to provide summary of all campaigns.

        Access Level: List

        Possible conditions:

        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/connect/latest/adminguide/enable-high-volume-outbound-communications.html

        :stability: experimental
        '''
        return typing.cast("ConnectCampaigns", jsii.invoke(self, "toListCampaigns", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "ConnectCampaigns":
        '''(experimental) Grants permission to list tags for a resource.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/connect/latest/adminguide/enable-high-volume-outbound-communications.html

        :stability: experimental
        '''
        return typing.cast("ConnectCampaigns", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toPauseCampaign")
    def to_pause_campaign(self) -> "ConnectCampaigns":
        '''(experimental) Grants permission to pause a campaign.

        Access Level: Write

        https://docs.aws.amazon.com/connect/latest/adminguide/enable-high-volume-outbound-communications.html

        :stability: experimental
        '''
        return typing.cast("ConnectCampaigns", jsii.invoke(self, "toPauseCampaign", []))

    @jsii.member(jsii_name="toPutDialRequestBatch")
    def to_put_dial_request_batch(self) -> "ConnectCampaigns":
        '''(experimental) Grants permission to create dial requests for the specified campaign.

        Access Level: Write

        https://docs.aws.amazon.com/connect/latest/adminguide/enable-high-volume-outbound-communications.html

        :stability: experimental
        '''
        return typing.cast("ConnectCampaigns", jsii.invoke(self, "toPutDialRequestBatch", []))

    @jsii.member(jsii_name="toResumeCampaign")
    def to_resume_campaign(self) -> "ConnectCampaigns":
        '''(experimental) Grants permission to resume a campaign.

        Access Level: Write

        https://docs.aws.amazon.com/connect/latest/adminguide/enable-high-volume-outbound-communications.html

        :stability: experimental
        '''
        return typing.cast("ConnectCampaigns", jsii.invoke(self, "toResumeCampaign", []))

    @jsii.member(jsii_name="toStartCampaign")
    def to_start_campaign(self) -> "ConnectCampaigns":
        '''(experimental) Grants permission to start a campaign.

        Access Level: Write

        https://docs.aws.amazon.com/connect/latest/adminguide/enable-high-volume-outbound-communications.html

        :stability: experimental
        '''
        return typing.cast("ConnectCampaigns", jsii.invoke(self, "toStartCampaign", []))

    @jsii.member(jsii_name="toStartInstanceOnboardingJob")
    def to_start_instance_onboarding_job(self) -> "ConnectCampaigns":
        '''(experimental) Grants permission to start onboarding job for an Amazon Connect instance.

        Access Level: Write

        https://docs.aws.amazon.com/connect/latest/adminguide/enable-high-volume-outbound-communications.html

        :stability: experimental
        '''
        return typing.cast("ConnectCampaigns", jsii.invoke(self, "toStartInstanceOnboardingJob", []))

    @jsii.member(jsii_name="toStopCampaign")
    def to_stop_campaign(self) -> "ConnectCampaigns":
        '''(experimental) Grants permission to stop a campaign.

        Access Level: Write

        https://docs.aws.amazon.com/connect/latest/adminguide/enable-high-volume-outbound-communications.html

        :stability: experimental
        '''
        return typing.cast("ConnectCampaigns", jsii.invoke(self, "toStopCampaign", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "ConnectCampaigns":
        '''(experimental) Grants permission to tag a resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/connect/latest/adminguide/enable-high-volume-outbound-communications.html

        :stability: experimental
        '''
        return typing.cast("ConnectCampaigns", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "ConnectCampaigns":
        '''(experimental) Grants permission to untag a resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/connect/latest/adminguide/enable-high-volume-outbound-communications.html

        :stability: experimental
        '''
        return typing.cast("ConnectCampaigns", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateCampaignDialerConfig")
    def to_update_campaign_dialer_config(self) -> "ConnectCampaigns":
        '''(experimental) Grants permission to update the dialer configuration of a campaign.

        Access Level: Write

        https://docs.aws.amazon.com/connect/latest/adminguide/enable-high-volume-outbound-communications.html

        :stability: experimental
        '''
        return typing.cast("ConnectCampaigns", jsii.invoke(self, "toUpdateCampaignDialerConfig", []))

    @jsii.member(jsii_name="toUpdateCampaignName")
    def to_update_campaign_name(self) -> "ConnectCampaigns":
        '''(experimental) Grants permission to update the name of a campaign.

        Access Level: Write

        https://docs.aws.amazon.com/connect/latest/adminguide/enable-high-volume-outbound-communications.html

        :stability: experimental
        '''
        return typing.cast("ConnectCampaigns", jsii.invoke(self, "toUpdateCampaignName", []))

    @jsii.member(jsii_name="toUpdateCampaignOutboundCallConfig")
    def to_update_campaign_outbound_call_config(self) -> "ConnectCampaigns":
        '''(experimental) Grants permission to update the outbound call configuration of a campaign.

        Access Level: Write

        https://docs.aws.amazon.com/connect/latest/adminguide/enable-high-volume-outbound-communications.html

        :stability: experimental
        '''
        return typing.cast("ConnectCampaigns", jsii.invoke(self, "toUpdateCampaignOutboundCallConfig", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6aea7dacca7f6cf9a6ea1656004c7b5781d45c2e7a7496acecec103aee1fa6db)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__427d4fa8ba5249ffc58c048fbf2b47a44197a68d921745c71f10f9a58bbb6e4d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Controltower(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Controltower",
):
    '''(experimental) Statement provider for service `controltower <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awscontroltower.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `controltower <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awscontroltower.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="toCreateManagedAccount")
    def to_create_managed_account(self) -> "Controltower":
        '''(experimental) Grants permission to create an account managed by AWS Control Tower.

        Access Level: Write

        https://docs.aws.amazon.com/controltower/latest/userguide/account-factory.html

        :stability: experimental
        '''
        return typing.cast("Controltower", jsii.invoke(self, "toCreateManagedAccount", []))

    @jsii.member(jsii_name="toDeregisterManagedAccount")
    def to_deregister_managed_account(self) -> "Controltower":
        '''(experimental) Grants permission to deregister an account created through the account factory from AWS Control Tower.

        Access Level: Write

        https://docs.aws.amazon.com/controltower/latest/userguide/account-factory.html

        :stability: experimental
        '''
        return typing.cast("Controltower", jsii.invoke(self, "toDeregisterManagedAccount", []))

    @jsii.member(jsii_name="toDeregisterOrganizationalUnit")
    def to_deregister_organizational_unit(self) -> "Controltower":
        '''(experimental) Grants permission to deregister an organizational unit from AWS Control Tower management.

        Access Level: Write

        https://docs.aws.amazon.com/controltower/latest/userguide/organizations.html

        :stability: experimental
        '''
        return typing.cast("Controltower", jsii.invoke(self, "toDeregisterOrganizationalUnit", []))

    @jsii.member(jsii_name="toDescribeAccountFactoryConfig")
    def to_describe_account_factory_config(self) -> "Controltower":
        '''(experimental) Grants permission to describe the current account factory configuration.

        Access Level: Read

        https://docs.aws.amazon.com/controltower/latest/userguide/account-factory.html

        :stability: experimental
        '''
        return typing.cast("Controltower", jsii.invoke(self, "toDescribeAccountFactoryConfig", []))

    @jsii.member(jsii_name="toDescribeCoreService")
    def to_describe_core_service(self) -> "Controltower":
        '''(experimental) Grants permission to describe resources managed by core accounts in AWS Control Tower.

        Access Level: Read

        https://docs.aws.amazon.com/controltower/latest/userguide/how-control-tower-works.html#what-shared

        :stability: experimental
        '''
        return typing.cast("Controltower", jsii.invoke(self, "toDescribeCoreService", []))

    @jsii.member(jsii_name="toDescribeGuardrail")
    def to_describe_guardrail(self) -> "Controltower":
        '''(experimental) Grants permission to describe a guardrail.

        Access Level: Read

        https://docs.aws.amazon.com/controltower/latest/userguide/guardrails.html

        :stability: experimental
        '''
        return typing.cast("Controltower", jsii.invoke(self, "toDescribeGuardrail", []))

    @jsii.member(jsii_name="toDescribeGuardrailForTarget")
    def to_describe_guardrail_for_target(self) -> "Controltower":
        '''(experimental) Grants permission to describe a guardrail for a organizational unit.

        Access Level: Read

        https://docs.aws.amazon.com/controltower/latest/userguide/guardrails.html

        :stability: experimental
        '''
        return typing.cast("Controltower", jsii.invoke(self, "toDescribeGuardrailForTarget", []))

    @jsii.member(jsii_name="toDescribeManagedAccount")
    def to_describe_managed_account(self) -> "Controltower":
        '''(experimental) Grants permission to describe an account created through account factory.

        Access Level: Read

        https://docs.aws.amazon.com/controltower/latest/userguide/account-factory.html

        :stability: experimental
        '''
        return typing.cast("Controltower", jsii.invoke(self, "toDescribeManagedAccount", []))

    @jsii.member(jsii_name="toDescribeManagedOrganizationalUnit")
    def to_describe_managed_organizational_unit(self) -> "Controltower":
        '''(experimental) Grants permission to describe an AWS Organizations organizational unit managed by AWS Control Tower.

        Access Level: Read

        https://docs.aws.amazon.com/controltower/latest/userguide/organizations.html

        :stability: experimental
        '''
        return typing.cast("Controltower", jsii.invoke(self, "toDescribeManagedOrganizationalUnit", []))

    @jsii.member(jsii_name="toDescribeSingleSignOn")
    def to_describe_single_sign_on(self) -> "Controltower":
        '''(experimental) Grants permission to describe the current AWS Control Tower SSO configuration.

        Access Level: Read

        https://docs.aws.amazon.com/controltower/latest/userguide/sso.html

        :stability: experimental
        '''
        return typing.cast("Controltower", jsii.invoke(self, "toDescribeSingleSignOn", []))

    @jsii.member(jsii_name="toDisableControl")
    def to_disable_control(self) -> "Controltower":
        '''(experimental) Grants permission to remove a control from an organizational unit.

        Access Level: Write

        https://docs.aws.amazon.com/controltower/latest/APIReference/API_DisableControl.html

        :stability: experimental
        '''
        return typing.cast("Controltower", jsii.invoke(self, "toDisableControl", []))

    @jsii.member(jsii_name="toDisableGuardrail")
    def to_disable_guardrail(self) -> "Controltower":
        '''(experimental) Grants permission to disable a guardrail from an organizational unit.

        Access Level: Write

        https://docs.aws.amazon.com/controltower/latest/userguide/guardrails.html#enable-guardrails

        :stability: experimental
        '''
        return typing.cast("Controltower", jsii.invoke(self, "toDisableGuardrail", []))

    @jsii.member(jsii_name="toEnableControl")
    def to_enable_control(self) -> "Controltower":
        '''(experimental) Grants permission to activate a control for an organizational unit.

        Access Level: Write

        https://docs.aws.amazon.com/controltower/latest/APIReference/API_EnableControl.html

        :stability: experimental
        '''
        return typing.cast("Controltower", jsii.invoke(self, "toEnableControl", []))

    @jsii.member(jsii_name="toEnableGuardrail")
    def to_enable_guardrail(self) -> "Controltower":
        '''(experimental) Grants permission to enable a guardrail to an organizational unit.

        Access Level: Write

        https://docs.aws.amazon.com/controltower/latest/userguide/guardrails.html#enable-guardrails

        :stability: experimental
        '''
        return typing.cast("Controltower", jsii.invoke(self, "toEnableGuardrail", []))

    @jsii.member(jsii_name="toGetAvailableUpdates")
    def to_get_available_updates(self) -> "Controltower":
        '''(experimental) Grants permission to list available updates for the current AWS Control Tower deployment.

        Access Level: Read

        https://docs.aws.amazon.com/controltower/latest/userguide/configuration-updates.html

        :stability: experimental
        '''
        return typing.cast("Controltower", jsii.invoke(self, "toGetAvailableUpdates", []))

    @jsii.member(jsii_name="toGetControlOperation")
    def to_get_control_operation(self) -> "Controltower":
        '''(experimental) Grants permission to get the current status of a particular EnabledControl or DisableControl operation.

        Access Level: Read

        https://docs.aws.amazon.com/controltower/latest/APIReference/API_GetControlOperation.html

        :stability: experimental
        '''
        return typing.cast("Controltower", jsii.invoke(self, "toGetControlOperation", []))

    @jsii.member(jsii_name="toGetGuardrailComplianceStatus")
    def to_get_guardrail_compliance_status(self) -> "Controltower":
        '''(experimental) Grants permission to get the current compliance status of a guardrail.

        Access Level: Read

        https://docs.aws.amazon.com/controltower/latest/userguide/guardrails.html

        :stability: experimental
        '''
        return typing.cast("Controltower", jsii.invoke(self, "toGetGuardrailComplianceStatus", []))

    @jsii.member(jsii_name="toGetHomeRegion")
    def to_get_home_region(self) -> "Controltower":
        '''(experimental) Grants permission to get the home region of the AWS Control Tower setup.

        Access Level: Read

        https://docs.aws.amazon.com/controltower/latest/userguide/how-control-tower-works.html#region-how

        :stability: experimental
        '''
        return typing.cast("Controltower", jsii.invoke(self, "toGetHomeRegion", []))

    @jsii.member(jsii_name="toGetLandingZoneStatus")
    def to_get_landing_zone_status(self) -> "Controltower":
        '''(experimental) Grants permission to get the current status of the landing zone setup.

        Access Level: Read

        https://docs.aws.amazon.com/controltower/latest/userguide/getting-started-with-control-tower.html#step-two

        :stability: experimental
        '''
        return typing.cast("Controltower", jsii.invoke(self, "toGetLandingZoneStatus", []))

    @jsii.member(jsii_name="toListDirectoryGroups")
    def to_list_directory_groups(self) -> "Controltower":
        '''(experimental) Grants permission to list the current directory groups available through SSO.

        Access Level: List

        https://docs.aws.amazon.com/controltower/latest/userguide/sso.html

        :stability: experimental
        '''
        return typing.cast("Controltower", jsii.invoke(self, "toListDirectoryGroups", []))

    @jsii.member(jsii_name="toListEnabledControls")
    def to_list_enabled_controls(self) -> "Controltower":
        '''(experimental) Grants permission to list all enabled controls in a specified organizational unit.

        Access Level: List

        https://docs.aws.amazon.com/controltower/latest/APIReference/API_ListEnabledControls.html

        :stability: experimental
        '''
        return typing.cast("Controltower", jsii.invoke(self, "toListEnabledControls", []))

    @jsii.member(jsii_name="toListEnabledGuardrails")
    def to_list_enabled_guardrails(self) -> "Controltower":
        '''(experimental) Grants permission to list currently enabled guardrails.

        Access Level: List

        https://docs.aws.amazon.com/controltower/latest/userguide/guardrails.html

        :stability: experimental
        '''
        return typing.cast("Controltower", jsii.invoke(self, "toListEnabledGuardrails", []))

    @jsii.member(jsii_name="toListGuardrails")
    def to_list_guardrails(self) -> "Controltower":
        '''(experimental) Grants permission to list all available guardrails.

        Access Level: List

        https://docs.aws.amazon.com/controltower/latest/userguide/guardrails.html

        :stability: experimental
        '''
        return typing.cast("Controltower", jsii.invoke(self, "toListGuardrails", []))

    @jsii.member(jsii_name="toListGuardrailsForTarget")
    def to_list_guardrails_for_target(self) -> "Controltower":
        '''(experimental) Grants permission to list guardrails and their current state for a organizational unit.

        Access Level: List

        https://docs.aws.amazon.com/controltower/latest/userguide/guardrails.html

        :stability: experimental
        '''
        return typing.cast("Controltower", jsii.invoke(self, "toListGuardrailsForTarget", []))

    @jsii.member(jsii_name="toListGuardrailViolations")
    def to_list_guardrail_violations(self) -> "Controltower":
        '''(experimental) Grants permission to list existing guardrail violations.

        Access Level: List

        https://docs.aws.amazon.com/controltower/latest/userguide/guardrails.html

        :stability: experimental
        '''
        return typing.cast("Controltower", jsii.invoke(self, "toListGuardrailViolations", []))

    @jsii.member(jsii_name="toListManagedAccounts")
    def to_list_managed_accounts(self) -> "Controltower":
        '''(experimental) Grants permission to list accounts managed through AWS Control Tower.

        Access Level: List

        https://docs.aws.amazon.com/controltower/latest/userguide/account-factory.html

        :stability: experimental
        '''
        return typing.cast("Controltower", jsii.invoke(self, "toListManagedAccounts", []))

    @jsii.member(jsii_name="toListManagedAccountsForGuardrail")
    def to_list_managed_accounts_for_guardrail(self) -> "Controltower":
        '''(experimental) Grants permission to list managed accounts with a specified guardrail applied.

        Access Level: List

        https://docs.aws.amazon.com/controltower/latest/userguide/account-factory.html

        :stability: experimental
        '''
        return typing.cast("Controltower", jsii.invoke(self, "toListManagedAccountsForGuardrail", []))

    @jsii.member(jsii_name="toListManagedAccountsForParent")
    def to_list_managed_accounts_for_parent(self) -> "Controltower":
        '''(experimental) Grants permission to list managed accounts under an organizational unit.

        Access Level: List

        https://docs.aws.amazon.com/controltower/latest/userguide/account-factory.html

        :stability: experimental
        '''
        return typing.cast("Controltower", jsii.invoke(self, "toListManagedAccountsForParent", []))

    @jsii.member(jsii_name="toListManagedOrganizationalUnits")
    def to_list_managed_organizational_units(self) -> "Controltower":
        '''(experimental) Grants permission to list organizational units managed by AWS Control Tower.

        Access Level: List

        https://docs.aws.amazon.com/controltower/latest/userguide/organizations.html

        :stability: experimental
        '''
        return typing.cast("Controltower", jsii.invoke(self, "toListManagedOrganizationalUnits", []))

    @jsii.member(jsii_name="toListManagedOrganizationalUnitsForGuardrail")
    def to_list_managed_organizational_units_for_guardrail(self) -> "Controltower":
        '''(experimental) Grants permission to list managed organizational units that have a specified guardrail applied.

        Access Level: List

        https://docs.aws.amazon.com/controltower/latest/userguide/organizations.html

        :stability: experimental
        '''
        return typing.cast("Controltower", jsii.invoke(self, "toListManagedOrganizationalUnitsForGuardrail", []))

    @jsii.member(jsii_name="toManageOrganizationalUnit")
    def to_manage_organizational_unit(self) -> "Controltower":
        '''(experimental) Grants permission to set up an organizational unit to be managed by AWS Control Tower.

        Access Level: Write

        https://docs.aws.amazon.com/controltower/latest/userguide/organizations.html

        :stability: experimental
        '''
        return typing.cast("Controltower", jsii.invoke(self, "toManageOrganizationalUnit", []))

    @jsii.member(jsii_name="toSetupLandingZone")
    def to_setup_landing_zone(self) -> "Controltower":
        '''(experimental) Grants permission to set up or update AWS Control Tower landing zone.

        Access Level: Write

        https://docs.aws.amazon.com/controltower/latest/userguide/getting-started-with-control-tower.html#step-two

        :stability: experimental
        '''
        return typing.cast("Controltower", jsii.invoke(self, "toSetupLandingZone", []))

    @jsii.member(jsii_name="toUpdateAccountFactoryConfig")
    def to_update_account_factory_config(self) -> "Controltower":
        '''(experimental) Grants permission to update the account factory configuration.

        Access Level: Write

        https://docs.aws.amazon.com/controltower/latest/userguide/account-factory.html

        :stability: experimental
        '''
        return typing.cast("Controltower", jsii.invoke(self, "toUpdateAccountFactoryConfig", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__792ed98adf3985a239cb7697a5757681f849e89b94764490dd531e39719d4580)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__82ac4604bce4c0bf09d0c4acb82b00f3f7d72304769ce44e196c7a1da3634510)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Cur(PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Cur"):
    '''(experimental) Statement provider for service `cur <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awscostandusagereport.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `cur <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awscostandusagereport.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onCur")
    def on_cur(
        self,
        report_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Cur":
        '''(experimental) Adds a resource of type cur to the statement.

        https://docs.aws.amazon.com/awsaccountbilling/latest/aboutv2/billing-reports.html#enhanced-reports

        :param report_name: - Identifier for the reportName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e7e0ecbf772ad2e900dd71ab3bde8cbeb321dd5e3037f309df7b2d52c70e7744)
            check_type(argname="argument report_name", value=report_name, expected_type=type_hints["report_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Cur", jsii.invoke(self, "onCur", [report_name, account, region, partition]))

    @jsii.member(jsii_name="toDeleteReportDefinition")
    def to_delete_report_definition(self) -> "Cur":
        '''(experimental) Delete Cost and Usage Report Definition.

        Access Level: Write

        https://docs.aws.amazon.com/awsaccountbilling/latest/aboutv2/delete-report-definition.html

        :stability: experimental
        '''
        return typing.cast("Cur", jsii.invoke(self, "toDeleteReportDefinition", []))

    @jsii.member(jsii_name="toDescribeReportDefinitions")
    def to_describe_report_definitions(self) -> "Cur":
        '''(experimental) Get Cost and Usage Report Definitions.

        Access Level: Read

        https://docs.aws.amazon.com/awsaccountbilling/latest/aboutv2/describe-report-definitions.html

        :stability: experimental
        '''
        return typing.cast("Cur", jsii.invoke(self, "toDescribeReportDefinitions", []))

    @jsii.member(jsii_name="toModifyReportDefinition")
    def to_modify_report_definition(self) -> "Cur":
        '''(experimental) Modify Cost and Usage Report Definition.

        Access Level: Write

        https://docs.aws.amazon.com/awsaccountbilling/latest/aboutv2/modify-report-definition.html

        :stability: experimental
        '''
        return typing.cast("Cur", jsii.invoke(self, "toModifyReportDefinition", []))

    @jsii.member(jsii_name="toPutReportDefinition")
    def to_put_report_definition(self) -> "Cur":
        '''(experimental) Write Cost and Usage Report Definition.

        Access Level: Write

        https://docs.aws.amazon.com/awsaccountbilling/latest/aboutv2/put-report-definition.html

        :stability: experimental
        '''
        return typing.cast("Cur", jsii.invoke(self, "toPutReportDefinition", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8c993afd890026f10d3c11a74419194f4f01fbf78eafadbff7df8601ec475f24)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ceb0a2a85875b57d85ac6fa19847b003c8f1c1b4a5fb0e5ddf288df3066be496)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Databrew(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Databrew",
):
    '''(experimental) Statement provider for service `databrew <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsgluedatabrew.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `databrew <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsgluedatabrew.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onDataset")
    def on_dataset(
        self,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Databrew":
        '''(experimental) Adds a resource of type Dataset to the statement.

        https://docs.aws.amazon.com/databrew/latest/dg/datasets.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f6b06532dd055384e105385917f71bf649498dbe7ace4d4e6a73434599c04330)
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Databrew", jsii.invoke(self, "onDataset", [resource_id, account, region, partition]))

    @jsii.member(jsii_name="onJob")
    def on_job(
        self,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Databrew":
        '''(experimental) Adds a resource of type Job to the statement.

        https://docs.aws.amazon.com/databrew/latest/dg/jobs.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a9d32ba4b7439a97e67eac554706ed4cbb05a7c6879bd6aa30f3b572acb05329)
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Databrew", jsii.invoke(self, "onJob", [resource_id, account, region, partition]))

    @jsii.member(jsii_name="onProject")
    def on_project(
        self,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Databrew":
        '''(experimental) Adds a resource of type Project to the statement.

        https://docs.aws.amazon.com/databrew/latest/dg/projects.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d59ab1c1b71f98bb6323cbc99ed07a081f56513a24ab820b6fd2ad63ed47c4f6)
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Databrew", jsii.invoke(self, "onProject", [resource_id, account, region, partition]))

    @jsii.member(jsii_name="onRecipe")
    def on_recipe(
        self,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Databrew":
        '''(experimental) Adds a resource of type Recipe to the statement.

        https://docs.aws.amazon.com/databrew/latest/dg/recipes.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c9688eefcc2ae3e99fd230c8cd451cec26b9ba0b648eef7def056a7959fd2f58)
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Databrew", jsii.invoke(self, "onRecipe", [resource_id, account, region, partition]))

    @jsii.member(jsii_name="onRuleset")
    def on_ruleset(
        self,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Databrew":
        '''(experimental) Adds a resource of type Ruleset to the statement.

        https://docs.aws.amazon.com/databrew/latest/dg/rulesets.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2f019579d54f5f37b2976a379665324d9d85ce611f5c61fdffc7a02b651c8146)
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Databrew", jsii.invoke(self, "onRuleset", [resource_id, account, region, partition]))

    @jsii.member(jsii_name="onSchedule")
    def on_schedule(
        self,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Databrew":
        '''(experimental) Adds a resource of type Schedule to the statement.

        https://docs.aws.amazon.com/databrew/latest/dg/jobs.html#jobs.scheduling

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3e14038ab98e86d367efca599c5fe3314540c35dd42a645bfae5b8f1486c9acf)
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Databrew", jsii.invoke(self, "onSchedule", [resource_id, account, region, partition]))

    @jsii.member(jsii_name="toBatchDeleteRecipeVersion")
    def to_batch_delete_recipe_version(self) -> "Databrew":
        '''(experimental) Grants permission to delete one or more recipe versions.

        Access Level: Write

        https://docs.aws.amazon.com/databrew/latest/dg/API_BatchDeleteRecipeVersion.html

        :stability: experimental
        '''
        return typing.cast("Databrew", jsii.invoke(self, "toBatchDeleteRecipeVersion", []))

    @jsii.member(jsii_name="toCreateDataset")
    def to_create_dataset(self) -> "Databrew":
        '''(experimental) Grants permission to create a dataset.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/databrew/latest/dg/API_CreateDataset.html

        :stability: experimental
        '''
        return typing.cast("Databrew", jsii.invoke(self, "toCreateDataset", []))

    @jsii.member(jsii_name="toCreateProfileJob")
    def to_create_profile_job(self) -> "Databrew":
        '''(experimental) Grants permission to create a profile job.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/databrew/latest/dg/API_CreateProfileJob.html

        :stability: experimental
        '''
        return typing.cast("Databrew", jsii.invoke(self, "toCreateProfileJob", []))

    @jsii.member(jsii_name="toCreateProject")
    def to_create_project(self) -> "Databrew":
        '''(experimental) Grants permission to create a project.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/databrew/latest/dg/API_CreateProject.html

        :stability: experimental
        '''
        return typing.cast("Databrew", jsii.invoke(self, "toCreateProject", []))

    @jsii.member(jsii_name="toCreateRecipe")
    def to_create_recipe(self) -> "Databrew":
        '''(experimental) Grants permission to create a recipe.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/databrew/latest/dg/API_CreateRecipe.html

        :stability: experimental
        '''
        return typing.cast("Databrew", jsii.invoke(self, "toCreateRecipe", []))

    @jsii.member(jsii_name="toCreateRecipeJob")
    def to_create_recipe_job(self) -> "Databrew":
        '''(experimental) Grants permission to create a recipe job.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/databrew/latest/dg/API_CreateRecipeJob.html

        :stability: experimental
        '''
        return typing.cast("Databrew", jsii.invoke(self, "toCreateRecipeJob", []))

    @jsii.member(jsii_name="toCreateRuleset")
    def to_create_ruleset(self) -> "Databrew":
        '''(experimental) Grants permission to create a ruleset.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/databrew/latest/dg/API_CreateRuleset.html

        :stability: experimental
        '''
        return typing.cast("Databrew", jsii.invoke(self, "toCreateRuleset", []))

    @jsii.member(jsii_name="toCreateSchedule")
    def to_create_schedule(self) -> "Databrew":
        '''(experimental) Grants permission to create a schedule.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/databrew/latest/dg/API_CreateSchedule.html

        :stability: experimental
        '''
        return typing.cast("Databrew", jsii.invoke(self, "toCreateSchedule", []))

    @jsii.member(jsii_name="toDeleteDataset")
    def to_delete_dataset(self) -> "Databrew":
        '''(experimental) Grants permission to delete a dataset.

        Access Level: Write

        https://docs.aws.amazon.com/databrew/latest/dg/API_DeleteDataset.html

        :stability: experimental
        '''
        return typing.cast("Databrew", jsii.invoke(self, "toDeleteDataset", []))

    @jsii.member(jsii_name="toDeleteJob")
    def to_delete_job(self) -> "Databrew":
        '''(experimental) Grants permission to delete a job.

        Access Level: Write

        https://docs.aws.amazon.com/databrew/latest/dg/API_DeleteJob.html

        :stability: experimental
        '''
        return typing.cast("Databrew", jsii.invoke(self, "toDeleteJob", []))

    @jsii.member(jsii_name="toDeleteProject")
    def to_delete_project(self) -> "Databrew":
        '''(experimental) Grants permission to delete a project.

        Access Level: Write

        https://docs.aws.amazon.com/databrew/latest/dg/API_DeleteProject.html

        :stability: experimental
        '''
        return typing.cast("Databrew", jsii.invoke(self, "toDeleteProject", []))

    @jsii.member(jsii_name="toDeleteRecipeVersion")
    def to_delete_recipe_version(self) -> "Databrew":
        '''(experimental) Grants permission to delete a recipe version.

        Access Level: Write

        https://docs.aws.amazon.com/databrew/latest/dg/API_DeleteRecipeVersion.html

        :stability: experimental
        '''
        return typing.cast("Databrew", jsii.invoke(self, "toDeleteRecipeVersion", []))

    @jsii.member(jsii_name="toDeleteRuleset")
    def to_delete_ruleset(self) -> "Databrew":
        '''(experimental) Grants permission to delete a ruleset.

        Access Level: Write

        https://docs.aws.amazon.com/databrew/latest/dg/API_DeleteRuleset.html

        :stability: experimental
        '''
        return typing.cast("Databrew", jsii.invoke(self, "toDeleteRuleset", []))

    @jsii.member(jsii_name="toDeleteSchedule")
    def to_delete_schedule(self) -> "Databrew":
        '''(experimental) Grants permission to delete a schedule.

        Access Level: Write

        https://docs.aws.amazon.com/databrew/latest/dg/API_DeleteSchedule.html

        :stability: experimental
        '''
        return typing.cast("Databrew", jsii.invoke(self, "toDeleteSchedule", []))

    @jsii.member(jsii_name="toDescribeDataset")
    def to_describe_dataset(self) -> "Databrew":
        '''(experimental) Grants permission to view details about a dataset.

        Access Level: Read

        https://docs.aws.amazon.com/databrew/latest/dg/API_DescribeDataset.html

        :stability: experimental
        '''
        return typing.cast("Databrew", jsii.invoke(self, "toDescribeDataset", []))

    @jsii.member(jsii_name="toDescribeJob")
    def to_describe_job(self) -> "Databrew":
        '''(experimental) Grants permission to view details about a job.

        Access Level: Read

        https://docs.aws.amazon.com/databrew/latest/dg/API_DescribeJob.html

        :stability: experimental
        '''
        return typing.cast("Databrew", jsii.invoke(self, "toDescribeJob", []))

    @jsii.member(jsii_name="toDescribeJobRun")
    def to_describe_job_run(self) -> "Databrew":
        '''(experimental) Grants permission to view details about job run for a given job.

        Access Level: Read

        https://docs.aws.amazon.com/databrew/latest/dg/API_DescribeJobRun.html

        :stability: experimental
        '''
        return typing.cast("Databrew", jsii.invoke(self, "toDescribeJobRun", []))

    @jsii.member(jsii_name="toDescribeProject")
    def to_describe_project(self) -> "Databrew":
        '''(experimental) Grants permission to view details about a project.

        Access Level: Read

        https://docs.aws.amazon.com/databrew/latest/dg/API_DescribeProject.html

        :stability: experimental
        '''
        return typing.cast("Databrew", jsii.invoke(self, "toDescribeProject", []))

    @jsii.member(jsii_name="toDescribeRecipe")
    def to_describe_recipe(self) -> "Databrew":
        '''(experimental) Grants permission to view details about a recipe.

        Access Level: Read

        https://docs.aws.amazon.com/databrew/latest/dg/API_DescribeRecipe.html

        :stability: experimental
        '''
        return typing.cast("Databrew", jsii.invoke(self, "toDescribeRecipe", []))

    @jsii.member(jsii_name="toDescribeRuleset")
    def to_describe_ruleset(self) -> "Databrew":
        '''(experimental) Grants permission to view details about a ruleset.

        Access Level: Read

        https://docs.aws.amazon.com/databrew/latest/dg/API_DescribeRuleset.html

        :stability: experimental
        '''
        return typing.cast("Databrew", jsii.invoke(self, "toDescribeRuleset", []))

    @jsii.member(jsii_name="toDescribeSchedule")
    def to_describe_schedule(self) -> "Databrew":
        '''(experimental) Grants permission to view details about a schedule.

        Access Level: Read

        https://docs.aws.amazon.com/databrew/latest/dg/API_DescribeSchedule.html

        :stability: experimental
        '''
        return typing.cast("Databrew", jsii.invoke(self, "toDescribeSchedule", []))

    @jsii.member(jsii_name="toListDatasets")
    def to_list_datasets(self) -> "Databrew":
        '''(experimental) Grants permission to list datasets in your account.

        Access Level: Read

        https://docs.aws.amazon.com/databrew/latest/dg/API_ListDatasets.html

        :stability: experimental
        '''
        return typing.cast("Databrew", jsii.invoke(self, "toListDatasets", []))

    @jsii.member(jsii_name="toListJobRuns")
    def to_list_job_runs(self) -> "Databrew":
        '''(experimental) Grants permission to list job runs for a given job.

        Access Level: Read

        https://docs.aws.amazon.com/databrew/latest/dg/API_ListJobRuns.html

        :stability: experimental
        '''
        return typing.cast("Databrew", jsii.invoke(self, "toListJobRuns", []))

    @jsii.member(jsii_name="toListJobs")
    def to_list_jobs(self) -> "Databrew":
        '''(experimental) Grants permission to list jobs in your account.

        Access Level: Read

        https://docs.aws.amazon.com/databrew/latest/dg/API_ListJobs.html

        :stability: experimental
        '''
        return typing.cast("Databrew", jsii.invoke(self, "toListJobs", []))

    @jsii.member(jsii_name="toListProjects")
    def to_list_projects(self) -> "Databrew":
        '''(experimental) Grants permission to list projects in your account.

        Access Level: Read

        https://docs.aws.amazon.com/databrew/latest/dg/API_ListProjects.html

        :stability: experimental
        '''
        return typing.cast("Databrew", jsii.invoke(self, "toListProjects", []))

    @jsii.member(jsii_name="toListRecipes")
    def to_list_recipes(self) -> "Databrew":
        '''(experimental) Grants permission to list recipes in your account.

        Access Level: Read

        https://docs.aws.amazon.com/databrew/latest/dg/API_ListRecipes.html

        :stability: experimental
        '''
        return typing.cast("Databrew", jsii.invoke(self, "toListRecipes", []))

    @jsii.member(jsii_name="toListRecipeVersions")
    def to_list_recipe_versions(self) -> "Databrew":
        '''(experimental) Grants permission to list versions in your recipe.

        Access Level: Read

        https://docs.aws.amazon.com/databrew/latest/dg/API_ListRecipeVersions.html

        :stability: experimental
        '''
        return typing.cast("Databrew", jsii.invoke(self, "toListRecipeVersions", []))

    @jsii.member(jsii_name="toListRulesets")
    def to_list_rulesets(self) -> "Databrew":
        '''(experimental) Grants permission to list rulesets in your account.

        Access Level: Read

        https://docs.aws.amazon.com/databrew/latest/dg/API_ListRulesets.html

        :stability: experimental
        '''
        return typing.cast("Databrew", jsii.invoke(self, "toListRulesets", []))

    @jsii.member(jsii_name="toListSchedules")
    def to_list_schedules(self) -> "Databrew":
        '''(experimental) Grants permission to list schedules in your account.

        Access Level: Read

        https://docs.aws.amazon.com/databrew/latest/dg/API_ListSchedules.html

        :stability: experimental
        '''
        return typing.cast("Databrew", jsii.invoke(self, "toListSchedules", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Databrew":
        '''(experimental) Grants permission to retrieve tags associated with a resource.

        Access Level: Read

        https://docs.aws.amazon.com/databrew/latest/dg/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("Databrew", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toPublishRecipe")
    def to_publish_recipe(self) -> "Databrew":
        '''(experimental) Grants permission to publish a major verison of a recipe.

        Access Level: Write

        https://docs.aws.amazon.com/databrew/latest/dg/API_PublishRecipe.html

        :stability: experimental
        '''
        return typing.cast("Databrew", jsii.invoke(self, "toPublishRecipe", []))

    @jsii.member(jsii_name="toSendProjectSessionAction")
    def to_send_project_session_action(self) -> "Databrew":
        '''(experimental) Grants permission to submit an action to the interactive session for a project.

        Access Level: Write

        https://docs.aws.amazon.com/databrew/latest/dg/API_SendProjectSessionAction.html

        :stability: experimental
        '''
        return typing.cast("Databrew", jsii.invoke(self, "toSendProjectSessionAction", []))

    @jsii.member(jsii_name="toStartJobRun")
    def to_start_job_run(self) -> "Databrew":
        '''(experimental) Grants permission to start running a job.

        Access Level: Write

        https://docs.aws.amazon.com/databrew/latest/dg/API_StartJobRun.html

        :stability: experimental
        '''
        return typing.cast("Databrew", jsii.invoke(self, "toStartJobRun", []))

    @jsii.member(jsii_name="toStartProjectSession")
    def to_start_project_session(self) -> "Databrew":
        '''(experimental) Grants permission to start an interactive session for a project.

        Access Level: Write

        https://docs.aws.amazon.com/databrew/latest/dg/API_StartProjectSession.html

        :stability: experimental
        '''
        return typing.cast("Databrew", jsii.invoke(self, "toStartProjectSession", []))

    @jsii.member(jsii_name="toStopJobRun")
    def to_stop_job_run(self) -> "Databrew":
        '''(experimental) Grants permission to stop a job run for a job.

        Access Level: Write

        https://docs.aws.amazon.com/databrew/latest/dg/API_StopJobRun.html

        :stability: experimental
        '''
        return typing.cast("Databrew", jsii.invoke(self, "toStopJobRun", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Databrew":
        '''(experimental) Grants permission to add tags to a resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/databrew/latest/dg/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("Databrew", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Databrew":
        '''(experimental) Grants permission to remove tags associated with a resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/databrew/latest/dg/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("Databrew", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateDataset")
    def to_update_dataset(self) -> "Databrew":
        '''(experimental) Grants permission to modify a dataset.

        Access Level: Write

        https://docs.aws.amazon.com/databrew/latest/dg/API_UpdateDataset.html

        :stability: experimental
        '''
        return typing.cast("Databrew", jsii.invoke(self, "toUpdateDataset", []))

    @jsii.member(jsii_name="toUpdateProfileJob")
    def to_update_profile_job(self) -> "Databrew":
        '''(experimental) Grants permission to modify a profile job.

        Access Level: Write

        https://docs.aws.amazon.com/databrew/latest/dg/API_UpdateProfileJob.html

        :stability: experimental
        '''
        return typing.cast("Databrew", jsii.invoke(self, "toUpdateProfileJob", []))

    @jsii.member(jsii_name="toUpdateProject")
    def to_update_project(self) -> "Databrew":
        '''(experimental) Grants permission to modify a project.

        Access Level: Write

        https://docs.aws.amazon.com/databrew/latest/dg/API_UpdateProject.html

        :stability: experimental
        '''
        return typing.cast("Databrew", jsii.invoke(self, "toUpdateProject", []))

    @jsii.member(jsii_name="toUpdateRecipe")
    def to_update_recipe(self) -> "Databrew":
        '''(experimental) Grants permission to modify a recipe.

        Access Level: Write

        https://docs.aws.amazon.com/databrew/latest/dg/API_UpdateRecipe.html

        :stability: experimental
        '''
        return typing.cast("Databrew", jsii.invoke(self, "toUpdateRecipe", []))

    @jsii.member(jsii_name="toUpdateRecipeJob")
    def to_update_recipe_job(self) -> "Databrew":
        '''(experimental) Grants permission to modify a recipe job.

        Access Level: Write

        https://docs.aws.amazon.com/databrew/latest/dg/API_UpdateRecipeJob.html

        :stability: experimental
        '''
        return typing.cast("Databrew", jsii.invoke(self, "toUpdateRecipeJob", []))

    @jsii.member(jsii_name="toUpdateRuleset")
    def to_update_ruleset(self) -> "Databrew":
        '''(experimental) Grants permission to modify a ruleset.

        Access Level: Write

        https://docs.aws.amazon.com/databrew/latest/dg/API_UpdateRuleset.html

        :stability: experimental
        '''
        return typing.cast("Databrew", jsii.invoke(self, "toUpdateRuleset", []))

    @jsii.member(jsii_name="toUpdateSchedule")
    def to_update_schedule(self) -> "Databrew":
        '''(experimental) Grants permission to modify a schedule.

        Access Level: Write

        https://docs.aws.amazon.com/databrew/latest/dg/API_UpdateSchedule.html

        :stability: experimental
        '''
        return typing.cast("Databrew", jsii.invoke(self, "toUpdateSchedule", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__97783c4b73bc5a89ba67f645051a8722018cd26e281a28f700c05cda7af785ac)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__36ebcd9d2923d4180c2f35b7b2b8473a0887e725783bfc8ef2bcd54407f47714)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Dataexchange(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Dataexchange",
):
    '''(experimental) Statement provider for service `dataexchange <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsdataexchange.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `dataexchange <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsdataexchange.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="ifJobType")
    def if_job_type(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Dataexchange":
        '''(experimental) Filters access by the specified job type.

        https://docs.aws.amazon.com/data-exchange/latest/userguide/access-control.html

        Applies to resource types:

        - jobs

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e26dce38427d43372da1233d722bbefb4aeef05763758a6146c97cc6dc550d9d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Dataexchange", jsii.invoke(self, "ifJobType", [value, operator]))

    @jsii.member(jsii_name="onAssets")
    def on_assets(
        self,
        data_set_id: builtins.str,
        revision_id: builtins.str,
        asset_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Dataexchange":
        '''(experimental) Adds a resource of type assets to the statement.

        https://docs.aws.amazon.com/data-exchange/latest/userguide/data-sets.html#assets

        :param data_set_id: - Identifier for the dataSetId.
        :param revision_id: - Identifier for the revisionId.
        :param asset_id: - Identifier for the assetId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3eaae1b77bf199b30452485831d8134d7b2d17e7f6b0d185086638d3f69f6414)
            check_type(argname="argument data_set_id", value=data_set_id, expected_type=type_hints["data_set_id"])
            check_type(argname="argument revision_id", value=revision_id, expected_type=type_hints["revision_id"])
            check_type(argname="argument asset_id", value=asset_id, expected_type=type_hints["asset_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Dataexchange", jsii.invoke(self, "onAssets", [data_set_id, revision_id, asset_id, account, region, partition]))

    @jsii.member(jsii_name="onDataSets")
    def on_data_sets(
        self,
        data_set_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Dataexchange":
        '''(experimental) Adds a resource of type data-sets to the statement.

        https://docs.aws.amazon.com/data-exchange/latest/userguide/data-sets.html

        :param data_set_id: - Identifier for the dataSetId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__954408eb9835dda8f6072fd77ac1562946ca76bf39b4a5a8e4afbde2d183c9ec)
            check_type(argname="argument data_set_id", value=data_set_id, expected_type=type_hints["data_set_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Dataexchange", jsii.invoke(self, "onDataSets", [data_set_id, account, region, partition]))

    @jsii.member(jsii_name="onEventActions")
    def on_event_actions(
        self,
        event_action_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Dataexchange":
        '''(experimental) Adds a resource of type event-actions to the statement.

        https://docs.aws.amazon.com/data-exchange/latest/userguide/data-sets.html

        :param event_action_id: - Identifier for the eventActionId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__faed329dd0bc10c00f2578dbe0629be1160b3584ba1589760bd446ceea959f03)
            check_type(argname="argument event_action_id", value=event_action_id, expected_type=type_hints["event_action_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Dataexchange", jsii.invoke(self, "onEventActions", [event_action_id, account, region, partition]))

    @jsii.member(jsii_name="onJobs")
    def on_jobs(
        self,
        job_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Dataexchange":
        '''(experimental) Adds a resource of type jobs to the statement.

        https://docs.aws.amazon.com/data-exchange/latest/userguide/jobs.html

        :param job_id: - Identifier for the jobId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifJobType()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__27765c2c60b145a5a2ef97ce7bd10627d7dd16fb87485c32c04bcf3f982f7bb7)
            check_type(argname="argument job_id", value=job_id, expected_type=type_hints["job_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Dataexchange", jsii.invoke(self, "onJobs", [job_id, account, region, partition]))

    @jsii.member(jsii_name="onRevisions")
    def on_revisions(
        self,
        data_set_id: builtins.str,
        revision_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Dataexchange":
        '''(experimental) Adds a resource of type revisions to the statement.

        https://docs.aws.amazon.com/data-exchange/latest/userguide/data-sets.html#revisions

        :param data_set_id: - Identifier for the dataSetId.
        :param revision_id: - Identifier for the revisionId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__077b4ffd2f4ce79c02ceea488de33512ef4ed84a20ca74bfe27c444ab8ae86b5)
            check_type(argname="argument data_set_id", value=data_set_id, expected_type=type_hints["data_set_id"])
            check_type(argname="argument revision_id", value=revision_id, expected_type=type_hints["revision_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Dataexchange", jsii.invoke(self, "onRevisions", [data_set_id, revision_id, account, region, partition]))

    @jsii.member(jsii_name="toCancelJob")
    def to_cancel_job(self) -> "Dataexchange":
        '''(experimental) Grants permission to cancel a job.

        Access Level: Write

        https://docs.aws.amazon.com/data-exchange/latest/apireference/v1-jobs.html#CancelJob

        :stability: experimental
        '''
        return typing.cast("Dataexchange", jsii.invoke(self, "toCancelJob", []))

    @jsii.member(jsii_name="toCreateAsset")
    def to_create_asset(self) -> "Dataexchange":
        '''(experimental) Grants permission to create an asset (for example, in a Job).

        Access Level: Write

        https://docs.aws.amazon.com/data-exchange/latest/apireference/v1-data-sets-datasetid-revisions.html#CreateAsset

        :stability: experimental
        '''
        return typing.cast("Dataexchange", jsii.invoke(self, "toCreateAsset", []))

    @jsii.member(jsii_name="toCreateDataSet")
    def to_create_data_set(self) -> "Dataexchange":
        '''(experimental) Grants permission to create a data set.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsResourceTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/data-exchange/latest/apireference/v1-data-sets.html#CreateDataSet

        :stability: experimental
        '''
        return typing.cast("Dataexchange", jsii.invoke(self, "toCreateDataSet", []))

    @jsii.member(jsii_name="toCreateEventAction")
    def to_create_event_action(self) -> "Dataexchange":
        '''(experimental) Grants permission to create an event action.

        Access Level: Write

        https://docs.aws.amazon.com/data-exchange/latest/userguide/api-permission-ref.html

        :stability: experimental
        '''
        return typing.cast("Dataexchange", jsii.invoke(self, "toCreateEventAction", []))

    @jsii.member(jsii_name="toCreateJob")
    def to_create_job(self) -> "Dataexchange":
        '''(experimental) Grants permission to create a job to import or export assets.

        Access Level: Write

        https://docs.aws.amazon.com/data-exchange/latest/apireference/v1-jobs.html#CreateJob

        :stability: experimental
        '''
        return typing.cast("Dataexchange", jsii.invoke(self, "toCreateJob", []))

    @jsii.member(jsii_name="toCreateRevision")
    def to_create_revision(self) -> "Dataexchange":
        '''(experimental) Grants permission to create a revision.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsResourceTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/data-exchange/latest/apireference/v1-data-sets-datasetid-revisions.html#CreateRevision

        :stability: experimental
        '''
        return typing.cast("Dataexchange", jsii.invoke(self, "toCreateRevision", []))

    @jsii.member(jsii_name="toDeleteAsset")
    def to_delete_asset(self) -> "Dataexchange":
        '''(experimental) Grants permission to delete an asset.

        Access Level: Write

        https://docs.aws.amazon.com/data-exchange/latest/apireference/v1-data-sets-datasetid-revisions-revisionid-assets-assetid.html#DeleteAsset

        :stability: experimental
        '''
        return typing.cast("Dataexchange", jsii.invoke(self, "toDeleteAsset", []))

    @jsii.member(jsii_name="toDeleteDataSet")
    def to_delete_data_set(self) -> "Dataexchange":
        '''(experimental) Grants permission to delete a data set.

        Access Level: Write

        https://docs.aws.amazon.com/data-exchange/latest/apireference/v1-data-sets-datasetid.html#DeleteDataSet

        :stability: experimental
        '''
        return typing.cast("Dataexchange", jsii.invoke(self, "toDeleteDataSet", []))

    @jsii.member(jsii_name="toDeleteEventAction")
    def to_delete_event_action(self) -> "Dataexchange":
        '''(experimental) Grants permission to delete an event action.

        Access Level: Write

        https://docs.aws.amazon.com/data-exchange/latest/userguide/api-permission-ref.html

        :stability: experimental
        '''
        return typing.cast("Dataexchange", jsii.invoke(self, "toDeleteEventAction", []))

    @jsii.member(jsii_name="toDeleteRevision")
    def to_delete_revision(self) -> "Dataexchange":
        '''(experimental) Grants permission to delete a revision.

        Access Level: Write

        https://docs.aws.amazon.com/data-exchange/latest/apireference/v1-data-sets-datasetid-revisions-revisionid.html#DeleteRevision

        :stability: experimental
        '''
        return typing.cast("Dataexchange", jsii.invoke(self, "toDeleteRevision", []))

    @jsii.member(jsii_name="toGetAsset")
    def to_get_asset(self) -> "Dataexchange":
        '''(experimental) Grants permission to get information about an asset and to export it (for example, in a Job).

        Access Level: Read

        https://docs.aws.amazon.com/data-exchange/latest/apireference/v1-data-sets-datasetid-revisions-revisionid-assets-assetid.html#GetAsset

        :stability: experimental
        '''
        return typing.cast("Dataexchange", jsii.invoke(self, "toGetAsset", []))

    @jsii.member(jsii_name="toGetDataSet")
    def to_get_data_set(self) -> "Dataexchange":
        '''(experimental) Grants permission to get information about a data set.

        Access Level: Read

        https://docs.aws.amazon.com/data-exchange/latest/apireference/v1-data-sets-datasetid.html#GetDataSet

        :stability: experimental
        '''
        return typing.cast("Dataexchange", jsii.invoke(self, "toGetDataSet", []))

    @jsii.member(jsii_name="toGetEventAction")
    def to_get_event_action(self) -> "Dataexchange":
        '''(experimental) Grants permission to get an event action.

        Access Level: Read

        https://docs.aws.amazon.com/data-exchange/latest/userguide/api-permission-ref.html

        :stability: experimental
        '''
        return typing.cast("Dataexchange", jsii.invoke(self, "toGetEventAction", []))

    @jsii.member(jsii_name="toGetJob")
    def to_get_job(self) -> "Dataexchange":
        '''(experimental) Grants permission to get information about a job.

        Access Level: Read

        https://docs.aws.amazon.com/data-exchange/latest/apireference/v1-jobs.html#GetJob

        :stability: experimental
        '''
        return typing.cast("Dataexchange", jsii.invoke(self, "toGetJob", []))

    @jsii.member(jsii_name="toGetRevision")
    def to_get_revision(self) -> "Dataexchange":
        '''(experimental) Grants permission to get information about a revision.

        Access Level: Read

        https://docs.aws.amazon.com/data-exchange/latest/apireference/v1-data-sets-datasetid-revisions-revisionid.html#GetRevision

        :stability: experimental
        '''
        return typing.cast("Dataexchange", jsii.invoke(self, "toGetRevision", []))

    @jsii.member(jsii_name="toListDataSetRevisions")
    def to_list_data_set_revisions(self) -> "Dataexchange":
        '''(experimental) Grants permission to list the revisions of a data set.

        Access Level: Read

        https://docs.aws.amazon.com/data-exchange/latest/apireference/v1-data-sets-datasetid-revisions.html#ListDataSetRevisions

        :stability: experimental
        '''
        return typing.cast("Dataexchange", jsii.invoke(self, "toListDataSetRevisions", []))

    @jsii.member(jsii_name="toListDataSets")
    def to_list_data_sets(self) -> "Dataexchange":
        '''(experimental) Grants permission to list data sets for the account.

        Access Level: Read

        https://docs.aws.amazon.com/data-exchange/latest/apireference/v1-data-sets.html#ListDataSets

        :stability: experimental
        '''
        return typing.cast("Dataexchange", jsii.invoke(self, "toListDataSets", []))

    @jsii.member(jsii_name="toListEventActions")
    def to_list_event_actions(self) -> "Dataexchange":
        '''(experimental) Grants permission to list event actions for the account.

        Access Level: Read

        https://docs.aws.amazon.com/data-exchange/latest/userguide/api-permission-ref.html

        :stability: experimental
        '''
        return typing.cast("Dataexchange", jsii.invoke(self, "toListEventActions", []))

    @jsii.member(jsii_name="toListJobs")
    def to_list_jobs(self) -> "Dataexchange":
        '''(experimental) Grants permission to list jobs for the account.

        Access Level: Read

        https://docs.aws.amazon.com/data-exchange/latest/apireference/v1-jobs.html#ListJobs

        :stability: experimental
        '''
        return typing.cast("Dataexchange", jsii.invoke(self, "toListJobs", []))

    @jsii.member(jsii_name="toListRevisionAssets")
    def to_list_revision_assets(self) -> "Dataexchange":
        '''(experimental) Grants permission to get list the assets of a revision.

        Access Level: Read

        https://docs.aws.amazon.com/data-exchange/latest/apireference/v1-data-sets-datasetid-revisions-revisionid-assets.html#ListRevisionAssets

        :stability: experimental
        '''
        return typing.cast("Dataexchange", jsii.invoke(self, "toListRevisionAssets", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Dataexchange":
        '''(experimental) Grants permission to list the tags that you associated with the specified resource.

        Access Level: Read

        https://docs.aws.amazon.com/data-exchange/latest/apireference/tags-resource-arn.html#ListTagsForResource

        :stability: experimental
        '''
        return typing.cast("Dataexchange", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toPublishDataSet")
    def to_publish_data_set(self) -> "Dataexchange":
        '''(experimental) Grants permission to publish a data set.

        Access Level: Write

        https://docs.aws.amazon.com/data-exchange/latest/userguide/api-permission-ref.html

        :stability: experimental
        '''
        return typing.cast("Dataexchange", jsii.invoke(self, "toPublishDataSet", []))

    @jsii.member(jsii_name="toRevokeRevision")
    def to_revoke_revision(self) -> "Dataexchange":
        '''(experimental) Grants permission to revoke subscriber access to a revision.

        Access Level: Write

        https://docs.aws.amazon.com/data-exchange/latest/apireference/v1-data-sets-datasetid-revisions-revisionid.html#DeleteRevision

        :stability: experimental
        '''
        return typing.cast("Dataexchange", jsii.invoke(self, "toRevokeRevision", []))

    @jsii.member(jsii_name="toSendApiAsset")
    def to_send_api_asset(self) -> "Dataexchange":
        '''(experimental) Grants permission to send a request to an API asset.

        Access Level: Write

        https://docs.aws.amazon.com/data-exchange/latest/userguide/api-permission-ref.html

        :stability: experimental
        '''
        return typing.cast("Dataexchange", jsii.invoke(self, "toSendApiAsset", []))

    @jsii.member(jsii_name="toStartJob")
    def to_start_job(self) -> "Dataexchange":
        '''(experimental) Grants permission to start a job.

        Access Level: Write

        https://docs.aws.amazon.com/data-exchange/latest/apireference/v1-jobs.html#StartJob

        :stability: experimental
        '''
        return typing.cast("Dataexchange", jsii.invoke(self, "toStartJob", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Dataexchange":
        '''(experimental) Grants permission to add one or more tags to a specified resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/data-exchange/latest/apireference/tags-resource-arn.html#TagResource

        :stability: experimental
        '''
        return typing.cast("Dataexchange", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Dataexchange":
        '''(experimental) Grants permission to remove one or more tags from a specified resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/data-exchange/latest/apireference/tags-resource-arn.html#UntagResource

        :stability: experimental
        '''
        return typing.cast("Dataexchange", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateAsset")
    def to_update_asset(self) -> "Dataexchange":
        '''(experimental) Grants permission to get update information about an asset.

        Access Level: Write

        https://docs.aws.amazon.com/data-exchange/latest/apireference/v1-data-sets-datasetid-revisions-revisionid-assets-assetid.html#UpdateAsset

        :stability: experimental
        '''
        return typing.cast("Dataexchange", jsii.invoke(self, "toUpdateAsset", []))

    @jsii.member(jsii_name="toUpdateDataSet")
    def to_update_data_set(self) -> "Dataexchange":
        '''(experimental) Grants permission to update information about a data set.

        Access Level: Write

        https://docs.aws.amazon.com/data-exchange/latest/apireference/v1-data-sets-datasetid.html#UpdateDataSet

        :stability: experimental
        '''
        return typing.cast("Dataexchange", jsii.invoke(self, "toUpdateDataSet", []))

    @jsii.member(jsii_name="toUpdateEventAction")
    def to_update_event_action(self) -> "Dataexchange":
        '''(experimental) Grants permission to update information for an event action.

        Access Level: Write

        https://docs.aws.amazon.com/data-exchange/latest/userguide/api-permission-ref.html

        :stability: experimental
        '''
        return typing.cast("Dataexchange", jsii.invoke(self, "toUpdateEventAction", []))

    @jsii.member(jsii_name="toUpdateRevision")
    def to_update_revision(self) -> "Dataexchange":
        '''(experimental) Grants permission to update information about a revision.

        Access Level: Write

        https://docs.aws.amazon.com/data-exchange/latest/apireference/v1-data-sets-datasetid-revisions-revisionid.html#UpdateRevision

        :stability: experimental
        '''
        return typing.cast("Dataexchange", jsii.invoke(self, "toUpdateRevision", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__56016a49e664930d1c8c5f0c33761452d30c53896e7ac00c0f69012ecd571ace)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__55d4597f9581f7c57a1dcf43873ceb917dec8d22de85d68dc6635c56d4001164)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Datapipeline(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Datapipeline",
):
    '''(experimental) Statement provider for service `datapipeline <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsdatapipeline.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `datapipeline <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsdatapipeline.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="ifPipelineCreator")
    def if_pipeline_creator(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Datapipeline":
        '''(experimental) Filters access by the IAM user that created the pipeline.

        https://docs.aws.amazon.com/datapipeline/latest/DeveloperGuide/dp-example-tag-policies.html#ex3

        Applies to actions:

        - .toActivatePipeline()
        - .toAddTags()
        - .toDeactivatePipeline()
        - .toDeletePipeline()
        - .toDescribeObjects()
        - .toDescribePipelines()
        - .toEvaluateExpression()
        - .toGetPipelineDefinition()
        - .toPutPipelineDefinition()
        - .toQueryObjects()
        - .toRemoveTags()
        - .toSetStatus()
        - .toValidatePipelineDefinition()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__75fd5b4dbfd5372a2b1189466c7fb429f057aa4371451e5b9e61d32a2d2e6866)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Datapipeline", jsii.invoke(self, "ifPipelineCreator", [value, operator]))

    @jsii.member(jsii_name="ifTag")
    def if_tag(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Datapipeline":
        '''(experimental) Filters access by customer-specified key/value pair that can be attached to a resource.

        https://docs.aws.amazon.com/datapipeline/latest/DeveloperGuide/dp-iam-resourcebased-access.html#dp-control-access-tags

        Applies to actions:

        - .toActivatePipeline()
        - .toAddTags()
        - .toCreatePipeline()
        - .toDeactivatePipeline()
        - .toDeletePipeline()
        - .toDescribeObjects()
        - .toDescribePipelines()
        - .toEvaluateExpression()
        - .toGetPipelineDefinition()
        - .toPutPipelineDefinition()
        - .toQueryObjects()
        - .toRemoveTags()
        - .toSetStatus()
        - .toValidatePipelineDefinition()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8b9e5479d6e05e4676088105fb662e73d16f7a8632be7d4444ddf0b3284ec05c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Datapipeline", jsii.invoke(self, "ifTag", [value, operator]))

    @jsii.member(jsii_name="ifWorkerGroup")
    def if_worker_group(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Datapipeline":
        '''(experimental) Filters access by the name of a worker group for which a Task Runner retrieves work.

        https://docs.aws.amazon.com/datapipeline/latest/DeveloperGuide/dp-iam-resourcebased-access.html#dp-control-access-workergroup

        Applies to actions:

        - .toActivatePipeline()
        - .toDeactivatePipeline()
        - .toGetPipelineDefinition()
        - .toPollForTask()
        - .toPutPipelineDefinition()
        - .toValidatePipelineDefinition()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__afb442f93ee4257c1c3e50f348990a24596aa88e0dfa0f3aeb57f9eaa972909e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Datapipeline", jsii.invoke(self, "ifWorkerGroup", [value, operator]))

    @jsii.member(jsii_name="onPipeline")
    def on_pipeline(
        self,
        pipeline_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Datapipeline":
        '''(experimental) Adds a resource of type pipeline to the statement.

        https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsdatapipeline.html

        :param pipeline_id: - Identifier for the pipelineId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__edae5d1607d3d3c5d409c0752a94cb9d1bed389c90d55a6bf0d7b6bc01d8c553)
            check_type(argname="argument pipeline_id", value=pipeline_id, expected_type=type_hints["pipeline_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Datapipeline", jsii.invoke(self, "onPipeline", [pipeline_id, account, region, partition]))

    @jsii.member(jsii_name="toActivatePipeline")
    def to_activate_pipeline(self) -> "Datapipeline":
        '''(experimental) Grants permission to validate the specified pipeline and starts processing pipeline tasks.

        If the pipeline does not pass validation, activation fails

        Access Level: Write

        Possible conditions:

        - .ifPipelineCreator()
        - .ifTag()
        - .ifWorkerGroup()

        https://docs.aws.amazon.com/datapipeline/latest/APIReference/API_ActivatePipeline.html

        :stability: experimental
        '''
        return typing.cast("Datapipeline", jsii.invoke(self, "toActivatePipeline", []))

    @jsii.member(jsii_name="toAddTags")
    def to_add_tags(self) -> "Datapipeline":
        '''(experimental) Grants permission to add or modify tags for the specified pipeline.

        Access Level: Tagging

        Possible conditions:

        - .ifPipelineCreator()
        - .ifTag()
        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/datapipeline/latest/APIReference/API_AddTags.html

        :stability: experimental
        '''
        return typing.cast("Datapipeline", jsii.invoke(self, "toAddTags", []))

    @jsii.member(jsii_name="toCreatePipeline")
    def to_create_pipeline(self) -> "Datapipeline":
        '''(experimental) Grants permission to create a new, empty pipeline.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifTag()

        Dependent actions:

        - datapipeline:AddTags

        https://docs.aws.amazon.com/datapipeline/latest/APIReference/API_CreatePipeline.html

        :stability: experimental
        '''
        return typing.cast("Datapipeline", jsii.invoke(self, "toCreatePipeline", []))

    @jsii.member(jsii_name="toDeactivatePipeline")
    def to_deactivate_pipeline(self) -> "Datapipeline":
        '''(experimental) Grants permission to Deactivate the specified running pipeline.

        Access Level: Write

        Possible conditions:

        - .ifPipelineCreator()
        - .ifTag()
        - .ifWorkerGroup()

        https://docs.aws.amazon.com/datapipeline/latest/APIReference/API_DeactivatePipeline.html

        :stability: experimental
        '''
        return typing.cast("Datapipeline", jsii.invoke(self, "toDeactivatePipeline", []))

    @jsii.member(jsii_name="toDeletePipeline")
    def to_delete_pipeline(self) -> "Datapipeline":
        '''(experimental) Grants permission to delete a pipeline, its pipeline definition, and its run history.

        Access Level: Write

        Possible conditions:

        - .ifPipelineCreator()
        - .ifTag()

        https://docs.aws.amazon.com/datapipeline/latest/APIReference/API_DeletePipeline.html

        :stability: experimental
        '''
        return typing.cast("Datapipeline", jsii.invoke(self, "toDeletePipeline", []))

    @jsii.member(jsii_name="toDescribeObjects")
    def to_describe_objects(self) -> "Datapipeline":
        '''(experimental) Grants permission to get the object definitions for a set of objects associated with the pipeline.

        Access Level: Read

        Possible conditions:

        - .ifPipelineCreator()
        - .ifTag()

        https://docs.aws.amazon.com/datapipeline/latest/APIReference/API_DescribeObjects.html

        :stability: experimental
        '''
        return typing.cast("Datapipeline", jsii.invoke(self, "toDescribeObjects", []))

    @jsii.member(jsii_name="toDescribePipelines")
    def to_describe_pipelines(self) -> "Datapipeline":
        '''(experimental) Grants permission to retrieves metadata about one or more pipelines.

        Access Level: Read

        Possible conditions:

        - .ifPipelineCreator()
        - .ifTag()

        https://docs.aws.amazon.com/datapipeline/latest/APIReference/API_DescribePipelines.html

        :stability: experimental
        '''
        return typing.cast("Datapipeline", jsii.invoke(self, "toDescribePipelines", []))

    @jsii.member(jsii_name="toEvaluateExpression")
    def to_evaluate_expression(self) -> "Datapipeline":
        '''(experimental) Grants permission to task runners to call EvaluateExpression, to evaluate a string in the context of the specified object.

        Access Level: Read

        Possible conditions:

        - .ifPipelineCreator()
        - .ifTag()

        https://docs.aws.amazon.com/datapipeline/latest/APIReference/API_EvaluateExpression.html

        :stability: experimental
        '''
        return typing.cast("Datapipeline", jsii.invoke(self, "toEvaluateExpression", []))

    @jsii.member(jsii_name="toGetAccountLimits")
    def to_get_account_limits(self) -> "Datapipeline":
        '''(experimental) Grants permission to call GetAccountLimits.

        Access Level: List

        https://docs.aws.amazon.com/datapipeline/latest/APIReference/API_GetAccountLimits.html

        :stability: experimental
        '''
        return typing.cast("Datapipeline", jsii.invoke(self, "toGetAccountLimits", []))

    @jsii.member(jsii_name="toGetPipelineDefinition")
    def to_get_pipeline_definition(self) -> "Datapipeline":
        '''(experimental) Grants permission to gets the definition of the specified pipeline.

        Access Level: Read

        Possible conditions:

        - .ifPipelineCreator()
        - .ifTag()
        - .ifWorkerGroup()

        https://docs.aws.amazon.com/datapipeline/latest/APIReference/API_GetPipelineDefinition.html

        :stability: experimental
        '''
        return typing.cast("Datapipeline", jsii.invoke(self, "toGetPipelineDefinition", []))

    @jsii.member(jsii_name="toListPipelines")
    def to_list_pipelines(self) -> "Datapipeline":
        '''(experimental) Grants permission to list the pipeline identifiers for all active pipelines that you have permission to access.

        Access Level: List

        https://docs.aws.amazon.com/datapipeline/latest/APIReference/API_ListPipelines.html

        :stability: experimental
        '''
        return typing.cast("Datapipeline", jsii.invoke(self, "toListPipelines", []))

    @jsii.member(jsii_name="toPollForTask")
    def to_poll_for_task(self) -> "Datapipeline":
        '''(experimental) Grants permission to task runners to call PollForTask, to receive a task to perform from AWS Data Pipeline.

        Access Level: Write

        Possible conditions:

        - .ifWorkerGroup()

        https://docs.aws.amazon.com/datapipeline/latest/APIReference/API_PollForTask.html

        :stability: experimental
        '''
        return typing.cast("Datapipeline", jsii.invoke(self, "toPollForTask", []))

    @jsii.member(jsii_name="toPutAccountLimits")
    def to_put_account_limits(self) -> "Datapipeline":
        '''(experimental) Grants permission to call PutAccountLimits.

        Access Level: Write

        https://docs.aws.amazon.com/datapipeline/latest/APIReference/API_PutAccountLimits.html

        :stability: experimental
        '''
        return typing.cast("Datapipeline", jsii.invoke(self, "toPutAccountLimits", []))

    @jsii.member(jsii_name="toPutPipelineDefinition")
    def to_put_pipeline_definition(self) -> "Datapipeline":
        '''(experimental) Grants permission to add tasks, schedules, and preconditions to the specified pipeline.

        Access Level: Write

        Possible conditions:

        - .ifPipelineCreator()
        - .ifTag()
        - .ifWorkerGroup()

        https://docs.aws.amazon.com/datapipeline/latest/APIReference/API_PutPipelineDefinition.html

        :stability: experimental
        '''
        return typing.cast("Datapipeline", jsii.invoke(self, "toPutPipelineDefinition", []))

    @jsii.member(jsii_name="toQueryObjects")
    def to_query_objects(self) -> "Datapipeline":
        '''(experimental) Grants permission to query the specified pipeline for the names of objects that match the specified set of conditions.

        Access Level: Read

        Possible conditions:

        - .ifPipelineCreator()
        - .ifTag()

        https://docs.aws.amazon.com/datapipeline/latest/APIReference/API_QueryObjects.html

        :stability: experimental
        '''
        return typing.cast("Datapipeline", jsii.invoke(self, "toQueryObjects", []))

    @jsii.member(jsii_name="toRemoveTags")
    def to_remove_tags(self) -> "Datapipeline":
        '''(experimental) Grants permission to remove existing tags from the specified pipeline.

        Access Level: Tagging

        Possible conditions:

        - .ifPipelineCreator()
        - .ifTag()
        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/datapipeline/latest/APIReference/API_RemoveTags.html

        :stability: experimental
        '''
        return typing.cast("Datapipeline", jsii.invoke(self, "toRemoveTags", []))

    @jsii.member(jsii_name="toReportTaskProgress")
    def to_report_task_progress(self) -> "Datapipeline":
        '''(experimental) Grants permission to task runners to call ReportTaskProgress, when they are assigned a task to acknowledge that it has the task.

        Access Level: Write

        https://docs.aws.amazon.com/datapipeline/latest/APIReference/API_ReportTaskProgress.html

        :stability: experimental
        '''
        return typing.cast("Datapipeline", jsii.invoke(self, "toReportTaskProgress", []))

    @jsii.member(jsii_name="toReportTaskRunnerHeartbeat")
    def to_report_task_runner_heartbeat(self) -> "Datapipeline":
        '''(experimental) Grants permission to task runners to call ReportTaskRunnerHeartbeat every 15 minutes to indicate that they are operational.

        Access Level: Write

        https://docs.aws.amazon.com/datapipeline/latest/APIReference/API_ReportTaskRunnerHeartbeat.html

        :stability: experimental
        '''
        return typing.cast("Datapipeline", jsii.invoke(self, "toReportTaskRunnerHeartbeat", []))

    @jsii.member(jsii_name="toSetStatus")
    def to_set_status(self) -> "Datapipeline":
        '''(experimental) Grants permission to requests that the status of the specified physical or logical pipeline objects be updated in the specified pipeline.

        Access Level: Write

        Possible conditions:

        - .ifPipelineCreator()
        - .ifTag()

        https://docs.aws.amazon.com/datapipeline/latest/APIReference/API_SetStatus.html

        :stability: experimental
        '''
        return typing.cast("Datapipeline", jsii.invoke(self, "toSetStatus", []))

    @jsii.member(jsii_name="toSetTaskStatus")
    def to_set_task_status(self) -> "Datapipeline":
        '''(experimental) Grants permission to task runners to call SetTaskStatus to notify AWS Data Pipeline that a task is completed and provide information about the final status.

        Access Level: Write

        https://docs.aws.amazon.com/datapipeline/latest/APIReference/API_SetTaskStatus.html

        :stability: experimental
        '''
        return typing.cast("Datapipeline", jsii.invoke(self, "toSetTaskStatus", []))

    @jsii.member(jsii_name="toValidatePipelineDefinition")
    def to_validate_pipeline_definition(self) -> "Datapipeline":
        '''(experimental) Grants permission to validate the specified pipeline definition to ensure that it is well formed and can be run without error.

        Access Level: Read

        Possible conditions:

        - .ifPipelineCreator()
        - .ifTag()
        - .ifWorkerGroup()

        https://docs.aws.amazon.com/datapipeline/latest/APIReference/API_ValidatePipelineDefinition.html

        :stability: experimental
        '''
        return typing.cast("Datapipeline", jsii.invoke(self, "toValidatePipelineDefinition", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1227eb94fdefdd920868b8046e467e06ef07916002eb5ab0975166cdc98d6b38)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__58afce216a258a0996ae45c65e1dce58ce9131bcdd98380c4de7ee525618ff22)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Datasync(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Datasync",
):
    '''(experimental) Statement provider for service `datasync <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsdatasync.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `datasync <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsdatasync.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onAgent")
    def on_agent(
        self,
        agent_id: builtins.str,
        account_id: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Datasync":
        '''(experimental) Adds a resource of type agent to the statement.

        https://docs.aws.amazon.com/datasync/latest/userguide/working-with-agents.html

        :param agent_id: - Identifier for the agentId.
        :param account_id: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__54a2a822ec3b38de84073cabd8e1ad861a62de10fcda3e2b8bc7fe4e6e5d32a2)
            check_type(argname="argument agent_id", value=agent_id, expected_type=type_hints["agent_id"])
            check_type(argname="argument account_id", value=account_id, expected_type=type_hints["account_id"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Datasync", jsii.invoke(self, "onAgent", [agent_id, account_id, region, partition]))

    @jsii.member(jsii_name="onLocation")
    def on_location(
        self,
        location_id: builtins.str,
        account_id: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Datasync":
        '''(experimental) Adds a resource of type location to the statement.

        https://docs.aws.amazon.com/datasync/latest/userguide/working-with-locations.html

        :param location_id: - Identifier for the locationId.
        :param account_id: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7b93f0375218496e2cd462d79efbb96629bc085ca6f7b28fceafcb09980e3192)
            check_type(argname="argument location_id", value=location_id, expected_type=type_hints["location_id"])
            check_type(argname="argument account_id", value=account_id, expected_type=type_hints["account_id"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Datasync", jsii.invoke(self, "onLocation", [location_id, account_id, region, partition]))

    @jsii.member(jsii_name="onTask")
    def on_task(
        self,
        task_id: builtins.str,
        account_id: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Datasync":
        '''(experimental) Adds a resource of type task to the statement.

        https://docs.aws.amazon.com/datasync/latest/userguide/working-with-tasks.html

        :param task_id: - Identifier for the taskId.
        :param account_id: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c5628fc097441d28fb0d2e29ef33b80e9be280f83463307ce9f52c78da12501f)
            check_type(argname="argument task_id", value=task_id, expected_type=type_hints["task_id"])
            check_type(argname="argument account_id", value=account_id, expected_type=type_hints["account_id"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Datasync", jsii.invoke(self, "onTask", [task_id, account_id, region, partition]))

    @jsii.member(jsii_name="onTaskexecution")
    def on_taskexecution(
        self,
        task_id: builtins.str,
        execution_id: builtins.str,
        account_id: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Datasync":
        '''(experimental) Adds a resource of type taskexecution to the statement.

        https://docs.aws.amazon.com/datasync/latest/userguide/working-with-task-executions.html

        :param task_id: - Identifier for the taskId.
        :param execution_id: - Identifier for the executionId.
        :param account_id: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__13e612203e44e3aa7ba6b8161b6ec84977d59ea6cb260fa0be7c1775313b9661)
            check_type(argname="argument task_id", value=task_id, expected_type=type_hints["task_id"])
            check_type(argname="argument execution_id", value=execution_id, expected_type=type_hints["execution_id"])
            check_type(argname="argument account_id", value=account_id, expected_type=type_hints["account_id"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Datasync", jsii.invoke(self, "onTaskexecution", [task_id, execution_id, account_id, region, partition]))

    @jsii.member(jsii_name="toCancelTaskExecution")
    def to_cancel_task_execution(self) -> "Datasync":
        '''(experimental) Grants permission to cancel execution of a sync task.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/datasync/latest/userguide/API_CancelTaskExecution.html

        :stability: experimental
        '''
        return typing.cast("Datasync", jsii.invoke(self, "toCancelTaskExecution", []))

    @jsii.member(jsii_name="toCreateAgent")
    def to_create_agent(self) -> "Datasync":
        '''(experimental) Grants permission to activate an agent that you have deployed on your host.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/datasync/latest/userguide/API_CreateAgent.html

        :stability: experimental
        '''
        return typing.cast("Datasync", jsii.invoke(self, "toCreateAgent", []))

    @jsii.member(jsii_name="toCreateLocationEfs")
    def to_create_location_efs(self) -> "Datasync":
        '''(experimental) Grants permission to create an endpoint for an Amazon EFS file system.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/datasync/latest/userguide/API_CreateLocationEfs.html

        :stability: experimental
        '''
        return typing.cast("Datasync", jsii.invoke(self, "toCreateLocationEfs", []))

    @jsii.member(jsii_name="toCreateLocationFsxLustre")
    def to_create_location_fsx_lustre(self) -> "Datasync":
        '''(experimental) Grants permission to create an endpoint for an Amazon Fsx Lustre.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/datasync/latest/userguide/API_CreateLocationFsxLustre.html

        :stability: experimental
        '''
        return typing.cast("Datasync", jsii.invoke(self, "toCreateLocationFsxLustre", []))

    @jsii.member(jsii_name="toCreateLocationFsxOntap")
    def to_create_location_fsx_ontap(self) -> "Datasync":
        '''(experimental) Grants permission to create an endpoint for Amazon FSx for ONTAP.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/datasync/latest/userguide/API_CreateLocationFsxOntap.html

        :stability: experimental
        '''
        return typing.cast("Datasync", jsii.invoke(self, "toCreateLocationFsxOntap", []))

    @jsii.member(jsii_name="toCreateLocationFsxOpenZfs")
    def to_create_location_fsx_open_zfs(self) -> "Datasync":
        '''(experimental) Grants permission to create an endpoint for Amazon FSx for OpenZFS.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/datasync/latest/userguide/API_CreateLocationFsxOpenZfs.html

        :stability: experimental
        '''
        return typing.cast("Datasync", jsii.invoke(self, "toCreateLocationFsxOpenZfs", []))

    @jsii.member(jsii_name="toCreateLocationFsxWindows")
    def to_create_location_fsx_windows(self) -> "Datasync":
        '''(experimental) Grants permission to create an endpoint for an Amazon FSx Windows File Server file system.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/datasync/latest/userguide/API_CreateLocationFsxWindows.html

        :stability: experimental
        '''
        return typing.cast("Datasync", jsii.invoke(self, "toCreateLocationFsxWindows", []))

    @jsii.member(jsii_name="toCreateLocationHdfs")
    def to_create_location_hdfs(self) -> "Datasync":
        '''(experimental) Grants permission to create an endpoint for an Amazon Hdfs.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/datasync/latest/userguide/API_CreateLocationHdfs.html

        :stability: experimental
        '''
        return typing.cast("Datasync", jsii.invoke(self, "toCreateLocationHdfs", []))

    @jsii.member(jsii_name="toCreateLocationNfs")
    def to_create_location_nfs(self) -> "Datasync":
        '''(experimental) Grants permission to create an endpoint for a NFS file system.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/datasync/latest/userguide/API_CreateLocationNfs.html

        :stability: experimental
        '''
        return typing.cast("Datasync", jsii.invoke(self, "toCreateLocationNfs", []))

    @jsii.member(jsii_name="toCreateLocationObjectStorage")
    def to_create_location_object_storage(self) -> "Datasync":
        '''(experimental) Grants permission to create an endpoint for a self-managed object storage bucket.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/datasync/latest/userguide/API_CreateLocationObjectStorage.html

        :stability: experimental
        '''
        return typing.cast("Datasync", jsii.invoke(self, "toCreateLocationObjectStorage", []))

    @jsii.member(jsii_name="toCreateLocationS3")
    def to_create_location_s3(self) -> "Datasync":
        '''(experimental) Grants permission to create an endpoint for an Amazon S3 bucket.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/datasync/latest/userguide/API_CreateLocationS3.html

        :stability: experimental
        '''
        return typing.cast("Datasync", jsii.invoke(self, "toCreateLocationS3", []))

    @jsii.member(jsii_name="toCreateLocationSmb")
    def to_create_location_smb(self) -> "Datasync":
        '''(experimental) Grants permission to create an endpoint for an SMB file system.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/datasync/latest/userguide/API_CreateLocationSmb.html

        :stability: experimental
        '''
        return typing.cast("Datasync", jsii.invoke(self, "toCreateLocationSmb", []))

    @jsii.member(jsii_name="toCreateTask")
    def to_create_task(self) -> "Datasync":
        '''(experimental) Grants permission to create a sync task.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/datasync/latest/userguide/API_CreateTask.html

        :stability: experimental
        '''
        return typing.cast("Datasync", jsii.invoke(self, "toCreateTask", []))

    @jsii.member(jsii_name="toDeleteAgent")
    def to_delete_agent(self) -> "Datasync":
        '''(experimental) Grants permission to delete an agent.

        Access Level: Write

        https://docs.aws.amazon.com/datasync/latest/userguide/API_DeleteAgent.html

        :stability: experimental
        '''
        return typing.cast("Datasync", jsii.invoke(self, "toDeleteAgent", []))

    @jsii.member(jsii_name="toDeleteLocation")
    def to_delete_location(self) -> "Datasync":
        '''(experimental) Grants permission to delete a location used by AWS DataSync.

        Access Level: Write

        https://docs.aws.amazon.com/datasync/latest/userguide/API_DeleteLocation.html

        :stability: experimental
        '''
        return typing.cast("Datasync", jsii.invoke(self, "toDeleteLocation", []))

    @jsii.member(jsii_name="toDeleteTask")
    def to_delete_task(self) -> "Datasync":
        '''(experimental) Grants permission to delete a sync task.

        Access Level: Write

        https://docs.aws.amazon.com/datasync/latest/userguide/API_DeleteTask.html

        :stability: experimental
        '''
        return typing.cast("Datasync", jsii.invoke(self, "toDeleteTask", []))

    @jsii.member(jsii_name="toDescribeAgent")
    def to_describe_agent(self) -> "Datasync":
        '''(experimental) Grants permission to view metadata such as name, network interfaces, and the status (that is, whether the agent is running or not) about a sync agent.

        Access Level: Read

        https://docs.aws.amazon.com/datasync/latest/userguide/API_DescribeAgent.html

        :stability: experimental
        '''
        return typing.cast("Datasync", jsii.invoke(self, "toDescribeAgent", []))

    @jsii.member(jsii_name="toDescribeLocationEfs")
    def to_describe_location_efs(self) -> "Datasync":
        '''(experimental) Grants permission to view metadata, such as the path information about an Amazon EFS sync location.

        Access Level: Read

        https://docs.aws.amazon.com/datasync/latest/userguide/API_DescribeLocationEfs.html

        :stability: experimental
        '''
        return typing.cast("Datasync", jsii.invoke(self, "toDescribeLocationEfs", []))

    @jsii.member(jsii_name="toDescribeLocationFsxLustre")
    def to_describe_location_fsx_lustre(self) -> "Datasync":
        '''(experimental) Grants permission to view metadata, such as the path information about an Amazon FSx Lustre sync location.

        Access Level: Read

        https://docs.aws.amazon.com/datasync/latest/userguide/API_DescribeLocationFsxLustre.html

        :stability: experimental
        '''
        return typing.cast("Datasync", jsii.invoke(self, "toDescribeLocationFsxLustre", []))

    @jsii.member(jsii_name="toDescribeLocationFsxOntap")
    def to_describe_location_fsx_ontap(self) -> "Datasync":
        '''(experimental) Grants permission to view metadata, such as the path information about an Amazon FSx for ONTAP sync location.

        Access Level: Read

        https://docs.aws.amazon.com/datasync/latest/userguide/API_DescribeLocationFsxOntap.html

        :stability: experimental
        '''
        return typing.cast("Datasync", jsii.invoke(self, "toDescribeLocationFsxOntap", []))

    @jsii.member(jsii_name="toDescribeLocationFsxOpenZfs")
    def to_describe_location_fsx_open_zfs(self) -> "Datasync":
        '''(experimental) Grants permission to view metadata, such as the path information about an Amazon FSx OpenZFS sync location.

        Access Level: Read

        https://docs.aws.amazon.com/datasync/latest/userguide/API_DescribeLocationFsxOpenZfs.html

        :stability: experimental
        '''
        return typing.cast("Datasync", jsii.invoke(self, "toDescribeLocationFsxOpenZfs", []))

    @jsii.member(jsii_name="toDescribeLocationFsxWindows")
    def to_describe_location_fsx_windows(self) -> "Datasync":
        '''(experimental) Grants permission to view metadata, such as the path information about an Amazon FSx Windows sync location.

        Access Level: Read

        https://docs.aws.amazon.com/datasync/latest/userguide/API_DescribeLocationFsxWindows.html

        :stability: experimental
        '''
        return typing.cast("Datasync", jsii.invoke(self, "toDescribeLocationFsxWindows", []))

    @jsii.member(jsii_name="toDescribeLocationHdfs")
    def to_describe_location_hdfs(self) -> "Datasync":
        '''(experimental) Grants permission to view metadata, such as the path information about an Amazon HDFS sync location.

        Access Level: Read

        https://docs.aws.amazon.com/datasync/latest/userguide/API_DescribeLocationHdfs.html

        :stability: experimental
        '''
        return typing.cast("Datasync", jsii.invoke(self, "toDescribeLocationHdfs", []))

    @jsii.member(jsii_name="toDescribeLocationNfs")
    def to_describe_location_nfs(self) -> "Datasync":
        '''(experimental) Grants permission to view metadata, such as the path information, about a NFS sync location.

        Access Level: Read

        https://docs.aws.amazon.com/datasync/latest/userguide/API_DescribeLocationNfs.html

        :stability: experimental
        '''
        return typing.cast("Datasync", jsii.invoke(self, "toDescribeLocationNfs", []))

    @jsii.member(jsii_name="toDescribeLocationObjectStorage")
    def to_describe_location_object_storage(self) -> "Datasync":
        '''(experimental) Grants permission to view metadata about a self-managed object storage server location.

        Access Level: Read

        https://docs.aws.amazon.com/datasync/latest/userguide/API_DescribeLocationObjectStorage.html

        :stability: experimental
        '''
        return typing.cast("Datasync", jsii.invoke(self, "toDescribeLocationObjectStorage", []))

    @jsii.member(jsii_name="toDescribeLocationS3")
    def to_describe_location_s3(self) -> "Datasync":
        '''(experimental) Grants permission to view metadata, such as bucket name, about an Amazon S3 bucket sync location.

        Access Level: Read

        https://docs.aws.amazon.com/datasync/latest/userguide/API_DescribeLocationS3.html

        :stability: experimental
        '''
        return typing.cast("Datasync", jsii.invoke(self, "toDescribeLocationS3", []))

    @jsii.member(jsii_name="toDescribeLocationSmb")
    def to_describe_location_smb(self) -> "Datasync":
        '''(experimental) Grants permission to view metadata, such as the path information, about an SMB sync location.

        Access Level: Read

        https://docs.aws.amazon.com/datasync/latest/userguide/API_DescribeLocationSmb.html

        :stability: experimental
        '''
        return typing.cast("Datasync", jsii.invoke(self, "toDescribeLocationSmb", []))

    @jsii.member(jsii_name="toDescribeTask")
    def to_describe_task(self) -> "Datasync":
        '''(experimental) Grants permission to view metadata about a sync task.

        Access Level: Read

        https://docs.aws.amazon.com/datasync/latest/userguide/API_DescribeTask.html

        :stability: experimental
        '''
        return typing.cast("Datasync", jsii.invoke(self, "toDescribeTask", []))

    @jsii.member(jsii_name="toDescribeTaskExecution")
    def to_describe_task_execution(self) -> "Datasync":
        '''(experimental) Grants permission to view metadata about a sync task that is being executed.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/datasync/latest/userguide/API_DescribeTaskExecution.html

        :stability: experimental
        '''
        return typing.cast("Datasync", jsii.invoke(self, "toDescribeTaskExecution", []))

    @jsii.member(jsii_name="toListAgents")
    def to_list_agents(self) -> "Datasync":
        '''(experimental) Grants permission to list agents owned by an AWS account in a region specified in the request.

        Access Level: List

        https://docs.aws.amazon.com/datasync/latest/userguide/API_ListAgents.html

        :stability: experimental
        '''
        return typing.cast("Datasync", jsii.invoke(self, "toListAgents", []))

    @jsii.member(jsii_name="toListLocations")
    def to_list_locations(self) -> "Datasync":
        '''(experimental) Grants permission to list source and destination sync locations.

        Access Level: List

        https://docs.aws.amazon.com/datasync/latest/userguide/API_ListLocations.html

        :stability: experimental
        '''
        return typing.cast("Datasync", jsii.invoke(self, "toListLocations", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Datasync":
        '''(experimental) Grants permission to list tags that have been added to the specified resource.

        Access Level: Read

        https://docs.aws.amazon.com/datasync/latest/userguide/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("Datasync", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toListTaskExecutions")
    def to_list_task_executions(self) -> "Datasync":
        '''(experimental) Grants permission to list executed sync tasks.

        Access Level: List

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/datasync/latest/userguide/API_ListTaskExecutions.html

        :stability: experimental
        '''
        return typing.cast("Datasync", jsii.invoke(self, "toListTaskExecutions", []))

    @jsii.member(jsii_name="toListTasks")
    def to_list_tasks(self) -> "Datasync":
        '''(experimental) Grants permission to list of all the sync tasks.

        Access Level: List

        https://docs.aws.amazon.com/datasync/latest/userguide/API_ListTasks.html

        :stability: experimental
        '''
        return typing.cast("Datasync", jsii.invoke(self, "toListTasks", []))

    @jsii.member(jsii_name="toStartTaskExecution")
    def to_start_task_execution(self) -> "Datasync":
        '''(experimental) Grants permission to start a specific invocation of a sync task.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsResourceTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/datasync/latest/userguide/API_StartTaskExecution.html

        :stability: experimental
        '''
        return typing.cast("Datasync", jsii.invoke(self, "toStartTaskExecution", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Datasync":
        '''(experimental) Grants permission to apply a key-value pair to an AWS resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/datasync/latest/userguide/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("Datasync", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Datasync":
        '''(experimental) Grants permission to remove one or more tags from the specified resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/datasync/latest/userguide/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("Datasync", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateAgent")
    def to_update_agent(self) -> "Datasync":
        '''(experimental) Grants permission to update the name of an agent.

        Access Level: Write

        https://docs.aws.amazon.com/datasync/latest/userguide/API_UpdateAgent.html

        :stability: experimental
        '''
        return typing.cast("Datasync", jsii.invoke(self, "toUpdateAgent", []))

    @jsii.member(jsii_name="toUpdateLocationHdfs")
    def to_update_location_hdfs(self) -> "Datasync":
        '''(experimental) Grants permission to update an HDFS sync Location.

        Access Level: Write

        https://docs.aws.amazon.com/datasync/latest/userguide/API_UpdateLocationHdfs.html

        :stability: experimental
        '''
        return typing.cast("Datasync", jsii.invoke(self, "toUpdateLocationHdfs", []))

    @jsii.member(jsii_name="toUpdateLocationNfs")
    def to_update_location_nfs(self) -> "Datasync":
        '''(experimental) Grants permission to update an NFS sync Location.

        Access Level: Write

        https://docs.aws.amazon.com/datasync/latest/userguide/API_UpdateLocationNfs.html

        :stability: experimental
        '''
        return typing.cast("Datasync", jsii.invoke(self, "toUpdateLocationNfs", []))

    @jsii.member(jsii_name="toUpdateLocationObjectStorage")
    def to_update_location_object_storage(self) -> "Datasync":
        '''(experimental) Grants permission to update a self-managed object storage server location.

        Access Level: Write

        https://docs.aws.amazon.com/datasync/latest/userguide/API_UpdateLocationObjectStorage.html

        :stability: experimental
        '''
        return typing.cast("Datasync", jsii.invoke(self, "toUpdateLocationObjectStorage", []))

    @jsii.member(jsii_name="toUpdateLocationSmb")
    def to_update_location_smb(self) -> "Datasync":
        '''(experimental) Grants permission to update a SMB sync location.

        Access Level: Write

        https://docs.aws.amazon.com/datasync/latest/userguide/API_UpdateLocationSmb.html

        :stability: experimental
        '''
        return typing.cast("Datasync", jsii.invoke(self, "toUpdateLocationSmb", []))

    @jsii.member(jsii_name="toUpdateTask")
    def to_update_task(self) -> "Datasync":
        '''(experimental) Grants permission to update metadata associated with a sync task.

        Access Level: Write

        https://docs.aws.amazon.com/datasync/latest/userguide/API_UpdateTask.html

        :stability: experimental
        '''
        return typing.cast("Datasync", jsii.invoke(self, "toUpdateTask", []))

    @jsii.member(jsii_name="toUpdateTaskExecution")
    def to_update_task_execution(self) -> "Datasync":
        '''(experimental) Grants permission to update execution of a sync task.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/datasync/latest/userguide/API_UpdateTaskExecution.html

        :stability: experimental
        '''
        return typing.cast("Datasync", jsii.invoke(self, "toUpdateTaskExecution", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__83cb6ac250277a28dd8da25a0e54bc764ab94135a4187fe081f75d33e0076a1b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5785fd762a201d481e1d821c7035199d97fc4fa279d9d448f4da88baa8834f40)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Dax(PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Dax"):
    '''(experimental) Statement provider for service `dax <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazondynamodbacceleratordax.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `dax <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazondynamodbacceleratordax.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="ifEnclosingOperation")
    def if_enclosing_operation(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Dax":
        '''(experimental) Used to block Transactions APIs calls and allow the non-Transaction APIs calls and vice-versa.

        https://docs.aws.amazon.com/amazondynamodb/latest/developerguide/DAX.access-control.htmlspecifying-conditions.html#FGAC_DDB.ConditionKeys

        Applies to actions:

        - .toDeleteItem()
        - .toGetItem()
        - .toPutItem()
        - .toUpdateItem()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e47411505e93849c31429ebafb277d2f1e2bb0500c91aaa52c6936af6c5b3877)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Dax", jsii.invoke(self, "ifEnclosingOperation", [value, operator]))

    @jsii.member(jsii_name="onApplication")
    def on_application(
        self,
        cluster_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Dax":
        '''(experimental) Adds a resource of type application to the statement.

        https://docs.aws.amazon.com/amazondynamodb/latest/developerguide/DAX.access-control.html

        :param cluster_name: - Identifier for the clusterName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b4076b6f88b21feefff4dc9e3fdd9de17662f8490e99c00a464c14ba666f52f5)
            check_type(argname="argument cluster_name", value=cluster_name, expected_type=type_hints["cluster_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Dax", jsii.invoke(self, "onApplication", [cluster_name, account, region, partition]))

    @jsii.member(jsii_name="toBatchGetItem")
    def to_batch_get_item(self) -> "Dax":
        '''(experimental) Grants permission to return the attributes of one or more items from one or more tables.

        Access Level: Read

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_BatchGetItem.html

        :stability: experimental
        '''
        return typing.cast("Dax", jsii.invoke(self, "toBatchGetItem", []))

    @jsii.member(jsii_name="toBatchWriteItem")
    def to_batch_write_item(self) -> "Dax":
        '''(experimental) Grants permission to put or delete multiple items in one or more tables.

        Access Level: Write

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_BatchWriteItem.html

        :stability: experimental
        '''
        return typing.cast("Dax", jsii.invoke(self, "toBatchWriteItem", []))

    @jsii.member(jsii_name="toConditionCheckItem")
    def to_condition_check_item(self) -> "Dax":
        '''(experimental) Grants permission to the ConditionCheckItem operation that checks the existence of a set of attributes for the item with the given primary key.

        Access Level: Read

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_ConditionCheckItem.html

        :stability: experimental
        '''
        return typing.cast("Dax", jsii.invoke(self, "toConditionCheckItem", []))

    @jsii.member(jsii_name="toCreateCluster")
    def to_create_cluster(self) -> "Dax":
        '''(experimental) Grants permission to create a DAX cluster.

        Access Level: Write

        Dependent actions:

        - dax:CreateParameterGroup
        - dax:CreateSubnetGroup
        - ec2:CreateNetworkInterface
        - ec2:DeleteNetworkInterface
        - ec2:DescribeNetworkInterfaces
        - ec2:DescribeSecurityGroups
        - ec2:DescribeSubnets
        - ec2:DescribeVpcs
        - iam:GetRole
        - iam:PassRole

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_dax_CreateCluster.html

        :stability: experimental
        '''
        return typing.cast("Dax", jsii.invoke(self, "toCreateCluster", []))

    @jsii.member(jsii_name="toCreateParameterGroup")
    def to_create_parameter_group(self) -> "Dax":
        '''(experimental) Grants permission to create a parameter group.

        Access Level: Write

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_dax_CreateParameterGroup.html

        :stability: experimental
        '''
        return typing.cast("Dax", jsii.invoke(self, "toCreateParameterGroup", []))

    @jsii.member(jsii_name="toCreateSubnetGroup")
    def to_create_subnet_group(self) -> "Dax":
        '''(experimental) Grants permission to create a subnet group.

        Access Level: Write

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_dax_CreateSubnetGroup.html

        :stability: experimental
        '''
        return typing.cast("Dax", jsii.invoke(self, "toCreateSubnetGroup", []))

    @jsii.member(jsii_name="toDecreaseReplicationFactor")
    def to_decrease_replication_factor(self) -> "Dax":
        '''(experimental) Grants permission to remove one or more nodes from a DAX cluster.

        Access Level: Write

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_dax_DecreaseReplicationFactor.html

        :stability: experimental
        '''
        return typing.cast("Dax", jsii.invoke(self, "toDecreaseReplicationFactor", []))

    @jsii.member(jsii_name="toDeleteCluster")
    def to_delete_cluster(self) -> "Dax":
        '''(experimental) Grants permission to delete a previously provisioned DAX cluster.

        Access Level: Write

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_dax_DeleteCluster.html

        :stability: experimental
        '''
        return typing.cast("Dax", jsii.invoke(self, "toDeleteCluster", []))

    @jsii.member(jsii_name="toDeleteItem")
    def to_delete_item(self) -> "Dax":
        '''(experimental) Grants permission to delete a single item in a table by primary key.

        Access Level: Write

        Possible conditions:

        - .ifEnclosingOperation()

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_DeleteItem.html

        :stability: experimental
        '''
        return typing.cast("Dax", jsii.invoke(self, "toDeleteItem", []))

    @jsii.member(jsii_name="toDeleteParameterGroup")
    def to_delete_parameter_group(self) -> "Dax":
        '''(experimental) Grants permission to delete the specified parameter group.

        Access Level: Write

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_dax_DeleteParameterGroup.html

        :stability: experimental
        '''
        return typing.cast("Dax", jsii.invoke(self, "toDeleteParameterGroup", []))

    @jsii.member(jsii_name="toDeleteSubnetGroup")
    def to_delete_subnet_group(self) -> "Dax":
        '''(experimental) Grants permission to delete a subnet group.

        Access Level: Write

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_dax_DeleteSubnetGroup.html

        :stability: experimental
        '''
        return typing.cast("Dax", jsii.invoke(self, "toDeleteSubnetGroup", []))

    @jsii.member(jsii_name="toDescribeClusters")
    def to_describe_clusters(self) -> "Dax":
        '''(experimental) Grants permission to return information about all provisioned DAX clusters.

        Access Level: List

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_dax_DescribeClusters.html

        :stability: experimental
        '''
        return typing.cast("Dax", jsii.invoke(self, "toDescribeClusters", []))

    @jsii.member(jsii_name="toDescribeDefaultParameters")
    def to_describe_default_parameters(self) -> "Dax":
        '''(experimental) Grants permission to return the default system parameter information for DAX.

        Access Level: List

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_dax_DescribeDefaultParameters.html

        :stability: experimental
        '''
        return typing.cast("Dax", jsii.invoke(self, "toDescribeDefaultParameters", []))

    @jsii.member(jsii_name="toDescribeEvents")
    def to_describe_events(self) -> "Dax":
        '''(experimental) Grants permission to return events related to DAX clusters and parameter groups.

        Access Level: List

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_dax_DescribeEvents.html

        :stability: experimental
        '''
        return typing.cast("Dax", jsii.invoke(self, "toDescribeEvents", []))

    @jsii.member(jsii_name="toDescribeParameterGroups")
    def to_describe_parameter_groups(self) -> "Dax":
        '''(experimental) Grants permission to return a list of parameter group descriptions.

        Access Level: List

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_dax_DescribeParameterGroups.html

        :stability: experimental
        '''
        return typing.cast("Dax", jsii.invoke(self, "toDescribeParameterGroups", []))

    @jsii.member(jsii_name="toDescribeParameters")
    def to_describe_parameters(self) -> "Dax":
        '''(experimental) Grants permission to return the detailed parameter list for a particular parameter group.

        Access Level: Read

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_dax_DescribeParameters.html

        :stability: experimental
        '''
        return typing.cast("Dax", jsii.invoke(self, "toDescribeParameters", []))

    @jsii.member(jsii_name="toDescribeSubnetGroups")
    def to_describe_subnet_groups(self) -> "Dax":
        '''(experimental) Grants permission to return a list of subnet group descriptions.

        Access Level: List

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_dax_DescribeSubnetGroups.html

        :stability: experimental
        '''
        return typing.cast("Dax", jsii.invoke(self, "toDescribeSubnetGroups", []))

    @jsii.member(jsii_name="toGetItem")
    def to_get_item(self) -> "Dax":
        '''(experimental) Grants permission to the GetItem operation that returns a set of attributes for the item with the given primary key.

        Access Level: Read

        Possible conditions:

        - .ifEnclosingOperation()

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_GetItem.html

        :stability: experimental
        '''
        return typing.cast("Dax", jsii.invoke(self, "toGetItem", []))

    @jsii.member(jsii_name="toIncreaseReplicationFactor")
    def to_increase_replication_factor(self) -> "Dax":
        '''(experimental) Grants permission to add one or more nodes to a DAX cluster.

        Access Level: Write

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_dax_IncreaseReplicationFactor.html

        :stability: experimental
        '''
        return typing.cast("Dax", jsii.invoke(self, "toIncreaseReplicationFactor", []))

    @jsii.member(jsii_name="toListTags")
    def to_list_tags(self) -> "Dax":
        '''(experimental) Grants permission to return a list all of the tags for a DAX cluster.

        Access Level: Read

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_dax_ListTags.html

        :stability: experimental
        '''
        return typing.cast("Dax", jsii.invoke(self, "toListTags", []))

    @jsii.member(jsii_name="toPutItem")
    def to_put_item(self) -> "Dax":
        '''(experimental) Grants permission to create a new item, or replace an old item with a new item.

        Access Level: Write

        Possible conditions:

        - .ifEnclosingOperation()

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_PutItem.html

        :stability: experimental
        '''
        return typing.cast("Dax", jsii.invoke(self, "toPutItem", []))

    @jsii.member(jsii_name="toQuery")
    def to_query(self) -> "Dax":
        '''(experimental) Grants permission to use the primary key of a table or a secondary index to directly access items from that table or index.

        Access Level: Read

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_Query.html

        :stability: experimental
        '''
        return typing.cast("Dax", jsii.invoke(self, "toQuery", []))

    @jsii.member(jsii_name="toRebootNode")
    def to_reboot_node(self) -> "Dax":
        '''(experimental) Grants permission to reboot a single node of a DAX cluster.

        Access Level: Write

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_dax_RebootNode.html

        :stability: experimental
        '''
        return typing.cast("Dax", jsii.invoke(self, "toRebootNode", []))

    @jsii.member(jsii_name="toScan")
    def to_scan(self) -> "Dax":
        '''(experimental) Grants permission to return one or more items and item attributes by accessing every item in a table or a secondary index.

        Access Level: Read

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_Scan.html

        :stability: experimental
        '''
        return typing.cast("Dax", jsii.invoke(self, "toScan", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Dax":
        '''(experimental) Grants permission to associate a set of tags with a DAX resource.

        Access Level: Tagging

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_dax_TagResource.html

        :stability: experimental
        '''
        return typing.cast("Dax", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Dax":
        '''(experimental) Grants permission to remove the association of tags from a DAX resource.

        Access Level: Tagging

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_dax_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("Dax", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateCluster")
    def to_update_cluster(self) -> "Dax":
        '''(experimental) Grants permission to modify the settings for a DAX cluster.

        Access Level: Write

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_dax_UpdateCluster.html

        :stability: experimental
        '''
        return typing.cast("Dax", jsii.invoke(self, "toUpdateCluster", []))

    @jsii.member(jsii_name="toUpdateItem")
    def to_update_item(self) -> "Dax":
        '''(experimental) Grants permission to edit an existing item's attributes, or adds a new item to the table if it does not already exist.

        Access Level: Write

        Possible conditions:

        - .ifEnclosingOperation()

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_UpdateItem.html

        :stability: experimental
        '''
        return typing.cast("Dax", jsii.invoke(self, "toUpdateItem", []))

    @jsii.member(jsii_name="toUpdateParameterGroup")
    def to_update_parameter_group(self) -> "Dax":
        '''(experimental) Grants permission to modify the parameters of a parameter group.

        Access Level: Write

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_dax_UpdateParameterGroup.html

        :stability: experimental
        '''
        return typing.cast("Dax", jsii.invoke(self, "toUpdateParameterGroup", []))

    @jsii.member(jsii_name="toUpdateSubnetGroup")
    def to_update_subnet_group(self) -> "Dax":
        '''(experimental) Grants permission to modify an existing subnet group.

        Access Level: Write

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_dax_UpdateSubnetGroup.html

        :stability: experimental
        '''
        return typing.cast("Dax", jsii.invoke(self, "toUpdateSubnetGroup", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ac675cbf5a544d430f1d01530c15b55f895eda72da28f5a53b076c6e414847bc)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3bde1aa2c09531aa1f46d778e8b227c495790e32669d3d03643e717a22e1278c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Dbqms(PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Dbqms"):
    '''(experimental) Statement provider for service `dbqms <https://docs.aws.amazon.com/service-authorization/latest/reference/list_databasequerymetadataservice.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `dbqms <https://docs.aws.amazon.com/service-authorization/latest/reference/list_databasequerymetadataservice.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="toCreateFavoriteQuery")
    def to_create_favorite_query(self) -> "Dbqms":
        '''(experimental) Grants permission to create a new favorite query.

        Access Level: Write

        https://docs.aws.amazon.com/qldb/latest/developerguide/dbqms-api.html#CreateFavoriteQuery

        :stability: experimental
        '''
        return typing.cast("Dbqms", jsii.invoke(self, "toCreateFavoriteQuery", []))

    @jsii.member(jsii_name="toCreateQueryHistory")
    def to_create_query_history(self) -> "Dbqms":
        '''(experimental) Grants permission to add a query to the history.

        Access Level: Write

        :stability: experimental
        '''
        return typing.cast("Dbqms", jsii.invoke(self, "toCreateQueryHistory", []))

    @jsii.member(jsii_name="toCreateTab")
    def to_create_tab(self) -> "Dbqms":
        '''(experimental) Grants permission to create a new query tab.

        Access Level: Write

        https://docs.aws.amazon.com/qldb/latest/developerguide/dbqms-api.html#CreateTab

        :stability: experimental
        '''
        return typing.cast("Dbqms", jsii.invoke(self, "toCreateTab", []))

    @jsii.member(jsii_name="toDeleteFavoriteQueries")
    def to_delete_favorite_queries(self) -> "Dbqms":
        '''(experimental) Grants permission to delete saved queries.

        Access Level: Write

        https://docs.aws.amazon.com/qldb/latest/developerguide/dbqms-api.html#DeleteFavoriteQueries

        :stability: experimental
        '''
        return typing.cast("Dbqms", jsii.invoke(self, "toDeleteFavoriteQueries", []))

    @jsii.member(jsii_name="toDeleteQueryHistory")
    def to_delete_query_history(self) -> "Dbqms":
        '''(experimental) Grants permission to delete a historical query.

        Access Level: Write

        https://docs.aws.amazon.com/qldb/latest/developerguide/dbqms-api.html#DeleteQueryHistory

        :stability: experimental
        '''
        return typing.cast("Dbqms", jsii.invoke(self, "toDeleteQueryHistory", []))

    @jsii.member(jsii_name="toDeleteTab")
    def to_delete_tab(self) -> "Dbqms":
        '''(experimental) Grants permission to delete query tab.

        Access Level: Write

        https://docs.aws.amazon.com/qldb/latest/developerguide/dbqms-api.html#DeleteTab

        :stability: experimental
        '''
        return typing.cast("Dbqms", jsii.invoke(self, "toDeleteTab", []))

    @jsii.member(jsii_name="toDescribeFavoriteQueries")
    def to_describe_favorite_queries(self) -> "Dbqms":
        '''(experimental) Grants permission to list saved queries and associated metadata.

        Access Level: List

        https://docs.aws.amazon.com/qldb/latest/developerguide/dbqms-api.html#DescribeFavoriteQueries

        :stability: experimental
        '''
        return typing.cast("Dbqms", jsii.invoke(self, "toDescribeFavoriteQueries", []))

    @jsii.member(jsii_name="toDescribeQueryHistory")
    def to_describe_query_history(self) -> "Dbqms":
        '''(experimental) Grants permission to list history of queries that were run.

        Access Level: List

        https://docs.aws.amazon.com/qldb/latest/developerguide/dbqms-api.html#DescribeQueryHistory

        :stability: experimental
        '''
        return typing.cast("Dbqms", jsii.invoke(self, "toDescribeQueryHistory", []))

    @jsii.member(jsii_name="toDescribeTabs")
    def to_describe_tabs(self) -> "Dbqms":
        '''(experimental) Grants permission to list query tabs and associated metadata.

        Access Level: List

        https://docs.aws.amazon.com/qldb/latest/developerguide/dbqms-api.html#DescribeTabs

        :stability: experimental
        '''
        return typing.cast("Dbqms", jsii.invoke(self, "toDescribeTabs", []))

    @jsii.member(jsii_name="toGetQueryString")
    def to_get_query_string(self) -> "Dbqms":
        '''(experimental) Grants permission to retrieve favorite or history query string by id.

        Access Level: Read

        https://docs.aws.amazon.com/qldb/latest/developerguide/dbqms-api.html#GetQueryString

        :stability: experimental
        '''
        return typing.cast("Dbqms", jsii.invoke(self, "toGetQueryString", []))

    @jsii.member(jsii_name="toUpdateFavoriteQuery")
    def to_update_favorite_query(self) -> "Dbqms":
        '''(experimental) Grants permission to update saved query and description.

        Access Level: Write

        https://docs.aws.amazon.com/qldb/latest/developerguide/dbqms-api.html#UpdateFavoriteQuery

        :stability: experimental
        '''
        return typing.cast("Dbqms", jsii.invoke(self, "toUpdateFavoriteQuery", []))

    @jsii.member(jsii_name="toUpdateQueryHistory")
    def to_update_query_history(self) -> "Dbqms":
        '''(experimental) Grants permission to update the query history.

        Access Level: Write

        https://docs.aws.amazon.com/qldb/latest/developerguide/dbqms-api.html#UpdateQueryHistory

        :stability: experimental
        '''
        return typing.cast("Dbqms", jsii.invoke(self, "toUpdateQueryHistory", []))

    @jsii.member(jsii_name="toUpdateTab")
    def to_update_tab(self) -> "Dbqms":
        '''(experimental) Grants permission to update query tab.

        Access Level: Write

        https://docs.aws.amazon.com/qldb/latest/developerguide/dbqms-api.html#UpdateTab

        :stability: experimental
        '''
        return typing.cast("Dbqms", jsii.invoke(self, "toUpdateTab", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b80860b6ada0ea8c9c500c8e1ea5e25cc2a1e42cb853184ecb2719f7a2c9f368)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__090a06792186813f732a9b3266fcb49ad5ef744dc212c90851b83c5646ed6b56)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Deepcomposer(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Deepcomposer",
):
    '''(experimental) Statement provider for service `deepcomposer <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsdeepcomposer.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `deepcomposer <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsdeepcomposer.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onAudio")
    def on_audio(
        self,
        audio_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Deepcomposer":
        '''(experimental) Adds a resource of type audio to the statement.

        https://docs.aws.amazon.com/deepcomposer/latest/devguide/get-started-learn-from-pre-trained-models.html

        :param audio_id: - Identifier for the audioId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f31e329af39dcde394fe50dfc2366e3df3abc6473b034f50f96c78d54de1f97c)
            check_type(argname="argument audio_id", value=audio_id, expected_type=type_hints["audio_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Deepcomposer", jsii.invoke(self, "onAudio", [audio_id, account, region, partition]))

    @jsii.member(jsii_name="onComposition")
    def on_composition(
        self,
        composition_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Deepcomposer":
        '''(experimental) Adds a resource of type composition to the statement.

        https://docs.aws.amazon.com/deepcomposer/latest/devguide/get-started-learn-from-pre-trained-models.html

        :param composition_id: - Identifier for the compositionId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9bab151b2add5e5deda929194506c17ee86a4f9708a566cac9f32bb8b900f607)
            check_type(argname="argument composition_id", value=composition_id, expected_type=type_hints["composition_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Deepcomposer", jsii.invoke(self, "onComposition", [composition_id, account, region, partition]))

    @jsii.member(jsii_name="onModel")
    def on_model(
        self,
        model_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Deepcomposer":
        '''(experimental) Adds a resource of type model to the statement.

        https://docs.aws.amazon.com/deepcomposer/latest/devguide/get-started-custom-model.html

        :param model_id: - Identifier for the modelId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4df37c343be91031c108f50f4a597b6bf711a0aa5a9efc652e7d3392f5e531c4)
            check_type(argname="argument model_id", value=model_id, expected_type=type_hints["model_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Deepcomposer", jsii.invoke(self, "onModel", [model_id, account, region, partition]))

    @jsii.member(jsii_name="toAssociateCoupon")
    def to_associate_coupon(self) -> "Deepcomposer":
        '''(experimental) Grants permission to associate a DeepComposer coupon (or DSN) with the account associated with the sender of the request.

        Access Level: Write

        https://docs.aws.amazon.com/deepcomposer/latest/devguide/what-it-is-keyboard.html

        :stability: experimental
        '''
        return typing.cast("Deepcomposer", jsii.invoke(self, "toAssociateCoupon", []))

    @jsii.member(jsii_name="toCreateAudio")
    def to_create_audio(self) -> "Deepcomposer":
        '''(experimental) Grants permission to create an audio file by converting the midi composition into a wav or mp3 file.

        Access Level: Write

        https://docs.aws.amazon.com/deepcomposer/latest/devguide/get-started-learn-from-pre-trained-models.html

        :stability: experimental
        '''
        return typing.cast("Deepcomposer", jsii.invoke(self, "toCreateAudio", []))

    @jsii.member(jsii_name="toCreateComposition")
    def to_create_composition(self) -> "Deepcomposer":
        '''(experimental) Grants permission to create a multi-track midi composition.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/deepcomposer/latest/devguide/get-started-learn-from-pre-trained-models.html

        :stability: experimental
        '''
        return typing.cast("Deepcomposer", jsii.invoke(self, "toCreateComposition", []))

    @jsii.member(jsii_name="toCreateModel")
    def to_create_model(self) -> "Deepcomposer":
        '''(experimental) Grants permission to start creating/training a generative-model that is able to perform inference against the user-provided piano-melody to create a multi-track midi composition.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/deepcomposer/latest/devguide/get-started-custom-model.html

        :stability: experimental
        '''
        return typing.cast("Deepcomposer", jsii.invoke(self, "toCreateModel", []))

    @jsii.member(jsii_name="toDeleteComposition")
    def to_delete_composition(self) -> "Deepcomposer":
        '''(experimental) Grants permission to delete the composition.

        Access Level: Write

        https://docs.aws.amazon.com/deepcomposer/latest/devguide/get-started-learn-from-pre-trained-models.html

        :stability: experimental
        '''
        return typing.cast("Deepcomposer", jsii.invoke(self, "toDeleteComposition", []))

    @jsii.member(jsii_name="toDeleteModel")
    def to_delete_model(self) -> "Deepcomposer":
        '''(experimental) Grants permission to delete the model.

        Access Level: Write

        https://docs.aws.amazon.com/deepcomposer/latest/devguide/get-started-custom-model.html

        :stability: experimental
        '''
        return typing.cast("Deepcomposer", jsii.invoke(self, "toDeleteModel", []))

    @jsii.member(jsii_name="toGetComposition")
    def to_get_composition(self) -> "Deepcomposer":
        '''(experimental) Grants permission to get information about the composition.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/deepcomposer/latest/devguide/get-started-learn-from-pre-trained-models.html

        :stability: experimental
        '''
        return typing.cast("Deepcomposer", jsii.invoke(self, "toGetComposition", []))

    @jsii.member(jsii_name="toGetModel")
    def to_get_model(self) -> "Deepcomposer":
        '''(experimental) Grants permission to get information about the model.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/deepcomposer/latest/devguide/get-started-custom-model.html

        :stability: experimental
        '''
        return typing.cast("Deepcomposer", jsii.invoke(self, "toGetModel", []))

    @jsii.member(jsii_name="toGetSampleModel")
    def to_get_sample_model(self) -> "Deepcomposer":
        '''(experimental) Grants permission to get information about the sample/pre-trained DeepComposer model.

        Access Level: Read

        https://docs.aws.amazon.com/deepcomposer/latest/devguide/get-started-learn-from-pre-trained-models.html

        :stability: experimental
        '''
        return typing.cast("Deepcomposer", jsii.invoke(self, "toGetSampleModel", []))

    @jsii.member(jsii_name="toListCompositions")
    def to_list_compositions(self) -> "Deepcomposer":
        '''(experimental) Grants permission to list all the compositions owned by the sender of the request.

        Access Level: List

        https://docs.aws.amazon.com/deepcomposer/latest/devguide/get-started-learn-from-pre-trained-models.html

        :stability: experimental
        '''
        return typing.cast("Deepcomposer", jsii.invoke(self, "toListCompositions", []))

    @jsii.member(jsii_name="toListModels")
    def to_list_models(self) -> "Deepcomposer":
        '''(experimental) Grants permission to list all the models owned by the sender of the request.

        Access Level: List

        https://docs.aws.amazon.com/deepcomposer/latest/devguide/get-started-custom-model.html

        :stability: experimental
        '''
        return typing.cast("Deepcomposer", jsii.invoke(self, "toListModels", []))

    @jsii.member(jsii_name="toListSampleModels")
    def to_list_sample_models(self) -> "Deepcomposer":
        '''(experimental) Grants permission to list all the sample/pre-trained models provided by the DeepComposer service.

        Access Level: List

        https://docs.aws.amazon.com/deepcomposer/latest/devguide/get-started-learn-from-pre-trained-models.html

        :stability: experimental
        '''
        return typing.cast("Deepcomposer", jsii.invoke(self, "toListSampleModels", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Deepcomposer":
        '''(experimental) Grants permission to list tags for a resource.

        Access Level: List

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/deepcomposer/latest/devguide/deepcomposer-tagging.html

        :stability: experimental
        '''
        return typing.cast("Deepcomposer", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toListTrainingTopics")
    def to_list_training_topics(self) -> "Deepcomposer":
        '''(experimental) Grants permission to list all the training options or topic for creating/training a model.

        Access Level: List

        https://docs.aws.amazon.com/deepcomposer/latest/devguide/get-started-custom-model.html

        :stability: experimental
        '''
        return typing.cast("Deepcomposer", jsii.invoke(self, "toListTrainingTopics", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Deepcomposer":
        '''(experimental) Grants permission to tag a resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()
        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/deepcomposer/latest/devguide/deepcomposer-tagging.html

        :stability: experimental
        '''
        return typing.cast("Deepcomposer", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Deepcomposer":
        '''(experimental) Grants permission to untag a resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()
        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/deepcomposer/latest/devguide/deepcomposer-tagging.html

        :stability: experimental
        '''
        return typing.cast("Deepcomposer", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateComposition")
    def to_update_composition(self) -> "Deepcomposer":
        '''(experimental) Grants permission to modify the mutable properties associated with a composition.

        Access Level: Write

        https://docs.aws.amazon.com/deepcomposer/latest/devguide/get-started-learn-from-pre-trained-models.html

        :stability: experimental
        '''
        return typing.cast("Deepcomposer", jsii.invoke(self, "toUpdateComposition", []))

    @jsii.member(jsii_name="toUpdateModel")
    def to_update_model(self) -> "Deepcomposer":
        '''(experimental) Grants permission to to modify the mutable properties associated with a model.

        Access Level: Write

        https://docs.aws.amazon.com/deepcomposer/latest/devguide/get-started-custom-model.html

        :stability: experimental
        '''
        return typing.cast("Deepcomposer", jsii.invoke(self, "toUpdateModel", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3ec5529244076e16b3101dfe011cb5708fcbe800392eca7a64fd46276b6a5780)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c2e748fb8f86c1cb25be894ab1e3a6f400b197e7d13c358664212eb8a9153df5)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Deeplens(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Deeplens",
):
    '''(experimental) Statement provider for service `deeplens <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsdeeplens.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `deeplens <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsdeeplens.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onDevice")
    def on_device(
        self,
        device_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Deeplens":
        '''(experimental) Adds a resource of type device to the statement.

        :param device_name: - Identifier for the deviceName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c23e812f33b01867f121091465b3fd5822c233c615e746e69e04f99b4c9a8c8d)
            check_type(argname="argument device_name", value=device_name, expected_type=type_hints["device_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Deeplens", jsii.invoke(self, "onDevice", [device_name, account, region, partition]))

    @jsii.member(jsii_name="onModel")
    def on_model(
        self,
        model_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Deeplens":
        '''(experimental) Adds a resource of type model to the statement.

        :param model_name: - Identifier for the modelName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__30211cc694483cc41c31fbe7abba189402e1b4e7819b41894bf0b36a54d98f66)
            check_type(argname="argument model_name", value=model_name, expected_type=type_hints["model_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Deeplens", jsii.invoke(self, "onModel", [model_name, account, region, partition]))

    @jsii.member(jsii_name="onProject")
    def on_project(
        self,
        project_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Deeplens":
        '''(experimental) Adds a resource of type project to the statement.

        :param project_name: - Identifier for the projectName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d4feca257aa57aabf8528426740dcbec6f4cc9ae9ddc23c73dc1e710c671a9ed)
            check_type(argname="argument project_name", value=project_name, expected_type=type_hints["project_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Deeplens", jsii.invoke(self, "onProject", [project_name, account, region, partition]))

    @jsii.member(jsii_name="toAssociateServiceRoleToAccount")
    def to_associate_service_role_to_account(self) -> "Deeplens":
        '''(experimental) Associates the user's account with IAM roles controlling various permissions needed by AWS DeepLens for proper functionality.

        Access Level: Permissions management

        :stability: experimental
        '''
        return typing.cast("Deeplens", jsii.invoke(self, "toAssociateServiceRoleToAccount", []))

    @jsii.member(jsii_name="toBatchGetDevice")
    def to_batch_get_device(self) -> "Deeplens":
        '''(experimental) Retrieves a list of AWS DeepLens devices.

        Access Level: Read

        :stability: experimental
        '''
        return typing.cast("Deeplens", jsii.invoke(self, "toBatchGetDevice", []))

    @jsii.member(jsii_name="toBatchGetModel")
    def to_batch_get_model(self) -> "Deeplens":
        '''(experimental) Retrieves a list of AWS DeepLens Models.

        Access Level: Read

        :stability: experimental
        '''
        return typing.cast("Deeplens", jsii.invoke(self, "toBatchGetModel", []))

    @jsii.member(jsii_name="toBatchGetProject")
    def to_batch_get_project(self) -> "Deeplens":
        '''(experimental) Retrieves a list of AWS DeepLens Projects.

        Access Level: Read

        :stability: experimental
        '''
        return typing.cast("Deeplens", jsii.invoke(self, "toBatchGetProject", []))

    @jsii.member(jsii_name="toCreateDeviceCertificates")
    def to_create_device_certificates(self) -> "Deeplens":
        '''(experimental) Creates a certificate package that is used to successfully authenticate and Register an AWS DeepLens device.

        Access Level: Write

        :stability: experimental
        '''
        return typing.cast("Deeplens", jsii.invoke(self, "toCreateDeviceCertificates", []))

    @jsii.member(jsii_name="toCreateModel")
    def to_create_model(self) -> "Deeplens":
        '''(experimental) Creates a new AWS DeepLens Model.

        Access Level: Write

        :stability: experimental
        '''
        return typing.cast("Deeplens", jsii.invoke(self, "toCreateModel", []))

    @jsii.member(jsii_name="toCreateProject")
    def to_create_project(self) -> "Deeplens":
        '''(experimental) Creates a new AWS DeepLens Project.

        Access Level: Write

        :stability: experimental
        '''
        return typing.cast("Deeplens", jsii.invoke(self, "toCreateProject", []))

    @jsii.member(jsii_name="toDeleteModel")
    def to_delete_model(self) -> "Deeplens":
        '''(experimental) Deletes an AWS DeepLens Model.

        Access Level: Write

        :stability: experimental
        '''
        return typing.cast("Deeplens", jsii.invoke(self, "toDeleteModel", []))

    @jsii.member(jsii_name="toDeleteProject")
    def to_delete_project(self) -> "Deeplens":
        '''(experimental) Deletes an AWS DeepLens Project.

        Access Level: Write

        :stability: experimental
        '''
        return typing.cast("Deeplens", jsii.invoke(self, "toDeleteProject", []))

    @jsii.member(jsii_name="toDeployProject")
    def to_deploy_project(self) -> "Deeplens":
        '''(experimental) Deploys an AWS DeepLens project to a registered AWS DeepLens device.

        Access Level: Write

        :stability: experimental
        '''
        return typing.cast("Deeplens", jsii.invoke(self, "toDeployProject", []))

    @jsii.member(jsii_name="toDeregisterDevice")
    def to_deregister_device(self) -> "Deeplens":
        '''(experimental) Begins a device de-registration workflow for a registered AWS DeepLens device.

        Access Level: Write

        :stability: experimental
        '''
        return typing.cast("Deeplens", jsii.invoke(self, "toDeregisterDevice", []))

    @jsii.member(jsii_name="toGetAssociatedResources")
    def to_get_associated_resources(self) -> "Deeplens":
        '''(experimental) Retrieves the account level resources associated with the user's account.

        Access Level: Read

        :stability: experimental
        '''
        return typing.cast("Deeplens", jsii.invoke(self, "toGetAssociatedResources", []))

    @jsii.member(jsii_name="toGetDeploymentStatus")
    def to_get_deployment_status(self) -> "Deeplens":
        '''(experimental) Retrieves the the deployment status of a particular AWS DeepLens device, along with any associated metadata.

        Access Level: Read

        :stability: experimental
        '''
        return typing.cast("Deeplens", jsii.invoke(self, "toGetDeploymentStatus", []))

    @jsii.member(jsii_name="toGetDevice")
    def to_get_device(self) -> "Deeplens":
        '''(experimental) Retrieves information about an AWS DeepLens device.

        Access Level: Read

        :stability: experimental
        '''
        return typing.cast("Deeplens", jsii.invoke(self, "toGetDevice", []))

    @jsii.member(jsii_name="toGetModel")
    def to_get_model(self) -> "Deeplens":
        '''(experimental) Retrieves an AWS DeepLens Model.

        Access Level: Read

        :stability: experimental
        '''
        return typing.cast("Deeplens", jsii.invoke(self, "toGetModel", []))

    @jsii.member(jsii_name="toGetProject")
    def to_get_project(self) -> "Deeplens":
        '''(experimental) Retrieves an AWS DeepLens Project.

        Access Level: Read

        :stability: experimental
        '''
        return typing.cast("Deeplens", jsii.invoke(self, "toGetProject", []))

    @jsii.member(jsii_name="toImportProjectFromTemplate")
    def to_import_project_from_template(self) -> "Deeplens":
        '''(experimental) Creates a new AWS DeepLens project from a sample project template.

        Access Level: Write

        :stability: experimental
        '''
        return typing.cast("Deeplens", jsii.invoke(self, "toImportProjectFromTemplate", []))

    @jsii.member(jsii_name="toListDeployments")
    def to_list_deployments(self) -> "Deeplens":
        '''(experimental) Retrieves a list of AWS DeepLens Deployment identifiers.

        Access Level: List

        :stability: experimental
        '''
        return typing.cast("Deeplens", jsii.invoke(self, "toListDeployments", []))

    @jsii.member(jsii_name="toListDevices")
    def to_list_devices(self) -> "Deeplens":
        '''(experimental) Retrieves a list of AWS DeepLens device identifiers.

        Access Level: List

        :stability: experimental
        '''
        return typing.cast("Deeplens", jsii.invoke(self, "toListDevices", []))

    @jsii.member(jsii_name="toListModels")
    def to_list_models(self) -> "Deeplens":
        '''(experimental) Retrieves a list of AWS DeepLens Model identifiers.

        Access Level: List

        :stability: experimental
        '''
        return typing.cast("Deeplens", jsii.invoke(self, "toListModels", []))

    @jsii.member(jsii_name="toListProjects")
    def to_list_projects(self) -> "Deeplens":
        '''(experimental) Retrieves a list of AWS DeepLens Project identifiers.

        Access Level: List

        :stability: experimental
        '''
        return typing.cast("Deeplens", jsii.invoke(self, "toListProjects", []))

    @jsii.member(jsii_name="toRegisterDevice")
    def to_register_device(self) -> "Deeplens":
        '''(experimental) Begins a device registration workflow for an AWS DeepLens device.

        Access Level: Write

        :stability: experimental
        '''
        return typing.cast("Deeplens", jsii.invoke(self, "toRegisterDevice", []))

    @jsii.member(jsii_name="toRemoveProject")
    def to_remove_project(self) -> "Deeplens":
        '''(experimental) Removes a deployed AWS DeepLens project from an AWS DeepLens device.

        Access Level: Write

        :stability: experimental
        '''
        return typing.cast("Deeplens", jsii.invoke(self, "toRemoveProject", []))

    @jsii.member(jsii_name="toUpdateProject")
    def to_update_project(self) -> "Deeplens":
        '''(experimental) Updates an existing AWS DeepLens Project.

        Access Level: Write

        :stability: experimental
        '''
        return typing.cast("Deeplens", jsii.invoke(self, "toUpdateProject", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b5ffdcc42b9e1eb2aff5d30270008e15e945691fa3cd46a402e08db567ee12f9)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9cc31b631c27269ab531d8d3e9d67556c1c17df0a50a4427ba8552f82e73eaa1)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Deepracer(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Deepracer",
):
    '''(experimental) Statement provider for service `deepracer <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsdeepracer.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `deepracer <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsdeepracer.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="ifMultiUser")
    def if_multi_user(
        self,
        value: typing.Optional[builtins.bool] = None,
    ) -> "Deepracer":
        '''(experimental) Filters access by multiuser flag.

        https://docs.aws.amazon.com/deepracer/latest/developerguide/reference_policies_iam-condition-keys.html#condition-keys-multiuser

        Applies to actions:

        - .toAddLeaderboardAccessPermission()
        - .toCloneReinforcementLearningModel()
        - .toCreateCar()
        - .toCreateLeaderboard()
        - .toCreateLeaderboardAccessToken()
        - .toCreateLeaderboardSubmission()
        - .toCreateReinforcementLearningModel()
        - .toDeleteLeaderboard()
        - .toDeleteModel()
        - .toEditLeaderboard()
        - .toGetAccountConfig()
        - .toGetAlias()
        - .toGetAssetUrl()
        - .toGetCar()
        - .toGetCars()
        - .toGetEvaluation()
        - .toGetLatestUserSubmission()
        - .toGetLeaderboard()
        - .toGetModel()
        - .toGetPrivateLeaderboard()
        - .toGetRankedUserSubmission()
        - .toGetTrainingJob()
        - .toImportModel()
        - .toListEvaluations()
        - .toListLeaderboardSubmissions()
        - .toListLeaderboards()
        - .toListModels()
        - .toListPrivateLeaderboardParticipants()
        - .toListPrivateLeaderboards()
        - .toListSubscribedPrivateLeaderboards()
        - .toListTagsForResource()
        - .toListTrainingJobs()
        - .toPerformLeaderboardOperation()
        - .toRemoveLeaderboardAccessPermission()
        - .toSetAlias()
        - .toStartEvaluation()
        - .toStopEvaluation()
        - .toStopTrainingReinforcementLearningModel()
        - .toTagResource()
        - .toUntagResource()
        - .toUpdateCar()

        :param value: ``true`` or ``false``. **Default:** ``true``

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b9134abe5c3a628d5a072aa2d7ec28f3c5260aa69a16aed5278c894fbf36784f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast("Deepracer", jsii.invoke(self, "ifMultiUser", [value]))

    @jsii.member(jsii_name="ifUserToken")
    def if_user_token(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Deepracer":
        '''(experimental) Filters access by user token in the request.

        https://docs.aws.amazon.com/deepracer/latest/developerguide/reference_policies_iam-condition-keys.html#condition-keys-usertoken

        Applies to actions:

        - .toAddLeaderboardAccessPermission()
        - .toCloneReinforcementLearningModel()
        - .toCreateCar()
        - .toCreateLeaderboard()
        - .toCreateLeaderboardAccessToken()
        - .toCreateLeaderboardSubmission()
        - .toCreateReinforcementLearningModel()
        - .toDeleteLeaderboard()
        - .toDeleteModel()
        - .toEditLeaderboard()
        - .toGetAccountConfig()
        - .toGetAlias()
        - .toGetAssetUrl()
        - .toGetCar()
        - .toGetCars()
        - .toGetEvaluation()
        - .toGetLatestUserSubmission()
        - .toGetLeaderboard()
        - .toGetModel()
        - .toGetPrivateLeaderboard()
        - .toGetRankedUserSubmission()
        - .toGetTrainingJob()
        - .toImportModel()
        - .toListEvaluations()
        - .toListLeaderboardSubmissions()
        - .toListLeaderboards()
        - .toListModels()
        - .toListPrivateLeaderboardParticipants()
        - .toListPrivateLeaderboards()
        - .toListSubscribedPrivateLeaderboards()
        - .toListTagsForResource()
        - .toListTrainingJobs()
        - .toPerformLeaderboardOperation()
        - .toRemoveLeaderboardAccessPermission()
        - .toSetAlias()
        - .toStartEvaluation()
        - .toStopEvaluation()
        - .toStopTrainingReinforcementLearningModel()
        - .toTagResource()
        - .toUntagResource()
        - .toUpdateCar()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__af25b3930d6585a8ab6a3cbcf27d273c6d93b50e638d8e54d545c3e1a528fe7b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Deepracer", jsii.invoke(self, "ifUserToken", [value, operator]))

    @jsii.member(jsii_name="onCar")
    def on_car(
        self,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Deepracer":
        '''(experimental) Adds a resource of type car to the statement.

        https://docs.aws.amazon.com/deepracer/latest/developerguide/deepracer-choose-race-type.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5c55b62c0fb6f50bb20a6a2aa869d3481bf9c329746a4d4610f79410daf59c3c)
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Deepracer", jsii.invoke(self, "onCar", [resource_id, account, region, partition]))

    @jsii.member(jsii_name="onEvaluationJob")
    def on_evaluation_job(
        self,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Deepracer":
        '''(experimental) Adds a resource of type evaluation_job to the statement.

        https://docs.aws.amazon.com/deepracer/latest/developerguide/deepracer-get-started-test-in-simulator.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5c3b6628140b09ca6d6e207f6b458c8edd9a6d8546883d2ffdb4c335230a12cc)
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Deepracer", jsii.invoke(self, "onEvaluationJob", [resource_id, account, region, partition]))

    @jsii.member(jsii_name="onLeaderboard")
    def on_leaderboard(
        self,
        resource_id: builtins.str,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Deepracer":
        '''(experimental) Adds a resource of type leaderboard to the statement.

        https://docs.aws.amazon.com/deepracer/latest/developerguide/deepracer-submit-model-to-leaderboard.html

        :param resource_id: - Identifier for the resourceId.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9c1208587d7a09354f23d2bd463320fcf3b68515f9dde1ab10cbab306f10e404)
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Deepracer", jsii.invoke(self, "onLeaderboard", [resource_id, region, partition]))

    @jsii.member(jsii_name="onLeaderboardEvaluationJob")
    def on_leaderboard_evaluation_job(
        self,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Deepracer":
        '''(experimental) Adds a resource of type leaderboard_evaluation_job to the statement.

        https://docs.aws.amazon.com/deepracer/latest/developerguide/deepracer-submit-model-to-leaderboard.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6ef80ced8238cb0938e411791a372cd56b975e95ee9891459392fb5a9849d6a4)
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Deepracer", jsii.invoke(self, "onLeaderboardEvaluationJob", [resource_id, account, region, partition]))

    @jsii.member(jsii_name="onReinforcementLearningModel")
    def on_reinforcement_learning_model(
        self,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Deepracer":
        '''(experimental) Adds a resource of type reinforcement_learning_model to the statement.

        https://docs.aws.amazon.com/deepracer/latest/developerguide/deepracer-get-started-training-model.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__900c7803d7119f3ed9ae18fab539a1de5806fc573eb4d78d8c4abd14e5e4e95d)
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Deepracer", jsii.invoke(self, "onReinforcementLearningModel", [resource_id, account, region, partition]))

    @jsii.member(jsii_name="onTrack")
    def on_track(
        self,
        resource_id: builtins.str,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Deepracer":
        '''(experimental) Adds a resource of type track to the statement.

        https://docs.aws.amazon.com/deepracer/latest/developerguide/deepracer-console-train-evaluate-models.html

        :param resource_id: - Identifier for the resourceId.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__86a216cb1639c5ec54f1562f08a176f10fe7266e436a3db458b70f3fef018c94)
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Deepracer", jsii.invoke(self, "onTrack", [resource_id, region, partition]))

    @jsii.member(jsii_name="onTrainingJob")
    def on_training_job(
        self,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Deepracer":
        '''(experimental) Adds a resource of type training_job to the statement.

        https://docs.aws.amazon.com/deepracer/latest/developerguide/deepracer-get-started-training-model.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e1a464fc13ad17e83d0aa26ac34aa33f53f9ea3d45b0759fbec4fa61e4d71ffd)
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Deepracer", jsii.invoke(self, "onTrainingJob", [resource_id, account, region, partition]))

    @jsii.member(jsii_name="toAddLeaderboardAccessPermission")
    def to_add_leaderboard_access_permission(self) -> "Deepracer":
        '''(experimental) Grants permission to add access for a private leaderboard.

        Access Level: Write

        Possible conditions:

        - .ifUserToken()
        - .ifMultiUser()

        https://docs.aws.amazon.com/deepracer/latest/developerguide/deepracer-manage-community-races.html

        :stability: experimental
        '''
        return typing.cast("Deepracer", jsii.invoke(self, "toAddLeaderboardAccessPermission", []))

    @jsii.member(jsii_name="toAdminGetAccountConfig")
    def to_admin_get_account_config(self) -> "Deepracer":
        '''(experimental) Grants permission to get current admin multiuser configuration for this account.

        Access Level: Read

        https://docs.aws.amazon.com/deepracer/latest/developerguide/deepracer-admin-set-account-config.html

        :stability: experimental
        '''
        return typing.cast("Deepracer", jsii.invoke(self, "toAdminGetAccountConfig", []))

    @jsii.member(jsii_name="toAdminListAssociatedResources")
    def to_admin_list_associated_resources(self) -> "Deepracer":
        '''(experimental) Grants permission to list all deepracer users with their associated resources created under this account.

        Access Level: Read

        https://docs.aws.amazon.com/deepracer/latest/developerguide/deepracer-admin-list-associated-resources.html

        :stability: experimental
        '''
        return typing.cast("Deepracer", jsii.invoke(self, "toAdminListAssociatedResources", []))

    @jsii.member(jsii_name="toAdminListAssociatedUsers")
    def to_admin_list_associated_users(self) -> "Deepracer":
        '''(experimental) Grants permission to list user data for all users associated with this account.

        Access Level: Read

        https://docs.aws.amazon.com/deepracer/latest/developerguide/deepracer-admin-list-associated-users.html

        :stability: experimental
        '''
        return typing.cast("Deepracer", jsii.invoke(self, "toAdminListAssociatedUsers", []))

    @jsii.member(jsii_name="toAdminManageUser")
    def to_admin_manage_user(self) -> "Deepracer":
        '''(experimental) Grants permission to manage a user associated with this account.

        Access Level: Write

        https://docs.aws.amazon.com/deepracer/latest/developerguide/deepracer-admin-manage-user.html

        :stability: experimental
        '''
        return typing.cast("Deepracer", jsii.invoke(self, "toAdminManageUser", []))

    @jsii.member(jsii_name="toAdminSetAccountConfig")
    def to_admin_set_account_config(self) -> "Deepracer":
        '''(experimental) Grants permission to set configuration options for this account.

        Access Level: Write

        https://docs.aws.amazon.com/deepracer/latest/developerguide/deepracer-admin-set-account-config.html

        :stability: experimental
        '''
        return typing.cast("Deepracer", jsii.invoke(self, "toAdminSetAccountConfig", []))

    @jsii.member(jsii_name="toCloneReinforcementLearningModel")
    def to_clone_reinforcement_learning_model(self) -> "Deepracer":
        '''(experimental) Grants permission to clone an existing DeepRacer model.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifUserToken()
        - .ifMultiUser()

        https://docs.aws.amazon.com/deepracer/latest/developerguide/deepracer-console-train-evaluate-models.html#deepracer-clone-trained-model

        :stability: experimental
        '''
        return typing.cast("Deepracer", jsii.invoke(self, "toCloneReinforcementLearningModel", []))

    @jsii.member(jsii_name="toCreateCar")
    def to_create_car(self) -> "Deepracer":
        '''(experimental) Grants permission to create a DeepRacer car in your garage.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifUserToken()
        - .ifMultiUser()

        https://docs.aws.amazon.com/deepracer/latest/developerguide/deepracer-choose-race-type.html

        :stability: experimental
        '''
        return typing.cast("Deepracer", jsii.invoke(self, "toCreateCar", []))

    @jsii.member(jsii_name="toCreateLeaderboard")
    def to_create_leaderboard(self) -> "Deepracer":
        '''(experimental) Grants permission to create a leaderboard.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifUserToken()
        - .ifMultiUser()

        https://docs.aws.amazon.com/deepracer/latest/developerguide/deepracer-create-community-race.html

        :stability: experimental
        '''
        return typing.cast("Deepracer", jsii.invoke(self, "toCreateLeaderboard", []))

    @jsii.member(jsii_name="toCreateLeaderboardAccessToken")
    def to_create_leaderboard_access_token(self) -> "Deepracer":
        '''(experimental) Grants permission to create an access token for a private leaderboard.

        Access Level: Write

        Possible conditions:

        - .ifUserToken()
        - .ifMultiUser()

        https://docs.aws.amazon.com/deepracer/latest/developerguide/deepracer-manage-community-races.html

        :stability: experimental
        '''
        return typing.cast("Deepracer", jsii.invoke(self, "toCreateLeaderboardAccessToken", []))

    @jsii.member(jsii_name="toCreateLeaderboardSubmission")
    def to_create_leaderboard_submission(self) -> "Deepracer":
        '''(experimental) Grants permission to submit a DeepRacer model to be evaluated for leaderboards.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifUserToken()
        - .ifMultiUser()

        https://docs.aws.amazon.com/deepracer/latest/developerguide/deepracer-submit-model-to-leaderboard.html

        :stability: experimental
        '''
        return typing.cast("Deepracer", jsii.invoke(self, "toCreateLeaderboardSubmission", []))

    @jsii.member(jsii_name="toCreateReinforcementLearningModel")
    def to_create_reinforcement_learning_model(self) -> "Deepracer":
        '''(experimental) Grants permission to create ra einforcement learning model for DeepRacer.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifUserToken()
        - .ifMultiUser()

        https://docs.aws.amazon.com/deepracer/latest/developerguide/deepracer-get-started-training-model.html

        :stability: experimental
        '''
        return typing.cast("Deepracer", jsii.invoke(self, "toCreateReinforcementLearningModel", []))

    @jsii.member(jsii_name="toDeleteLeaderboard")
    def to_delete_leaderboard(self) -> "Deepracer":
        '''(experimental) Grants permission to delete a leaderboard.

        Access Level: Write

        Possible conditions:

        - .ifUserToken()
        - .ifMultiUser()

        https://docs.aws.amazon.com/deepracer/latest/developerguide/deepracer-manage-community-races.html

        :stability: experimental
        '''
        return typing.cast("Deepracer", jsii.invoke(self, "toDeleteLeaderboard", []))

    @jsii.member(jsii_name="toDeleteModel")
    def to_delete_model(self) -> "Deepracer":
        '''(experimental) Grants permission to delete a DeepRacer model.

        Access Level: Write

        Possible conditions:

        - .ifUserToken()
        - .ifMultiUser()

        https://docs.aws.amazon.com/deepracer/latest/developerguide/deepracer-get-started-training-model.html

        :stability: experimental
        '''
        return typing.cast("Deepracer", jsii.invoke(self, "toDeleteModel", []))

    @jsii.member(jsii_name="toEditLeaderboard")
    def to_edit_leaderboard(self) -> "Deepracer":
        '''(experimental) Grants permission to edit a leaderboard.

        Access Level: Write

        Possible conditions:

        - .ifUserToken()
        - .ifMultiUser()

        https://docs.aws.amazon.com/deepracer/latest/developerguide/deepracer-manage-community-races.html

        :stability: experimental
        '''
        return typing.cast("Deepracer", jsii.invoke(self, "toEditLeaderboard", []))

    @jsii.member(jsii_name="toGetAccountConfig")
    def to_get_account_config(self) -> "Deepracer":
        '''(experimental) Grants permission to get current multiuser configuration for this account.

        Access Level: Read

        Possible conditions:

        - .ifUserToken()
        - .ifMultiUser()

        https://docs.aws.amazon.com/deepracer/latest/developerguide/deepracer-admin-set-account-config.html

        :stability: experimental
        '''
        return typing.cast("Deepracer", jsii.invoke(self, "toGetAccountConfig", []))

    @jsii.member(jsii_name="toGetAlias")
    def to_get_alias(self) -> "Deepracer":
        '''(experimental) Grants permission to retrieve the user's alias for submitting a DeepRacer model to leaderboards.

        Access Level: Read

        Possible conditions:

        - .ifUserToken()
        - .ifMultiUser()

        https://docs.aws.amazon.com/deepracer/latest/developerguide/deepracer-submit-model-to-leaderboard.html

        :stability: experimental
        '''
        return typing.cast("Deepracer", jsii.invoke(self, "toGetAlias", []))

    @jsii.member(jsii_name="toGetAssetUrl")
    def to_get_asset_url(self) -> "Deepracer":
        '''(experimental) Grants permission to download artifacts for an existing DeepRacer model.

        Access Level: Read

        Possible conditions:

        - .ifUserToken()
        - .ifMultiUser()

        https://docs.aws.amazon.com/deepracer/latest/developerguide/deepracer-console-train-evaluate-models.html

        :stability: experimental
        '''
        return typing.cast("Deepracer", jsii.invoke(self, "toGetAssetUrl", []))

    @jsii.member(jsii_name="toGetCar")
    def to_get_car(self) -> "Deepracer":
        '''(experimental) Grants permission to retrieve a specific DeepRacer car from your garage.

        Access Level: Read

        Possible conditions:

        - .ifUserToken()
        - .ifMultiUser()

        https://docs.aws.amazon.com/deepracer/latest/developerguide/deepracer-choose-race-type.html

        :stability: experimental
        '''
        return typing.cast("Deepracer", jsii.invoke(self, "toGetCar", []))

    @jsii.member(jsii_name="toGetCars")
    def to_get_cars(self) -> "Deepracer":
        '''(experimental) Grants permission to view all the DeepRacer cars in your garage.

        Access Level: Read

        Possible conditions:

        - .ifUserToken()
        - .ifMultiUser()

        https://docs.aws.amazon.com/deepracer/latest/developerguide/deepracer-choose-race-type.html

        :stability: experimental
        '''
        return typing.cast("Deepracer", jsii.invoke(self, "toGetCars", []))

    @jsii.member(jsii_name="toGetEvaluation")
    def to_get_evaluation(self) -> "Deepracer":
        '''(experimental) Grants permission to retrieve information about an existing DeepRacer model's evaluation jobs.

        Access Level: Read

        Possible conditions:

        - .ifUserToken()
        - .ifMultiUser()

        https://docs.aws.amazon.com/deepracer/latest/developerguide/deepracer-get-started-test-in-simulator.html

        :stability: experimental
        '''
        return typing.cast("Deepracer", jsii.invoke(self, "toGetEvaluation", []))

    @jsii.member(jsii_name="toGetLatestUserSubmission")
    def to_get_latest_user_submission(self) -> "Deepracer":
        '''(experimental) Grants permission to retrieve information about how the latest submitted DeepRacer model for a user performed on a leaderboard.

        Access Level: Read

        Possible conditions:

        - .ifUserToken()
        - .ifMultiUser()

        https://docs.aws.amazon.com/deepracer/latest/developerguide/deepracer-submit-model-to-leaderboard.html

        :stability: experimental
        '''
        return typing.cast("Deepracer", jsii.invoke(self, "toGetLatestUserSubmission", []))

    @jsii.member(jsii_name="toGetLeaderboard")
    def to_get_leaderboard(self) -> "Deepracer":
        '''(experimental) Grants permission to retrieve information about leaderboards.

        Access Level: Read

        Possible conditions:

        - .ifUserToken()
        - .ifMultiUser()

        https://docs.aws.amazon.com/deepracer/latest/developerguide/deepracer-submit-model-to-leaderboard.html

        :stability: experimental
        '''
        return typing.cast("Deepracer", jsii.invoke(self, "toGetLeaderboard", []))

    @jsii.member(jsii_name="toGetModel")
    def to_get_model(self) -> "Deepracer":
        '''(experimental) Grants permission to retrieve information about an existing DeepRacer model.

        Access Level: Read

        Possible conditions:

        - .ifUserToken()
        - .ifMultiUser()

        https://docs.aws.amazon.com/deepracer/latest/developerguide/deepracer-get-started-training-model.html

        :stability: experimental
        '''
        return typing.cast("Deepracer", jsii.invoke(self, "toGetModel", []))

    @jsii.member(jsii_name="toGetPrivateLeaderboard")
    def to_get_private_leaderboard(self) -> "Deepracer":
        '''(experimental) Grants permission to retrieve information about private leaderboards.

        Access Level: Read

        Possible conditions:

        - .ifUserToken()
        - .ifMultiUser()

        https://docs.aws.amazon.com/deepracer/latest/developerguide/deepracer-join-community-race.html

        :stability: experimental
        '''
        return typing.cast("Deepracer", jsii.invoke(self, "toGetPrivateLeaderboard", []))

    @jsii.member(jsii_name="toGetRankedUserSubmission")
    def to_get_ranked_user_submission(self) -> "Deepracer":
        '''(experimental) Grants permission to retrieve information about the performance of a user's DeepRacer model that got placed on a leaderboard.

        Access Level: Read

        Possible conditions:

        - .ifUserToken()
        - .ifMultiUser()

        https://docs.aws.amazon.com/deepracer/latest/developerguide/deepracer-submit-model-to-leaderboard.html

        :stability: experimental
        '''
        return typing.cast("Deepracer", jsii.invoke(self, "toGetRankedUserSubmission", []))

    @jsii.member(jsii_name="toGetTrack")
    def to_get_track(self) -> "Deepracer":
        '''(experimental) Grants permission to retrieve information about DeepRacer tracks.

        Access Level: Read

        https://docs.aws.amazon.com/deepracer/latest/developerguide/deepracer-console-train-evaluate-models.html

        :stability: experimental
        '''
        return typing.cast("Deepracer", jsii.invoke(self, "toGetTrack", []))

    @jsii.member(jsii_name="toGetTrainingJob")
    def to_get_training_job(self) -> "Deepracer":
        '''(experimental) Grants permission to retrieve information about an existing DeepRacer model's training job.

        Access Level: Read

        Possible conditions:

        - .ifUserToken()
        - .ifMultiUser()

        https://docs.aws.amazon.com/deepracer/latest/developerguide/deepracer-get-started-training-model.html

        :stability: experimental
        '''
        return typing.cast("Deepracer", jsii.invoke(self, "toGetTrainingJob", []))

    @jsii.member(jsii_name="toImportModel")
    def to_import_model(self) -> "Deepracer":
        '''(experimental) Grants permission to import a reinforcement learning model for DeepRacer.

        Access Level: Write

        Possible conditions:

        - .ifUserToken()
        - .ifMultiUser()

        https://docs.aws.amazon.com/deepracer/latest/developerguide/deepracer-troubleshooting-service-migration-errors.html

        :stability: experimental
        '''
        return typing.cast("Deepracer", jsii.invoke(self, "toImportModel", []))

    @jsii.member(jsii_name="toListEvaluations")
    def to_list_evaluations(self) -> "Deepracer":
        '''(experimental) Grants permission to list a DeepRacer model's evaluation jobs.

        Access Level: Read

        Possible conditions:

        - .ifUserToken()
        - .ifMultiUser()

        https://docs.aws.amazon.com/deepracer/latest/developerguide/deepracer-get-started-test-in-simulator.html

        :stability: experimental
        '''
        return typing.cast("Deepracer", jsii.invoke(self, "toListEvaluations", []))

    @jsii.member(jsii_name="toListLeaderboards")
    def to_list_leaderboards(self) -> "Deepracer":
        '''(experimental) Grants permission to list all the available leaderboards.

        Access Level: Read

        Possible conditions:

        - .ifUserToken()
        - .ifMultiUser()

        https://docs.aws.amazon.com/deepracer/latest/developerguide/deepracer-submit-model-to-leaderboard.html

        :stability: experimental
        '''
        return typing.cast("Deepracer", jsii.invoke(self, "toListLeaderboards", []))

    @jsii.member(jsii_name="toListLeaderboardSubmissions")
    def to_list_leaderboard_submissions(self) -> "Deepracer":
        '''(experimental) Grants permission to list all the DeepRacer model submissions of a user on a leaderboard.

        Access Level: Read

        Possible conditions:

        - .ifUserToken()
        - .ifMultiUser()

        https://docs.aws.amazon.com/deepracer/latest/developerguide/deepracer-submit-model-to-leaderboard.html

        :stability: experimental
        '''
        return typing.cast("Deepracer", jsii.invoke(self, "toListLeaderboardSubmissions", []))

    @jsii.member(jsii_name="toListModels")
    def to_list_models(self) -> "Deepracer":
        '''(experimental) Grants permission to list all existing DeepRacer models.

        Access Level: Read

        Possible conditions:

        - .ifUserToken()
        - .ifMultiUser()

        https://docs.aws.amazon.com/deepracer/latest/developerguide/deepracer-get-started-training-model.html

        :stability: experimental
        '''
        return typing.cast("Deepracer", jsii.invoke(self, "toListModels", []))

    @jsii.member(jsii_name="toListPrivateLeaderboardParticipants")
    def to_list_private_leaderboard_participants(self) -> "Deepracer":
        '''(experimental) Grants permission to retrieve participant information about private leaderboards.

        Access Level: Read

        Possible conditions:

        - .ifUserToken()
        - .ifMultiUser()

        https://docs.aws.amazon.com/deepracer/latest/developerguide/deepracer-join-community-race.html

        :stability: experimental
        '''
        return typing.cast("Deepracer", jsii.invoke(self, "toListPrivateLeaderboardParticipants", []))

    @jsii.member(jsii_name="toListPrivateLeaderboards")
    def to_list_private_leaderboards(self) -> "Deepracer":
        '''(experimental) Grants permission to list all the available private leaderboards.

        Access Level: Read

        Possible conditions:

        - .ifUserToken()
        - .ifMultiUser()

        https://docs.aws.amazon.com/deepracer/latest/developerguide/deepracer-join-community-race.html

        :stability: experimental
        '''
        return typing.cast("Deepracer", jsii.invoke(self, "toListPrivateLeaderboards", []))

    @jsii.member(jsii_name="toListSubscribedPrivateLeaderboards")
    def to_list_subscribed_private_leaderboards(self) -> "Deepracer":
        '''(experimental) Grants permission to list all the subscribed private leaderboards.

        Access Level: Read

        Possible conditions:

        - .ifUserToken()
        - .ifMultiUser()

        https://docs.aws.amazon.com/deepracer/latest/developerguide/deepracer-join-community-race.html

        :stability: experimental
        '''
        return typing.cast("Deepracer", jsii.invoke(self, "toListSubscribedPrivateLeaderboards", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Deepracer":
        '''(experimental) Grants permission to lists tag for a resource.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()
        - .ifUserToken()
        - .ifMultiUser()

        https://docs.aws.amazon.com/deepracer/latest/developerguide/deepracer-tagging.html

        :stability: experimental
        '''
        return typing.cast("Deepracer", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toListTracks")
    def to_list_tracks(self) -> "Deepracer":
        '''(experimental) Grants permission to list all DeepRacer tracks.

        Access Level: Read

        https://docs.aws.amazon.com/deepracer/latest/developerguide/deepracer-console-train-evaluate-models.html

        :stability: experimental
        '''
        return typing.cast("Deepracer", jsii.invoke(self, "toListTracks", []))

    @jsii.member(jsii_name="toListTrainingJobs")
    def to_list_training_jobs(self) -> "Deepracer":
        '''(experimental) Grants permission to list a DeepRacer model's training jobs.

        Access Level: Read

        Possible conditions:

        - .ifUserToken()
        - .ifMultiUser()

        https://docs.aws.amazon.com/deepracer/latest/developerguide/deepracer-get-started-training-model.html

        :stability: experimental
        '''
        return typing.cast("Deepracer", jsii.invoke(self, "toListTrainingJobs", []))

    @jsii.member(jsii_name="toMigrateModels")
    def to_migrate_models(self) -> "Deepracer":
        '''(experimental) Grants permission to migrate previous reinforcement learning models for DeepRacer.

        Access Level: Write

        https://docs.aws.amazon.com/deepracer/latest/developerguide/deepracer-troubleshooting-service-migration-errors.html

        :stability: experimental
        '''
        return typing.cast("Deepracer", jsii.invoke(self, "toMigrateModels", []))

    @jsii.member(jsii_name="toPerformLeaderboardOperation")
    def to_perform_leaderboard_operation(self) -> "Deepracer":
        '''(experimental) Grants permission to performs the leaderboard operation mentioned in the operation attribute.

        Access Level: Write

        Possible conditions:

        - .ifUserToken()
        - .ifMultiUser()

        https://docs.aws.amazon.com/deepracer/latest/developerguide/deepracer-perform-leaderboard-operation.html

        :stability: experimental
        '''
        return typing.cast("Deepracer", jsii.invoke(self, "toPerformLeaderboardOperation", []))

    @jsii.member(jsii_name="toRemoveLeaderboardAccessPermission")
    def to_remove_leaderboard_access_permission(self) -> "Deepracer":
        '''(experimental) Grants permission to remove access for a private leaderboard.

        Access Level: Write

        Possible conditions:

        - .ifUserToken()
        - .ifMultiUser()

        https://docs.aws.amazon.com/deepracer/latest/developerguide/deepracer-manage-community-races.html

        :stability: experimental
        '''
        return typing.cast("Deepracer", jsii.invoke(self, "toRemoveLeaderboardAccessPermission", []))

    @jsii.member(jsii_name="toSetAlias")
    def to_set_alias(self) -> "Deepracer":
        '''(experimental) Grants permission to set the user's alias for submitting a DeepRacer model to leaderboards.

        Access Level: Write

        Possible conditions:

        - .ifUserToken()
        - .ifMultiUser()

        https://docs.aws.amazon.com/deepracer/latest/developerguide/deepracer-submit-model-to-leaderboard.html

        :stability: experimental
        '''
        return typing.cast("Deepracer", jsii.invoke(self, "toSetAlias", []))

    @jsii.member(jsii_name="toStartEvaluation")
    def to_start_evaluation(self) -> "Deepracer":
        '''(experimental) Grants permission to evaluate a DeepRacer model in a simulated environment.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifUserToken()
        - .ifMultiUser()

        https://docs.aws.amazon.com/deepracer/latest/developerguide/deepracer-get-started-test-in-simulator.html

        :stability: experimental
        '''
        return typing.cast("Deepracer", jsii.invoke(self, "toStartEvaluation", []))

    @jsii.member(jsii_name="toStopEvaluation")
    def to_stop_evaluation(self) -> "Deepracer":
        '''(experimental) Grants permission to stop DeepRacer model evaluations.

        Access Level: Write

        Possible conditions:

        - .ifUserToken()
        - .ifMultiUser()

        https://docs.aws.amazon.com/deepracer/latest/developerguide/deepracer-get-started-test-in-simulator.html

        :stability: experimental
        '''
        return typing.cast("Deepracer", jsii.invoke(self, "toStopEvaluation", []))

    @jsii.member(jsii_name="toStopTrainingReinforcementLearningModel")
    def to_stop_training_reinforcement_learning_model(self) -> "Deepracer":
        '''(experimental) Grants permission to stop training a DeepRacer model.

        Access Level: Write

        Possible conditions:

        - .ifUserToken()
        - .ifMultiUser()

        https://docs.aws.amazon.com/deepracer/latest/developerguide/deepracer-get-started-training-model.html

        :stability: experimental
        '''
        return typing.cast("Deepracer", jsii.invoke(self, "toStopTrainingReinforcementLearningModel", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Deepracer":
        '''(experimental) Grants permission to tag a resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()
        - .ifAwsResourceTag()
        - .ifUserToken()
        - .ifMultiUser()

        https://docs.aws.amazon.com/deepracer/latest/developerguide/deepracer-tagging.html

        :stability: experimental
        '''
        return typing.cast("Deepracer", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toTestRewardFunction")
    def to_test_reward_function(self) -> "Deepracer":
        '''(experimental) Grants permission to test reward functions for correctness.

        Access Level: Write

        https://docs.aws.amazon.com/deepracer/latest/developerguide/deepracer-console-train-evaluate-models.html#deepracer-train-models-define-reward-function

        :stability: experimental
        '''
        return typing.cast("Deepracer", jsii.invoke(self, "toTestRewardFunction", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Deepracer":
        '''(experimental) Grants permission to untag a resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()
        - .ifAwsResourceTag()
        - .ifUserToken()
        - .ifMultiUser()

        https://docs.aws.amazon.com/deepracer/latest/developerguide/deepracer-tagging.html

        :stability: experimental
        '''
        return typing.cast("Deepracer", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateCar")
    def to_update_car(self) -> "Deepracer":
        '''(experimental) Grants permission to update a DeepRacer car in your garage.

        Access Level: Write

        Possible conditions:

        - .ifUserToken()
        - .ifMultiUser()

        https://docs.aws.amazon.com/deepracer/latest/developerguide/deepracer-choose-race-type.html

        :stability: experimental
        '''
        return typing.cast("Deepracer", jsii.invoke(self, "toUpdateCar", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__72fc9121ae89f0c96e05a27d1ca51af319a84c2af90fb54b63716fba2371dc2a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__22cb73c8250bd05c3af29c2b45db41d8896f3121e2a9272a1d82ba729b86a119)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Detective(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Detective",
):
    '''(experimental) Statement provider for service `detective <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazondetective.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `detective <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazondetective.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onGraph")
    def on_graph(
        self,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Detective":
        '''(experimental) Adds a resource of type Graph to the statement.

        https://docs.aws.amazon.com/detective/latest/adminguide/security_iam_service-with-iam.html#security_iam_service-with-iam-id-based-policies-resources

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a1b2d16e63209d9d837bc1e7464955af9597467f09a5f9009d54061e6cf2dfde)
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Detective", jsii.invoke(self, "onGraph", [resource_id, account, region, partition]))

    @jsii.member(jsii_name="toAcceptInvitation")
    def to_accept_invitation(self) -> "Detective":
        '''(experimental) Grants permission to accept an invitation to become a member of a behavior graph.

        Access Level: Write

        https://docs.aws.amazon.com/detective/latest/APIReference/API_AcceptInvitation.html

        :stability: experimental
        '''
        return typing.cast("Detective", jsii.invoke(self, "toAcceptInvitation", []))

    @jsii.member(jsii_name="toBatchGetGraphMemberDatasources")
    def to_batch_get_graph_member_datasources(self) -> "Detective":
        '''(experimental) Grants permission to retrieve the datasource package history for the specified member accounts in a behavior graph managed by this account.

        Access Level: Read

        https://docs.aws.amazon.com/detective/latest/APIReference/API_BatchGetGraphMemberDatasources.html

        :stability: experimental
        '''
        return typing.cast("Detective", jsii.invoke(self, "toBatchGetGraphMemberDatasources", []))

    @jsii.member(jsii_name="toBatchGetMembershipDatasources")
    def to_batch_get_membership_datasources(self) -> "Detective":
        '''(experimental) Grants permission to retrieve the datasource package history of the caller account for the specified graphs.

        Access Level: Read

        https://docs.aws.amazon.com/detective/latest/APIReference/API_BatchGetMembershipDatasources.html

        :stability: experimental
        '''
        return typing.cast("Detective", jsii.invoke(self, "toBatchGetMembershipDatasources", []))

    @jsii.member(jsii_name="toCreateGraph")
    def to_create_graph(self) -> "Detective":
        '''(experimental) Grants permission to create a behavior graph and begin to aggregate security information.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/detective/latest/APIReference/API_CreateGraph.html

        :stability: experimental
        '''
        return typing.cast("Detective", jsii.invoke(self, "toCreateGraph", []))

    @jsii.member(jsii_name="toCreateMembers")
    def to_create_members(self) -> "Detective":
        '''(experimental) Grants permission to request the membership of one or more accounts in a behavior graph managed by this account.

        Access Level: Write

        https://docs.aws.amazon.com/detective/latest/APIReference/API_CreateMembers.html

        :stability: experimental
        '''
        return typing.cast("Detective", jsii.invoke(self, "toCreateMembers", []))

    @jsii.member(jsii_name="toDeleteGraph")
    def to_delete_graph(self) -> "Detective":
        '''(experimental) Grants permission to delete a behavior graph and stop aggregating security information.

        Access Level: Write

        https://docs.aws.amazon.com/detective/latest/APIReference/API_DeleteGraph.html

        :stability: experimental
        '''
        return typing.cast("Detective", jsii.invoke(self, "toDeleteGraph", []))

    @jsii.member(jsii_name="toDeleteMembers")
    def to_delete_members(self) -> "Detective":
        '''(experimental) Grants permission to remove member accounts from a behavior graph managed by this account.

        Access Level: Write

        https://docs.aws.amazon.com/detective/latest/APIReference/API_DeleteMembers.html

        :stability: experimental
        '''
        return typing.cast("Detective", jsii.invoke(self, "toDeleteMembers", []))

    @jsii.member(jsii_name="toDescribeOrganizationConfiguration")
    def to_describe_organization_configuration(self) -> "Detective":
        '''(experimental) Grants permission to view the current configuration related to the Amazon Detective integration with AWS Organizations.

        Access Level: Read

        Dependent actions:

        - organizations:DescribeOrganization

        https://docs.aws.amazon.com/detective/latest/APIReference/API_DescribeOrganizationConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Detective", jsii.invoke(self, "toDescribeOrganizationConfiguration", []))

    @jsii.member(jsii_name="toDisableOrganizationAdminAccount")
    def to_disable_organization_admin_account(self) -> "Detective":
        '''(experimental) Grants permission to remove the Amazon Detective delegated administrator account for an organization.

        Access Level: Write

        Dependent actions:

        - organizations:DescribeOrganization

        https://docs.aws.amazon.com/detective/latest/APIReference/API_DisableOrganizationAdminAccount.html

        :stability: experimental
        '''
        return typing.cast("Detective", jsii.invoke(self, "toDisableOrganizationAdminAccount", []))

    @jsii.member(jsii_name="toDisassociateMembership")
    def to_disassociate_membership(self) -> "Detective":
        '''(experimental) Grants permission to remove the association of this account with a behavior graph.

        Access Level: Write

        https://docs.aws.amazon.com/detective/latest/APIReference/API_DisassociateMembership.html

        :stability: experimental
        '''
        return typing.cast("Detective", jsii.invoke(self, "toDisassociateMembership", []))

    @jsii.member(jsii_name="toEnableOrganizationAdminAccount")
    def to_enable_organization_admin_account(self) -> "Detective":
        '''(experimental) Grants permission to designate the Amazon Detective delegated administrator account for an organization.

        Access Level: Write

        Dependent actions:

        - iam:CreateServiceLinkedRole
        - organizations:DescribeOrganization
        - organizations:EnableAWSServiceAccess
        - organizations:RegisterDelegatedAdministrator

        https://docs.aws.amazon.com/detective/latest/APIReference/API_EnableOrganizationAdminAccount.html

        :stability: experimental
        '''
        return typing.cast("Detective", jsii.invoke(self, "toEnableOrganizationAdminAccount", []))

    @jsii.member(jsii_name="toGetFreeTrialEligibility")
    def to_get_free_trial_eligibility(self) -> "Detective":
        '''(experimental) Grants permission to retrieve a behavior graph's eligibility for a free trial period.

        Access Level: Read

        https://docs.aws.amazon.com/detective/latest/adminguide/free-trial-overview.html

        :stability: experimental
        '''
        return typing.cast("Detective", jsii.invoke(self, "toGetFreeTrialEligibility", []))

    @jsii.member(jsii_name="toGetGraphIngestState")
    def to_get_graph_ingest_state(self) -> "Detective":
        '''(experimental) Grants permission to retrieve the data ingestion state of a behavior graph.

        Access Level: Read

        https://docs.aws.amazon.com/detective/latest/adminguide/detective-source-data-about.html

        :stability: experimental
        '''
        return typing.cast("Detective", jsii.invoke(self, "toGetGraphIngestState", []))

    @jsii.member(jsii_name="toGetMembers")
    def to_get_members(self) -> "Detective":
        '''(experimental) Grants permission to retrieve details on specified members of a behavior graph.

        Access Level: Read

        https://docs.aws.amazon.com/detective/latest/APIReference/API_GetMembers.html

        :stability: experimental
        '''
        return typing.cast("Detective", jsii.invoke(self, "toGetMembers", []))

    @jsii.member(jsii_name="toGetPricingInformation")
    def to_get_pricing_information(self) -> "Detective":
        '''(experimental) Grants permission to retrieve information about Amazon Detective's pricing.

        Access Level: Read

        https://docs.aws.amazon.com/detective/latest/adminguide/usage-projected-cost-calculation.html

        :stability: experimental
        '''
        return typing.cast("Detective", jsii.invoke(self, "toGetPricingInformation", []))

    @jsii.member(jsii_name="toGetUsageInformation")
    def to_get_usage_information(self) -> "Detective":
        '''(experimental) Grants permission to list usage information of a behavior graph.

        Access Level: Read

        https://docs.aws.amazon.com/detective/latest/adminguide/tracking-usage-logging.html

        :stability: experimental
        '''
        return typing.cast("Detective", jsii.invoke(self, "toGetUsageInformation", []))

    @jsii.member(jsii_name="toListDatasourcePackages")
    def to_list_datasource_packages(self) -> "Detective":
        '''(experimental) Grants permission to list a graph's datasource package ingest states and timestamps for the most recent state changes in a behavior graph managed by this account.

        Access Level: List

        https://docs.aws.amazon.com/detective/latest/APIReference/API_ListDatasourcePackages.html

        :stability: experimental
        '''
        return typing.cast("Detective", jsii.invoke(self, "toListDatasourcePackages", []))

    @jsii.member(jsii_name="toListGraphs")
    def to_list_graphs(self) -> "Detective":
        '''(experimental) Grants permission to list behavior graphs managed by this account.

        Access Level: List

        https://docs.aws.amazon.com/detective/latest/APIReference/API_ListGraphs.html

        :stability: experimental
        '''
        return typing.cast("Detective", jsii.invoke(self, "toListGraphs", []))

    @jsii.member(jsii_name="toListHighDegreeEntities")
    def to_list_high_degree_entities(self) -> "Detective":
        '''(experimental) Grants permission to retrieve high volume entities whose relationships cannot be stored by Detective.

        Access Level: List

        https://docs.aws.amazon.com/detective/latest/userguide/high-volume-entities.html

        :stability: experimental
        '''
        return typing.cast("Detective", jsii.invoke(self, "toListHighDegreeEntities", []))

    @jsii.member(jsii_name="toListInvitations")
    def to_list_invitations(self) -> "Detective":
        '''(experimental) Grants permission to retrieve details on the behavior graphs to which this account has been invited to join.

        Access Level: List

        https://docs.aws.amazon.com/detective/latest/APIReference/API_ListInvitations.html

        :stability: experimental
        '''
        return typing.cast("Detective", jsii.invoke(self, "toListInvitations", []))

    @jsii.member(jsii_name="toListMembers")
    def to_list_members(self) -> "Detective":
        '''(experimental) Grants permission to retrieve details on all members of a behavior graph.

        Access Level: List

        https://docs.aws.amazon.com/detective/latest/APIReference/API_ListMembers.html

        :stability: experimental
        '''
        return typing.cast("Detective", jsii.invoke(self, "toListMembers", []))

    @jsii.member(jsii_name="toListOrganizationAdminAccount")
    def to_list_organization_admin_account(self) -> "Detective":
        '''(experimental) Grants permission to view the current Amazon Detective delegated administrator account for an organization.

        Access Level: List

        Dependent actions:

        - organizations:DescribeOrganization

        https://docs.aws.amazon.com/detective/latest/APIReference/API_ListOrganizationAdminAccounts.html

        :stability: experimental
        '''
        return typing.cast("Detective", jsii.invoke(self, "toListOrganizationAdminAccount", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Detective":
        '''(experimental) Grants permission to list the tag values that are assigned to a behavior graph.

        Access Level: List

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/detective/latest/APIReference/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("Detective", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toRejectInvitation")
    def to_reject_invitation(self) -> "Detective":
        '''(experimental) Grants permission to reject an invitation to become a member of a behavior graph.

        Access Level: Write

        https://docs.aws.amazon.com/detective/latest/APIReference/API_RejectInvitation.html

        :stability: experimental
        '''
        return typing.cast("Detective", jsii.invoke(self, "toRejectInvitation", []))

    @jsii.member(jsii_name="toSearchGraph")
    def to_search_graph(self) -> "Detective":
        '''(experimental) Grants permission to search the data stored in a behavior graph.

        Access Level: Read

        https://docs.aws.amazon.com/detective/latest/userguide/detective-search.html

        :stability: experimental
        '''
        return typing.cast("Detective", jsii.invoke(self, "toSearchGraph", []))

    @jsii.member(jsii_name="toStartMonitoringMember")
    def to_start_monitoring_member(self) -> "Detective":
        '''(experimental) Grants permission to start data ingest for a member account that has a status of ACCEPTED_BUT_DISABLED.

        Access Level: Write

        https://docs.aws.amazon.com/detective/latest/APIReference/API_StartMonitoringMember.html

        :stability: experimental
        '''
        return typing.cast("Detective", jsii.invoke(self, "toStartMonitoringMember", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Detective":
        '''(experimental) Grants permission to assign tag values to a behavior graph.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()
        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/detective/latest/APIReference/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("Detective", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Detective":
        '''(experimental) Grants permission to remove tag values from a behavior graph.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/detective/latest/APIReference/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("Detective", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateDatasourcePackages")
    def to_update_datasource_packages(self) -> "Detective":
        '''(experimental) Grants permission to enable or disable datasource package(s) in a behavior graph managed by this account.

        Access Level: Write

        https://docs.aws.amazon.com/detective/latest/APIReference/API_UpdateDatasourcePackages.html

        :stability: experimental
        '''
        return typing.cast("Detective", jsii.invoke(self, "toUpdateDatasourcePackages", []))

    @jsii.member(jsii_name="toUpdateOrganizationConfiguration")
    def to_update_organization_configuration(self) -> "Detective":
        '''(experimental) Grants permission to update the current configuration related to the Amazon Detective integration with AWS Organizations.

        Access Level: Write

        Dependent actions:

        - organizations:DescribeOrganization

        https://docs.aws.amazon.com/detective/latest/APIReference/API_UpdateOrganizationConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Detective", jsii.invoke(self, "toUpdateOrganizationConfiguration", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fdd62ff1589c1ecfdc2aaea627bfc41f627f1267b241f79089531d6e2138612c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8f7dfabb3714f5812f3b49529fed78dcf36f93491c2292b40f8bfbfdf3172cea)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Devicefarm(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Devicefarm",
):
    '''(experimental) Statement provider for service `devicefarm <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsdevicefarm.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `devicefarm <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsdevicefarm.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onArtifact")
    def on_artifact(
        self,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Devicefarm":
        '''(experimental) Adds a resource of type artifact to the statement.

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_Artifact.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__27c47050d73f3596e65e02ab11ece0e6b46a09b78c9f94fecb204e62b377e71b)
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Devicefarm", jsii.invoke(self, "onArtifact", [resource_id, account, region, partition]))

    @jsii.member(jsii_name="onDevice")
    def on_device(
        self,
        resource_id: builtins.str,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Devicefarm":
        '''(experimental) Adds a resource of type device to the statement.

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_Device.html

        :param resource_id: - Identifier for the resourceId.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__41d3007cf8b3856c2e601113e38b1864a040a0d1159da3f07d46f40913ca2822)
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Devicefarm", jsii.invoke(self, "onDevice", [resource_id, region, partition]))

    @jsii.member(jsii_name="onDeviceinstance")
    def on_deviceinstance(
        self,
        resource_id: builtins.str,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Devicefarm":
        '''(experimental) Adds a resource of type deviceinstance to the statement.

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_DeviceInstance.html

        :param resource_id: - Identifier for the resourceId.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__60f53e6a2587d98156d6d689822a1b577149f3f0222f9041c5e47220e13820a6)
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Devicefarm", jsii.invoke(self, "onDeviceinstance", [resource_id, region, partition]))

    @jsii.member(jsii_name="onDevicepool")
    def on_devicepool(
        self,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Devicefarm":
        '''(experimental) Adds a resource of type devicepool to the statement.

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_DevicePool.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__27a0144f99f38387fd594b6ee423e598e03882128e36d8d61588a9c23c0b7678)
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Devicefarm", jsii.invoke(self, "onDevicepool", [resource_id, account, region, partition]))

    @jsii.member(jsii_name="onInstanceprofile")
    def on_instanceprofile(
        self,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Devicefarm":
        '''(experimental) Adds a resource of type instanceprofile to the statement.

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_InstanceProfile.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__942acb233a4d13def17d5d7e1310ae9e3422d1e879a5db1f02fbaade9f0297a2)
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Devicefarm", jsii.invoke(self, "onInstanceprofile", [resource_id, account, region, partition]))

    @jsii.member(jsii_name="onJob")
    def on_job(
        self,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Devicefarm":
        '''(experimental) Adds a resource of type job to the statement.

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_Job.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fd61b5e2ed9c641c3711b55043360887f3f3af0431924b10c12b2bdeed59e1e9)
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Devicefarm", jsii.invoke(self, "onJob", [resource_id, account, region, partition]))

    @jsii.member(jsii_name="onNetworkprofile")
    def on_networkprofile(
        self,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Devicefarm":
        '''(experimental) Adds a resource of type networkprofile to the statement.

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_NetworkProfile.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a9a19499f0b4360fd4a6d813d79e6eb895198508937350111cd3a469d93b03a8)
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Devicefarm", jsii.invoke(self, "onNetworkprofile", [resource_id, account, region, partition]))

    @jsii.member(jsii_name="onProject")
    def on_project(
        self,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Devicefarm":
        '''(experimental) Adds a resource of type project to the statement.

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_Project.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__45147aff8059a8764ac8d4cbd6cadca558686c186c88085c6e110f3d4903f370)
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Devicefarm", jsii.invoke(self, "onProject", [resource_id, account, region, partition]))

    @jsii.member(jsii_name="onRun")
    def on_run(
        self,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Devicefarm":
        '''(experimental) Adds a resource of type run to the statement.

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_Run.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__53267c2d91df2c3bf7f6ce6b5aaf432f8c2e49854b69843df0c883cbc6220763)
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Devicefarm", jsii.invoke(self, "onRun", [resource_id, account, region, partition]))

    @jsii.member(jsii_name="onSample")
    def on_sample(
        self,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Devicefarm":
        '''(experimental) Adds a resource of type sample to the statement.

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_Sample.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d90cd2ac28354bf87b009dc7ed0ffc8a507391909c7328fa7c187ebc38cf65fb)
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Devicefarm", jsii.invoke(self, "onSample", [resource_id, account, region, partition]))

    @jsii.member(jsii_name="onSession")
    def on_session(
        self,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Devicefarm":
        '''(experimental) Adds a resource of type session to the statement.

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_RemoteAccessSession.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4805c5714935f6fd1d6ab11582287b4a9d339ad47f8637744cc12cd23fcf8ec9)
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Devicefarm", jsii.invoke(self, "onSession", [resource_id, account, region, partition]))

    @jsii.member(jsii_name="onSuite")
    def on_suite(
        self,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Devicefarm":
        '''(experimental) Adds a resource of type suite to the statement.

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_Suite.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__691ca538e823e1f0b6037f17a63e021ca479e087c79511818c10fb5885199e37)
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Devicefarm", jsii.invoke(self, "onSuite", [resource_id, account, region, partition]))

    @jsii.member(jsii_name="onTest")
    def on_test(
        self,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Devicefarm":
        '''(experimental) Adds a resource of type test to the statement.

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_Test.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f5f597fa6694fd1d9c42db42cc84b1c835fdbad88f80a65477657d21075c3286)
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Devicefarm", jsii.invoke(self, "onTest", [resource_id, account, region, partition]))

    @jsii.member(jsii_name="onTestgridProject")
    def on_testgrid_project(
        self,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Devicefarm":
        '''(experimental) Adds a resource of type testgrid-project to the statement.

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_TestGridProject.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1b36ce52195f421910b82b08b0cfe16701238a0550fc32150fddb34c84f137d2)
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Devicefarm", jsii.invoke(self, "onTestgridProject", [resource_id, account, region, partition]))

    @jsii.member(jsii_name="onTestgridSession")
    def on_testgrid_session(
        self,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Devicefarm":
        '''(experimental) Adds a resource of type testgrid-session to the statement.

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_TestGridSession.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ff685a508e375f46bec9f43b0caeef0e82961c634273dad465aed3dc59b4ccda)
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Devicefarm", jsii.invoke(self, "onTestgridSession", [resource_id, account, region, partition]))

    @jsii.member(jsii_name="onUpload")
    def on_upload(
        self,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Devicefarm":
        '''(experimental) Adds a resource of type upload to the statement.

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_Upload.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d79181b6283ae1bf921ac48afc920aa55a348df1a935b39830c46a4c25149cef)
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Devicefarm", jsii.invoke(self, "onUpload", [resource_id, account, region, partition]))

    @jsii.member(jsii_name="onVpceconfiguration")
    def on_vpceconfiguration(
        self,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Devicefarm":
        '''(experimental) Adds a resource of type vpceconfiguration to the statement.

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_VPCEConfiguration.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8b36c02c9e7938ebb5079ea0202a18e0028e41607fdfb78f206ab9a2576093c0)
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Devicefarm", jsii.invoke(self, "onVpceconfiguration", [resource_id, account, region, partition]))

    @jsii.member(jsii_name="toCreateDevicePool")
    def to_create_device_pool(self) -> "Devicefarm":
        '''(experimental) Grants permission to create a device pool within a project.

        Access Level: Write

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_CreateDevicePool.html

        :stability: experimental
        '''
        return typing.cast("Devicefarm", jsii.invoke(self, "toCreateDevicePool", []))

    @jsii.member(jsii_name="toCreateInstanceProfile")
    def to_create_instance_profile(self) -> "Devicefarm":
        '''(experimental) Grants permission to create a device instance profile.

        Access Level: Write

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_CreateInstanceProfile.html

        :stability: experimental
        '''
        return typing.cast("Devicefarm", jsii.invoke(self, "toCreateInstanceProfile", []))

    @jsii.member(jsii_name="toCreateNetworkProfile")
    def to_create_network_profile(self) -> "Devicefarm":
        '''(experimental) Grants permission to create a network profile within a project.

        Access Level: Write

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_CreateNetworkProfile.html

        :stability: experimental
        '''
        return typing.cast("Devicefarm", jsii.invoke(self, "toCreateNetworkProfile", []))

    @jsii.member(jsii_name="toCreateProject")
    def to_create_project(self) -> "Devicefarm":
        '''(experimental) Grants permission to create a project for mobile testing.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - ec2:CreateNetworkInterface
        - ec2:DescribeSecurityGroups
        - ec2:DescribeSubnets
        - ec2:DescribeVpcs
        - iam:CreateServiceLinkedRole

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_CreateProject.html

        :stability: experimental
        '''
        return typing.cast("Devicefarm", jsii.invoke(self, "toCreateProject", []))

    @jsii.member(jsii_name="toCreateRemoteAccessSession")
    def to_create_remote_access_session(self) -> "Devicefarm":
        '''(experimental) Grants permission to start a remote access session to a device instance.

        Access Level: Write

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_CreateRemoteAccessSession.html

        :stability: experimental
        '''
        return typing.cast("Devicefarm", jsii.invoke(self, "toCreateRemoteAccessSession", []))

    @jsii.member(jsii_name="toCreateTestGridProject")
    def to_create_test_grid_project(self) -> "Devicefarm":
        '''(experimental) Grants permission to create a project for desktop testing.

        Access Level: Write

        Dependent actions:

        - ec2:CreateNetworkInterface
        - ec2:DescribeSecurityGroups
        - ec2:DescribeSubnets
        - ec2:DescribeVpcs
        - iam:CreateServiceLinkedRole

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_CreateTestGridProject.html

        :stability: experimental
        '''
        return typing.cast("Devicefarm", jsii.invoke(self, "toCreateTestGridProject", []))

    @jsii.member(jsii_name="toCreateTestGridUrl")
    def to_create_test_grid_url(self) -> "Devicefarm":
        '''(experimental) Grants permission to generate a new pre-signed url used to access our test grid service.

        Access Level: Write

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_CreateTestGridUrl.html

        :stability: experimental
        '''
        return typing.cast("Devicefarm", jsii.invoke(self, "toCreateTestGridUrl", []))

    @jsii.member(jsii_name="toCreateUpload")
    def to_create_upload(self) -> "Devicefarm":
        '''(experimental) Grants permission to upload a new file or app within a project.

        Access Level: Write

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_CreateUpload.html

        :stability: experimental
        '''
        return typing.cast("Devicefarm", jsii.invoke(self, "toCreateUpload", []))

    @jsii.member(jsii_name="toCreateVPCEConfiguration")
    def to_create_vpce_configuration(self) -> "Devicefarm":
        '''(experimental) Grants permission to create an Amazon Virtual Private Cloud (VPC) endpoint configuration.

        Access Level: Write

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_CreateVPCEConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Devicefarm", jsii.invoke(self, "toCreateVPCEConfiguration", []))

    @jsii.member(jsii_name="toDeleteDevicePool")
    def to_delete_device_pool(self) -> "Devicefarm":
        '''(experimental) Grants permission to delete a user-generated device pool.

        Access Level: Write

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_DeleteDevicePool.html

        :stability: experimental
        '''
        return typing.cast("Devicefarm", jsii.invoke(self, "toDeleteDevicePool", []))

    @jsii.member(jsii_name="toDeleteInstanceProfile")
    def to_delete_instance_profile(self) -> "Devicefarm":
        '''(experimental) Grants permission to delete a user-generated instance profile.

        Access Level: Write

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_DeleteInstanceProfile.html

        :stability: experimental
        '''
        return typing.cast("Devicefarm", jsii.invoke(self, "toDeleteInstanceProfile", []))

    @jsii.member(jsii_name="toDeleteNetworkProfile")
    def to_delete_network_profile(self) -> "Devicefarm":
        '''(experimental) Grants permission to delete a user-generated network profile.

        Access Level: Write

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/DeleteNetworkProfile.html

        :stability: experimental
        '''
        return typing.cast("Devicefarm", jsii.invoke(self, "toDeleteNetworkProfile", []))

    @jsii.member(jsii_name="toDeleteProject")
    def to_delete_project(self) -> "Devicefarm":
        '''(experimental) Grants permission to delete a mobile testing project.

        Access Level: Write

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_DeleteProject.html

        :stability: experimental
        '''
        return typing.cast("Devicefarm", jsii.invoke(self, "toDeleteProject", []))

    @jsii.member(jsii_name="toDeleteRemoteAccessSession")
    def to_delete_remote_access_session(self) -> "Devicefarm":
        '''(experimental) Grants permission to delete a completed remote access session and its results.

        Access Level: Write

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_DeleteRemoteAccessSession.html

        :stability: experimental
        '''
        return typing.cast("Devicefarm", jsii.invoke(self, "toDeleteRemoteAccessSession", []))

    @jsii.member(jsii_name="toDeleteRun")
    def to_delete_run(self) -> "Devicefarm":
        '''(experimental) Grants permission to delete a run.

        Access Level: Write

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_DeleteRun.html

        :stability: experimental
        '''
        return typing.cast("Devicefarm", jsii.invoke(self, "toDeleteRun", []))

    @jsii.member(jsii_name="toDeleteTestGridProject")
    def to_delete_test_grid_project(self) -> "Devicefarm":
        '''(experimental) Grants permission to delete a desktop testing project.

        Access Level: Write

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_DeleteTestGridProject.html

        :stability: experimental
        '''
        return typing.cast("Devicefarm", jsii.invoke(self, "toDeleteTestGridProject", []))

    @jsii.member(jsii_name="toDeleteUpload")
    def to_delete_upload(self) -> "Devicefarm":
        '''(experimental) Grants permission to delete a user-uploaded file.

        Access Level: Write

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_DeleteUpload.html

        :stability: experimental
        '''
        return typing.cast("Devicefarm", jsii.invoke(self, "toDeleteUpload", []))

    @jsii.member(jsii_name="toDeleteVPCEConfiguration")
    def to_delete_vpce_configuration(self) -> "Devicefarm":
        '''(experimental) Grants permission to delete an Amazon Virtual Private Cloud (VPC) endpoint configuration.

        Access Level: Write

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_DeleteVPCEConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Devicefarm", jsii.invoke(self, "toDeleteVPCEConfiguration", []))

    @jsii.member(jsii_name="toGetAccountSettings")
    def to_get_account_settings(self) -> "Devicefarm":
        '''(experimental) Grants permission to retrieve the number of unmetered iOS and/or unmetered Android devices purchased by the account.

        Access Level: Read

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_GetAccountSettings.html

        :stability: experimental
        '''
        return typing.cast("Devicefarm", jsii.invoke(self, "toGetAccountSettings", []))

    @jsii.member(jsii_name="toGetDevice")
    def to_get_device(self) -> "Devicefarm":
        '''(experimental) Grants permission to retrieve the information of a unique device type.

        Access Level: Read

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_GetDevice.html

        :stability: experimental
        '''
        return typing.cast("Devicefarm", jsii.invoke(self, "toGetDevice", []))

    @jsii.member(jsii_name="toGetDeviceInstance")
    def to_get_device_instance(self) -> "Devicefarm":
        '''(experimental) Grants permission to retireve the information of a device instance.

        Access Level: Read

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_GetDeviceInstance.html

        :stability: experimental
        '''
        return typing.cast("Devicefarm", jsii.invoke(self, "toGetDeviceInstance", []))

    @jsii.member(jsii_name="toGetDevicePool")
    def to_get_device_pool(self) -> "Devicefarm":
        '''(experimental) Grants permission to retireve the information of a device pool.

        Access Level: Read

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_GetDevicePool.html

        :stability: experimental
        '''
        return typing.cast("Devicefarm", jsii.invoke(self, "toGetDevicePool", []))

    @jsii.member(jsii_name="toGetDevicePoolCompatibility")
    def to_get_device_pool_compatibility(self) -> "Devicefarm":
        '''(experimental) Grants permission to retrieve information about the compatibility of a test and/or app with a device pool.

        Access Level: Read

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_GetDevicePoolCompatibility.html

        :stability: experimental
        '''
        return typing.cast("Devicefarm", jsii.invoke(self, "toGetDevicePoolCompatibility", []))

    @jsii.member(jsii_name="toGetInstanceProfile")
    def to_get_instance_profile(self) -> "Devicefarm":
        '''(experimental) Grants permission to retireve the information of an instance profile.

        Access Level: Read

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_GetInstanceProfile.html

        :stability: experimental
        '''
        return typing.cast("Devicefarm", jsii.invoke(self, "toGetInstanceProfile", []))

    @jsii.member(jsii_name="toGetJob")
    def to_get_job(self) -> "Devicefarm":
        '''(experimental) Grants permission to retireve the information of a job.

        Access Level: Read

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_GetJob.html

        :stability: experimental
        '''
        return typing.cast("Devicefarm", jsii.invoke(self, "toGetJob", []))

    @jsii.member(jsii_name="toGetNetworkProfile")
    def to_get_network_profile(self) -> "Devicefarm":
        '''(experimental) Grants permission to retireve the information of a network profile.

        Access Level: Read

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_GetNetworkProfile.html

        :stability: experimental
        '''
        return typing.cast("Devicefarm", jsii.invoke(self, "toGetNetworkProfile", []))

    @jsii.member(jsii_name="toGetOfferingStatus")
    def to_get_offering_status(self) -> "Devicefarm":
        '''(experimental) Grants permission to retrieve the current status and future status of all offerings purchased by an AWS account.

        Access Level: Read

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_GetOfferingStatus.html

        :stability: experimental
        '''
        return typing.cast("Devicefarm", jsii.invoke(self, "toGetOfferingStatus", []))

    @jsii.member(jsii_name="toGetProject")
    def to_get_project(self) -> "Devicefarm":
        '''(experimental) Grants permission to retrieve information about a mobile testing project.

        Access Level: Read

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_GetProject.html

        :stability: experimental
        '''
        return typing.cast("Devicefarm", jsii.invoke(self, "toGetProject", []))

    @jsii.member(jsii_name="toGetRemoteAccessSession")
    def to_get_remote_access_session(self) -> "Devicefarm":
        '''(experimental) Grants permission to retireve the link to a currently running remote access session.

        Access Level: Read

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_GetRemoteAccessSession.html

        :stability: experimental
        '''
        return typing.cast("Devicefarm", jsii.invoke(self, "toGetRemoteAccessSession", []))

    @jsii.member(jsii_name="toGetRun")
    def to_get_run(self) -> "Devicefarm":
        '''(experimental) Grants permission to retireve the information of a run.

        Access Level: Read

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_GetRun.html

        :stability: experimental
        '''
        return typing.cast("Devicefarm", jsii.invoke(self, "toGetRun", []))

    @jsii.member(jsii_name="toGetSuite")
    def to_get_suite(self) -> "Devicefarm":
        '''(experimental) Grants permission to retireve the information of a testing suite.

        Access Level: Read

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_GetSuite.html

        :stability: experimental
        '''
        return typing.cast("Devicefarm", jsii.invoke(self, "toGetSuite", []))

    @jsii.member(jsii_name="toGetTest")
    def to_get_test(self) -> "Devicefarm":
        '''(experimental) Grants permission to retireve the information of a test case.

        Access Level: Read

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_GetTest.html

        :stability: experimental
        '''
        return typing.cast("Devicefarm", jsii.invoke(self, "toGetTest", []))

    @jsii.member(jsii_name="toGetTestGridProject")
    def to_get_test_grid_project(self) -> "Devicefarm":
        '''(experimental) Grants permission to retrieve information about a desktop testing project.

        Access Level: Read

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_GetTestGridProject.html

        :stability: experimental
        '''
        return typing.cast("Devicefarm", jsii.invoke(self, "toGetTestGridProject", []))

    @jsii.member(jsii_name="toGetTestGridSession")
    def to_get_test_grid_session(self) -> "Devicefarm":
        '''(experimental) Grants permission to retireve the information of a test grid session.

        Access Level: Read

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_GetTestGridSession.html

        :stability: experimental
        '''
        return typing.cast("Devicefarm", jsii.invoke(self, "toGetTestGridSession", []))

    @jsii.member(jsii_name="toGetUpload")
    def to_get_upload(self) -> "Devicefarm":
        '''(experimental) Grants permission to retireve the information of an uploaded file.

        Access Level: Read

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_GetUpload.html

        :stability: experimental
        '''
        return typing.cast("Devicefarm", jsii.invoke(self, "toGetUpload", []))

    @jsii.member(jsii_name="toGetVPCEConfiguration")
    def to_get_vpce_configuration(self) -> "Devicefarm":
        '''(experimental) Grants permission to retireve the information of an Amazon Virtual Private Cloud (VPC) endpoint configuration.

        Access Level: Read

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_GetVPCEConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Devicefarm", jsii.invoke(self, "toGetVPCEConfiguration", []))

    @jsii.member(jsii_name="toInstallToRemoteAccessSession")
    def to_install_to_remote_access_session(self) -> "Devicefarm":
        '''(experimental) Grants permission to install an application to a device in a remote access session.

        Access Level: Write

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_InstallToRemoteAccessSession.html

        :stability: experimental
        '''
        return typing.cast("Devicefarm", jsii.invoke(self, "toInstallToRemoteAccessSession", []))

    @jsii.member(jsii_name="toListArtifacts")
    def to_list_artifacts(self) -> "Devicefarm":
        '''(experimental) Grants permission to list the artifacts in a project.

        Access Level: List

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_ListArtifacts.html

        :stability: experimental
        '''
        return typing.cast("Devicefarm", jsii.invoke(self, "toListArtifacts", []))

    @jsii.member(jsii_name="toListDeviceInstances")
    def to_list_device_instances(self) -> "Devicefarm":
        '''(experimental) Grants permission to list the information of device instances.

        Access Level: List

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_ListDeviceInstances.html

        :stability: experimental
        '''
        return typing.cast("Devicefarm", jsii.invoke(self, "toListDeviceInstances", []))

    @jsii.member(jsii_name="toListDevicePools")
    def to_list_device_pools(self) -> "Devicefarm":
        '''(experimental) Grants permission to list the information of device pools.

        Access Level: List

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_ListDevicePools.html

        :stability: experimental
        '''
        return typing.cast("Devicefarm", jsii.invoke(self, "toListDevicePools", []))

    @jsii.member(jsii_name="toListDevices")
    def to_list_devices(self) -> "Devicefarm":
        '''(experimental) Grants permission to list the information of unique device types.

        Access Level: List

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_ListDevices.html

        :stability: experimental
        '''
        return typing.cast("Devicefarm", jsii.invoke(self, "toListDevices", []))

    @jsii.member(jsii_name="toListInstanceProfiles")
    def to_list_instance_profiles(self) -> "Devicefarm":
        '''(experimental) Grants permission to list the information of device instance profiles.

        Access Level: List

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_ListInstanceProfiles.html

        :stability: experimental
        '''
        return typing.cast("Devicefarm", jsii.invoke(self, "toListInstanceProfiles", []))

    @jsii.member(jsii_name="toListJobs")
    def to_list_jobs(self) -> "Devicefarm":
        '''(experimental) Grants permission to list the information of jobs within a run.

        Access Level: List

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_ListJobs.html

        :stability: experimental
        '''
        return typing.cast("Devicefarm", jsii.invoke(self, "toListJobs", []))

    @jsii.member(jsii_name="toListNetworkProfiles")
    def to_list_network_profiles(self) -> "Devicefarm":
        '''(experimental) Grants permission to list the information of network profiles within a project.

        Access Level: List

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_ListNetworkProfiles.html

        :stability: experimental
        '''
        return typing.cast("Devicefarm", jsii.invoke(self, "toListNetworkProfiles", []))

    @jsii.member(jsii_name="toListOfferingPromotions")
    def to_list_offering_promotions(self) -> "Devicefarm":
        '''(experimental) Grants permission to list the offering promotions.

        Access Level: List

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_ListOfferingPromotions.html

        :stability: experimental
        '''
        return typing.cast("Devicefarm", jsii.invoke(self, "toListOfferingPromotions", []))

    @jsii.member(jsii_name="toListOfferings")
    def to_list_offerings(self) -> "Devicefarm":
        '''(experimental) Grants permission to list the products or offerings that the user can manage through the API.

        Access Level: List

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_ListOfferings.html

        :stability: experimental
        '''
        return typing.cast("Devicefarm", jsii.invoke(self, "toListOfferings", []))

    @jsii.member(jsii_name="toListOfferingTransactions")
    def to_list_offering_transactions(self) -> "Devicefarm":
        '''(experimental) Grants permission to list all of the historical purchases, renewals, and system renewal transactions for an AWS account.

        Access Level: List

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_ListOfferingTransactions.html

        :stability: experimental
        '''
        return typing.cast("Devicefarm", jsii.invoke(self, "toListOfferingTransactions", []))

    @jsii.member(jsii_name="toListProjects")
    def to_list_projects(self) -> "Devicefarm":
        '''(experimental) Grants permission to list the information of mobile testing projects for an AWS account.

        Access Level: List

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_ListProjects.html

        :stability: experimental
        '''
        return typing.cast("Devicefarm", jsii.invoke(self, "toListProjects", []))

    @jsii.member(jsii_name="toListRemoteAccessSessions")
    def to_list_remote_access_sessions(self) -> "Devicefarm":
        '''(experimental) Grants permission to list the information of currently running remote access sessions.

        Access Level: List

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_ListRemoteAccessSessions.html

        :stability: experimental
        '''
        return typing.cast("Devicefarm", jsii.invoke(self, "toListRemoteAccessSessions", []))

    @jsii.member(jsii_name="toListRuns")
    def to_list_runs(self) -> "Devicefarm":
        '''(experimental) Grants permission to list the information of runs within a project.

        Access Level: List

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_ListRuns.html

        :stability: experimental
        '''
        return typing.cast("Devicefarm", jsii.invoke(self, "toListRuns", []))

    @jsii.member(jsii_name="toListSamples")
    def to_list_samples(self) -> "Devicefarm":
        '''(experimental) Grants permission to list the information of samples within a project.

        Access Level: List

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_ListSamples.html

        :stability: experimental
        '''
        return typing.cast("Devicefarm", jsii.invoke(self, "toListSamples", []))

    @jsii.member(jsii_name="toListSuites")
    def to_list_suites(self) -> "Devicefarm":
        '''(experimental) Grants permission to list the information of testing suites within a job.

        Access Level: List

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_ListSuites.html

        :stability: experimental
        '''
        return typing.cast("Devicefarm", jsii.invoke(self, "toListSuites", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Devicefarm":
        '''(experimental) Grants permission to list the tags of a resource.

        Access Level: List

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("Devicefarm", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toListTestGridProjects")
    def to_list_test_grid_projects(self) -> "Devicefarm":
        '''(experimental) Grants permission to list the information of desktop testing projects for an AWS account.

        Access Level: List

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_ListTestGridProjects.html

        :stability: experimental
        '''
        return typing.cast("Devicefarm", jsii.invoke(self, "toListTestGridProjects", []))

    @jsii.member(jsii_name="toListTestGridSessionActions")
    def to_list_test_grid_session_actions(self) -> "Devicefarm":
        '''(experimental) Grants permission to list the session actions performed during a test grid session.

        Access Level: List

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_ListTestGridSessionActions.html

        :stability: experimental
        '''
        return typing.cast("Devicefarm", jsii.invoke(self, "toListTestGridSessionActions", []))

    @jsii.member(jsii_name="toListTestGridSessionArtifacts")
    def to_list_test_grid_session_artifacts(self) -> "Devicefarm":
        '''(experimental) Grants permission to list the artifacts generated by a test grid session.

        Access Level: List

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_ListTestGridSessionArtifacts.html

        :stability: experimental
        '''
        return typing.cast("Devicefarm", jsii.invoke(self, "toListTestGridSessionArtifacts", []))

    @jsii.member(jsii_name="toListTestGridSessions")
    def to_list_test_grid_sessions(self) -> "Devicefarm":
        '''(experimental) Grants permission to list the sessions within a test grid project.

        Access Level: List

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_ListTestGridSessions.html

        :stability: experimental
        '''
        return typing.cast("Devicefarm", jsii.invoke(self, "toListTestGridSessions", []))

    @jsii.member(jsii_name="toListTests")
    def to_list_tests(self) -> "Devicefarm":
        '''(experimental) Grants permission to list the information of tests within a testing suite.

        Access Level: List

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_ListTests.html

        :stability: experimental
        '''
        return typing.cast("Devicefarm", jsii.invoke(self, "toListTests", []))

    @jsii.member(jsii_name="toListUniqueProblems")
    def to_list_unique_problems(self) -> "Devicefarm":
        '''(experimental) Grants permission to list the information of unique problems within a run.

        Access Level: List

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_ListUniqueProblems.html

        :stability: experimental
        '''
        return typing.cast("Devicefarm", jsii.invoke(self, "toListUniqueProblems", []))

    @jsii.member(jsii_name="toListUploads")
    def to_list_uploads(self) -> "Devicefarm":
        '''(experimental) Grants permission to list the information of uploads within a project.

        Access Level: List

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_ListUploads.html

        :stability: experimental
        '''
        return typing.cast("Devicefarm", jsii.invoke(self, "toListUploads", []))

    @jsii.member(jsii_name="toListVPCEConfigurations")
    def to_list_vpce_configurations(self) -> "Devicefarm":
        '''(experimental) Grants permission to list the information of Amazon Virtual Private Cloud (VPC) endpoint configurations.

        Access Level: List

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_ListVPCEConfigurations.html

        :stability: experimental
        '''
        return typing.cast("Devicefarm", jsii.invoke(self, "toListVPCEConfigurations", []))

    @jsii.member(jsii_name="toPurchaseOffering")
    def to_purchase_offering(self) -> "Devicefarm":
        '''(experimental) Grants permission to purchase offerings for an AWS account.

        Access Level: Write

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_PurchaseOffering.html

        :stability: experimental
        '''
        return typing.cast("Devicefarm", jsii.invoke(self, "toPurchaseOffering", []))

    @jsii.member(jsii_name="toRenewOffering")
    def to_renew_offering(self) -> "Devicefarm":
        '''(experimental) Grants permission to set the quantity of devices to renew for an offering.

        Access Level: Write

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_RenewOffering.html

        :stability: experimental
        '''
        return typing.cast("Devicefarm", jsii.invoke(self, "toRenewOffering", []))

    @jsii.member(jsii_name="toScheduleRun")
    def to_schedule_run(self) -> "Devicefarm":
        '''(experimental) Grants permission to schedule a run.

        Access Level: Write

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_ScheduleRun.html

        :stability: experimental
        '''
        return typing.cast("Devicefarm", jsii.invoke(self, "toScheduleRun", []))

    @jsii.member(jsii_name="toStopJob")
    def to_stop_job(self) -> "Devicefarm":
        '''(experimental) Grants permission to terminate a running job.

        Access Level: Write

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_StopJob.html

        :stability: experimental
        '''
        return typing.cast("Devicefarm", jsii.invoke(self, "toStopJob", []))

    @jsii.member(jsii_name="toStopRemoteAccessSession")
    def to_stop_remote_access_session(self) -> "Devicefarm":
        '''(experimental) Grants permission to terminate a running remote access session.

        Access Level: Write

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_StopRemoteAccessSession.html

        :stability: experimental
        '''
        return typing.cast("Devicefarm", jsii.invoke(self, "toStopRemoteAccessSession", []))

    @jsii.member(jsii_name="toStopRun")
    def to_stop_run(self) -> "Devicefarm":
        '''(experimental) Grants permission to terminate a running test run.

        Access Level: Write

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_StopRun.html

        :stability: experimental
        '''
        return typing.cast("Devicefarm", jsii.invoke(self, "toStopRun", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Devicefarm":
        '''(experimental) Grants permission to add tags to a resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("Devicefarm", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Devicefarm":
        '''(experimental) Grants permission to remove tags from a resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("Devicefarm", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateDeviceInstance")
    def to_update_device_instance(self) -> "Devicefarm":
        '''(experimental) Grants permission to modify an existing device instance.

        Access Level: Write

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_UpdateDeviceInstance.html

        :stability: experimental
        '''
        return typing.cast("Devicefarm", jsii.invoke(self, "toUpdateDeviceInstance", []))

    @jsii.member(jsii_name="toUpdateDevicePool")
    def to_update_device_pool(self) -> "Devicefarm":
        '''(experimental) Grants permission to modify an existing device pool.

        Access Level: Write

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_UpdateDevicePool.html

        :stability: experimental
        '''
        return typing.cast("Devicefarm", jsii.invoke(self, "toUpdateDevicePool", []))

    @jsii.member(jsii_name="toUpdateInstanceProfile")
    def to_update_instance_profile(self) -> "Devicefarm":
        '''(experimental) Grants permission to modify an existing instance profile.

        Access Level: Write

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_UpdateInstanceProfile.html

        :stability: experimental
        '''
        return typing.cast("Devicefarm", jsii.invoke(self, "toUpdateInstanceProfile", []))

    @jsii.member(jsii_name="toUpdateNetworkProfile")
    def to_update_network_profile(self) -> "Devicefarm":
        '''(experimental) Grants permission to modify an existing network profile.

        Access Level: Write

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_UpdateNetworkProfile.html

        :stability: experimental
        '''
        return typing.cast("Devicefarm", jsii.invoke(self, "toUpdateNetworkProfile", []))

    @jsii.member(jsii_name="toUpdateProject")
    def to_update_project(self) -> "Devicefarm":
        '''(experimental) Grants permission to modify an existing mobile testing project.

        Access Level: Write

        Dependent actions:

        - ec2:CreateNetworkInterface
        - ec2:DescribeSecurityGroups
        - ec2:DescribeSubnets
        - ec2:DescribeVpcs
        - iam:CreateServiceLinkedRole

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_UpdateProject.html

        :stability: experimental
        '''
        return typing.cast("Devicefarm", jsii.invoke(self, "toUpdateProject", []))

    @jsii.member(jsii_name="toUpdateTestGridProject")
    def to_update_test_grid_project(self) -> "Devicefarm":
        '''(experimental) Grants permission to modify an existing desktop testing project.

        Access Level: Write

        Dependent actions:

        - ec2:CreateNetworkInterface
        - ec2:DescribeSecurityGroups
        - ec2:DescribeSubnets
        - ec2:DescribeVpcs
        - iam:CreateServiceLinkedRole

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_UpdateTestGridProject.html

        :stability: experimental
        '''
        return typing.cast("Devicefarm", jsii.invoke(self, "toUpdateTestGridProject", []))

    @jsii.member(jsii_name="toUpdateUpload")
    def to_update_upload(self) -> "Devicefarm":
        '''(experimental) Grants permission to modify an existing upload.

        Access Level: Write

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_UpdateUpload.html

        :stability: experimental
        '''
        return typing.cast("Devicefarm", jsii.invoke(self, "toUpdateUpload", []))

    @jsii.member(jsii_name="toUpdateVPCEConfiguration")
    def to_update_vpce_configuration(self) -> "Devicefarm":
        '''(experimental) Grants permission to modify an existing Amazon Virtual Private Cloud (VPC) endpoint configuration.

        Access Level: Write

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_UpdateVPCEConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Devicefarm", jsii.invoke(self, "toUpdateVPCEConfiguration", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__df09e7a1bf45d3675dbf8b9b001f2272695cd5ed9626b519aa36169aa96af559)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8e2de2758aceb7e7ebeab53ff9ed0a1ae4f98ec6e66c4d15daefb3611792d80a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class DevopsGuru(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.DevopsGuru",
):
    '''(experimental) Statement provider for service `devops-guru <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazondevopsguru.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `devops-guru <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazondevopsguru.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onTopic")
    def on_topic(
        self,
        topic_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "DevopsGuru":
        '''(experimental) Adds a resource of type topic to the statement.

        https://docs.aws.amazon.com/devops-guru/latest/userguide/setting-up.html#setting-up-notifications

        :param topic_name: - Identifier for the topicName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5f3f6d89cf999ac0095a61f5b4bb7ba8465e750a4998daeef38f2663eddc6cb2)
            check_type(argname="argument topic_name", value=topic_name, expected_type=type_hints["topic_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("DevopsGuru", jsii.invoke(self, "onTopic", [topic_name, account, region, partition]))

    @jsii.member(jsii_name="toAddNotificationChannel")
    def to_add_notification_channel(self) -> "DevopsGuru":
        '''(experimental) Grants permission to add a notification channel to DevOps Guru.

        Access Level: Write

        Dependent actions:

        - sns:GetTopicAttributes
        - sns:SetTopicAttributes

        https://docs.aws.amazon.com/devops-guru/latest/APIReference/API_AddNotificationChannel.html

        :stability: experimental
        '''
        return typing.cast("DevopsGuru", jsii.invoke(self, "toAddNotificationChannel", []))

    @jsii.member(jsii_name="toDeleteInsight")
    def to_delete_insight(self) -> "DevopsGuru":
        '''(experimental) Grants permission to delete specified insight in your account.

        Access Level: Write

        https://docs.aws.amazon.com/devops-guru/latest/APIReference/API_DeleteInsight.html

        :stability: experimental
        '''
        return typing.cast("DevopsGuru", jsii.invoke(self, "toDeleteInsight", []))

    @jsii.member(jsii_name="toDescribeAccountHealth")
    def to_describe_account_health(self) -> "DevopsGuru":
        '''(experimental) Grants permission to view the health of operations in your AWS account.

        Access Level: Read

        https://docs.aws.amazon.com/devops-guru/latest/APIReference/API_DescribeAccountHealth.html

        :stability: experimental
        '''
        return typing.cast("DevopsGuru", jsii.invoke(self, "toDescribeAccountHealth", []))

    @jsii.member(jsii_name="toDescribeAccountOverview")
    def to_describe_account_overview(self) -> "DevopsGuru":
        '''(experimental) Grants permission to view the health of operations within a time range in your AWS account.

        Access Level: Read

        https://docs.aws.amazon.com/devops-guru/latest/APIReference/API_DescribeAccountOverview.html

        :stability: experimental
        '''
        return typing.cast("DevopsGuru", jsii.invoke(self, "toDescribeAccountOverview", []))

    @jsii.member(jsii_name="toDescribeAnomaly")
    def to_describe_anomaly(self) -> "DevopsGuru":
        '''(experimental) Grants permission to list the details of a specified anomaly.

        Access Level: Read

        https://docs.aws.amazon.com/devops-guru/latest/APIReference/API_DescribeAnomaly.html

        :stability: experimental
        '''
        return typing.cast("DevopsGuru", jsii.invoke(self, "toDescribeAnomaly", []))

    @jsii.member(jsii_name="toDescribeEventSourcesConfig")
    def to_describe_event_sources_config(self) -> "DevopsGuru":
        '''(experimental) Grants permission to retrieve details about event sources for DevOps Guru.

        Access Level: Read

        https://docs.aws.amazon.com/devops-guru/latest/APIReference/API_DescribeEventSourcesConfig.html

        :stability: experimental
        '''
        return typing.cast("DevopsGuru", jsii.invoke(self, "toDescribeEventSourcesConfig", []))

    @jsii.member(jsii_name="toDescribeFeedback")
    def to_describe_feedback(self) -> "DevopsGuru":
        '''(experimental) Grants permission to view the feedback details of a specified insight.

        Access Level: Read

        https://docs.aws.amazon.com/devops-guru/latest/APIReference/API_DescribeFeedback.html

        :stability: experimental
        '''
        return typing.cast("DevopsGuru", jsii.invoke(self, "toDescribeFeedback", []))

    @jsii.member(jsii_name="toDescribeInsight")
    def to_describe_insight(self) -> "DevopsGuru":
        '''(experimental) Grants permission to list the details of a specified insight.

        Access Level: Read

        https://docs.aws.amazon.com/devops-guru/latest/APIReference/API_DescribeInsight.html

        :stability: experimental
        '''
        return typing.cast("DevopsGuru", jsii.invoke(self, "toDescribeInsight", []))

    @jsii.member(jsii_name="toDescribeOrganizationHealth")
    def to_describe_organization_health(self) -> "DevopsGuru":
        '''(experimental) Grants permission to view the health of operations in your organization.

        Access Level: Read

        https://docs.aws.amazon.com/devops-guru/latest/APIReference/API_DescribeOrganizationHealth.html

        :stability: experimental
        '''
        return typing.cast("DevopsGuru", jsii.invoke(self, "toDescribeOrganizationHealth", []))

    @jsii.member(jsii_name="toDescribeOrganizationOverview")
    def to_describe_organization_overview(self) -> "DevopsGuru":
        '''(experimental) Grants permission to view the health of operations within a time range in your organization.

        Access Level: Read

        https://docs.aws.amazon.com/devops-guru/latest/APIReference/API_DescribeOrganizationOverview.html

        :stability: experimental
        '''
        return typing.cast("DevopsGuru", jsii.invoke(self, "toDescribeOrganizationOverview", []))

    @jsii.member(jsii_name="toDescribeOrganizationResourceCollectionHealth")
    def to_describe_organization_resource_collection_health(self) -> "DevopsGuru":
        '''(experimental) Grants permission to view the health of operations for each AWS CloudFormation stack or AWS Services or accounts specified in DevOps Guru in your organization.

        Access Level: Read

        https://docs.aws.amazon.com/devops-guru/latest/APIReference/API_DescribeOrganizationResourceCollectionHealth.html

        :stability: experimental
        '''
        return typing.cast("DevopsGuru", jsii.invoke(self, "toDescribeOrganizationResourceCollectionHealth", []))

    @jsii.member(jsii_name="toDescribeResourceCollectionHealth")
    def to_describe_resource_collection_health(self) -> "DevopsGuru":
        '''(experimental) Grants permission to view the health of operations for each AWS CloudFormation stack specified in DevOps Guru.

        Access Level: Read

        https://docs.aws.amazon.com/devops-guru/latest/APIReference/API_DescribeResourceCollectionHealth.html

        :stability: experimental
        '''
        return typing.cast("DevopsGuru", jsii.invoke(self, "toDescribeResourceCollectionHealth", []))

    @jsii.member(jsii_name="toDescribeServiceIntegration")
    def to_describe_service_integration(self) -> "DevopsGuru":
        '''(experimental) Grants permission to view the integration status of services that can be integrated with DevOps Guru.

        Access Level: Read

        https://docs.aws.amazon.com/devops-guru/latest/APIReference/API_DescribeServiceIntegration.html

        :stability: experimental
        '''
        return typing.cast("DevopsGuru", jsii.invoke(self, "toDescribeServiceIntegration", []))

    @jsii.member(jsii_name="toGetCostEstimation")
    def to_get_cost_estimation(self) -> "DevopsGuru":
        '''(experimental) Grants permission to list service resource cost estimates.

        Access Level: Read

        https://docs.aws.amazon.com/devops-guru/latest/APIReference/API_GetCostEstimation.html

        :stability: experimental
        '''
        return typing.cast("DevopsGuru", jsii.invoke(self, "toGetCostEstimation", []))

    @jsii.member(jsii_name="toGetResourceCollection")
    def to_get_resource_collection(self) -> "DevopsGuru":
        '''(experimental) Grants permission to list AWS CloudFormation stacks that DevOps Guru is configured to use.

        Access Level: Read

        https://docs.aws.amazon.com/devops-guru/latest/APIReference/API_GetResourceCollection.html

        :stability: experimental
        '''
        return typing.cast("DevopsGuru", jsii.invoke(self, "toGetResourceCollection", []))

    @jsii.member(jsii_name="toListAnomaliesForInsight")
    def to_list_anomalies_for_insight(self) -> "DevopsGuru":
        '''(experimental) Grants permission to list anomalies of a given insight in your account.

        Access Level: List

        https://docs.aws.amazon.com/devops-guru/latest/APIReference/API_ListAnomaliesForInsight.html

        :stability: experimental
        '''
        return typing.cast("DevopsGuru", jsii.invoke(self, "toListAnomaliesForInsight", []))

    @jsii.member(jsii_name="toListAnomalousLogGroups")
    def to_list_anomalous_log_groups(self) -> "DevopsGuru":
        '''(experimental) Grants permission to list log anomalies of a given insight in your account.

        Access Level: List

        https://docs.aws.amazon.com/devops-guru/latest/APIReference/API_ListAnomalousLogGroups.html

        :stability: experimental
        '''
        return typing.cast("DevopsGuru", jsii.invoke(self, "toListAnomalousLogGroups", []))

    @jsii.member(jsii_name="toListEvents")
    def to_list_events(self) -> "DevopsGuru":
        '''(experimental) Grants permission to list resource events that are evaluated by DevOps Guru.

        Access Level: List

        https://docs.aws.amazon.com/devops-guru/latest/APIReference/API_ListEvents.html

        :stability: experimental
        '''
        return typing.cast("DevopsGuru", jsii.invoke(self, "toListEvents", []))

    @jsii.member(jsii_name="toListInsights")
    def to_list_insights(self) -> "DevopsGuru":
        '''(experimental) Grants permission to list insights in your account.

        Access Level: List

        https://docs.aws.amazon.com/devops-guru/latest/APIReference/API_ListInsights.html

        :stability: experimental
        '''
        return typing.cast("DevopsGuru", jsii.invoke(self, "toListInsights", []))

    @jsii.member(jsii_name="toListMonitoredResources")
    def to_list_monitored_resources(self) -> "DevopsGuru":
        '''(experimental) Grants permission to list resource monitored by DevOps Guru in your account.

        Access Level: List

        https://docs.aws.amazon.com/devops-guru/latest/APIReference/API_ListMonitoredResources.html

        :stability: experimental
        '''
        return typing.cast("DevopsGuru", jsii.invoke(self, "toListMonitoredResources", []))

    @jsii.member(jsii_name="toListNotificationChannels")
    def to_list_notification_channels(self) -> "DevopsGuru":
        '''(experimental) Grants permission to list notification channels configured for DevOps Guru in your account.

        Access Level: List

        https://docs.aws.amazon.com/devops-guru/latest/APIReference/API_ListNotificationChannels.html

        :stability: experimental
        '''
        return typing.cast("DevopsGuru", jsii.invoke(self, "toListNotificationChannels", []))

    @jsii.member(jsii_name="toListOrganizationInsights")
    def to_list_organization_insights(self) -> "DevopsGuru":
        '''(experimental) Grants permission to list insights in your organization.

        Access Level: List

        https://docs.aws.amazon.com/devops-guru/latest/APIReference/API_ListOrganizationInsights.html

        :stability: experimental
        '''
        return typing.cast("DevopsGuru", jsii.invoke(self, "toListOrganizationInsights", []))

    @jsii.member(jsii_name="toListRecommendations")
    def to_list_recommendations(self) -> "DevopsGuru":
        '''(experimental) Grants permission to list a specified insight's recommendations.

        Access Level: List

        https://docs.aws.amazon.com/devops-guru/latest/APIReference/API_ListRecommendations.html

        :stability: experimental
        '''
        return typing.cast("DevopsGuru", jsii.invoke(self, "toListRecommendations", []))

    @jsii.member(jsii_name="toPutFeedback")
    def to_put_feedback(self) -> "DevopsGuru":
        '''(experimental) Grants permission to submit a feedback to DevOps Guru.

        Access Level: Write

        https://docs.aws.amazon.com/devops-guru/latest/APIReference/API_PutFeedback.html

        :stability: experimental
        '''
        return typing.cast("DevopsGuru", jsii.invoke(self, "toPutFeedback", []))

    @jsii.member(jsii_name="toRemoveNotificationChannel")
    def to_remove_notification_channel(self) -> "DevopsGuru":
        '''(experimental) Grants permission to remove a notification channel from DevOps Guru.

        Access Level: Write

        Dependent actions:

        - sns:GetTopicAttributes
        - sns:SetTopicAttributes

        https://docs.aws.amazon.com/devops-guru/latest/APIReference/API_RemoveNotificationChannel.html

        :stability: experimental
        '''
        return typing.cast("DevopsGuru", jsii.invoke(self, "toRemoveNotificationChannel", []))

    @jsii.member(jsii_name="toSearchInsights")
    def to_search_insights(self) -> "DevopsGuru":
        '''(experimental) Grants permission to search insights in your account.

        Access Level: List

        https://docs.aws.amazon.com/devops-guru/latest/APIReference/API_SearchInsights.html

        :stability: experimental
        '''
        return typing.cast("DevopsGuru", jsii.invoke(self, "toSearchInsights", []))

    @jsii.member(jsii_name="toSearchOrganizationInsights")
    def to_search_organization_insights(self) -> "DevopsGuru":
        '''(experimental) Grants permission to search insights in your organization.

        Access Level: List

        https://docs.aws.amazon.com/devops-guru/latest/APIReference/API_SearchOrganizationInsights.html

        :stability: experimental
        '''
        return typing.cast("DevopsGuru", jsii.invoke(self, "toSearchOrganizationInsights", []))

    @jsii.member(jsii_name="toStartCostEstimation")
    def to_start_cost_estimation(self) -> "DevopsGuru":
        '''(experimental) Grants permission to start the creation of an estimate of the monthly cost.

        Access Level: Read

        https://docs.aws.amazon.com/devops-guru/latest/APIReference/API_StartCostEstimation.html

        :stability: experimental
        '''
        return typing.cast("DevopsGuru", jsii.invoke(self, "toStartCostEstimation", []))

    @jsii.member(jsii_name="toUpdateEventSourcesConfig")
    def to_update_event_sources_config(self) -> "DevopsGuru":
        '''(experimental) Grants permission to update an event source for DevOps Guru.

        Access Level: Write

        https://docs.aws.amazon.com/devops-guru/latest/APIReference/API_UpdateEventSourcesConfig.html

        :stability: experimental
        '''
        return typing.cast("DevopsGuru", jsii.invoke(self, "toUpdateEventSourcesConfig", []))

    @jsii.member(jsii_name="toUpdateResourceCollection")
    def to_update_resource_collection(self) -> "DevopsGuru":
        '''(experimental) Grants permission to update the list of AWS CloudFormation stacks that are used to specify which AWS resources in your account are analyzed by DevOps Guru.

        Access Level: Write

        https://docs.aws.amazon.com/devops-guru/latest/APIReference/API_UpdateResourceCollection.html

        :stability: experimental
        '''
        return typing.cast("DevopsGuru", jsii.invoke(self, "toUpdateResourceCollection", []))

    @jsii.member(jsii_name="toUpdateServiceIntegration")
    def to_update_service_integration(self) -> "DevopsGuru":
        '''(experimental) Grants permission to enable or disable a service that integrates with DevOps Guru.

        Access Level: Write

        https://docs.aws.amazon.com/devops-guru/latest/APIReference/API_UpdateServiceIntegration.html

        :stability: experimental
        '''
        return typing.cast("DevopsGuru", jsii.invoke(self, "toUpdateServiceIntegration", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__91a429516291494461cb9bba39e3fe8ef0cb18f2e26bafa434620b52a3293acb)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a7c4f61555c5ec755bbfe28db8abb7c61952740490ef74118f504e6ea9c9d89f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Directconnect(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Directconnect",
):
    '''(experimental) Statement provider for service `directconnect <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsdirectconnect.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `directconnect <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsdirectconnect.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onDxcon")
    def on_dxcon(
        self,
        connection_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Directconnect":
        '''(experimental) Adds a resource of type dxcon to the statement.

        https://docs.aws.amazon.com/directconnect/latest/APIReference/API_Connection.html

        :param connection_id: - Identifier for the connectionId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__34b61d7d18033e54916b7fa13384b91ee3323238b1c5f2ac46932cb34e6c3e14)
            check_type(argname="argument connection_id", value=connection_id, expected_type=type_hints["connection_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Directconnect", jsii.invoke(self, "onDxcon", [connection_id, account, region, partition]))

    @jsii.member(jsii_name="onDxGateway")
    def on_dx_gateway(
        self,
        direct_connect_gateway_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Directconnect":
        '''(experimental) Adds a resource of type dx-gateway to the statement.

        https://docs.aws.amazon.com/directconnect/latest/APIReference/API_DirectConnectGateway.html

        :param direct_connect_gateway_id: - Identifier for the directConnectGatewayId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__66e48d2afb7c5313d12509d13e8bd03361ac5f0741237c3d4b4896d77ecee94a)
            check_type(argname="argument direct_connect_gateway_id", value=direct_connect_gateway_id, expected_type=type_hints["direct_connect_gateway_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Directconnect", jsii.invoke(self, "onDxGateway", [direct_connect_gateway_id, account, partition]))

    @jsii.member(jsii_name="onDxlag")
    def on_dxlag(
        self,
        lag_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Directconnect":
        '''(experimental) Adds a resource of type dxlag to the statement.

        https://docs.aws.amazon.com/directconnect/latest/APIReference/API_Lag.html

        :param lag_id: - Identifier for the lagId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f442681d2a4076b5a8e99e7d269d7f2c75065b7284c5628121e73a5bed6979c1)
            check_type(argname="argument lag_id", value=lag_id, expected_type=type_hints["lag_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Directconnect", jsii.invoke(self, "onDxlag", [lag_id, account, region, partition]))

    @jsii.member(jsii_name="onDxvif")
    def on_dxvif(
        self,
        virtual_interface_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Directconnect":
        '''(experimental) Adds a resource of type dxvif to the statement.

        https://docs.aws.amazon.com/directconnect/latest/APIReference/API_VirtualInterface.html

        :param virtual_interface_id: - Identifier for the virtualInterfaceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5679b50d0867b04badc8c54679a39c5281f36c75c45249093f03e182ff632a32)
            check_type(argname="argument virtual_interface_id", value=virtual_interface_id, expected_type=type_hints["virtual_interface_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Directconnect", jsii.invoke(self, "onDxvif", [virtual_interface_id, account, region, partition]))

    @jsii.member(jsii_name="toAcceptDirectConnectGatewayAssociationProposal")
    def to_accept_direct_connect_gateway_association_proposal(self) -> "Directconnect":
        '''(experimental) Grants permission to accept a proposal request to attach a virtual private gateway to a Direct Connect gateway.

        Access Level: Write

        https://docs.aws.amazon.com/directconnect/latest/APIReference/API_AcceptDirectConnectGatewayAssociationProposal.html

        :stability: experimental
        '''
        return typing.cast("Directconnect", jsii.invoke(self, "toAcceptDirectConnectGatewayAssociationProposal", []))

    @jsii.member(jsii_name="toAllocateConnectionOnInterconnect")
    def to_allocate_connection_on_interconnect(self) -> "Directconnect":
        '''(experimental) Grants permission to create a hosted connection on an interconnect.

        Access Level: Write

        https://docs.aws.amazon.com/directconnect/latest/APIReference/API_AllocateConnectionOnInterconnect.html

        :stability: experimental
        '''
        return typing.cast("Directconnect", jsii.invoke(self, "toAllocateConnectionOnInterconnect", []))

    @jsii.member(jsii_name="toAllocateHostedConnection")
    def to_allocate_hosted_connection(self) -> "Directconnect":
        '''(experimental) Grants permission to create a new hosted connection between a AWS Direct Connect partner's network and a specific AWS Direct Connect location.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/directconnect/latest/APIReference/API_AllocateHostedConnection.html

        :stability: experimental
        '''
        return typing.cast("Directconnect", jsii.invoke(self, "toAllocateHostedConnection", []))

    @jsii.member(jsii_name="toAllocatePrivateVirtualInterface")
    def to_allocate_private_virtual_interface(self) -> "Directconnect":
        '''(experimental) Grants permission to provision a private virtual interface to be owned by a different customer.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/directconnect/latest/APIReference/API_AllocatePrivateVirtualInterface.html

        :stability: experimental
        '''
        return typing.cast("Directconnect", jsii.invoke(self, "toAllocatePrivateVirtualInterface", []))

    @jsii.member(jsii_name="toAllocatePublicVirtualInterface")
    def to_allocate_public_virtual_interface(self) -> "Directconnect":
        '''(experimental) Grants permission to provision a public virtual interface to be owned by a different customer.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/directconnect/latest/APIReference/API_AllocatePublicVirtualInterface.html

        :stability: experimental
        '''
        return typing.cast("Directconnect", jsii.invoke(self, "toAllocatePublicVirtualInterface", []))

    @jsii.member(jsii_name="toAllocateTransitVirtualInterface")
    def to_allocate_transit_virtual_interface(self) -> "Directconnect":
        '''(experimental) Grants permission to provision a transit virtual interface to be owned by a different customer.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/directconnect/latest/APIReference/API_AllocateTransitVirtualInterface.html

        :stability: experimental
        '''
        return typing.cast("Directconnect", jsii.invoke(self, "toAllocateTransitVirtualInterface", []))

    @jsii.member(jsii_name="toAssociateConnectionWithLag")
    def to_associate_connection_with_lag(self) -> "Directconnect":
        '''(experimental) Grants permission to associate a connection with a LAG.

        Access Level: Write

        https://docs.aws.amazon.com/directconnect/latest/APIReference/API_AssociateConnectionWithLag.html

        :stability: experimental
        '''
        return typing.cast("Directconnect", jsii.invoke(self, "toAssociateConnectionWithLag", []))

    @jsii.member(jsii_name="toAssociateHostedConnection")
    def to_associate_hosted_connection(self) -> "Directconnect":
        '''(experimental) Grants permission to associate a hosted connection and its virtual interfaces with a link aggregation group (LAG) or interconnect.

        Access Level: Write

        https://docs.aws.amazon.com/directconnect/latest/APIReference/API_AssociateHostedConnection.html

        :stability: experimental
        '''
        return typing.cast("Directconnect", jsii.invoke(self, "toAssociateHostedConnection", []))

    @jsii.member(jsii_name="toAssociateMacSecKey")
    def to_associate_mac_sec_key(self) -> "Directconnect":
        '''(experimental) Grants permission to associate a MAC Security (MACsec) Connection Key Name (CKN)/ Connectivity Association Key (CAK) pair with an AWS Direct Connect dedicated connection.

        Access Level: Write

        https://docs.aws.amazon.com/directconnect/latest/APIReference/API_AssociateMacSecKey.html

        :stability: experimental
        '''
        return typing.cast("Directconnect", jsii.invoke(self, "toAssociateMacSecKey", []))

    @jsii.member(jsii_name="toAssociateVirtualInterface")
    def to_associate_virtual_interface(self) -> "Directconnect":
        '''(experimental) Grants permission to associate a virtual interface with a specified link aggregation group (LAG) or connection.

        Access Level: Write

        https://docs.aws.amazon.com/directconnect/latest/APIReference/API_AssociateVirtualInterface.html

        :stability: experimental
        '''
        return typing.cast("Directconnect", jsii.invoke(self, "toAssociateVirtualInterface", []))

    @jsii.member(jsii_name="toConfirmConnection")
    def to_confirm_connection(self) -> "Directconnect":
        '''(experimental) Grants permission to confirm the creation of a hosted connection on an interconnect.

        Access Level: Write

        https://docs.aws.amazon.com/directconnect/latest/APIReference/API_ConfirmConnection.html

        :stability: experimental
        '''
        return typing.cast("Directconnect", jsii.invoke(self, "toConfirmConnection", []))

    @jsii.member(jsii_name="toConfirmCustomerAgreement")
    def to_confirm_customer_agreement(self) -> "Directconnect":
        '''(experimental) Grants permission to confirm the the terms of agreement when creating the connection or link aggregation group (LAG).

        Access Level: Write

        https://docs.aws.amazon.com/directconnect/latest/APIReference/API_ConfirmCustomerAgreement.html

        :stability: experimental
        '''
        return typing.cast("Directconnect", jsii.invoke(self, "toConfirmCustomerAgreement", []))

    @jsii.member(jsii_name="toConfirmPrivateVirtualInterface")
    def to_confirm_private_virtual_interface(self) -> "Directconnect":
        '''(experimental) Grants permission to accept ownership of a private virtual interface created by another customer.

        Access Level: Write

        https://docs.aws.amazon.com/directconnect/latest/APIReference/API_ConfirmPrivateVirtualInterface.html

        :stability: experimental
        '''
        return typing.cast("Directconnect", jsii.invoke(self, "toConfirmPrivateVirtualInterface", []))

    @jsii.member(jsii_name="toConfirmPublicVirtualInterface")
    def to_confirm_public_virtual_interface(self) -> "Directconnect":
        '''(experimental) Grants permission to accept ownership of a public virtual interface created by another customer.

        Access Level: Write

        https://docs.aws.amazon.com/directconnect/latest/APIReference/API_ConfirmPublicVirtualInterface.html

        :stability: experimental
        '''
        return typing.cast("Directconnect", jsii.invoke(self, "toConfirmPublicVirtualInterface", []))

    @jsii.member(jsii_name="toConfirmTransitVirtualInterface")
    def to_confirm_transit_virtual_interface(self) -> "Directconnect":
        '''(experimental) Grants permission to accept ownership of a transit virtual interface created by another customer.

        Access Level: Write

        https://docs.aws.amazon.com/directconnect/latest/APIReference/API_ConfirmTransitVirtualInterface.html

        :stability: experimental
        '''
        return typing.cast("Directconnect", jsii.invoke(self, "toConfirmTransitVirtualInterface", []))

    @jsii.member(jsii_name="toCreateBGPPeer")
    def to_create_bgp_peer(self) -> "Directconnect":
        '''(experimental) Grants permission to create a BGP peer on the specified virtual interface.

        Access Level: Write

        https://docs.aws.amazon.com/directconnect/latest/APIReference/API_CreateBGPPeer.html

        :stability: experimental
        '''
        return typing.cast("Directconnect", jsii.invoke(self, "toCreateBGPPeer", []))

    @jsii.member(jsii_name="toCreateConnection")
    def to_create_connection(self) -> "Directconnect":
        '''(experimental) Grants permission to create a new connection between the customer network and a specific AWS Direct Connect location.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/directconnect/latest/APIReference/API_CreateConnection.html

        :stability: experimental
        '''
        return typing.cast("Directconnect", jsii.invoke(self, "toCreateConnection", []))

    @jsii.member(jsii_name="toCreateDirectConnectGateway")
    def to_create_direct_connect_gateway(self) -> "Directconnect":
        '''(experimental) Grants permission to create a Direct Connect gateway, which is an intermediate object that enables you to connect a set of virtual interfaces and virtual private gateways.

        Access Level: Write

        https://docs.aws.amazon.com/directconnect/latest/APIReference/API_CreateDirectConnectGateway.html

        :stability: experimental
        '''
        return typing.cast("Directconnect", jsii.invoke(self, "toCreateDirectConnectGateway", []))

    @jsii.member(jsii_name="toCreateDirectConnectGatewayAssociation")
    def to_create_direct_connect_gateway_association(self) -> "Directconnect":
        '''(experimental) Grants permission to create an association between a Direct Connect gateway and a virtual private gateway.

        Access Level: Write

        https://docs.aws.amazon.com/directconnect/latest/APIReference/API_CreateDirectConnectGatewayAssociation.html

        :stability: experimental
        '''
        return typing.cast("Directconnect", jsii.invoke(self, "toCreateDirectConnectGatewayAssociation", []))

    @jsii.member(jsii_name="toCreateDirectConnectGatewayAssociationProposal")
    def to_create_direct_connect_gateway_association_proposal(self) -> "Directconnect":
        '''(experimental) Grants permission to create a proposal to associate the specified virtual private gateway with the specified Direct Connect gateway.

        Access Level: Write

        https://docs.aws.amazon.com/directconnect/latest/APIReference/API_CreateDirectConnectGatewayAssociationProposal.html

        :stability: experimental
        '''
        return typing.cast("Directconnect", jsii.invoke(self, "toCreateDirectConnectGatewayAssociationProposal", []))

    @jsii.member(jsii_name="toCreateInterconnect")
    def to_create_interconnect(self) -> "Directconnect":
        '''(experimental) Grants permission to create a new interconnect between a AWS Direct Connect partner's network and a specific AWS Direct Connect location.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/directconnect/latest/APIReference/API_CreateInterconnect.html

        :stability: experimental
        '''
        return typing.cast("Directconnect", jsii.invoke(self, "toCreateInterconnect", []))

    @jsii.member(jsii_name="toCreateLag")
    def to_create_lag(self) -> "Directconnect":
        '''(experimental) Grants permission to create a link aggregation group (LAG) with the specified number of bundled physical connections between the customer network and a specific AWS Direct Connect location.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/directconnect/latest/APIReference/API_CreateLag.html

        :stability: experimental
        '''
        return typing.cast("Directconnect", jsii.invoke(self, "toCreateLag", []))

    @jsii.member(jsii_name="toCreatePrivateVirtualInterface")
    def to_create_private_virtual_interface(self) -> "Directconnect":
        '''(experimental) Grants permission to create a new private virtual interface.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/directconnect/latest/APIReference/API_CreatePrivateVirtualInterface.html

        :stability: experimental
        '''
        return typing.cast("Directconnect", jsii.invoke(self, "toCreatePrivateVirtualInterface", []))

    @jsii.member(jsii_name="toCreatePublicVirtualInterface")
    def to_create_public_virtual_interface(self) -> "Directconnect":
        '''(experimental) Grants permission to create a new public virtual interface.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/directconnect/latest/APIReference/API_CreatePublicVirtualInterface.html

        :stability: experimental
        '''
        return typing.cast("Directconnect", jsii.invoke(self, "toCreatePublicVirtualInterface", []))

    @jsii.member(jsii_name="toCreateTransitVirtualInterface")
    def to_create_transit_virtual_interface(self) -> "Directconnect":
        '''(experimental) Grants permission to create a new transit virtual interface.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/directconnect/latest/APIReference/API_CreateTransitVirtualInterface.html

        :stability: experimental
        '''
        return typing.cast("Directconnect", jsii.invoke(self, "toCreateTransitVirtualInterface", []))

    @jsii.member(jsii_name="toDeleteBGPPeer")
    def to_delete_bgp_peer(self) -> "Directconnect":
        '''(experimental) Grants permission to delete the specified BGP peer on the specified virtual interface with the specified customer address and ASN.

        Access Level: Write

        https://docs.aws.amazon.com/directconnect/latest/APIReference/API_DeleteBGPPeer.html

        :stability: experimental
        '''
        return typing.cast("Directconnect", jsii.invoke(self, "toDeleteBGPPeer", []))

    @jsii.member(jsii_name="toDeleteConnection")
    def to_delete_connection(self) -> "Directconnect":
        '''(experimental) Grants permission to delete the connection.

        Access Level: Write

        https://docs.aws.amazon.com/directconnect/latest/APIReference/API_DeleteConnection.html

        :stability: experimental
        '''
        return typing.cast("Directconnect", jsii.invoke(self, "toDeleteConnection", []))

    @jsii.member(jsii_name="toDeleteDirectConnectGateway")
    def to_delete_direct_connect_gateway(self) -> "Directconnect":
        '''(experimental) Grants permission to delete the specified Direct Connect gateway.

        Access Level: Write

        https://docs.aws.amazon.com/directconnect/latest/APIReference/API_DeleteDirectConnectGateway.html

        :stability: experimental
        '''
        return typing.cast("Directconnect", jsii.invoke(self, "toDeleteDirectConnectGateway", []))

    @jsii.member(jsii_name="toDeleteDirectConnectGatewayAssociation")
    def to_delete_direct_connect_gateway_association(self) -> "Directconnect":
        '''(experimental) Grants permission to delete the association between the specified Direct Connect gateway and virtual private gateway.

        Access Level: Write

        https://docs.aws.amazon.com/directconnect/latest/APIReference/API_DeleteDirectConnectGatewayAssociation.html

        :stability: experimental
        '''
        return typing.cast("Directconnect", jsii.invoke(self, "toDeleteDirectConnectGatewayAssociation", []))

    @jsii.member(jsii_name="toDeleteDirectConnectGatewayAssociationProposal")
    def to_delete_direct_connect_gateway_association_proposal(self) -> "Directconnect":
        '''(experimental) Grants permission to delete the association proposal request between the specified Direct Connect gateway and virtual private gateway.

        Access Level: Write

        https://docs.aws.amazon.com/directconnect/latest/APIReference/API_DeleteDirectConnectGatewayAssociationProposal.html

        :stability: experimental
        '''
        return typing.cast("Directconnect", jsii.invoke(self, "toDeleteDirectConnectGatewayAssociationProposal", []))

    @jsii.member(jsii_name="toDeleteInterconnect")
    def to_delete_interconnect(self) -> "Directconnect":
        '''(experimental) Grants permission to delete the specified interconnect.

        Access Level: Write

        https://docs.aws.amazon.com/directconnect/latest/APIReference/API_DeleteInterconnect.html

        :stability: experimental
        '''
        return typing.cast("Directconnect", jsii.invoke(self, "toDeleteInterconnect", []))

    @jsii.member(jsii_name="toDeleteLag")
    def to_delete_lag(self) -> "Directconnect":
        '''(experimental) Grants permission to delete the specified link aggregation group (LAG).

        Access Level: Write

        https://docs.aws.amazon.com/directconnect/latest/APIReference/API_DeleteLag.html

        :stability: experimental
        '''
        return typing.cast("Directconnect", jsii.invoke(self, "toDeleteLag", []))

    @jsii.member(jsii_name="toDeleteVirtualInterface")
    def to_delete_virtual_interface(self) -> "Directconnect":
        '''(experimental) Grants permission to delete a virtual interface.

        Access Level: Write

        https://docs.aws.amazon.com/directconnect/latest/APIReference/API_DeleteVirtualInterface.html

        :stability: experimental
        '''
        return typing.cast("Directconnect", jsii.invoke(self, "toDeleteVirtualInterface", []))

    @jsii.member(jsii_name="toDescribeConnectionLoa")
    def to_describe_connection_loa(self) -> "Directconnect":
        '''(experimental) Grants permission to describe the LOA-CFA for a Connection.

        Access Level: Read

        https://docs.aws.amazon.com/directconnect/latest/APIReference/API_DescribeConnectionLoa.html

        :stability: experimental
        '''
        return typing.cast("Directconnect", jsii.invoke(self, "toDescribeConnectionLoa", []))

    @jsii.member(jsii_name="toDescribeConnections")
    def to_describe_connections(self) -> "Directconnect":
        '''(experimental) Grants permission to describe all connections in this region.

        Access Level: Read

        https://docs.aws.amazon.com/directconnect/latest/APIReference/API_DescribeConnections.html

        :stability: experimental
        '''
        return typing.cast("Directconnect", jsii.invoke(self, "toDescribeConnections", []))

    @jsii.member(jsii_name="toDescribeConnectionsOnInterconnect")
    def to_describe_connections_on_interconnect(self) -> "Directconnect":
        '''(experimental) Grants permission to describe a list of connections that have been provisioned on the given interconnect.

        Access Level: Read

        https://docs.aws.amazon.com/directconnect/latest/APIReference/API_DescribeConnectionsOnInterconnect.html

        :stability: experimental
        '''
        return typing.cast("Directconnect", jsii.invoke(self, "toDescribeConnectionsOnInterconnect", []))

    @jsii.member(jsii_name="toDescribeCustomerMetadata")
    def to_describe_customer_metadata(self) -> "Directconnect":
        '''(experimental) Grants permission to view a list of customer agreements, along with their signed status and whether the customer is an NNIPartner, NNIPartnerV2, or a nonPartner.

        Access Level: Read

        https://docs.aws.amazon.com/directconnect/latest/APIReference/API_DescribeCustomerMetadata.html

        :stability: experimental
        '''
        return typing.cast("Directconnect", jsii.invoke(self, "toDescribeCustomerMetadata", []))

    @jsii.member(jsii_name="toDescribeDirectConnectGatewayAssociationProposals")
    def to_describe_direct_connect_gateway_association_proposals(
        self,
    ) -> "Directconnect":
        '''(experimental) Grants permission to describe one or more association proposals for connection between a virtual private gateway and a Direct Connect gateway.

        Access Level: Read

        https://docs.aws.amazon.com/directconnect/latest/APIReference/API_DescribeDirectConnectGatewayAssociationProposals.html

        :stability: experimental
        '''
        return typing.cast("Directconnect", jsii.invoke(self, "toDescribeDirectConnectGatewayAssociationProposals", []))

    @jsii.member(jsii_name="toDescribeDirectConnectGatewayAssociations")
    def to_describe_direct_connect_gateway_associations(self) -> "Directconnect":
        '''(experimental) Grants permission to describe the associations between your Direct Connect gateways and virtual private gateways.

        Access Level: Read

        https://docs.aws.amazon.com/directconnect/latest/APIReference/API_DescribeDirectConnectGatewayAssociations.html

        :stability: experimental
        '''
        return typing.cast("Directconnect", jsii.invoke(self, "toDescribeDirectConnectGatewayAssociations", []))

    @jsii.member(jsii_name="toDescribeDirectConnectGatewayAttachments")
    def to_describe_direct_connect_gateway_attachments(self) -> "Directconnect":
        '''(experimental) Grants permission to describe the attachments between your Direct Connect gateways and virtual interfaces.

        Access Level: Read

        https://docs.aws.amazon.com/directconnect/latest/APIReference/API_DescribeDirectConnectGatewayAttachments.html

        :stability: experimental
        '''
        return typing.cast("Directconnect", jsii.invoke(self, "toDescribeDirectConnectGatewayAttachments", []))

    @jsii.member(jsii_name="toDescribeDirectConnectGateways")
    def to_describe_direct_connect_gateways(self) -> "Directconnect":
        '''(experimental) Grants permission to describe all your Direct Connect gateways or only the specified Direct Connect gateway.

        Access Level: Read

        https://docs.aws.amazon.com/directconnect/latest/APIReference/API_DescribeDirectConnectGateways.html

        :stability: experimental
        '''
        return typing.cast("Directconnect", jsii.invoke(self, "toDescribeDirectConnectGateways", []))

    @jsii.member(jsii_name="toDescribeHostedConnections")
    def to_describe_hosted_connections(self) -> "Directconnect":
        '''(experimental) Grants permission to describe the hosted connections that have been provisioned on the specified interconnect or link aggregation group (LAG).

        Access Level: Read

        https://docs.aws.amazon.com/directconnect/latest/APIReference/API_DescribeHostedConnections.html

        :stability: experimental
        '''
        return typing.cast("Directconnect", jsii.invoke(self, "toDescribeHostedConnections", []))

    @jsii.member(jsii_name="toDescribeInterconnectLoa")
    def to_describe_interconnect_loa(self) -> "Directconnect":
        '''(experimental) Grants permission to describe the LOA-CFA for an Interconnect.

        Access Level: Read

        https://docs.aws.amazon.com/directconnect/latest/APIReference/API_DescribeInterconnectLoa.html

        :stability: experimental
        '''
        return typing.cast("Directconnect", jsii.invoke(self, "toDescribeInterconnectLoa", []))

    @jsii.member(jsii_name="toDescribeInterconnects")
    def to_describe_interconnects(self) -> "Directconnect":
        '''(experimental) Grants permission to describe a list of interconnects owned by the AWS account.

        Access Level: Read

        https://docs.aws.amazon.com/directconnect/latest/APIReference/API_DescribeInterconnects.html

        :stability: experimental
        '''
        return typing.cast("Directconnect", jsii.invoke(self, "toDescribeInterconnects", []))

    @jsii.member(jsii_name="toDescribeLags")
    def to_describe_lags(self) -> "Directconnect":
        '''(experimental) Grants permission to describe all your link aggregation groups (LAG) or the specified LAG.

        Access Level: Read

        https://docs.aws.amazon.com/directconnect/latest/APIReference/API_DescribeLags.html

        :stability: experimental
        '''
        return typing.cast("Directconnect", jsii.invoke(self, "toDescribeLags", []))

    @jsii.member(jsii_name="toDescribeLoa")
    def to_describe_loa(self) -> "Directconnect":
        '''(experimental) Grants permission to describe the LOA-CFA for a connection, interconnect, or link aggregation group (LAG).

        Access Level: Read

        https://docs.aws.amazon.com/directconnect/latest/APIReference/API_DescribeLoa.html

        :stability: experimental
        '''
        return typing.cast("Directconnect", jsii.invoke(self, "toDescribeLoa", []))

    @jsii.member(jsii_name="toDescribeLocations")
    def to_describe_locations(self) -> "Directconnect":
        '''(experimental) Grants permission to describe the list of AWS Direct Connect locations in the current AWS region.

        Access Level: Read

        https://docs.aws.amazon.com/directconnect/latest/APIReference/API_DescribeLocations.html

        :stability: experimental
        '''
        return typing.cast("Directconnect", jsii.invoke(self, "toDescribeLocations", []))

    @jsii.member(jsii_name="toDescribeRouterConfiguration")
    def to_describe_router_configuration(self) -> "Directconnect":
        '''(experimental) Grants permission to describe Details about the router for a virtual interface.

        Access Level: Read

        https://docs.aws.amazon.com/directconnect/latest/APIReference/API_DescribeRouterConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Directconnect", jsii.invoke(self, "toDescribeRouterConfiguration", []))

    @jsii.member(jsii_name="toDescribeTags")
    def to_describe_tags(self) -> "Directconnect":
        '''(experimental) Grants permission to describe the tags associated with the specified AWS Direct Connect resources.

        Access Level: Read

        https://docs.aws.amazon.com/directconnect/latest/APIReference/API_DescribeTags.html

        :stability: experimental
        '''
        return typing.cast("Directconnect", jsii.invoke(self, "toDescribeTags", []))

    @jsii.member(jsii_name="toDescribeVirtualGateways")
    def to_describe_virtual_gateways(self) -> "Directconnect":
        '''(experimental) Grants permission to describe a list of virtual private gateways owned by the AWS account.

        Access Level: Read

        https://docs.aws.amazon.com/directconnect/latest/APIReference/API_DescribeVirtualGateways.html

        :stability: experimental
        '''
        return typing.cast("Directconnect", jsii.invoke(self, "toDescribeVirtualGateways", []))

    @jsii.member(jsii_name="toDescribeVirtualInterfaces")
    def to_describe_virtual_interfaces(self) -> "Directconnect":
        '''(experimental) Grants permission to describe all virtual interfaces for an AWS account.

        Access Level: Read

        https://docs.aws.amazon.com/directconnect/latest/APIReference/API_DescribeVirtualInterfaces.html

        :stability: experimental
        '''
        return typing.cast("Directconnect", jsii.invoke(self, "toDescribeVirtualInterfaces", []))

    @jsii.member(jsii_name="toDisassociateConnectionFromLag")
    def to_disassociate_connection_from_lag(self) -> "Directconnect":
        '''(experimental) Grants permission to disassociate a connection from a link aggregation group (LAG).

        Access Level: Write

        https://docs.aws.amazon.com/directconnect/latest/APIReference/API_DisassociateConnectionFromLag.html

        :stability: experimental
        '''
        return typing.cast("Directconnect", jsii.invoke(self, "toDisassociateConnectionFromLag", []))

    @jsii.member(jsii_name="toDisassociateMacSecKey")
    def to_disassociate_mac_sec_key(self) -> "Directconnect":
        '''(experimental) Grants permission to remove the association between a MAC Security (MACsec) security key and an AWS Direct Connect dedicated connection.

        Access Level: Write

        https://docs.aws.amazon.com/directconnect/latest/APIReference/API_DisassociateMacSecKey.html

        :stability: experimental
        '''
        return typing.cast("Directconnect", jsii.invoke(self, "toDisassociateMacSecKey", []))

    @jsii.member(jsii_name="toListVirtualInterfaceTestHistory")
    def to_list_virtual_interface_test_history(self) -> "Directconnect":
        '''(experimental) Grants permission to list the virtual interface failover test history.

        Access Level: List

        https://docs.aws.amazon.com/directconnect/latest/APIReference/API_ListVirtualInterfaceTestHistory.html

        :stability: experimental
        '''
        return typing.cast("Directconnect", jsii.invoke(self, "toListVirtualInterfaceTestHistory", []))

    @jsii.member(jsii_name="toStartBgpFailoverTest")
    def to_start_bgp_failover_test(self) -> "Directconnect":
        '''(experimental) Grants permission to start the virtual interface failover test that verifies your configuration meets your resiliency requirements by placing the BGP peering session in the DOWN state.

        You can then send traffic to verify that there are no outages

        Access Level: Write

        https://docs.aws.amazon.com/directconnect/latest/APIReference/API_StartBgpFailoverTest.html

        :stability: experimental
        '''
        return typing.cast("Directconnect", jsii.invoke(self, "toStartBgpFailoverTest", []))

    @jsii.member(jsii_name="toStopBgpFailoverTest")
    def to_stop_bgp_failover_test(self) -> "Directconnect":
        '''(experimental) Grants permission to stop the virtual interface failover test.

        Access Level: Write

        https://docs.aws.amazon.com/directconnect/latest/APIReference/API_StopBgpFailoverTest.html

        :stability: experimental
        '''
        return typing.cast("Directconnect", jsii.invoke(self, "toStopBgpFailoverTest", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Directconnect":
        '''(experimental) Grants permission to add the specified tags to the specified AWS Direct Connect resource.

        Each resource can have a maximum of 50 tags

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/directconnect/latest/APIReference/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("Directconnect", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Directconnect":
        '''(experimental) Grants permission to remove one or more tags from the specified AWS Direct Connect resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/directconnect/latest/APIReference/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("Directconnect", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateConnection")
    def to_update_connection(self) -> "Directconnect":
        '''(experimental) Grants permission to update the AWS Direct Connect dedicated connection configuration.

        You can update the following parameters for a connection: The connection name or The connection's MAC Security (MACsec) encryption mode

        Access Level: Write

        https://docs.aws.amazon.com/directconnect/latest/APIReference/API_UpdateConnection.html

        :stability: experimental
        '''
        return typing.cast("Directconnect", jsii.invoke(self, "toUpdateConnection", []))

    @jsii.member(jsii_name="toUpdateDirectConnectGateway")
    def to_update_direct_connect_gateway(self) -> "Directconnect":
        '''(experimental) Grants permission to update the name of a Direct Connect gateway.

        Access Level: Write

        https://docs.aws.amazon.com/directconnect/latest/APIReference/API_UpdateDirectConnectGateway.html

        :stability: experimental
        '''
        return typing.cast("Directconnect", jsii.invoke(self, "toUpdateDirectConnectGateway", []))

    @jsii.member(jsii_name="toUpdateDirectConnectGatewayAssociation")
    def to_update_direct_connect_gateway_association(self) -> "Directconnect":
        '''(experimental) Grants permission to update the specified attributes of the Direct Connect gateway association.

        Access Level: Write

        https://docs.aws.amazon.com/directconnect/latest/APIReference/API_UpdateDirectConnectGatewayAssociation.html

        :stability: experimental
        '''
        return typing.cast("Directconnect", jsii.invoke(self, "toUpdateDirectConnectGatewayAssociation", []))

    @jsii.member(jsii_name="toUpdateLag")
    def to_update_lag(self) -> "Directconnect":
        '''(experimental) Grants permission to update the attributes of the specified link aggregation group (LAG).

        Access Level: Write

        https://docs.aws.amazon.com/directconnect/latest/APIReference/API_UpdateLag.html

        :stability: experimental
        '''
        return typing.cast("Directconnect", jsii.invoke(self, "toUpdateLag", []))

    @jsii.member(jsii_name="toUpdateVirtualInterfaceAttributes")
    def to_update_virtual_interface_attributes(self) -> "Directconnect":
        '''(experimental) Grants permission to update the specified attributes of the specified virtual private interface.

        Access Level: Write

        https://docs.aws.amazon.com/directconnect/latest/APIReference/API_UpdateVirtualInterfaceAttributes.html

        :stability: experimental
        '''
        return typing.cast("Directconnect", jsii.invoke(self, "toUpdateVirtualInterfaceAttributes", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5ad850f7e7536943e77c11b7531b24d3bf4431cae51aa9eaeb851fdd065132f5)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8ecdfd05f8fe2905dd7694290ecb0cbd9acfededcb827273f762f2104460e6cc)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Discovery(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Discovery",
):
    '''(experimental) Statement provider for service `discovery <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsapplicationdiscoveryservice.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `discovery <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsapplicationdiscoveryservice.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="toAssociateConfigurationItemsToApplication")
    def to_associate_configuration_items_to_application(self) -> "Discovery":
        '''(experimental) Grants permission to AssociateConfigurationItemsToApplication API. AssociateConfigurationItemsToApplication associates one or more configuration items with an application.

        Access Level: Write

        https://docs.aws.amazon.com/application-discovery/latest/APIReference/API_AssociateConfigurationItemsToApplication.html

        :stability: experimental
        '''
        return typing.cast("Discovery", jsii.invoke(self, "toAssociateConfigurationItemsToApplication", []))

    @jsii.member(jsii_name="toBatchDeleteImportData")
    def to_batch_delete_import_data(self) -> "Discovery":
        '''(experimental) Grants permission to BatchDeleteImportData API.

        BatchDeleteImportData deletes one or more Migration Hub import tasks, each identified by their import ID. Each import task has a number of records, which can identify servers or applications

        Access Level: Write

        https://docs.aws.amazon.com/application-discovery/latest/APIReference/API_BatchDeleteImportData.html

        :stability: experimental
        '''
        return typing.cast("Discovery", jsii.invoke(self, "toBatchDeleteImportData", []))

    @jsii.member(jsii_name="toCreateApplication")
    def to_create_application(self) -> "Discovery":
        '''(experimental) Grants permission to CreateApplication API. CreateApplication creates an application with the given name and description.

        Access Level: Write

        https://docs.aws.amazon.com/application-discovery/latest/APIReference/API_CreateApplication.html

        :stability: experimental
        '''
        return typing.cast("Discovery", jsii.invoke(self, "toCreateApplication", []))

    @jsii.member(jsii_name="toCreateTags")
    def to_create_tags(self) -> "Discovery":
        '''(experimental) Grants permission to CreateTags API.

        CreateTags creates one or more tags for configuration items. Tags are metadata that help you categorize IT assets. This API accepts a list of multiple configuration items

        Access Level: Tagging

        https://docs.aws.amazon.com/application-discovery/latest/APIReference/API_CreateTags.html

        :stability: experimental
        '''
        return typing.cast("Discovery", jsii.invoke(self, "toCreateTags", []))

    @jsii.member(jsii_name="toDeleteApplications")
    def to_delete_applications(self) -> "Discovery":
        '''(experimental) Grants permission to DeleteApplications API. DeleteApplications deletes a list of applications and their associations with configuration items.

        Access Level: Write

        https://docs.aws.amazon.com/application-discovery/latest/APIReference/API_DeleteApplications.html

        :stability: experimental
        '''
        return typing.cast("Discovery", jsii.invoke(self, "toDeleteApplications", []))

    @jsii.member(jsii_name="toDeleteTags")
    def to_delete_tags(self) -> "Discovery":
        '''(experimental) Grants permission to DeleteTags API.

        DeleteTags deletes the association between configuration items and one or more tags. This API accepts a list of multiple configuration items

        Access Level: Tagging

        https://docs.aws.amazon.com/application-discovery/latest/APIReference/API_DeleteTags.html

        :stability: experimental
        '''
        return typing.cast("Discovery", jsii.invoke(self, "toDeleteTags", []))

    @jsii.member(jsii_name="toDescribeAgents")
    def to_describe_agents(self) -> "Discovery":
        '''(experimental) Grants permission to DescribeAgents API.

        DescribeAgents lists agents or the Connector by ID or lists all agents/Connectors associated with your user account if you did not specify an ID

        Access Level: Read

        https://docs.aws.amazon.com/application-discovery/latest/APIReference/API_DescribeAgents.html

        :stability: experimental
        '''
        return typing.cast("Discovery", jsii.invoke(self, "toDescribeAgents", []))

    @jsii.member(jsii_name="toDescribeConfigurations")
    def to_describe_configurations(self) -> "Discovery":
        '''(experimental) Grants permission to DescribeConfigurations API.

        DescribeConfigurations retrieves attributes for a list of configuration item IDs. All of the supplied IDs must be for the same asset type (server, application, process, or connection). Output fields are specific to the asset type selected. For example, the output for a server configuration item includes a list of attributes about the server, such as host name, operating system, and number of network cards

        Access Level: Read

        https://docs.aws.amazon.com/application-discovery/latest/APIReference/API_DescribeConfigurations.html

        :stability: experimental
        '''
        return typing.cast("Discovery", jsii.invoke(self, "toDescribeConfigurations", []))

    @jsii.member(jsii_name="toDescribeContinuousExports")
    def to_describe_continuous_exports(self) -> "Discovery":
        '''(experimental) Grants permission to DescribeContinuousExports API.

        DescribeContinuousExports lists exports as specified by ID. All continuous exports associated with your user account can be listed if you call DescribeContinuousExports as is without passing any parameters

        Access Level: Read

        https://docs.aws.amazon.com/application-discovery/latest/APIReference/API_DescribeContinuousExports.html

        :stability: experimental
        '''
        return typing.cast("Discovery", jsii.invoke(self, "toDescribeContinuousExports", []))

    @jsii.member(jsii_name="toDescribeExportConfigurations")
    def to_describe_export_configurations(self) -> "Discovery":
        '''(experimental) Grants permission to DescribeExportConfigurations API.

        DescribeExportConfigurations retrieves the status of a given export process. You can retrieve status from a maximum of 100 processes

        Access Level: Read

        https://docs.aws.amazon.com/application-discovery/latest/APIReference/API_DescribeExportConfigurations.html

        :stability: experimental
        '''
        return typing.cast("Discovery", jsii.invoke(self, "toDescribeExportConfigurations", []))

    @jsii.member(jsii_name="toDescribeExportTasks")
    def to_describe_export_tasks(self) -> "Discovery":
        '''(experimental) Grants permission to DescribeExportTasks API.

        DescribeExportTasks retrieve status of one or more export tasks. You can retrieve the status of up to 100 export tasks

        Access Level: Read

        https://docs.aws.amazon.com/application-discovery/latest/APIReference/API_DescribeExportTasks.html

        :stability: experimental
        '''
        return typing.cast("Discovery", jsii.invoke(self, "toDescribeExportTasks", []))

    @jsii.member(jsii_name="toDescribeImportTasks")
    def to_describe_import_tasks(self) -> "Discovery":
        '''(experimental) Grants permission to DescribeImportTasks API.

        DescribeImportTasks returns an array of import tasks for your account, including status information, times, IDs, the Amazon S3 Object URL for the import file, and more

        Access Level: List

        https://docs.aws.amazon.com/application-discovery/latest/APIReference/API_DescribeImportTasks.html

        :stability: experimental
        '''
        return typing.cast("Discovery", jsii.invoke(self, "toDescribeImportTasks", []))

    @jsii.member(jsii_name="toDescribeTags")
    def to_describe_tags(self) -> "Discovery":
        '''(experimental) Grants permission to DescribeTags API.

        DescribeTags retrieves a list of configuration items that are tagged with a specific tag. Or retrieves a list of all tags assigned to a specific configuration item

        Access Level: Read

        https://docs.aws.amazon.com/application-discovery/latest/APIReference/API_DescribeTags.html

        :stability: experimental
        '''
        return typing.cast("Discovery", jsii.invoke(self, "toDescribeTags", []))

    @jsii.member(jsii_name="toDisassociateConfigurationItemsFromApplication")
    def to_disassociate_configuration_items_from_application(self) -> "Discovery":
        '''(experimental) Grants permission to DisassociateConfigurationItemsFromApplication API. DisassociateConfigurationItemsFromApplication disassociates one or more configuration items from an application.

        Access Level: Write

        https://docs.aws.amazon.com/application-discovery/latest/APIReference/API_DisassociateConfigurationItemsFromApplication.html

        :stability: experimental
        '''
        return typing.cast("Discovery", jsii.invoke(self, "toDisassociateConfigurationItemsFromApplication", []))

    @jsii.member(jsii_name="toExportConfigurations")
    def to_export_configurations(self) -> "Discovery":
        '''(experimental) Grants permission to ExportConfigurations API.

        ExportConfigurations exports all discovered configuration data to an Amazon S3 bucket or an application that enables you to view and evaluate the data. Data includes tags and tag associations, processes, connections, servers, and system performance

        Access Level: Write

        https://docs.aws.amazon.com/application-discovery/latest/APIReference/API_ExportConfigurations.html

        :stability: experimental
        '''
        return typing.cast("Discovery", jsii.invoke(self, "toExportConfigurations", []))

    @jsii.member(jsii_name="toGetDiscoverySummary")
    def to_get_discovery_summary(self) -> "Discovery":
        '''(experimental) Grants permission to GetDiscoverySummary API. GetDiscoverySummary retrieves a short summary of discovered assets.

        Access Level: Read

        https://docs.aws.amazon.com/application-discovery/latest/APIReference/API_GetDiscoverySummary.html

        :stability: experimental
        '''
        return typing.cast("Discovery", jsii.invoke(self, "toGetDiscoverySummary", []))

    @jsii.member(jsii_name="toGetNetworkConnectionGraph")
    def to_get_network_connection_graph(self) -> "Discovery":
        '''(experimental) Grants permission to GetNetworkConnectionGraph API.

        GetNetworkConnectionGraph accepts input list of one of - Ip Addresses, server ids or node ids. Returns a list of nodes and edges which help customer visualize network connection graph. This API is used for visualize network graph functionality in MigrationHub console

        Access Level: Read

        https://docs.aws.amazon.com/application-discovery/latest/APIReference/API_GetNetworkConnectionGraph.html

        :stability: experimental
        '''
        return typing.cast("Discovery", jsii.invoke(self, "toGetNetworkConnectionGraph", []))

    @jsii.member(jsii_name="toListConfigurations")
    def to_list_configurations(self) -> "Discovery":
        '''(experimental) Grants permission to ListConfigurations API.

        ListConfigurations retrieves a list of configuration items according to criteria you specify in a filter. The filter criteria identify relationship requirements

        Access Level: List

        https://docs.aws.amazon.com/application-discovery/latest/APIReference/API_ListConfigurations.html

        :stability: experimental
        '''
        return typing.cast("Discovery", jsii.invoke(self, "toListConfigurations", []))

    @jsii.member(jsii_name="toListServerNeighbors")
    def to_list_server_neighbors(self) -> "Discovery":
        '''(experimental) Grants permission to ListServerNeighbors API.

        ListServerNeighbors retrieves a list of servers which are one network hop away from a specified server

        Access Level: List

        https://docs.aws.amazon.com/application-discovery/latest/APIReference/API_ListServerNeighbors.html

        :stability: experimental
        '''
        return typing.cast("Discovery", jsii.invoke(self, "toListServerNeighbors", []))

    @jsii.member(jsii_name="toStartContinuousExport")
    def to_start_continuous_export(self) -> "Discovery":
        '''(experimental) Grants permission to StartContinuousExport API. StartContinuousExport start the continuous flow of agent's discovered data into Amazon Athena.

        Access Level: Write

        Dependent actions:

        - iam:AttachRolePolicy
        - iam:CreatePolicy
        - iam:CreateRole
        - iam:CreateServiceLinkedRole

        https://docs.aws.amazon.com/application-discovery/latest/APIReference/API_StartContinuousExport.html

        :stability: experimental
        '''
        return typing.cast("Discovery", jsii.invoke(self, "toStartContinuousExport", []))

    @jsii.member(jsii_name="toStartDataCollectionByAgentIds")
    def to_start_data_collection_by_agent_ids(self) -> "Discovery":
        '''(experimental) Grants permission to StartDataCollectionByAgentIds API. StartDataCollectionByAgentIds instructs the specified agents or Connectors to start collecting data.

        Access Level: Write

        https://docs.aws.amazon.com/application-discovery/latest/APIReference/API_StartDataCollectionByAgentIds.html

        :stability: experimental
        '''
        return typing.cast("Discovery", jsii.invoke(self, "toStartDataCollectionByAgentIds", []))

    @jsii.member(jsii_name="toStartExportTask")
    def to_start_export_task(self) -> "Discovery":
        '''(experimental) Grants permission to StartExportTask API.

        StartExportTask export the configuration data about discovered configuration items and relationships to an S3 bucket in a specified format

        Access Level: Write

        https://docs.aws.amazon.com/application-discovery/latest/APIReference/API_StartExportTask.html

        :stability: experimental
        '''
        return typing.cast("Discovery", jsii.invoke(self, "toStartExportTask", []))

    @jsii.member(jsii_name="toStartImportTask")
    def to_start_import_task(self) -> "Discovery":
        '''(experimental) Grants permission to StartImportTask API.

        StartImportTask starts an import task. The Migration Hub import feature allows you to import details of your on-premises environment directly into AWS without having to use the Application Discovery Service (ADS) tools such as the Discovery Connector or Discovery Agent. This gives you the option to perform migration assessment and planning directly from your imported data including the ability to group your devices as applications and track their migration status

        Access Level: Write

        Dependent actions:

        - discovery:AssociateConfigurationItemsToApplication
        - discovery:CreateApplication
        - discovery:CreateTags
        - discovery:ListConfigurations

        https://docs.aws.amazon.com/application-discovery/latest/APIReference/API_StartImportTask.html

        :stability: experimental
        '''
        return typing.cast("Discovery", jsii.invoke(self, "toStartImportTask", []))

    @jsii.member(jsii_name="toStopContinuousExport")
    def to_stop_continuous_export(self) -> "Discovery":
        '''(experimental) Grants permission to StopContinuousExport API. StopContinuousExport stops the continuous flow of agent's discovered data into Amazon Athena.

        Access Level: Write

        https://docs.aws.amazon.com/application-discovery/latest/APIReference/API_StopContinuousExport.html

        :stability: experimental
        '''
        return typing.cast("Discovery", jsii.invoke(self, "toStopContinuousExport", []))

    @jsii.member(jsii_name="toStopDataCollectionByAgentIds")
    def to_stop_data_collection_by_agent_ids(self) -> "Discovery":
        '''(experimental) Grants permission to StopDataCollectionByAgentIds API. StopDataCollectionByAgentIds instructs the specified agents or Connectors to stop collecting data.

        Access Level: Write

        https://docs.aws.amazon.com/application-discovery/latest/APIReference/API_StopDataCollectionByAgentIds.html

        :stability: experimental
        '''
        return typing.cast("Discovery", jsii.invoke(self, "toStopDataCollectionByAgentIds", []))

    @jsii.member(jsii_name="toUpdateApplication")
    def to_update_application(self) -> "Discovery":
        '''(experimental) Grants permission to UpdateApplication API. UpdateApplication updates metadata about an application.

        Access Level: Write

        https://docs.aws.amazon.com/application-discovery/latest/APIReference/API_UpdateApplication.html

        :stability: experimental
        '''
        return typing.cast("Discovery", jsii.invoke(self, "toUpdateApplication", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6bcb97e5c2e660d0afba42d436fe26b50ecdba3d9ccb4c066cf2186923dbd2df)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a2813455b818e4671a81f706d794783eef3df74b4d84653ef74cb78a4301ba64)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Dlm(PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Dlm"):
    '''(experimental) Statement provider for service `dlm <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazondatalifecyclemanager.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `dlm <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazondatalifecyclemanager.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onPolicy")
    def on_policy(
        self,
        resource_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Dlm":
        '''(experimental) Adds a resource of type policy to the statement.

        https://docs.aws.amazon.com/dlm/latest/APIReference/API_LifecyclePolicy.html

        :param resource_name: - Identifier for the resourceName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__45e8a99f69386caf2428e2d9b55264dfceac03caca6f8796d51e94498278f53a)
            check_type(argname="argument resource_name", value=resource_name, expected_type=type_hints["resource_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Dlm", jsii.invoke(self, "onPolicy", [resource_name, account, region, partition]))

    @jsii.member(jsii_name="toCreateLifecyclePolicy")
    def to_create_lifecycle_policy(self) -> "Dlm":
        '''(experimental) Grants permission to create a data lifecycle policy to manage the scheduled creation and retention of Amazon EBS snapshots.

        You may have up to 100 policies

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/dlm/latest/APIReference/API_CreateLifecyclePolicy.html

        :stability: experimental
        '''
        return typing.cast("Dlm", jsii.invoke(self, "toCreateLifecyclePolicy", []))

    @jsii.member(jsii_name="toDeleteLifecyclePolicy")
    def to_delete_lifecycle_policy(self) -> "Dlm":
        '''(experimental) Grants permission to delete an existing data lifecycle policy.

        In addition, this action halts the creation and deletion of snapshots that the policy specified. Existing snapshots are not affected

        Access Level: Write

        https://docs.aws.amazon.com/dlm/latest/APIReference/API_DeleteLifecyclePolicy.html

        :stability: experimental
        '''
        return typing.cast("Dlm", jsii.invoke(self, "toDeleteLifecyclePolicy", []))

    @jsii.member(jsii_name="toGetLifecyclePolicies")
    def to_get_lifecycle_policies(self) -> "Dlm":
        '''(experimental) Grants permission to returns a list of summary descriptions of data lifecycle policies.

        Access Level: List

        https://docs.aws.amazon.com/dlm/latest/APIReference/API_GetLifecyclePolicies.html

        :stability: experimental
        '''
        return typing.cast("Dlm", jsii.invoke(self, "toGetLifecyclePolicies", []))

    @jsii.member(jsii_name="toGetLifecyclePolicy")
    def to_get_lifecycle_policy(self) -> "Dlm":
        '''(experimental) Grants permission to return a complete description of a single data lifecycle policy.

        Access Level: Read

        https://docs.aws.amazon.com/dlm/latest/APIReference/API_GetLifecyclePolicy.html

        :stability: experimental
        '''
        return typing.cast("Dlm", jsii.invoke(self, "toGetLifecyclePolicy", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Dlm":
        '''(experimental) Grants permission to list the tags associated with a resource.

        Access Level: Read

        https://docs.aws.amazon.com/dlm/latest/APIReference/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("Dlm", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Dlm":
        '''(experimental) Grants permission to add or update tags of a resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/dlm/latest/APIReference/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("Dlm", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Dlm":
        '''(experimental) Grants permission to remove tags associated with a resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/dlm/latest/APIReference/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("Dlm", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateLifecyclePolicy")
    def to_update_lifecycle_policy(self) -> "Dlm":
        '''(experimental) Grants permission to update an existing data lifecycle policy.

        Access Level: Write

        https://docs.aws.amazon.com/dlm/latest/APIReference/API_UpdateLifecyclePolicy.html

        :stability: experimental
        '''
        return typing.cast("Dlm", jsii.invoke(self, "toUpdateLifecyclePolicy", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ddaed32ea62bb45a533b3f04bcbd2453a8ec8fc4606d38a4d3f9d736d4f8254f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c0618bb1408949107774e175f9baa7936e00d54b58381aa087c9faa9e7159f22)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Dms(PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Dms"):
    '''(experimental) Statement provider for service `dms <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsdatabasemigrationservice.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `dms <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsdatabasemigrationservice.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="ifCertTag")
    def if_cert_tag(
        self,
        tag_key: builtins.str,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Dms":
        '''(experimental) Filters access by the presence of tag key-value pairs in the request for Certificate.

        https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsdatabasemigrationservice.html#awsdatabasemigrationservice--dms_cert-tag___TagKey_

        Applies to resource types:

        - Certificate

        :param tag_key: The tag key to check.
        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a9a8780a8e30792b051dc5fdf8f47fdfb57a39e60e94f386299018b8170a8b12)
            check_type(argname="argument tag_key", value=tag_key, expected_type=type_hints["tag_key"])
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Dms", jsii.invoke(self, "ifCertTag", [tag_key, value, operator]))

    @jsii.member(jsii_name="ifDpTag")
    def if_dp_tag(
        self,
        tag_key: builtins.str,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Dms":
        '''(experimental) Filters access by the presence of tag key-value pairs in the request for DataProvider.

        https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsdatabasemigrationservice.html#awsdatabasemigrationservice--dms_dp-tag___TagKey_

        Applies to resource types:

        - DataProvider

        :param tag_key: The tag key to check.
        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4ac6b829c3aee68304f739100cc0cfb549351810a3105efd28ff9c6c780e6a8c)
            check_type(argname="argument tag_key", value=tag_key, expected_type=type_hints["tag_key"])
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Dms", jsii.invoke(self, "ifDpTag", [tag_key, value, operator]))

    @jsii.member(jsii_name="ifEndpointTag")
    def if_endpoint_tag(
        self,
        tag_key: builtins.str,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Dms":
        '''(experimental) Filters access by the presence of tag key-value pairs in the request for Endpoint.

        https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsdatabasemigrationservice.html#awsdatabasemigrationservice-dms_endpoint-tag___TagKey_

        Applies to resource types:

        - Endpoint

        :param tag_key: The tag key to check.
        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7a8e1ae887bc34dda8334d8dbefe7d752c48bf82e7b8f45fac453fa56a3a75c9)
            check_type(argname="argument tag_key", value=tag_key, expected_type=type_hints["tag_key"])
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Dms", jsii.invoke(self, "ifEndpointTag", [tag_key, value, operator]))

    @jsii.member(jsii_name="ifEsTag")
    def if_es_tag(
        self,
        tag_key: builtins.str,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Dms":
        '''(experimental) Filters access by the presence of tag key-value pairs in the request for EventSubscription.

        https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsdatabasemigrationservice.html#awsdatabasemigrationservice-dms_es-tag___TagKey_

        Applies to resource types:

        - EventSubscription

        :param tag_key: The tag key to check.
        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6cd49adc880f8890dfae3bf3b9b6944b93bbc5f8feafc76332660d257acc76ec)
            check_type(argname="argument tag_key", value=tag_key, expected_type=type_hints["tag_key"])
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Dms", jsii.invoke(self, "ifEsTag", [tag_key, value, operator]))

    @jsii.member(jsii_name="ifIpTag")
    def if_ip_tag(
        self,
        tag_key: builtins.str,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Dms":
        '''(experimental) Filters access by the presence of tag key-value pairs in the request for InstanceProfile.

        https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsdatabasemigrationservice.html#awsdatabasemigrationservice--dms_ip-tag___TagKey_

        Applies to resource types:

        - InstanceProfile

        :param tag_key: The tag key to check.
        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7944fc39494e530da1e43047ead2c7e7d3d84b7f0d4a2d51b3a31ba1feba95c0)
            check_type(argname="argument tag_key", value=tag_key, expected_type=type_hints["tag_key"])
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Dms", jsii.invoke(self, "ifIpTag", [tag_key, value, operator]))

    @jsii.member(jsii_name="ifMpTag")
    def if_mp_tag(
        self,
        tag_key: builtins.str,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Dms":
        '''(experimental) Filters access by the presence of tag key-value pairs in the request for MigrationProject.

        https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsdatabasemigrationservice.html#awsdatabasemigrationservice--dms_mp-tag___TagKey_

        Applies to resource types:

        - MigrationProject

        :param tag_key: The tag key to check.
        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6cf3cf89cea6127f3e49153723dc418788aeb5ddc1c6a1845cf3ebcf31712ee3)
            check_type(argname="argument tag_key", value=tag_key, expected_type=type_hints["tag_key"])
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Dms", jsii.invoke(self, "ifMpTag", [tag_key, value, operator]))

    @jsii.member(jsii_name="ifRepTag")
    def if_rep_tag(
        self,
        tag_key: builtins.str,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Dms":
        '''(experimental) Filters access by the presence of tag key-value pairs in the request for ReplicationInstance.

        https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsdatabasemigrationservice.html#awsdatabasemigrationservice-dms_rep-tag___TagKey_

        Applies to resource types:

        - ReplicationInstance

        :param tag_key: The tag key to check.
        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__838cd38b53af026722fa9f69856b62f690a076c525706eec337007ef4c7361a9)
            check_type(argname="argument tag_key", value=tag_key, expected_type=type_hints["tag_key"])
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Dms", jsii.invoke(self, "ifRepTag", [tag_key, value, operator]))

    @jsii.member(jsii_name="ifReqTag")
    def if_req_tag(
        self,
        tag_key: builtins.str,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Dms":
        '''(experimental) Filters access by the presence of tag key-value pairs in the given request.

        https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsdatabasemigrationservice.html#awsdatabasemigrationservice-dms_req-tag___TagKey_

        Applies to actions:

        - .toAddTagsToResource()
        - .toCreateDataProvider()
        - .toCreateEndpoint()
        - .toCreateEventSubscription()
        - .toCreateInstanceProfile()
        - .toCreateMigrationProject()
        - .toCreateReplicationInstance()
        - .toCreateReplicationSubnetGroup()
        - .toCreateReplicationTask()

        :param tag_key: The tag key to check.
        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c9edba34ace67d9bf0663cff9073ec40b01fae4d4114cce3fd556e0f8682decd)
            check_type(argname="argument tag_key", value=tag_key, expected_type=type_hints["tag_key"])
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Dms", jsii.invoke(self, "ifReqTag", [tag_key, value, operator]))

    @jsii.member(jsii_name="ifSubgrpTag")
    def if_subgrp_tag(
        self,
        tag_key: builtins.str,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Dms":
        '''(experimental) Filters access by the presence of tag key-value pairs in the request for ReplicationSubnetGroup.

        https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsdatabasemigrationservice.html#awsdatabasemigrationservice-dms_subgrp-tag___TagKey_

        Applies to resource types:

        - ReplicationSubnetGroup

        :param tag_key: The tag key to check.
        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7375f805dde60a281f10296cb33a2e9b69b524eed1eccd73f29c8dbc39fe5012)
            check_type(argname="argument tag_key", value=tag_key, expected_type=type_hints["tag_key"])
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Dms", jsii.invoke(self, "ifSubgrpTag", [tag_key, value, operator]))

    @jsii.member(jsii_name="ifTaskTag")
    def if_task_tag(
        self,
        tag_key: builtins.str,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Dms":
        '''(experimental) Filters access by the presence of tag key-value pairs in the request for ReplicationTask.

        https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsdatabasemigrationservice.html#awsdatabasemigrationservice-dms_task-tag___TagKey_

        Applies to resource types:

        - ReplicationTask

        :param tag_key: The tag key to check.
        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4242060899c566cfa4c2605c5c8a8b3e257cdec2c1afbf24dc9bf3a308b98254)
            check_type(argname="argument tag_key", value=tag_key, expected_type=type_hints["tag_key"])
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Dms", jsii.invoke(self, "ifTaskTag", [tag_key, value, operator]))

    @jsii.member(jsii_name="onCertificate")
    def on_certificate(
        self,
        resource_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Dms":
        '''(experimental) Adds a resource of type Certificate to the statement.

        https://docs.aws.amazon.com/dms/latest/APIReference/API_Certificate.html

        :param resource_name: - Identifier for the resourceName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag() - .ifCertTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__979a46e4b9acc7d816ac69cf6ef6c2caa122afae41f7f021018923f9a7368dd8)
            check_type(argname="argument resource_name", value=resource_name, expected_type=type_hints["resource_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Dms", jsii.invoke(self, "onCertificate", [resource_name, account, region, partition]))

    @jsii.member(jsii_name="onDataProvider")
    def on_data_provider(
        self,
        resource_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Dms":
        '''(experimental) Adds a resource of type DataProvider to the statement.

        https://docs.aws.amazon.com/dms/latest/APIReference/Welcome.html

        :param resource_name: - Identifier for the resourceName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag() - .ifDpTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__178929aae43b25e1238bae50bfa3cbdc44d1242f1d311642c979bce67c1acddb)
            check_type(argname="argument resource_name", value=resource_name, expected_type=type_hints["resource_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Dms", jsii.invoke(self, "onDataProvider", [resource_name, account, region, partition]))

    @jsii.member(jsii_name="onEndpoint")
    def on_endpoint(
        self,
        resource_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Dms":
        '''(experimental) Adds a resource of type Endpoint to the statement.

        https://docs.aws.amazon.com/dms/latest/APIReference/API_Endpoint.html

        :param resource_name: - Identifier for the resourceName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag() - .ifEndpointTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f0d15376802169154d1838f0c70411babbc3c8bc2ed4ee7b2bbcae952e8c6b80)
            check_type(argname="argument resource_name", value=resource_name, expected_type=type_hints["resource_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Dms", jsii.invoke(self, "onEndpoint", [resource_name, account, region, partition]))

    @jsii.member(jsii_name="onEventSubscription")
    def on_event_subscription(
        self,
        resource_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Dms":
        '''(experimental) Adds a resource of type EventSubscription to the statement.

        https://docs.aws.amazon.com/dms/latest/APIReference/API_EventSubscription.html

        :param resource_name: - Identifier for the resourceName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag() - .ifEsTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a8da5ff7ecad7bbcd8bb112bcc1e9c61d35d7f82803d01115ca6d7a550c24840)
            check_type(argname="argument resource_name", value=resource_name, expected_type=type_hints["resource_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Dms", jsii.invoke(self, "onEventSubscription", [resource_name, account, region, partition]))

    @jsii.member(jsii_name="onInstanceProfile")
    def on_instance_profile(
        self,
        resource_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Dms":
        '''(experimental) Adds a resource of type InstanceProfile to the statement.

        https://docs.aws.amazon.com/dms/latest/APIReference/Welcome.html

        :param resource_name: - Identifier for the resourceName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag() - .ifIpTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__617d71d8079d120da3cc7f5863cfa5df244bf685895bdd3a58533d1233146b72)
            check_type(argname="argument resource_name", value=resource_name, expected_type=type_hints["resource_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Dms", jsii.invoke(self, "onInstanceProfile", [resource_name, account, region, partition]))

    @jsii.member(jsii_name="onMigrationProject")
    def on_migration_project(
        self,
        resource_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Dms":
        '''(experimental) Adds a resource of type MigrationProject to the statement.

        https://docs.aws.amazon.com/dms/latest/APIReference/Welcome.html

        :param resource_name: - Identifier for the resourceName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag() - .ifMpTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6509d5078b12a4321db779ae2331df5a7fb085399f9ef3abe05e68328c08e238)
            check_type(argname="argument resource_name", value=resource_name, expected_type=type_hints["resource_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Dms", jsii.invoke(self, "onMigrationProject", [resource_name, account, region, partition]))

    @jsii.member(jsii_name="onReplicationInstance")
    def on_replication_instance(
        self,
        resource_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Dms":
        '''(experimental) Adds a resource of type ReplicationInstance to the statement.

        https://docs.aws.amazon.com/dms/latest/APIReference/API_ReplicationInstance.html

        :param resource_name: - Identifier for the resourceName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag() - .ifRepTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6583e2dba19e940ebb679e7da5a0cc53687bab80739b5f2bade05120944ece25)
            check_type(argname="argument resource_name", value=resource_name, expected_type=type_hints["resource_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Dms", jsii.invoke(self, "onReplicationInstance", [resource_name, account, region, partition]))

    @jsii.member(jsii_name="onReplicationSubnetGroup")
    def on_replication_subnet_group(
        self,
        resource_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Dms":
        '''(experimental) Adds a resource of type ReplicationSubnetGroup to the statement.

        https://docs.aws.amazon.com/dms/latest/APIReference/API_ReplicationSubnetGroup.html

        :param resource_name: - Identifier for the resourceName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag() - .ifSubgrpTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__73e7c3328c2db643648ee78e38a2929be4750219c79fb574452d11b8e9d830e8)
            check_type(argname="argument resource_name", value=resource_name, expected_type=type_hints["resource_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Dms", jsii.invoke(self, "onReplicationSubnetGroup", [resource_name, account, region, partition]))

    @jsii.member(jsii_name="onReplicationTask")
    def on_replication_task(
        self,
        resource_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Dms":
        '''(experimental) Adds a resource of type ReplicationTask to the statement.

        https://docs.aws.amazon.com/dms/latest/APIReference/API_ReplicationTask.html

        :param resource_name: - Identifier for the resourceName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag() - .ifTaskTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d628658cdf3264e135e8a6ae0ec9039de3e9cd740d8d0fba8a7093bac6eb263d)
            check_type(argname="argument resource_name", value=resource_name, expected_type=type_hints["resource_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Dms", jsii.invoke(self, "onReplicationTask", [resource_name, account, region, partition]))

    @jsii.member(jsii_name="onReplicationTaskAssessmentRun")
    def on_replication_task_assessment_run(
        self,
        resource_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Dms":
        '''(experimental) Adds a resource of type ReplicationTaskAssessmentRun to the statement.

        https://docs.aws.amazon.com/dms/latest/APIReference/API_ReplicationTaskAssessmentRun.html

        :param resource_name: - Identifier for the resourceName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0349cdf999d27c4a48d6ed9ed769b534bb6312126821f0f99b3484929f667612)
            check_type(argname="argument resource_name", value=resource_name, expected_type=type_hints["resource_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Dms", jsii.invoke(self, "onReplicationTaskAssessmentRun", [resource_name, account, region, partition]))

    @jsii.member(jsii_name="onReplicationTaskIndividualAssessment")
    def on_replication_task_individual_assessment(
        self,
        resource_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Dms":
        '''(experimental) Adds a resource of type ReplicationTaskIndividualAssessment to the statement.

        https://docs.aws.amazon.com/dms/latest/APIReference/API_ReplicationTaskIndividualAssessment.html

        :param resource_name: - Identifier for the resourceName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8968b30f24e960badedbd07279d380aaeaf0dc48911f9c1d0947efde83d57561)
            check_type(argname="argument resource_name", value=resource_name, expected_type=type_hints["resource_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Dms", jsii.invoke(self, "onReplicationTaskIndividualAssessment", [resource_name, account, region, partition]))

    @jsii.member(jsii_name="toAddTagsToResource")
    def to_add_tags_to_resource(self) -> "Dms":
        '''(experimental) Grants permission to add metadata tags to DMS resources, including replication instances, endpoints, security groups, and migration tasks.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifReqTag()

        https://docs.aws.amazon.com/dms/latest/APIReference/API_AddTagsToResource.html

        :stability: experimental
        '''
        return typing.cast("Dms", jsii.invoke(self, "toAddTagsToResource", []))

    @jsii.member(jsii_name="toApplyPendingMaintenanceAction")
    def to_apply_pending_maintenance_action(self) -> "Dms":
        '''(experimental) Grants permission to apply a pending maintenance action to a resource (for example, to a replication instance).

        Access Level: Write

        https://docs.aws.amazon.com/dms/latest/APIReference/API_ApplyPendingMaintenanceAction.html

        :stability: experimental
        '''
        return typing.cast("Dms", jsii.invoke(self, "toApplyPendingMaintenanceAction", []))

    @jsii.member(jsii_name="toAssociateExtensionPack")
    def to_associate_extension_pack(self) -> "Dms":
        '''(experimental) Grants permission to associate a extension pack.

        Access Level: Write

        https://docs.aws.amazon.com/dms/latest/APIReference/Welcome.html

        :stability: experimental
        '''
        return typing.cast("Dms", jsii.invoke(self, "toAssociateExtensionPack", []))

    @jsii.member(jsii_name="toCancelMetadataModelAssessment")
    def to_cancel_metadata_model_assessment(self) -> "Dms":
        '''(experimental) Grants permission to cancel a single metadata model assessment run.

        Access Level: Write

        https://docs.aws.amazon.com/dms/latest/APIReference/Welcome.html

        :stability: experimental
        '''
        return typing.cast("Dms", jsii.invoke(self, "toCancelMetadataModelAssessment", []))

    @jsii.member(jsii_name="toCancelMetadataModelConversion")
    def to_cancel_metadata_model_conversion(self) -> "Dms":
        '''(experimental) Grants permission to cancel a single metadata model conversion run.

        Access Level: Write

        https://docs.aws.amazon.com/dms/latest/APIReference/Welcome.html

        :stability: experimental
        '''
        return typing.cast("Dms", jsii.invoke(self, "toCancelMetadataModelConversion", []))

    @jsii.member(jsii_name="toCancelMetadataModelExport")
    def to_cancel_metadata_model_export(self) -> "Dms":
        '''(experimental) Grants permission to cancel a single metadata model export run.

        Access Level: Write

        https://docs.aws.amazon.com/dms/latest/APIReference/Welcome.html

        :stability: experimental
        '''
        return typing.cast("Dms", jsii.invoke(self, "toCancelMetadataModelExport", []))

    @jsii.member(jsii_name="toCancelReplicationTaskAssessmentRun")
    def to_cancel_replication_task_assessment_run(self) -> "Dms":
        '''(experimental) Grants permission to cancel a single premigration assessment run.

        Access Level: Write

        https://docs.aws.amazon.com/dms/latest/APIReference/API_CancelReplicationTaskAssessmentRun.html

        :stability: experimental
        '''
        return typing.cast("Dms", jsii.invoke(self, "toCancelReplicationTaskAssessmentRun", []))

    @jsii.member(jsii_name="toCreateDataProvider")
    def to_create_data_provider(self) -> "Dms":
        '''(experimental) Grants permission to create an data provider using the provided settings.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifReqTag()

        https://docs.aws.amazon.com/dms/latest/APIReference/Welcome.html

        :stability: experimental
        '''
        return typing.cast("Dms", jsii.invoke(self, "toCreateDataProvider", []))

    @jsii.member(jsii_name="toCreateEndpoint")
    def to_create_endpoint(self) -> "Dms":
        '''(experimental) Grants permission to create an endpoint using the provided settings.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifReqTag()

        https://docs.aws.amazon.com/dms/latest/APIReference/API_CreateEndpoint.html

        :stability: experimental
        '''
        return typing.cast("Dms", jsii.invoke(self, "toCreateEndpoint", []))

    @jsii.member(jsii_name="toCreateEventSubscription")
    def to_create_event_subscription(self) -> "Dms":
        '''(experimental) Grants permission to create an AWS DMS event notification subscription.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifReqTag()

        https://docs.aws.amazon.com/dms/latest/APIReference/API_CreateEventSubscription.html

        :stability: experimental
        '''
        return typing.cast("Dms", jsii.invoke(self, "toCreateEventSubscription", []))

    @jsii.member(jsii_name="toCreateInstanceProfile")
    def to_create_instance_profile(self) -> "Dms":
        '''(experimental) Grants permission to create an instance profile using the provided settings.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifReqTag()

        https://docs.aws.amazon.com/dms/latest/APIReference/Welcome.html

        :stability: experimental
        '''
        return typing.cast("Dms", jsii.invoke(self, "toCreateInstanceProfile", []))

    @jsii.member(jsii_name="toCreateMigrationProject")
    def to_create_migration_project(self) -> "Dms":
        '''(experimental) Grants permission to create an migration project using the provided settings.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifReqTag()

        https://docs.aws.amazon.com/dms/latest/APIReference/Welcome.html

        :stability: experimental
        '''
        return typing.cast("Dms", jsii.invoke(self, "toCreateMigrationProject", []))

    @jsii.member(jsii_name="toCreateReplicationInstance")
    def to_create_replication_instance(self) -> "Dms":
        '''(experimental) Grants permission to create a replication instance using the specified parameters.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifReqTag()

        https://docs.aws.amazon.com/dms/latest/APIReference/API_CreateReplicationInstance.html

        :stability: experimental
        '''
        return typing.cast("Dms", jsii.invoke(self, "toCreateReplicationInstance", []))

    @jsii.member(jsii_name="toCreateReplicationSubnetGroup")
    def to_create_replication_subnet_group(self) -> "Dms":
        '''(experimental) Grants permission to create a replication subnet group given a list of the subnet IDs in a VPC.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifReqTag()

        https://docs.aws.amazon.com/dms/latest/APIReference/API_CreateReplicationSubnetGroup.html

        :stability: experimental
        '''
        return typing.cast("Dms", jsii.invoke(self, "toCreateReplicationSubnetGroup", []))

    @jsii.member(jsii_name="toCreateReplicationTask")
    def to_create_replication_task(self) -> "Dms":
        '''(experimental) Grants permission to create a replication task using the specified parameters.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifReqTag()

        https://docs.aws.amazon.com/dms/latest/APIReference/API_CreateReplicationTask.html

        :stability: experimental
        '''
        return typing.cast("Dms", jsii.invoke(self, "toCreateReplicationTask", []))

    @jsii.member(jsii_name="toDeleteCertificate")
    def to_delete_certificate(self) -> "Dms":
        '''(experimental) Grants permission to delete the specified certificate.

        Access Level: Write

        https://docs.aws.amazon.com/dms/latest/APIReference/API_DeleteCertificate.html

        :stability: experimental
        '''
        return typing.cast("Dms", jsii.invoke(self, "toDeleteCertificate", []))

    @jsii.member(jsii_name="toDeleteConnection")
    def to_delete_connection(self) -> "Dms":
        '''(experimental) Grants permission to delete the specified connection between a replication instance and an endpoint.

        Access Level: Write

        https://docs.aws.amazon.com/dms/latest/APIReference/API_DeleteConnection.html

        :stability: experimental
        '''
        return typing.cast("Dms", jsii.invoke(self, "toDeleteConnection", []))

    @jsii.member(jsii_name="toDeleteDataProvider")
    def to_delete_data_provider(self) -> "Dms":
        '''(experimental) Grants permission to delete the specified data provider.

        Access Level: Write

        https://docs.aws.amazon.com/dms/latest/APIReference/Welcome.html

        :stability: experimental
        '''
        return typing.cast("Dms", jsii.invoke(self, "toDeleteDataProvider", []))

    @jsii.member(jsii_name="toDeleteEndpoint")
    def to_delete_endpoint(self) -> "Dms":
        '''(experimental) Grants permission to delete the specified endpoint.

        Access Level: Write

        https://docs.aws.amazon.com/dms/latest/APIReference/API_DeleteEndpoint.html

        :stability: experimental
        '''
        return typing.cast("Dms", jsii.invoke(self, "toDeleteEndpoint", []))

    @jsii.member(jsii_name="toDeleteEventSubscription")
    def to_delete_event_subscription(self) -> "Dms":
        '''(experimental) Grants permission to delete an AWS DMS event subscription.

        Access Level: Write

        https://docs.aws.amazon.com/dms/latest/APIReference/API_DeleteEventSubscription.html

        :stability: experimental
        '''
        return typing.cast("Dms", jsii.invoke(self, "toDeleteEventSubscription", []))

    @jsii.member(jsii_name="toDeleteInstanceProfile")
    def to_delete_instance_profile(self) -> "Dms":
        '''(experimental) Grants permission to delete the specified instance profile.

        Access Level: Write

        https://docs.aws.amazon.com/dms/latest/APIReference/Welcome.html

        :stability: experimental
        '''
        return typing.cast("Dms", jsii.invoke(self, "toDeleteInstanceProfile", []))

    @jsii.member(jsii_name="toDeleteMigrationProject")
    def to_delete_migration_project(self) -> "Dms":
        '''(experimental) Grants permission to delete the specified migration project.

        Access Level: Write

        https://docs.aws.amazon.com/dms/latest/APIReference/Welcome.html

        :stability: experimental
        '''
        return typing.cast("Dms", jsii.invoke(self, "toDeleteMigrationProject", []))

    @jsii.member(jsii_name="toDeleteReplicationInstance")
    def to_delete_replication_instance(self) -> "Dms":
        '''(experimental) Grants permission to delete the specified replication instance.

        Access Level: Write

        https://docs.aws.amazon.com/dms/latest/APIReference/API_DeleteReplicationInstance.html

        :stability: experimental
        '''
        return typing.cast("Dms", jsii.invoke(self, "toDeleteReplicationInstance", []))

    @jsii.member(jsii_name="toDeleteReplicationSubnetGroup")
    def to_delete_replication_subnet_group(self) -> "Dms":
        '''(experimental) Grants permission to deletes a subnet group.

        Access Level: Write

        https://docs.aws.amazon.com/dms/latest/APIReference/API_DeleteReplicationSubnetGroup.html

        :stability: experimental
        '''
        return typing.cast("Dms", jsii.invoke(self, "toDeleteReplicationSubnetGroup", []))

    @jsii.member(jsii_name="toDeleteReplicationTask")
    def to_delete_replication_task(self) -> "Dms":
        '''(experimental) Grants permission to delete the specified replication task.

        Access Level: Write

        https://docs.aws.amazon.com/dms/latest/APIReference/API_DeleteReplicationTask.html

        :stability: experimental
        '''
        return typing.cast("Dms", jsii.invoke(self, "toDeleteReplicationTask", []))

    @jsii.member(jsii_name="toDeleteReplicationTaskAssessmentRun")
    def to_delete_replication_task_assessment_run(self) -> "Dms":
        '''(experimental) Grants permission to delete the record of a single premigration assessment run.

        Access Level: Write

        https://docs.aws.amazon.com/dms/latest/APIReference/API_DeleteReplicationTaskAssessmentRun.html

        :stability: experimental
        '''
        return typing.cast("Dms", jsii.invoke(self, "toDeleteReplicationTaskAssessmentRun", []))

    @jsii.member(jsii_name="toDescribeAccountAttributes")
    def to_describe_account_attributes(self) -> "Dms":
        '''(experimental) Grants permission to list all of the AWS DMS attributes for a customer account.

        Access Level: Read

        https://docs.aws.amazon.com/dms/latest/APIReference/API_DescribeAccountAttributes.html

        :stability: experimental
        '''
        return typing.cast("Dms", jsii.invoke(self, "toDescribeAccountAttributes", []))

    @jsii.member(jsii_name="toDescribeApplicableIndividualAssessments")
    def to_describe_applicable_individual_assessments(self) -> "Dms":
        '''(experimental) Grants permission to list individual assessments that you can specify for a new premigration assessment run.

        Access Level: Read

        https://docs.aws.amazon.com/dms/latest/APIReference/API_DescribeApplicableIndividualAssessments.html

        :stability: experimental
        '''
        return typing.cast("Dms", jsii.invoke(self, "toDescribeApplicableIndividualAssessments", []))

    @jsii.member(jsii_name="toDescribeCertificates")
    def to_describe_certificates(self) -> "Dms":
        '''(experimental) Grants permission to provide a description of the certificate.

        Access Level: Read

        https://docs.aws.amazon.com/dms/latest/APIReference/API_DescribeCertificates.html

        :stability: experimental
        '''
        return typing.cast("Dms", jsii.invoke(self, "toDescribeCertificates", []))

    @jsii.member(jsii_name="toDescribeConnections")
    def to_describe_connections(self) -> "Dms":
        '''(experimental) Grants permission to describe the status of the connections that have been made between the replication instance and an endpoint.

        Access Level: Read

        https://docs.aws.amazon.com/dms/latest/APIReference/API_DescribeConnections.html

        :stability: experimental
        '''
        return typing.cast("Dms", jsii.invoke(self, "toDescribeConnections", []))

    @jsii.member(jsii_name="toDescribeEndpoints")
    def to_describe_endpoints(self) -> "Dms":
        '''(experimental) Grants permission to return information about the endpoints for your account in the current region.

        Access Level: Read

        https://docs.aws.amazon.com/dms/latest/APIReference/API_DescribeEndpoints.html

        :stability: experimental
        '''
        return typing.cast("Dms", jsii.invoke(self, "toDescribeEndpoints", []))

    @jsii.member(jsii_name="toDescribeEndpointSettings")
    def to_describe_endpoint_settings(self) -> "Dms":
        '''(experimental) Grants permission to return the possible endpoint settings available when you create an endpoint for a specific database engine.

        Access Level: Read

        https://docs.aws.amazon.com/dms/latest/APIReference/API_DescribeEndpointSettings.html

        :stability: experimental
        '''
        return typing.cast("Dms", jsii.invoke(self, "toDescribeEndpointSettings", []))

    @jsii.member(jsii_name="toDescribeEndpointTypes")
    def to_describe_endpoint_types(self) -> "Dms":
        '''(experimental) Grants permission to return information about the type of endpoints available.

        Access Level: Read

        https://docs.aws.amazon.com/dms/latest/APIReference/API_DescribeEndpointTypes.html

        :stability: experimental
        '''
        return typing.cast("Dms", jsii.invoke(self, "toDescribeEndpointTypes", []))

    @jsii.member(jsii_name="toDescribeEventCategories")
    def to_describe_event_categories(self) -> "Dms":
        '''(experimental) Grants permission to list categories for all event source types, or, if specified, for a specified source type.

        Access Level: Read

        https://docs.aws.amazon.com/dms/latest/APIReference/API_DescribeEventCategories.html

        :stability: experimental
        '''
        return typing.cast("Dms", jsii.invoke(self, "toDescribeEventCategories", []))

    @jsii.member(jsii_name="toDescribeEvents")
    def to_describe_events(self) -> "Dms":
        '''(experimental) Grants permission to list events for a given source identifier and source type.

        Access Level: Read

        https://docs.aws.amazon.com/dms/latest/APIReference/API_DescribeEvents.html

        :stability: experimental
        '''
        return typing.cast("Dms", jsii.invoke(self, "toDescribeEvents", []))

    @jsii.member(jsii_name="toDescribeEventSubscriptions")
    def to_describe_event_subscriptions(self) -> "Dms":
        '''(experimental) Grants permission to list all the event subscriptions for a customer account.

        Access Level: Read

        https://docs.aws.amazon.com/dms/latest/APIReference/API_DescribeEventSubscriptions.html

        :stability: experimental
        '''
        return typing.cast("Dms", jsii.invoke(self, "toDescribeEventSubscriptions", []))

    @jsii.member(jsii_name="toDescribeOrderableReplicationInstances")
    def to_describe_orderable_replication_instances(self) -> "Dms":
        '''(experimental) Grants permission to return information about the replication instance types that can be created in the specified region.

        Access Level: Read

        https://docs.aws.amazon.com/dms/latest/APIReference/API_DescribeOrderableReplicationInstances.html

        :stability: experimental
        '''
        return typing.cast("Dms", jsii.invoke(self, "toDescribeOrderableReplicationInstances", []))

    @jsii.member(jsii_name="toDescribePendingMaintenanceActions")
    def to_describe_pending_maintenance_actions(self) -> "Dms":
        '''(experimental) Grants permission to return information about pending maintenance actions.

        Access Level: Read

        https://docs.aws.amazon.com/dms/latest/APIReference/API_DescribePendingMaintenanceActions.html

        :stability: experimental
        '''
        return typing.cast("Dms", jsii.invoke(self, "toDescribePendingMaintenanceActions", []))

    @jsii.member(jsii_name="toDescribeRefreshSchemasStatus")
    def to_describe_refresh_schemas_status(self) -> "Dms":
        '''(experimental) Grants permission to returns the status of the RefreshSchemas operation.

        Access Level: Read

        https://docs.aws.amazon.com/dms/latest/APIReference/API_DescribeRefreshSchemasStatus.html

        :stability: experimental
        '''
        return typing.cast("Dms", jsii.invoke(self, "toDescribeRefreshSchemasStatus", []))

    @jsii.member(jsii_name="toDescribeReplicationInstances")
    def to_describe_replication_instances(self) -> "Dms":
        '''(experimental) Grants permission to return information about replication instances for your account in the current region.

        Access Level: Read

        https://docs.aws.amazon.com/dms/latest/APIReference/API_DescribeReplicationInstances.html

        :stability: experimental
        '''
        return typing.cast("Dms", jsii.invoke(self, "toDescribeReplicationInstances", []))

    @jsii.member(jsii_name="toDescribeReplicationInstanceTaskLogs")
    def to_describe_replication_instance_task_logs(self) -> "Dms":
        '''(experimental) Grants permission to return information about the task logs for the specified task.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/dms/latest/APIReference/API_DescribeReplicationInstanceTaskLogs.html

        :stability: experimental
        '''
        return typing.cast("Dms", jsii.invoke(self, "toDescribeReplicationInstanceTaskLogs", []))

    @jsii.member(jsii_name="toDescribeReplicationSubnetGroups")
    def to_describe_replication_subnet_groups(self) -> "Dms":
        '''(experimental) Grants permission to return information about the replication subnet groups.

        Access Level: Read

        https://docs.aws.amazon.com/dms/latest/APIReference/API_DescribeReplicationSubnetGroups.html

        :stability: experimental
        '''
        return typing.cast("Dms", jsii.invoke(self, "toDescribeReplicationSubnetGroups", []))

    @jsii.member(jsii_name="toDescribeReplicationTaskAssessmentResults")
    def to_describe_replication_task_assessment_results(self) -> "Dms":
        '''(experimental) Grants permission to return the latest task assessment results from Amazon S3.

        Access Level: Read

        https://docs.aws.amazon.com/dms/latest/APIReference/API_DescribeReplicationTaskAssessmentResults.html

        :stability: experimental
        '''
        return typing.cast("Dms", jsii.invoke(self, "toDescribeReplicationTaskAssessmentResults", []))

    @jsii.member(jsii_name="toDescribeReplicationTaskAssessmentRuns")
    def to_describe_replication_task_assessment_runs(self) -> "Dms":
        '''(experimental) Grants permission to return a paginated list of premigration assessment runs based on filter settings.

        Access Level: Read

        https://docs.aws.amazon.com/dms/latest/APIReference/API_DescribeReplicationTaskAssessmentRuns.html

        :stability: experimental
        '''
        return typing.cast("Dms", jsii.invoke(self, "toDescribeReplicationTaskAssessmentRuns", []))

    @jsii.member(jsii_name="toDescribeReplicationTaskIndividualAssessments")
    def to_describe_replication_task_individual_assessments(self) -> "Dms":
        '''(experimental) Grants permission to return a paginated list of individual assessments based on filter settings.

        Access Level: Read

        https://docs.aws.amazon.com/dms/latest/APIReference/API_DescribeReplicationTaskIndividualAssessments.html

        :stability: experimental
        '''
        return typing.cast("Dms", jsii.invoke(self, "toDescribeReplicationTaskIndividualAssessments", []))

    @jsii.member(jsii_name="toDescribeReplicationTasks")
    def to_describe_replication_tasks(self) -> "Dms":
        '''(experimental) Grants permission to return information about replication tasks for your account in the current region.

        Access Level: Read

        https://docs.aws.amazon.com/dms/latest/APIReference/API_DescribeReplicationTasks.html

        :stability: experimental
        '''
        return typing.cast("Dms", jsii.invoke(self, "toDescribeReplicationTasks", []))

    @jsii.member(jsii_name="toDescribeSchemas")
    def to_describe_schemas(self) -> "Dms":
        '''(experimental) Grants permission to return information about the schema for the specified endpoint.

        Access Level: Read

        https://docs.aws.amazon.com/dms/latest/APIReference/API_DescribeSchemas.html

        :stability: experimental
        '''
        return typing.cast("Dms", jsii.invoke(self, "toDescribeSchemas", []))

    @jsii.member(jsii_name="toDescribeTableStatistics")
    def to_describe_table_statistics(self) -> "Dms":
        '''(experimental) Grants permission to return table statistics on the database migration task, including table name, rows inserted, rows updated, and rows deleted.

        Access Level: Read

        https://docs.aws.amazon.com/dms/latest/APIReference/API_DescribeTableStatistics.html

        :stability: experimental
        '''
        return typing.cast("Dms", jsii.invoke(self, "toDescribeTableStatistics", []))

    @jsii.member(jsii_name="toDisassociateExtensionPack")
    def to_disassociate_extension_pack(self) -> "Dms":
        '''(experimental) Grants permission to disassociate a extension pack.

        Access Level: Write

        https://docs.aws.amazon.com/dms/latest/APIReference/Welcome.html

        :stability: experimental
        '''
        return typing.cast("Dms", jsii.invoke(self, "toDisassociateExtensionPack", []))

    @jsii.member(jsii_name="toExportMetadataModelAssessment")
    def to_export_metadata_model_assessment(self) -> "Dms":
        '''(experimental) Grants permission to export the specified metadata model assessment.

        Access Level: Write

        https://docs.aws.amazon.com/dms/latest/APIReference/Welcome.html

        :stability: experimental
        '''
        return typing.cast("Dms", jsii.invoke(self, "toExportMetadataModelAssessment", []))

    @jsii.member(jsii_name="toGetMetadataModel")
    def to_get_metadata_model(self) -> "Dms":
        '''(experimental) Grants permission to list all of the AWS DMS attributes for a metadata model.

        Access Level: Read

        https://docs.aws.amazon.com/dms/latest/APIReference/Welcome.html

        :stability: experimental
        '''
        return typing.cast("Dms", jsii.invoke(self, "toGetMetadataModel", []))

    @jsii.member(jsii_name="toImportCertificate")
    def to_import_certificate(self) -> "Dms":
        '''(experimental) Grants permission to upload the specified certificate.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/dms/latest/APIReference/API_ImportCertificate.html

        :stability: experimental
        '''
        return typing.cast("Dms", jsii.invoke(self, "toImportCertificate", []))

    @jsii.member(jsii_name="toListDataProviders")
    def to_list_data_providers(self) -> "Dms":
        '''(experimental) Grants permission to list the AWS DMS attributes for a data providers.

        Access Level: Read

        https://docs.aws.amazon.com/dms/latest/APIReference/Welcome.html

        :stability: experimental
        '''
        return typing.cast("Dms", jsii.invoke(self, "toListDataProviders", []))

    @jsii.member(jsii_name="toListExtensionPacks")
    def to_list_extension_packs(self) -> "Dms":
        '''(experimental) Grants permission to list the AWS DMS attributes for a extension packs.

        Access Level: Read

        https://docs.aws.amazon.com/dms/latest/APIReference/Welcome.html

        :stability: experimental
        '''
        return typing.cast("Dms", jsii.invoke(self, "toListExtensionPacks", []))

    @jsii.member(jsii_name="toListInstanceProfiles")
    def to_list_instance_profiles(self) -> "Dms":
        '''(experimental) Grants permission to list the AWS DMS attributes for a instance profiles.

        Access Level: Read

        https://docs.aws.amazon.com/dms/latest/APIReference/Welcome.html

        :stability: experimental
        '''
        return typing.cast("Dms", jsii.invoke(self, "toListInstanceProfiles", []))

    @jsii.member(jsii_name="toListMetadataModelAssessmentActionItems")
    def to_list_metadata_model_assessment_action_items(self) -> "Dms":
        '''(experimental) Grants permission to list the AWS DMS attributes for a metadata model assessment action items.

        Access Level: Read

        https://docs.aws.amazon.com/dms/latest/APIReference/Welcome.html

        :stability: experimental
        '''
        return typing.cast("Dms", jsii.invoke(self, "toListMetadataModelAssessmentActionItems", []))

    @jsii.member(jsii_name="toListMetadataModelAssessments")
    def to_list_metadata_model_assessments(self) -> "Dms":
        '''(experimental) Grants permission to list the AWS DMS attributes for a metadata model assessments.

        Access Level: Read

        https://docs.aws.amazon.com/dms/latest/APIReference/Welcome.html

        :stability: experimental
        '''
        return typing.cast("Dms", jsii.invoke(self, "toListMetadataModelAssessments", []))

    @jsii.member(jsii_name="toListMetadataModelConversions")
    def to_list_metadata_model_conversions(self) -> "Dms":
        '''(experimental) Grants permission to list the AWS DMS attributes for a metadata model conversions.

        Access Level: Read

        https://docs.aws.amazon.com/dms/latest/APIReference/Welcome.html

        :stability: experimental
        '''
        return typing.cast("Dms", jsii.invoke(self, "toListMetadataModelConversions", []))

    @jsii.member(jsii_name="toListMetadataModelExports")
    def to_list_metadata_model_exports(self) -> "Dms":
        '''(experimental) Grants permission to list the AWS DMS attributes for a metadata model exports.

        Access Level: Read

        https://docs.aws.amazon.com/dms/latest/APIReference/Welcome.html

        :stability: experimental
        '''
        return typing.cast("Dms", jsii.invoke(self, "toListMetadataModelExports", []))

    @jsii.member(jsii_name="toListMigrationProjects")
    def to_list_migration_projects(self) -> "Dms":
        '''(experimental) Grants permission to list the AWS DMS attributes for a migration projects.

        Access Level: Read

        https://docs.aws.amazon.com/dms/latest/APIReference/Welcome.html

        :stability: experimental
        '''
        return typing.cast("Dms", jsii.invoke(self, "toListMigrationProjects", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Dms":
        '''(experimental) Grants permission to list all tags for an AWS DMS resource.

        Access Level: Read

        https://docs.aws.amazon.com/dms/latest/APIReference/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("Dms", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toModifyEndpoint")
    def to_modify_endpoint(self) -> "Dms":
        '''(experimental) Grants permission to modify the specified endpoint.

        Access Level: Write

        https://docs.aws.amazon.com/dms/latest/APIReference/API_ModifyEndpoint.html

        :stability: experimental
        '''
        return typing.cast("Dms", jsii.invoke(self, "toModifyEndpoint", []))

    @jsii.member(jsii_name="toModifyEventSubscription")
    def to_modify_event_subscription(self) -> "Dms":
        '''(experimental) Grants permission to modify an existing AWS DMS event notification subscription.

        Access Level: Write

        https://docs.aws.amazon.com/dms/latest/APIReference/API_ModifyEventSubscription.html

        :stability: experimental
        '''
        return typing.cast("Dms", jsii.invoke(self, "toModifyEventSubscription", []))

    @jsii.member(jsii_name="toModifyReplicationInstance")
    def to_modify_replication_instance(self) -> "Dms":
        '''(experimental) Grants permission to modify the replication instance to apply new settings.

        Access Level: Write

        https://docs.aws.amazon.com/dms/latest/APIReference/API_ModifyReplicationInstance.html

        :stability: experimental
        '''
        return typing.cast("Dms", jsii.invoke(self, "toModifyReplicationInstance", []))

    @jsii.member(jsii_name="toModifyReplicationSubnetGroup")
    def to_modify_replication_subnet_group(self) -> "Dms":
        '''(experimental) Grants permission to modify the settings for the specified replication subnet group.

        Access Level: Write

        https://docs.aws.amazon.com/dms/latest/APIReference/API_ModifyReplicationSubnetGroup.html

        :stability: experimental
        '''
        return typing.cast("Dms", jsii.invoke(self, "toModifyReplicationSubnetGroup", []))

    @jsii.member(jsii_name="toModifyReplicationTask")
    def to_modify_replication_task(self) -> "Dms":
        '''(experimental) Grants permission to modify the specified replication task.

        Access Level: Write

        https://docs.aws.amazon.com/dms/latest/APIReference/API_ModifyReplicationTask.html

        :stability: experimental
        '''
        return typing.cast("Dms", jsii.invoke(self, "toModifyReplicationTask", []))

    @jsii.member(jsii_name="toMoveReplicationTask")
    def to_move_replication_task(self) -> "Dms":
        '''(experimental) Grants permission to move the specified replication task to a different replication instance.

        Access Level: Write

        https://docs.aws.amazon.com/dms/latest/APIReference/API_MoveReplicationTask.html

        :stability: experimental
        '''
        return typing.cast("Dms", jsii.invoke(self, "toMoveReplicationTask", []))

    @jsii.member(jsii_name="toRebootReplicationInstance")
    def to_reboot_replication_instance(self) -> "Dms":
        '''(experimental) Grants permission to reboot a replication instance.

        Rebooting results in a momentary outage, until the replication instance becomes available again

        Access Level: Write

        https://docs.aws.amazon.com/dms/latest/APIReference/API_RebootReplicationInstance.html

        :stability: experimental
        '''
        return typing.cast("Dms", jsii.invoke(self, "toRebootReplicationInstance", []))

    @jsii.member(jsii_name="toRefreshSchemas")
    def to_refresh_schemas(self) -> "Dms":
        '''(experimental) Grants permission to populate the schema for the specified endpoint.

        Access Level: Write

        https://docs.aws.amazon.com/dms/latest/APIReference/API_RefreshSchemas.html

        :stability: experimental
        '''
        return typing.cast("Dms", jsii.invoke(self, "toRefreshSchemas", []))

    @jsii.member(jsii_name="toReloadTables")
    def to_reload_tables(self) -> "Dms":
        '''(experimental) Grants permission to reload the target database table with the source data.

        Access Level: Write

        https://docs.aws.amazon.com/dms/latest/APIReference/API_ReloadTables.html

        :stability: experimental
        '''
        return typing.cast("Dms", jsii.invoke(self, "toReloadTables", []))

    @jsii.member(jsii_name="toRemoveTagsFromResource")
    def to_remove_tags_from_resource(self) -> "Dms":
        '''(experimental) Grants permission to remove metadata tags from a DMS resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/dms/latest/APIReference/API_RemoveTagsFromResource.html

        :stability: experimental
        '''
        return typing.cast("Dms", jsii.invoke(self, "toRemoveTagsFromResource", []))

    @jsii.member(jsii_name="toStartMetadataModelAssessment")
    def to_start_metadata_model_assessment(self) -> "Dms":
        '''(experimental) Grants permission to start a new assessment of metadata model.

        Access Level: Write

        https://docs.aws.amazon.com/dms/latest/APIReference/Welcome.html

        :stability: experimental
        '''
        return typing.cast("Dms", jsii.invoke(self, "toStartMetadataModelAssessment", []))

    @jsii.member(jsii_name="toStartMetadataModelConversion")
    def to_start_metadata_model_conversion(self) -> "Dms":
        '''(experimental) Grants permission to start a new conversion of metadata model.

        Access Level: Write

        https://docs.aws.amazon.com/dms/latest/APIReference/Welcome.html

        :stability: experimental
        '''
        return typing.cast("Dms", jsii.invoke(self, "toStartMetadataModelConversion", []))

    @jsii.member(jsii_name="toStartMetadataModelExportAsScripts")
    def to_start_metadata_model_export_as_scripts(self) -> "Dms":
        '''(experimental) Grants permission to start a new export of metadata model as script.

        Access Level: Write

        https://docs.aws.amazon.com/dms/latest/APIReference/Welcome.html

        :stability: experimental
        '''
        return typing.cast("Dms", jsii.invoke(self, "toStartMetadataModelExportAsScripts", []))

    @jsii.member(jsii_name="toStartMetadataModelExportToTarget")
    def to_start_metadata_model_export_to_target(self) -> "Dms":
        '''(experimental) Grants permission to start a new export of metadata model to target.

        Access Level: Write

        https://docs.aws.amazon.com/dms/latest/APIReference/Welcome.html

        :stability: experimental
        '''
        return typing.cast("Dms", jsii.invoke(self, "toStartMetadataModelExportToTarget", []))

    @jsii.member(jsii_name="toStartMetadataModelImport")
    def to_start_metadata_model_import(self) -> "Dms":
        '''(experimental) Grants permission to start a new import of metadata model.

        Access Level: Write

        https://docs.aws.amazon.com/dms/latest/APIReference/Welcome.html

        :stability: experimental
        '''
        return typing.cast("Dms", jsii.invoke(self, "toStartMetadataModelImport", []))

    @jsii.member(jsii_name="toStartReplicationTask")
    def to_start_replication_task(self) -> "Dms":
        '''(experimental) Grants permission to start the replication task.

        Access Level: Write

        https://docs.aws.amazon.com/dms/latest/APIReference/API_StartReplicationTask.html

        :stability: experimental
        '''
        return typing.cast("Dms", jsii.invoke(self, "toStartReplicationTask", []))

    @jsii.member(jsii_name="toStartReplicationTaskAssessment")
    def to_start_replication_task_assessment(self) -> "Dms":
        '''(experimental) Grants permission to start the replication task assessment for unsupported data types in the source database.

        Access Level: Write

        https://docs.aws.amazon.com/dms/latest/APIReference/API_StartReplicationTaskAssessment.html

        :stability: experimental
        '''
        return typing.cast("Dms", jsii.invoke(self, "toStartReplicationTaskAssessment", []))

    @jsii.member(jsii_name="toStartReplicationTaskAssessmentRun")
    def to_start_replication_task_assessment_run(self) -> "Dms":
        '''(experimental) Grants permission to start a new premigration assessment run for one or more individual assessments of a migration task.

        Access Level: Write

        https://docs.aws.amazon.com/dms/latest/APIReference/API_StartReplicationTaskAssessmentRun.html

        :stability: experimental
        '''
        return typing.cast("Dms", jsii.invoke(self, "toStartReplicationTaskAssessmentRun", []))

    @jsii.member(jsii_name="toStopReplicationTask")
    def to_stop_replication_task(self) -> "Dms":
        '''(experimental) Grants permission to stop the replication task.

        Access Level: Write

        https://docs.aws.amazon.com/dms/latest/APIReference/API_StopReplicationTask.html

        :stability: experimental
        '''
        return typing.cast("Dms", jsii.invoke(self, "toStopReplicationTask", []))

    @jsii.member(jsii_name="toTestConnection")
    def to_test_connection(self) -> "Dms":
        '''(experimental) Grants permission to test the connection between the replication instance and the endpoint.

        Access Level: Read

        https://docs.aws.amazon.com/dms/latest/APIReference/API_TestConnection.html

        :stability: experimental
        '''
        return typing.cast("Dms", jsii.invoke(self, "toTestConnection", []))

    @jsii.member(jsii_name="toUpdateConversionConfiguration")
    def to_update_conversion_configuration(self) -> "Dms":
        '''(experimental) Grants permission to update a conversion configuration.

        Access Level: Write

        https://docs.aws.amazon.com/dms/latest/APIReference/Welcome.html

        :stability: experimental
        '''
        return typing.cast("Dms", jsii.invoke(self, "toUpdateConversionConfiguration", []))

    @jsii.member(jsii_name="toUpdateDataProvider")
    def to_update_data_provider(self) -> "Dms":
        '''(experimental) Grants permission to update the specified data provider.

        Access Level: Write

        https://docs.aws.amazon.com/dms/latest/APIReference/Welcome.html

        :stability: experimental
        '''
        return typing.cast("Dms", jsii.invoke(self, "toUpdateDataProvider", []))

    @jsii.member(jsii_name="toUpdateInstanceProfile")
    def to_update_instance_profile(self) -> "Dms":
        '''(experimental) Grants permission to update the specified instance profile.

        Access Level: Write

        https://docs.aws.amazon.com/dms/latest/APIReference/Welcome.html

        :stability: experimental
        '''
        return typing.cast("Dms", jsii.invoke(self, "toUpdateInstanceProfile", []))

    @jsii.member(jsii_name="toUpdateMigrationProject")
    def to_update_migration_project(self) -> "Dms":
        '''(experimental) Grants permission to update the specified migration project.

        Access Level: Write

        https://docs.aws.amazon.com/dms/latest/APIReference/Welcome.html

        :stability: experimental
        '''
        return typing.cast("Dms", jsii.invoke(self, "toUpdateMigrationProject", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4089374071b2aed6e910cefd94b39246fdc3e91e8050ef4b8beafbfdf0886232)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c53e9d8ec2ba9b2d424ee63b306dcf73f6039be18ac3b6147c1e372f7f631183)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class DocdbElastic(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.DocdbElastic",
):
    '''(experimental) Statement provider for service `docdb-elastic <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazondocumentdbelasticclusters.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `docdb-elastic <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazondocumentdbelasticclusters.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onCluster")
    def on_cluster(
        self,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "DocdbElastic":
        '''(experimental) Adds a resource of type cluster to the statement.

        https://docs.aws.amazon.com/documentdb/latest/developerguide/docdb-elastic-usingdocdb-elastic.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__786ee16db6ee971b279e2502bf5879d4757482cb833a85923315de561ebb5b0a)
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("DocdbElastic", jsii.invoke(self, "onCluster", [resource_id, account, region, partition]))

    @jsii.member(jsii_name="onClusterSnapshot")
    def on_cluster_snapshot(
        self,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "DocdbElastic":
        '''(experimental) Adds a resource of type cluster-snapshot to the statement.

        https://docs.aws.amazon.com/documentdb/latest/developerguide/docdb-elastic-usingdocdb-elastic.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ab0b01c19416edd4e5e2b3b16fe8a84e78935d5275c32198d00835f0b5270bac)
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("DocdbElastic", jsii.invoke(self, "onClusterSnapshot", [resource_id, account, region, partition]))

    @jsii.member(jsii_name="toCreateCluster")
    def to_create_cluster(self) -> "DocdbElastic":
        '''(experimental) Grants permission to create a new Amazon DocDB-Elastic cluster.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - ec2:CreateVpcEndpoint
        - ec2:DeleteVpcEndpoints
        - ec2:DescribeAvailabilityZones
        - ec2:DescribeSecurityGroups
        - ec2:DescribeSubnets
        - ec2:DescribeVpcAttribute
        - ec2:DescribeVpcEndpoints
        - ec2:DescribeVpcs
        - ec2:ModifyVpcEndpoint
        - iam:CreateServiceLinkedRole
        - kms:CreateGrant
        - kms:Decrypt
        - kms:DescribeKey
        - kms:GenerateDataKey
        - secretsmanager:DescribeSecret
        - secretsmanager:GetResourcePolicy
        - secretsmanager:GetSecretValue
        - secretsmanager:ListSecretVersionIds
        - secretsmanager:ListSecrets

        https://docs.aws.amazon.com/documentdb/latest/developerguide/docdb-elastic-usingcreate_cluster.html

        :stability: experimental
        '''
        return typing.cast("DocdbElastic", jsii.invoke(self, "toCreateCluster", []))

    @jsii.member(jsii_name="toCreateClusterSnapshot")
    def to_create_cluster_snapshot(self) -> "DocdbElastic":
        '''(experimental) Grants permission to create a new Amazon DocDB-Elastic cluster snapshot.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifAwsResourceTag()

        Dependent actions:

        - ec2:CreateVpcEndpoint
        - ec2:DeleteVpcEndpoints
        - ec2:DescribeAvailabilityZones
        - ec2:DescribeSecurityGroups
        - ec2:DescribeSubnets
        - ec2:DescribeVpcAttribute
        - ec2:DescribeVpcEndpoints
        - ec2:DescribeVpcs
        - ec2:ModifyVpcEndpoint
        - iam:CreateServiceLinkedRole
        - kms:CreateGrant
        - kms:Decrypt
        - kms:DescribeKey
        - kms:GenerateDataKey
        - secretsmanager:DescribeSecret
        - secretsmanager:GetResourcePolicy
        - secretsmanager:GetSecretValue
        - secretsmanager:ListSecretVersionIds
        - secretsmanager:ListSecrets

        https://docs.aws.amazon.com/documentdb/latest/developerguide/docdb-elastic-usingcreate_cluster_snapshot.html

        :stability: experimental
        '''
        return typing.cast("DocdbElastic", jsii.invoke(self, "toCreateClusterSnapshot", []))

    @jsii.member(jsii_name="toDeleteCluster")
    def to_delete_cluster(self) -> "DocdbElastic":
        '''(experimental) Grants permission to delete a cluster.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        Dependent actions:

        - ec2:DeleteVpcEndpoints
        - ec2:DescribeAvailabilityZones
        - ec2:DescribeSecurityGroups
        - ec2:DescribeSubnets
        - ec2:DescribeVpcAttribute
        - ec2:DescribeVpcEndpoints
        - ec2:DescribeVpcs
        - ec2:ModifyVpcEndpoint

        https://docs.aws.amazon.com/documentdb/latest/developerguide/docdb-elastic-usingdelete_cluster.html

        :stability: experimental
        '''
        return typing.cast("DocdbElastic", jsii.invoke(self, "toDeleteCluster", []))

    @jsii.member(jsii_name="toDeleteClusterSnapshot")
    def to_delete_cluster_snapshot(self) -> "DocdbElastic":
        '''(experimental) Grants permission to delete a cluster snapshot.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        Dependent actions:

        - ec2:DeleteVpcEndpoints
        - ec2:DescribeAvailabilityZones
        - ec2:DescribeSecurityGroups
        - ec2:DescribeSubnets
        - ec2:DescribeVpcAttribute
        - ec2:DescribeVpcEndpoints
        - ec2:DescribeVpcs
        - ec2:ModifyVpcEndpoint

        https://docs.aws.amazon.com/documentdb/latest/developerguide/docdb-elastic-usingdelete_cluster_snapshot.html

        :stability: experimental
        '''
        return typing.cast("DocdbElastic", jsii.invoke(self, "toDeleteClusterSnapshot", []))

    @jsii.member(jsii_name="toGetCluster")
    def to_get_cluster(self) -> "DocdbElastic":
        '''(experimental) Grants permission to view details about a cluster.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/documentdb/latest/developerguide/docdb-elastic-usingget_cluster.html

        :stability: experimental
        '''
        return typing.cast("DocdbElastic", jsii.invoke(self, "toGetCluster", []))

    @jsii.member(jsii_name="toGetClusterSnapshot")
    def to_get_cluster_snapshot(self) -> "DocdbElastic":
        '''(experimental) Grants permission to view details about a cluster snapshot.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/documentdb/latest/developerguide/docdb-elastic-usingget_cluster_snapshot.html

        :stability: experimental
        '''
        return typing.cast("DocdbElastic", jsii.invoke(self, "toGetClusterSnapshot", []))

    @jsii.member(jsii_name="toListClusters")
    def to_list_clusters(self) -> "DocdbElastic":
        '''(experimental) Grants permission to list the clusters in your account.

        Access Level: List

        https://docs.aws.amazon.com/documentdb/latest/developerguide/docdb-elastic-usinglist_clusters.html

        :stability: experimental
        '''
        return typing.cast("DocdbElastic", jsii.invoke(self, "toListClusters", []))

    @jsii.member(jsii_name="toListClusterSnapshots")
    def to_list_cluster_snapshots(self) -> "DocdbElastic":
        '''(experimental) Grants permission to list the cluster snapshots in your account.

        Access Level: List

        https://docs.aws.amazon.com/documentdb/latest/developerguide/docdb-elastic-usinglist_cluster_snapshots.html

        :stability: experimental
        '''
        return typing.cast("DocdbElastic", jsii.invoke(self, "toListClusterSnapshots", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "DocdbElastic":
        '''(experimental) Grants permission to lists tag for an DocumentDB Elastic resource.

        Access Level: List

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/documentdb/latest/developerguide/docdb-elastic-usingAPI_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("DocdbElastic", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toRestoreClusterFromSnapshot")
    def to_restore_cluster_from_snapshot(self) -> "DocdbElastic":
        '''(experimental) Grants permission to restore cluster from a Amazon DocDB-Elastic cluster snapshot.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifAwsResourceTag()

        Dependent actions:

        - ec2:CreateVpcEndpoint
        - ec2:DeleteVpcEndpoints
        - ec2:DescribeAvailabilityZones
        - ec2:DescribeSecurityGroups
        - ec2:DescribeSubnets
        - ec2:DescribeVpcAttribute
        - ec2:DescribeVpcEndpoints
        - ec2:DescribeVpcs
        - ec2:ModifyVpcEndpoint
        - iam:CreateServiceLinkedRole
        - kms:CreateGrant
        - kms:Decrypt
        - kms:DescribeKey
        - kms:GenerateDataKey
        - secretsmanager:DescribeSecret
        - secretsmanager:GetResourcePolicy
        - secretsmanager:GetSecretValue
        - secretsmanager:ListSecretVersionIds
        - secretsmanager:ListSecrets

        https://docs.aws.amazon.com/documentdb/latest/developerguide/docdb-elastic-usingrestore_cluster_from_snapshot.html

        :stability: experimental
        '''
        return typing.cast("DocdbElastic", jsii.invoke(self, "toRestoreClusterFromSnapshot", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "DocdbElastic":
        '''(experimental) Grants permission to tag an DocumentDB Elastic resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()
        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/documentdb/latest/developerguide/docdb-elastic-usingAPI_TagResource.html

        :stability: experimental
        '''
        return typing.cast("DocdbElastic", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "DocdbElastic":
        '''(experimental) Grants permission to untag a DocumentDB Elastic resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/documentdb/latest/developerguide/docdb-elastic-usingAPI_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("DocdbElastic", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateCluster")
    def to_update_cluster(self) -> "DocdbElastic":
        '''(experimental) Grants permission to modify a cluster.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        Dependent actions:

        - ec2:CreateVpcEndpoint
        - ec2:DeleteVpcEndpoints
        - ec2:DescribeAvailabilityZones
        - ec2:DescribeSecurityGroups
        - ec2:DescribeSubnets
        - ec2:DescribeVpcAttribute
        - ec2:DescribeVpcEndpoints
        - ec2:DescribeVpcs
        - ec2:ModifyVpcEndpoint
        - kms:CreateGrant
        - kms:Decrypt
        - kms:DescribeKey
        - kms:GenerateDataKey
        - secretsmanager:DescribeSecret
        - secretsmanager:GetResourcePolicy
        - secretsmanager:GetSecretValue
        - secretsmanager:ListSecretVersionIds
        - secretsmanager:ListSecrets

        https://docs.aws.amazon.com/documentdb/latest/developerguide/docdb-elastic-usingupdate_cluster.html

        :stability: experimental
        '''
        return typing.cast("DocdbElastic", jsii.invoke(self, "toUpdateCluster", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b61ea483175cc6617e34f5ebdbd975011dc74b4090ce5ae4dee0056aa98a4534)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ff0982417bcb4280f45dfa24598c041fdcbf585321b7f45b89178c6cad84ae35)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Drs(PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Drs"):
    '''(experimental) Statement provider for service `drs <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awselasticdisasterrecovery.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `drs <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awselasticdisasterrecovery.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="ifCreateAction")
    def if_create_action(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Drs":
        '''(experimental) Filters access by the name of a resource-creating API action.

        https://docs.aws.amazon.com/drs/latest/userguide/supported-iam-actions-tagging.html

        Applies to actions:

        - .toTagResource()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1d8423bfbd4444d3b0420fafecee9b73475433350651707366dfd76e62ac0fff)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Drs", jsii.invoke(self, "ifCreateAction", [value, operator]))

    @jsii.member(jsii_name="ifEC2InstanceARN")
    def if_ec2_instance_arn(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Drs":
        '''(experimental) Filters access by the EC2 instance the request originated from.

        https://docs.aws.amazon.com/drs/latest/userguide/security_iam_authentication.html

        Applies to resource types:

        - RecoveryInstanceResource

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__cda4d39264d8195471d5ffbd971ab52d2e6b3d1f8f1b98d03915d1c27da146a0)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Drs", jsii.invoke(self, "ifEC2InstanceARN", [value, operator]))

    @jsii.member(jsii_name="onJobResource")
    def on_job_resource(
        self,
        job_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Drs":
        '''(experimental) Adds a resource of type JobResource to the statement.

        https://docs.aws.amazon.com/drs/latest/userguide/failback-overview.html

        :param job_id: - Identifier for the jobID.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1080cd962370304b58acd28bc635647a3a3d8bacd56b440fd29484cc17a7ee39)
            check_type(argname="argument job_id", value=job_id, expected_type=type_hints["job_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Drs", jsii.invoke(self, "onJobResource", [job_id, account, region, partition]))

    @jsii.member(jsii_name="onRecoveryInstanceResource")
    def on_recovery_instance_resource(
        self,
        recovery_instance_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Drs":
        '''(experimental) Adds a resource of type RecoveryInstanceResource to the statement.

        https://docs.aws.amazon.com/drs/latest/userguide/recovery-instances.html

        :param recovery_instance_id: - Identifier for the recoveryInstanceID.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag() - .ifEC2InstanceARN()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__24b075c6ac56aa6c53593486341334e5111d2b0b44620dd28df7bc9b2c83ea7a)
            check_type(argname="argument recovery_instance_id", value=recovery_instance_id, expected_type=type_hints["recovery_instance_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Drs", jsii.invoke(self, "onRecoveryInstanceResource", [recovery_instance_id, account, region, partition]))

    @jsii.member(jsii_name="onReplicationConfigurationTemplateResource")
    def on_replication_configuration_template_resource(
        self,
        replication_configuration_template_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Drs":
        '''(experimental) Adds a resource of type ReplicationConfigurationTemplateResource to the statement.

        https://docs.aws.amazon.com/drs/latest/userguide/replication-settings-template.html

        :param replication_configuration_template_id: - Identifier for the replicationConfigurationTemplateID.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__665a40444d6192d2e39a6165247ca6153cb153f59c094471a3e73745276fe268)
            check_type(argname="argument replication_configuration_template_id", value=replication_configuration_template_id, expected_type=type_hints["replication_configuration_template_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Drs", jsii.invoke(self, "onReplicationConfigurationTemplateResource", [replication_configuration_template_id, account, region, partition]))

    @jsii.member(jsii_name="onSourceServerResource")
    def on_source_server_resource(
        self,
        source_server_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Drs":
        '''(experimental) Adds a resource of type SourceServerResource to the statement.

        https://docs.aws.amazon.com/drs/latest/userguide/source-servers.html

        :param source_server_id: - Identifier for the sourceServerID.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d24234c4e99b46228388b6796fb7462e10338bc54eb1f5587c0a2a9a4477f00a)
            check_type(argname="argument source_server_id", value=source_server_id, expected_type=type_hints["source_server_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Drs", jsii.invoke(self, "onSourceServerResource", [source_server_id, account, region, partition]))

    @jsii.member(jsii_name="toAssociateFailbackClientToRecoveryInstanceForDrs")
    def to_associate_failback_client_to_recovery_instance_for_drs(self) -> "Drs":
        '''(experimental) Grants permission to get associate failback client to recovery instance.

        Access Level: Write

        https://docs.aws.amazon.com/drs/latest/userguide/drs-apis.html

        :stability: experimental
        '''
        return typing.cast("Drs", jsii.invoke(self, "toAssociateFailbackClientToRecoveryInstanceForDrs", []))

    @jsii.member(jsii_name="toBatchCreateVolumeSnapshotGroupForDrs")
    def to_batch_create_volume_snapshot_group_for_drs(self) -> "Drs":
        '''(experimental) Grants permission to batch create volume snapshot group.

        Access Level: Write

        https://docs.aws.amazon.com/drs/latest/userguide/drs-apis.html

        :stability: experimental
        '''
        return typing.cast("Drs", jsii.invoke(self, "toBatchCreateVolumeSnapshotGroupForDrs", []))

    @jsii.member(jsii_name="toBatchDeleteSnapshotRequestForDrs")
    def to_batch_delete_snapshot_request_for_drs(self) -> "Drs":
        '''(experimental) Grants permission to batch delete snapshot request.

        Access Level: Write

        https://docs.aws.amazon.com/drs/latest/userguide/drs-apis.html

        :stability: experimental
        '''
        return typing.cast("Drs", jsii.invoke(self, "toBatchDeleteSnapshotRequestForDrs", []))

    @jsii.member(jsii_name="toCreateConvertedSnapshotForDrs")
    def to_create_converted_snapshot_for_drs(self) -> "Drs":
        '''(experimental) Grants permission to create converted snapshot.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/drs/latest/userguide/drs-apis.html

        :stability: experimental
        '''
        return typing.cast("Drs", jsii.invoke(self, "toCreateConvertedSnapshotForDrs", []))

    @jsii.member(jsii_name="toCreateExtendedSourceServer")
    def to_create_extended_source_server(self) -> "Drs":
        '''(experimental) Grants permission to extend a source server.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - drs:DescribeSourceServers
        - drs:GetReplicationConfiguration

        https://docs.aws.amazon.com/drs/latest/APIReference/API_CreateExtendedSourceServer.html

        :stability: experimental
        '''
        return typing.cast("Drs", jsii.invoke(self, "toCreateExtendedSourceServer", []))

    @jsii.member(jsii_name="toCreateRecoveryInstanceForDrs")
    def to_create_recovery_instance_for_drs(self) -> "Drs":
        '''(experimental) Grants permission to create recovery instance.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/drs/latest/userguide/drs-apis.html

        :stability: experimental
        '''
        return typing.cast("Drs", jsii.invoke(self, "toCreateRecoveryInstanceForDrs", []))

    @jsii.member(jsii_name="toCreateReplicationConfigurationTemplate")
    def to_create_replication_configuration_template(self) -> "Drs":
        '''(experimental) Grants permission to create replication configuration template.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - ec2:CreateSecurityGroup
        - ec2:DescribeSecurityGroups
        - ec2:DescribeSubnets
        - ec2:GetEbsDefaultKmsKeyId
        - ec2:GetEbsEncryptionByDefault
        - kms:CreateGrant
        - kms:DescribeKey

        https://docs.aws.amazon.com/drs/latest/APIReference/API_CreateReplicationConfigurationTemplate.html

        :stability: experimental
        '''
        return typing.cast("Drs", jsii.invoke(self, "toCreateReplicationConfigurationTemplate", []))

    @jsii.member(jsii_name="toCreateSourceServerForDrs")
    def to_create_source_server_for_drs(self) -> "Drs":
        '''(experimental) Grants permission to create a source server.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/drs/latest/userguide/drs-apis.html

        :stability: experimental
        '''
        return typing.cast("Drs", jsii.invoke(self, "toCreateSourceServerForDrs", []))

    @jsii.member(jsii_name="toDeleteJob")
    def to_delete_job(self) -> "Drs":
        '''(experimental) Grants permission to delete a job.

        Access Level: Write

        https://docs.aws.amazon.com/drs/latest/APIReference/API_DeleteJob.html

        :stability: experimental
        '''
        return typing.cast("Drs", jsii.invoke(self, "toDeleteJob", []))

    @jsii.member(jsii_name="toDeleteRecoveryInstance")
    def to_delete_recovery_instance(self) -> "Drs":
        '''(experimental) Grants permission to delete recovery instance.

        Access Level: Write

        https://docs.aws.amazon.com/drs/latest/APIReference/API_DeleteRecoveryInstance.html

        :stability: experimental
        '''
        return typing.cast("Drs", jsii.invoke(self, "toDeleteRecoveryInstance", []))

    @jsii.member(jsii_name="toDeleteReplicationConfigurationTemplate")
    def to_delete_replication_configuration_template(self) -> "Drs":
        '''(experimental) Grants permission to delete replication configuration template.

        Access Level: Write

        https://docs.aws.amazon.com/drs/latest/APIReference/API_DeleteReplicationConfigurationTemplate.html

        :stability: experimental
        '''
        return typing.cast("Drs", jsii.invoke(self, "toDeleteReplicationConfigurationTemplate", []))

    @jsii.member(jsii_name="toDeleteSourceServer")
    def to_delete_source_server(self) -> "Drs":
        '''(experimental) Grants permission to delete source server.

        Access Level: Write

        https://docs.aws.amazon.com/drs/latest/APIReference/API_DeleteSourceServer.html

        :stability: experimental
        '''
        return typing.cast("Drs", jsii.invoke(self, "toDeleteSourceServer", []))

    @jsii.member(jsii_name="toDescribeJobLogItems")
    def to_describe_job_log_items(self) -> "Drs":
        '''(experimental) Grants permission to describe job log items.

        Access Level: Read

        https://docs.aws.amazon.com/drs/latest/APIReference/API_DescribeJobLogItems.html

        :stability: experimental
        '''
        return typing.cast("Drs", jsii.invoke(self, "toDescribeJobLogItems", []))

    @jsii.member(jsii_name="toDescribeJobs")
    def to_describe_jobs(self) -> "Drs":
        '''(experimental) Grants permission to describe jobs.

        Access Level: Read

        https://docs.aws.amazon.com/drs/latest/APIReference/API_DescribeJobs.html

        :stability: experimental
        '''
        return typing.cast("Drs", jsii.invoke(self, "toDescribeJobs", []))

    @jsii.member(jsii_name="toDescribeRecoveryInstances")
    def to_describe_recovery_instances(self) -> "Drs":
        '''(experimental) Grants permission to describe recovery instances.

        Access Level: Read

        Dependent actions:

        - drs:DescribeSourceServers
        - ec2:DescribeInstances

        https://docs.aws.amazon.com/drs/latest/APIReference/API_DescribeRecoveryInstances.html

        :stability: experimental
        '''
        return typing.cast("Drs", jsii.invoke(self, "toDescribeRecoveryInstances", []))

    @jsii.member(jsii_name="toDescribeRecoverySnapshots")
    def to_describe_recovery_snapshots(self) -> "Drs":
        '''(experimental) Grants permission to describe recovery snapshots.

        Access Level: Read

        https://docs.aws.amazon.com/drs/latest/APIReference/API_DescribeRecoverySnapshots.html

        :stability: experimental
        '''
        return typing.cast("Drs", jsii.invoke(self, "toDescribeRecoverySnapshots", []))

    @jsii.member(jsii_name="toDescribeReplicationConfigurationTemplates")
    def to_describe_replication_configuration_templates(self) -> "Drs":
        '''(experimental) Grants permission to describe replication configuration template.

        Access Level: Read

        https://docs.aws.amazon.com/drs/latest/APIReference/API_DescribeReplicationConfigurationTemplates.html

        :stability: experimental
        '''
        return typing.cast("Drs", jsii.invoke(self, "toDescribeReplicationConfigurationTemplates", []))

    @jsii.member(jsii_name="toDescribeReplicationServerAssociationsForDrs")
    def to_describe_replication_server_associations_for_drs(self) -> "Drs":
        '''(experimental) Grants permission to describe replication server associations.

        Access Level: Read

        https://docs.aws.amazon.com/drs/latest/userguide/drs-apis.html

        :stability: experimental
        '''
        return typing.cast("Drs", jsii.invoke(self, "toDescribeReplicationServerAssociationsForDrs", []))

    @jsii.member(jsii_name="toDescribeSnapshotRequestsForDrs")
    def to_describe_snapshot_requests_for_drs(self) -> "Drs":
        '''(experimental) Grants permission to describe snapshot requests.

        Access Level: Read

        https://docs.aws.amazon.com/drs/latest/userguide/drs-apis.html

        :stability: experimental
        '''
        return typing.cast("Drs", jsii.invoke(self, "toDescribeSnapshotRequestsForDrs", []))

    @jsii.member(jsii_name="toDescribeSourceServers")
    def to_describe_source_servers(self) -> "Drs":
        '''(experimental) Grants permission to describe source servers.

        Access Level: Read

        https://docs.aws.amazon.com/drs/latest/APIReference/API_DescribeSourceServers.html

        :stability: experimental
        '''
        return typing.cast("Drs", jsii.invoke(self, "toDescribeSourceServers", []))

    @jsii.member(jsii_name="toDisconnectRecoveryInstance")
    def to_disconnect_recovery_instance(self) -> "Drs":
        '''(experimental) Grants permission to disconnect recovery instance.

        Access Level: Write

        https://docs.aws.amazon.com/drs/latest/APIReference/API_DisconnectRecoveryInstance.html

        :stability: experimental
        '''
        return typing.cast("Drs", jsii.invoke(self, "toDisconnectRecoveryInstance", []))

    @jsii.member(jsii_name="toDisconnectSourceServer")
    def to_disconnect_source_server(self) -> "Drs":
        '''(experimental) Grants permission to disconnect source server.

        Access Level: Write

        https://docs.aws.amazon.com/drs/latest/APIReference/API_DisconnectSourceServer.html

        :stability: experimental
        '''
        return typing.cast("Drs", jsii.invoke(self, "toDisconnectSourceServer", []))

    @jsii.member(jsii_name="toGetAgentCommandForDrs")
    def to_get_agent_command_for_drs(self) -> "Drs":
        '''(experimental) Grants permission to get agent command.

        Access Level: Read

        https://docs.aws.amazon.com/drs/latest/userguide/drs-apis.html

        :stability: experimental
        '''
        return typing.cast("Drs", jsii.invoke(self, "toGetAgentCommandForDrs", []))

    @jsii.member(jsii_name="toGetAgentConfirmedResumeInfoForDrs")
    def to_get_agent_confirmed_resume_info_for_drs(self) -> "Drs":
        '''(experimental) Grants permission to get agent confirmed resume info.

        Access Level: Read

        https://docs.aws.amazon.com/drs/latest/userguide/drs-apis.html

        :stability: experimental
        '''
        return typing.cast("Drs", jsii.invoke(self, "toGetAgentConfirmedResumeInfoForDrs", []))

    @jsii.member(jsii_name="toGetAgentInstallationAssetsForDrs")
    def to_get_agent_installation_assets_for_drs(self) -> "Drs":
        '''(experimental) Grants permission to get agent installation assets.

        Access Level: Read

        https://docs.aws.amazon.com/drs/latest/userguide/drs-apis.html

        :stability: experimental
        '''
        return typing.cast("Drs", jsii.invoke(self, "toGetAgentInstallationAssetsForDrs", []))

    @jsii.member(jsii_name="toGetAgentReplicationInfoForDrs")
    def to_get_agent_replication_info_for_drs(self) -> "Drs":
        '''(experimental) Grants permission to get agent replication info.

        Access Level: Read

        https://docs.aws.amazon.com/drs/latest/userguide/drs-apis.html

        :stability: experimental
        '''
        return typing.cast("Drs", jsii.invoke(self, "toGetAgentReplicationInfoForDrs", []))

    @jsii.member(jsii_name="toGetAgentRuntimeConfigurationForDrs")
    def to_get_agent_runtime_configuration_for_drs(self) -> "Drs":
        '''(experimental) Grants permission to get agent runtime configuration.

        Access Level: Read

        https://docs.aws.amazon.com/drs/latest/userguide/drs-apis.html

        :stability: experimental
        '''
        return typing.cast("Drs", jsii.invoke(self, "toGetAgentRuntimeConfigurationForDrs", []))

    @jsii.member(jsii_name="toGetAgentSnapshotCreditsForDrs")
    def to_get_agent_snapshot_credits_for_drs(self) -> "Drs":
        '''(experimental) Grants permission to get agent snapshot credits.

        Access Level: Read

        https://docs.aws.amazon.com/drs/latest/userguide/drs-apis.html

        :stability: experimental
        '''
        return typing.cast("Drs", jsii.invoke(self, "toGetAgentSnapshotCreditsForDrs", []))

    @jsii.member(jsii_name="toGetChannelCommandsForDrs")
    def to_get_channel_commands_for_drs(self) -> "Drs":
        '''(experimental) Grants permission to get channel commands.

        Access Level: Read

        https://docs.aws.amazon.com/drs/latest/userguide/drs-apis.html

        :stability: experimental
        '''
        return typing.cast("Drs", jsii.invoke(self, "toGetChannelCommandsForDrs", []))

    @jsii.member(jsii_name="toGetFailbackCommandForDrs")
    def to_get_failback_command_for_drs(self) -> "Drs":
        '''(experimental) Grants permission to get failback command.

        Access Level: Read

        https://docs.aws.amazon.com/drs/latest/userguide/drs-apis.html

        :stability: experimental
        '''
        return typing.cast("Drs", jsii.invoke(self, "toGetFailbackCommandForDrs", []))

    @jsii.member(jsii_name="toGetFailbackLaunchRequestedForDrs")
    def to_get_failback_launch_requested_for_drs(self) -> "Drs":
        '''(experimental) Grants permission to get failback launch requested.

        Access Level: Read

        https://docs.aws.amazon.com/drs/latest/userguide/drs-apis.html

        :stability: experimental
        '''
        return typing.cast("Drs", jsii.invoke(self, "toGetFailbackLaunchRequestedForDrs", []))

    @jsii.member(jsii_name="toGetFailbackReplicationConfiguration")
    def to_get_failback_replication_configuration(self) -> "Drs":
        '''(experimental) Grants permission to get failback replication configuration.

        Access Level: Read

        https://docs.aws.amazon.com/drs/latest/APIReference/API_GetFailbackReplicationConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Drs", jsii.invoke(self, "toGetFailbackReplicationConfiguration", []))

    @jsii.member(jsii_name="toGetLaunchConfiguration")
    def to_get_launch_configuration(self) -> "Drs":
        '''(experimental) Grants permission to get launch configuration.

        Access Level: Read

        https://docs.aws.amazon.com/drs/latest/APIReference/API_GetLaunchConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Drs", jsii.invoke(self, "toGetLaunchConfiguration", []))

    @jsii.member(jsii_name="toGetReplicationConfiguration")
    def to_get_replication_configuration(self) -> "Drs":
        '''(experimental) Grants permission to get replication configuration.

        Access Level: Read

        https://docs.aws.amazon.com/drs/latest/APIReference/API_GetReplicationConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Drs", jsii.invoke(self, "toGetReplicationConfiguration", []))

    @jsii.member(jsii_name="toGetSuggestedFailbackClientDeviceMappingForDrs")
    def to_get_suggested_failback_client_device_mapping_for_drs(self) -> "Drs":
        '''(experimental) Grants permission to get suggested failback client device mapping.

        Access Level: Read

        https://docs.aws.amazon.com/drs/latest/userguide/drs-apis.html

        :stability: experimental
        '''
        return typing.cast("Drs", jsii.invoke(self, "toGetSuggestedFailbackClientDeviceMappingForDrs", []))

    @jsii.member(jsii_name="toInitializeService")
    def to_initialize_service(self) -> "Drs":
        '''(experimental) Grants permission to initialize service.

        Access Level: Write

        Dependent actions:

        - iam:AddRoleToInstanceProfile
        - iam:CreateInstanceProfile
        - iam:CreateServiceLinkedRole
        - iam:GetInstanceProfile

        https://docs.aws.amazon.com/drs/latest/APIReference/API_InitializeService.html

        :stability: experimental
        '''
        return typing.cast("Drs", jsii.invoke(self, "toInitializeService", []))

    @jsii.member(jsii_name="toIssueAgentCertificateForDrs")
    def to_issue_agent_certificate_for_drs(self) -> "Drs":
        '''(experimental) Grants permission to issue an agent certificate.

        Access Level: Write

        https://docs.aws.amazon.com/drs/latest/userguide/drs-apis.html

        :stability: experimental
        '''
        return typing.cast("Drs", jsii.invoke(self, "toIssueAgentCertificateForDrs", []))

    @jsii.member(jsii_name="toListExtensibleSourceServers")
    def to_list_extensible_source_servers(self) -> "Drs":
        '''(experimental) Grants permission to list extensible source servers.

        Access Level: Read

        Dependent actions:

        - drs:DescribeSourceServers

        https://docs.aws.amazon.com/drs/latest/APIReference/API_ListExtensibleSourceServers.html

        :stability: experimental
        '''
        return typing.cast("Drs", jsii.invoke(self, "toListExtensibleSourceServers", []))

    @jsii.member(jsii_name="toListStagingAccounts")
    def to_list_staging_accounts(self) -> "Drs":
        '''(experimental) Grants permission to list staging accounts.

        Access Level: Read

        https://docs.aws.amazon.com/drs/latest/APIReference/API_ListStagingAccounts.html

        :stability: experimental
        '''
        return typing.cast("Drs", jsii.invoke(self, "toListStagingAccounts", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Drs":
        '''(experimental) Grants permission to list tags for a resource.

        Access Level: Read

        https://docs.aws.amazon.com/drs/latest/APIReference/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("Drs", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toNotifyAgentAuthenticationForDrs")
    def to_notify_agent_authentication_for_drs(self) -> "Drs":
        '''(experimental) Grants permission to notify agent authentication.

        Access Level: Write

        https://docs.aws.amazon.com/drs/latest/userguide/drs-apis.html

        :stability: experimental
        '''
        return typing.cast("Drs", jsii.invoke(self, "toNotifyAgentAuthenticationForDrs", []))

    @jsii.member(jsii_name="toNotifyAgentConnectedForDrs")
    def to_notify_agent_connected_for_drs(self) -> "Drs":
        '''(experimental) Grants permission to notify agent is connected.

        Access Level: Write

        https://docs.aws.amazon.com/drs/latest/userguide/drs-apis.html

        :stability: experimental
        '''
        return typing.cast("Drs", jsii.invoke(self, "toNotifyAgentConnectedForDrs", []))

    @jsii.member(jsii_name="toNotifyAgentDisconnectedForDrs")
    def to_notify_agent_disconnected_for_drs(self) -> "Drs":
        '''(experimental) Grants permission to notify agent is disconnected.

        Access Level: Write

        https://docs.aws.amazon.com/drs/latest/userguide/drs-apis.html

        :stability: experimental
        '''
        return typing.cast("Drs", jsii.invoke(self, "toNotifyAgentDisconnectedForDrs", []))

    @jsii.member(jsii_name="toNotifyAgentReplicationProgressForDrs")
    def to_notify_agent_replication_progress_for_drs(self) -> "Drs":
        '''(experimental) Grants permission to notify agent replication progress.

        Access Level: Write

        https://docs.aws.amazon.com/drs/latest/userguide/drs-apis.html

        :stability: experimental
        '''
        return typing.cast("Drs", jsii.invoke(self, "toNotifyAgentReplicationProgressForDrs", []))

    @jsii.member(jsii_name="toNotifyConsistencyAttainedForDrs")
    def to_notify_consistency_attained_for_drs(self) -> "Drs":
        '''(experimental) Grants permission to notify consistency attained.

        Access Level: Write

        https://docs.aws.amazon.com/drs/latest/userguide/drs-apis.html

        :stability: experimental
        '''
        return typing.cast("Drs", jsii.invoke(self, "toNotifyConsistencyAttainedForDrs", []))

    @jsii.member(jsii_name="toNotifyReplicationServerAuthenticationForDrs")
    def to_notify_replication_server_authentication_for_drs(self) -> "Drs":
        '''(experimental) Grants permission to notify replication server authentication.

        Access Level: Write

        https://docs.aws.amazon.com/drs/latest/userguide/drs-apis.html

        :stability: experimental
        '''
        return typing.cast("Drs", jsii.invoke(self, "toNotifyReplicationServerAuthenticationForDrs", []))

    @jsii.member(jsii_name="toNotifyVolumeEventForDrs")
    def to_notify_volume_event_for_drs(self) -> "Drs":
        '''(experimental) Grants permission to notify replicator volume events.

        Access Level: Write

        https://docs.aws.amazon.com/drs/latest/userguide/drs-apis.html

        :stability: experimental
        '''
        return typing.cast("Drs", jsii.invoke(self, "toNotifyVolumeEventForDrs", []))

    @jsii.member(jsii_name="toRetryDataReplication")
    def to_retry_data_replication(self) -> "Drs":
        '''(experimental) Grants permission to retry data replication.

        Access Level: Write

        https://docs.aws.amazon.com/drs/latest/APIReference/API_RetryDataReplication.html

        :stability: experimental
        '''
        return typing.cast("Drs", jsii.invoke(self, "toRetryDataReplication", []))

    @jsii.member(jsii_name="toReverseReplication")
    def to_reverse_replication(self) -> "Drs":
        '''(experimental) Grants permission to reverse replication.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - drs:DescribeReplicationConfigurationTemplates
        - drs:DescribeSourceServers
        - ec2:DescribeInstances

        https://docs.aws.amazon.com/drs/latest/APIReference/API_ReverseReplication.html

        :stability: experimental
        '''
        return typing.cast("Drs", jsii.invoke(self, "toReverseReplication", []))

    @jsii.member(jsii_name="toSendAgentLogsForDrs")
    def to_send_agent_logs_for_drs(self) -> "Drs":
        '''(experimental) Grants permission to send agent logs.

        Access Level: Write

        https://docs.aws.amazon.com/drs/latest/userguide/drs-apis.html

        :stability: experimental
        '''
        return typing.cast("Drs", jsii.invoke(self, "toSendAgentLogsForDrs", []))

    @jsii.member(jsii_name="toSendAgentMetricsForDrs")
    def to_send_agent_metrics_for_drs(self) -> "Drs":
        '''(experimental) Grants permission to send agent metrics.

        Access Level: Write

        https://docs.aws.amazon.com/drs/latest/userguide/drs-apis.html

        :stability: experimental
        '''
        return typing.cast("Drs", jsii.invoke(self, "toSendAgentMetricsForDrs", []))

    @jsii.member(jsii_name="toSendChannelCommandResultForDrs")
    def to_send_channel_command_result_for_drs(self) -> "Drs":
        '''(experimental) Grants permission to send channel command result.

        Access Level: Write

        https://docs.aws.amazon.com/drs/latest/userguide/drs-apis.html

        :stability: experimental
        '''
        return typing.cast("Drs", jsii.invoke(self, "toSendChannelCommandResultForDrs", []))

    @jsii.member(jsii_name="toSendClientLogsForDrs")
    def to_send_client_logs_for_drs(self) -> "Drs":
        '''(experimental) Grants permission to send client logs.

        Access Level: Write

        https://docs.aws.amazon.com/drs/latest/userguide/drs-apis.html

        :stability: experimental
        '''
        return typing.cast("Drs", jsii.invoke(self, "toSendClientLogsForDrs", []))

    @jsii.member(jsii_name="toSendClientMetricsForDrs")
    def to_send_client_metrics_for_drs(self) -> "Drs":
        '''(experimental) Grants permission to send client metrics.

        Access Level: Write

        https://docs.aws.amazon.com/drs/latest/userguide/drs-apis.html

        :stability: experimental
        '''
        return typing.cast("Drs", jsii.invoke(self, "toSendClientMetricsForDrs", []))

    @jsii.member(jsii_name="toSendVolumeStatsForDrs")
    def to_send_volume_stats_for_drs(self) -> "Drs":
        '''(experimental) Grants permission to send volume throughput statistics.

        Access Level: Write

        https://docs.aws.amazon.com/drs/latest/userguide/drs-apis.html

        :stability: experimental
        '''
        return typing.cast("Drs", jsii.invoke(self, "toSendVolumeStatsForDrs", []))

    @jsii.member(jsii_name="toStartFailbackLaunch")
    def to_start_failback_launch(self) -> "Drs":
        '''(experimental) Grants permission to start failback launch.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/drs/latest/APIReference/API_StartFailbackLaunch.html

        :stability: experimental
        '''
        return typing.cast("Drs", jsii.invoke(self, "toStartFailbackLaunch", []))

    @jsii.member(jsii_name="toStartRecovery")
    def to_start_recovery(self) -> "Drs":
        '''(experimental) Grants permission to start recovery.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - drs:CreateRecoveryInstanceForDrs
        - drs:ListTagsForResource
        - ec2:AttachVolume
        - ec2:AuthorizeSecurityGroupEgress
        - ec2:AuthorizeSecurityGroupIngress
        - ec2:CreateLaunchTemplate
        - ec2:CreateLaunchTemplateVersion
        - ec2:CreateSnapshot
        - ec2:CreateTags
        - ec2:CreateVolume
        - ec2:DeleteLaunchTemplateVersions
        - ec2:DeleteSnapshot
        - ec2:DeleteVolume
        - ec2:DescribeAccountAttributes
        - ec2:DescribeAvailabilityZones
        - ec2:DescribeImages
        - ec2:DescribeInstanceAttribute
        - ec2:DescribeInstanceStatus
        - ec2:DescribeInstanceTypes
        - ec2:DescribeInstances
        - ec2:DescribeLaunchTemplateVersions
        - ec2:DescribeLaunchTemplates
        - ec2:DescribeSecurityGroups
        - ec2:DescribeSnapshots
        - ec2:DescribeSubnets
        - ec2:DescribeVolumes
        - ec2:DetachVolume
        - ec2:ModifyInstanceAttribute
        - ec2:ModifyLaunchTemplate
        - ec2:RevokeSecurityGroupEgress
        - ec2:RunInstances
        - ec2:StartInstances
        - ec2:StopInstances
        - ec2:TerminateInstances
        - iam:PassRole

        https://docs.aws.amazon.com/drs/latest/APIReference/API_StartRecovery.html

        :stability: experimental
        '''
        return typing.cast("Drs", jsii.invoke(self, "toStartRecovery", []))

    @jsii.member(jsii_name="toStartReplication")
    def to_start_replication(self) -> "Drs":
        '''(experimental) Grants permission to start replication.

        Access Level: Write

        https://docs.aws.amazon.com/drs/latest/APIReference/API_StartReplication.html

        :stability: experimental
        '''
        return typing.cast("Drs", jsii.invoke(self, "toStartReplication", []))

    @jsii.member(jsii_name="toStopFailback")
    def to_stop_failback(self) -> "Drs":
        '''(experimental) Grants permission to stop failback.

        Access Level: Write

        https://docs.aws.amazon.com/drs/latest/APIReference/API_StopFailback.html

        :stability: experimental
        '''
        return typing.cast("Drs", jsii.invoke(self, "toStopFailback", []))

    @jsii.member(jsii_name="toStopReplication")
    def to_stop_replication(self) -> "Drs":
        '''(experimental) Grants permission to stop replication.

        Access Level: Write

        https://docs.aws.amazon.com/drs/latest/APIReference/API_StopReplication.html

        :stability: experimental
        '''
        return typing.cast("Drs", jsii.invoke(self, "toStopReplication", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Drs":
        '''(experimental) Grants permission to assign a resource tag.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifCreateAction()

        https://docs.aws.amazon.com/drs/latest/APIReference/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("Drs", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toTerminateRecoveryInstances")
    def to_terminate_recovery_instances(self) -> "Drs":
        '''(experimental) Grants permission to terminate recovery instances.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - drs:DescribeSourceServers
        - ec2:DeleteVolume
        - ec2:DescribeInstances
        - ec2:DescribeVolumes
        - ec2:TerminateInstances

        https://docs.aws.amazon.com/drs/latest/APIReference/API_TerminateRecoveryInstances.html

        :stability: experimental
        '''
        return typing.cast("Drs", jsii.invoke(self, "toTerminateRecoveryInstances", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Drs":
        '''(experimental) Grants permission to untag a resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/drs/latest/APIReference/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("Drs", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateAgentBacklogForDrs")
    def to_update_agent_backlog_for_drs(self) -> "Drs":
        '''(experimental) Grants permission to update agent backlog.

        Access Level: Write

        https://docs.aws.amazon.com/drs/latest/userguide/drs-apis.html

        :stability: experimental
        '''
        return typing.cast("Drs", jsii.invoke(self, "toUpdateAgentBacklogForDrs", []))

    @jsii.member(jsii_name="toUpdateAgentConversionInfoForDrs")
    def to_update_agent_conversion_info_for_drs(self) -> "Drs":
        '''(experimental) Grants permission to update agent conversion info.

        Access Level: Write

        https://docs.aws.amazon.com/drs/latest/userguide/drs-apis.html

        :stability: experimental
        '''
        return typing.cast("Drs", jsii.invoke(self, "toUpdateAgentConversionInfoForDrs", []))

    @jsii.member(jsii_name="toUpdateAgentReplicationInfoForDrs")
    def to_update_agent_replication_info_for_drs(self) -> "Drs":
        '''(experimental) Grants permission to update agent replication info.

        Access Level: Write

        https://docs.aws.amazon.com/drs/latest/userguide/drs-apis.html

        :stability: experimental
        '''
        return typing.cast("Drs", jsii.invoke(self, "toUpdateAgentReplicationInfoForDrs", []))

    @jsii.member(jsii_name="toUpdateAgentReplicationProcessStateForDrs")
    def to_update_agent_replication_process_state_for_drs(self) -> "Drs":
        '''(experimental) Grants permission to update agent replication process state.

        Access Level: Write

        https://docs.aws.amazon.com/drs/latest/userguide/drs-apis.html

        :stability: experimental
        '''
        return typing.cast("Drs", jsii.invoke(self, "toUpdateAgentReplicationProcessStateForDrs", []))

    @jsii.member(jsii_name="toUpdateAgentSourcePropertiesForDrs")
    def to_update_agent_source_properties_for_drs(self) -> "Drs":
        '''(experimental) Grants permission to update agent source properties.

        Access Level: Write

        https://docs.aws.amazon.com/drs/latest/userguide/drs-apis.html

        :stability: experimental
        '''
        return typing.cast("Drs", jsii.invoke(self, "toUpdateAgentSourcePropertiesForDrs", []))

    @jsii.member(jsii_name="toUpdateFailbackClientDeviceMappingForDrs")
    def to_update_failback_client_device_mapping_for_drs(self) -> "Drs":
        '''(experimental) Grants permission to update failback client device mapping.

        Access Level: Write

        https://docs.aws.amazon.com/drs/latest/userguide/drs-apis.html

        :stability: experimental
        '''
        return typing.cast("Drs", jsii.invoke(self, "toUpdateFailbackClientDeviceMappingForDrs", []))

    @jsii.member(jsii_name="toUpdateFailbackClientLastSeenForDrs")
    def to_update_failback_client_last_seen_for_drs(self) -> "Drs":
        '''(experimental) Grants permission to update failback client last seen.

        Access Level: Write

        https://docs.aws.amazon.com/drs/latest/userguide/drs-apis.html

        :stability: experimental
        '''
        return typing.cast("Drs", jsii.invoke(self, "toUpdateFailbackClientLastSeenForDrs", []))

    @jsii.member(jsii_name="toUpdateFailbackReplicationConfiguration")
    def to_update_failback_replication_configuration(self) -> "Drs":
        '''(experimental) Grants permission to update failback replication configuration.

        Access Level: Write

        https://docs.aws.amazon.com/drs/latest/APIReference/API_UpdateFailbackReplicationConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Drs", jsii.invoke(self, "toUpdateFailbackReplicationConfiguration", []))

    @jsii.member(jsii_name="toUpdateLaunchConfiguration")
    def to_update_launch_configuration(self) -> "Drs":
        '''(experimental) Grants permission to update launch configuration.

        Access Level: Write

        https://docs.aws.amazon.com/drs/latest/APIReference/API_UpdateLaunchConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Drs", jsii.invoke(self, "toUpdateLaunchConfiguration", []))

    @jsii.member(jsii_name="toUpdateReplicationCertificateForDrs")
    def to_update_replication_certificate_for_drs(self) -> "Drs":
        '''(experimental) Grants permission to update a replication certificate.

        Access Level: Write

        https://docs.aws.amazon.com/drs/latest/userguide/drs-apis.html

        :stability: experimental
        '''
        return typing.cast("Drs", jsii.invoke(self, "toUpdateReplicationCertificateForDrs", []))

    @jsii.member(jsii_name="toUpdateReplicationConfiguration")
    def to_update_replication_configuration(self) -> "Drs":
        '''(experimental) Grants permission to update replication configuration.

        Access Level: Write

        Dependent actions:

        - ec2:CreateSecurityGroup
        - ec2:DescribeSecurityGroups
        - ec2:DescribeSubnets
        - ec2:GetEbsDefaultKmsKeyId
        - ec2:GetEbsEncryptionByDefault
        - kms:CreateGrant
        - kms:DescribeKey

        https://docs.aws.amazon.com/drs/latest/APIReference/API_UpdateReplicationConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Drs", jsii.invoke(self, "toUpdateReplicationConfiguration", []))

    @jsii.member(jsii_name="toUpdateReplicationConfigurationTemplate")
    def to_update_replication_configuration_template(self) -> "Drs":
        '''(experimental) Grants permission to update replication configuration template.

        Access Level: Write

        Dependent actions:

        - ec2:CreateSecurityGroup
        - ec2:DescribeSecurityGroups
        - ec2:DescribeSubnets
        - ec2:GetEbsDefaultKmsKeyId
        - ec2:GetEbsEncryptionByDefault
        - kms:CreateGrant
        - kms:DescribeKey

        https://docs.aws.amazon.com/drs/latest/APIReference/API_UpdateReplicationConfigurationTemplate.html

        :stability: experimental
        '''
        return typing.cast("Drs", jsii.invoke(self, "toUpdateReplicationConfigurationTemplate", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5f2d711f406fbc877afd19337c05236a9def7f5417627ee48d8d7ffe73cb7c54)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__439cd2aff3b488039d90bde9393f5e051de716fc4eb3bdc95e39ed1372b15977)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Ds(PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Ds"):
    '''(experimental) Statement provider for service `ds <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsdirectoryservice.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `ds <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsdirectoryservice.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onDirectory")
    def on_directory(
        self,
        directory_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Ds":
        '''(experimental) Adds a resource of type directory to the statement.

        https://docs.aws.amazon.com/directoryservice/latest/devguide/welcome.html

        :param directory_id: - Identifier for the directoryId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__56125b7f47133b6023d785b2665b5e66c557e86be724c498b220e9b3b106e849)
            check_type(argname="argument directory_id", value=directory_id, expected_type=type_hints["directory_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Ds", jsii.invoke(self, "onDirectory", [directory_id, account, region, partition]))

    @jsii.member(jsii_name="toAcceptSharedDirectory")
    def to_accept_shared_directory(self) -> "Ds":
        '''(experimental) Grants permission to accept a directory sharing request that was sent from the directory owner account.

        Access Level: Write

        https://docs.aws.amazon.com/directoryservice/latest/devguide/API_AcceptSharedDirectory.html

        :stability: experimental
        '''
        return typing.cast("Ds", jsii.invoke(self, "toAcceptSharedDirectory", []))

    @jsii.member(jsii_name="toAddIpRoutes")
    def to_add_ip_routes(self) -> "Ds":
        '''(experimental) Grants permission to add a CIDR address block to correctly route traffic to and from your Microsoft AD on Amazon Web Services.

        Access Level: Write

        Dependent actions:

        - ec2:AuthorizeSecurityGroupEgress
        - ec2:AuthorizeSecurityGroupIngress
        - ec2:DescribeSecurityGroups

        https://docs.aws.amazon.com/directoryservice/latest/devguide/API_AddIpRoutes.html

        :stability: experimental
        '''
        return typing.cast("Ds", jsii.invoke(self, "toAddIpRoutes", []))

    @jsii.member(jsii_name="toAddRegion")
    def to_add_region(self) -> "Ds":
        '''(experimental) Grants permission to add two domain controllers in the specified Region for the specified directory.

        Access Level: Write

        https://docs.aws.amazon.com/directoryservice/latest/devguide/API_AddRegion.html

        :stability: experimental
        '''
        return typing.cast("Ds", jsii.invoke(self, "toAddRegion", []))

    @jsii.member(jsii_name="toAddTagsToResource")
    def to_add_tags_to_resource(self) -> "Ds":
        '''(experimental) Grants permission to add or overwrite one or more tags for the specified Amazon Directory Services directory.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - ec2:CreateTags

        https://docs.aws.amazon.com/directoryservice/latest/devguide/API_AddTagsToResource.html

        :stability: experimental
        '''
        return typing.cast("Ds", jsii.invoke(self, "toAddTagsToResource", []))

    @jsii.member(jsii_name="toAuthorizeApplication")
    def to_authorize_application(self) -> "Ds":
        '''(experimental) Grants permission to authorize an application for your AWS Directory.

        Access Level: Write

        :stability: experimental
        '''
        return typing.cast("Ds", jsii.invoke(self, "toAuthorizeApplication", []))

    @jsii.member(jsii_name="toCancelSchemaExtension")
    def to_cancel_schema_extension(self) -> "Ds":
        '''(experimental) Grants permission to cancel an in-progress schema extension to a Microsoft AD directory.

        Access Level: Write

        https://docs.aws.amazon.com/directoryservice/latest/devguide/API_CancelSchemaExtension.html

        :stability: experimental
        '''
        return typing.cast("Ds", jsii.invoke(self, "toCancelSchemaExtension", []))

    @jsii.member(jsii_name="toCheckAlias")
    def to_check_alias(self) -> "Ds":
        '''(experimental) Grants permission to verify that the alias is available for use.

        Access Level: Read

        :stability: experimental
        '''
        return typing.cast("Ds", jsii.invoke(self, "toCheckAlias", []))

    @jsii.member(jsii_name="toConnectDirectory")
    def to_connect_directory(self) -> "Ds":
        '''(experimental) Grants permission to create an AD Connector to connect to an on-premises directory.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - ec2:AuthorizeSecurityGroupEgress
        - ec2:AuthorizeSecurityGroupIngress
        - ec2:CreateNetworkInterface
        - ec2:CreateSecurityGroup
        - ec2:CreateTags
        - ec2:DescribeNetworkInterfaces
        - ec2:DescribeSubnets
        - ec2:DescribeVpcs

        https://docs.aws.amazon.com/directoryservice/latest/devguide/API_ConnectDirectory.html

        :stability: experimental
        '''
        return typing.cast("Ds", jsii.invoke(self, "toConnectDirectory", []))

    @jsii.member(jsii_name="toCreateAlias")
    def to_create_alias(self) -> "Ds":
        '''(experimental) Grants permission to create an alias for a directory and assigns the alias to the directory.

        Access Level: Write

        https://docs.aws.amazon.com/directoryservice/latest/devguide/API_CreateAlias.html

        :stability: experimental
        '''
        return typing.cast("Ds", jsii.invoke(self, "toCreateAlias", []))

    @jsii.member(jsii_name="toCreateComputer")
    def to_create_computer(self) -> "Ds":
        '''(experimental) Grants permission to create a computer account in the specified directory, and joins the computer to the directory.

        Access Level: Write

        https://docs.aws.amazon.com/directoryservice/latest/devguide/API_CreateComputer.html

        :stability: experimental
        '''
        return typing.cast("Ds", jsii.invoke(self, "toCreateComputer", []))

    @jsii.member(jsii_name="toCreateConditionalForwarder")
    def to_create_conditional_forwarder(self) -> "Ds":
        '''(experimental) Grants permission to create a conditional forwarder associated with your AWS directory.

        Access Level: Write

        https://docs.aws.amazon.com/directoryservice/latest/devguide/API_CreateConditionalForwarder.html

        :stability: experimental
        '''
        return typing.cast("Ds", jsii.invoke(self, "toCreateConditionalForwarder", []))

    @jsii.member(jsii_name="toCreateDirectory")
    def to_create_directory(self) -> "Ds":
        '''(experimental) Grants permission to create a Simple AD directory.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - ec2:AuthorizeSecurityGroupEgress
        - ec2:AuthorizeSecurityGroupIngress
        - ec2:CreateNetworkInterface
        - ec2:CreateSecurityGroup
        - ec2:CreateTags
        - ec2:DescribeNetworkInterfaces
        - ec2:DescribeSubnets
        - ec2:DescribeVpcs

        https://docs.aws.amazon.com/directoryservice/latest/devguide/API_CreateDirectory.html

        :stability: experimental
        '''
        return typing.cast("Ds", jsii.invoke(self, "toCreateDirectory", []))

    @jsii.member(jsii_name="toCreateIdentityPoolDirectory")
    def to_create_identity_pool_directory(self) -> "Ds":
        '''(experimental) Grants permission to create an IdentityPool Directory in the AWS cloud.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        :stability: experimental
        '''
        return typing.cast("Ds", jsii.invoke(self, "toCreateIdentityPoolDirectory", []))

    @jsii.member(jsii_name="toCreateLogSubscription")
    def to_create_log_subscription(self) -> "Ds":
        '''(experimental) Grants permission to create a subscription to forward real time Directory Service domain controller security logs to the specified CloudWatch log group in your AWS account.

        Access Level: Write

        https://docs.aws.amazon.com/directoryservice/latest/devguide/API_CreateLogSubscription.html

        :stability: experimental
        '''
        return typing.cast("Ds", jsii.invoke(self, "toCreateLogSubscription", []))

    @jsii.member(jsii_name="toCreateMicrosoftAD")
    def to_create_microsoft_ad(self) -> "Ds":
        '''(experimental) Grants permission to create a Microsoft AD in the AWS cloud.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - ec2:AuthorizeSecurityGroupEgress
        - ec2:AuthorizeSecurityGroupIngress
        - ec2:CreateNetworkInterface
        - ec2:CreateSecurityGroup
        - ec2:CreateTags
        - ec2:DescribeNetworkInterfaces
        - ec2:DescribeSubnets
        - ec2:DescribeVpcs

        https://docs.aws.amazon.com/directoryservice/latest/devguide/API_CreateMicrosoftAD.html

        :stability: experimental
        '''
        return typing.cast("Ds", jsii.invoke(self, "toCreateMicrosoftAD", []))

    @jsii.member(jsii_name="toCreateSnapshot")
    def to_create_snapshot(self) -> "Ds":
        '''(experimental) Grants permission to create a snapshot of a Simple AD or Microsoft AD directory in the AWS cloud.

        Access Level: Write

        https://docs.aws.amazon.com/directoryservice/latest/devguide/API_CreateSnapshot.html

        :stability: experimental
        '''
        return typing.cast("Ds", jsii.invoke(self, "toCreateSnapshot", []))

    @jsii.member(jsii_name="toCreateTrust")
    def to_create_trust(self) -> "Ds":
        '''(experimental) Grants permission to initiate the creation of the AWS side of a trust relationship between a Microsoft AD in the AWS cloud and an external domain.

        Access Level: Write

        https://docs.aws.amazon.com/directoryservice/latest/devguide/API_CreateTrust.html

        :stability: experimental
        '''
        return typing.cast("Ds", jsii.invoke(self, "toCreateTrust", []))

    @jsii.member(jsii_name="toDeleteConditionalForwarder")
    def to_delete_conditional_forwarder(self) -> "Ds":
        '''(experimental) Grants permission to delete a conditional forwarder that has been set up for your AWS directory.

        Access Level: Write

        https://docs.aws.amazon.com/directoryservice/latest/devguide/API_DeleteConditionalForwarder.html

        :stability: experimental
        '''
        return typing.cast("Ds", jsii.invoke(self, "toDeleteConditionalForwarder", []))

    @jsii.member(jsii_name="toDeleteDirectory")
    def to_delete_directory(self) -> "Ds":
        '''(experimental) Grants permission to delete an AWS Directory Service directory.

        Access Level: Write

        Dependent actions:

        - ec2:DeleteNetworkInterface
        - ec2:DeleteSecurityGroup
        - ec2:DescribeNetworkInterfaces
        - ec2:RevokeSecurityGroupEgress
        - ec2:RevokeSecurityGroupIngress

        https://docs.aws.amazon.com/directoryservice/latest/devguide/API_DeleteDirectory.html

        :stability: experimental
        '''
        return typing.cast("Ds", jsii.invoke(self, "toDeleteDirectory", []))

    @jsii.member(jsii_name="toDeleteLogSubscription")
    def to_delete_log_subscription(self) -> "Ds":
        '''(experimental) Grants permission to delete the specified log subscription.

        Access Level: Write

        https://docs.aws.amazon.com/directoryservice/latest/devguide/API_DeleteLogSubscription.html

        :stability: experimental
        '''
        return typing.cast("Ds", jsii.invoke(self, "toDeleteLogSubscription", []))

    @jsii.member(jsii_name="toDeleteSnapshot")
    def to_delete_snapshot(self) -> "Ds":
        '''(experimental) Grants permission to delete a directory snapshot.

        Access Level: Write

        https://docs.aws.amazon.com/directoryservice/latest/devguide/API_DeleteSnapshot.html

        :stability: experimental
        '''
        return typing.cast("Ds", jsii.invoke(self, "toDeleteSnapshot", []))

    @jsii.member(jsii_name="toDeleteTrust")
    def to_delete_trust(self) -> "Ds":
        '''(experimental) Grants permission to delete an existing trust relationship between your Microsoft AD in the AWS cloud and an external domain.

        Access Level: Write

        https://docs.aws.amazon.com/directoryservice/latest/devguide/DeleteTrust.html

        :stability: experimental
        '''
        return typing.cast("Ds", jsii.invoke(self, "toDeleteTrust", []))

    @jsii.member(jsii_name="toDeregisterCertificate")
    def to_deregister_certificate(self) -> "Ds":
        '''(experimental) Grants permission to delete from the system the certificate that was registered for a secured LDAP connection.

        Access Level: Write

        https://docs.aws.amazon.com/directoryservice/latest/devguide/API_DeregisterCertificate.html

        :stability: experimental
        '''
        return typing.cast("Ds", jsii.invoke(self, "toDeregisterCertificate", []))

    @jsii.member(jsii_name="toDeregisterEventTopic")
    def to_deregister_event_topic(self) -> "Ds":
        '''(experimental) Grants permission to remove the specified directory as a publisher to the specified SNS topic.

        Access Level: Write

        https://docs.aws.amazon.com/directoryservice/latest/devguide/API_DeregisterEventTopic.html

        :stability: experimental
        '''
        return typing.cast("Ds", jsii.invoke(self, "toDeregisterEventTopic", []))

    @jsii.member(jsii_name="toDescribeCertificate")
    def to_describe_certificate(self) -> "Ds":
        '''(experimental) Grants permission to display information about the certificate registered for a secured LDAP connection.

        Access Level: Read

        https://docs.aws.amazon.com/directoryservice/latest/devguide/API_DescribeCertificate.html

        :stability: experimental
        '''
        return typing.cast("Ds", jsii.invoke(self, "toDescribeCertificate", []))

    @jsii.member(jsii_name="toDescribeClientAuthenticationSettings")
    def to_describe_client_authentication_settings(self) -> "Ds":
        '''(experimental) Grants permission to retrieve information about the type of client authentication for the specified directory, if the type is specified.

        If no type is specified, information about all client authentication types that are supported for the specified directory is retrieved. Currently, only SmartCard is supported

        Access Level: Read

        https://docs.aws.amazon.com/directoryservice/latest/devguide/API_DescribeClientAuthenticationSettings.html

        :stability: experimental
        '''
        return typing.cast("Ds", jsii.invoke(self, "toDescribeClientAuthenticationSettings", []))

    @jsii.member(jsii_name="toDescribeConditionalForwarders")
    def to_describe_conditional_forwarders(self) -> "Ds":
        '''(experimental) Grants permission to obtain information about the conditional forwarders for this account.

        Access Level: Read

        https://docs.aws.amazon.com/directoryservice/latest/devguide/API_DescribeConditionalForwarders.html

        :stability: experimental
        '''
        return typing.cast("Ds", jsii.invoke(self, "toDescribeConditionalForwarders", []))

    @jsii.member(jsii_name="toDescribeDirectories")
    def to_describe_directories(self) -> "Ds":
        '''(experimental) Grants permission to obtain information about the directories that belong to this account.

        Access Level: List

        https://docs.aws.amazon.com/directoryservice/latest/devguide/API_DescribeDirectories.html

        :stability: experimental
        '''
        return typing.cast("Ds", jsii.invoke(self, "toDescribeDirectories", []))

    @jsii.member(jsii_name="toDescribeDomainControllers")
    def to_describe_domain_controllers(self) -> "Ds":
        '''(experimental) Grants permission to provide information about any domain controllers in your directory.

        Access Level: Read

        https://docs.aws.amazon.com/directoryservice/latest/devguide/API_DescribeDomainControllers.html

        :stability: experimental
        '''
        return typing.cast("Ds", jsii.invoke(self, "toDescribeDomainControllers", []))

    @jsii.member(jsii_name="toDescribeEventTopics")
    def to_describe_event_topics(self) -> "Ds":
        '''(experimental) Grants permission to obtain information about which SNS topics receive status messages from the specified directory.

        Access Level: Read

        https://docs.aws.amazon.com/directoryservice/latest/devguide/API_DescribeEventTopics.html

        :stability: experimental
        '''
        return typing.cast("Ds", jsii.invoke(self, "toDescribeEventTopics", []))

    @jsii.member(jsii_name="toDescribeLDAPSSettings")
    def to_describe_ldaps_settings(self) -> "Ds":
        '''(experimental) Grants permission to describe the status of LDAP security for the specified directory.

        Access Level: Read

        https://docs.aws.amazon.com/directoryservice/latest/devguide/API_DescribeLDAPSSettings.html

        :stability: experimental
        '''
        return typing.cast("Ds", jsii.invoke(self, "toDescribeLDAPSSettings", []))

    @jsii.member(jsii_name="toDescribeRegions")
    def to_describe_regions(self) -> "Ds":
        '''(experimental) Grants permission to provide information about the Regions that are configured for multi-Region replication.

        Access Level: Read

        https://docs.aws.amazon.com/directoryservice/latest/devguide/API_DescribeRegions.html

        :stability: experimental
        '''
        return typing.cast("Ds", jsii.invoke(self, "toDescribeRegions", []))

    @jsii.member(jsii_name="toDescribeSettings")
    def to_describe_settings(self) -> "Ds":
        '''(experimental) Grants permission to retrieve information about the configurable settings for the specified directory.

        Access Level: Read

        https://docs.aws.amazon.com/directoryservice/latest/devguide/API_DescribeSettings.html

        :stability: experimental
        '''
        return typing.cast("Ds", jsii.invoke(self, "toDescribeSettings", []))

    @jsii.member(jsii_name="toDescribeSharedDirectories")
    def to_describe_shared_directories(self) -> "Ds":
        '''(experimental) Grants permission to return the shared directories in your account.

        Access Level: Read

        https://docs.aws.amazon.com/directoryservice/latest/devguide/API_DescribeSharedDirectories.html

        :stability: experimental
        '''
        return typing.cast("Ds", jsii.invoke(self, "toDescribeSharedDirectories", []))

    @jsii.member(jsii_name="toDescribeSnapshots")
    def to_describe_snapshots(self) -> "Ds":
        '''(experimental) Grants permission to obtain information about the directory snapshots that belong to this account.

        Access Level: Read

        https://docs.aws.amazon.com/directoryservice/latest/devguide/API_DescribeSnapshots.html

        :stability: experimental
        '''
        return typing.cast("Ds", jsii.invoke(self, "toDescribeSnapshots", []))

    @jsii.member(jsii_name="toDescribeTrusts")
    def to_describe_trusts(self) -> "Ds":
        '''(experimental) Grants permission to obtain information about the trust relationships for this account.

        Access Level: Read

        https://docs.aws.amazon.com/directoryservice/latest/devguide/API_DescribeTrusts.html

        :stability: experimental
        '''
        return typing.cast("Ds", jsii.invoke(self, "toDescribeTrusts", []))

    @jsii.member(jsii_name="toDescribeUpdateDirectory")
    def to_describe_update_directory(self) -> "Ds":
        '''(experimental) Grants permission to describe the updates of a directory for a particular update type.

        Access Level: Read

        https://docs.aws.amazon.com/directoryservice/latest/devguide/API_DescribeUpdateDirectory.html

        :stability: experimental
        '''
        return typing.cast("Ds", jsii.invoke(self, "toDescribeUpdateDirectory", []))

    @jsii.member(jsii_name="toDisableClientAuthentication")
    def to_disable_client_authentication(self) -> "Ds":
        '''(experimental) Grants permission to disable alternative client authentication methods for the specified directory.

        Access Level: Write

        https://docs.aws.amazon.com/directoryservice/latest/devguide/API_DisableClientAuthentication.html

        :stability: experimental
        '''
        return typing.cast("Ds", jsii.invoke(self, "toDisableClientAuthentication", []))

    @jsii.member(jsii_name="toDisableLDAPS")
    def to_disable_ldaps(self) -> "Ds":
        '''(experimental) Grants permission to deactivate LDAP secure calls for the specified directory.

        Access Level: Write

        https://docs.aws.amazon.com/directoryservice/latest/devguide/API_DisableLDAPS.html

        :stability: experimental
        '''
        return typing.cast("Ds", jsii.invoke(self, "toDisableLDAPS", []))

    @jsii.member(jsii_name="toDisableRadius")
    def to_disable_radius(self) -> "Ds":
        '''(experimental) Grants permission to disable multi-factor authentication (MFA) with the Remote Authentication Dial In User Service (RADIUS) server for an AD Connector directory.

        Access Level: Write

        https://docs.aws.amazon.com/directoryservice/latest/devguide/API_DisableRadius.html

        :stability: experimental
        '''
        return typing.cast("Ds", jsii.invoke(self, "toDisableRadius", []))

    @jsii.member(jsii_name="toDisableSso")
    def to_disable_sso(self) -> "Ds":
        '''(experimental) Grants permission to disable single-sign on for a directory.

        Access Level: Write

        https://docs.aws.amazon.com/directoryservice/latest/devguide/API_DisableSso.html

        :stability: experimental
        '''
        return typing.cast("Ds", jsii.invoke(self, "toDisableSso", []))

    @jsii.member(jsii_name="toEnableClientAuthentication")
    def to_enable_client_authentication(self) -> "Ds":
        '''(experimental) Grants permission to enable alternative client authentication methods for the specified directory.

        Access Level: Write

        https://docs.aws.amazon.com/directoryservice/latest/devguide/API_EnableClientAuthentication.html

        :stability: experimental
        '''
        return typing.cast("Ds", jsii.invoke(self, "toEnableClientAuthentication", []))

    @jsii.member(jsii_name="toEnableLDAPS")
    def to_enable_ldaps(self) -> "Ds":
        '''(experimental) Grants permission to activate the switch for the specific directory to always use LDAP secure calls.

        Access Level: Write

        https://docs.aws.amazon.com/directoryservice/latest/devguide/API_EnableLDAPS.html

        :stability: experimental
        '''
        return typing.cast("Ds", jsii.invoke(self, "toEnableLDAPS", []))

    @jsii.member(jsii_name="toEnableRadius")
    def to_enable_radius(self) -> "Ds":
        '''(experimental) Grants permission to enable multi-factor authentication (MFA) with the Remote Authentication Dial In User Service (RADIUS) server for an AD Connector directory.

        Access Level: Write

        https://docs.aws.amazon.com/directoryservice/latest/devguide/API_EnableRadius.html

        :stability: experimental
        '''
        return typing.cast("Ds", jsii.invoke(self, "toEnableRadius", []))

    @jsii.member(jsii_name="toEnableSso")
    def to_enable_sso(self) -> "Ds":
        '''(experimental) Grants permission to enable single-sign on for a directory.

        Access Level: Write

        https://docs.aws.amazon.com/directoryservice/latest/devguide/API_EnableSso.html

        :stability: experimental
        '''
        return typing.cast("Ds", jsii.invoke(self, "toEnableSso", []))

    @jsii.member(jsii_name="toGetAuthorizedApplicationDetails")
    def to_get_authorized_application_details(self) -> "Ds":
        '''(experimental) Grants permission to retrieve the details of the authorized applications on a directory.

        Access Level: Read

        https://docs.aws.amazon.com/directoryservice/latest/devguide/API_GetAuthorizedApplicationDetails.html

        :stability: experimental
        '''
        return typing.cast("Ds", jsii.invoke(self, "toGetAuthorizedApplicationDetails", []))

    @jsii.member(jsii_name="toGetDirectoryLimits")
    def to_get_directory_limits(self) -> "Ds":
        '''(experimental) Grants permission to obtain directory limit information for the current region.

        Access Level: Read

        https://docs.aws.amazon.com/directoryservice/latest/devguide/API_GetDirectoryLimits.html

        :stability: experimental
        '''
        return typing.cast("Ds", jsii.invoke(self, "toGetDirectoryLimits", []))

    @jsii.member(jsii_name="toGetSnapshotLimits")
    def to_get_snapshot_limits(self) -> "Ds":
        '''(experimental) Grants permission to obtain the manual snapshot limits for a directory.

        Access Level: Read

        https://docs.aws.amazon.com/directoryservice/latest/devguide/API_GetSnapshotLimits.html

        :stability: experimental
        '''
        return typing.cast("Ds", jsii.invoke(self, "toGetSnapshotLimits", []))

    @jsii.member(jsii_name="toListAuthorizedApplications")
    def to_list_authorized_applications(self) -> "Ds":
        '''(experimental) Grants permission to obtain the AWS applications authorized for a directory.

        Access Level: Read

        :stability: experimental
        '''
        return typing.cast("Ds", jsii.invoke(self, "toListAuthorizedApplications", []))

    @jsii.member(jsii_name="toListCertificates")
    def to_list_certificates(self) -> "Ds":
        '''(experimental) Grants permission to list all the certificates registered for a secured LDAP connection, for the specified directory.

        Access Level: List

        https://docs.aws.amazon.com/directoryservice/latest/devguide/API_ListCertificates.html

        :stability: experimental
        '''
        return typing.cast("Ds", jsii.invoke(self, "toListCertificates", []))

    @jsii.member(jsii_name="toListIpRoutes")
    def to_list_ip_routes(self) -> "Ds":
        '''(experimental) Grants permission to list the address blocks that you have added to a directory.

        Access Level: Read

        https://docs.aws.amazon.com/directoryservice/latest/devguide/API_ListIpRoutes.html

        :stability: experimental
        '''
        return typing.cast("Ds", jsii.invoke(self, "toListIpRoutes", []))

    @jsii.member(jsii_name="toListLogSubscriptions")
    def to_list_log_subscriptions(self) -> "Ds":
        '''(experimental) Grants permission to list the active log subscriptions for the AWS account.

        Access Level: Read

        https://docs.aws.amazon.com/directoryservice/latest/devguide/API_ListLogSubscriptions.html

        :stability: experimental
        '''
        return typing.cast("Ds", jsii.invoke(self, "toListLogSubscriptions", []))

    @jsii.member(jsii_name="toListSchemaExtensions")
    def to_list_schema_extensions(self) -> "Ds":
        '''(experimental) Grants permission to list all schema extensions applied to a Microsoft AD Directory.

        Access Level: List

        https://docs.aws.amazon.com/directoryservice/latest/devguide/API_ListSchemaExtensions.html

        :stability: experimental
        '''
        return typing.cast("Ds", jsii.invoke(self, "toListSchemaExtensions", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Ds":
        '''(experimental) Grants permission to list all tags on an Amazon Directory Services directory.

        Access Level: Read

        https://docs.aws.amazon.com/directoryservice/latest/devguide/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("Ds", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toRegisterCertificate")
    def to_register_certificate(self) -> "Ds":
        '''(experimental) Grants permission to register a certificate for secured LDAP connection.

        Access Level: Write

        https://docs.aws.amazon.com/directoryservice/latest/devguide/API_RegisterCertificate.html

        :stability: experimental
        '''
        return typing.cast("Ds", jsii.invoke(self, "toRegisterCertificate", []))

    @jsii.member(jsii_name="toRegisterEventTopic")
    def to_register_event_topic(self) -> "Ds":
        '''(experimental) Grants permission to associate a directory with an SNS topic.

        Access Level: Write

        Dependent actions:

        - sns:GetTopicAttributes

        https://docs.aws.amazon.com/directoryservice/latest/devguide/API_RegisterEventTopic.html

        :stability: experimental
        '''
        return typing.cast("Ds", jsii.invoke(self, "toRegisterEventTopic", []))

    @jsii.member(jsii_name="toRejectSharedDirectory")
    def to_reject_shared_directory(self) -> "Ds":
        '''(experimental) Grants permission to reject a directory sharing request that was sent from the directory owner account.

        Access Level: Write

        https://docs.aws.amazon.com/directoryservice/latest/devguide/API_RejectSharedDirectory.html

        :stability: experimental
        '''
        return typing.cast("Ds", jsii.invoke(self, "toRejectSharedDirectory", []))

    @jsii.member(jsii_name="toRemoveIpRoutes")
    def to_remove_ip_routes(self) -> "Ds":
        '''(experimental) Grants permission to remove IP address blocks from a directory.

        Access Level: Write

        https://docs.aws.amazon.com/directoryservice/latest/devguide/API_RemoveIpRoutes.html

        :stability: experimental
        '''
        return typing.cast("Ds", jsii.invoke(self, "toRemoveIpRoutes", []))

    @jsii.member(jsii_name="toRemoveRegion")
    def to_remove_region(self) -> "Ds":
        '''(experimental) Grants permission to stop all replication and removes the domain controllers from the specified Region.

        You cannot remove the primary Region with this operation

        Access Level: Write

        https://docs.aws.amazon.com/directoryservice/latest/devguide/API_RemoveRegion.html

        :stability: experimental
        '''
        return typing.cast("Ds", jsii.invoke(self, "toRemoveRegion", []))

    @jsii.member(jsii_name="toRemoveTagsFromResource")
    def to_remove_tags_from_resource(self) -> "Ds":
        '''(experimental) Grants permission to remove tags from an Amazon Directory Services directory.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - ec2:DeleteTags

        https://docs.aws.amazon.com/directoryservice/latest/devguide/API_RemoveTagsFromResource.html

        :stability: experimental
        '''
        return typing.cast("Ds", jsii.invoke(self, "toRemoveTagsFromResource", []))

    @jsii.member(jsii_name="toResetUserPassword")
    def to_reset_user_password(self) -> "Ds":
        '''(experimental) Grants permission to reset the password for any user in your AWS Managed Microsoft AD or Simple AD directory.

        Access Level: Write

        https://docs.aws.amazon.com/directoryservice/latest/devguide/API_ResetUserPassword.html

        :stability: experimental
        '''
        return typing.cast("Ds", jsii.invoke(self, "toResetUserPassword", []))

    @jsii.member(jsii_name="toRestoreFromSnapshot")
    def to_restore_from_snapshot(self) -> "Ds":
        '''(experimental) Grants permission to restore a directory using an existing directory snapshot.

        Access Level: Write

        https://docs.aws.amazon.com/directoryservice/latest/devguide/API_RestoreFromSnapshot.html

        :stability: experimental
        '''
        return typing.cast("Ds", jsii.invoke(self, "toRestoreFromSnapshot", []))

    @jsii.member(jsii_name="toShareDirectory")
    def to_share_directory(self) -> "Ds":
        '''(experimental) Grants permission to share a specified directory in your AWS account (directory owner) with another AWS account (directory consumer).

        With this operation you can use your directory from any AWS account and from any Amazon VPC within an AWS Region

        Access Level: Write

        https://docs.aws.amazon.com/directoryservice/latest/devguide/API_ShareDirectory.html

        :stability: experimental
        '''
        return typing.cast("Ds", jsii.invoke(self, "toShareDirectory", []))

    @jsii.member(jsii_name="toStartSchemaExtension")
    def to_start_schema_extension(self) -> "Ds":
        '''(experimental) Grants permission to apply a schema extension to a Microsoft AD directory.

        Access Level: Write

        https://docs.aws.amazon.com/directoryservice/latest/devguide/API_StartSchemaExtension.html

        :stability: experimental
        '''
        return typing.cast("Ds", jsii.invoke(self, "toStartSchemaExtension", []))

    @jsii.member(jsii_name="toUnauthorizeApplication")
    def to_unauthorize_application(self) -> "Ds":
        '''(experimental) Grants permission to unauthorize an application from your AWS Directory.

        Access Level: Write

        :stability: experimental
        '''
        return typing.cast("Ds", jsii.invoke(self, "toUnauthorizeApplication", []))

    @jsii.member(jsii_name="toUnshareDirectory")
    def to_unshare_directory(self) -> "Ds":
        '''(experimental) Grants permission to stop the directory sharing between the directory owner and consumer accounts.

        Access Level: Write

        https://docs.aws.amazon.com/directoryservice/latest/devguide/API_UnshareDirectory.html

        :stability: experimental
        '''
        return typing.cast("Ds", jsii.invoke(self, "toUnshareDirectory", []))

    @jsii.member(jsii_name="toUpdateConditionalForwarder")
    def to_update_conditional_forwarder(self) -> "Ds":
        '''(experimental) Grants permission to update a conditional forwarder that has been set up for your AWS directory.

        Access Level: Write

        https://docs.aws.amazon.com/directoryservice/latest/devguide/API_UpdateConditionalForwarder.html

        :stability: experimental
        '''
        return typing.cast("Ds", jsii.invoke(self, "toUpdateConditionalForwarder", []))

    @jsii.member(jsii_name="toUpdateDirectorySetup")
    def to_update_directory_setup(self) -> "Ds":
        '''(experimental) Grants permission to update the directory for a particular update type.

        Access Level: Write

        https://docs.aws.amazon.com/directoryservice/latest/devguide/API_UpdateDirectorySetup.html

        :stability: experimental
        '''
        return typing.cast("Ds", jsii.invoke(self, "toUpdateDirectorySetup", []))

    @jsii.member(jsii_name="toUpdateNumberOfDomainControllers")
    def to_update_number_of_domain_controllers(self) -> "Ds":
        '''(experimental) Grants permission to add or remove domain controllers to or from the directory.

        Based on the difference between current value and new value (provided through this API call), domain controllers will be added or removed. It may take up to 45 minutes for any new domain controllers to become fully active once the requested number of domain controllers is updated. During this time, you cannot make another update request

        Access Level: Write

        https://docs.aws.amazon.com/directoryservice/latest/devguide/API_UpdateNumberOfDomainControllers.html

        :stability: experimental
        '''
        return typing.cast("Ds", jsii.invoke(self, "toUpdateNumberOfDomainControllers", []))

    @jsii.member(jsii_name="toUpdateRadius")
    def to_update_radius(self) -> "Ds":
        '''(experimental) Grants permission to update the Remote Authentication Dial In User Service (RADIUS) server information for an AD Connector directory.

        Access Level: Write

        https://docs.aws.amazon.com/directoryservice/latest/devguide/API_UpdateRadius.html

        :stability: experimental
        '''
        return typing.cast("Ds", jsii.invoke(self, "toUpdateRadius", []))

    @jsii.member(jsii_name="toUpdateSettings")
    def to_update_settings(self) -> "Ds":
        '''(experimental) Grants permission to update the configurable settings for the specified directory.

        Access Level: Write

        https://docs.aws.amazon.com/directoryservice/latest/devguide/API_UpdateSettings.html

        :stability: experimental
        '''
        return typing.cast("Ds", jsii.invoke(self, "toUpdateSettings", []))

    @jsii.member(jsii_name="toUpdateTrust")
    def to_update_trust(self) -> "Ds":
        '''(experimental) Grants permission to update the trust that has been set up between your AWS Managed Microsoft AD directory and an on-premises Active Directory.

        Access Level: Write

        https://docs.aws.amazon.com/directoryservice/latest/devguide/API_UpdateTrust.html

        :stability: experimental
        '''
        return typing.cast("Ds", jsii.invoke(self, "toUpdateTrust", []))

    @jsii.member(jsii_name="toVerifyTrust")
    def to_verify_trust(self) -> "Ds":
        '''(experimental) Grants permission to verify a trust relationship between your Microsoft AD in the AWS cloud and an external domain.

        Access Level: Read

        https://docs.aws.amazon.com/directoryservice/latest/devguide/API_VerifyTrust.html

        :stability: experimental
        '''
        return typing.cast("Ds", jsii.invoke(self, "toVerifyTrust", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__43db3845491e40d2525118d0d31ec876fd18dd3f0ca585fde9d9ec49b66d8f17)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bfd1457459910ce11af69af40172e317bf830f791e102053f04dfa8805b2f860)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Dynamodb(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Dynamodb",
):
    '''(experimental) Statement provider for service `dynamodb <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazondynamodb.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `dynamodb <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazondynamodb.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="ifAttributes")
    def if_attributes(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Dynamodb":
        '''(experimental) Filter based on the attribute (field or column) names of the table.

        https://docs.aws.amazon.com/amazondynamodb/latest/developerguide/specifying-conditions.html#FGAC_DDB.ConditionKeys

        Applies to actions:

        - .toBatchGetItem()
        - .toBatchWriteItem()
        - .toConditionCheckItem()
        - .toDeleteItem()
        - .toGetItem()
        - .toPartiQLDelete()
        - .toPartiQLInsert()
        - .toPartiQLSelect()
        - .toPartiQLUpdate()
        - .toPutItem()
        - .toQuery()
        - .toScan()
        - .toUpdateItem()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0094abdd2847d992b0cee765c9687d5ba79d7cf0851e03ea6dc0d71f6e4ebb96)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Dynamodb", jsii.invoke(self, "ifAttributes", [value, operator]))

    @jsii.member(jsii_name="ifEnclosingOperation")
    def if_enclosing_operation(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Dynamodb":
        '''(experimental) Used to block Transactions APIs calls and allow the non-Transaction APIs calls and vice-versa.

        https://docs.aws.amazon.com/amazondynamodb/latest/developerguide/specifying-conditions.html#FGAC_DDB.ConditionKeys

        Applies to actions:

        - .toDeleteItem()
        - .toGetItem()
        - .toPartiQLDelete()
        - .toPartiQLInsert()
        - .toPartiQLSelect()
        - .toPartiQLUpdate()
        - .toPutItem()
        - .toUpdateItem()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d4a4e93ad2bc3b551d9c67ef55e3ff8a9a377a3e56d81b2644e887cd6cd797e1)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Dynamodb", jsii.invoke(self, "ifEnclosingOperation", [value, operator]))

    @jsii.member(jsii_name="ifFullTableScan")
    def if_full_table_scan(
        self,
        value: typing.Optional[builtins.bool] = None,
    ) -> "Dynamodb":
        '''(experimental) Used to block full table scan.

        https://docs.aws.amazon.com/amazondynamodb/latest/developerguide/ql-iam.html

        Applies to actions:

        - .toPartiQLSelect()

        :param value: ``true`` or ``false``. **Default:** ``true``

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c0c00a530411385f52359216490558bd5c08e4669dafee3799211f5992f4096c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast("Dynamodb", jsii.invoke(self, "ifFullTableScan", [value]))

    @jsii.member(jsii_name="ifLeadingKeys")
    def if_leading_keys(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Dynamodb":
        '''(experimental) Filters based on the partition key of the table.

        https://docs.aws.amazon.com/amazondynamodb/latest/developerguide/specifying-conditions.html#FGAC_DDB.ConditionKeys

        Applies to actions:

        - .toBatchGetItem()
        - .toBatchWriteItem()
        - .toConditionCheckItem()
        - .toDeleteItem()
        - .toGetItem()
        - .toPartiQLDelete()
        - .toPartiQLInsert()
        - .toPartiQLSelect()
        - .toPartiQLUpdate()
        - .toPutItem()
        - .toQuery()
        - .toUpdateItem()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5ecc503b3f40fdb0e678c08e280dee21c00366c8747aa5175f16c6fd841ec634)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Dynamodb", jsii.invoke(self, "ifLeadingKeys", [value, operator]))

    @jsii.member(jsii_name="ifReturnConsumedCapacity")
    def if_return_consumed_capacity(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Dynamodb":
        '''(experimental) Filter based on the ReturnConsumedCapacity parameter of a request. Contains either "TOTAL" or "NONE".

        https://docs.aws.amazon.com/amazondynamodb/latest/developerguide/specifying-conditions.html#FGAC_DDB.ConditionKeys

        Applies to actions:

        - .toBatchGetItem()
        - .toBatchWriteItem()
        - .toConditionCheckItem()
        - .toDeleteItem()
        - .toGetItem()
        - .toPutItem()
        - .toQuery()
        - .toScan()
        - .toUpdateItem()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ec933b1f83954768cc7ec3323dca7df240d68a6d53de6cb1a10e208a1dedefb4)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Dynamodb", jsii.invoke(self, "ifReturnConsumedCapacity", [value, operator]))

    @jsii.member(jsii_name="ifReturnValues")
    def if_return_values(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Dynamodb":
        '''(experimental) Filter based on the ReturnValues parameter of request. Contains one of the following: "ALL_OLD", "UPDATED_OLD","ALL_NEW","UPDATED_NEW", or "NONE".

        https://docs.aws.amazon.com/amazondynamodb/latest/developerguide/specifying-conditions.html#FGAC_DDB.ConditionKeys

        Applies to actions:

        - .toConditionCheckItem()
        - .toDeleteItem()
        - .toPartiQLDelete()
        - .toPartiQLUpdate()
        - .toPutItem()
        - .toQuery()
        - .toScan()
        - .toUpdateItem()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4b5731b027982b01dc477f5a013761658b5f78faa6f0cef3118953dc4ecf057c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Dynamodb", jsii.invoke(self, "ifReturnValues", [value, operator]))

    @jsii.member(jsii_name="ifSelect")
    def if_select(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Dynamodb":
        '''(experimental) Filter based on the Select parameter of a Query or Scan request.

        https://docs.aws.amazon.com/amazondynamodb/latest/developerguide/specifying-conditions.html#FGAC_DDB.ConditionKeys

        Applies to actions:

        - .toBatchGetItem()
        - .toGetItem()
        - .toPartiQLSelect()
        - .toQuery()
        - .toScan()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c883703965b56dae0d42137f4aea66cb41bf25273b2fe3c3dcb2c765a3849b28)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Dynamodb", jsii.invoke(self, "ifSelect", [value, operator]))

    @jsii.member(jsii_name="onBackup")
    def on_backup(
        self,
        table_name: builtins.str,
        backup_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Dynamodb":
        '''(experimental) Adds a resource of type backup to the statement.

        https://docs.aws.amazon.com/amazondynamodb/latest/developerguide/backuprestore_HowItWorks.html

        :param table_name: - Identifier for the tableName.
        :param backup_name: - Identifier for the backupName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e6e30b0926358ec558b821e0ba16ab234f33ac553955bc8e74efa5958f26b2a6)
            check_type(argname="argument table_name", value=table_name, expected_type=type_hints["table_name"])
            check_type(argname="argument backup_name", value=backup_name, expected_type=type_hints["backup_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Dynamodb", jsii.invoke(self, "onBackup", [table_name, backup_name, account, region, partition]))

    @jsii.member(jsii_name="onExport")
    def on_export(
        self,
        table_name: builtins.str,
        export_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Dynamodb":
        '''(experimental) Adds a resource of type export to the statement.

        https://docs.aws.amazon.com/amazondynamodb/latest/developerguide/S3DataExport.HowItWorks.html

        :param table_name: - Identifier for the tableName.
        :param export_name: - Identifier for the exportName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__beba8f51f9af91f7bc8218b3f3f496765f1db6160f4ea62f2952ec5fc779b969)
            check_type(argname="argument table_name", value=table_name, expected_type=type_hints["table_name"])
            check_type(argname="argument export_name", value=export_name, expected_type=type_hints["export_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Dynamodb", jsii.invoke(self, "onExport", [table_name, export_name, account, region, partition]))

    @jsii.member(jsii_name="onGlobalTable")
    def on_global_table(
        self,
        global_table_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Dynamodb":
        '''(experimental) Adds a resource of type global-table to the statement.

        https://docs.aws.amazon.com/amazondynamodb/latest/developerguide/globaltables_HowItWorks.html

        :param global_table_name: - Identifier for the globalTableName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__df516d509b2ad218b848098ac8730b9727a02350c0db1127a827ce68bcc276df)
            check_type(argname="argument global_table_name", value=global_table_name, expected_type=type_hints["global_table_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Dynamodb", jsii.invoke(self, "onGlobalTable", [global_table_name, account, partition]))

    @jsii.member(jsii_name="onImport")
    def on_import(
        self,
        table_name: builtins.str,
        import_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Dynamodb":
        '''(experimental) Adds a resource of type import to the statement.

        https://docs.aws.amazon.com/amazondynamodb/latest/developerguide/HowItWorks.CoreComponents.htmlS3DataImport.HowItWorks.html

        :param table_name: - Identifier for the tableName.
        :param import_name: - Identifier for the importName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__71e267f3829bc64f44088d63c04a8bc79156cd02b9595de65064c26f9956d7c4)
            check_type(argname="argument table_name", value=table_name, expected_type=type_hints["table_name"])
            check_type(argname="argument import_name", value=import_name, expected_type=type_hints["import_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Dynamodb", jsii.invoke(self, "onImport", [table_name, import_name, account, region, partition]))

    @jsii.member(jsii_name="onIndex")
    def on_index(
        self,
        table_name: builtins.str,
        index_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Dynamodb":
        '''(experimental) Adds a resource of type index to the statement.

        https://docs.aws.amazon.com/amazondynamodb/latest/developerguide/HowItWorks.CoreComponents.htmlHowItWorks.CoreComponents.html#HowItWorks.CoreComponents.PrimaryKey

        :param table_name: - Identifier for the tableName.
        :param index_name: - Identifier for the indexName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ec7356548561a8fe75d246d5fbff79aef1f69ece8f7f558f60a845d3f9e83df4)
            check_type(argname="argument table_name", value=table_name, expected_type=type_hints["table_name"])
            check_type(argname="argument index_name", value=index_name, expected_type=type_hints["index_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Dynamodb", jsii.invoke(self, "onIndex", [table_name, index_name, account, region, partition]))

    @jsii.member(jsii_name="onStream")
    def on_stream(
        self,
        table_name: builtins.str,
        stream_label: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Dynamodb":
        '''(experimental) Adds a resource of type stream to the statement.

        https://docs.aws.amazon.com/amazondynamodb/latest/developerguide/HowItWorks.CoreComponents.htmlHowItWorks.CoreComponents.html#HowItWorks.CoreComponents.Streams

        :param table_name: - Identifier for the tableName.
        :param stream_label: - Identifier for the streamLabel.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6370a0b4b19154ba4480800e6eca20db413b542c46c8faa975a51a430a33303a)
            check_type(argname="argument table_name", value=table_name, expected_type=type_hints["table_name"])
            check_type(argname="argument stream_label", value=stream_label, expected_type=type_hints["stream_label"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Dynamodb", jsii.invoke(self, "onStream", [table_name, stream_label, account, region, partition]))

    @jsii.member(jsii_name="onTable")
    def on_table(
        self,
        table_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Dynamodb":
        '''(experimental) Adds a resource of type table to the statement.

        https://docs.aws.amazon.com/amazondynamodb/latest/developerguide/HowItWorks.CoreComponents.htmlHowItWorks.CoreComponents.html#HowItWorks.CoreComponents.TablesItemsAttributes

        :param table_name: - Identifier for the tableName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c95e9284d6a3e8fc4d58ef1fa8412cd8564c26c292cda15eb43eebf9701295ea)
            check_type(argname="argument table_name", value=table_name, expected_type=type_hints["table_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Dynamodb", jsii.invoke(self, "onTable", [table_name, account, region, partition]))

    @jsii.member(jsii_name="toBatchGetItem")
    def to_batch_get_item(self) -> "Dynamodb":
        '''(experimental) Grants permission to return the attributes of one or more items from one or more tables.

        Access Level: Read

        Possible conditions:

        - .ifAttributes()
        - .ifLeadingKeys()
        - .ifReturnConsumedCapacity()
        - .ifSelect()

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_BatchGetItem.html

        :stability: experimental
        '''
        return typing.cast("Dynamodb", jsii.invoke(self, "toBatchGetItem", []))

    @jsii.member(jsii_name="toBatchWriteItem")
    def to_batch_write_item(self) -> "Dynamodb":
        '''(experimental) Grants permission to put or delete multiple items in one or more tables.

        Access Level: Write

        Possible conditions:

        - .ifAttributes()
        - .ifLeadingKeys()
        - .ifReturnConsumedCapacity()

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_BatchWriteItem.html

        :stability: experimental
        '''
        return typing.cast("Dynamodb", jsii.invoke(self, "toBatchWriteItem", []))

    @jsii.member(jsii_name="toConditionCheckItem")
    def to_condition_check_item(self) -> "Dynamodb":
        '''(experimental) Grants permission to the ConditionCheckItem operation checks the existence of a set of attributes for the item with the given primary key.

        Access Level: Read

        Possible conditions:

        - .ifAttributes()
        - .ifLeadingKeys()
        - .ifReturnConsumedCapacity()
        - .ifReturnValues()

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_ConditionCheckItem.html

        :stability: experimental
        '''
        return typing.cast("Dynamodb", jsii.invoke(self, "toConditionCheckItem", []))

    @jsii.member(jsii_name="toCreateBackup")
    def to_create_backup(self) -> "Dynamodb":
        '''(experimental) Grants permission to create a backup for an existing table.

        Access Level: Write

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_CreateBackup.html

        :stability: experimental
        '''
        return typing.cast("Dynamodb", jsii.invoke(self, "toCreateBackup", []))

    @jsii.member(jsii_name="toCreateGlobalTable")
    def to_create_global_table(self) -> "Dynamodb":
        '''(experimental) Grants permission to create a global table from an existing table.

        Access Level: Write

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_CreateGlobalTable.html

        :stability: experimental
        '''
        return typing.cast("Dynamodb", jsii.invoke(self, "toCreateGlobalTable", []))

    @jsii.member(jsii_name="toCreateTable")
    def to_create_table(self) -> "Dynamodb":
        '''(experimental) Grants permission to the CreateTable operation adds a new table to your account.

        Access Level: Write

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_CreateTable.html

        :stability: experimental
        '''
        return typing.cast("Dynamodb", jsii.invoke(self, "toCreateTable", []))

    @jsii.member(jsii_name="toCreateTableReplica")
    def to_create_table_replica(self) -> "Dynamodb":
        '''(experimental) Grants permission to add a new replica table.

        Access Level: Write

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/V2gt_IAM.html

        :stability: experimental
        '''
        return typing.cast("Dynamodb", jsii.invoke(self, "toCreateTableReplica", []))

    @jsii.member(jsii_name="toDeleteBackup")
    def to_delete_backup(self) -> "Dynamodb":
        '''(experimental) Grants permission to delete an existing backup of a table.

        Access Level: Write

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_DeleteBackup.html

        :stability: experimental
        '''
        return typing.cast("Dynamodb", jsii.invoke(self, "toDeleteBackup", []))

    @jsii.member(jsii_name="toDeleteItem")
    def to_delete_item(self) -> "Dynamodb":
        '''(experimental) Grants permission to deletes a single item in a table by primary key.

        Access Level: Write

        Possible conditions:

        - .ifAttributes()
        - .ifEnclosingOperation()
        - .ifLeadingKeys()
        - .ifReturnConsumedCapacity()
        - .ifReturnValues()

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_DeleteItem.html

        :stability: experimental
        '''
        return typing.cast("Dynamodb", jsii.invoke(self, "toDeleteItem", []))

    @jsii.member(jsii_name="toDeleteTable")
    def to_delete_table(self) -> "Dynamodb":
        '''(experimental) Grants permission to the DeleteTable operation which deletes a table and all of its items.

        Access Level: Write

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_DeleteTable.html

        :stability: experimental
        '''
        return typing.cast("Dynamodb", jsii.invoke(self, "toDeleteTable", []))

    @jsii.member(jsii_name="toDeleteTableReplica")
    def to_delete_table_replica(self) -> "Dynamodb":
        '''(experimental) Grants permission to delete a replica table and all of its items.

        Access Level: Write

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/V2gt_IAM.html

        :stability: experimental
        '''
        return typing.cast("Dynamodb", jsii.invoke(self, "toDeleteTableReplica", []))

    @jsii.member(jsii_name="toDescribeBackup")
    def to_describe_backup(self) -> "Dynamodb":
        '''(experimental) Grants permission to describe an existing backup of a table.

        Access Level: Read

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_DescribeBackup.html

        :stability: experimental
        '''
        return typing.cast("Dynamodb", jsii.invoke(self, "toDescribeBackup", []))

    @jsii.member(jsii_name="toDescribeContinuousBackups")
    def to_describe_continuous_backups(self) -> "Dynamodb":
        '''(experimental) Grants permission to check the status of the backup restore settings on the specified table.

        Access Level: Read

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_DescribeContinuousBackups.html

        :stability: experimental
        '''
        return typing.cast("Dynamodb", jsii.invoke(self, "toDescribeContinuousBackups", []))

    @jsii.member(jsii_name="toDescribeContributorInsights")
    def to_describe_contributor_insights(self) -> "Dynamodb":
        '''(experimental) Grants permission to describe the contributor insights status and related details for a given table or global secondary index.

        Access Level: Read

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_DescribeContributorInsights.html

        :stability: experimental
        '''
        return typing.cast("Dynamodb", jsii.invoke(self, "toDescribeContributorInsights", []))

    @jsii.member(jsii_name="toDescribeExport")
    def to_describe_export(self) -> "Dynamodb":
        '''(experimental) Grants permission to describe an existing Export of a table.

        Access Level: Read

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_DescribeExport.html

        :stability: experimental
        '''
        return typing.cast("Dynamodb", jsii.invoke(self, "toDescribeExport", []))

    @jsii.member(jsii_name="toDescribeGlobalTable")
    def to_describe_global_table(self) -> "Dynamodb":
        '''(experimental) Grants permission to return information about the specified global table.

        Access Level: Read

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_DescribeGlobalTable.html

        :stability: experimental
        '''
        return typing.cast("Dynamodb", jsii.invoke(self, "toDescribeGlobalTable", []))

    @jsii.member(jsii_name="toDescribeGlobalTableSettings")
    def to_describe_global_table_settings(self) -> "Dynamodb":
        '''(experimental) Grants permission to return settings information about the specified global table.

        Access Level: Read

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_DescribeGlobalTableSettings.html

        :stability: experimental
        '''
        return typing.cast("Dynamodb", jsii.invoke(self, "toDescribeGlobalTableSettings", []))

    @jsii.member(jsii_name="toDescribeImport")
    def to_describe_import(self) -> "Dynamodb":
        '''(experimental) Grants permission to describe an existing import.

        Access Level: Read

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_DescribeImport.html

        :stability: experimental
        '''
        return typing.cast("Dynamodb", jsii.invoke(self, "toDescribeImport", []))

    @jsii.member(jsii_name="toDescribeKinesisStreamingDestination")
    def to_describe_kinesis_streaming_destination(self) -> "Dynamodb":
        '''(experimental) Grants permission to grant permission to describe the status of Kinesis streaming and related details for a given table.

        Access Level: Read

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_DescribeKinesisStreamingDestination.html

        :stability: experimental
        '''
        return typing.cast("Dynamodb", jsii.invoke(self, "toDescribeKinesisStreamingDestination", []))

    @jsii.member(jsii_name="toDescribeLimits")
    def to_describe_limits(self) -> "Dynamodb":
        '''(experimental) Grants permission to return the current provisioned-capacity limits for your AWS account in a region, both for the region as a whole and for any one DynamoDB table that you create there.

        Access Level: Read

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_DescribeLimits.html

        :stability: experimental
        '''
        return typing.cast("Dynamodb", jsii.invoke(self, "toDescribeLimits", []))

    @jsii.member(jsii_name="toDescribeReservedCapacity")
    def to_describe_reserved_capacity(self) -> "Dynamodb":
        '''(experimental) Grants permission to describe one or more of the Reserved Capacity purchased.

        Access Level: Read

        :stability: experimental
        '''
        return typing.cast("Dynamodb", jsii.invoke(self, "toDescribeReservedCapacity", []))

    @jsii.member(jsii_name="toDescribeReservedCapacityOfferings")
    def to_describe_reserved_capacity_offerings(self) -> "Dynamodb":
        '''(experimental) Grants permission to describe Reserved Capacity offerings that are available for purchase.

        Access Level: Read

        :stability: experimental
        '''
        return typing.cast("Dynamodb", jsii.invoke(self, "toDescribeReservedCapacityOfferings", []))

    @jsii.member(jsii_name="toDescribeStream")
    def to_describe_stream(self) -> "Dynamodb":
        '''(experimental) Grants permission to return information about a stream, including the current status of the stream, its Amazon Resource Name (ARN), the composition of its shards, and its corresponding DynamoDB table.

        Access Level: Read

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_DescribeStream.html

        :stability: experimental
        '''
        return typing.cast("Dynamodb", jsii.invoke(self, "toDescribeStream", []))

    @jsii.member(jsii_name="toDescribeTable")
    def to_describe_table(self) -> "Dynamodb":
        '''(experimental) Grants permission to return information about the table.

        Access Level: Read

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_DescribeTable.html

        :stability: experimental
        '''
        return typing.cast("Dynamodb", jsii.invoke(self, "toDescribeTable", []))

    @jsii.member(jsii_name="toDescribeTableReplicaAutoScaling")
    def to_describe_table_replica_auto_scaling(self) -> "Dynamodb":
        '''(experimental) Grants permission to describe the auto scaling settings across all replicas of the global table.

        Access Level: Read

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_DescribeTableReplicaAutoScaling.html

        :stability: experimental
        '''
        return typing.cast("Dynamodb", jsii.invoke(self, "toDescribeTableReplicaAutoScaling", []))

    @jsii.member(jsii_name="toDescribeTimeToLive")
    def to_describe_time_to_live(self) -> "Dynamodb":
        '''(experimental) Grants permission to give a description of the Time to Live (TTL) status on the specified table.

        Access Level: Read

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_DescribeTimeToLive.html

        :stability: experimental
        '''
        return typing.cast("Dynamodb", jsii.invoke(self, "toDescribeTimeToLive", []))

    @jsii.member(jsii_name="toDisableKinesisStreamingDestination")
    def to_disable_kinesis_streaming_destination(self) -> "Dynamodb":
        '''(experimental) Grants permission to grant permission to stop replication from the DynamoDB table to the Kinesis data stream.

        Access Level: Write

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_DisableKinesisStreamingDestination.html

        :stability: experimental
        '''
        return typing.cast("Dynamodb", jsii.invoke(self, "toDisableKinesisStreamingDestination", []))

    @jsii.member(jsii_name="toEnableKinesisStreamingDestination")
    def to_enable_kinesis_streaming_destination(self) -> "Dynamodb":
        '''(experimental) Grants permission to grant permission to start table data replication to the specified Kinesis data stream at a timestamp chosen during the enable workflow.

        Access Level: Write

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_EnableKinesisStreamingDestination.html

        :stability: experimental
        '''
        return typing.cast("Dynamodb", jsii.invoke(self, "toEnableKinesisStreamingDestination", []))

    @jsii.member(jsii_name="toExportTableToPointInTime")
    def to_export_table_to_point_in_time(self) -> "Dynamodb":
        '''(experimental) Grants permission to initiate an Export of a DynamoDB table to S3.

        Access Level: Write

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_ExportTableToPointInTime.html

        :stability: experimental
        '''
        return typing.cast("Dynamodb", jsii.invoke(self, "toExportTableToPointInTime", []))

    @jsii.member(jsii_name="toGetItem")
    def to_get_item(self) -> "Dynamodb":
        '''(experimental) Grants permission to the GetItem operation that returns a set of attributes for the item with the given primary key.

        Access Level: Read

        Possible conditions:

        - .ifAttributes()
        - .ifEnclosingOperation()
        - .ifLeadingKeys()
        - .ifReturnConsumedCapacity()
        - .ifSelect()

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_GetItem.html

        :stability: experimental
        '''
        return typing.cast("Dynamodb", jsii.invoke(self, "toGetItem", []))

    @jsii.member(jsii_name="toGetRecords")
    def to_get_records(self) -> "Dynamodb":
        '''(experimental) Grants permission to retrieve the stream records from a given shard.

        Access Level: Read

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_GetRecords.html

        :stability: experimental
        '''
        return typing.cast("Dynamodb", jsii.invoke(self, "toGetRecords", []))

    @jsii.member(jsii_name="toGetShardIterator")
    def to_get_shard_iterator(self) -> "Dynamodb":
        '''(experimental) Grants permission to return a shard iterator.

        Access Level: Read

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_GetShardIterator.html

        :stability: experimental
        '''
        return typing.cast("Dynamodb", jsii.invoke(self, "toGetShardIterator", []))

    @jsii.member(jsii_name="toImportTable")
    def to_import_table(self) -> "Dynamodb":
        '''(experimental) Grants permission to initiate an import from S3 to a DynamoDB table.

        Access Level: Write

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_ImportTable.html

        :stability: experimental
        '''
        return typing.cast("Dynamodb", jsii.invoke(self, "toImportTable", []))

    @jsii.member(jsii_name="toListBackups")
    def to_list_backups(self) -> "Dynamodb":
        '''(experimental) Grants permission to list backups associated with the account and endpoint.

        Access Level: List

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_ListBackups.html

        :stability: experimental
        '''
        return typing.cast("Dynamodb", jsii.invoke(self, "toListBackups", []))

    @jsii.member(jsii_name="toListContributorInsights")
    def to_list_contributor_insights(self) -> "Dynamodb":
        '''(experimental) Grants permission to list the ContributorInsightsSummary for all tables and global secondary indexes associated with the current account and endpoint.

        Access Level: List

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_ListContributorInsights.html

        :stability: experimental
        '''
        return typing.cast("Dynamodb", jsii.invoke(self, "toListContributorInsights", []))

    @jsii.member(jsii_name="toListExports")
    def to_list_exports(self) -> "Dynamodb":
        '''(experimental) Grants permission to list exports associated with the account and endpoint.

        Access Level: List

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_ListExports.html

        :stability: experimental
        '''
        return typing.cast("Dynamodb", jsii.invoke(self, "toListExports", []))

    @jsii.member(jsii_name="toListGlobalTables")
    def to_list_global_tables(self) -> "Dynamodb":
        '''(experimental) Grants permission to list all global tables that have a replica in the specified region.

        Access Level: List

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_ListGlobalTables.html

        :stability: experimental
        '''
        return typing.cast("Dynamodb", jsii.invoke(self, "toListGlobalTables", []))

    @jsii.member(jsii_name="toListImports")
    def to_list_imports(self) -> "Dynamodb":
        '''(experimental) Grants permission to list imports associated with the account and endpoint.

        Access Level: List

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_ListImports.html

        :stability: experimental
        '''
        return typing.cast("Dynamodb", jsii.invoke(self, "toListImports", []))

    @jsii.member(jsii_name="toListStreams")
    def to_list_streams(self) -> "Dynamodb":
        '''(experimental) Grants permission to return an array of stream ARNs associated with the current account and endpoint.

        Access Level: Read

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_ListStreams.html

        :stability: experimental
        '''
        return typing.cast("Dynamodb", jsii.invoke(self, "toListStreams", []))

    @jsii.member(jsii_name="toListTables")
    def to_list_tables(self) -> "Dynamodb":
        '''(experimental) Grants permission to return an array of table names associated with the current account and endpoint.

        Access Level: List

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_ListTables.html

        :stability: experimental
        '''
        return typing.cast("Dynamodb", jsii.invoke(self, "toListTables", []))

    @jsii.member(jsii_name="toListTagsOfResource")
    def to_list_tags_of_resource(self) -> "Dynamodb":
        '''(experimental) Grants permission to list all tags on an Amazon DynamoDB resource.

        Access Level: Read

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_ListTagsOfResource.html

        :stability: experimental
        '''
        return typing.cast("Dynamodb", jsii.invoke(self, "toListTagsOfResource", []))

    @jsii.member(jsii_name="toPartiQLDelete")
    def to_parti_ql_delete(self) -> "Dynamodb":
        '''(experimental) Grants permission to delete a single item in a table by primary key.

        Access Level: Write

        Possible conditions:

        - .ifAttributes()
        - .ifEnclosingOperation()
        - .ifLeadingKeys()
        - .ifReturnValues()

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_ExecuteStatement.html

        :stability: experimental
        '''
        return typing.cast("Dynamodb", jsii.invoke(self, "toPartiQLDelete", []))

    @jsii.member(jsii_name="toPartiQLInsert")
    def to_parti_ql_insert(self) -> "Dynamodb":
        '''(experimental) Grants permission to create a new item, if an item with same primary key does not exist in the table.

        Access Level: Write

        Possible conditions:

        - .ifAttributes()
        - .ifEnclosingOperation()
        - .ifLeadingKeys()

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_ExecuteStatement.html

        :stability: experimental
        '''
        return typing.cast("Dynamodb", jsii.invoke(self, "toPartiQLInsert", []))

    @jsii.member(jsii_name="toPartiQLSelect")
    def to_parti_ql_select(self) -> "Dynamodb":
        '''(experimental) Grants permission to read a set of attributes for items from a table or index.

        Access Level: Read

        Possible conditions:

        - .ifAttributes()
        - .ifEnclosingOperation()
        - .ifFullTableScan()
        - .ifLeadingKeys()
        - .ifSelect()

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_ExecuteStatement.html

        :stability: experimental
        '''
        return typing.cast("Dynamodb", jsii.invoke(self, "toPartiQLSelect", []))

    @jsii.member(jsii_name="toPartiQLUpdate")
    def to_parti_ql_update(self) -> "Dynamodb":
        '''(experimental) Grants permission to edit an existing item's attributes.

        Access Level: Write

        Possible conditions:

        - .ifAttributes()
        - .ifEnclosingOperation()
        - .ifLeadingKeys()
        - .ifReturnValues()

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_ExecuteStatement.html

        :stability: experimental
        '''
        return typing.cast("Dynamodb", jsii.invoke(self, "toPartiQLUpdate", []))

    @jsii.member(jsii_name="toPurchaseReservedCapacityOfferings")
    def to_purchase_reserved_capacity_offerings(self) -> "Dynamodb":
        '''(experimental) Grants permission to purchases reserved capacity for use with your account.

        Access Level: Write

        :stability: experimental
        '''
        return typing.cast("Dynamodb", jsii.invoke(self, "toPurchaseReservedCapacityOfferings", []))

    @jsii.member(jsii_name="toPutItem")
    def to_put_item(self) -> "Dynamodb":
        '''(experimental) Grants permission to create a new item, or replace an old item with a new item.

        Access Level: Write

        Possible conditions:

        - .ifAttributes()
        - .ifEnclosingOperation()
        - .ifLeadingKeys()
        - .ifReturnConsumedCapacity()
        - .ifReturnValues()

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_PutItem.html

        :stability: experimental
        '''
        return typing.cast("Dynamodb", jsii.invoke(self, "toPutItem", []))

    @jsii.member(jsii_name="toQuery")
    def to_query(self) -> "Dynamodb":
        '''(experimental) Grants permission to use the primary key of a table or a secondary index to directly access items from that table or index.

        Access Level: Read

        Possible conditions:

        - .ifAttributes()
        - .ifLeadingKeys()
        - .ifReturnConsumedCapacity()
        - .ifReturnValues()
        - .ifSelect()

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_Query.html

        :stability: experimental
        '''
        return typing.cast("Dynamodb", jsii.invoke(self, "toQuery", []))

    @jsii.member(jsii_name="toRestoreTableFromAwsBackup")
    def to_restore_table_from_aws_backup(self) -> "Dynamodb":
        '''(experimental) Grants permission to create a new table from recovery point on AWS Backup.

        Access Level: Write

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_RestoreTableFromAwsBackup.html

        :stability: experimental
        '''
        return typing.cast("Dynamodb", jsii.invoke(self, "toRestoreTableFromAwsBackup", []))

    @jsii.member(jsii_name="toRestoreTableFromBackup")
    def to_restore_table_from_backup(self) -> "Dynamodb":
        '''(experimental) Grants permission to create a new table from an existing backup.

        Access Level: Write

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_RestoreTableFromBackup.html

        :stability: experimental
        '''
        return typing.cast("Dynamodb", jsii.invoke(self, "toRestoreTableFromBackup", []))

    @jsii.member(jsii_name="toRestoreTableToPointInTime")
    def to_restore_table_to_point_in_time(self) -> "Dynamodb":
        '''(experimental) Grants permission to restore a table to a point in time.

        Access Level: Write

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_RestoreTableToPointInTime.html

        :stability: experimental
        '''
        return typing.cast("Dynamodb", jsii.invoke(self, "toRestoreTableToPointInTime", []))

    @jsii.member(jsii_name="toScan")
    def to_scan(self) -> "Dynamodb":
        '''(experimental) Grants permission to return one or more items and item attributes by accessing every item in a table or a secondary index.

        Access Level: Read

        Possible conditions:

        - .ifAttributes()
        - .ifReturnConsumedCapacity()
        - .ifReturnValues()
        - .ifSelect()

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_Scan.html

        :stability: experimental
        '''
        return typing.cast("Dynamodb", jsii.invoke(self, "toScan", []))

    @jsii.member(jsii_name="toStartAwsBackupJob")
    def to_start_aws_backup_job(self) -> "Dynamodb":
        '''(experimental) Grants permission to create a backup on AWS Backup with advanced features enabled.

        Access Level: Write

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_StartAwsBackupJob.html

        :stability: experimental
        '''
        return typing.cast("Dynamodb", jsii.invoke(self, "toStartAwsBackupJob", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Dynamodb":
        '''(experimental) Grants permission to associate a set of tags with an Amazon DynamoDB resource.

        Access Level: Tagging

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("Dynamodb", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Dynamodb":
        '''(experimental) Grants permission to remove the association of tags from an Amazon DynamoDB resource.

        Access Level: Tagging

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("Dynamodb", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateContinuousBackups")
    def to_update_continuous_backups(self) -> "Dynamodb":
        '''(experimental) Grants permission to enable or disable continuous backups.

        Access Level: Write

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_UpdateContinuousBackups.html

        :stability: experimental
        '''
        return typing.cast("Dynamodb", jsii.invoke(self, "toUpdateContinuousBackups", []))

    @jsii.member(jsii_name="toUpdateContributorInsights")
    def to_update_contributor_insights(self) -> "Dynamodb":
        '''(experimental) Grants permission to update the status for contributor insights for a specific table or global secondary index.

        Access Level: Write

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_UpdateContributorInsights.html

        :stability: experimental
        '''
        return typing.cast("Dynamodb", jsii.invoke(self, "toUpdateContributorInsights", []))

    @jsii.member(jsii_name="toUpdateGlobalTable")
    def to_update_global_table(self) -> "Dynamodb":
        '''(experimental) Grants permission to add or remove replicas in the specified global table.

        Access Level: Write

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_UpdateGlobalTable.html

        :stability: experimental
        '''
        return typing.cast("Dynamodb", jsii.invoke(self, "toUpdateGlobalTable", []))

    @jsii.member(jsii_name="toUpdateGlobalTableSettings")
    def to_update_global_table_settings(self) -> "Dynamodb":
        '''(experimental) Grants permission to update settings of the specified global table.

        Access Level: Write

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_UpdateGlobalTableSettings.html

        :stability: experimental
        '''
        return typing.cast("Dynamodb", jsii.invoke(self, "toUpdateGlobalTableSettings", []))

    @jsii.member(jsii_name="toUpdateItem")
    def to_update_item(self) -> "Dynamodb":
        '''(experimental) Grants permission to edit an existing item's attributes, or adds a new item to the table if it does not already exist.

        Access Level: Write

        Possible conditions:

        - .ifAttributes()
        - .ifEnclosingOperation()
        - .ifLeadingKeys()
        - .ifReturnConsumedCapacity()
        - .ifReturnValues()

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_UpdateItem.html

        :stability: experimental
        '''
        return typing.cast("Dynamodb", jsii.invoke(self, "toUpdateItem", []))

    @jsii.member(jsii_name="toUpdateTable")
    def to_update_table(self) -> "Dynamodb":
        '''(experimental) Grants permission to modify the provisioned throughput settings, global secondary indexes, or DynamoDB Streams settings for a given table.

        Access Level: Write

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_UpdateTable.html

        :stability: experimental
        '''
        return typing.cast("Dynamodb", jsii.invoke(self, "toUpdateTable", []))

    @jsii.member(jsii_name="toUpdateTableReplicaAutoScaling")
    def to_update_table_replica_auto_scaling(self) -> "Dynamodb":
        '''(experimental) Grants permission to update auto scaling settings on your replica table.

        Access Level: Write

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_UpdateTableReplicaAutoScaling.html

        :stability: experimental
        '''
        return typing.cast("Dynamodb", jsii.invoke(self, "toUpdateTableReplicaAutoScaling", []))

    @jsii.member(jsii_name="toUpdateTimeToLive")
    def to_update_time_to_live(self) -> "Dynamodb":
        '''(experimental) Grants permission to enable or disable TTL for the specified table.

        Access Level: Write

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_UpdateTimeToLive.html

        :stability: experimental
        '''
        return typing.cast("Dynamodb", jsii.invoke(self, "toUpdateTimeToLive", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ee579fa17e7e15ead802fb00485dee2707cb6981dee27d18fda4ea00665264e4)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6e0fe0a5b1a6c6f829c3a5a78c801308978bb7ca358fdf14d40c76bdec7d2fc6)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Ebs(PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Ebs"):
    '''(experimental) Statement provider for service `ebs <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonelasticblockstore.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `ebs <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonelasticblockstore.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="ifDescription")
    def if_description(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Ebs":
        '''(experimental) Filters access by the description of the snapshot being created.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonelasticblockstore.html#amazonelasticblockstore-policy-keys

        Applies to actions:

        - .toStartSnapshot()

        Applies to resource types:

        - snapshot

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8420b12704870d60a9a94d97e5951eacb27036fce788c2a39d27c32c4ea73efb)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Ebs", jsii.invoke(self, "ifDescription", [value, operator]))

    @jsii.member(jsii_name="ifParentSnapshot")
    def if_parent_snapshot(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Ebs":
        '''(experimental) Filters access by the ID of the parent snapshot.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonelasticblockstore.html#amazonelasticblockstore-policy-keys

        Applies to actions:

        - .toStartSnapshot()

        Applies to resource types:

        - snapshot

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f6421034fcb4fb408fb15683e205e1e0e9f81315e26f531af3f38d4bad19ac59)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Ebs", jsii.invoke(self, "ifParentSnapshot", [value, operator]))

    @jsii.member(jsii_name="ifVolumeSize")
    def if_volume_size(
        self,
        value: typing.Union[jsii.Number, typing.Sequence[jsii.Number]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Ebs":
        '''(experimental) Filters access by the size of the volume for the snapshot being created, in GiB.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonelasticblockstore.html#amazonelasticblockstore-policy-keys

        Applies to actions:

        - .toStartSnapshot()

        Applies to resource types:

        - snapshot

        :param value: The value(s) to check.
        :param operator: Works with `numeric operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_Numeric>`_. **Default:** ``NumericEquals``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__690aafd91fca905136e49b9cf1616a1f94ade72096fed55c0b4aff1cbb1203cd)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Ebs", jsii.invoke(self, "ifVolumeSize", [value, operator]))

    @jsii.member(jsii_name="onSnapshot")
    def on_snapshot(
        self,
        snapshot_id: builtins.str,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Ebs":
        '''(experimental) Adds a resource of type snapshot to the statement.

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/EBSSnapshots.html

        :param snapshot_id: - Identifier for the snapshotId.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsRequestTag() - .ifAwsResourceTag() - .ifAwsTagKeys() - .ifDescription() - .ifParentSnapshot() - .ifVolumeSize()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6dee477c75c03781f77b895a068ce6cbed381825e498d8c630915056aecfd74a)
            check_type(argname="argument snapshot_id", value=snapshot_id, expected_type=type_hints["snapshot_id"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Ebs", jsii.invoke(self, "onSnapshot", [snapshot_id, region, partition]))

    @jsii.member(jsii_name="toCompleteSnapshot")
    def to_complete_snapshot(self) -> "Ebs":
        '''(experimental) Grants permission to seal and complete the snapshot after all of the required blocks of data have been written to it.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/ebs/latest/APIReference/API_CompleteSnapshot.html

        :stability: experimental
        '''
        return typing.cast("Ebs", jsii.invoke(self, "toCompleteSnapshot", []))

    @jsii.member(jsii_name="toGetSnapshotBlock")
    def to_get_snapshot_block(self) -> "Ebs":
        '''(experimental) Grants permission to return the data of a block in an Amazon Elastic Block Store (EBS) snapshot.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/ebs/latest/APIReference/API_GetSnapshotBlock.html

        :stability: experimental
        '''
        return typing.cast("Ebs", jsii.invoke(self, "toGetSnapshotBlock", []))

    @jsii.member(jsii_name="toListChangedBlocks")
    def to_list_changed_blocks(self) -> "Ebs":
        '''(experimental) Grants permission to list the blocks that are different between two Amazon Elastic Block Store (EBS) snapshots of the same volume/snapshot lineage.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/ebs/latest/APIReference/API_ListChangedBlocks.html

        :stability: experimental
        '''
        return typing.cast("Ebs", jsii.invoke(self, "toListChangedBlocks", []))

    @jsii.member(jsii_name="toListSnapshotBlocks")
    def to_list_snapshot_blocks(self) -> "Ebs":
        '''(experimental) Grants permission to list the blocks in an Amazon Elastic Block Store (EBS) snapshot.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/ebs/latest/APIReference/API_ListSnapshotBlocks.html

        :stability: experimental
        '''
        return typing.cast("Ebs", jsii.invoke(self, "toListSnapshotBlocks", []))

    @jsii.member(jsii_name="toPutSnapshotBlock")
    def to_put_snapshot_block(self) -> "Ebs":
        '''(experimental) Grants permission to write a block of data to a snapshot created by the StartSnapshot operation.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/ebs/latest/APIReference/API_PutSnapshotBlock.html

        :stability: experimental
        '''
        return typing.cast("Ebs", jsii.invoke(self, "toPutSnapshotBlock", []))

    @jsii.member(jsii_name="toStartSnapshot")
    def to_start_snapshot(self) -> "Ebs":
        '''(experimental) Grants permission to create a new EBS snapshot.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsResourceTag()
        - .ifAwsTagKeys()
        - .ifDescription()
        - .ifParentSnapshot()
        - .ifVolumeSize()

        https://docs.aws.amazon.com/ebs/latest/APIReference/API_StartSnapshot.html

        :stability: experimental
        '''
        return typing.cast("Ebs", jsii.invoke(self, "toStartSnapshot", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6ab060e160a84ebfff9a656f457426a287f82d0b6ce4f8c7ada064505259c6a3)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7fd34649c3b261dcbe9d435c393aa108a0bd3d308c571d0baf289129826599f9)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Ec2(PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Ec2"):
    '''(experimental) Statement provider for service `ec2 <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonec2.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `ec2 <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonec2.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="ifAccepterVpc")
    def if_accepter_vpc(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Ec2":
        '''(experimental) Filters access by the ARN of an accepter VPC in a VPC peering connection.

        https://docs.aws.amazon.com/vpc/latest/peering/security-iam.html

        Applies to actions:

        - .toAcceptVpcPeeringConnection()
        - .toCreateNetworkInsightsPath()
        - .toCreateTags()
        - .toCreateVpcPeeringConnection()
        - .toDeleteVpcPeeringConnection()
        - .toModifyVpcPeeringConnectionOptions()
        - .toRejectVpcPeeringConnection()

        Applies to resource types:

        - vpc-peering-connection

        :param value: The value(s) to check.
        :param operator: Works with `arn operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_ARN>`_. **Default:** ``ArnLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f8f50c48ad04bc6ebfb4c4b5598ea8fadbaf1e6979bcabf0c90909675ad42125)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Ec2", jsii.invoke(self, "ifAccepterVpc", [value, operator]))

    @jsii.member(jsii_name="ifAddGroup")
    def if_add_group(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Ec2":
        '''(experimental) Filters access by the group being added to a snapshot.

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/iam-policy-structure.html#amazon-ec2-keys

        Applies to actions:

        - .toModifySnapshotAttribute()

        Applies to resource types:

        - snapshot

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a4612ad2a34a50feddb99c5382d0af71c677a426f4300e2ff22bec328d69ae86)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Ec2", jsii.invoke(self, "ifAddGroup", [value, operator]))

    @jsii.member(jsii_name="ifAddUserId")
    def if_add_user_id(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Ec2":
        '''(experimental) Filters access by the account id being added to a snapshot.

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/iam-policy-structure.html#amazon-ec2-keys

        Applies to actions:

        - .toModifySnapshotAttribute()

        Applies to resource types:

        - snapshot

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__802f4d67d9f5a2b1721bd0e0bfab0075391d6c54ae0eb5da49c2a25803ef730e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Ec2", jsii.invoke(self, "ifAddUserId", [value, operator]))

    @jsii.member(jsii_name="ifAllocationId")
    def if_allocation_id(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Ec2":
        '''(experimental) Filters access by the allocation ID of the Elastic IP address.

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/iam-policy-structure.html#amazon-ec2-keys

        Applies to actions:

        - .toAcceptAddressTransfer()
        - .toAssociateAddress()
        - .toCreateNatGateway()
        - .toCreateTags()
        - .toDescribeAddressesAttribute()
        - .toDisableAddressTransfer()
        - .toDisassociateAddress()
        - .toEnableAddressTransfer()
        - .toModifyAddressAttribute()
        - .toReleaseAddress()
        - .toResetAddressAttribute()

        Applies to resource types:

        - elastic-ip

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ad23ea40782284167e5f5047b975b1e3693b6dfe1762298659bf0e2049d4211d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Ec2", jsii.invoke(self, "ifAllocationId", [value, operator]))

    @jsii.member(jsii_name="ifAssociatePublicIpAddress")
    def if_associate_public_ip_address(
        self,
        value: typing.Optional[builtins.bool] = None,
    ) -> "Ec2":
        '''(experimental) Filters access by whether the user wants to associate a public IP address with the instance.

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/iam-policy-structure.html#amazon-ec2-keys

        Applies to actions:

        - .toCreateFleet()
        - .toCreateNetworkInsightsPath()
        - .toCreateTags()
        - .toCreateVerifiedAccessEndpoint()
        - .toDeleteNetworkInterfacePermission()
        - .toModifyFleet()
        - .toModifyLocalGatewayRoute()
        - .toRequestSpotInstances()
        - .toRunInstances()
        - .toRunScheduledInstances()

        Applies to resource types:

        - network-interface

        :param value: ``true`` or ``false``. **Default:** ``true``

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6286d544fd13ded719eab99b35593e0260c111c43085f7c48dcb7571fd606a2f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast("Ec2", jsii.invoke(self, "ifAssociatePublicIpAddress", [value]))

    @jsii.member(jsii_name="ifAttribute")
    def if_attribute(
        self,
        attribute_name: builtins.str,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Ec2":
        '''(experimental) Filters access by an attribute being set on a resource.

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/iam-policy-structure.html#amazon-ec2-keys

        Applies to actions:

        - .toModifyAddressAttribute()
        - .toModifyCapacityReservation()
        - .toModifyCapacityReservationFleet()
        - .toModifyClientVpnEndpoint()
        - .toModifyFleet()
        - .toModifyFpgaImageAttribute()
        - .toModifyHosts()
        - .toModifyImageAttribute()
        - .toModifyInstanceAttribute()
        - .toModifyInstanceCapacityReservationAttributes()
        - .toModifyInstanceCreditSpecification()
        - .toModifyInstanceEventStartTime()
        - .toModifyInstanceMaintenanceOptions()
        - .toModifyInstanceMetadataOptions()
        - .toModifyInstancePlacement()
        - .toModifyIpam()
        - .toModifyIpamPool()
        - .toModifyIpamResourceCidr()
        - .toModifyIpamScope()
        - .toModifyLaunchTemplate()
        - .toModifyManagedPrefixList()
        - .toModifyNetworkInterfaceAttribute()
        - .toModifyPrivateDnsNameOptions()
        - .toModifyReservedInstances()
        - .toModifySecurityGroupRules()
        - .toModifySnapshotAttribute()
        - .toModifySnapshotTier()
        - .toModifySpotFleetRequest()
        - .toModifySubnetAttribute()
        - .toModifyTrafficMirrorFilterNetworkServices()
        - .toModifyTrafficMirrorFilterRule()
        - .toModifyTrafficMirrorSession()
        - .toModifyTransitGateway()
        - .toModifyTransitGatewayPrefixListReference()
        - .toModifyTransitGatewayVpcAttachment()
        - .toModifyVolume()
        - .toModifyVolumeAttribute()
        - .toModifyVpcAttribute()
        - .toModifyVpcEndpoint()
        - .toModifyVpcEndpointConnectionNotification()
        - .toModifyVpcEndpointServiceConfiguration()
        - .toModifyVpcEndpointServicePayerResponsibility()
        - .toModifyVpcEndpointServicePermissions()
        - .toModifyVpcPeeringConnectionOptions()
        - .toModifyVpcTenancy()
        - .toModifyVpnConnection()
        - .toModifyVpnConnectionOptions()
        - .toModifyVpnTunnelCertificate()
        - .toModifyVpnTunnelOptions()
        - .toResetAddressAttribute()
        - .toResetFpgaImageAttribute()
        - .toResetImageAttribute()
        - .toResetSnapshotAttribute()

        Applies to resource types:

        - elastic-ip
        - capacity-reservation-fleet
        - capacity-reservation
        - client-vpn-endpoint
        - dedicated-host
        - fleet
        - fpga-image
        - image
        - instance
        - ipam
        - ipam-pool
        - ipam-scope
        - launch-template
        - network-interface
        - prefix-list
        - reserved-instances
        - security-group
        - snapshot
        - spot-fleet-request
        - subnet
        - traffic-mirror-filter
        - traffic-mirror-filter-rule
        - traffic-mirror-session
        - transit-gateway-attachment
        - transit-gateway
        - transit-gateway-route-table
        - volume
        - vpc-endpoint
        - vpc-endpoint-service
        - vpc
        - vpc-peering-connection
        - vpn-connection

        :param attribute_name: The tag key to check.
        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__38359839899decd15fba858a2fe7fa7039a7fd1b762f79c9f8535db645216a05)
            check_type(argname="argument attribute_name", value=attribute_name, expected_type=type_hints["attribute_name"])
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Ec2", jsii.invoke(self, "ifAttribute", [attribute_name, value, operator]))

    @jsii.member(jsii_name="ifAttributeExists")
    def if_attribute_exists(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Ec2":
        '''(experimental) Filters access by an attribute of a resource.

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/iam-policy-structure.html#amazon-ec2-keys

        Applies to actions:

        - .toModifyAddressAttribute()
        - .toModifyCapacityReservation()
        - .toModifyCapacityReservationFleet()
        - .toModifyClientVpnEndpoint()
        - .toModifyFleet()
        - .toModifyFpgaImageAttribute()
        - .toModifyHosts()
        - .toModifyImageAttribute()
        - .toModifyInstanceAttribute()
        - .toModifyInstanceCapacityReservationAttributes()
        - .toModifyInstanceCreditSpecification()
        - .toModifyInstanceMaintenanceOptions()
        - .toModifyInstanceMetadataOptions()
        - .toModifyInstancePlacement()
        - .toModifyIpam()
        - .toModifyIpamPool()
        - .toModifyIpamResourceCidr()
        - .toModifyIpamScope()
        - .toModifyLaunchTemplate()
        - .toModifyManagedPrefixList()
        - .toModifyNetworkInterfaceAttribute()
        - .toModifyPrivateDnsNameOptions()
        - .toModifyReservedInstances()
        - .toModifySecurityGroupRules()
        - .toModifySnapshotAttribute()
        - .toModifySnapshotTier()
        - .toModifySpotFleetRequest()
        - .toModifySubnetAttribute()
        - .toModifyTrafficMirrorFilterNetworkServices()
        - .toModifyTrafficMirrorFilterRule()
        - .toModifyTrafficMirrorSession()
        - .toModifyTransitGateway()
        - .toModifyTransitGatewayPrefixListReference()
        - .toModifyTransitGatewayVpcAttachment()
        - .toModifyVolume()
        - .toModifyVolumeAttribute()
        - .toModifyVpcAttribute()
        - .toModifyVpcEndpoint()
        - .toModifyVpcEndpointConnectionNotification()
        - .toModifyVpcEndpointServiceConfiguration()
        - .toModifyVpcEndpointServicePayerResponsibility()
        - .toModifyVpcEndpointServicePermissions()
        - .toModifyVpcPeeringConnectionOptions()
        - .toModifyVpcTenancy()
        - .toModifyVpnConnection()
        - .toModifyVpnConnectionOptions()
        - .toModifyVpnTunnelCertificate()
        - .toModifyVpnTunnelOptions()
        - .toResetAddressAttribute()
        - .toResetFpgaImageAttribute()
        - .toResetImageAttribute()
        - .toResetSnapshotAttribute()

        Applies to resource types:

        - elastic-ip
        - capacity-reservation-fleet
        - capacity-reservation
        - client-vpn-endpoint
        - dedicated-host
        - fleet
        - fpga-image
        - image
        - instance
        - ipam
        - ipam-pool
        - ipam-scope
        - launch-template
        - network-interface
        - prefix-list
        - reserved-instances
        - security-group
        - snapshot
        - spot-fleet-request
        - subnet
        - traffic-mirror-filter
        - traffic-mirror-filter-rule
        - traffic-mirror-session
        - transit-gateway-attachment
        - transit-gateway
        - transit-gateway-route-table
        - volume
        - vpc-endpoint
        - vpc-endpoint-service
        - vpc
        - vpc-peering-connection
        - vpn-connection

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ac4823f1f4a6e8291df54597ecd77e36b91f15910355e19d712bd2b6a6f1ea59)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Ec2", jsii.invoke(self, "ifAttributeExists", [value, operator]))

    @jsii.member(jsii_name="ifAuthenticationType")
    def if_authentication_type(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Ec2":
        '''(experimental) Filters access by the authentication type for the VPN tunnel endpoints.

        https://docs.aws.amazon.com/vpn/latest/s2svpn/vpn-authentication-access-control.html

        Applies to actions:

        - .toCreateTags()
        - .toCreateVpnConnection()
        - .toModifyVpnConnection()
        - .toModifyVpnTunnelOptions()

        Applies to resource types:

        - vpn-connection

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__700f2974c34bd07143b8402ad7b5895c5240d03123a11bd2d824e0c3fa467742)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Ec2", jsii.invoke(self, "ifAuthenticationType", [value, operator]))

    @jsii.member(jsii_name="ifAuthorizedService")
    def if_authorized_service(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Ec2":
        '''(experimental) Filters access by the AWS service that has permission to use a resource.

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/iam-policy-structure.html#amazon-ec2-keys

        Applies to actions:

        - .toCreateFleet()
        - .toCreateNetworkInsightsPath()
        - .toCreateNetworkInterfacePermission()
        - .toCreateTags()
        - .toCreateVerifiedAccessEndpoint()
        - .toDeleteNetworkInterfacePermission()
        - .toModifyFleet()
        - .toModifyLocalGatewayRoute()
        - .toRequestSpotInstances()
        - .toRunInstances()
        - .toRunScheduledInstances()

        Applies to resource types:

        - network-interface

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__925db782e3ff7aac23f0bcf89493a6f44ebfddbc2b971ebf547afd0c20f905d0)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Ec2", jsii.invoke(self, "ifAuthorizedService", [value, operator]))

    @jsii.member(jsii_name="ifAuthorizedUser")
    def if_authorized_user(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Ec2":
        '''(experimental) Filters access by an IAM principal that has permission to use a resource.

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/iam-policy-structure.html#amazon-ec2-keys

        Applies to actions:

        - .toCreateNetworkInterfacePermission()
        - .toCreateTags()
        - .toCreateVerifiedAccessEndpoint()
        - .toModifyLocalGatewayRoute()
        - .toRequestSpotInstances()

        Applies to resource types:

        - network-interface

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f990078d513f84f2dc386c9b363a811b44e458624ff72059fbf6986ffe7aafc2)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Ec2", jsii.invoke(self, "ifAuthorizedUser", [value, operator]))

    @jsii.member(jsii_name="ifAutoPlacement")
    def if_auto_placement(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Ec2":
        '''(experimental) Filters access by the Auto Placement properties of a Dedicated Host.

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/iam-policy-structure.html#amazon-ec2-keys

        Applies to actions:

        - .toAllocateHosts()
        - .toCreateTags()

        Applies to resource types:

        - dedicated-host

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3eae124cc4249d380102b52accb327c843cede9189f70c5f37713a07ae061e4e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Ec2", jsii.invoke(self, "ifAutoPlacement", [value, operator]))

    @jsii.member(jsii_name="ifAvailabilityZone")
    def if_availability_zone(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Ec2":
        '''(experimental) Filters access by the name of an Availability Zone in an AWS Region.

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/iam-policy-structure.html#amazon-ec2-keys

        Applies to actions:

        - .toAllocateHosts()
        - .toAssignIpv6Addresses()
        - .toAssignPrivateIpAddresses()
        - .toAssociateAddress()
        - .toAssociateIamInstanceProfile()
        - .toAssociateRouteTable()
        - .toAssociateSubnetCidrBlock()
        - .toAssociateTransitGatewayMulticastDomain()
        - .toAttachClassicLinkVpc()
        - .toAttachNetworkInterface()
        - .toAttachVolume()
        - .toCreateFleet()
        - .toCreateFlowLogs()
        - .toCreateImage()
        - .toCreateInstanceExportTask()
        - .toCreateLocalGatewayRoute()
        - .toCreateNatGateway()
        - .toCreateNetworkInsightsPath()
        - .toCreateNetworkInterface()
        - .toCreateNetworkInterfacePermission()
        - .toCreateReplaceRootVolumeTask()
        - .toCreateSnapshots()
        - .toCreateTags()
        - .toCreateTransitGatewayVpcAttachment()
        - .toCreateVerifiedAccessEndpoint()
        - .toCreateVolume()
        - .toDeleteClientVpnRoute()
        - .toDeleteNetworkInterface()
        - .toDeleteNetworkInterfacePermission()
        - .toDeleteSubnet()
        - .toDeleteVolume()
        - .toDeregisterTransitGatewayMulticastGroupMembers()
        - .toDeregisterTransitGatewayMulticastGroupSources()
        - .toDescribeInstanceAttribute()
        - .toDescribeSnapshotAttribute()
        - .toDescribeVolumeAttribute()
        - .toDetachClassicLinkVpc()
        - .toDetachNetworkInterface()
        - .toDetachVolume()
        - .toDisableFastSnapshotRestores()
        - .toDisassociateAddress()
        - .toDisassociateIamInstanceProfile()
        - .toDisassociateRouteTable()
        - .toDisassociateSubnetCidrBlock()
        - .toDisassociateTransitGatewayMulticastDomain()
        - .toEnableFastSnapshotRestores()
        - .toEnableVolumeIO()
        - .toGetConsoleOutput()
        - .toGetConsoleScreenshot()
        - .toGetInstanceUefiData()
        - .toGetLaunchTemplateData()
        - .toGetPasswordData()
        - .toImportInstance()
        - .toImportVolume()
        - .toListSnapshotsInRecycleBin()
        - .toModifyFleet()
        - .toModifyInstanceAttribute()
        - .toModifyInstanceCapacityReservationAttributes()
        - .toModifyInstanceCreditSpecification()
        - .toModifyInstanceMaintenanceOptions()
        - .toModifyInstanceMetadataOptions()
        - .toModifyInstancePlacement()
        - .toModifyLocalGatewayRoute()
        - .toModifyNetworkInterfaceAttribute()
        - .toModifyPrivateDnsNameOptions()
        - .toModifyReservedInstances()
        - .toModifySnapshotTier()
        - .toModifySpotFleetRequest()
        - .toModifySubnetAttribute()
        - .toModifyVerifiedAccessEndpoint()
        - .toModifyVolume()
        - .toModifyVolumeAttribute()
        - .toMonitorInstances()
        - .toRebootInstances()
        - .toRegisterTransitGatewayMulticastGroupMembers()
        - .toRegisterTransitGatewayMulticastGroupSources()
        - .toReplaceIamInstanceProfileAssociation()
        - .toReplaceNetworkAclAssociation()
        - .toReplaceRouteTableAssociation()
        - .toRequestSpotFleet()
        - .toRequestSpotInstances()
        - .toResetInstanceAttribute()
        - .toResetNetworkInterfaceAttribute()
        - .toRestoreSnapshotFromRecycleBin()
        - .toRestoreSnapshotTier()
        - .toRunInstances()
        - .toRunScheduledInstances()
        - .toSendDiagnosticInterrupt()
        - .toSendSpotInstanceInterruptions()
        - .toStartInstances()
        - .toStopInstances()
        - .toTerminateInstances()
        - .toUnassignIpv6Addresses()
        - .toUnassignPrivateIpAddresses()
        - .toUnmonitorInstances()

        Applies to resource types:

        - dedicated-host
        - instance
        - network-interface
        - reserved-instances
        - snapshot
        - subnet
        - volume

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__cfe8cef3548c616e0cc690a8875a4b09566108ee2fa4d0d9c62e77534a7d65fb)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Ec2", jsii.invoke(self, "ifAvailabilityZone", [value, operator]))

    @jsii.member(jsii_name="ifCapacityReservationFleet")
    def if_capacity_reservation_fleet(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Ec2":
        '''(experimental) Filters access by the ARN of the Capacity Reservation Fleet.

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/iam-policy-structure.html#amazon-ec2-keys

        Applies to actions:

        - .toCancelCapacityReservation()
        - .toCreateCapacityReservation()
        - .toGetCapacityReservationUsage()
        - .toGetGroupsForCapacityReservation()
        - .toModifyCapacityReservation()

        Applies to resource types:

        - capacity-reservation

        :param value: The value(s) to check.
        :param operator: Works with `arn operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_ARN>`_. **Default:** ``ArnLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__88a4f54443b19108c169fdd00ed2b495902f6707c7f75f72adb6cc1a6aa88d7c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Ec2", jsii.invoke(self, "ifCapacityReservationFleet", [value, operator]))

    @jsii.member(jsii_name="ifClientRootCertificateChainArn")
    def if_client_root_certificate_chain_arn(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Ec2":
        '''(experimental) Filters access by the ARN of the client root certificate chain.

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/iam-policy-structure.html#amazon-ec2-keys

        Applies to actions:

        - .toApplySecurityGroupsToClientVpnTargetNetwork()
        - .toAssociateClientVpnTargetNetwork()
        - .toAuthorizeClientVpnIngress()
        - .toCreateClientVpnEndpoint()
        - .toCreateClientVpnRoute()
        - .toCreateTags()
        - .toDeleteClientVpnEndpoint()
        - .toDeleteClientVpnRoute()
        - .toDescribeClientVpnConnections()
        - .toDescribeClientVpnEndpoints()
        - .toDescribeClientVpnRoutes()
        - .toDescribeClientVpnTargetNetworks()
        - .toDisassociateClientVpnTargetNetwork()
        - .toExportClientVpnClientCertificateRevocationList()
        - .toExportClientVpnClientConfiguration()
        - .toImportClientVpnClientCertificateRevocationList()
        - .toModifyClientVpnEndpoint()
        - .toRevokeClientVpnIngress()
        - .toTerminateClientVpnConnections()

        Applies to resource types:

        - client-vpn-endpoint

        :param value: The value(s) to check.
        :param operator: Works with `arn operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_ARN>`_. **Default:** ``ArnLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__35b424cef69cc9757237c2e8a0f48afbb7fe97553e384bcaaaef171d45c53444)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Ec2", jsii.invoke(self, "ifClientRootCertificateChainArn", [value, operator]))

    @jsii.member(jsii_name="ifCloudwatchLogGroupArn")
    def if_cloudwatch_log_group_arn(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Ec2":
        '''(experimental) Filters access by the ARN of the CloudWatch Logs log group.

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/iam-policy-structure.html#amazon-ec2-keys

        Applies to actions:

        - .toApplySecurityGroupsToClientVpnTargetNetwork()
        - .toAssociateClientVpnTargetNetwork()
        - .toAuthorizeClientVpnIngress()
        - .toCreateClientVpnEndpoint()
        - .toCreateClientVpnRoute()
        - .toCreateTags()
        - .toDeleteClientVpnEndpoint()
        - .toDeleteClientVpnRoute()
        - .toDescribeClientVpnConnections()
        - .toDescribeClientVpnEndpoints()
        - .toDescribeClientVpnRoutes()
        - .toDescribeClientVpnTargetNetworks()
        - .toDisassociateClientVpnTargetNetwork()
        - .toExportClientVpnClientCertificateRevocationList()
        - .toExportClientVpnClientConfiguration()
        - .toImportClientVpnClientCertificateRevocationList()
        - .toModifyClientVpnEndpoint()
        - .toRevokeClientVpnIngress()
        - .toTerminateClientVpnConnections()

        Applies to resource types:

        - client-vpn-endpoint

        :param value: The value(s) to check.
        :param operator: Works with `arn operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_ARN>`_. **Default:** ``ArnLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2e064486effed4e7294bedba31f304a46a92455e44d3d84ab2e30392acc28c54)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Ec2", jsii.invoke(self, "ifCloudwatchLogGroupArn", [value, operator]))

    @jsii.member(jsii_name="ifCloudwatchLogStreamArn")
    def if_cloudwatch_log_stream_arn(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Ec2":
        '''(experimental) Filters access by the ARN of the CloudWatch Logs log stream.

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/iam-policy-structure.html#amazon-ec2-keys

        Applies to actions:

        - .toApplySecurityGroupsToClientVpnTargetNetwork()
        - .toAssociateClientVpnTargetNetwork()
        - .toAuthorizeClientVpnIngress()
        - .toCreateClientVpnEndpoint()
        - .toCreateClientVpnRoute()
        - .toCreateTags()
        - .toDeleteClientVpnEndpoint()
        - .toDeleteClientVpnRoute()
        - .toDescribeClientVpnConnections()
        - .toDescribeClientVpnEndpoints()
        - .toDescribeClientVpnRoutes()
        - .toDescribeClientVpnTargetNetworks()
        - .toDisassociateClientVpnTargetNetwork()
        - .toExportClientVpnClientCertificateRevocationList()
        - .toExportClientVpnClientConfiguration()
        - .toImportClientVpnClientCertificateRevocationList()
        - .toModifyClientVpnEndpoint()
        - .toRevokeClientVpnIngress()
        - .toTerminateClientVpnConnections()

        Applies to resource types:

        - client-vpn-endpoint

        :param value: The value(s) to check.
        :param operator: Works with `arn operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_ARN>`_. **Default:** ``ArnLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e5d941d1f4a3703147fca85449e69ccef3873230a42eabd0bd7ab5e619c0c0fe)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Ec2", jsii.invoke(self, "ifCloudwatchLogStreamArn", [value, operator]))

    @jsii.member(jsii_name="ifCreateAction")
    def if_create_action(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Ec2":
        '''(experimental) Filters access by the name of a resource-creating API action.

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/supported-iam-actions-tagging.html

        Applies to actions:

        - .toCreateTags()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9f758c663ea71686011283c1ca2513cde21fa10e484f15298a8d687cf864514f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Ec2", jsii.invoke(self, "ifCreateAction", [value, operator]))

    @jsii.member(jsii_name="ifDhcpOptionsID")
    def if_dhcp_options_id(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Ec2":
        '''(experimental) Filters access by the ID of a dynamic host configuration protocol (DHCP) options set.

        Applies to actions:

        - .toAssociateDhcpOptions()
        - .toCreateDhcpOptions()
        - .toCreateTags()
        - .toDeleteDhcpOptions()

        Applies to resource types:

        - dhcp-options

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__37f7f882ed78e818d901e898e03f767e8bcd1495a76f64bc3f3e6ce76e8bf02c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Ec2", jsii.invoke(self, "ifDhcpOptionsID", [value, operator]))

    @jsii.member(jsii_name="ifDirectoryArn")
    def if_directory_arn(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Ec2":
        '''(experimental) Filters access by the ARN of the directory.

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/iam-policy-structure.html#amazon-ec2-keys

        Applies to actions:

        - .toApplySecurityGroupsToClientVpnTargetNetwork()
        - .toAssociateClientVpnTargetNetwork()
        - .toAuthorizeClientVpnIngress()
        - .toCreateClientVpnEndpoint()
        - .toCreateClientVpnRoute()
        - .toCreateTags()
        - .toDeleteClientVpnEndpoint()
        - .toDeleteClientVpnRoute()
        - .toDescribeClientVpnConnections()
        - .toDescribeClientVpnEndpoints()
        - .toDescribeClientVpnRoutes()
        - .toDescribeClientVpnTargetNetworks()
        - .toDisassociateClientVpnTargetNetwork()
        - .toExportClientVpnClientCertificateRevocationList()
        - .toExportClientVpnClientConfiguration()
        - .toImportClientVpnClientCertificateRevocationList()
        - .toModifyClientVpnEndpoint()
        - .toRevokeClientVpnIngress()
        - .toTerminateClientVpnConnections()

        Applies to resource types:

        - client-vpn-endpoint

        :param value: The value(s) to check.
        :param operator: Works with `arn operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_ARN>`_. **Default:** ``ArnLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7d9d35ba8baea3d5254e894833c77f9f88661c985c4536b5b7671ef580845911)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Ec2", jsii.invoke(self, "ifDirectoryArn", [value, operator]))

    @jsii.member(jsii_name="ifDomain")
    def if_domain(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Ec2":
        '''(experimental) Filters access by the domain of the Elastic IP address.

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/iam-policy-structure.html#amazon-ec2-keys

        Applies to actions:

        - .toAcceptAddressTransfer()
        - .toAssociateAddress()
        - .toCreateNatGateway()
        - .toCreateTags()
        - .toDescribeAddressesAttribute()
        - .toDisableAddressTransfer()
        - .toDisassociateAddress()
        - .toEnableAddressTransfer()
        - .toModifyAddressAttribute()
        - .toReleaseAddress()
        - .toResetAddressAttribute()

        Applies to resource types:

        - elastic-ip

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a1fd3898af63ffd3142a469a74168d838cf070551e1efd97a0f7b57cd38b4e13)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Ec2", jsii.invoke(self, "ifDomain", [value, operator]))

    @jsii.member(jsii_name="ifDomainCertificateArn")
    def if_domain_certificate_arn(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Ec2":
        '''(experimental) Filters access by the ARN of an Amazon Certificate Manager certificate.

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/iam-policy-structure.html#amazon-ec2-keys

        Applies to actions:

        - .toCreateTags()
        - .toCreateVerifiedAccessEndpoint()
        - .toDeleteVerifiedAccessEndpoint()
        - .toGetVerifiedAccessEndpointPolicy()
        - .toModifyVerifiedAccessEndpoint()
        - .toModifyVerifiedAccessEndpointPolicy()

        Applies to resource types:

        - verified-access-endpoint

        :param value: The value(s) to check.
        :param operator: Works with `arn operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_ARN>`_. **Default:** ``ArnLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__12d38aa1eace71bfb9ba5b717facea9808c59734d0d59a17261df66cafc16287)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Ec2", jsii.invoke(self, "ifDomainCertificateArn", [value, operator]))

    @jsii.member(jsii_name="ifDPDTimeoutSeconds")
    def if_dpd_timeout_seconds(
        self,
        value: typing.Union[jsii.Number, typing.Sequence[jsii.Number]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Ec2":
        '''(experimental) Filters access by the duration after which DPD timeout occurs on a VPN tunnel.

        https://docs.aws.amazon.com/vpn/latest/s2svpn/vpn-authentication-access-control.html

        Applies to actions:

        - .toCreateTags()
        - .toCreateVpnConnection()
        - .toModifyVpnConnection()
        - .toModifyVpnTunnelOptions()

        Applies to resource types:

        - vpn-connection

        :param value: The value(s) to check.
        :param operator: Works with `numeric operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_Numeric>`_. **Default:** ``NumericEquals``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__36ee909fea1e05cc5168475754eef43b496bceef19f22bad6d43d0ee283bdf64)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Ec2", jsii.invoke(self, "ifDPDTimeoutSeconds", [value, operator]))

    @jsii.member(jsii_name="ifEbsOptimized")
    def if_ebs_optimized(self, value: typing.Optional[builtins.bool] = None) -> "Ec2":
        '''(experimental) Filters access by whether the instance is enabled for EBS optimization.

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/iam-policy-structure.html#amazon-ec2-keys

        Applies to actions:

        - .toAssociateAddress()
        - .toAssociateIamInstanceProfile()
        - .toAttachClassicLinkVpc()
        - .toAttachNetworkInterface()
        - .toAttachVolume()
        - .toCreateFleet()
        - .toCreateImage()
        - .toCreateInstanceExportTask()
        - .toCreateNetworkInsightsPath()
        - .toCreateReplaceRootVolumeTask()
        - .toCreateSnapshots()
        - .toCreateTags()
        - .toDescribeInstanceAttribute()
        - .toDetachClassicLinkVpc()
        - .toDetachNetworkInterface()
        - .toDetachVolume()
        - .toDisassociateIamInstanceProfile()
        - .toGetConsoleOutput()
        - .toGetConsoleScreenshot()
        - .toGetInstanceUefiData()
        - .toGetLaunchTemplateData()
        - .toGetPasswordData()
        - .toModifyInstanceAttribute()
        - .toModifyInstanceCapacityReservationAttributes()
        - .toModifyInstanceCreditSpecification()
        - .toModifyInstanceMaintenanceOptions()
        - .toModifyInstanceMetadataOptions()
        - .toModifyInstancePlacement()
        - .toModifyNetworkInterfaceAttribute()
        - .toModifyPrivateDnsNameOptions()
        - .toMonitorInstances()
        - .toRebootInstances()
        - .toReplaceIamInstanceProfileAssociation()
        - .toResetInstanceAttribute()
        - .toRunInstances()
        - .toSendDiagnosticInterrupt()
        - .toSendSpotInstanceInterruptions()
        - .toStartInstances()
        - .toStopInstances()
        - .toTerminateInstances()
        - .toUnmonitorInstances()

        Applies to resource types:

        - instance

        :param value: ``true`` or ``false``. **Default:** ``true``

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d6a12b2fdfd96740db634204e10755b9a6baa2aadcff0582a902cac4a08cdb53)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast("Ec2", jsii.invoke(self, "ifEbsOptimized", [value]))

    @jsii.member(jsii_name="ifElasticGpuType")
    def if_elastic_gpu_type(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Ec2":
        '''(experimental) Filters access by the type of Elastic Graphics accelerator.

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/iam-policy-structure.html#amazon-ec2-keys

        Applies to actions:

        - .toCreateTags()
        - .toRunInstances()

        Applies to resource types:

        - elastic-gpu

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__047d56c802da50b5c065a6438433fd1ea2889a0a8eea4e28d763e51c3af666f4)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Ec2", jsii.invoke(self, "ifElasticGpuType", [value, operator]))

    @jsii.member(jsii_name="ifEncrypted")
    def if_encrypted(self, value: typing.Optional[builtins.bool] = None) -> "Ec2":
        '''(experimental) Filters access by whether the EBS volume is encrypted.

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/iam-policy-structure.html#amazon-ec2-keys

        Applies to actions:

        - .toAttachVolume()
        - .toCreateFleet()
        - .toCreateSnapshot()
        - .toCreateSnapshots()
        - .toCreateTags()
        - .toCreateVolume()
        - .toDeleteVolume()
        - .toDescribeSnapshotAttribute()
        - .toDescribeVolumeAttribute()
        - .toDetachVolume()
        - .toDisableFastSnapshotRestores()
        - .toEnableFastSnapshotRestores()
        - .toEnableVolumeIO()
        - .toImportInstance()
        - .toImportVolume()
        - .toListSnapshotsInRecycleBin()
        - .toModifyInstanceAttribute()
        - .toModifySnapshotTier()
        - .toModifyVolume()
        - .toModifyVolumeAttribute()
        - .toRestoreSnapshotFromRecycleBin()
        - .toRestoreSnapshotTier()
        - .toRunInstances()

        Applies to resource types:

        - snapshot
        - volume

        :param value: ``true`` or ``false``. **Default:** ``true``

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__15e21d333e2b0f8bb3ab0b0828d305e1eaa95a0656b858f2d6314d4e23af17d3)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast("Ec2", jsii.invoke(self, "ifEncrypted", [value]))

    @jsii.member(jsii_name="ifGatewayType")
    def if_gateway_type(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Ec2":
        '''(experimental) Filters access by the gateway type for a VPN endpoint on the AWS side of a VPN connection.

        https://docs.aws.amazon.com/vpn/latest/s2svpn/vpn-authentication-access-control.html

        Applies to actions:

        - .toCreateTags()
        - .toCreateVpnConnection()
        - .toModifyVpnConnection()
        - .toModifyVpnTunnelOptions()

        Applies to resource types:

        - vpn-connection

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0415b8a3214a7780a06c5d4115db7a2def724bf4979e89cdf31e3d7f2021f965)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Ec2", jsii.invoke(self, "ifGatewayType", [value, operator]))

    @jsii.member(jsii_name="ifHostRecovery")
    def if_host_recovery(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Ec2":
        '''(experimental) Filters access by whether host recovery is enabled for a Dedicated Host.

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/iam-policy-structure.html#amazon-ec2-keys

        Applies to actions:

        - .toAllocateHosts()
        - .toCreateTags()

        Applies to resource types:

        - dedicated-host

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3827ab76800e793e5b6fd36c232275dd79fd35420542f33210067b5809602ca7)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Ec2", jsii.invoke(self, "ifHostRecovery", [value, operator]))

    @jsii.member(jsii_name="ifIKEVersions")
    def if_ike_versions(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Ec2":
        '''(experimental) Filters access by the internet key exchange (IKE) versions that are permitted for a VPN tunnel.

        https://docs.aws.amazon.com/vpn/latest/s2svpn/vpn-authentication-access-control.html

        Applies to actions:

        - .toCreateTags()
        - .toCreateVpnConnection()
        - .toModifyVpnConnection()
        - .toModifyVpnTunnelOptions()

        Applies to resource types:

        - vpn-connection

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a6f6fb70fad602f86dc1212cc3f5be5f0ddfe9a3a4bf683d4ccafe48a608641b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Ec2", jsii.invoke(self, "ifIKEVersions", [value, operator]))

    @jsii.member(jsii_name="ifImageID")
    def if_image_id(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Ec2":
        '''(experimental) Filters access by the ID of an image.

        Applies to actions:

        - .toCancelImageLaunchPermission()
        - .toCopyImage()
        - .toCreateFleet()
        - .toCreateImage()
        - .toCreateReplaceRootVolumeTask()
        - .toCreateRestoreImageTask()
        - .toCreateStoreImageTask()
        - .toCreateTags()
        - .toDeregisterImage()
        - .toDescribeFastLaunchImages()
        - .toDescribeImageAttribute()
        - .toDescribeStoreImageTasks()
        - .toDisableFastLaunch()
        - .toDisableImageDeprecation()
        - .toEnableFastLaunch()
        - .toEnableImageDeprecation()
        - .toExportImage()
        - .toImportImage()
        - .toListImagesInRecycleBin()
        - .toModifyFleet()
        - .toModifyImageAttribute()
        - .toRegisterImage()
        - .toRequestSpotFleet()
        - .toRequestSpotInstances()
        - .toResetImageAttribute()
        - .toRestoreImageFromRecycleBin()
        - .toRunInstances()
        - .toRunScheduledInstances()

        Applies to resource types:

        - image

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e9673d4cc46195e8fca2cb68a7967fa2d72147194745dc2ce7c31923db1d216f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Ec2", jsii.invoke(self, "ifImageID", [value, operator]))

    @jsii.member(jsii_name="ifImageType")
    def if_image_type(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Ec2":
        '''(experimental) Filters access by the type of image (machine, aki, or ari).

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/iam-policy-structure.html#amazon-ec2-keys

        Applies to actions:

        - .toCancelImageLaunchPermission()
        - .toCreateFleet()
        - .toCreateReplaceRootVolumeTask()
        - .toCreateStoreImageTask()
        - .toCreateTags()
        - .toDeregisterImage()
        - .toDescribeFastLaunchImages()
        - .toDescribeImageAttribute()
        - .toDescribeStoreImageTasks()
        - .toDisableFastLaunch()
        - .toDisableImageDeprecation()
        - .toEnableFastLaunch()
        - .toEnableImageDeprecation()
        - .toExportImage()
        - .toImportImage()
        - .toListImagesInRecycleBin()
        - .toModifyFleet()
        - .toModifyImageAttribute()
        - .toRequestSpotFleet()
        - .toRequestSpotInstances()
        - .toResetImageAttribute()
        - .toRestoreImageFromRecycleBin()
        - .toRunInstances()
        - .toRunScheduledInstances()

        Applies to resource types:

        - image

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f740993be93b043b135001f0f46dd12f625b7147095ad284fa817bd171533515)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Ec2", jsii.invoke(self, "ifImageType", [value, operator]))

    @jsii.member(jsii_name="ifInsideTunnelCidr")
    def if_inside_tunnel_cidr(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Ec2":
        '''(experimental) Filters access by the range of inside IP addresses for a VPN tunnel.

        https://docs.aws.amazon.com/vpn/latest/s2svpn/vpn-authentication-access-control.html

        Applies to actions:

        - .toCreateTags()
        - .toCreateVpnConnection()
        - .toModifyVpnConnection()
        - .toModifyVpnTunnelOptions()

        Applies to resource types:

        - vpn-connection

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__36ee5641e6af4fb0583b528ac01513364e2c4032393be1f59905c31db2125fe4)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Ec2", jsii.invoke(self, "ifInsideTunnelCidr", [value, operator]))

    @jsii.member(jsii_name="ifInsideTunnelIpv6Cidr")
    def if_inside_tunnel_ipv6_cidr(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Ec2":
        '''(experimental) Filters access by a range of inside IPv6 addresses for a VPN tunnel.

        https://docs.aws.amazon.com/vpn/latest/s2svpn/vpn-authentication-access-control.html

        Applies to actions:

        - .toCreateTags()
        - .toCreateVpnConnection()
        - .toModifyVpnConnection()
        - .toModifyVpnTunnelOptions()

        Applies to resource types:

        - vpn-connection

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__19f21b7bbe550ed695ea2a296cad35dc878bd55d2531e840afc9885c28bb954f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Ec2", jsii.invoke(self, "ifInsideTunnelIpv6Cidr", [value, operator]))

    @jsii.member(jsii_name="ifInstanceAutoRecovery")
    def if_instance_auto_recovery(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Ec2":
        '''(experimental) Filters access by whether the instance type supports auto recovery.

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/iam-policy-structure.html#amazon-ec2-keys

        Applies to actions:

        - .toAssociateAddress()
        - .toAssociateIamInstanceProfile()
        - .toAttachNetworkInterface()
        - .toCreateImage()
        - .toCreateInstanceExportTask()
        - .toCreateReplaceRootVolumeTask()
        - .toCreateTags()
        - .toDescribeInstanceAttribute()
        - .toDetachNetworkInterface()
        - .toDisassociateIamInstanceProfile()
        - .toGetConsoleOutput()
        - .toGetConsoleScreenshot()
        - .toGetInstanceUefiData()
        - .toGetLaunchTemplateData()
        - .toGetPasswordData()
        - .toModifyInstanceAttribute()
        - .toModifyInstanceCapacityReservationAttributes()
        - .toModifyInstanceCreditSpecification()
        - .toModifyInstanceMaintenanceOptions()
        - .toModifyInstanceMetadataOptions()
        - .toModifyInstancePlacement()
        - .toModifyNetworkInterfaceAttribute()
        - .toModifyPrivateDnsNameOptions()
        - .toMonitorInstances()
        - .toRebootInstances()
        - .toReplaceIamInstanceProfileAssociation()
        - .toRunInstances()
        - .toSendDiagnosticInterrupt()
        - .toSendSpotInstanceInterruptions()
        - .toUnmonitorInstances()

        Applies to resource types:

        - instance

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__82d1eef9dbe0b86f8ab9ae733af258c255527a69c3d5bf11374222fe8542b20d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Ec2", jsii.invoke(self, "ifInstanceAutoRecovery", [value, operator]))

    @jsii.member(jsii_name="ifInstanceID")
    def if_instance_id(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Ec2":
        '''(experimental) Filters access by the ID of an instance.

        Applies to actions:

        - .toAssociateAddress()
        - .toAssociateIamInstanceProfile()
        - .toAttachClassicLinkVpc()
        - .toAttachNetworkInterface()
        - .toAttachVolume()
        - .toCreateFleet()
        - .toCreateImage()
        - .toCreateInstanceExportTask()
        - .toCreateNetworkInsightsPath()
        - .toCreateReplaceRootVolumeTask()
        - .toCreateSnapshots()
        - .toCreateTags()
        - .toDescribeInstanceAttribute()
        - .toDetachClassicLinkVpc()
        - .toDetachNetworkInterface()
        - .toDetachVolume()
        - .toDisassociateIamInstanceProfile()
        - .toGetConsoleOutput()
        - .toGetConsoleScreenshot()
        - .toGetInstanceUefiData()
        - .toGetLaunchTemplateData()
        - .toGetPasswordData()
        - .toImportInstance()
        - .toModifyInstanceAttribute()
        - .toModifyInstanceCapacityReservationAttributes()
        - .toModifyInstanceCreditSpecification()
        - .toModifyInstanceEventStartTime()
        - .toModifyInstanceMaintenanceOptions()
        - .toModifyInstanceMetadataOptions()
        - .toModifyInstancePlacement()
        - .toModifyNetworkInterfaceAttribute()
        - .toModifyPrivateDnsNameOptions()
        - .toMonitorInstances()
        - .toRebootInstances()
        - .toReplaceIamInstanceProfileAssociation()
        - .toResetInstanceAttribute()
        - .toRunInstances()
        - .toSendDiagnosticInterrupt()
        - .toSendSpotInstanceInterruptions()
        - .toStartInstances()
        - .toStopInstances()
        - .toTerminateInstances()
        - .toUnmonitorInstances()

        Applies to resource types:

        - instance

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__333732ea20168e808eb498e83979d0de73ea87a9a19e0ce4d05213ba4e297c61)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Ec2", jsii.invoke(self, "ifInstanceID", [value, operator]))

    @jsii.member(jsii_name="ifInstanceMarketType")
    def if_instance_market_type(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Ec2":
        '''(experimental) Filters access by the market or purchasing option of an instance (on-demand or spot).

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/iam-policy-structure.html#amazon-ec2-keys

        Applies to actions:

        - .toAssociateAddress()
        - .toAssociateIamInstanceProfile()
        - .toAttachClassicLinkVpc()
        - .toAttachNetworkInterface()
        - .toAttachVolume()
        - .toCreateImage()
        - .toCreateInstanceExportTask()
        - .toCreateReplaceRootVolumeTask()
        - .toCreateTags()
        - .toDescribeInstanceAttribute()
        - .toDetachClassicLinkVpc()
        - .toDetachNetworkInterface()
        - .toDetachVolume()
        - .toDisassociateIamInstanceProfile()
        - .toGetConsoleOutput()
        - .toGetConsoleScreenshot()
        - .toGetInstanceUefiData()
        - .toGetLaunchTemplateData()
        - .toGetPasswordData()
        - .toModifyInstanceAttribute()
        - .toModifyInstanceCapacityReservationAttributes()
        - .toModifyInstanceCreditSpecification()
        - .toModifyInstanceMaintenanceOptions()
        - .toModifyInstanceMetadataOptions()
        - .toModifyInstancePlacement()
        - .toModifyNetworkInterfaceAttribute()
        - .toModifyPrivateDnsNameOptions()
        - .toMonitorInstances()
        - .toRebootInstances()
        - .toReplaceIamInstanceProfileAssociation()
        - .toResetInstanceAttribute()
        - .toRunInstances()
        - .toSendDiagnosticInterrupt()
        - .toSendSpotInstanceInterruptions()
        - .toStartInstances()
        - .toStopInstances()
        - .toTerminateInstances()
        - .toUnmonitorInstances()

        Applies to resource types:

        - instance

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6f1169da7d40ba069a30b4580592f56f0e6c0e0318946f540822d809764268b5)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Ec2", jsii.invoke(self, "ifInstanceMarketType", [value, operator]))

    @jsii.member(jsii_name="ifInstanceMetadataTags")
    def if_instance_metadata_tags(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Ec2":
        '''(experimental) Filters access by whether the instance allows access to instance tags from the instance metadata.

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/iam-policy-structure.html#amazon-ec2-keys

        Applies to actions:

        - .toAssociateAddress()
        - .toAssociateIamInstanceProfile()
        - .toAttachNetworkInterface()
        - .toCreateImage()
        - .toCreateInstanceExportTask()
        - .toCreateReplaceRootVolumeTask()
        - .toCreateTags()
        - .toDescribeInstanceAttribute()
        - .toDetachNetworkInterface()
        - .toDisassociateIamInstanceProfile()
        - .toGetConsoleOutput()
        - .toGetConsoleScreenshot()
        - .toGetInstanceUefiData()
        - .toGetLaunchTemplateData()
        - .toGetPasswordData()
        - .toModifyInstanceAttribute()
        - .toModifyInstanceCapacityReservationAttributes()
        - .toModifyInstanceCreditSpecification()
        - .toModifyInstanceMaintenanceOptions()
        - .toModifyInstanceMetadataOptions()
        - .toModifyInstancePlacement()
        - .toModifyNetworkInterfaceAttribute()
        - .toModifyPrivateDnsNameOptions()
        - .toMonitorInstances()
        - .toRebootInstances()
        - .toReplaceIamInstanceProfileAssociation()
        - .toRunInstances()
        - .toSendDiagnosticInterrupt()
        - .toSendSpotInstanceInterruptions()
        - .toUnmonitorInstances()

        Applies to resource types:

        - instance

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ec4072195f2a341bc429350819ee61690ae6a86b79774ae9098b1f69b8a52d70)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Ec2", jsii.invoke(self, "ifInstanceMetadataTags", [value, operator]))

    @jsii.member(jsii_name="ifInstanceProfile")
    def if_instance_profile(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Ec2":
        '''(experimental) Filters access by the ARN of an instance profile.

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/iam-policy-structure.html#amazon-ec2-keys

        Applies to actions:

        - .toAssociateAddress()
        - .toAssociateIamInstanceProfile()
        - .toAttachClassicLinkVpc()
        - .toAttachNetworkInterface()
        - .toAttachVolume()
        - .toCreateFleet()
        - .toCreateImage()
        - .toCreateInstanceExportTask()
        - .toCreateNetworkInsightsPath()
        - .toCreateReplaceRootVolumeTask()
        - .toCreateSnapshots()
        - .toCreateTags()
        - .toDescribeInstanceAttribute()
        - .toDetachClassicLinkVpc()
        - .toDetachNetworkInterface()
        - .toDetachVolume()
        - .toDisassociateIamInstanceProfile()
        - .toGetConsoleOutput()
        - .toGetConsoleScreenshot()
        - .toGetInstanceUefiData()
        - .toGetLaunchTemplateData()
        - .toGetPasswordData()
        - .toModifyInstanceAttribute()
        - .toModifyInstanceCapacityReservationAttributes()
        - .toModifyInstanceCreditSpecification()
        - .toModifyInstanceMaintenanceOptions()
        - .toModifyInstanceMetadataOptions()
        - .toModifyInstancePlacement()
        - .toModifyNetworkInterfaceAttribute()
        - .toModifyPrivateDnsNameOptions()
        - .toMonitorInstances()
        - .toRebootInstances()
        - .toReplaceIamInstanceProfileAssociation()
        - .toResetInstanceAttribute()
        - .toRunInstances()
        - .toSendDiagnosticInterrupt()
        - .toSendSpotInstanceInterruptions()
        - .toStartInstances()
        - .toStopInstances()
        - .toTerminateInstances()
        - .toUnmonitorInstances()

        Applies to resource types:

        - instance

        :param value: The value(s) to check.
        :param operator: Works with `arn operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_ARN>`_. **Default:** ``ArnLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__60ef6ee8e9de0db3262a0f9a4f91c61ecfefd1368d88f226308d209659448735)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Ec2", jsii.invoke(self, "ifInstanceProfile", [value, operator]))

    @jsii.member(jsii_name="ifInstanceType")
    def if_instance_type(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Ec2":
        '''(experimental) Filters access by the type of instance.

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/iam-policy-structure.html#amazon-ec2-keys

        Applies to actions:

        - .toAllocateHosts()
        - .toAssociateAddress()
        - .toAssociateIamInstanceProfile()
        - .toAttachClassicLinkVpc()
        - .toAttachNetworkInterface()
        - .toAttachVolume()
        - .toCreateFleet()
        - .toCreateImage()
        - .toCreateInstanceExportTask()
        - .toCreateNetworkInsightsPath()
        - .toCreateReplaceRootVolumeTask()
        - .toCreateSnapshots()
        - .toCreateTags()
        - .toDescribeInstanceAttribute()
        - .toDetachClassicLinkVpc()
        - .toDetachNetworkInterface()
        - .toDetachVolume()
        - .toDisassociateIamInstanceProfile()
        - .toGetConsoleOutput()
        - .toGetConsoleScreenshot()
        - .toGetInstanceUefiData()
        - .toGetLaunchTemplateData()
        - .toGetPasswordData()
        - .toModifyInstanceAttribute()
        - .toModifyInstanceCapacityReservationAttributes()
        - .toModifyInstanceCreditSpecification()
        - .toModifyInstanceMaintenanceOptions()
        - .toModifyInstanceMetadataOptions()
        - .toModifyInstancePlacement()
        - .toModifyNetworkInterfaceAttribute()
        - .toModifyPrivateDnsNameOptions()
        - .toModifyReservedInstances()
        - .toMonitorInstances()
        - .toRebootInstances()
        - .toReplaceIamInstanceProfileAssociation()
        - .toResetInstanceAttribute()
        - .toRunInstances()
        - .toSendDiagnosticInterrupt()
        - .toSendSpotInstanceInterruptions()
        - .toStartInstances()
        - .toStopInstances()
        - .toTerminateInstances()
        - .toUnmonitorInstances()

        Applies to resource types:

        - dedicated-host
        - instance
        - reserved-instances

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d0ccbea6543a54803f5476132fe86bac0a1dfac79c5b7c6fa579fb377d6e22ab)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Ec2", jsii.invoke(self, "ifInstanceType", [value, operator]))

    @jsii.member(jsii_name="ifInternetGatewayID")
    def if_internet_gateway_id(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Ec2":
        '''(experimental) Filters access by the ID of an internet gateway.

        Applies to actions:

        - .toAssociateRouteTable()
        - .toAttachInternetGateway()
        - .toCreateInternetGateway()
        - .toCreateNetworkInsightsPath()
        - .toCreateTags()
        - .toDeleteInternetGateway()
        - .toDetachInternetGateway()
        - .toDisassociateRouteTable()

        Applies to resource types:

        - internet-gateway

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7a96e3dd0963776680872b6f7d373213400213202de1401a5f87fee65db3c4da)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Ec2", jsii.invoke(self, "ifInternetGatewayID", [value, operator]))

    @jsii.member(jsii_name="ifIpv4IpamPoolId")
    def if_ipv4_ipam_pool_id(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Ec2":
        '''(experimental) Filters access by the ID of an IPAM pool provided for IPv4 CIDR block allocation.

        Applies to actions:

        - .toAssociateVpcCidrBlock()
        - .toCreateVpc()

        Applies to resource types:

        - vpc

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__744909111fd3745942b4a34156a4259efc52cd9f4bda68b78827c214a72bd4c7)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Ec2", jsii.invoke(self, "ifIpv4IpamPoolId", [value, operator]))

    @jsii.member(jsii_name="ifIpv6IpamPoolId")
    def if_ipv6_ipam_pool_id(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Ec2":
        '''(experimental) Filters access by the ID of an IPAM pool provided for IPv6 CIDR block allocation.

        Applies to actions:

        - .toAssociateVpcCidrBlock()
        - .toCreateVpc()

        Applies to resource types:

        - vpc

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__989699a0b2daa2a369129d277980eb027374d2c3ae573195bee6bcb354de303a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Ec2", jsii.invoke(self, "ifIpv6IpamPoolId", [value, operator]))

    @jsii.member(jsii_name="ifIsLaunchTemplateResource")
    def if_is_launch_template_resource(
        self,
        value: typing.Optional[builtins.bool] = None,
    ) -> "Ec2":
        '''(experimental) Filters access by whether users are able to override resources that are specified in the launch template.

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/iam-policy-structure.html#amazon-ec2-keys

        Applies to actions:

        - .toRunInstances()

        Applies to resource types:

        - capacity-reservation
        - dedicated-host
        - elastic-gpu
        - image
        - instance
        - key-pair
        - launch-template
        - network-interface
        - placement-group
        - security-group
        - snapshot
        - subnet
        - volume

        :param value: ``true`` or ``false``. **Default:** ``true``

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__19a5ed61b4f065269a360dffbf17bfd6e5515fb0fcaf9baf3fe97617c726a941)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast("Ec2", jsii.invoke(self, "ifIsLaunchTemplateResource", [value]))

    @jsii.member(jsii_name="ifKeyPairName")
    def if_key_pair_name(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Ec2":
        '''(experimental) Filters access by the name of a key pair.

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/iam-policy-structure.html#amazon-ec2-keys

        Applies to actions:

        - .toCreateFleet()
        - .toCreateTags()
        - .toDeleteKeyPair()
        - .toModifyFleet()
        - .toRequestSpotFleet()
        - .toRequestSpotInstances()
        - .toRunInstances()
        - .toRunScheduledInstances()

        Applies to resource types:

        - key-pair

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9c8969b27ba178b9d4e39fb9ae660252f8c7f4f221d59b803ea185c24fa32ccd)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Ec2", jsii.invoke(self, "ifKeyPairName", [value, operator]))

    @jsii.member(jsii_name="ifKeyPairType")
    def if_key_pair_type(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Ec2":
        '''(experimental) Filters access by the type of a key pair.

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/iam-policy-structure.html#amazon-ec2-keys

        Applies to actions:

        - .toCreateFleet()
        - .toCreateKeyPair()
        - .toCreateTags()
        - .toDeleteKeyPair()
        - .toRequestSpotFleet()
        - .toRequestSpotInstances()
        - .toRunInstances()
        - .toRunScheduledInstances()

        Applies to resource types:

        - key-pair

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f9aa2d1d7b3eabe65c32ec35dd83be66e0df822d105ca8fdb42002fb8159873f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Ec2", jsii.invoke(self, "ifKeyPairType", [value, operator]))

    @jsii.member(jsii_name="ifKmsKeyId")
    def if_kms_key_id(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Ec2":
        '''(experimental) Filters access by the ID of an AWS KMS key.

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/iam-policy-structure.html#amazon-ec2-keys

        Applies to actions:

        - .toCreateFleet()
        - .toCreateVolume()

        Applies to resource types:

        - volume

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__74322a963c73c20e7e304c0b97fc78a8fc21a5c2701043e8fdd1889ca70ad35d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Ec2", jsii.invoke(self, "ifKmsKeyId", [value, operator]))

    @jsii.member(jsii_name="ifLaunchTemplate")
    def if_launch_template(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Ec2":
        '''(experimental) Filters access by the ARN of a launch template.

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/iam-policy-structure.html#amazon-ec2-keys

        Applies to actions:

        - .toRunInstances()

        Applies to resource types:

        - capacity-reservation
        - dedicated-host
        - elastic-gpu
        - image
        - instance
        - key-pair
        - launch-template
        - network-interface
        - placement-group
        - security-group
        - snapshot
        - subnet
        - volume

        :param value: The value(s) to check.
        :param operator: Works with `arn operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_ARN>`_. **Default:** ``ArnLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__28d1ed6dbf8ea017b547d99dd04c446b91632370da9e71ed12e53cead52f5414)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Ec2", jsii.invoke(self, "ifLaunchTemplate", [value, operator]))

    @jsii.member(jsii_name="ifLoadBalancerArn")
    def if_load_balancer_arn(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Ec2":
        '''(experimental) Filters access by the ARN of an Elastic Load Balancer.

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/iam-policy-structure.html#amazon-ec2-keys

        Applies to actions:

        - .toCreateTags()
        - .toCreateVerifiedAccessEndpoint()
        - .toDeleteVerifiedAccessEndpoint()
        - .toGetVerifiedAccessEndpointPolicy()
        - .toModifyVerifiedAccessEndpoint()
        - .toModifyVerifiedAccessEndpointPolicy()

        Applies to resource types:

        - verified-access-endpoint

        :param value: The value(s) to check.
        :param operator: Works with `arn operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_ARN>`_. **Default:** ``ArnLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__719b3c6674919f4a7510872a3c38351183d8b47711b175ddf273cbbac4bd10dd)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Ec2", jsii.invoke(self, "ifLoadBalancerArn", [value, operator]))

    @jsii.member(jsii_name="ifMetadataHttpEndpoint")
    def if_metadata_http_endpoint(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Ec2":
        '''(experimental) Filters access by whether the HTTP endpoint is enabled for the instance metadata service.

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/iam-policy-structure.html#amazon-ec2-keys

        Applies to actions:

        - .toAssociateAddress()
        - .toAssociateIamInstanceProfile()
        - .toAttachClassicLinkVpc()
        - .toAttachNetworkInterface()
        - .toAttachVolume()
        - .toCreateImage()
        - .toCreateInstanceExportTask()
        - .toCreateReplaceRootVolumeTask()
        - .toCreateTags()
        - .toDescribeInstanceAttribute()
        - .toDetachClassicLinkVpc()
        - .toDetachNetworkInterface()
        - .toDetachVolume()
        - .toDisassociateIamInstanceProfile()
        - .toGetConsoleOutput()
        - .toGetConsoleScreenshot()
        - .toGetInstanceUefiData()
        - .toGetLaunchTemplateData()
        - .toGetPasswordData()
        - .toModifyInstanceAttribute()
        - .toModifyInstanceCapacityReservationAttributes()
        - .toModifyInstanceCreditSpecification()
        - .toModifyInstanceMaintenanceOptions()
        - .toModifyInstanceMetadataOptions()
        - .toModifyInstancePlacement()
        - .toModifyNetworkInterfaceAttribute()
        - .toModifyPrivateDnsNameOptions()
        - .toMonitorInstances()
        - .toRebootInstances()
        - .toReplaceIamInstanceProfileAssociation()
        - .toResetInstanceAttribute()
        - .toRunInstances()
        - .toSendDiagnosticInterrupt()
        - .toSendSpotInstanceInterruptions()
        - .toTerminateInstances()
        - .toUnmonitorInstances()

        Applies to resource types:

        - instance

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d5e03acc1c2c0a9bd57d6d523e3aa2199072489f02c149c879f5f30be1263425)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Ec2", jsii.invoke(self, "ifMetadataHttpEndpoint", [value, operator]))

    @jsii.member(jsii_name="ifMetadataHttpPutResponseHopLimit")
    def if_metadata_http_put_response_hop_limit(
        self,
        value: typing.Union[jsii.Number, typing.Sequence[jsii.Number]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Ec2":
        '''(experimental) Filters access by the allowed number of hops when calling the instance metadata service.

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/iam-policy-structure.html#amazon-ec2-keys

        Applies to actions:

        - .toAssociateAddress()
        - .toAssociateIamInstanceProfile()
        - .toAttachClassicLinkVpc()
        - .toAttachNetworkInterface()
        - .toAttachVolume()
        - .toCreateImage()
        - .toCreateInstanceExportTask()
        - .toCreateReplaceRootVolumeTask()
        - .toCreateTags()
        - .toDescribeInstanceAttribute()
        - .toDetachClassicLinkVpc()
        - .toDetachNetworkInterface()
        - .toDetachVolume()
        - .toDisassociateIamInstanceProfile()
        - .toGetConsoleOutput()
        - .toGetConsoleScreenshot()
        - .toGetInstanceUefiData()
        - .toGetLaunchTemplateData()
        - .toGetPasswordData()
        - .toModifyInstanceAttribute()
        - .toModifyInstanceCapacityReservationAttributes()
        - .toModifyInstanceCreditSpecification()
        - .toModifyInstanceMaintenanceOptions()
        - .toModifyInstanceMetadataOptions()
        - .toModifyInstancePlacement()
        - .toModifyNetworkInterfaceAttribute()
        - .toModifyPrivateDnsNameOptions()
        - .toMonitorInstances()
        - .toRebootInstances()
        - .toReplaceIamInstanceProfileAssociation()
        - .toResetInstanceAttribute()
        - .toRunInstances()
        - .toSendDiagnosticInterrupt()
        - .toSendSpotInstanceInterruptions()
        - .toTerminateInstances()
        - .toUnmonitorInstances()

        Applies to resource types:

        - instance

        :param value: The value(s) to check.
        :param operator: Works with `numeric operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_Numeric>`_. **Default:** ``NumericEquals``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__597fe5e5a5947c1b961bc50d3a572528c4d3195d6f200d6e87c8a466018bb586)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Ec2", jsii.invoke(self, "ifMetadataHttpPutResponseHopLimit", [value, operator]))

    @jsii.member(jsii_name="ifMetadataHttpTokens")
    def if_metadata_http_tokens(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Ec2":
        '''(experimental) Filters access by whether tokens are required when calling the instance metadata service (optional or required).

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/iam-policy-structure.html#amazon-ec2-keys

        Applies to actions:

        - .toAssociateAddress()
        - .toAssociateIamInstanceProfile()
        - .toAttachClassicLinkVpc()
        - .toAttachNetworkInterface()
        - .toAttachVolume()
        - .toCreateImage()
        - .toCreateInstanceExportTask()
        - .toCreateReplaceRootVolumeTask()
        - .toCreateTags()
        - .toDescribeInstanceAttribute()
        - .toDetachClassicLinkVpc()
        - .toDetachNetworkInterface()
        - .toDetachVolume()
        - .toDisassociateIamInstanceProfile()
        - .toGetConsoleOutput()
        - .toGetConsoleScreenshot()
        - .toGetInstanceUefiData()
        - .toGetLaunchTemplateData()
        - .toGetPasswordData()
        - .toModifyInstanceAttribute()
        - .toModifyInstanceCapacityReservationAttributes()
        - .toModifyInstanceCreditSpecification()
        - .toModifyInstanceMaintenanceOptions()
        - .toModifyInstanceMetadataOptions()
        - .toModifyInstancePlacement()
        - .toModifyNetworkInterfaceAttribute()
        - .toModifyPrivateDnsNameOptions()
        - .toMonitorInstances()
        - .toRebootInstances()
        - .toReplaceIamInstanceProfileAssociation()
        - .toResetInstanceAttribute()
        - .toRunInstances()
        - .toSendDiagnosticInterrupt()
        - .toSendSpotInstanceInterruptions()
        - .toTerminateInstances()
        - .toUnmonitorInstances()

        Applies to resource types:

        - instance

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fb0d815ccec13ec83c0f19677807b9b8dade99d0d75c89d9410c27c523606e0d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Ec2", jsii.invoke(self, "ifMetadataHttpTokens", [value, operator]))

    @jsii.member(jsii_name="ifNetworkAclID")
    def if_network_acl_id(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Ec2":
        '''(experimental) Filters access by the ID of a network access control list (ACL).

        Applies to actions:

        - .toCreateNetworkAcl()
        - .toCreateNetworkAclEntry()
        - .toCreateTags()
        - .toDeleteNetworkAcl()
        - .toDeleteNetworkAclEntry()
        - .toReplaceNetworkAclAssociation()
        - .toReplaceNetworkAclEntry()

        Applies to resource types:

        - network-acl

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__51bf19b6d65720648bcba6d6ba8c3181fabdfa63728fdae5d906aec741215dae)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Ec2", jsii.invoke(self, "ifNetworkAclID", [value, operator]))

    @jsii.member(jsii_name="ifNetworkInterfaceID")
    def if_network_interface_id(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Ec2":
        '''(experimental) Filters access by the ID of an elastic network interface.

        Applies to actions:

        - .toAssignIpv6Addresses()
        - .toAssignPrivateIpAddresses()
        - .toAssociateAddress()
        - .toAttachNetworkInterface()
        - .toCreateFleet()
        - .toCreateFlowLogs()
        - .toCreateLocalGatewayRoute()
        - .toCreateNetworkInsightsPath()
        - .toCreateNetworkInterface()
        - .toCreateNetworkInterfacePermission()
        - .toCreateTags()
        - .toCreateTrafficMirrorSession()
        - .toCreateTrafficMirrorTarget()
        - .toCreateVerifiedAccessEndpoint()
        - .toDeleteNetworkInterface()
        - .toDeleteNetworkInterfacePermission()
        - .toDeregisterTransitGatewayMulticastGroupMembers()
        - .toDeregisterTransitGatewayMulticastGroupSources()
        - .toDetachNetworkInterface()
        - .toDisassociateAddress()
        - .toModifyFleet()
        - .toModifyLocalGatewayRoute()
        - .toModifyNetworkInterfaceAttribute()
        - .toRegisterTransitGatewayMulticastGroupMembers()
        - .toRegisterTransitGatewayMulticastGroupSources()
        - .toRequestSpotInstances()
        - .toResetNetworkInterfaceAttribute()
        - .toRunInstances()
        - .toRunScheduledInstances()
        - .toUnassignIpv6Addresses()
        - .toUnassignPrivateIpAddresses()

        Applies to resource types:

        - network-interface

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__266220e3276bb9566c3bb23f457e7db33f6e961539393f3fcf2c7fbdcff55115)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Ec2", jsii.invoke(self, "ifNetworkInterfaceID", [value, operator]))

    @jsii.member(jsii_name="ifNewInstanceProfile")
    def if_new_instance_profile(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Ec2":
        '''(experimental) Filters access by the ARN of the instance profile being attached.

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/iam-policy-structure.html#amazon-ec2-keys

        Applies to actions:

        - .toAssociateIamInstanceProfile()
        - .toGetConsoleScreenshot()
        - .toGetInstanceUefiData()
        - .toModifyPrivateDnsNameOptions()
        - .toReplaceIamInstanceProfileAssociation()

        Applies to resource types:

        - instance

        :param value: The value(s) to check.
        :param operator: Works with `arn operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_ARN>`_. **Default:** ``ArnLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__307c861dc4e5cb0868655a64ac38da6d71fa4baf2b19d9c402a9ebaca7ec2400)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Ec2", jsii.invoke(self, "ifNewInstanceProfile", [value, operator]))

    @jsii.member(jsii_name="ifOutpostArn")
    def if_outpost_arn(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Ec2":
        '''(experimental) Filters access by the ARN of the Outpost.

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/iam-policy-structure.html#amazon-ec2-keys

        Applies to actions:

        - .toCopySnapshot()
        - .toCreateImage()
        - .toCreateSnapshot()
        - .toCreateSnapshots()
        - .toDeleteSnapshot()
        - .toDescribeSnapshotAttribute()
        - .toRegisterImage()
        - .toRequestSpotFleet()
        - .toRequestSpotInstances()

        Applies to resource types:

        - snapshot

        :param value: The value(s) to check.
        :param operator: Works with `arn operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_ARN>`_. **Default:** ``ArnLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__aac6b27eb7663ff2a4f55124991af927882ef42d78b37f7699b39ed0f957852c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Ec2", jsii.invoke(self, "ifOutpostArn", [value, operator]))

    @jsii.member(jsii_name="ifOwner")
    def if_owner(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Ec2":
        '''(experimental) Filters access by the owner of the resource (amazon, aws-marketplace, or an AWS account ID).

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/iam-policy-structure.html#amazon-ec2-keys

        Applies to actions:

        - .toCancelImageLaunchPermission()
        - .toCopyFpgaImage()
        - .toCopyImage()
        - .toCreateFleet()
        - .toCreateFpgaImage()
        - .toCreateImage()
        - .toCreateReplaceRootVolumeTask()
        - .toCreateRestoreImageTask()
        - .toCreateStoreImageTask()
        - .toCreateTags()
        - .toDeleteFpgaImage()
        - .toDeleteSnapshot()
        - .toDeregisterImage()
        - .toDescribeFastLaunchImages()
        - .toDescribeFpgaImageAttribute()
        - .toDescribeImageAttribute()
        - .toDescribeSnapshotAttribute()
        - .toDescribeStoreImageTasks()
        - .toDisableFastLaunch()
        - .toDisableFastSnapshotRestores()
        - .toDisableImageDeprecation()
        - .toEnableFastLaunch()
        - .toEnableFastSnapshotRestores()
        - .toEnableImageDeprecation()
        - .toExportImage()
        - .toImportImage()
        - .toImportSnapshot()
        - .toListImagesInRecycleBin()
        - .toListSnapshotsInRecycleBin()
        - .toModifyFleet()
        - .toModifyFpgaImageAttribute()
        - .toModifyImageAttribute()
        - .toModifySnapshotAttribute()
        - .toModifySnapshotTier()
        - .toRegisterImage()
        - .toRequestSpotFleet()
        - .toRequestSpotInstances()
        - .toResetFpgaImageAttribute()
        - .toResetImageAttribute()
        - .toResetSnapshotAttribute()
        - .toRestoreImageFromRecycleBin()
        - .toRestoreSnapshotFromRecycleBin()
        - .toRestoreSnapshotTier()
        - .toRunInstances()
        - .toRunScheduledInstances()

        Applies to resource types:

        - fpga-image
        - image
        - snapshot

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6ad6bcb6cb10fd813f662a6dffc0d53874cef6acd7c9feb194806a73d0c92015)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Ec2", jsii.invoke(self, "ifOwner", [value, operator]))

    @jsii.member(jsii_name="ifParentSnapshot")
    def if_parent_snapshot(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Ec2":
        '''(experimental) Filters access by the ARN of the parent snapshot.

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/iam-policy-structure.html#amazon-ec2-keys

        Applies to actions:

        - .toAttachVolume()
        - .toCreateFleet()
        - .toCreateTags()
        - .toCreateVolume()
        - .toDeleteVolume()
        - .toDescribeVolumeAttribute()
        - .toDetachVolume()
        - .toEnableVolumeIO()
        - .toImportInstance()
        - .toImportVolume()
        - .toModifyInstanceAttribute()
        - .toModifyVolume()
        - .toModifyVolumeAttribute()
        - .toRunInstances()

        Applies to resource types:

        - volume

        :param value: The value(s) to check.
        :param operator: Works with `arn operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_ARN>`_. **Default:** ``ArnLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f5dc567ddf96b17e83583e7246e0ec7e2b606ba8d0b3499c7933eada2d187920)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Ec2", jsii.invoke(self, "ifParentSnapshot", [value, operator]))

    @jsii.member(jsii_name="ifParentVolume")
    def if_parent_volume(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Ec2":
        '''(experimental) Filters access by the ARN of the parent volume from which the snapshot was created.

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/iam-policy-structure.html#amazon-ec2-keys

        Applies to actions:

        - .toCreateFleet()
        - .toCreateImage()
        - .toCreateReplaceRootVolumeTask()
        - .toCreateSnapshot()
        - .toCreateSnapshots()
        - .toCreateTags()
        - .toDeleteSnapshot()
        - .toDescribeSnapshotAttribute()
        - .toDisableFastSnapshotRestores()
        - .toEnableFastSnapshotRestores()
        - .toImportImage()
        - .toImportSnapshot()
        - .toListSnapshotsInRecycleBin()
        - .toModifyFleet()
        - .toModifySnapshotAttribute()
        - .toModifySnapshotTier()
        - .toRegisterImage()
        - .toRequestSpotFleet()
        - .toRequestSpotInstances()
        - .toResetSnapshotAttribute()
        - .toRestoreSnapshotFromRecycleBin()
        - .toRestoreSnapshotTier()
        - .toRunInstances()
        - .toRunScheduledInstances()

        Applies to resource types:

        - snapshot

        :param value: The value(s) to check.
        :param operator: Works with `arn operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_ARN>`_. **Default:** ``ArnLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fdbf4a59f3ca63c5c338dd68bb745dbccd13124b27c3aa032a870c4db9bd4190)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Ec2", jsii.invoke(self, "ifParentVolume", [value, operator]))

    @jsii.member(jsii_name="ifPermission")
    def if_permission(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Ec2":
        '''(experimental) Filters access by the type of permission for a resource (INSTANCE-ATTACH or EIP-ASSOCIATE).

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/iam-policy-structure.html#amazon-ec2-keys

        Applies to actions:

        - .toCreateNetworkInterfacePermission()
        - .toCreateTags()
        - .toCreateVerifiedAccessEndpoint()
        - .toModifyLocalGatewayRoute()
        - .toRequestSpotInstances()

        Applies to resource types:

        - network-interface

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0d46dc0f007e0d14be9d3cddc505761382ec31623641c023198b6f14c24871cf)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Ec2", jsii.invoke(self, "ifPermission", [value, operator]))

    @jsii.member(jsii_name="ifPhase1DHGroup")
    def if_phase1_dh_group(
        self,
        value: typing.Union[jsii.Number, typing.Sequence[jsii.Number]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Ec2":
        '''(experimental) Filters access by the Diffie-Hellman group numbers that are permitted for a VPN tunnel for the phase 1 IKE negotiations.

        https://docs.aws.amazon.com/vpn/latest/s2svpn/vpn-authentication-access-control.html

        Applies to actions:

        - .toCreateTags()
        - .toCreateVpnConnection()
        - .toModifyVpnConnection()
        - .toModifyVpnTunnelOptions()

        Applies to resource types:

        - vpn-connection

        :param value: The value(s) to check.
        :param operator: Works with `numeric operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_Numeric>`_. **Default:** ``NumericEquals``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7c2ccf717d03cc99f6c3256e4466fed89f6cc95525fc39a52c693e245a53774b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Ec2", jsii.invoke(self, "ifPhase1DHGroup", [value, operator]))

    @jsii.member(jsii_name="ifPhase1EncryptionAlgorithms")
    def if_phase1_encryption_algorithms(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Ec2":
        '''(experimental) Filters access by the encryption algorithms that are permitted for a VPN tunnel for the phase 1 IKE negotiations.

        https://docs.aws.amazon.com/vpn/latest/s2svpn/vpn-authentication-access-control.html

        Applies to actions:

        - .toCreateTags()
        - .toCreateVpnConnection()
        - .toModifyVpnConnection()
        - .toModifyVpnTunnelOptions()

        Applies to resource types:

        - vpn-connection

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0066a1edbd928ed3e9ed4390a688975c63e49a10842a496e7d3fccd6a002c7d3)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Ec2", jsii.invoke(self, "ifPhase1EncryptionAlgorithms", [value, operator]))

    @jsii.member(jsii_name="ifPhase1IntegrityAlgorithms")
    def if_phase1_integrity_algorithms(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Ec2":
        '''(experimental) Filters access by the integrity algorithms that are permitted for a VPN tunnel for the phase 1 IKE negotiations.

        https://docs.aws.amazon.com/vpn/latest/s2svpn/vpn-authentication-access-control.html

        Applies to actions:

        - .toCreateTags()
        - .toCreateVpnConnection()
        - .toModifyVpnConnection()
        - .toModifyVpnTunnelOptions()

        Applies to resource types:

        - vpn-connection

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__49108caedd2e2248a34c77de27c2cec889f740d7062f503b03fe8513460cf7bd)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Ec2", jsii.invoke(self, "ifPhase1IntegrityAlgorithms", [value, operator]))

    @jsii.member(jsii_name="ifPhase1LifetimeSeconds")
    def if_phase1_lifetime_seconds(
        self,
        value: typing.Union[jsii.Number, typing.Sequence[jsii.Number]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Ec2":
        '''(experimental) Filters access by the lifetime in seconds for phase 1 of the IKE negotiations for a VPN tunnel.

        https://docs.aws.amazon.com/vpn/latest/s2svpn/vpn-authentication-access-control.html

        Applies to actions:

        - .toCreateTags()
        - .toCreateVpnConnection()
        - .toModifyVpnConnection()
        - .toModifyVpnTunnelOptions()

        Applies to resource types:

        - vpn-connection

        :param value: The value(s) to check.
        :param operator: Works with `numeric operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_Numeric>`_. **Default:** ``NumericEquals``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c11142849641b07bd5b23f1411b3e75911fa61ad4281a6db3df02a8dfd697603)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Ec2", jsii.invoke(self, "ifPhase1LifetimeSeconds", [value, operator]))

    @jsii.member(jsii_name="ifPhase2DHGroup")
    def if_phase2_dh_group(
        self,
        value: typing.Union[jsii.Number, typing.Sequence[jsii.Number]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Ec2":
        '''(experimental) Filters access by the Diffie-Hellman group numbers that are permitted for a VPN tunnel for the phase 2 IKE negotiations.

        https://docs.aws.amazon.com/vpn/latest/s2svpn/vpn-authentication-access-control.html

        Applies to actions:

        - .toCreateTags()
        - .toCreateVpnConnection()
        - .toModifyVpnConnection()
        - .toModifyVpnTunnelOptions()

        Applies to resource types:

        - vpn-connection

        :param value: The value(s) to check.
        :param operator: Works with `numeric operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_Numeric>`_. **Default:** ``NumericEquals``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c53bada1e6fbe04ff888517b90e8088f10df08f531c83064798f9670dd950dab)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Ec2", jsii.invoke(self, "ifPhase2DHGroup", [value, operator]))

    @jsii.member(jsii_name="ifPhase2EncryptionAlgorithms")
    def if_phase2_encryption_algorithms(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Ec2":
        '''(experimental) Filters access by the encryption algorithms that are permitted for a VPN tunnel for the phase 2 IKE negotiations.

        https://docs.aws.amazon.com/vpn/latest/s2svpn/vpn-authentication-access-control.html

        Applies to actions:

        - .toCreateTags()
        - .toCreateVpnConnection()
        - .toModifyVpnConnection()
        - .toModifyVpnTunnelOptions()

        Applies to resource types:

        - vpn-connection

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bfeae2b3d57884115cda9453cbc8d9d5d3e8e3ace5e80c0123671217c3a6c14d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Ec2", jsii.invoke(self, "ifPhase2EncryptionAlgorithms", [value, operator]))

    @jsii.member(jsii_name="ifPhase2IntegrityAlgorithms")
    def if_phase2_integrity_algorithms(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Ec2":
        '''(experimental) Filters access by the integrity algorithms that are permitted for a VPN tunnel for the phase 2 IKE negotiations.

        https://docs.aws.amazon.com/vpn/latest/s2svpn/vpn-authentication-access-control.html

        Applies to actions:

        - .toCreateTags()
        - .toCreateVpnConnection()
        - .toModifyVpnConnection()
        - .toModifyVpnTunnelOptions()

        Applies to resource types:

        - vpn-connection

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__054fc6df4dee823c85bbcd351721899c0e221d442daa604c13d3ecaaededa4c2)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Ec2", jsii.invoke(self, "ifPhase2IntegrityAlgorithms", [value, operator]))

    @jsii.member(jsii_name="ifPhase2LifetimeSeconds")
    def if_phase2_lifetime_seconds(
        self,
        value: typing.Union[jsii.Number, typing.Sequence[jsii.Number]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Ec2":
        '''(experimental) Filters access by the lifetime in seconds for phase 2 of the IKE negotiations for a VPN tunnel.

        https://docs.aws.amazon.com/vpn/latest/s2svpn/vpn-authentication-access-control.html

        Applies to actions:

        - .toCreateTags()
        - .toCreateVpnConnection()
        - .toModifyVpnConnection()
        - .toModifyVpnTunnelOptions()

        Applies to resource types:

        - vpn-connection

        :param value: The value(s) to check.
        :param operator: Works with `numeric operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_Numeric>`_. **Default:** ``NumericEquals``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7e659b83d4606871b16579c89ed135f5154e788ab8235205d7268b466cdd30fd)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Ec2", jsii.invoke(self, "ifPhase2LifetimeSeconds", [value, operator]))

    @jsii.member(jsii_name="ifPlacementGroup")
    def if_placement_group(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Ec2":
        '''(experimental) Filters access by the ARN of the placement group.

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/iam-policy-structure.html#amazon-ec2-keys

        Applies to actions:

        - .toAssociateAddress()
        - .toAssociateIamInstanceProfile()
        - .toAttachClassicLinkVpc()
        - .toAttachNetworkInterface()
        - .toAttachVolume()
        - .toCreateFleet()
        - .toCreateImage()
        - .toCreateNetworkInsightsPath()
        - .toCreateReplaceRootVolumeTask()
        - .toCreateSnapshots()
        - .toCreateTags()
        - .toDescribeInstanceAttribute()
        - .toDetachClassicLinkVpc()
        - .toDetachNetworkInterface()
        - .toDetachVolume()
        - .toDisassociateIamInstanceProfile()
        - .toGetConsoleOutput()
        - .toGetConsoleScreenshot()
        - .toGetInstanceUefiData()
        - .toGetLaunchTemplateData()
        - .toGetPasswordData()
        - .toModifyInstanceAttribute()
        - .toModifyInstanceCapacityReservationAttributes()
        - .toModifyInstanceCreditSpecification()
        - .toModifyInstanceMaintenanceOptions()
        - .toModifyInstanceMetadataOptions()
        - .toModifyInstancePlacement()
        - .toModifyNetworkInterfaceAttribute()
        - .toModifyPrivateDnsNameOptions()
        - .toMonitorInstances()
        - .toRebootInstances()
        - .toReplaceIamInstanceProfileAssociation()
        - .toRunInstances()
        - .toStartInstances()
        - .toStopInstances()
        - .toTerminateInstances()
        - .toUnmonitorInstances()

        Applies to resource types:

        - instance

        :param value: The value(s) to check.
        :param operator: Works with `arn operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_ARN>`_. **Default:** ``ArnLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ebc2077b159606cbbae4dde37b90e73ec78012ddf1c5f8336faa5497fa2c5028)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Ec2", jsii.invoke(self, "ifPlacementGroup", [value, operator]))

    @jsii.member(jsii_name="ifPlacementGroupName")
    def if_placement_group_name(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Ec2":
        '''(experimental) Filters access by the name of a placement group.

        Applies to actions:

        - .toCreateFleet()
        - .toCreatePlacementGroup()
        - .toCreateTags()
        - .toDeletePlacementGroup()
        - .toDeleteResourcePolicy()
        - .toGetResourcePolicy()
        - .toModifyInstancePlacement()
        - .toPutResourcePolicy()
        - .toRequestSpotFleet()
        - .toRequestSpotInstances()
        - .toRunInstances()
        - .toRunScheduledInstances()

        Applies to resource types:

        - placement-group

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3d63678cd13dc3800fb6c9899405d99a181c045082385917ea38fddf139d72f2)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Ec2", jsii.invoke(self, "ifPlacementGroupName", [value, operator]))

    @jsii.member(jsii_name="ifPlacementGroupStrategy")
    def if_placement_group_strategy(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Ec2":
        '''(experimental) Filters access by the instance placement strategy used by the placement group (cluster, spread, or partition).

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/iam-policy-structure.html#amazon-ec2-keys

        Applies to actions:

        - .toCreateFleet()
        - .toCreatePlacementGroup()
        - .toCreateTags()
        - .toDeletePlacementGroup()
        - .toDeleteResourcePolicy()
        - .toGetResourcePolicy()
        - .toModifyInstancePlacement()
        - .toPutResourcePolicy()
        - .toRequestSpotFleet()
        - .toRequestSpotInstances()
        - .toRunInstances()
        - .toRunScheduledInstances()

        Applies to resource types:

        - placement-group

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c05bc1b229aca753b7e0fa43e18c3f66132e2cba3a9aa851d3ec000e1bd2c0c3)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Ec2", jsii.invoke(self, "ifPlacementGroupStrategy", [value, operator]))

    @jsii.member(jsii_name="ifPreSharedKeys")
    def if_pre_shared_keys(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Ec2":
        '''(experimental) Filters access by the pre-shared key (PSK) used to establish the initial IKE security association between a virtual private gateway and a customer gateway.

        https://docs.aws.amazon.com/vpn/latest/s2svpn/vpn-authentication-access-control.html

        Applies to actions:

        - .toCreateTags()
        - .toCreateVpnConnection()
        - .toModifyVpnConnection()
        - .toModifyVpnTunnelOptions()

        Applies to resource types:

        - vpn-connection

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0412c8c4e804a75b1ef9acc068f7ed63211aa724dcb401fc87718549f1ad994e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Ec2", jsii.invoke(self, "ifPreSharedKeys", [value, operator]))

    @jsii.member(jsii_name="ifProductCode")
    def if_product_code(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Ec2":
        '''(experimental) Filters access by the product code that is associated with the AMI.

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/iam-policy-structure.html#amazon-ec2-keys

        Applies to actions:

        - .toAssociateAddress()
        - .toAssociateIamInstanceProfile()
        - .toAttachNetworkInterface()
        - .toAttachVolume()
        - .toCreateImage()
        - .toCreateInstanceExportTask()
        - .toCreateReplaceRootVolumeTask()
        - .toCreateTags()
        - .toDescribeInstanceAttribute()
        - .toDetachNetworkInterface()
        - .toDetachVolume()
        - .toDisassociateIamInstanceProfile()
        - .toGetConsoleOutput()
        - .toGetConsoleScreenshot()
        - .toGetInstanceUefiData()
        - .toGetLaunchTemplateData()
        - .toGetPasswordData()
        - .toModifyInstanceAttribute()
        - .toModifyInstanceCapacityReservationAttributes()
        - .toModifyInstanceCreditSpecification()
        - .toModifyInstanceMaintenanceOptions()
        - .toModifyInstanceMetadataOptions()
        - .toModifyInstancePlacement()
        - .toModifyNetworkInterfaceAttribute()
        - .toModifyPrivateDnsNameOptions()
        - .toMonitorInstances()
        - .toRebootInstances()
        - .toReplaceIamInstanceProfileAssociation()
        - .toResetInstanceAttribute()
        - .toRunInstances()
        - .toUnmonitorInstances()

        Applies to resource types:

        - instance

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4823539c3c1c3ff47ddd949e999f730039635a3ff6fff636fb5a423c04aa26fe)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Ec2", jsii.invoke(self, "ifProductCode", [value, operator]))

    @jsii.member(jsii_name="ifPublic")
    def if_public(self, value: typing.Optional[builtins.bool] = None) -> "Ec2":
        '''(experimental) Filters access by whether the image has public launch permissions.

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/iam-policy-structure.html#amazon-ec2-keys

        Applies to actions:

        - .toCancelImageLaunchPermission()
        - .toCreateFleet()
        - .toCreateFpgaImage()
        - .toCreateReplaceRootVolumeTask()
        - .toCreateStoreImageTask()
        - .toCreateTags()
        - .toDeleteFpgaImage()
        - .toDeregisterImage()
        - .toDescribeFastLaunchImages()
        - .toDescribeImageAttribute()
        - .toDescribeStoreImageTasks()
        - .toDisableFastLaunch()
        - .toDisableImageDeprecation()
        - .toEnableFastLaunch()
        - .toEnableImageDeprecation()
        - .toExportImage()
        - .toImportImage()
        - .toListImagesInRecycleBin()
        - .toModifyFleet()
        - .toModifyFpgaImageAttribute()
        - .toModifyImageAttribute()
        - .toRequestSpotFleet()
        - .toRequestSpotInstances()
        - .toResetFpgaImageAttribute()
        - .toResetImageAttribute()
        - .toRestoreImageFromRecycleBin()
        - .toRunInstances()
        - .toRunScheduledInstances()

        Applies to resource types:

        - fpga-image
        - image

        :param value: ``true`` or ``false``. **Default:** ``true``

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3de4d6e9b9b7b137277b8dce374a06bdd6df76c6bf8b4c3a9d4c1c194efd2f4f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast("Ec2", jsii.invoke(self, "ifPublic", [value]))

    @jsii.member(jsii_name="ifPublicIpAddress")
    def if_public_ip_address(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Ec2":
        '''(experimental) Filters access by a public IP address.

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/iam-policy-structure.html#amazon-ec2-keys

        Applies to actions:

        - .toAcceptAddressTransfer()
        - .toAssociateAddress()
        - .toCreateNatGateway()
        - .toCreateTags()
        - .toDescribeAddressesAttribute()
        - .toDisableAddressTransfer()
        - .toDisassociateAddress()
        - .toEnableAddressTransfer()
        - .toModifyAddressAttribute()
        - .toReleaseAddress()
        - .toResetAddressAttribute()

        Applies to resource types:

        - elastic-ip

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__79ece51f24f1bbe98dc2a72051d7794e71831798f42ad21843df6db9d1026873)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Ec2", jsii.invoke(self, "ifPublicIpAddress", [value, operator]))

    @jsii.member(jsii_name="ifQuantity")
    def if_quantity(
        self,
        value: typing.Union[jsii.Number, typing.Sequence[jsii.Number]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Ec2":
        '''(experimental) Filters access by the number of Dedicated Hosts in a request.

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/iam-policy-structure.html#amazon-ec2-keys

        Applies to actions:

        - .toAllocateHosts()
        - .toCreateTags()

        Applies to resource types:

        - dedicated-host

        :param value: The value(s) to check.
        :param operator: Works with `numeric operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_Numeric>`_. **Default:** ``NumericEquals``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a393844f6cff7c87a92759c72e23c429e11b36f5bf4e21c06c5faba0e34ffd02)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Ec2", jsii.invoke(self, "ifQuantity", [value, operator]))

    @jsii.member(jsii_name="ifRegion")
    def if_region(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Ec2":
        '''(experimental) Filters access by the name of the AWS Region.

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/iam-policy-structure.html#amazon-ec2-keys

        Applies to actions:

        - .toAcceptAddressTransfer()
        - .toAcceptReservedInstancesExchangeQuote()
        - .toAcceptTransitGatewayMulticastDomainAssociations()
        - .toAcceptTransitGatewayPeeringAttachment()
        - .toAcceptTransitGatewayVpcAttachment()
        - .toAcceptVpcEndpointConnections()
        - .toAcceptVpcPeeringConnection()
        - .toAdvertiseByoipCidr()
        - .toAllocateAddress()
        - .toAllocateHosts()
        - .toAllocateIpamPoolCidr()
        - .toApplySecurityGroupsToClientVpnTargetNetwork()
        - .toAssignIpv6Addresses()
        - .toAssignPrivateIpAddresses()
        - .toAssociateAddress()
        - .toAssociateClientVpnTargetNetwork()
        - .toAssociateDhcpOptions()
        - .toAssociateEnclaveCertificateIamRole()
        - .toAssociateIamInstanceProfile()
        - .toAssociateInstanceEventWindow()
        - .toAssociateRouteTable()
        - .toAssociateSubnetCidrBlock()
        - .toAssociateTransitGatewayMulticastDomain()
        - .toAssociateTransitGatewayPolicyTable()
        - .toAssociateTransitGatewayRouteTable()
        - .toAssociateTrunkInterface()
        - .toAssociateVpcCidrBlock()
        - .toAttachClassicLinkVpc()
        - .toAttachInternetGateway()
        - .toAttachNetworkInterface()
        - .toAttachVerifiedAccessTrustProvider()
        - .toAttachVolume()
        - .toAttachVpnGateway()
        - .toAuthorizeClientVpnIngress()
        - .toAuthorizeSecurityGroupEgress()
        - .toAuthorizeSecurityGroupIngress()
        - .toBundleInstance()
        - .toCancelBundleTask()
        - .toCancelCapacityReservation()
        - .toCancelCapacityReservationFleets()
        - .toCancelConversionTask()
        - .toCancelExportTask()
        - .toCancelImageLaunchPermission()
        - .toCancelImportTask()
        - .toCancelReservedInstancesListing()
        - .toCancelSpotFleetRequests()
        - .toCancelSpotInstanceRequests()
        - .toConfirmProductInstance()
        - .toCopyFpgaImage()
        - .toCopyImage()
        - .toCopySnapshot()
        - .toCreateCapacityReservation()
        - .toCreateCapacityReservationFleet()
        - .toCreateCarrierGateway()
        - .toCreateClientVpnEndpoint()
        - .toCreateClientVpnRoute()
        - .toCreateCoipCidr()
        - .toCreateCoipPool()
        - .toCreateCoipPoolPermission()
        - .toCreateCustomerGateway()
        - .toCreateDefaultSubnet()
        - .toCreateDefaultVpc()
        - .toCreateDhcpOptions()
        - .toCreateEgressOnlyInternetGateway()
        - .toCreateFleet()
        - .toCreateFlowLogs()
        - .toCreateFpgaImage()
        - .toCreateImage()
        - .toCreateInstanceEventWindow()
        - .toCreateInstanceExportTask()
        - .toCreateInternetGateway()
        - .toCreateIpam()
        - .toCreateIpamPool()
        - .toCreateIpamScope()
        - .toCreateKeyPair()
        - .toCreateLaunchTemplate()
        - .toCreateLaunchTemplateVersion()
        - .toCreateLocalGatewayRoute()
        - .toCreateLocalGatewayRouteTable()
        - .toCreateLocalGatewayRouteTablePermission()
        - .toCreateLocalGatewayRouteTableVirtualInterfaceGroupAssociation()
        - .toCreateLocalGatewayRouteTableVpcAssociation()
        - .toCreateManagedPrefixList()
        - .toCreateNatGateway()
        - .toCreateNetworkAcl()
        - .toCreateNetworkAclEntry()
        - .toCreateNetworkInsightsAccessScope()
        - .toCreateNetworkInsightsPath()
        - .toCreateNetworkInterface()
        - .toCreateNetworkInterfacePermission()
        - .toCreatePlacementGroup()
        - .toCreatePublicIpv4Pool()
        - .toCreateReplaceRootVolumeTask()
        - .toCreateReservedInstancesListing()
        - .toCreateRestoreImageTask()
        - .toCreateRoute()
        - .toCreateRouteTable()
        - .toCreateSecurityGroup()
        - .toCreateSnapshot()
        - .toCreateSnapshots()
        - .toCreateSpotDatafeedSubscription()
        - .toCreateStoreImageTask()
        - .toCreateSubnet()
        - .toCreateSubnetCidrReservation()
        - .toCreateTags()
        - .toCreateTrafficMirrorFilter()
        - .toCreateTrafficMirrorFilterRule()
        - .toCreateTrafficMirrorSession()
        - .toCreateTrafficMirrorTarget()
        - .toCreateTransitGateway()
        - .toCreateTransitGatewayConnect()
        - .toCreateTransitGatewayConnectPeer()
        - .toCreateTransitGatewayMulticastDomain()
        - .toCreateTransitGatewayPeeringAttachment()
        - .toCreateTransitGatewayPolicyTable()
        - .toCreateTransitGatewayPrefixListReference()
        - .toCreateTransitGatewayRoute()
        - .toCreateTransitGatewayRouteTable()
        - .toCreateTransitGatewayRouteTableAnnouncement()
        - .toCreateTransitGatewayVpcAttachment()
        - .toCreateVerifiedAccessEndpoint()
        - .toCreateVerifiedAccessGroup()
        - .toCreateVerifiedAccessInstance()
        - .toCreateVerifiedAccessTrustProvider()
        - .toCreateVolume()
        - .toCreateVpc()
        - .toCreateVpcEndpoint()
        - .toCreateVpcEndpointConnectionNotification()
        - .toCreateVpcEndpointServiceConfiguration()
        - .toCreateVpcPeeringConnection()
        - .toCreateVpnConnection()
        - .toCreateVpnConnectionRoute()
        - .toCreateVpnGateway()
        - .toDeleteCarrierGateway()
        - .toDeleteClientVpnEndpoint()
        - .toDeleteClientVpnRoute()
        - .toDeleteCoipCidr()
        - .toDeleteCoipPool()
        - .toDeleteCoipPoolPermission()
        - .toDeleteCustomerGateway()
        - .toDeleteDhcpOptions()
        - .toDeleteEgressOnlyInternetGateway()
        - .toDeleteFleets()
        - .toDeleteFlowLogs()
        - .toDeleteFpgaImage()
        - .toDeleteInstanceEventWindow()
        - .toDeleteInternetGateway()
        - .toDeleteIpam()
        - .toDeleteIpamPool()
        - .toDeleteIpamScope()
        - .toDeleteKeyPair()
        - .toDeleteLaunchTemplate()
        - .toDeleteLaunchTemplateVersions()
        - .toDeleteLocalGatewayRoute()
        - .toDeleteLocalGatewayRouteTable()
        - .toDeleteLocalGatewayRouteTablePermission()
        - .toDeleteLocalGatewayRouteTableVirtualInterfaceGroupAssociation()
        - .toDeleteLocalGatewayRouteTableVpcAssociation()
        - .toDeleteManagedPrefixList()
        - .toDeleteNatGateway()
        - .toDeleteNetworkAcl()
        - .toDeleteNetworkAclEntry()
        - .toDeleteNetworkInsightsAccessScope()
        - .toDeleteNetworkInsightsAccessScopeAnalysis()
        - .toDeleteNetworkInsightsAnalysis()
        - .toDeleteNetworkInsightsPath()
        - .toDeleteNetworkInterface()
        - .toDeleteNetworkInterfacePermission()
        - .toDeletePlacementGroup()
        - .toDeletePublicIpv4Pool()
        - .toDeleteQueuedReservedInstances()
        - .toDeleteResourcePolicy()
        - .toDeleteRoute()
        - .toDeleteRouteTable()
        - .toDeleteSecurityGroup()
        - .toDeleteSnapshot()
        - .toDeleteSpotDatafeedSubscription()
        - .toDeleteSubnet()
        - .toDeleteSubnetCidrReservation()
        - .toDeleteTags()
        - .toDeleteTrafficMirrorFilter()
        - .toDeleteTrafficMirrorFilterRule()
        - .toDeleteTrafficMirrorSession()
        - .toDeleteTrafficMirrorTarget()
        - .toDeleteTransitGateway()
        - .toDeleteTransitGatewayConnect()
        - .toDeleteTransitGatewayConnectPeer()
        - .toDeleteTransitGatewayMulticastDomain()
        - .toDeleteTransitGatewayPeeringAttachment()
        - .toDeleteTransitGatewayPolicyTable()
        - .toDeleteTransitGatewayPrefixListReference()
        - .toDeleteTransitGatewayRoute()
        - .toDeleteTransitGatewayRouteTable()
        - .toDeleteTransitGatewayRouteTableAnnouncement()
        - .toDeleteTransitGatewayVpcAttachment()
        - .toDeleteVerifiedAccessEndpoint()
        - .toDeleteVerifiedAccessGroup()
        - .toDeleteVerifiedAccessInstance()
        - .toDeleteVerifiedAccessTrustProvider()
        - .toDeleteVolume()
        - .toDeleteVpc()
        - .toDeleteVpcEndpointConnectionNotifications()
        - .toDeleteVpcEndpointServiceConfigurations()
        - .toDeleteVpcEndpoints()
        - .toDeleteVpcPeeringConnection()
        - .toDeleteVpnConnection()
        - .toDeleteVpnConnectionRoute()
        - .toDeleteVpnGateway()
        - .toDeprovisionByoipCidr()
        - .toDeprovisionIpamPoolCidr()
        - .toDeprovisionPublicIpv4PoolCidr()
        - .toDeregisterImage()
        - .toDeregisterInstanceEventNotificationAttributes()
        - .toDeregisterTransitGatewayMulticastGroupMembers()
        - .toDeregisterTransitGatewayMulticastGroupSources()
        - .toDescribeAccountAttributes()
        - .toDescribeAddressTransfers()
        - .toDescribeAddresses()
        - .toDescribeAddressesAttribute()
        - .toDescribeAggregateIdFormat()
        - .toDescribeAvailabilityZones()
        - .toDescribeAwsNetworkPerformanceMetricSubscriptions()
        - .toDescribeBundleTasks()
        - .toDescribeByoipCidrs()
        - .toDescribeCapacityReservationFleets()
        - .toDescribeCapacityReservations()
        - .toDescribeCarrierGateways()
        - .toDescribeClassicLinkInstances()
        - .toDescribeClientVpnAuthorizationRules()
        - .toDescribeClientVpnConnections()
        - .toDescribeClientVpnEndpoints()
        - .toDescribeClientVpnRoutes()
        - .toDescribeClientVpnTargetNetworks()
        - .toDescribeCoipPools()
        - .toDescribeConversionTasks()
        - .toDescribeCustomerGateways()
        - .toDescribeDhcpOptions()
        - .toDescribeEgressOnlyInternetGateways()
        - .toDescribeElasticGpus()
        - .toDescribeExportImageTasks()
        - .toDescribeExportTasks()
        - .toDescribeFastLaunchImages()
        - .toDescribeFastSnapshotRestores()
        - .toDescribeFleetHistory()
        - .toDescribeFleetInstances()
        - .toDescribeFleets()
        - .toDescribeFlowLogs()
        - .toDescribeFpgaImageAttribute()
        - .toDescribeFpgaImages()
        - .toDescribeHostReservationOfferings()
        - .toDescribeHostReservations()
        - .toDescribeHosts()
        - .toDescribeIamInstanceProfileAssociations()
        - .toDescribeIdFormat()
        - .toDescribeIdentityIdFormat()
        - .toDescribeImageAttribute()
        - .toDescribeImages()
        - .toDescribeImportImageTasks()
        - .toDescribeImportSnapshotTasks()
        - .toDescribeInstanceAttribute()
        - .toDescribeInstanceCreditSpecifications()
        - .toDescribeInstanceEventNotificationAttributes()
        - .toDescribeInstanceEventWindows()
        - .toDescribeInstanceStatus()
        - .toDescribeInstanceTypeOfferings()
        - .toDescribeInstanceTypes()
        - .toDescribeInstances()
        - .toDescribeInternetGateways()
        - .toDescribeIpamPools()
        - .toDescribeIpamScopes()
        - .toDescribeIpams()
        - .toDescribeIpv6Pools()
        - .toDescribeKeyPairs()
        - .toDescribeLaunchTemplateVersions()
        - .toDescribeLaunchTemplates()
        - .toDescribeLocalGatewayRouteTablePermissions()
        - .toDescribeLocalGatewayRouteTableVirtualInterfaceGroupAssociations()
        - .toDescribeLocalGatewayRouteTableVpcAssociations()
        - .toDescribeLocalGatewayRouteTables()
        - .toDescribeLocalGatewayVirtualInterfaceGroups()
        - .toDescribeLocalGatewayVirtualInterfaces()
        - .toDescribeLocalGateways()
        - .toDescribeManagedPrefixLists()
        - .toDescribeMovingAddresses()
        - .toDescribeNatGateways()
        - .toDescribeNetworkAcls()
        - .toDescribeNetworkInsightsAccessScopeAnalyses()
        - .toDescribeNetworkInsightsAccessScopes()
        - .toDescribeNetworkInsightsAnalyses()
        - .toDescribeNetworkInsightsPaths()
        - .toDescribeNetworkInterfaceAttribute()
        - .toDescribeNetworkInterfacePermissions()
        - .toDescribeNetworkInterfaces()
        - .toDescribePlacementGroups()
        - .toDescribePrefixLists()
        - .toDescribePrincipalIdFormat()
        - .toDescribePublicIpv4Pools()
        - .toDescribeRegions()
        - .toDescribeReplaceRootVolumeTasks()
        - .toDescribeReservedInstances()
        - .toDescribeReservedInstancesListings()
        - .toDescribeReservedInstancesModifications()
        - .toDescribeReservedInstancesOfferings()
        - .toDescribeRouteTables()
        - .toDescribeScheduledInstanceAvailability()
        - .toDescribeScheduledInstances()
        - .toDescribeSecurityGroupReferences()
        - .toDescribeSecurityGroupRules()
        - .toDescribeSecurityGroups()
        - .toDescribeSnapshotAttribute()
        - .toDescribeSnapshotTierStatus()
        - .toDescribeSnapshots()
        - .toDescribeSpotDatafeedSubscription()
        - .toDescribeSpotFleetInstances()
        - .toDescribeSpotFleetRequestHistory()
        - .toDescribeSpotFleetRequests()
        - .toDescribeSpotInstanceRequests()
        - .toDescribeSpotPriceHistory()
        - .toDescribeStaleSecurityGroups()
        - .toDescribeStoreImageTasks()
        - .toDescribeSubnets()
        - .toDescribeTags()
        - .toDescribeTrafficMirrorFilters()
        - .toDescribeTrafficMirrorSessions()
        - .toDescribeTrafficMirrorTargets()
        - .toDescribeTransitGatewayAttachments()
        - .toDescribeTransitGatewayConnectPeers()
        - .toDescribeTransitGatewayConnects()
        - .toDescribeTransitGatewayMulticastDomains()
        - .toDescribeTransitGatewayPeeringAttachments()
        - .toDescribeTransitGatewayPolicyTables()
        - .toDescribeTransitGatewayRouteTableAnnouncements()
        - .toDescribeTransitGatewayRouteTables()
        - .toDescribeTransitGatewayVpcAttachments()
        - .toDescribeTransitGateways()
        - .toDescribeTrunkInterfaceAssociations()
        - .toDescribeVerifiedAccessEndpoints()
        - .toDescribeVerifiedAccessGroups()
        - .toDescribeVerifiedAccessInstanceLoggingConfigurations()
        - .toDescribeVerifiedAccessInstances()
        - .toDescribeVerifiedAccessTrustProviders()
        - .toDescribeVolumeAttribute()
        - .toDescribeVolumeStatus()
        - .toDescribeVolumes()
        - .toDescribeVolumesModifications()
        - .toDescribeVpcAttribute()
        - .toDescribeVpcClassicLink()
        - .toDescribeVpcClassicLinkDnsSupport()
        - .toDescribeVpcEndpointConnectionNotifications()
        - .toDescribeVpcEndpointConnections()
        - .toDescribeVpcEndpointServiceConfigurations()
        - .toDescribeVpcEndpointServicePermissions()
        - .toDescribeVpcEndpointServices()
        - .toDescribeVpcEndpoints()
        - .toDescribeVpcPeeringConnections()
        - .toDescribeVpcs()
        - .toDescribeVpnConnections()
        - .toDescribeVpnGateways()
        - .toDetachClassicLinkVpc()
        - .toDetachInternetGateway()
        - .toDetachNetworkInterface()
        - .toDetachVerifiedAccessTrustProvider()
        - .toDetachVolume()
        - .toDetachVpnGateway()
        - .toDisableAddressTransfer()
        - .toDisableAwsNetworkPerformanceMetricSubscription()
        - .toDisableEbsEncryptionByDefault()
        - .toDisableFastLaunch()
        - .toDisableFastSnapshotRestores()
        - .toDisableImageDeprecation()
        - .toDisableIpamOrganizationAdminAccount()
        - .toDisableSerialConsoleAccess()
        - .toDisableTransitGatewayRouteTablePropagation()
        - .toDisableVgwRoutePropagation()
        - .toDisableVpcClassicLink()
        - .toDisableVpcClassicLinkDnsSupport()
        - .toDisassociateAddress()
        - .toDisassociateClientVpnTargetNetwork()
        - .toDisassociateEnclaveCertificateIamRole()
        - .toDisassociateIamInstanceProfile()
        - .toDisassociateInstanceEventWindow()
        - .toDisassociateRouteTable()
        - .toDisassociateSubnetCidrBlock()
        - .toDisassociateTransitGatewayMulticastDomain()
        - .toDisassociateTransitGatewayPolicyTable()
        - .toDisassociateTransitGatewayRouteTable()
        - .toDisassociateTrunkInterface()
        - .toDisassociateVpcCidrBlock()
        - .toEnableAddressTransfer()
        - .toEnableAwsNetworkPerformanceMetricSubscription()
        - .toEnableEbsEncryptionByDefault()
        - .toEnableFastLaunch()
        - .toEnableFastSnapshotRestores()
        - .toEnableImageDeprecation()
        - .toEnableIpamOrganizationAdminAccount()
        - .toEnableReachabilityAnalyzerOrganizationSharing()
        - .toEnableSerialConsoleAccess()
        - .toEnableTransitGatewayRouteTablePropagation()
        - .toEnableVgwRoutePropagation()
        - .toEnableVolumeIO()
        - .toEnableVpcClassicLink()
        - .toEnableVpcClassicLinkDnsSupport()
        - .toExportClientVpnClientCertificateRevocationList()
        - .toExportClientVpnClientConfiguration()
        - .toExportImage()
        - .toExportTransitGatewayRoutes()
        - .toGetAssociatedEnclaveCertificateIamRoles()
        - .toGetAssociatedIpv6PoolCidrs()
        - .toGetAwsNetworkPerformanceData()
        - .toGetCapacityReservationUsage()
        - .toGetCoipPoolUsage()
        - .toGetConsoleOutput()
        - .toGetConsoleScreenshot()
        - .toGetDefaultCreditSpecification()
        - .toGetEbsDefaultKmsKeyId()
        - .toGetEbsEncryptionByDefault()
        - .toGetFlowLogsIntegrationTemplate()
        - .toGetGroupsForCapacityReservation()
        - .toGetHostReservationPurchasePreview()
        - .toGetInstanceTypesFromInstanceRequirements()
        - .toGetInstanceUefiData()
        - .toGetIpamAddressHistory()
        - .toGetIpamPoolAllocations()
        - .toGetIpamPoolCidrs()
        - .toGetIpamResourceCidrs()
        - .toGetLaunchTemplateData()
        - .toGetManagedPrefixListAssociations()
        - .toGetManagedPrefixListEntries()
        - .toGetNetworkInsightsAccessScopeAnalysisFindings()
        - .toGetNetworkInsightsAccessScopeContent()
        - .toGetPasswordData()
        - .toGetReservedInstancesExchangeQuote()
        - .toGetResourcePolicy()
        - .toGetSerialConsoleAccessStatus()
        - .toGetSpotPlacementScores()
        - .toGetSubnetCidrReservations()
        - .toGetTransitGatewayAttachmentPropagations()
        - .toGetTransitGatewayMulticastDomainAssociations()
        - .toGetTransitGatewayPolicyTableAssociations()
        - .toGetTransitGatewayPolicyTableEntries()
        - .toGetTransitGatewayPrefixListReferences()
        - .toGetTransitGatewayRouteTableAssociations()
        - .toGetTransitGatewayRouteTablePropagations()
        - .toGetVerifiedAccessEndpointPolicy()
        - .toGetVerifiedAccessGroupPolicy()
        - .toGetVpnConnectionDeviceSampleConfiguration()
        - .toGetVpnConnectionDeviceTypes()
        - .toImportClientVpnClientCertificateRevocationList()
        - .toImportImage()
        - .toImportInstance()
        - .toImportKeyPair()
        - .toImportSnapshot()
        - .toImportVolume()
        - .toListImagesInRecycleBin()
        - .toListSnapshotsInRecycleBin()
        - .toModifyAddressAttribute()
        - .toModifyAvailabilityZoneGroup()
        - .toModifyCapacityReservation()
        - .toModifyCapacityReservationFleet()
        - .toModifyClientVpnEndpoint()
        - .toModifyDefaultCreditSpecification()
        - .toModifyEbsDefaultKmsKeyId()
        - .toModifyFleet()
        - .toModifyFpgaImageAttribute()
        - .toModifyHosts()
        - .toModifyIdFormat()
        - .toModifyIdentityIdFormat()
        - .toModifyImageAttribute()
        - .toModifyInstanceAttribute()
        - .toModifyInstanceCapacityReservationAttributes()
        - .toModifyInstanceCreditSpecification()
        - .toModifyInstanceEventStartTime()
        - .toModifyInstanceEventWindow()
        - .toModifyInstanceMaintenanceOptions()
        - .toModifyInstanceMetadataOptions()
        - .toModifyInstancePlacement()
        - .toModifyIpam()
        - .toModifyIpamPool()
        - .toModifyIpamResourceCidr()
        - .toModifyIpamScope()
        - .toModifyLaunchTemplate()
        - .toModifyLocalGatewayRoute()
        - .toModifyManagedPrefixList()
        - .toModifyNetworkInterfaceAttribute()
        - .toModifyPrivateDnsNameOptions()
        - .toModifyReservedInstances()
        - .toModifySecurityGroupRules()
        - .toModifySnapshotAttribute()
        - .toModifySnapshotTier()
        - .toModifySpotFleetRequest()
        - .toModifySubnetAttribute()
        - .toModifyTrafficMirrorFilterNetworkServices()
        - .toModifyTrafficMirrorFilterRule()
        - .toModifyTrafficMirrorSession()
        - .toModifyTransitGateway()
        - .toModifyTransitGatewayPrefixListReference()
        - .toModifyTransitGatewayVpcAttachment()
        - .toModifyVerifiedAccessEndpoint()
        - .toModifyVerifiedAccessEndpointPolicy()
        - .toModifyVerifiedAccessGroup()
        - .toModifyVerifiedAccessGroupPolicy()
        - .toModifyVerifiedAccessInstance()
        - .toModifyVerifiedAccessInstanceLoggingConfiguration()
        - .toModifyVerifiedAccessTrustProvider()
        - .toModifyVolume()
        - .toModifyVolumeAttribute()
        - .toModifyVpcAttribute()
        - .toModifyVpcEndpoint()
        - .toModifyVpcEndpointConnectionNotification()
        - .toModifyVpcEndpointServiceConfiguration()
        - .toModifyVpcEndpointServicePayerResponsibility()
        - .toModifyVpcEndpointServicePermissions()
        - .toModifyVpcPeeringConnectionOptions()
        - .toModifyVpcTenancy()
        - .toModifyVpnConnection()
        - .toModifyVpnConnectionOptions()
        - .toModifyVpnTunnelCertificate()
        - .toModifyVpnTunnelOptions()
        - .toMonitorInstances()
        - .toMoveAddressToVpc()
        - .toMoveByoipCidrToIpam()
        - .toProvisionByoipCidr()
        - .toProvisionIpamPoolCidr()
        - .toProvisionPublicIpv4PoolCidr()
        - .toPurchaseHostReservation()
        - .toPurchaseReservedInstancesOffering()
        - .toPurchaseScheduledInstances()
        - .toPutResourcePolicy()
        - .toRebootInstances()
        - .toRegisterImage()
        - .toRegisterInstanceEventNotificationAttributes()
        - .toRegisterTransitGatewayMulticastGroupMembers()
        - .toRegisterTransitGatewayMulticastGroupSources()
        - .toRejectTransitGatewayMulticastDomainAssociations()
        - .toRejectTransitGatewayPeeringAttachment()
        - .toRejectTransitGatewayVpcAttachment()
        - .toRejectVpcEndpointConnections()
        - .toRejectVpcPeeringConnection()
        - .toReleaseAddress()
        - .toReleaseHosts()
        - .toReleaseIpamPoolAllocation()
        - .toReplaceIamInstanceProfileAssociation()
        - .toReplaceNetworkAclAssociation()
        - .toReplaceNetworkAclEntry()
        - .toReplaceRoute()
        - .toReplaceRouteTableAssociation()
        - .toReplaceTransitGatewayRoute()
        - .toReportInstanceStatus()
        - .toRequestSpotFleet()
        - .toRequestSpotInstances()
        - .toResetAddressAttribute()
        - .toResetEbsDefaultKmsKeyId()
        - .toResetFpgaImageAttribute()
        - .toResetImageAttribute()
        - .toResetInstanceAttribute()
        - .toResetNetworkInterfaceAttribute()
        - .toResetSnapshotAttribute()
        - .toRestoreAddressToClassic()
        - .toRestoreImageFromRecycleBin()
        - .toRestoreManagedPrefixListVersion()
        - .toRestoreSnapshotFromRecycleBin()
        - .toRestoreSnapshotTier()
        - .toRevokeClientVpnIngress()
        - .toRevokeSecurityGroupEgress()
        - .toRevokeSecurityGroupIngress()
        - .toRunInstances()
        - .toRunScheduledInstances()
        - .toSearchLocalGatewayRoutes()
        - .toSearchTransitGatewayMulticastGroups()
        - .toSearchTransitGatewayRoutes()
        - .toSendDiagnosticInterrupt()
        - .toSendSpotInstanceInterruptions()
        - .toStartInstances()
        - .toStartNetworkInsightsAccessScopeAnalysis()
        - .toStartNetworkInsightsAnalysis()
        - .toStartVpcEndpointServicePrivateDnsVerification()
        - .toStopInstances()
        - .toTerminateClientVpnConnections()
        - .toTerminateInstances()
        - .toUnassignIpv6Addresses()
        - .toUnassignPrivateIpAddresses()
        - .toUnmonitorInstances()
        - .toUpdateSecurityGroupRuleDescriptionsEgress()
        - .toUpdateSecurityGroupRuleDescriptionsIngress()
        - .toWithdrawByoipCidr()

        Applies to resource types:

        - elastic-ip
        - capacity-reservation-fleet
        - capacity-reservation
        - carrier-gateway
        - client-vpn-endpoint
        - customer-gateway
        - dedicated-host
        - dhcp-options
        - egress-only-internet-gateway
        - elastic-gpu
        - export-image-task
        - export-instance-task
        - fleet
        - fpga-image
        - host-reservation
        - image
        - import-image-task
        - import-snapshot-task
        - instance-event-window
        - instance
        - internet-gateway
        - ipam
        - ipam-pool
        - ipam-scope
        - coip-pool
        - ipv4pool-ec2
        - ipv6pool-ec2
        - key-pair
        - launch-template
        - local-gateway
        - local-gateway-route-table-virtual-interface-group-association
        - local-gateway-route-table-vpc-association
        - local-gateway-route-table
        - local-gateway-virtual-interface-group
        - local-gateway-virtual-interface
        - natgateway
        - network-acl
        - network-insights-access-scope-analysis
        - network-insights-access-scope
        - network-insights-analysis
        - network-insights-path
        - network-interface
        - placement-group
        - prefix-list
        - replace-root-volume-task
        - reserved-instances
        - route-table
        - security-group
        - security-group-rule
        - snapshot
        - spot-fleet-request
        - spot-instances-request
        - subnet-cidr-reservation
        - subnet
        - traffic-mirror-filter
        - traffic-mirror-filter-rule
        - traffic-mirror-session
        - traffic-mirror-target
        - transit-gateway-attachment
        - transit-gateway-connect-peer
        - transit-gateway
        - transit-gateway-multicast-domain
        - transit-gateway-policy-table
        - transit-gateway-route-table-announcement
        - transit-gateway-route-table
        - verified-access-endpoint
        - verified-access-group
        - verified-access-instance
        - verified-access-policy
        - verified-access-trust-provider
        - volume
        - vpc-endpoint-connection
        - vpc-endpoint
        - vpc-endpoint-service
        - vpc-endpoint-service-permission
        - vpc-flow-log
        - vpc
        - vpc-peering-connection
        - vpn-connection-device-type
        - vpn-connection
        - vpn-gateway

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5c649950e43aeb69f47568aad21624c81ea13a87fa080fcf8bc60372eccc12c6)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Ec2", jsii.invoke(self, "ifRegion", [value, operator]))

    @jsii.member(jsii_name="ifRekeyFuzzPercentage")
    def if_rekey_fuzz_percentage(
        self,
        value: typing.Union[jsii.Number, typing.Sequence[jsii.Number]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Ec2":
        '''(experimental) Filters access by the percentage of increase of the rekey window (determined by the rekey margin time) within which the rekey time is randomly selected for a VPN tunnel.

        https://docs.aws.amazon.com/vpn/latest/s2svpn/vpn-authentication-access-control.html

        Applies to actions:

        - .toCreateTags()
        - .toCreateVpnConnection()
        - .toModifyVpnConnection()
        - .toModifyVpnTunnelOptions()

        Applies to resource types:

        - vpn-connection

        :param value: The value(s) to check.
        :param operator: Works with `numeric operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_Numeric>`_. **Default:** ``NumericEquals``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__22cdae31aa3d8aa353f6e9edcd3fed766a6c8db874ccdea3287d7dd882d6196d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Ec2", jsii.invoke(self, "ifRekeyFuzzPercentage", [value, operator]))

    @jsii.member(jsii_name="ifRekeyMarginTimeSeconds")
    def if_rekey_margin_time_seconds(
        self,
        value: typing.Union[jsii.Number, typing.Sequence[jsii.Number]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Ec2":
        '''(experimental) Filters access by the margin time before the phase 2 lifetime expires for a VPN tunnel.

        https://docs.aws.amazon.com/vpn/latest/s2svpn/vpn-authentication-access-control.html

        Applies to actions:

        - .toCreateTags()
        - .toCreateVpnConnection()
        - .toModifyVpnConnection()
        - .toModifyVpnTunnelOptions()

        Applies to resource types:

        - vpn-connection

        :param value: The value(s) to check.
        :param operator: Works with `numeric operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_Numeric>`_. **Default:** ``NumericEquals``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5b6fc520d5441542943c0145e059cb6ec8bc3bf874b3114a103a68955051b651)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Ec2", jsii.invoke(self, "ifRekeyMarginTimeSeconds", [value, operator]))

    @jsii.member(jsii_name="ifRemoveGroup")
    def if_remove_group(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Ec2":
        '''(experimental) Filters access by the group being removed from a snapshot.

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/iam-policy-structure.html#amazon-ec2-keys

        Applies to actions:

        - .toModifySnapshotAttribute()

        Applies to resource types:

        - snapshot

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6cc01ab8aec76ef864b9ec256e2bb3faa95731125210fd69e7192f75a23f7e1b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Ec2", jsii.invoke(self, "ifRemoveGroup", [value, operator]))

    @jsii.member(jsii_name="ifRemoveUserId")
    def if_remove_user_id(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Ec2":
        '''(experimental) Filters access by the account id being removed from a snapshot.

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/iam-policy-structure.html#amazon-ec2-keys

        Applies to actions:

        - .toModifySnapshotAttribute()

        Applies to resource types:

        - snapshot

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e563484649b3ac0c2889b15a1983c3630e0dc098f22f34590851b55f99c683fc)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Ec2", jsii.invoke(self, "ifRemoveUserId", [value, operator]))

    @jsii.member(jsii_name="ifReplayWindowSizePackets")
    def if_replay_window_size_packets(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Ec2":
        '''(experimental) Filters access by the number of packets in an IKE replay window.

        Applies to actions:

        - .toCreateTags()
        - .toCreateVpnConnection()
        - .toModifyVpnConnection()
        - .toModifyVpnTunnelOptions()

        Applies to resource types:

        - vpn-connection

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0ecd4b19248898f758b1645422a4363c9c8611855655eadc2a8583d87ece7a21)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Ec2", jsii.invoke(self, "ifReplayWindowSizePackets", [value, operator]))

    @jsii.member(jsii_name="ifRequesterVpc")
    def if_requester_vpc(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Ec2":
        '''(experimental) Filters access by the ARN of a requester VPC in a VPC peering connection.

        https://docs.aws.amazon.com/vpc/latest/peering/security-iam.html

        Applies to actions:

        - .toAcceptVpcPeeringConnection()
        - .toCreateNetworkInsightsPath()
        - .toCreateTags()
        - .toCreateVpcPeeringConnection()
        - .toDeleteVpcPeeringConnection()
        - .toModifyVpcPeeringConnectionOptions()
        - .toRejectVpcPeeringConnection()

        Applies to resource types:

        - vpc-peering-connection

        :param value: The value(s) to check.
        :param operator: Works with `arn operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_ARN>`_. **Default:** ``ArnLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e7d709ac17f68cbf02b9949b904d418b3fdf9ce19a31330729346091ac912cd4)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Ec2", jsii.invoke(self, "ifRequesterVpc", [value, operator]))

    @jsii.member(jsii_name="ifReservedInstancesOfferingType")
    def if_reserved_instances_offering_type(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Ec2":
        '''(experimental) Filters access by the payment option of the Reserved Instance offering (No Upfront, Partial Upfront, or All Upfront).

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ec2-reserved-instances.html#ri-payment-options

        Applies to actions:

        - .toCreateTags()
        - .toModifyReservedInstances()

        Applies to resource types:

        - reserved-instances

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2724814297c4d8ba3502542abdfabd6cdea9c16976a950289ae7a76440ab5314)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Ec2", jsii.invoke(self, "ifReservedInstancesOfferingType", [value, operator]))

    @jsii.member(jsii_name="ifResourceTag")
    def if_resource_tag(
        self,
        tag_key: builtins.str,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Ec2":
        '''(experimental) Filters access by a tag key and value pair of a resource.

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/control-access-with-tags.html

        Applies to actions:

        - .toAcceptTransitGatewayMulticastDomainAssociations()
        - .toAcceptTransitGatewayPeeringAttachment()
        - .toAcceptTransitGatewayVpcAttachment()
        - .toAcceptVpcEndpointConnections()
        - .toAcceptVpcPeeringConnection()
        - .toAllocateAddress()
        - .toAllocateIpamPoolCidr()
        - .toApplySecurityGroupsToClientVpnTargetNetwork()
        - .toAssignIpv6Addresses()
        - .toAssignPrivateIpAddresses()
        - .toAssociateAddress()
        - .toAssociateClientVpnTargetNetwork()
        - .toAssociateDhcpOptions()
        - .toAssociateIamInstanceProfile()
        - .toAssociateInstanceEventWindow()
        - .toAssociateRouteTable()
        - .toAssociateSubnetCidrBlock()
        - .toAssociateTransitGatewayMulticastDomain()
        - .toAssociateTransitGatewayPolicyTable()
        - .toAssociateTransitGatewayRouteTable()
        - .toAssociateVpcCidrBlock()
        - .toAttachClassicLinkVpc()
        - .toAttachInternetGateway()
        - .toAttachNetworkInterface()
        - .toAttachVerifiedAccessTrustProvider()
        - .toAttachVolume()
        - .toAttachVpnGateway()
        - .toAuthorizeClientVpnIngress()
        - .toAuthorizeSecurityGroupEgress()
        - .toAuthorizeSecurityGroupIngress()
        - .toCancelCapacityReservation()
        - .toCancelCapacityReservationFleets()
        - .toCancelExportTask()
        - .toCancelImageLaunchPermission()
        - .toCancelImportTask()
        - .toCancelSpotFleetRequests()
        - .toCancelSpotInstanceRequests()
        - .toCreateCarrierGateway()
        - .toCreateClientVpnEndpoint()
        - .toCreateClientVpnRoute()
        - .toCreateCoipCidr()
        - .toCreateCoipPool()
        - .toCreateCoipPoolPermission()
        - .toCreateEgressOnlyInternetGateway()
        - .toCreateFleet()
        - .toCreateFlowLogs()
        - .toCreateImage()
        - .toCreateInstanceExportTask()
        - .toCreateIpamPool()
        - .toCreateIpamScope()
        - .toCreateLaunchTemplateVersion()
        - .toCreateLocalGatewayRoute()
        - .toCreateLocalGatewayRouteTable()
        - .toCreateLocalGatewayRouteTablePermission()
        - .toCreateLocalGatewayRouteTableVirtualInterfaceGroupAssociation()
        - .toCreateLocalGatewayRouteTableVpcAssociation()
        - .toCreateNatGateway()
        - .toCreateNetworkAcl()
        - .toCreateNetworkAclEntry()
        - .toCreateNetworkInsightsPath()
        - .toCreateNetworkInterface()
        - .toCreateNetworkInterfacePermission()
        - .toCreateReplaceRootVolumeTask()
        - .toCreateRoute()
        - .toCreateRouteTable()
        - .toCreateSecurityGroup()
        - .toCreateSnapshot()
        - .toCreateSnapshots()
        - .toCreateStoreImageTask()
        - .toCreateSubnet()
        - .toCreateTags()
        - .toCreateTrafficMirrorFilterRule()
        - .toCreateTrafficMirrorSession()
        - .toCreateTrafficMirrorTarget()
        - .toCreateTransitGatewayConnectPeer()
        - .toCreateTransitGatewayMulticastDomain()
        - .toCreateTransitGatewayPeeringAttachment()
        - .toCreateTransitGatewayPolicyTable()
        - .toCreateTransitGatewayPrefixListReference()
        - .toCreateTransitGatewayRoute()
        - .toCreateTransitGatewayRouteTable()
        - .toCreateTransitGatewayRouteTableAnnouncement()
        - .toCreateTransitGatewayVpcAttachment()
        - .toCreateVerifiedAccessEndpoint()
        - .toCreateVerifiedAccessGroup()
        - .toCreateVpc()
        - .toCreateVpcEndpoint()
        - .toCreateVpcEndpointConnectionNotification()
        - .toCreateVpcPeeringConnection()
        - .toCreateVpnConnection()
        - .toCreateVpnConnectionRoute()
        - .toDeleteCarrierGateway()
        - .toDeleteClientVpnEndpoint()
        - .toDeleteClientVpnRoute()
        - .toDeleteCoipCidr()
        - .toDeleteCoipPool()
        - .toDeleteCoipPoolPermission()
        - .toDeleteCustomerGateway()
        - .toDeleteDhcpOptions()
        - .toDeleteEgressOnlyInternetGateway()
        - .toDeleteFleets()
        - .toDeleteFlowLogs()
        - .toDeleteFpgaImage()
        - .toDeleteInstanceEventWindow()
        - .toDeleteInternetGateway()
        - .toDeleteIpam()
        - .toDeleteIpamPool()
        - .toDeleteIpamScope()
        - .toDeleteKeyPair()
        - .toDeleteLaunchTemplate()
        - .toDeleteLaunchTemplateVersions()
        - .toDeleteLocalGatewayRoute()
        - .toDeleteLocalGatewayRouteTable()
        - .toDeleteLocalGatewayRouteTablePermission()
        - .toDeleteLocalGatewayRouteTableVirtualInterfaceGroupAssociation()
        - .toDeleteLocalGatewayRouteTableVpcAssociation()
        - .toDeleteManagedPrefixList()
        - .toDeleteNatGateway()
        - .toDeleteNetworkAcl()
        - .toDeleteNetworkAclEntry()
        - .toDeleteNetworkInsightsAccessScope()
        - .toDeleteNetworkInsightsAccessScopeAnalysis()
        - .toDeleteNetworkInsightsAnalysis()
        - .toDeleteNetworkInsightsPath()
        - .toDeleteNetworkInterface()
        - .toDeleteNetworkInterfacePermission()
        - .toDeletePlacementGroup()
        - .toDeletePublicIpv4Pool()
        - .toDeleteResourcePolicy()
        - .toDeleteRoute()
        - .toDeleteRouteTable()
        - .toDeleteSecurityGroup()
        - .toDeleteSnapshot()
        - .toDeleteSubnet()
        - .toDeleteTags()
        - .toDeleteTrafficMirrorFilter()
        - .toDeleteTrafficMirrorFilterRule()
        - .toDeleteTrafficMirrorSession()
        - .toDeleteTrafficMirrorTarget()
        - .toDeleteTransitGateway()
        - .toDeleteTransitGatewayConnect()
        - .toDeleteTransitGatewayConnectPeer()
        - .toDeleteTransitGatewayMulticastDomain()
        - .toDeleteTransitGatewayPeeringAttachment()
        - .toDeleteTransitGatewayPolicyTable()
        - .toDeleteTransitGatewayPrefixListReference()
        - .toDeleteTransitGatewayRoute()
        - .toDeleteTransitGatewayRouteTable()
        - .toDeleteTransitGatewayRouteTableAnnouncement()
        - .toDeleteTransitGatewayVpcAttachment()
        - .toDeleteVerifiedAccessEndpoint()
        - .toDeleteVerifiedAccessGroup()
        - .toDeleteVerifiedAccessInstance()
        - .toDeleteVerifiedAccessTrustProvider()
        - .toDeleteVolume()
        - .toDeleteVpc()
        - .toDeleteVpcEndpointConnectionNotifications()
        - .toDeleteVpcEndpointServiceConfigurations()
        - .toDeleteVpcEndpoints()
        - .toDeleteVpcPeeringConnection()
        - .toDeleteVpnConnection()
        - .toDeleteVpnConnectionRoute()
        - .toDeleteVpnGateway()
        - .toDeprovisionIpamPoolCidr()
        - .toDeprovisionPublicIpv4PoolCidr()
        - .toDeregisterImage()
        - .toDeregisterTransitGatewayMulticastGroupMembers()
        - .toDeregisterTransitGatewayMulticastGroupSources()
        - .toDescribeAddressesAttribute()
        - .toDescribeClientVpnAuthorizationRules()
        - .toDescribeClientVpnConnections()
        - .toDescribeClientVpnEndpoints()
        - .toDescribeClientVpnRoutes()
        - .toDescribeClientVpnTargetNetworks()
        - .toDescribeFastLaunchImages()
        - .toDescribeFleetHistory()
        - .toDescribeFleetInstances()
        - .toDescribeFpgaImageAttribute()
        - .toDescribeImageAttribute()
        - .toDescribeInstanceAttribute()
        - .toDescribeSnapshotAttribute()
        - .toDescribeSpotFleetInstances()
        - .toDescribeSpotFleetRequestHistory()
        - .toDescribeStoreImageTasks()
        - .toDescribeVolumeAttribute()
        - .toDescribeVpcAttribute()
        - .toDetachClassicLinkVpc()
        - .toDetachInternetGateway()
        - .toDetachNetworkInterface()
        - .toDetachVerifiedAccessTrustProvider()
        - .toDetachVolume()
        - .toDetachVpnGateway()
        - .toDisableAddressTransfer()
        - .toDisableFastLaunch()
        - .toDisableFastSnapshotRestores()
        - .toDisableImageDeprecation()
        - .toDisableTransitGatewayRouteTablePropagation()
        - .toDisableVgwRoutePropagation()
        - .toDisableVpcClassicLink()
        - .toDisableVpcClassicLinkDnsSupport()
        - .toDisassociateAddress()
        - .toDisassociateClientVpnTargetNetwork()
        - .toDisassociateIamInstanceProfile()
        - .toDisassociateInstanceEventWindow()
        - .toDisassociateRouteTable()
        - .toDisassociateSubnetCidrBlock()
        - .toDisassociateTransitGatewayMulticastDomain()
        - .toDisassociateTransitGatewayPolicyTable()
        - .toDisassociateTransitGatewayRouteTable()
        - .toDisassociateVpcCidrBlock()
        - .toEnableAddressTransfer()
        - .toEnableFastLaunch()
        - .toEnableFastSnapshotRestores()
        - .toEnableImageDeprecation()
        - .toEnableTransitGatewayRouteTablePropagation()
        - .toEnableVgwRoutePropagation()
        - .toEnableVolumeIO()
        - .toEnableVpcClassicLink()
        - .toEnableVpcClassicLinkDnsSupport()
        - .toExportClientVpnClientCertificateRevocationList()
        - .toExportClientVpnClientConfiguration()
        - .toExportImage()
        - .toGetCapacityReservationUsage()
        - .toGetCoipPoolUsage()
        - .toGetConsoleOutput()
        - .toGetConsoleScreenshot()
        - .toGetFlowLogsIntegrationTemplate()
        - .toGetGroupsForCapacityReservation()
        - .toGetInstanceUefiData()
        - .toGetIpamAddressHistory()
        - .toGetIpamPoolAllocations()
        - .toGetIpamPoolCidrs()
        - .toGetIpamResourceCidrs()
        - .toGetLaunchTemplateData()
        - .toGetManagedPrefixListAssociations()
        - .toGetManagedPrefixListEntries()
        - .toGetPasswordData()
        - .toGetResourcePolicy()
        - .toGetTransitGatewayMulticastDomainAssociations()
        - .toGetTransitGatewayPolicyTableAssociations()
        - .toGetTransitGatewayPolicyTableEntries()
        - .toGetVerifiedAccessEndpointPolicy()
        - .toGetVerifiedAccessGroupPolicy()
        - .toGetVpnConnectionDeviceSampleConfiguration()
        - .toImportClientVpnClientCertificateRevocationList()
        - .toImportImage()
        - .toImportInstance()
        - .toImportVolume()
        - .toListImagesInRecycleBin()
        - .toListSnapshotsInRecycleBin()
        - .toModifyAddressAttribute()
        - .toModifyCapacityReservation()
        - .toModifyCapacityReservationFleet()
        - .toModifyClientVpnEndpoint()
        - .toModifyFleet()
        - .toModifyFpgaImageAttribute()
        - .toModifyHosts()
        - .toModifyImageAttribute()
        - .toModifyInstanceAttribute()
        - .toModifyInstanceCapacityReservationAttributes()
        - .toModifyInstanceCreditSpecification()
        - .toModifyInstanceEventStartTime()
        - .toModifyInstanceEventWindow()
        - .toModifyInstanceMaintenanceOptions()
        - .toModifyInstanceMetadataOptions()
        - .toModifyInstancePlacement()
        - .toModifyIpam()
        - .toModifyIpamPool()
        - .toModifyIpamResourceCidr()
        - .toModifyIpamScope()
        - .toModifyLaunchTemplate()
        - .toModifyLocalGatewayRoute()
        - .toModifyManagedPrefixList()
        - .toModifyNetworkInterfaceAttribute()
        - .toModifyPrivateDnsNameOptions()
        - .toModifyReservedInstances()
        - .toModifySecurityGroupRules()
        - .toModifySnapshotAttribute()
        - .toModifySnapshotTier()
        - .toModifySpotFleetRequest()
        - .toModifySubnetAttribute()
        - .toModifyTrafficMirrorFilterNetworkServices()
        - .toModifyTrafficMirrorFilterRule()
        - .toModifyTrafficMirrorSession()
        - .toModifyTransitGateway()
        - .toModifyTransitGatewayPrefixListReference()
        - .toModifyTransitGatewayVpcAttachment()
        - .toModifyVerifiedAccessEndpoint()
        - .toModifyVerifiedAccessEndpointPolicy()
        - .toModifyVerifiedAccessGroup()
        - .toModifyVerifiedAccessGroupPolicy()
        - .toModifyVerifiedAccessInstance()
        - .toModifyVerifiedAccessInstanceLoggingConfiguration()
        - .toModifyVerifiedAccessTrustProvider()
        - .toModifyVolume()
        - .toModifyVolumeAttribute()
        - .toModifyVpcAttribute()
        - .toModifyVpcEndpoint()
        - .toModifyVpcEndpointConnectionNotification()
        - .toModifyVpcEndpointServiceConfiguration()
        - .toModifyVpcEndpointServicePayerResponsibility()
        - .toModifyVpcEndpointServicePermissions()
        - .toModifyVpcPeeringConnectionOptions()
        - .toModifyVpcTenancy()
        - .toModifyVpnConnection()
        - .toModifyVpnConnectionOptions()
        - .toModifyVpnTunnelCertificate()
        - .toModifyVpnTunnelOptions()
        - .toMonitorInstances()
        - .toMoveByoipCidrToIpam()
        - .toProvisionIpamPoolCidr()
        - .toProvisionPublicIpv4PoolCidr()
        - .toPurchaseHostReservation()
        - .toPutResourcePolicy()
        - .toRebootInstances()
        - .toRegisterImage()
        - .toRegisterTransitGatewayMulticastGroupMembers()
        - .toRegisterTransitGatewayMulticastGroupSources()
        - .toRejectTransitGatewayMulticastDomainAssociations()
        - .toRejectTransitGatewayPeeringAttachment()
        - .toRejectTransitGatewayVpcAttachment()
        - .toRejectVpcEndpointConnections()
        - .toRejectVpcPeeringConnection()
        - .toReleaseAddress()
        - .toReleaseHosts()
        - .toReleaseIpamPoolAllocation()
        - .toReplaceIamInstanceProfileAssociation()
        - .toReplaceNetworkAclAssociation()
        - .toReplaceNetworkAclEntry()
        - .toReplaceRoute()
        - .toReplaceRouteTableAssociation()
        - .toReplaceTransitGatewayRoute()
        - .toRequestSpotFleet()
        - .toRequestSpotInstances()
        - .toResetAddressAttribute()
        - .toResetFpgaImageAttribute()
        - .toResetImageAttribute()
        - .toResetInstanceAttribute()
        - .toResetNetworkInterfaceAttribute()
        - .toResetSnapshotAttribute()
        - .toRestoreImageFromRecycleBin()
        - .toRestoreManagedPrefixListVersion()
        - .toRestoreSnapshotFromRecycleBin()
        - .toRestoreSnapshotTier()
        - .toRevokeClientVpnIngress()
        - .toRevokeSecurityGroupEgress()
        - .toRevokeSecurityGroupIngress()
        - .toRunInstances()
        - .toRunScheduledInstances()
        - .toSearchLocalGatewayRoutes()
        - .toSearchTransitGatewayMulticastGroups()
        - .toSearchTransitGatewayRoutes()
        - .toSendDiagnosticInterrupt()
        - .toSendSpotInstanceInterruptions()
        - .toStartInstances()
        - .toStartNetworkInsightsAccessScopeAnalysis()
        - .toStartNetworkInsightsAnalysis()
        - .toStartVpcEndpointServicePrivateDnsVerification()
        - .toStopInstances()
        - .toTerminateClientVpnConnections()
        - .toTerminateInstances()
        - .toUnassignIpv6Addresses()
        - .toUnassignPrivateIpAddresses()
        - .toUnmonitorInstances()
        - .toUpdateSecurityGroupRuleDescriptionsEgress()
        - .toUpdateSecurityGroupRuleDescriptionsIngress()

        Applies to resource types:

        - elastic-ip
        - capacity-reservation-fleet
        - capacity-reservation
        - carrier-gateway
        - client-vpn-endpoint
        - customer-gateway
        - dedicated-host
        - dhcp-options
        - egress-only-internet-gateway
        - elastic-gpu
        - export-image-task
        - export-instance-task
        - fleet
        - fpga-image
        - host-reservation
        - image
        - import-image-task
        - import-snapshot-task
        - instance-event-window
        - instance
        - internet-gateway
        - ipam
        - ipam-pool
        - ipam-scope
        - coip-pool
        - ipv4pool-ec2
        - ipv6pool-ec2
        - key-pair
        - launch-template
        - local-gateway
        - local-gateway-route-table-virtual-interface-group-association
        - local-gateway-route-table-vpc-association
        - local-gateway-route-table
        - local-gateway-virtual-interface-group
        - local-gateway-virtual-interface
        - natgateway
        - network-acl
        - network-insights-access-scope-analysis
        - network-insights-access-scope
        - network-insights-analysis
        - network-insights-path
        - network-interface
        - placement-group
        - prefix-list
        - replace-root-volume-task
        - reserved-instances
        - route-table
        - security-group
        - security-group-rule
        - snapshot
        - spot-fleet-request
        - spot-instances-request
        - subnet-cidr-reservation
        - subnet
        - traffic-mirror-filter
        - traffic-mirror-session
        - traffic-mirror-target
        - transit-gateway-attachment
        - transit-gateway-connect-peer
        - transit-gateway
        - transit-gateway-multicast-domain
        - transit-gateway-policy-table
        - transit-gateway-route-table-announcement
        - transit-gateway-route-table
        - verified-access-endpoint
        - verified-access-group
        - verified-access-instance
        - verified-access-policy
        - verified-access-trust-provider
        - volume
        - vpc-endpoint-connection
        - vpc-endpoint
        - vpc-endpoint-service
        - vpc-endpoint-service-permission
        - vpc-flow-log
        - vpc
        - vpc-peering-connection
        - vpn-connection
        - vpn-gateway

        :param tag_key: The tag key to check.
        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4ca9a8d6119194d149537190960966874f6894ad997749e17d612bc989cd7ed0)
            check_type(argname="argument tag_key", value=tag_key, expected_type=type_hints["tag_key"])
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Ec2", jsii.invoke(self, "ifResourceTag", [tag_key, value, operator]))

    @jsii.member(jsii_name="ifRoleDelivery")
    def if_role_delivery(
        self,
        value: typing.Union[jsii.Number, typing.Sequence[jsii.Number]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Ec2":
        '''(experimental) Filters access by the version of the instance metadata service for retrieving IAM role credentials for EC2.

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/iam-policy-structure.html#amazon-ec2-keys

        :param value: The value(s) to check.
        :param operator: Works with `numeric operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_Numeric>`_. **Default:** ``NumericEquals``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__aee063e0e2c68b5cbae21527e58a849b722b23a84e230d17e369b2a603b4dc27)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Ec2", jsii.invoke(self, "ifRoleDelivery", [value, operator]))

    @jsii.member(jsii_name="ifRootDeviceType")
    def if_root_device_type(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Ec2":
        '''(experimental) Filters access by the root device type of the instance (ebs or instance-store).

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/iam-policy-structure.html#amazon-ec2-keys

        Applies to actions:

        - .toAssociateAddress()
        - .toAssociateIamInstanceProfile()
        - .toAttachClassicLinkVpc()
        - .toAttachNetworkInterface()
        - .toAttachVolume()
        - .toCancelImageLaunchPermission()
        - .toCreateFleet()
        - .toCreateImage()
        - .toCreateInstanceExportTask()
        - .toCreateNetworkInsightsPath()
        - .toCreateReplaceRootVolumeTask()
        - .toCreateSnapshots()
        - .toCreateStoreImageTask()
        - .toCreateTags()
        - .toDeregisterImage()
        - .toDescribeFastLaunchImages()
        - .toDescribeImageAttribute()
        - .toDescribeInstanceAttribute()
        - .toDescribeStoreImageTasks()
        - .toDetachClassicLinkVpc()
        - .toDetachNetworkInterface()
        - .toDetachVolume()
        - .toDisableFastLaunch()
        - .toDisableImageDeprecation()
        - .toDisassociateIamInstanceProfile()
        - .toEnableFastLaunch()
        - .toEnableImageDeprecation()
        - .toExportImage()
        - .toGetConsoleOutput()
        - .toGetConsoleScreenshot()
        - .toGetInstanceUefiData()
        - .toGetLaunchTemplateData()
        - .toGetPasswordData()
        - .toImportImage()
        - .toListImagesInRecycleBin()
        - .toModifyFleet()
        - .toModifyImageAttribute()
        - .toModifyInstanceAttribute()
        - .toModifyInstanceCapacityReservationAttributes()
        - .toModifyInstanceCreditSpecification()
        - .toModifyInstanceMaintenanceOptions()
        - .toModifyInstanceMetadataOptions()
        - .toModifyInstancePlacement()
        - .toModifyNetworkInterfaceAttribute()
        - .toModifyPrivateDnsNameOptions()
        - .toMonitorInstances()
        - .toRebootInstances()
        - .toReplaceIamInstanceProfileAssociation()
        - .toRequestSpotFleet()
        - .toRequestSpotInstances()
        - .toResetImageAttribute()
        - .toResetInstanceAttribute()
        - .toRestoreImageFromRecycleBin()
        - .toRunInstances()
        - .toRunScheduledInstances()
        - .toSendDiagnosticInterrupt()
        - .toSendSpotInstanceInterruptions()
        - .toStartInstances()
        - .toStopInstances()
        - .toTerminateInstances()
        - .toUnmonitorInstances()

        Applies to resource types:

        - image
        - instance

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fa222866d8796bff456f7b962403efc0775e271b3ef8f959a3ca5d5962314dbb)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Ec2", jsii.invoke(self, "ifRootDeviceType", [value, operator]))

    @jsii.member(jsii_name="ifRouteTableID")
    def if_route_table_id(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Ec2":
        '''(experimental) Filters access by the ID of a route table.

        Applies to actions:

        - .toAssociateRouteTable()
        - .toCreateRoute()
        - .toCreateRouteTable()
        - .toCreateTags()
        - .toCreateVpcEndpoint()
        - .toDeleteRoute()
        - .toDeleteRouteTable()
        - .toDisableVgwRoutePropagation()
        - .toDisassociateRouteTable()
        - .toEnableVgwRoutePropagation()
        - .toModifyVpcEndpoint()
        - .toReplaceRoute()
        - .toReplaceRouteTableAssociation()

        Applies to resource types:

        - route-table

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__de957f1470af18893125781ebbaa49cfb68526e98f9737e4fadff26720ec9b72)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Ec2", jsii.invoke(self, "ifRouteTableID", [value, operator]))

    @jsii.member(jsii_name="ifRoutingType")
    def if_routing_type(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Ec2":
        '''(experimental) Filters access by the routing type for the VPN connection.

        https://docs.aws.amazon.com/vpn/latest/s2svpn/vpn-authentication-access-control.html

        Applies to actions:

        - .toCreateTags()
        - .toCreateVpnConnection()
        - .toModifyVpnConnection()
        - .toModifyVpnTunnelOptions()

        Applies to resource types:

        - vpn-connection

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a6140454fa7d65f4b388dc915bf25198bcf7ce8d3911aefee16ccaa58e923202)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Ec2", jsii.invoke(self, "ifRoutingType", [value, operator]))

    @jsii.member(jsii_name="ifSamlProviderArn")
    def if_saml_provider_arn(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Ec2":
        '''(experimental) Filters access by the ARN of the IAM SAML identity provider.

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/iam-policy-structure.html#amazon-ec2-keys

        Applies to actions:

        - .toApplySecurityGroupsToClientVpnTargetNetwork()
        - .toAssociateClientVpnTargetNetwork()
        - .toAuthorizeClientVpnIngress()
        - .toCreateClientVpnEndpoint()
        - .toCreateClientVpnRoute()
        - .toCreateTags()
        - .toDeleteClientVpnEndpoint()
        - .toDeleteClientVpnRoute()
        - .toDescribeClientVpnConnections()
        - .toDescribeClientVpnEndpoints()
        - .toDescribeClientVpnRoutes()
        - .toDescribeClientVpnTargetNetworks()
        - .toDisassociateClientVpnTargetNetwork()
        - .toExportClientVpnClientCertificateRevocationList()
        - .toExportClientVpnClientConfiguration()
        - .toImportClientVpnClientCertificateRevocationList()
        - .toModifyClientVpnEndpoint()
        - .toRevokeClientVpnIngress()
        - .toTerminateClientVpnConnections()

        Applies to resource types:

        - client-vpn-endpoint

        :param value: The value(s) to check.
        :param operator: Works with `arn operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_ARN>`_. **Default:** ``ArnLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__78134d2500054346b464f7ef333d987097a942d7d15e52f3b9defa79beeb8f5d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Ec2", jsii.invoke(self, "ifSamlProviderArn", [value, operator]))

    @jsii.member(jsii_name="ifSecurityGroupID")
    def if_security_group_id(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Ec2":
        '''(experimental) Filters access by the ID of a security group.

        Applies to actions:

        - .toApplySecurityGroupsToClientVpnTargetNetwork()
        - .toAttachClassicLinkVpc()
        - .toAuthorizeSecurityGroupEgress()
        - .toAuthorizeSecurityGroupIngress()
        - .toCreateClientVpnEndpoint()
        - .toCreateFleet()
        - .toCreateNetworkInterface()
        - .toCreateSecurityGroup()
        - .toCreateTags()
        - .toCreateVerifiedAccessEndpoint()
        - .toCreateVpcEndpoint()
        - .toDeleteSecurityGroup()
        - .toImportInstance()
        - .toModifyClientVpnEndpoint()
        - .toModifyFleet()
        - .toModifyInstanceAttribute()
        - .toModifyNetworkInterfaceAttribute()
        - .toModifySecurityGroupRules()
        - .toModifyVpcEndpoint()
        - .toRequestSpotFleet()
        - .toRequestSpotInstances()
        - .toRevokeSecurityGroupEgress()
        - .toRevokeSecurityGroupIngress()
        - .toRunInstances()
        - .toRunScheduledInstances()
        - .toUpdateSecurityGroupRuleDescriptionsEgress()
        - .toUpdateSecurityGroupRuleDescriptionsIngress()

        Applies to resource types:

        - security-group

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1cd0b11de26c4bfd57ca3c3d97267ca69cc67da5230711820032e9a452706b01)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Ec2", jsii.invoke(self, "ifSecurityGroupID", [value, operator]))

    @jsii.member(jsii_name="ifServerCertificateArn")
    def if_server_certificate_arn(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Ec2":
        '''(experimental) Filters access by the ARN of the server certificate.

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/iam-policy-structure.html#amazon-ec2-keys

        Applies to actions:

        - .toApplySecurityGroupsToClientVpnTargetNetwork()
        - .toAssociateClientVpnTargetNetwork()
        - .toAuthorizeClientVpnIngress()
        - .toCreateClientVpnEndpoint()
        - .toCreateClientVpnRoute()
        - .toCreateTags()
        - .toDeleteClientVpnEndpoint()
        - .toDeleteClientVpnRoute()
        - .toDescribeClientVpnConnections()
        - .toDescribeClientVpnEndpoints()
        - .toDescribeClientVpnRoutes()
        - .toDescribeClientVpnTargetNetworks()
        - .toDisassociateClientVpnTargetNetwork()
        - .toExportClientVpnClientCertificateRevocationList()
        - .toExportClientVpnClientConfiguration()
        - .toImportClientVpnClientCertificateRevocationList()
        - .toModifyClientVpnEndpoint()
        - .toRevokeClientVpnIngress()
        - .toTerminateClientVpnConnections()

        Applies to resource types:

        - client-vpn-endpoint

        :param value: The value(s) to check.
        :param operator: Works with `arn operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_ARN>`_. **Default:** ``ArnLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8f1bcf35c0f8951516d76d7fd775e037019fa27c587ca44faf7d437813371d5e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Ec2", jsii.invoke(self, "ifServerCertificateArn", [value, operator]))

    @jsii.member(jsii_name="ifSnapshotID")
    def if_snapshot_id(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Ec2":
        '''(experimental) Filters access by the ID of a snapshot.

        Applies to actions:

        - .toCopySnapshot()
        - .toCreateFleet()
        - .toCreateImage()
        - .toCreateReplaceRootVolumeTask()
        - .toCreateSnapshot()
        - .toCreateSnapshots()
        - .toCreateTags()
        - .toDeleteSnapshot()
        - .toDescribeSnapshotAttribute()
        - .toDisableFastSnapshotRestores()
        - .toEnableFastSnapshotRestores()
        - .toImportImage()
        - .toImportSnapshot()
        - .toListSnapshotsInRecycleBin()
        - .toModifyFleet()
        - .toModifySnapshotAttribute()
        - .toModifySnapshotTier()
        - .toRegisterImage()
        - .toRequestSpotFleet()
        - .toRequestSpotInstances()
        - .toResetSnapshotAttribute()
        - .toRestoreSnapshotFromRecycleBin()
        - .toRestoreSnapshotTier()
        - .toRunInstances()
        - .toRunScheduledInstances()

        Applies to resource types:

        - snapshot

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0049bbb38a384953d241d186a2ee059263d86b7a467a785747c4fd7924cbced1)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Ec2", jsii.invoke(self, "ifSnapshotID", [value, operator]))

    @jsii.member(jsii_name="ifSnapshotTime")
    def if_snapshot_time(
        self,
        value: typing.Union[builtins.str, datetime.datetime, typing.Sequence[typing.Union[builtins.str, datetime.datetime]]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Ec2":
        '''(experimental) Filters access by the initiation time of a snapshot.

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/iam-policy-structure.html#amazon-ec2-keys

        Applies to actions:

        - .toCreateFleet()
        - .toCreateImage()
        - .toCreateReplaceRootVolumeTask()
        - .toCreateTags()
        - .toDeleteSnapshot()
        - .toDescribeSnapshotAttribute()
        - .toDisableFastSnapshotRestores()
        - .toEnableFastSnapshotRestores()
        - .toImportImage()
        - .toImportSnapshot()
        - .toListSnapshotsInRecycleBin()
        - .toModifyFleet()
        - .toModifySnapshotAttribute()
        - .toModifySnapshotTier()
        - .toRegisterImage()
        - .toRequestSpotFleet()
        - .toRequestSpotInstances()
        - .toResetSnapshotAttribute()
        - .toRestoreSnapshotFromRecycleBin()
        - .toRestoreSnapshotTier()
        - .toRunInstances()
        - .toRunScheduledInstances()

        Applies to resource types:

        - snapshot

        :param value: The value(s) to check.
        :param operator: Works with `date operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_Date>`_. **Default:** ``DateEquals``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__28cc01687f0297685992aebc6837d303150ec95335f1a1c28bebcd0cbc9ba015)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Ec2", jsii.invoke(self, "ifSnapshotTime", [value, operator]))

    @jsii.member(jsii_name="ifSourceInstanceARN")
    def if_source_instance_arn(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Ec2":
        '''(experimental) Filters access by the ARN of the instance from which the request originated.

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/iam-policy-structure.html#amazon-ec2-keys

        :param value: The value(s) to check.
        :param operator: Works with `arn operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_ARN>`_. **Default:** ``ArnLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__62bb29ed5ea2d281f86f0966e8ce8bfcc429638556a147a9becf54b29486ea5f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Ec2", jsii.invoke(self, "ifSourceInstanceARN", [value, operator]))

    @jsii.member(jsii_name="ifSourceOutpostArn")
    def if_source_outpost_arn(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Ec2":
        '''(experimental) Filters access by the ARN of the Outpost from which the request originated.

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/iam-policy-structure.html#amazon-ec2-keys

        Applies to actions:

        - .toCreateImage()
        - .toCreateSnapshot()
        - .toCreateSnapshots()
        - .toDeleteSnapshot()
        - .toDescribeSnapshotAttribute()
        - .toRegisterImage()
        - .toRequestSpotFleet()
        - .toRequestSpotInstances()

        Applies to resource types:

        - snapshot

        :param value: The value(s) to check.
        :param operator: Works with `arn operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_ARN>`_. **Default:** ``ArnLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__28d9ab53f4c6aba85b6e25aa284f2eb5f99455469e04c9f76c857ddef63202b3)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Ec2", jsii.invoke(self, "ifSourceOutpostArn", [value, operator]))

    @jsii.member(jsii_name="ifSubnet")
    def if_subnet(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Ec2":
        '''(experimental) Filters access by the ARN of the subnet.

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/iam-policy-structure.html#amazon-ec2-keys

        Applies to actions:

        - .toAssignIpv6Addresses()
        - .toAssignPrivateIpAddresses()
        - .toAssociateAddress()
        - .toAttachNetworkInterface()
        - .toCreateFleet()
        - .toCreateFlowLogs()
        - .toCreateLocalGatewayRoute()
        - .toCreateNetworkInsightsPath()
        - .toCreateNetworkInterfacePermission()
        - .toCreateTags()
        - .toCreateVerifiedAccessEndpoint()
        - .toDeleteNetworkInterface()
        - .toDeleteNetworkInterfacePermission()
        - .toDeregisterTransitGatewayMulticastGroupMembers()
        - .toDeregisterTransitGatewayMulticastGroupSources()
        - .toDetachNetworkInterface()
        - .toDisassociateAddress()
        - .toModifyFleet()
        - .toModifyLocalGatewayRoute()
        - .toModifyNetworkInterfaceAttribute()
        - .toRegisterTransitGatewayMulticastGroupMembers()
        - .toRegisterTransitGatewayMulticastGroupSources()
        - .toRequestSpotInstances()
        - .toResetNetworkInterfaceAttribute()
        - .toRunInstances()
        - .toRunScheduledInstances()
        - .toUnassignIpv6Addresses()
        - .toUnassignPrivateIpAddresses()

        Applies to resource types:

        - network-interface

        :param value: The value(s) to check.
        :param operator: Works with `arn operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_ARN>`_. **Default:** ``ArnLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1cd02df06b0efeb511a5dfc87e290a1bee847cb56c1a746c35acf1cad40478ef)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Ec2", jsii.invoke(self, "ifSubnet", [value, operator]))

    @jsii.member(jsii_name="ifSubnetID")
    def if_subnet_id(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Ec2":
        '''(experimental) Filters access by the ID of a subnet.

        Applies to actions:

        - .toAssociateClientVpnTargetNetwork()
        - .toAssociateRouteTable()
        - .toAssociateSubnetCidrBlock()
        - .toAssociateTransitGatewayMulticastDomain()
        - .toCreateClientVpnRoute()
        - .toCreateFleet()
        - .toCreateFlowLogs()
        - .toCreateNatGateway()
        - .toCreateNetworkInterface()
        - .toCreateSubnet()
        - .toCreateTags()
        - .toCreateTransitGatewayVpcAttachment()
        - .toCreateVerifiedAccessEndpoint()
        - .toCreateVpcEndpoint()
        - .toDeleteClientVpnRoute()
        - .toDeleteSubnet()
        - .toDisassociateRouteTable()
        - .toDisassociateSubnetCidrBlock()
        - .toDisassociateTransitGatewayMulticastDomain()
        - .toImportInstance()
        - .toModifyFleet()
        - .toModifySpotFleetRequest()
        - .toModifySubnetAttribute()
        - .toModifyTransitGatewayVpcAttachment()
        - .toModifyVerifiedAccessEndpoint()
        - .toModifyVpcEndpoint()
        - .toReplaceNetworkAclAssociation()
        - .toReplaceRouteTableAssociation()
        - .toRequestSpotFleet()
        - .toRequestSpotInstances()
        - .toRunInstances()
        - .toRunScheduledInstances()

        Applies to resource types:

        - subnet

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5e97ea1af7a101fd96b80cd8fe3cf40325b032a17f98596f073950112d071ef6)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Ec2", jsii.invoke(self, "ifSubnetID", [value, operator]))

    @jsii.member(jsii_name="ifTenancy")
    def if_tenancy(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Ec2":
        '''(experimental) Filters access by the tenancy of the VPC or instance (default, dedicated, or host).

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/iam-policy-structure.html#amazon-ec2-keys

        Applies to actions:

        - .toAcceptVpcPeeringConnection()
        - .toAssociateAddress()
        - .toAssociateDhcpOptions()
        - .toAssociateIamInstanceProfile()
        - .toAssociateVpcCidrBlock()
        - .toAttachClassicLinkVpc()
        - .toAttachInternetGateway()
        - .toAttachNetworkInterface()
        - .toAttachVolume()
        - .toAttachVpnGateway()
        - .toCreateCarrierGateway()
        - .toCreateEgressOnlyInternetGateway()
        - .toCreateFleet()
        - .toCreateFlowLogs()
        - .toCreateImage()
        - .toCreateInstanceExportTask()
        - .toCreateLocalGatewayRouteTableVpcAssociation()
        - .toCreateNetworkAcl()
        - .toCreateNetworkInsightsPath()
        - .toCreateReplaceRootVolumeTask()
        - .toCreateRouteTable()
        - .toCreateSecurityGroup()
        - .toCreateSnapshots()
        - .toCreateSubnet()
        - .toCreateTags()
        - .toCreateTransitGatewayVpcAttachment()
        - .toCreateVpcPeeringConnection()
        - .toDeleteVpc()
        - .toDescribeInstanceAttribute()
        - .toDescribeVpcAttribute()
        - .toDetachClassicLinkVpc()
        - .toDetachInternetGateway()
        - .toDetachNetworkInterface()
        - .toDetachVolume()
        - .toDetachVpnGateway()
        - .toDisableVpcClassicLink()
        - .toDisableVpcClassicLinkDnsSupport()
        - .toDisassociateIamInstanceProfile()
        - .toDisassociateVpcCidrBlock()
        - .toEnableVpcClassicLink()
        - .toEnableVpcClassicLinkDnsSupport()
        - .toGetConsoleOutput()
        - .toGetConsoleScreenshot()
        - .toGetInstanceUefiData()
        - .toGetLaunchTemplateData()
        - .toGetPasswordData()
        - .toModifyInstanceAttribute()
        - .toModifyInstanceCapacityReservationAttributes()
        - .toModifyInstanceCreditSpecification()
        - .toModifyInstanceMaintenanceOptions()
        - .toModifyInstanceMetadataOptions()
        - .toModifyInstancePlacement()
        - .toModifyNetworkInterfaceAttribute()
        - .toModifyPrivateDnsNameOptions()
        - .toModifyReservedInstances()
        - .toModifyVpcAttribute()
        - .toModifyVpcTenancy()
        - .toMonitorInstances()
        - .toRebootInstances()
        - .toReplaceIamInstanceProfileAssociation()
        - .toResetInstanceAttribute()
        - .toRunInstances()
        - .toSendDiagnosticInterrupt()
        - .toSendSpotInstanceInterruptions()
        - .toStartInstances()
        - .toStopInstances()
        - .toTerminateInstances()
        - .toUnmonitorInstances()

        Applies to resource types:

        - carrier-gateway
        - instance
        - reserved-instances
        - vpc

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a34f2bfdc092afd14d8cbe502a29a4db160e7ba22c58e33e032994d73efdee7a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Ec2", jsii.invoke(self, "ifTenancy", [value, operator]))

    @jsii.member(jsii_name="ifVolumeID")
    def if_volume_id(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Ec2":
        '''(experimental) Filters access by the ID of a volume.

        Applies to actions:

        - .toAttachVolume()
        - .toCreateFleet()
        - .toCreateReplaceRootVolumeTask()
        - .toCreateSnapshot()
        - .toCreateSnapshots()
        - .toCreateTags()
        - .toCreateVolume()
        - .toDeleteVolume()
        - .toDescribeVolumeAttribute()
        - .toDetachVolume()
        - .toEnableVolumeIO()
        - .toImportInstance()
        - .toImportVolume()
        - .toModifyInstanceAttribute()
        - .toModifyVolume()
        - .toModifyVolumeAttribute()
        - .toRunInstances()

        Applies to resource types:

        - volume

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c6f72b493a175e206f70d9f8e5d6e872b30c362a34061acc0d0369ae3750ec03)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Ec2", jsii.invoke(self, "ifVolumeID", [value, operator]))

    @jsii.member(jsii_name="ifVolumeIops")
    def if_volume_iops(
        self,
        value: typing.Union[jsii.Number, typing.Sequence[jsii.Number]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Ec2":
        '''(experimental) Filters access by the the number of input/output operations per second (IOPS) provisioned for the volume.

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/iam-policy-structure.html#amazon-ec2-keys

        Applies to actions:

        - .toAttachVolume()
        - .toCreateFleet()
        - .toCreateSnapshot()
        - .toCreateSnapshots()
        - .toCreateTags()
        - .toCreateVolume()
        - .toDeleteVolume()
        - .toDescribeVolumeAttribute()
        - .toDetachVolume()
        - .toEnableVolumeIO()
        - .toImportInstance()
        - .toImportVolume()
        - .toModifyInstanceAttribute()
        - .toModifyVolume()
        - .toModifyVolumeAttribute()
        - .toRunInstances()

        Applies to resource types:

        - volume

        :param value: The value(s) to check.
        :param operator: Works with `numeric operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_Numeric>`_. **Default:** ``NumericEquals``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7fa122c6bb70603b16596b0b83e65ec36172ab969decd1bf29b9718edde434db)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Ec2", jsii.invoke(self, "ifVolumeIops", [value, operator]))

    @jsii.member(jsii_name="ifVolumeSize")
    def if_volume_size(
        self,
        value: typing.Union[jsii.Number, typing.Sequence[jsii.Number]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Ec2":
        '''(experimental) Filters access by the size of the volume, in GiB.

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/iam-policy-structure.html#amazon-ec2-keys

        Applies to actions:

        - .toAttachVolume()
        - .toCreateFleet()
        - .toCreateImage()
        - .toCreateReplaceRootVolumeTask()
        - .toCreateSnapshot()
        - .toCreateSnapshots()
        - .toCreateTags()
        - .toCreateVolume()
        - .toDeleteSnapshot()
        - .toDeleteVolume()
        - .toDescribeSnapshotAttribute()
        - .toDescribeVolumeAttribute()
        - .toDetachVolume()
        - .toDisableFastSnapshotRestores()
        - .toEnableFastSnapshotRestores()
        - .toEnableVolumeIO()
        - .toImportImage()
        - .toImportInstance()
        - .toImportSnapshot()
        - .toImportVolume()
        - .toListSnapshotsInRecycleBin()
        - .toModifyFleet()
        - .toModifyInstanceAttribute()
        - .toModifySnapshotAttribute()
        - .toModifySnapshotTier()
        - .toModifyVolume()
        - .toModifyVolumeAttribute()
        - .toRegisterImage()
        - .toRequestSpotFleet()
        - .toRequestSpotInstances()
        - .toResetSnapshotAttribute()
        - .toRestoreSnapshotFromRecycleBin()
        - .toRestoreSnapshotTier()
        - .toRunInstances()
        - .toRunScheduledInstances()

        Applies to resource types:

        - snapshot
        - volume

        :param value: The value(s) to check.
        :param operator: Works with `numeric operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_Numeric>`_. **Default:** ``NumericEquals``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4ac93f3e9ff2f38b1516d23ea82bedd54a55be7307cdf45031f8825265897a1a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Ec2", jsii.invoke(self, "ifVolumeSize", [value, operator]))

    @jsii.member(jsii_name="ifVolumeThroughput")
    def if_volume_throughput(
        self,
        value: typing.Union[jsii.Number, typing.Sequence[jsii.Number]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Ec2":
        '''(experimental) Filters access by the throughput of the volume, in MiBps.

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/iam-policy-structure.html#amazon-ec2-keys

        Applies to actions:

        - .toAttachVolume()
        - .toCreateFleet()
        - .toCreateSnapshot()
        - .toCreateSnapshots()
        - .toCreateTags()
        - .toCreateVolume()
        - .toDeleteVolume()
        - .toDescribeVolumeAttribute()
        - .toDetachVolume()
        - .toEnableVolumeIO()
        - .toImportInstance()
        - .toImportVolume()
        - .toModifyInstanceAttribute()
        - .toModifyVolume()
        - .toModifyVolumeAttribute()
        - .toRunInstances()

        Applies to resource types:

        - volume

        :param value: The value(s) to check.
        :param operator: Works with `numeric operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_Numeric>`_. **Default:** ``NumericEquals``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5959b521d09e5b79aeac0bddd14124cb07018d16b16f438c15af8f949e7a4f2f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Ec2", jsii.invoke(self, "ifVolumeThroughput", [value, operator]))

    @jsii.member(jsii_name="ifVolumeType")
    def if_volume_type(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Ec2":
        '''(experimental) Filters access by the type of volume (gp2, gp3, io1, io2, st1, sc1, or standard).

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/iam-policy-structure.html#amazon-ec2-keys

        Applies to actions:

        - .toAttachVolume()
        - .toCreateFleet()
        - .toCreateSnapshot()
        - .toCreateSnapshots()
        - .toCreateTags()
        - .toCreateVolume()
        - .toDeleteVolume()
        - .toDescribeVolumeAttribute()
        - .toDetachVolume()
        - .toEnableVolumeIO()
        - .toImportInstance()
        - .toImportVolume()
        - .toModifyInstanceAttribute()
        - .toModifyVolume()
        - .toModifyVolumeAttribute()
        - .toRunInstances()

        Applies to resource types:

        - volume

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e0d32446c9ffcf63bc17a624a562ddafefdb29e4af69ca56c7ff437795dd012a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Ec2", jsii.invoke(self, "ifVolumeType", [value, operator]))

    @jsii.member(jsii_name="ifVpc")
    def if_vpc(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Ec2":
        '''(experimental) Filters access by the ARN of the VPC.

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/iam-policy-structure.html#amazon-ec2-keys

        Applies to actions:

        - .toAssignIpv6Addresses()
        - .toAssignPrivateIpAddresses()
        - .toAssociateAddress()
        - .toAssociateRouteTable()
        - .toAssociateSubnetCidrBlock()
        - .toAssociateTransitGatewayMulticastDomain()
        - .toAttachClassicLinkVpc()
        - .toAttachNetworkInterface()
        - .toAuthorizeSecurityGroupEgress()
        - .toAuthorizeSecurityGroupIngress()
        - .toCreateFleet()
        - .toCreateFlowLogs()
        - .toCreateLocalGatewayRoute()
        - .toCreateNatGateway()
        - .toCreateNetworkAclEntry()
        - .toCreateNetworkInsightsPath()
        - .toCreateNetworkInterface()
        - .toCreateNetworkInterfacePermission()
        - .toCreateRoute()
        - .toCreateTags()
        - .toCreateTransitGatewayVpcAttachment()
        - .toCreateVerifiedAccessEndpoint()
        - .toDeleteClientVpnRoute()
        - .toDeleteNetworkAcl()
        - .toDeleteNetworkAclEntry()
        - .toDeleteNetworkInterface()
        - .toDeleteNetworkInterfacePermission()
        - .toDeleteRoute()
        - .toDeleteRouteTable()
        - .toDeleteSecurityGroup()
        - .toDeleteSubnet()
        - .toDeregisterTransitGatewayMulticastGroupMembers()
        - .toDeregisterTransitGatewayMulticastGroupSources()
        - .toDetachNetworkInterface()
        - .toDisableVgwRoutePropagation()
        - .toDisassociateAddress()
        - .toDisassociateRouteTable()
        - .toDisassociateSubnetCidrBlock()
        - .toDisassociateTransitGatewayMulticastDomain()
        - .toEnableVgwRoutePropagation()
        - .toImportInstance()
        - .toModifyFleet()
        - .toModifyInstanceAttribute()
        - .toModifyLocalGatewayRoute()
        - .toModifyNetworkInterfaceAttribute()
        - .toModifySecurityGroupRules()
        - .toModifySpotFleetRequest()
        - .toModifySubnetAttribute()
        - .toModifyVerifiedAccessEndpoint()
        - .toRegisterTransitGatewayMulticastGroupMembers()
        - .toRegisterTransitGatewayMulticastGroupSources()
        - .toReplaceNetworkAclAssociation()
        - .toReplaceNetworkAclEntry()
        - .toReplaceRoute()
        - .toReplaceRouteTableAssociation()
        - .toRequestSpotFleet()
        - .toRequestSpotInstances()
        - .toResetNetworkInterfaceAttribute()
        - .toRevokeSecurityGroupEgress()
        - .toRevokeSecurityGroupIngress()
        - .toRunInstances()
        - .toRunScheduledInstances()
        - .toUnassignIpv6Addresses()
        - .toUnassignPrivateIpAddresses()
        - .toUpdateSecurityGroupRuleDescriptionsEgress()
        - .toUpdateSecurityGroupRuleDescriptionsIngress()

        Applies to resource types:

        - carrier-gateway
        - network-acl
        - network-interface
        - route-table
        - security-group
        - subnet

        :param value: The value(s) to check.
        :param operator: Works with `arn operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_ARN>`_. **Default:** ``ArnLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__575fdc18cf3146273fe71065d4390862678dec38207d42dcbe6be73b0a20d034)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Ec2", jsii.invoke(self, "ifVpc", [value, operator]))

    @jsii.member(jsii_name="ifVpceServiceName")
    def if_vpce_service_name(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Ec2":
        '''(experimental) Filters access by the name of the VPC endpoint service.

        https://docs.aws.amazon.com/vpc/latest/userguide/vpc-endpoints-iam.html

        Applies to actions:

        - .toCreateTrafficMirrorTarget()
        - .toCreateVpcEndpoint()
        - .toDeleteVpcEndpoints()

        Applies to resource types:

        - vpc-endpoint

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d17afabab6e5a6437f74e4c35ca1c27d03dcffe72a6e97e091f3894d7c2f9c2d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Ec2", jsii.invoke(self, "ifVpceServiceName", [value, operator]))

    @jsii.member(jsii_name="ifVpceServiceOwner")
    def if_vpce_service_owner(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Ec2":
        '''(experimental) Filters access by the service owner of the VPC endpoint service (amazon, aws-marketplace, or an AWS account ID).

        https://docs.aws.amazon.com/vpc/latest/userguide/vpc-endpoints-iam.html

        Applies to actions:

        - .toCreateTrafficMirrorTarget()
        - .toCreateVpcEndpoint()

        Applies to resource types:

        - vpc-endpoint

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c4d5ecae16e17b5b22a45839b0eac95e91a04035da5a082785721ff006c5927a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Ec2", jsii.invoke(self, "ifVpceServiceOwner", [value, operator]))

    @jsii.member(jsii_name="ifVpceServicePrivateDnsName")
    def if_vpce_service_private_dns_name(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Ec2":
        '''(experimental) Filters access by the private DNS name of the VPC endpoint service.

        https://docs.aws.amazon.com/vpc/latest/userguide/vpc-endpoints-iam.html

        Applies to actions:

        - .toCreateTags()
        - .toCreateVpcEndpointServiceConfiguration()
        - .toModifyVpcEndpointServiceConfiguration()

        Applies to resource types:

        - vpc-endpoint-service

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0b6b2885e419f9b23294be86a99fdc1a3835363cad896f9012205b2beee31d3f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Ec2", jsii.invoke(self, "ifVpceServicePrivateDnsName", [value, operator]))

    @jsii.member(jsii_name="ifVpcID")
    def if_vpc_id(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Ec2":
        '''(experimental) Filters access by the ID of a virtual private cloud (VPC).

        Applies to actions:

        - .toAcceptVpcPeeringConnection()
        - .toApplySecurityGroupsToClientVpnTargetNetwork()
        - .toAssociateDhcpOptions()
        - .toAssociateVpcCidrBlock()
        - .toAttachClassicLinkVpc()
        - .toAttachInternetGateway()
        - .toAttachVpnGateway()
        - .toCreateCarrierGateway()
        - .toCreateClientVpnEndpoint()
        - .toCreateEgressOnlyInternetGateway()
        - .toCreateFlowLogs()
        - .toCreateLocalGatewayRouteTableVpcAssociation()
        - .toCreateNetworkAcl()
        - .toCreateRouteTable()
        - .toCreateSecurityGroup()
        - .toCreateSubnet()
        - .toCreateTags()
        - .toCreateTransitGatewayVpcAttachment()
        - .toCreateVpc()
        - .toCreateVpcEndpoint()
        - .toCreateVpcPeeringConnection()
        - .toDeleteVpc()
        - .toDescribeVpcAttribute()
        - .toDetachClassicLinkVpc()
        - .toDetachInternetGateway()
        - .toDetachVpnGateway()
        - .toDisableVpcClassicLink()
        - .toDisableVpcClassicLinkDnsSupport()
        - .toDisassociateVpcCidrBlock()
        - .toEnableVpcClassicLink()
        - .toEnableVpcClassicLinkDnsSupport()
        - .toModifyClientVpnEndpoint()
        - .toModifyVpcAttribute()
        - .toModifyVpcTenancy()

        Applies to resource types:

        - vpc

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d54edba9bda6da3804a1f39521c91346eea5eba5e1ee3eba92e245452f837d6e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Ec2", jsii.invoke(self, "ifVpcID", [value, operator]))

    @jsii.member(jsii_name="ifVpcPeeringConnectionID")
    def if_vpc_peering_connection_id(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Ec2":
        '''(experimental) Filters access by the ID of a VPC peering connection.

        Applies to actions:

        - .toAcceptVpcPeeringConnection()
        - .toCreateNetworkInsightsPath()
        - .toCreateTags()
        - .toCreateVpcPeeringConnection()
        - .toDeleteVpcPeeringConnection()
        - .toModifyVpcPeeringConnectionOptions()
        - .toRejectVpcPeeringConnection()

        Applies to resource types:

        - vpc-peering-connection

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5974d812880e0f3c6b4a516156c4944982bcf1727875e7366b6d6e6303f08ada)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Ec2", jsii.invoke(self, "ifVpcPeeringConnectionID", [value, operator]))

    @jsii.member(jsii_name="onCapacityReservation")
    def on_capacity_reservation(
        self,
        capacity_reservation_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Ec2":
        '''(experimental) Adds a resource of type capacity-reservation to the statement.

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ec2-capacity-reservations.html

        :param capacity_reservation_id: - Identifier for the capacityReservationId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsRequestTag() - .ifAwsResourceTag() - .ifAwsTagKeys() - .ifAttribute() - .ifAttribute() - .ifCapacityReservationFleet() - .ifIsLaunchTemplateResource() - .ifLaunchTemplate() - .ifRegion() - .ifResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ff41c2fda110d642beafcabe0959bee533ab7f34133b5b0ee4af491c0845eb89)
            check_type(argname="argument capacity_reservation_id", value=capacity_reservation_id, expected_type=type_hints["capacity_reservation_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Ec2", jsii.invoke(self, "onCapacityReservation", [capacity_reservation_id, account, region, partition]))

    @jsii.member(jsii_name="onCapacityReservationFleet")
    def on_capacity_reservation_fleet(
        self,
        capacity_reservation_fleet_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Ec2":
        '''(experimental) Adds a resource of type capacity-reservation-fleet to the statement.

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/iam-policy-structure.html#EC2_ARN_Format

        :param capacity_reservation_fleet_id: - Identifier for the capacityReservationFleetId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsRequestTag() - .ifAwsResourceTag() - .ifAwsTagKeys() - .ifAttribute() - .ifAttribute() - .ifRegion() - .ifResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__18a9f8bcc38d2985b3e4c861c7c1901029dfaf5350bde104e1dfb7bed1247979)
            check_type(argname="argument capacity_reservation_fleet_id", value=capacity_reservation_fleet_id, expected_type=type_hints["capacity_reservation_fleet_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Ec2", jsii.invoke(self, "onCapacityReservationFleet", [capacity_reservation_fleet_id, account, region, partition]))

    @jsii.member(jsii_name="onCarrierGateway")
    def on_carrier_gateway(
        self,
        carrier_gateway_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Ec2":
        '''(experimental) Adds a resource of type carrier-gateway to the statement.

        https://docs.aws.amazon.com/vpc/latest/userguide/Carrier_Gateway.html

        :param carrier_gateway_id: - Identifier for the carrierGatewayId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsRequestTag() - .ifAwsResourceTag() - .ifAwsTagKeys() - .ifRegion() - .ifResourceTag() - .ifTenancy() - .ifVpc()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2fa6549d0ed21e190dd1379d31437bcdd4c95dd1de9d1f38c963885cae1cab67)
            check_type(argname="argument carrier_gateway_id", value=carrier_gateway_id, expected_type=type_hints["carrier_gateway_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Ec2", jsii.invoke(self, "onCarrierGateway", [carrier_gateway_id, account, region, partition]))

    @jsii.member(jsii_name="onCertificate")
    def on_certificate(
        self,
        certificate_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Ec2":
        '''(experimental) Adds a resource of type certificate to the statement.

        https://docs.aws.amazon.com/acm/latest/userguide/authen-overview.html#acm-resources-operations

        :param certificate_id: - Identifier for the certificateId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c53ee85556e4c23bbd3eaae5175dccaccb790cd2aeccee7e71bb9d5da9cff265)
            check_type(argname="argument certificate_id", value=certificate_id, expected_type=type_hints["certificate_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Ec2", jsii.invoke(self, "onCertificate", [certificate_id, account, region, partition]))

    @jsii.member(jsii_name="onClientVpnEndpoint")
    def on_client_vpn_endpoint(
        self,
        client_vpn_endpoint_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Ec2":
        '''(experimental) Adds a resource of type client-vpn-endpoint to the statement.

        https://docs.aws.amazon.com/vpn/latest/clientvpn-admin/what-is.html

        :param client_vpn_endpoint_id: - Identifier for the clientVpnEndpointId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsRequestTag() - .ifAwsResourceTag() - .ifAwsTagKeys() - .ifAttribute() - .ifAttribute() - .ifClientRootCertificateChainArn() - .ifCloudwatchLogGroupArn() - .ifCloudwatchLogStreamArn() - .ifDirectoryArn() - .ifRegion() - .ifResourceTag() - .ifSamlProviderArn() - .ifServerCertificateArn()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bdfc5504a51a6bb3e700c5a351e872cc7ba1bf4887e68bed0e9138222bf38ed9)
            check_type(argname="argument client_vpn_endpoint_id", value=client_vpn_endpoint_id, expected_type=type_hints["client_vpn_endpoint_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Ec2", jsii.invoke(self, "onClientVpnEndpoint", [client_vpn_endpoint_id, account, region, partition]))

    @jsii.member(jsii_name="onCoipPool")
    def on_coip_pool(
        self,
        ipv4_pool_coip_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Ec2":
        '''(experimental) Adds a resource of type coip-pool to the statement.

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/iam-policy-structure.html#EC2_ARN_Format

        :param ipv4_pool_coip_id: - Identifier for the ipv4PoolCoipId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsRequestTag() - .ifAwsResourceTag() - .ifAwsTagKeys() - .ifRegion() - .ifResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2b84e98b8f7f58ccfc91d4037c96f4b824a8d9c3d51a690024f94bf5be2ea277)
            check_type(argname="argument ipv4_pool_coip_id", value=ipv4_pool_coip_id, expected_type=type_hints["ipv4_pool_coip_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Ec2", jsii.invoke(self, "onCoipPool", [ipv4_pool_coip_id, account, region, partition]))

    @jsii.member(jsii_name="onCustomerGateway")
    def on_customer_gateway(
        self,
        customer_gateway_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Ec2":
        '''(experimental) Adds a resource of type customer-gateway to the statement.

        https://docs.aws.amazon.com/vpn/latest/s2svpn/VPC_VPN.html

        :param customer_gateway_id: - Identifier for the customerGatewayId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsRequestTag() - .ifAwsResourceTag() - .ifAwsTagKeys() - .ifRegion() - .ifResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1e98f25a25837837fa138116d82a10d071f582968a7f2eaedc7a575c0f28166d)
            check_type(argname="argument customer_gateway_id", value=customer_gateway_id, expected_type=type_hints["customer_gateway_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Ec2", jsii.invoke(self, "onCustomerGateway", [customer_gateway_id, account, region, partition]))

    @jsii.member(jsii_name="onDedicatedHost")
    def on_dedicated_host(
        self,
        dedicated_host_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Ec2":
        '''(experimental) Adds a resource of type dedicated-host to the statement.

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/dedicated-hosts-overview.html

        :param dedicated_host_id: - Identifier for the dedicatedHostId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsRequestTag() - .ifAwsResourceTag() - .ifAwsTagKeys() - .ifAttribute() - .ifAttribute() - .ifAutoPlacement() - .ifAvailabilityZone() - .ifHostRecovery() - .ifInstanceType() - .ifIsLaunchTemplateResource() - .ifLaunchTemplate() - .ifQuantity() - .ifRegion() - .ifResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0973eea738e20c9ffc5bbcbc015f8714a978c6d7638f9b9215b91aa550af305e)
            check_type(argname="argument dedicated_host_id", value=dedicated_host_id, expected_type=type_hints["dedicated_host_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Ec2", jsii.invoke(self, "onDedicatedHost", [dedicated_host_id, account, region, partition]))

    @jsii.member(jsii_name="onDhcpOptions")
    def on_dhcp_options(
        self,
        dhcp_options_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Ec2":
        '''(experimental) Adds a resource of type dhcp-options to the statement.

        https://docs.aws.amazon.com/vpc/latest/userguide/VPC_DHCP_Options.html

        :param dhcp_options_id: - Identifier for the dhcpOptionsId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsRequestTag() - .ifAwsResourceTag() - .ifAwsTagKeys() - .ifDhcpOptionsID() - .ifRegion() - .ifResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b894d8c356570c61a215632142176b6321dc9bf2e571cc80917f614cd41f4141)
            check_type(argname="argument dhcp_options_id", value=dhcp_options_id, expected_type=type_hints["dhcp_options_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Ec2", jsii.invoke(self, "onDhcpOptions", [dhcp_options_id, account, region, partition]))

    @jsii.member(jsii_name="onEgressOnlyInternetGateway")
    def on_egress_only_internet_gateway(
        self,
        egress_only_internet_gateway_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Ec2":
        '''(experimental) Adds a resource of type egress-only-internet-gateway to the statement.

        https://docs.aws.amazon.com/vpc/latest/userguide/egress-only-internet-gateway.html

        :param egress_only_internet_gateway_id: - Identifier for the egressOnlyInternetGatewayId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsRequestTag() - .ifAwsResourceTag() - .ifAwsTagKeys() - .ifRegion() - .ifResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__995abe701aae34805dc1b6651d2f5c79434f51b4de9af528a2a93ef469b37031)
            check_type(argname="argument egress_only_internet_gateway_id", value=egress_only_internet_gateway_id, expected_type=type_hints["egress_only_internet_gateway_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Ec2", jsii.invoke(self, "onEgressOnlyInternetGateway", [egress_only_internet_gateway_id, account, region, partition]))

    @jsii.member(jsii_name="onElasticGpu")
    def on_elastic_gpu(
        self,
        elastic_gpu_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Ec2":
        '''(experimental) Adds a resource of type elastic-gpu to the statement.

        https://docs.aws.amazon.com/AWSEC2/latest/WindowsGuide/elastic-gpus.html

        :param elastic_gpu_id: - Identifier for the elasticGpuId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsRequestTag() - .ifAwsResourceTag() - .ifAwsTagKeys() - .ifElasticGpuType() - .ifIsLaunchTemplateResource() - .ifLaunchTemplate() - .ifRegion() - .ifResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__87cf976d1fa0426f40c671ca4430a31fdabf28dca29f931a3d47ae3a4311d8dd)
            check_type(argname="argument elastic_gpu_id", value=elastic_gpu_id, expected_type=type_hints["elastic_gpu_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Ec2", jsii.invoke(self, "onElasticGpu", [elastic_gpu_id, account, region, partition]))

    @jsii.member(jsii_name="onElasticInference")
    def on_elastic_inference(
        self,
        accelerator_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Ec2":
        '''(experimental) Adds a resource of type elastic-inference to the statement.

        https://docs.aws.amazon.com/elastic-inference/latest/developerguide/what-is-ei.html

        :param accelerator_id: - Identifier for the acceleratorId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1f3c513c9ff62edc0a24365309d5be574e75368458386c4f3affa1ba704d84aa)
            check_type(argname="argument accelerator_id", value=accelerator_id, expected_type=type_hints["accelerator_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Ec2", jsii.invoke(self, "onElasticInference", [accelerator_id, account, region, partition]))

    @jsii.member(jsii_name="onElasticIp")
    def on_elastic_ip(
        self,
        allocation_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Ec2":
        '''(experimental) Adds a resource of type elastic-ip to the statement.

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/elastic-ip-addresses-eip.html

        :param allocation_id: - Identifier for the allocationId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsRequestTag() - .ifAwsResourceTag() - .ifAwsTagKeys() - .ifAllocationId() - .ifAttribute() - .ifAttribute() - .ifDomain() - .ifPublicIpAddress() - .ifRegion() - .ifResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__24aeed9d5213ca35616a4f2327f855689daefce19ac0467202e288bf62fa66e0)
            check_type(argname="argument allocation_id", value=allocation_id, expected_type=type_hints["allocation_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Ec2", jsii.invoke(self, "onElasticIp", [allocation_id, account, region, partition]))

    @jsii.member(jsii_name="onExportImageTask")
    def on_export_image_task(
        self,
        export_image_task_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Ec2":
        '''(experimental) Adds a resource of type export-image-task to the statement.

        https://docs.aws.amazon.com/vm-import/latest/userguide/vmimport-image-import.html#export-vm-image

        :param export_image_task_id: - Identifier for the exportImageTaskId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsRequestTag() - .ifAwsResourceTag() - .ifAwsTagKeys() - .ifRegion() - .ifResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e2eae3918a9e040c46244054bf6a1199d06e1e09b52d3beea283f80f06726d6d)
            check_type(argname="argument export_image_task_id", value=export_image_task_id, expected_type=type_hints["export_image_task_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Ec2", jsii.invoke(self, "onExportImageTask", [export_image_task_id, account, region, partition]))

    @jsii.member(jsii_name="onExportInstanceTask")
    def on_export_instance_task(
        self,
        export_task_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Ec2":
        '''(experimental) Adds a resource of type export-instance-task to the statement.

        https://docs.aws.amazon.com/vm-import/latest/userguide/vmexport.html

        :param export_task_id: - Identifier for the exportTaskId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsRequestTag() - .ifAwsResourceTag() - .ifAwsTagKeys() - .ifRegion() - .ifResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0f27268da4274ab7856be2becb92226f4f6a593d605f72bf96df4187664813e2)
            check_type(argname="argument export_task_id", value=export_task_id, expected_type=type_hints["export_task_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Ec2", jsii.invoke(self, "onExportInstanceTask", [export_task_id, account, region, partition]))

    @jsii.member(jsii_name="onFleet")
    def on_fleet(
        self,
        fleet_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Ec2":
        '''(experimental) Adds a resource of type fleet to the statement.

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ec2-fleet.html

        :param fleet_id: - Identifier for the fleetId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsRequestTag() - .ifAwsResourceTag() - .ifAwsTagKeys() - .ifAttribute() - .ifAttribute() - .ifRegion() - .ifResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__275caffd2d9652619ad94eaa39f933045678a6ae1fbe423142c50aed695de1e3)
            check_type(argname="argument fleet_id", value=fleet_id, expected_type=type_hints["fleet_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Ec2", jsii.invoke(self, "onFleet", [fleet_id, account, region, partition]))

    @jsii.member(jsii_name="onFpgaImage")
    def on_fpga_image(
        self,
        fpga_image_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Ec2":
        '''(experimental) Adds a resource of type fpga-image to the statement.

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/iam-policy-structure.html#EC2_ARN_Format

        :param fpga_image_id: - Identifier for the fpgaImageId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsRequestTag() - .ifAwsResourceTag() - .ifAwsTagKeys() - .ifAttribute() - .ifAttribute() - .ifOwner() - .ifPublic() - .ifRegion() - .ifResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e74c3459ebd918e807dd15710b61e351d6b68fcb31c1d46c97469690271da2ae)
            check_type(argname="argument fpga_image_id", value=fpga_image_id, expected_type=type_hints["fpga_image_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Ec2", jsii.invoke(self, "onFpgaImage", [fpga_image_id, account, region, partition]))

    @jsii.member(jsii_name="onGroup")
    def on_group(
        self,
        group_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Ec2":
        '''(experimental) Adds a resource of type group to the statement.

        https://docs.aws.amazon.com/ARG/latest/userguide/resource-groups.html

        :param group_name: - Identifier for the groupName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4fa2a071c2391bb20f846e520a79cef67f45bd0f02d36bedf1e13a8553033e01)
            check_type(argname="argument group_name", value=group_name, expected_type=type_hints["group_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Ec2", jsii.invoke(self, "onGroup", [group_name, account, region, partition]))

    @jsii.member(jsii_name="onHostReservation")
    def on_host_reservation(
        self,
        host_reservation_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Ec2":
        '''(experimental) Adds a resource of type host-reservation to the statement.

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/iam-policy-structure.html#EC2_ARN_Format

        :param host_reservation_id: - Identifier for the hostReservationId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsRequestTag() - .ifAwsResourceTag() - .ifAwsTagKeys() - .ifRegion() - .ifResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__038dd63a1f986bb810accf5de0868216e0d2222776f211b47ccdebf2a809c91a)
            check_type(argname="argument host_reservation_id", value=host_reservation_id, expected_type=type_hints["host_reservation_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Ec2", jsii.invoke(self, "onHostReservation", [host_reservation_id, account, region, partition]))

    @jsii.member(jsii_name="onImage")
    def on_image(
        self,
        image_id: builtins.str,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Ec2":
        '''(experimental) Adds a resource of type image to the statement.

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/AMIs.html

        :param image_id: - Identifier for the imageId.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsRequestTag() - .ifAwsResourceTag() - .ifAwsTagKeys() - .ifAttribute() - .ifAttribute() - .ifImageID() - .ifImageType() - .ifIsLaunchTemplateResource() - .ifLaunchTemplate() - .ifOwner() - .ifPublic() - .ifRegion() - .ifResourceTag() - .ifRootDeviceType()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__128ac21d255a419cb7a8a693f27f83d549f5474a99231190ae68fc01533a63df)
            check_type(argname="argument image_id", value=image_id, expected_type=type_hints["image_id"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Ec2", jsii.invoke(self, "onImage", [image_id, region, partition]))

    @jsii.member(jsii_name="onImportImageTask")
    def on_import_image_task(
        self,
        import_image_task_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Ec2":
        '''(experimental) Adds a resource of type import-image-task to the statement.

        https://docs.aws.amazon.com/vm-import/latest/userguide/vmimport-image-import.html#import-vm-image

        :param import_image_task_id: - Identifier for the importImageTaskId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsRequestTag() - .ifAwsResourceTag() - .ifAwsTagKeys() - .ifRegion() - .ifResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__cdc585105e2be50ba97bee94ed5661aa7c1d52d6dd7f4a5e866c8d4c4029f853)
            check_type(argname="argument import_image_task_id", value=import_image_task_id, expected_type=type_hints["import_image_task_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Ec2", jsii.invoke(self, "onImportImageTask", [import_image_task_id, account, region, partition]))

    @jsii.member(jsii_name="onImportSnapshotTask")
    def on_import_snapshot_task(
        self,
        import_snapshot_task_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Ec2":
        '''(experimental) Adds a resource of type import-snapshot-task to the statement.

        https://docs.aws.amazon.com/vm-import/latest/userguide/vmimport-import-snapshot.html

        :param import_snapshot_task_id: - Identifier for the importSnapshotTaskId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsRequestTag() - .ifAwsResourceTag() - .ifAwsTagKeys() - .ifRegion() - .ifResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__63988efb508ee2ee9f4f025d55de53052ab4431044c95805394e41162df7db25)
            check_type(argname="argument import_snapshot_task_id", value=import_snapshot_task_id, expected_type=type_hints["import_snapshot_task_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Ec2", jsii.invoke(self, "onImportSnapshotTask", [import_snapshot_task_id, account, region, partition]))

    @jsii.member(jsii_name="onInstance")
    def on_instance(
        self,
        instance_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Ec2":
        '''(experimental) Adds a resource of type instance to the statement.

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/Instances.html

        :param instance_id: - Identifier for the instanceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsRequestTag() - .ifAwsResourceTag() - .ifAwsTagKeys() - .ifAttribute() - .ifAttribute() - .ifAvailabilityZone() - .ifEbsOptimized() - .ifInstanceAutoRecovery() - .ifInstanceID() - .ifInstanceMarketType() - .ifInstanceMetadataTags() - .ifInstanceProfile() - .ifInstanceType() - .ifIsLaunchTemplateResource() - .ifLaunchTemplate() - .ifMetadataHttpEndpoint() - .ifMetadataHttpPutResponseHopLimit() - .ifMetadataHttpTokens() - .ifNewInstanceProfile() - .ifPlacementGroup() - .ifProductCode() - .ifRegion() - .ifResourceTag() - .ifRootDeviceType() - .ifTenancy()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7b5f4eb88c1597f515c0b0a7ad0f10eb95fcc48e82d0ef49a73e30f89735ef25)
            check_type(argname="argument instance_id", value=instance_id, expected_type=type_hints["instance_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Ec2", jsii.invoke(self, "onInstance", [instance_id, account, region, partition]))

    @jsii.member(jsii_name="onInstanceEventWindow")
    def on_instance_event_window(
        self,
        instance_event_window_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Ec2":
        '''(experimental) Adds a resource of type instance-event-window to the statement.

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/iam-policy-structure.html#EC2_ARN_Format

        :param instance_event_window_id: - Identifier for the instanceEventWindowId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsRequestTag() - .ifAwsResourceTag() - .ifAwsTagKeys() - .ifRegion() - .ifResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0ec9b0290c2ed8288635ee6e448cc007ace5af4338c153ad367c6f8dd8c5a793)
            check_type(argname="argument instance_event_window_id", value=instance_event_window_id, expected_type=type_hints["instance_event_window_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Ec2", jsii.invoke(self, "onInstanceEventWindow", [instance_event_window_id, account, region, partition]))

    @jsii.member(jsii_name="onInternetGateway")
    def on_internet_gateway(
        self,
        internet_gateway_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Ec2":
        '''(experimental) Adds a resource of type internet-gateway to the statement.

        https://docs.aws.amazon.com/vpc/latest/userguide/VPC_Internet_Gateway.html

        :param internet_gateway_id: - Identifier for the internetGatewayId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsRequestTag() - .ifAwsResourceTag() - .ifAwsTagKeys() - .ifInternetGatewayID() - .ifRegion() - .ifResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5a0801f6d45778d30e0e349e736f662da1b28770d748d6cf585fb70db7c37f14)
            check_type(argname="argument internet_gateway_id", value=internet_gateway_id, expected_type=type_hints["internet_gateway_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Ec2", jsii.invoke(self, "onInternetGateway", [internet_gateway_id, account, region, partition]))

    @jsii.member(jsii_name="onIpam")
    def on_ipam(
        self,
        ipam_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Ec2":
        '''(experimental) Adds a resource of type ipam to the statement.

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/iam-policy-structure.html#EC2_ARN_Format

        :param ipam_id: - Identifier for the ipamId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsRequestTag() - .ifAwsResourceTag() - .ifAwsTagKeys() - .ifAttribute() - .ifAttribute() - .ifRegion() - .ifResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c016a91a5d7c594ea9112b01a048fa247501982f24b56a5f8e9b7377f98965bb)
            check_type(argname="argument ipam_id", value=ipam_id, expected_type=type_hints["ipam_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Ec2", jsii.invoke(self, "onIpam", [ipam_id, account, partition]))

    @jsii.member(jsii_name="onIpamPool")
    def on_ipam_pool(
        self,
        ipam_pool_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Ec2":
        '''(experimental) Adds a resource of type ipam-pool to the statement.

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/iam-policy-structure.html#EC2_ARN_Format

        :param ipam_pool_id: - Identifier for the ipamPoolId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsRequestTag() - .ifAwsResourceTag() - .ifAwsTagKeys() - .ifAttribute() - .ifAttribute() - .ifRegion() - .ifResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__95d2ba0720d8f81bea195f380f4451deb650f34bf3d4ade943937a100a4e4da6)
            check_type(argname="argument ipam_pool_id", value=ipam_pool_id, expected_type=type_hints["ipam_pool_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Ec2", jsii.invoke(self, "onIpamPool", [ipam_pool_id, account, partition]))

    @jsii.member(jsii_name="onIpamScope")
    def on_ipam_scope(
        self,
        ipam_scope_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Ec2":
        '''(experimental) Adds a resource of type ipam-scope to the statement.

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/iam-policy-structure.html#EC2_ARN_Format

        :param ipam_scope_id: - Identifier for the ipamScopeId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsRequestTag() - .ifAwsResourceTag() - .ifAwsTagKeys() - .ifAttribute() - .ifAttribute() - .ifRegion() - .ifResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b97c815002439b0270e62e1f8473a9296d2d6cb8e23273027c9cc0d474db7efb)
            check_type(argname="argument ipam_scope_id", value=ipam_scope_id, expected_type=type_hints["ipam_scope_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Ec2", jsii.invoke(self, "onIpamScope", [ipam_scope_id, account, partition]))

    @jsii.member(jsii_name="onIpv4poolEc2")
    def on_ipv4pool_ec2(
        self,
        ipv4_pool_ec2_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Ec2":
        '''(experimental) Adds a resource of type ipv4pool-ec2 to the statement.

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/using-instance-addressing.html#ip-addressing-eips

        :param ipv4_pool_ec2_id: - Identifier for the ipv4PoolEc2Id.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsRequestTag() - .ifAwsResourceTag() - .ifAwsTagKeys() - .ifRegion() - .ifResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f54e2d29b01c2abbdd59cdc6be0cbe57c80eadb2a6ab670c3eadd353004033e2)
            check_type(argname="argument ipv4_pool_ec2_id", value=ipv4_pool_ec2_id, expected_type=type_hints["ipv4_pool_ec2_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Ec2", jsii.invoke(self, "onIpv4poolEc2", [ipv4_pool_ec2_id, account, region, partition]))

    @jsii.member(jsii_name="onIpv6poolEc2")
    def on_ipv6pool_ec2(
        self,
        ipv6_pool_ec2_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Ec2":
        '''(experimental) Adds a resource of type ipv6pool-ec2 to the statement.

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/using-instance-addressing.html#ipv6-addressing

        :param ipv6_pool_ec2_id: - Identifier for the ipv6PoolEc2Id.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsRequestTag() - .ifAwsResourceTag() - .ifAwsTagKeys() - .ifRegion() - .ifResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3bab84c9b8f13f56da1e325521e24ed6b54341d5d5126beea73af2e2010b5590)
            check_type(argname="argument ipv6_pool_ec2_id", value=ipv6_pool_ec2_id, expected_type=type_hints["ipv6_pool_ec2_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Ec2", jsii.invoke(self, "onIpv6poolEc2", [ipv6_pool_ec2_id, account, region, partition]))

    @jsii.member(jsii_name="onKeyPair")
    def on_key_pair(
        self,
        key_pair_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Ec2":
        '''(experimental) Adds a resource of type key-pair to the statement.

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ec2-key-pairs.html

        :param key_pair_name: - Identifier for the keyPairName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsRequestTag() - .ifAwsResourceTag() - .ifAwsTagKeys() - .ifIsLaunchTemplateResource() - .ifKeyPairName() - .ifKeyPairType() - .ifLaunchTemplate() - .ifRegion() - .ifResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__73d70858ca58eab66d0050b64cb2399b059e150334f64d8c3c5c87a76c3f38da)
            check_type(argname="argument key_pair_name", value=key_pair_name, expected_type=type_hints["key_pair_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Ec2", jsii.invoke(self, "onKeyPair", [key_pair_name, account, region, partition]))

    @jsii.member(jsii_name="onLaunchTemplate")
    def on_launch_template(
        self,
        launch_template_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Ec2":
        '''(experimental) Adds a resource of type launch-template to the statement.

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ec2-launch-templates.html

        :param launch_template_id: - Identifier for the launchTemplateId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsRequestTag() - .ifAwsResourceTag() - .ifAwsTagKeys() - .ifAttribute() - .ifAttribute() - .ifIsLaunchTemplateResource() - .ifLaunchTemplate() - .ifRegion() - .ifResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1a8c62ef57f9956fba2ecb10e98d603c6a1b38102720b484e149ca1799cb8f6d)
            check_type(argname="argument launch_template_id", value=launch_template_id, expected_type=type_hints["launch_template_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Ec2", jsii.invoke(self, "onLaunchTemplate", [launch_template_id, account, region, partition]))

    @jsii.member(jsii_name="onLicenseConfiguration")
    def on_license_configuration(
        self,
        license_configuration_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Ec2":
        '''(experimental) Adds a resource of type license-configuration to the statement.

        https://docs.aws.amazon.com/license-manager/latest/userguide/create-license-configuration.html

        :param license_configuration_id: - Identifier for the licenseConfigurationId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__424eb3aa990ad23a68b94c9860791d37091fdd89761384ccf791498971804e02)
            check_type(argname="argument license_configuration_id", value=license_configuration_id, expected_type=type_hints["license_configuration_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Ec2", jsii.invoke(self, "onLicenseConfiguration", [license_configuration_id, account, region, partition]))

    @jsii.member(jsii_name="onLocalGateway")
    def on_local_gateway(
        self,
        local_gateway_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Ec2":
        '''(experimental) Adds a resource of type local-gateway to the statement.

        https://docs.aws.amazon.com/outposts/latest/userguide/outposts-local-gateways.html#lgw

        :param local_gateway_id: - Identifier for the localGatewayId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsRequestTag() - .ifAwsResourceTag() - .ifAwsTagKeys() - .ifRegion() - .ifResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__03ab5ae72e9e5be4574eea33b8a3edc7021a36e28e7f2f66e18ea17a6d28a9e2)
            check_type(argname="argument local_gateway_id", value=local_gateway_id, expected_type=type_hints["local_gateway_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Ec2", jsii.invoke(self, "onLocalGateway", [local_gateway_id, account, region, partition]))

    @jsii.member(jsii_name="onLocalGatewayRouteTable")
    def on_local_gateway_route_table(
        self,
        local_gateway_routetable_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Ec2":
        '''(experimental) Adds a resource of type local-gateway-route-table to the statement.

        https://docs.aws.amazon.com/outposts/latest/userguide/outposts-local-gateways.html#route-tables

        :param local_gateway_routetable_id: - Identifier for the localGatewayRoutetableId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsRequestTag() - .ifAwsResourceTag() - .ifAwsTagKeys() - .ifRegion() - .ifResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__30fbccbab75eabbbbad4c0544bd4677f819a4766ecb5328f6605796724f74241)
            check_type(argname="argument local_gateway_routetable_id", value=local_gateway_routetable_id, expected_type=type_hints["local_gateway_routetable_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Ec2", jsii.invoke(self, "onLocalGatewayRouteTable", [local_gateway_routetable_id, account, region, partition]))

    @jsii.member(jsii_name="onLocalGatewayRouteTableVirtualInterfaceGroupAssociation")
    def on_local_gateway_route_table_virtual_interface_group_association(
        self,
        local_gateway_route_table_virtual_interface_group_association_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Ec2":
        '''(experimental) Adds a resource of type local-gateway-route-table-virtual-interface-group-association to the statement.

        https://docs.aws.amazon.com/outposts/latest/userguide/outposts-local-gateways.html

        :param local_gateway_route_table_virtual_interface_group_association_id: - Identifier for the localGatewayRouteTableVirtualInterfaceGroupAssociationId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsRequestTag() - .ifAwsResourceTag() - .ifAwsTagKeys() - .ifRegion() - .ifResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ce037f4563039e3defdf363a0c615d5e2d5da1fc1fa8e0c7cc2c4c2c9fdc9187)
            check_type(argname="argument local_gateway_route_table_virtual_interface_group_association_id", value=local_gateway_route_table_virtual_interface_group_association_id, expected_type=type_hints["local_gateway_route_table_virtual_interface_group_association_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Ec2", jsii.invoke(self, "onLocalGatewayRouteTableVirtualInterfaceGroupAssociation", [local_gateway_route_table_virtual_interface_group_association_id, account, region, partition]))

    @jsii.member(jsii_name="onLocalGatewayRouteTableVpcAssociation")
    def on_local_gateway_route_table_vpc_association(
        self,
        local_gateway_route_table_vpc_association_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Ec2":
        '''(experimental) Adds a resource of type local-gateway-route-table-vpc-association to the statement.

        https://docs.aws.amazon.com/outposts/latest/userguide/outposts-local-gateways.html#vpc-associations

        :param local_gateway_route_table_vpc_association_id: - Identifier for the localGatewayRouteTableVpcAssociationId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsRequestTag() - .ifAwsResourceTag() - .ifAwsTagKeys() - .ifRegion() - .ifResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__19c8196cd84705d97f2fb0752b8f8e8237b4803760daa20d0051b7529b59355a)
            check_type(argname="argument local_gateway_route_table_vpc_association_id", value=local_gateway_route_table_vpc_association_id, expected_type=type_hints["local_gateway_route_table_vpc_association_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Ec2", jsii.invoke(self, "onLocalGatewayRouteTableVpcAssociation", [local_gateway_route_table_vpc_association_id, account, region, partition]))

    @jsii.member(jsii_name="onLocalGatewayVirtualInterface")
    def on_local_gateway_virtual_interface(
        self,
        local_gateway_virtual_interface_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Ec2":
        '''(experimental) Adds a resource of type local-gateway-virtual-interface to the statement.

        https://docs.aws.amazon.com/outposts/latest/userguide/outposts-local-gateways.html

        :param local_gateway_virtual_interface_id: - Identifier for the localGatewayVirtualInterfaceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsRequestTag() - .ifAwsResourceTag() - .ifAwsTagKeys() - .ifRegion() - .ifResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__eb0c62a8b3038430827cc91bce580bbadffb8d43cad27eaf44f805bc4c853aa2)
            check_type(argname="argument local_gateway_virtual_interface_id", value=local_gateway_virtual_interface_id, expected_type=type_hints["local_gateway_virtual_interface_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Ec2", jsii.invoke(self, "onLocalGatewayVirtualInterface", [local_gateway_virtual_interface_id, account, region, partition]))

    @jsii.member(jsii_name="onLocalGatewayVirtualInterfaceGroup")
    def on_local_gateway_virtual_interface_group(
        self,
        local_gateway_virtual_interface_group_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Ec2":
        '''(experimental) Adds a resource of type local-gateway-virtual-interface-group to the statement.

        https://docs.aws.amazon.com/outposts/latest/userguide/outposts-local-gateways.html

        :param local_gateway_virtual_interface_group_id: - Identifier for the localGatewayVirtualInterfaceGroupId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsRequestTag() - .ifAwsResourceTag() - .ifAwsTagKeys() - .ifRegion() - .ifResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ee9ad2a34c0aa428bb8e63950546726d819b573afe912a421e1da9790570088f)
            check_type(argname="argument local_gateway_virtual_interface_group_id", value=local_gateway_virtual_interface_group_id, expected_type=type_hints["local_gateway_virtual_interface_group_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Ec2", jsii.invoke(self, "onLocalGatewayVirtualInterfaceGroup", [local_gateway_virtual_interface_group_id, account, region, partition]))

    @jsii.member(jsii_name="onNatgateway")
    def on_natgateway(
        self,
        nat_gateway_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Ec2":
        '''(experimental) Adds a resource of type natgateway to the statement.

        https://docs.aws.amazon.com/vpc/latest/userguide/vpc-nat-gateway.html

        :param nat_gateway_id: - Identifier for the natGatewayId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsRequestTag() - .ifAwsResourceTag() - .ifAwsTagKeys() - .ifRegion() - .ifResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4a6ba0710c73a276eb3a0577e052d93fb874c8d3acc9979bf901f590386a55db)
            check_type(argname="argument nat_gateway_id", value=nat_gateway_id, expected_type=type_hints["nat_gateway_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Ec2", jsii.invoke(self, "onNatgateway", [nat_gateway_id, account, region, partition]))

    @jsii.member(jsii_name="onNetworkAcl")
    def on_network_acl(
        self,
        nacl_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Ec2":
        '''(experimental) Adds a resource of type network-acl to the statement.

        https://docs.aws.amazon.com/vpc/latest/userguide/vpc-network-acls.html

        :param nacl_id: - Identifier for the naclId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsRequestTag() - .ifAwsResourceTag() - .ifAwsTagKeys() - .ifNetworkAclID() - .ifRegion() - .ifResourceTag() - .ifVpc()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2297d70d95fcb4a8a2bee798daeae3bf6fecea7e260e7e1334e73ba71de8bc2f)
            check_type(argname="argument nacl_id", value=nacl_id, expected_type=type_hints["nacl_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Ec2", jsii.invoke(self, "onNetworkAcl", [nacl_id, account, region, partition]))

    @jsii.member(jsii_name="onNetworkInsightsAccessScope")
    def on_network_insights_access_scope(
        self,
        network_insights_access_scope_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Ec2":
        '''(experimental) Adds a resource of type network-insights-access-scope to the statement.

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/iam-policy-structure.html#EC2_ARN_Format

        :param network_insights_access_scope_id: - Identifier for the networkInsightsAccessScopeId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsRequestTag() - .ifAwsResourceTag() - .ifAwsTagKeys() - .ifRegion() - .ifResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__625625649c6586dbd2b285e080d851ae6f9ceb23efc5aa0e7e83f8788386908b)
            check_type(argname="argument network_insights_access_scope_id", value=network_insights_access_scope_id, expected_type=type_hints["network_insights_access_scope_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Ec2", jsii.invoke(self, "onNetworkInsightsAccessScope", [network_insights_access_scope_id, account, region, partition]))

    @jsii.member(jsii_name="onNetworkInsightsAccessScopeAnalysis")
    def on_network_insights_access_scope_analysis(
        self,
        network_insights_access_scope_analysis_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Ec2":
        '''(experimental) Adds a resource of type network-insights-access-scope-analysis to the statement.

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/iam-policy-structure.html#EC2_ARN_Format

        :param network_insights_access_scope_analysis_id: - Identifier for the networkInsightsAccessScopeAnalysisId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsRequestTag() - .ifAwsResourceTag() - .ifAwsTagKeys() - .ifRegion() - .ifResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7518ae30f5475a57f32d381d2c12e9a32f0272a513c65d919465695c3f9b41f3)
            check_type(argname="argument network_insights_access_scope_analysis_id", value=network_insights_access_scope_analysis_id, expected_type=type_hints["network_insights_access_scope_analysis_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Ec2", jsii.invoke(self, "onNetworkInsightsAccessScopeAnalysis", [network_insights_access_scope_analysis_id, account, region, partition]))

    @jsii.member(jsii_name="onNetworkInsightsAnalysis")
    def on_network_insights_analysis(
        self,
        network_insights_analysis_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Ec2":
        '''(experimental) Adds a resource of type network-insights-analysis to the statement.

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/iam-policy-structure.html#EC2_ARN_Format

        :param network_insights_analysis_id: - Identifier for the networkInsightsAnalysisId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsRequestTag() - .ifAwsResourceTag() - .ifAwsTagKeys() - .ifRegion() - .ifResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__cf65b4e38026f9af15c0d1de82423efef3cfc123a825ffbe2b1d1cca782cc917)
            check_type(argname="argument network_insights_analysis_id", value=network_insights_analysis_id, expected_type=type_hints["network_insights_analysis_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Ec2", jsii.invoke(self, "onNetworkInsightsAnalysis", [network_insights_analysis_id, account, region, partition]))

    @jsii.member(jsii_name="onNetworkInsightsPath")
    def on_network_insights_path(
        self,
        network_insights_path_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Ec2":
        '''(experimental) Adds a resource of type network-insights-path to the statement.

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/iam-policy-structure.html#EC2_ARN_Format

        :param network_insights_path_id: - Identifier for the networkInsightsPathId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsRequestTag() - .ifAwsResourceTag() - .ifAwsTagKeys() - .ifRegion() - .ifResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b370e519b5f1f7652680f181edaa03cbc253d15df28fcfd1dbc9c6bf48d6359c)
            check_type(argname="argument network_insights_path_id", value=network_insights_path_id, expected_type=type_hints["network_insights_path_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Ec2", jsii.invoke(self, "onNetworkInsightsPath", [network_insights_path_id, account, region, partition]))

    @jsii.member(jsii_name="onNetworkInterface")
    def on_network_interface(
        self,
        network_interface_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Ec2":
        '''(experimental) Adds a resource of type network-interface to the statement.

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/using-eni.html

        :param network_interface_id: - Identifier for the networkInterfaceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsRequestTag() - .ifAwsResourceTag() - .ifAwsTagKeys() - .ifAssociatePublicIpAddress() - .ifAttribute() - .ifAttribute() - .ifAuthorizedService() - .ifAuthorizedUser() - .ifAvailabilityZone() - .ifIsLaunchTemplateResource() - .ifLaunchTemplate() - .ifNetworkInterfaceID() - .ifPermission() - .ifRegion() - .ifResourceTag() - .ifSubnet() - .ifVpc()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__24e03346a09440b995413651c44e476a2306029b9d9bab98cb91d749b48787e9)
            check_type(argname="argument network_interface_id", value=network_interface_id, expected_type=type_hints["network_interface_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Ec2", jsii.invoke(self, "onNetworkInterface", [network_interface_id, account, region, partition]))

    @jsii.member(jsii_name="onPlacementGroup")
    def on_placement_group(
        self,
        placement_group_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Ec2":
        '''(experimental) Adds a resource of type placement-group to the statement.

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/placement-groups.html

        :param placement_group_name: - Identifier for the placementGroupName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsRequestTag() - .ifAwsResourceTag() - .ifAwsTagKeys() - .ifIsLaunchTemplateResource() - .ifLaunchTemplate() - .ifPlacementGroupName() - .ifPlacementGroupStrategy() - .ifRegion() - .ifResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2d66f898c30cedb71d8d6a08af6166e275af30cc289cdd8811ed33cb1dfa170c)
            check_type(argname="argument placement_group_name", value=placement_group_name, expected_type=type_hints["placement_group_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Ec2", jsii.invoke(self, "onPlacementGroup", [placement_group_name, account, region, partition]))

    @jsii.member(jsii_name="onPrefixList")
    def on_prefix_list(
        self,
        prefix_list_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Ec2":
        '''(experimental) Adds a resource of type prefix-list to the statement.

        https://docs.aws.amazon.com/vpc/latest/userguide/managed-prefix-lists.html

        :param prefix_list_id: - Identifier for the prefixListId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsRequestTag() - .ifAwsResourceTag() - .ifAwsTagKeys() - .ifAttribute() - .ifAttribute() - .ifRegion() - .ifResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5680f6ef4446a8105815a2e17023cfbf5edc83e1b532773852de4dab8e8ea997)
            check_type(argname="argument prefix_list_id", value=prefix_list_id, expected_type=type_hints["prefix_list_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Ec2", jsii.invoke(self, "onPrefixList", [prefix_list_id, account, region, partition]))

    @jsii.member(jsii_name="onReplaceRootVolumeTask")
    def on_replace_root_volume_task(
        self,
        replace_root_volume_task_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Ec2":
        '''(experimental) Adds a resource of type replace-root-volume-task to the statement.

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/replace-root.html

        :param replace_root_volume_task_id: - Identifier for the replaceRootVolumeTaskId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsRequestTag() - .ifAwsResourceTag() - .ifAwsTagKeys() - .ifRegion() - .ifResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4568185401d99542b0ef1faa06d51128bf755073b627a788a0813cb4a18e43c1)
            check_type(argname="argument replace_root_volume_task_id", value=replace_root_volume_task_id, expected_type=type_hints["replace_root_volume_task_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Ec2", jsii.invoke(self, "onReplaceRootVolumeTask", [replace_root_volume_task_id, account, region, partition]))

    @jsii.member(jsii_name="onReservedInstances")
    def on_reserved_instances(
        self,
        reservation_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Ec2":
        '''(experimental) Adds a resource of type reserved-instances to the statement.

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ec2-reserved-instances.html

        :param reservation_id: - Identifier for the reservationId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsRequestTag() - .ifAwsResourceTag() - .ifAwsTagKeys() - .ifAttribute() - .ifAttribute() - .ifAvailabilityZone() - .ifInstanceType() - .ifRegion() - .ifReservedInstancesOfferingType() - .ifResourceTag() - .ifTenancy()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4ef05aa95a51459f6dd53cd65ec57c43af8cd5e23d3c546eec11ef697eb08201)
            check_type(argname="argument reservation_id", value=reservation_id, expected_type=type_hints["reservation_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Ec2", jsii.invoke(self, "onReservedInstances", [reservation_id, account, region, partition]))

    @jsii.member(jsii_name="onRole")
    def on_role(
        self,
        role_name_with_path: builtins.str,
        account: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Ec2":
        '''(experimental) Adds a resource of type role to the statement.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/id_roles.html

        :param role_name_with_path: - Identifier for the roleNameWithPath.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1bfa444315b99a38ae93d4b607bfd70a7e20c3aa86ac91ca2fb6e323e9b01c5f)
            check_type(argname="argument role_name_with_path", value=role_name_with_path, expected_type=type_hints["role_name_with_path"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Ec2", jsii.invoke(self, "onRole", [role_name_with_path, account, partition]))

    @jsii.member(jsii_name="onRouteTable")
    def on_route_table(
        self,
        route_table_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Ec2":
        '''(experimental) Adds a resource of type route-table to the statement.

        https://docs.aws.amazon.com/vpc/latest/userguide/VPC_Route_Tables.html

        :param route_table_id: - Identifier for the routeTableId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsRequestTag() - .ifAwsResourceTag() - .ifAwsTagKeys() - .ifRegion() - .ifResourceTag() - .ifRouteTableID() - .ifVpc()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__68d41184f7fa95f85ffef0bd1befc5952fa150a6b07aa6fb9c6eb9c361ac151a)
            check_type(argname="argument route_table_id", value=route_table_id, expected_type=type_hints["route_table_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Ec2", jsii.invoke(self, "onRouteTable", [route_table_id, account, region, partition]))

    @jsii.member(jsii_name="onSecurityGroup")
    def on_security_group(
        self,
        security_group_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Ec2":
        '''(experimental) Adds a resource of type security-group to the statement.

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ec2-security-groups.html

        :param security_group_id: - Identifier for the securityGroupId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsRequestTag() - .ifAwsResourceTag() - .ifAwsTagKeys() - .ifAttribute() - .ifAttribute() - .ifIsLaunchTemplateResource() - .ifLaunchTemplate() - .ifRegion() - .ifResourceTag() - .ifSecurityGroupID() - .ifVpc()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c4c992bb6bac8aabfb9c25bfd9cf3c637452901a39df4c5463eff3fc34dc5c34)
            check_type(argname="argument security_group_id", value=security_group_id, expected_type=type_hints["security_group_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Ec2", jsii.invoke(self, "onSecurityGroup", [security_group_id, account, region, partition]))

    @jsii.member(jsii_name="onSecurityGroupRule")
    def on_security_group_rule(
        self,
        security_group_rule_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Ec2":
        '''(experimental) Adds a resource of type security-group-rule to the statement.

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/iam-policy-structure.html#EC2_ARN_Format

        :param security_group_rule_id: - Identifier for the securityGroupRuleId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsRequestTag() - .ifAwsResourceTag() - .ifAwsTagKeys() - .ifRegion() - .ifResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__408fe256e3cd5dbe6134e5985eb83f26adfa1b5e6dbef0197b87358ae96283d1)
            check_type(argname="argument security_group_rule_id", value=security_group_rule_id, expected_type=type_hints["security_group_rule_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Ec2", jsii.invoke(self, "onSecurityGroupRule", [security_group_rule_id, account, region, partition]))

    @jsii.member(jsii_name="onSnapshot")
    def on_snapshot(
        self,
        snapshot_id: builtins.str,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Ec2":
        '''(experimental) Adds a resource of type snapshot to the statement.

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/EBSSnapshots.html

        :param snapshot_id: - Identifier for the snapshotId.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsRequestTag() - .ifAwsResourceTag() - .ifAwsTagKeys() - .ifAddGroup() - .ifAddUserId() - .ifAttribute() - .ifAttribute() - .ifAvailabilityZone() - .ifEncrypted() - .ifIsLaunchTemplateResource() - .ifLaunchTemplate() - .ifOutpostArn() - .ifOwner() - .ifParentVolume() - .ifRegion() - .ifRemoveGroup() - .ifRemoveUserId() - .ifResourceTag() - .ifSnapshotID() - .ifSnapshotTime() - .ifSourceOutpostArn() - .ifVolumeSize()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2f8d8ffe31aa417b5b25d257023b5f8ea7b14113f57e3c9bee04f37e128f63a1)
            check_type(argname="argument snapshot_id", value=snapshot_id, expected_type=type_hints["snapshot_id"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Ec2", jsii.invoke(self, "onSnapshot", [snapshot_id, region, partition]))

    @jsii.member(jsii_name="onSpotFleetRequest")
    def on_spot_fleet_request(
        self,
        spot_fleet_request_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Ec2":
        '''(experimental) Adds a resource of type spot-fleet-request to the statement.

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/iam-policy-structure.html#EC2_ARN_Format

        :param spot_fleet_request_id: - Identifier for the spotFleetRequestId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsRequestTag() - .ifAwsResourceTag() - .ifAwsTagKeys() - .ifAttribute() - .ifAttribute() - .ifRegion() - .ifResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b7d52f093f4d5219d007a81ea85afea701afb87c8f9553698684172942782de0)
            check_type(argname="argument spot_fleet_request_id", value=spot_fleet_request_id, expected_type=type_hints["spot_fleet_request_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Ec2", jsii.invoke(self, "onSpotFleetRequest", [spot_fleet_request_id, account, region, partition]))

    @jsii.member(jsii_name="onSpotInstancesRequest")
    def on_spot_instances_request(
        self,
        spot_instance_request_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Ec2":
        '''(experimental) Adds a resource of type spot-instances-request to the statement.

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/using-spot-instances.html

        :param spot_instance_request_id: - Identifier for the spotInstanceRequestId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsRequestTag() - .ifAwsResourceTag() - .ifAwsTagKeys() - .ifRegion() - .ifResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__565bc9e818a5fb8cd3fd989fb41f4f86b78b71bb7ebb6e86971e47ad76c8c5cd)
            check_type(argname="argument spot_instance_request_id", value=spot_instance_request_id, expected_type=type_hints["spot_instance_request_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Ec2", jsii.invoke(self, "onSpotInstancesRequest", [spot_instance_request_id, account, region, partition]))

    @jsii.member(jsii_name="onSubnet")
    def on_subnet(
        self,
        subnet_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Ec2":
        '''(experimental) Adds a resource of type subnet to the statement.

        https://docs.aws.amazon.com/vpc/latest/userguide/VPC_Subnets.html

        :param subnet_id: - Identifier for the subnetId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsRequestTag() - .ifAwsResourceTag() - .ifAwsTagKeys() - .ifAttribute() - .ifAttribute() - .ifAvailabilityZone() - .ifIsLaunchTemplateResource() - .ifLaunchTemplate() - .ifRegion() - .ifResourceTag() - .ifSubnetID() - .ifVpc()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__774aaaa6249ed323fbbb90783e15ccf274cae6d466751ff3e84dd4224292ed80)
            check_type(argname="argument subnet_id", value=subnet_id, expected_type=type_hints["subnet_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Ec2", jsii.invoke(self, "onSubnet", [subnet_id, account, region, partition]))

    @jsii.member(jsii_name="onSubnetCidrReservation")
    def on_subnet_cidr_reservation(
        self,
        subnet_cidr_reservation_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Ec2":
        '''(experimental) Adds a resource of type subnet-cidr-reservation to the statement.

        https://docs.aws.amazon.com/vpc/latest/userguide/subnet-cidr-reservation.html

        :param subnet_cidr_reservation_id: - Identifier for the subnetCidrReservationId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsRequestTag() - .ifAwsResourceTag() - .ifAwsTagKeys() - .ifRegion() - .ifResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7170ce99ba88094d622d4e1285ec0ecbc147d00728e0ec092cc930a3ce552e6f)
            check_type(argname="argument subnet_cidr_reservation_id", value=subnet_cidr_reservation_id, expected_type=type_hints["subnet_cidr_reservation_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Ec2", jsii.invoke(self, "onSubnetCidrReservation", [subnet_cidr_reservation_id, account, region, partition]))

    @jsii.member(jsii_name="onTrafficMirrorFilter")
    def on_traffic_mirror_filter(
        self,
        traffic_mirror_filter_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Ec2":
        '''(experimental) Adds a resource of type traffic-mirror-filter to the statement.

        https://docs.aws.amazon.com/vpc/latest/mirroring/traffic-mirroring-filter.html

        :param traffic_mirror_filter_id: - Identifier for the trafficMirrorFilterId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsRequestTag() - .ifAwsResourceTag() - .ifAwsTagKeys() - .ifAttribute() - .ifAttribute() - .ifRegion() - .ifResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__137c096ba3a00422a087ac9690bf8aa93bd9acf4bc4c66eb4c270b82cbb210ad)
            check_type(argname="argument traffic_mirror_filter_id", value=traffic_mirror_filter_id, expected_type=type_hints["traffic_mirror_filter_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Ec2", jsii.invoke(self, "onTrafficMirrorFilter", [traffic_mirror_filter_id, account, region, partition]))

    @jsii.member(jsii_name="onTrafficMirrorFilterRule")
    def on_traffic_mirror_filter_rule(
        self,
        traffic_mirror_filter_rule_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Ec2":
        '''(experimental) Adds a resource of type traffic-mirror-filter-rule to the statement.

        https://docs.aws.amazon.com/vpc/latest/mirroring/traffic-mirroring-filter.html

        :param traffic_mirror_filter_rule_id: - Identifier for the trafficMirrorFilterRuleId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAttribute() - .ifAttribute() - .ifRegion()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__90b4ee9fb5078b519fdca961d5f356d0840aa3acb9af81a879564f1039332864)
            check_type(argname="argument traffic_mirror_filter_rule_id", value=traffic_mirror_filter_rule_id, expected_type=type_hints["traffic_mirror_filter_rule_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Ec2", jsii.invoke(self, "onTrafficMirrorFilterRule", [traffic_mirror_filter_rule_id, account, region, partition]))

    @jsii.member(jsii_name="onTrafficMirrorSession")
    def on_traffic_mirror_session(
        self,
        traffic_mirror_session_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Ec2":
        '''(experimental) Adds a resource of type traffic-mirror-session to the statement.

        https://docs.aws.amazon.com/vpc/latest/mirroring/traffic-mirroring-session.html

        :param traffic_mirror_session_id: - Identifier for the trafficMirrorSessionId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsRequestTag() - .ifAwsResourceTag() - .ifAwsTagKeys() - .ifAttribute() - .ifAttribute() - .ifRegion() - .ifResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__556966a2a34d3225e7da938caca31b1c198da570e9c42459da187374b2dc9306)
            check_type(argname="argument traffic_mirror_session_id", value=traffic_mirror_session_id, expected_type=type_hints["traffic_mirror_session_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Ec2", jsii.invoke(self, "onTrafficMirrorSession", [traffic_mirror_session_id, account, region, partition]))

    @jsii.member(jsii_name="onTrafficMirrorTarget")
    def on_traffic_mirror_target(
        self,
        traffic_mirror_target_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Ec2":
        '''(experimental) Adds a resource of type traffic-mirror-target to the statement.

        https://docs.aws.amazon.com/vpc/latest/mirroring/traffic-mirroring-target.html

        :param traffic_mirror_target_id: - Identifier for the trafficMirrorTargetId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsRequestTag() - .ifAwsResourceTag() - .ifAwsTagKeys() - .ifRegion() - .ifResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3b986aa81ed3ed66e0cee53c9b8424ad2abf559f6156eb79e838a5bed3957702)
            check_type(argname="argument traffic_mirror_target_id", value=traffic_mirror_target_id, expected_type=type_hints["traffic_mirror_target_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Ec2", jsii.invoke(self, "onTrafficMirrorTarget", [traffic_mirror_target_id, account, region, partition]))

    @jsii.member(jsii_name="onTransitGateway")
    def on_transit_gateway(
        self,
        transit_gateway_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Ec2":
        '''(experimental) Adds a resource of type transit-gateway to the statement.

        https://docs.aws.amazon.com/vpc/latest/tgw/how-transit-gateways-work.html

        :param transit_gateway_id: - Identifier for the transitGatewayId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsRequestTag() - .ifAwsResourceTag() - .ifAwsTagKeys() - .ifAttribute() - .ifAttribute() - .ifRegion() - .ifResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__49a1e2dfb021917a22d853b3c16f51d907a53dcb331b909faa33a87760604948)
            check_type(argname="argument transit_gateway_id", value=transit_gateway_id, expected_type=type_hints["transit_gateway_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Ec2", jsii.invoke(self, "onTransitGateway", [transit_gateway_id, account, region, partition]))

    @jsii.member(jsii_name="onTransitGatewayAttachment")
    def on_transit_gateway_attachment(
        self,
        transit_gateway_attachment_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Ec2":
        '''(experimental) Adds a resource of type transit-gateway-attachment to the statement.

        https://docs.aws.amazon.com/vpc/latest/tgw/how-transit-gateways-work.html

        :param transit_gateway_attachment_id: - Identifier for the transitGatewayAttachmentId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsRequestTag() - .ifAwsResourceTag() - .ifAwsTagKeys() - .ifAttribute() - .ifAttribute() - .ifRegion() - .ifResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9dc2c3b44a22dc29b94a1a6e4b493522d07d5ea78e102e56492c656a9d9d9ed1)
            check_type(argname="argument transit_gateway_attachment_id", value=transit_gateway_attachment_id, expected_type=type_hints["transit_gateway_attachment_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Ec2", jsii.invoke(self, "onTransitGatewayAttachment", [transit_gateway_attachment_id, account, region, partition]))

    @jsii.member(jsii_name="onTransitGatewayConnectPeer")
    def on_transit_gateway_connect_peer(
        self,
        transit_gateway_connect_peer_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Ec2":
        '''(experimental) Adds a resource of type transit-gateway-connect-peer to the statement.

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/iam-policy-structure.html#EC2_ARN_Format

        :param transit_gateway_connect_peer_id: - Identifier for the transitGatewayConnectPeerId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsRequestTag() - .ifAwsResourceTag() - .ifAwsTagKeys() - .ifRegion() - .ifResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d7d588383c5bcba06545e9e0506bd05fd1f6dc26d88888b320060ba41f4dacad)
            check_type(argname="argument transit_gateway_connect_peer_id", value=transit_gateway_connect_peer_id, expected_type=type_hints["transit_gateway_connect_peer_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Ec2", jsii.invoke(self, "onTransitGatewayConnectPeer", [transit_gateway_connect_peer_id, account, region, partition]))

    @jsii.member(jsii_name="onTransitGatewayMulticastDomain")
    def on_transit_gateway_multicast_domain(
        self,
        transit_gateway_multicast_domain_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Ec2":
        '''(experimental) Adds a resource of type transit-gateway-multicast-domain to the statement.

        https://docs.aws.amazon.com/vpc/latest/tgw/tgw-multicast-overview.html

        :param transit_gateway_multicast_domain_id: - Identifier for the transitGatewayMulticastDomainId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsRequestTag() - .ifAwsResourceTag() - .ifAwsTagKeys() - .ifRegion() - .ifResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b6704f8dcea088c9c5505a85cf5a99a87c5b550684ed7806025dcbb5059f0688)
            check_type(argname="argument transit_gateway_multicast_domain_id", value=transit_gateway_multicast_domain_id, expected_type=type_hints["transit_gateway_multicast_domain_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Ec2", jsii.invoke(self, "onTransitGatewayMulticastDomain", [transit_gateway_multicast_domain_id, account, region, partition]))

    @jsii.member(jsii_name="onTransitGatewayPolicyTable")
    def on_transit_gateway_policy_table(
        self,
        transit_gateway_policy_table_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Ec2":
        '''(experimental) Adds a resource of type transit-gateway-policy-table to the statement.

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/iam-policy-structure.html#EC2_ARN_Format

        :param transit_gateway_policy_table_id: - Identifier for the transitGatewayPolicyTableId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsRequestTag() - .ifAwsResourceTag() - .ifAwsTagKeys() - .ifRegion() - .ifResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fbfe4aaa682610173a46e4335605b04c498ef741e78bd10ed5238b48a6b4641b)
            check_type(argname="argument transit_gateway_policy_table_id", value=transit_gateway_policy_table_id, expected_type=type_hints["transit_gateway_policy_table_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Ec2", jsii.invoke(self, "onTransitGatewayPolicyTable", [transit_gateway_policy_table_id, account, region, partition]))

    @jsii.member(jsii_name="onTransitGatewayRouteTable")
    def on_transit_gateway_route_table(
        self,
        transit_gateway_route_table_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Ec2":
        '''(experimental) Adds a resource of type transit-gateway-route-table to the statement.

        https://docs.aws.amazon.com/vpc/latest/tgw/how-transit-gateways-work.html

        :param transit_gateway_route_table_id: - Identifier for the transitGatewayRouteTableId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsRequestTag() - .ifAwsResourceTag() - .ifAwsTagKeys() - .ifAttribute() - .ifAttribute() - .ifRegion() - .ifResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bcac3f97e0d8c151cec899ffa84ce744426e047a5204966589a02d2c40e1736a)
            check_type(argname="argument transit_gateway_route_table_id", value=transit_gateway_route_table_id, expected_type=type_hints["transit_gateway_route_table_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Ec2", jsii.invoke(self, "onTransitGatewayRouteTable", [transit_gateway_route_table_id, account, region, partition]))

    @jsii.member(jsii_name="onTransitGatewayRouteTableAnnouncement")
    def on_transit_gateway_route_table_announcement(
        self,
        transit_gateway_route_table_announcement_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Ec2":
        '''(experimental) Adds a resource of type transit-gateway-route-table-announcement to the statement.

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/iam-policy-structure.html#EC2_ARN_Format

        :param transit_gateway_route_table_announcement_id: - Identifier for the transitGatewayRouteTableAnnouncementId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsRequestTag() - .ifAwsResourceTag() - .ifAwsTagKeys() - .ifRegion() - .ifResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8c29719f467d7be66d3d7a8731cd7ada92ad01d61f202eba62501f4be680f794)
            check_type(argname="argument transit_gateway_route_table_announcement_id", value=transit_gateway_route_table_announcement_id, expected_type=type_hints["transit_gateway_route_table_announcement_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Ec2", jsii.invoke(self, "onTransitGatewayRouteTableAnnouncement", [transit_gateway_route_table_announcement_id, account, region, partition]))

    @jsii.member(jsii_name="onVerifiedAccessEndpoint")
    def on_verified_access_endpoint(
        self,
        verified_access_endpoint_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Ec2":
        '''(experimental) Adds a resource of type verified-access-endpoint to the statement.

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/iam-policy-structure.html#EC2_ARN_Format

        :param verified_access_endpoint_id: - Identifier for the verifiedAccessEndpointId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsRequestTag() - .ifAwsResourceTag() - .ifAwsTagKeys() - .ifDomainCertificateArn() - .ifLoadBalancerArn() - .ifRegion() - .ifResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a63349803bbee55efe4acfd789f42092785bc2ef0a00c9cad1698700ae5017be)
            check_type(argname="argument verified_access_endpoint_id", value=verified_access_endpoint_id, expected_type=type_hints["verified_access_endpoint_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Ec2", jsii.invoke(self, "onVerifiedAccessEndpoint", [verified_access_endpoint_id, account, region, partition]))

    @jsii.member(jsii_name="onVerifiedAccessGroup")
    def on_verified_access_group(
        self,
        verified_access_group_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Ec2":
        '''(experimental) Adds a resource of type verified-access-group to the statement.

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/iam-policy-structure.html#EC2_ARN_Format

        :param verified_access_group_id: - Identifier for the verifiedAccessGroupId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsRequestTag() - .ifAwsResourceTag() - .ifAwsTagKeys() - .ifRegion() - .ifResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ab985e108a6105bb4b4ef33d13593ac193a6c2ed1dd51e5fdbe23da0d803a67c)
            check_type(argname="argument verified_access_group_id", value=verified_access_group_id, expected_type=type_hints["verified_access_group_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Ec2", jsii.invoke(self, "onVerifiedAccessGroup", [verified_access_group_id, account, region, partition]))

    @jsii.member(jsii_name="onVerifiedAccessInstance")
    def on_verified_access_instance(
        self,
        verified_access_instance_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Ec2":
        '''(experimental) Adds a resource of type verified-access-instance to the statement.

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/iam-policy-structure.html#EC2_ARN_Format

        :param verified_access_instance_id: - Identifier for the verifiedAccessInstanceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsRequestTag() - .ifAwsResourceTag() - .ifAwsTagKeys() - .ifRegion() - .ifResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__31f3461b70c40ed85fe087ac8d33742565337055f91adcce48f54d71c5334d4f)
            check_type(argname="argument verified_access_instance_id", value=verified_access_instance_id, expected_type=type_hints["verified_access_instance_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Ec2", jsii.invoke(self, "onVerifiedAccessInstance", [verified_access_instance_id, account, region, partition]))

    @jsii.member(jsii_name="onVerifiedAccessPolicy")
    def on_verified_access_policy(
        self,
        verified_access_policy_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Ec2":
        '''(experimental) Adds a resource of type verified-access-policy to the statement.

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/iam-policy-structure.html#EC2_ARN_Format

        :param verified_access_policy_id: - Identifier for the verifiedAccessPolicyId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsRequestTag() - .ifAwsResourceTag() - .ifAwsTagKeys() - .ifRegion() - .ifResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ba883fb23e433d9195557a1b9330df23af2dc17707374c0094cb870f507473ab)
            check_type(argname="argument verified_access_policy_id", value=verified_access_policy_id, expected_type=type_hints["verified_access_policy_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Ec2", jsii.invoke(self, "onVerifiedAccessPolicy", [verified_access_policy_id, account, region, partition]))

    @jsii.member(jsii_name="onVerifiedAccessTrustProvider")
    def on_verified_access_trust_provider(
        self,
        verified_access_trust_provider_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Ec2":
        '''(experimental) Adds a resource of type verified-access-trust-provider to the statement.

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/iam-policy-structure.html#EC2_ARN_Format

        :param verified_access_trust_provider_id: - Identifier for the verifiedAccessTrustProviderId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsRequestTag() - .ifAwsResourceTag() - .ifAwsTagKeys() - .ifRegion() - .ifResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1250788a1b44f73744b4ce9777426698bc61427df8f4df61e80b7ebc1ef7fb2d)
            check_type(argname="argument verified_access_trust_provider_id", value=verified_access_trust_provider_id, expected_type=type_hints["verified_access_trust_provider_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Ec2", jsii.invoke(self, "onVerifiedAccessTrustProvider", [verified_access_trust_provider_id, account, region, partition]))

    @jsii.member(jsii_name="onVolume")
    def on_volume(
        self,
        volume_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Ec2":
        '''(experimental) Adds a resource of type volume to the statement.

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ebs-volumes.html

        :param volume_id: - Identifier for the volumeId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsRequestTag() - .ifAwsResourceTag() - .ifAwsTagKeys() - .ifAttribute() - .ifAttribute() - .ifAvailabilityZone() - .ifEncrypted() - .ifIsLaunchTemplateResource() - .ifKmsKeyId() - .ifLaunchTemplate() - .ifParentSnapshot() - .ifRegion() - .ifResourceTag() - .ifVolumeID() - .ifVolumeIops() - .ifVolumeSize() - .ifVolumeThroughput() - .ifVolumeType()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e8ac5a869e885b41217b7ce236369205e759db96be229443a6b89801481dd6f1)
            check_type(argname="argument volume_id", value=volume_id, expected_type=type_hints["volume_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Ec2", jsii.invoke(self, "onVolume", [volume_id, account, region, partition]))

    @jsii.member(jsii_name="onVpc")
    def on_vpc(
        self,
        vpc_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Ec2":
        '''(experimental) Adds a resource of type vpc to the statement.

        https://docs.aws.amazon.com/vpc/latest/userguide/VPC_Subnets.html

        :param vpc_id: - Identifier for the vpcId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsRequestTag() - .ifAwsResourceTag() - .ifAwsTagKeys() - .ifAttribute() - .ifAttribute() - .ifIpv4IpamPoolId() - .ifIpv6IpamPoolId() - .ifRegion() - .ifResourceTag() - .ifTenancy() - .ifVpcID()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__25ba96f8bfb7ca0225571cec2ce7042cb1bb21b668a0b0378681ee73c54eff2d)
            check_type(argname="argument vpc_id", value=vpc_id, expected_type=type_hints["vpc_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Ec2", jsii.invoke(self, "onVpc", [vpc_id, account, region, partition]))

    @jsii.member(jsii_name="onVpcEndpoint")
    def on_vpc_endpoint(
        self,
        vpc_endpoint_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Ec2":
        '''(experimental) Adds a resource of type vpc-endpoint to the statement.

        https://docs.aws.amazon.com/vpc/latest/userguide/endpoint-services-overview.html

        :param vpc_endpoint_id: - Identifier for the vpcEndpointId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsRequestTag() - .ifAwsResourceTag() - .ifAwsTagKeys() - .ifAttribute() - .ifAttribute() - .ifRegion() - .ifResourceTag() - .ifVpceServiceName() - .ifVpceServiceOwner()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5f6c1b111e57e99c6e733a99921d1b693dec04fa3cb85de3dd8c323902fa8f13)
            check_type(argname="argument vpc_endpoint_id", value=vpc_endpoint_id, expected_type=type_hints["vpc_endpoint_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Ec2", jsii.invoke(self, "onVpcEndpoint", [vpc_endpoint_id, account, region, partition]))

    @jsii.member(jsii_name="onVpcEndpointConnection")
    def on_vpc_endpoint_connection(
        self,
        vpc_endpoint_connection_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Ec2":
        '''(experimental) Adds a resource of type vpc-endpoint-connection to the statement.

        https://docs.aws.amazon.com/vpc/latest/userguide/endpoint-services-overview.html

        :param vpc_endpoint_connection_id: - Identifier for the vpcEndpointConnectionId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsRequestTag() - .ifAwsResourceTag() - .ifAwsTagKeys() - .ifRegion() - .ifResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bdd4580372f0fc40ac2b7c4db1dba171ae78d80dec90b7671a572d5204b3e64d)
            check_type(argname="argument vpc_endpoint_connection_id", value=vpc_endpoint_connection_id, expected_type=type_hints["vpc_endpoint_connection_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Ec2", jsii.invoke(self, "onVpcEndpointConnection", [vpc_endpoint_connection_id, account, region, partition]))

    @jsii.member(jsii_name="onVpcEndpointService")
    def on_vpc_endpoint_service(
        self,
        vpc_endpoint_service_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Ec2":
        '''(experimental) Adds a resource of type vpc-endpoint-service to the statement.

        https://docs.aws.amazon.com/vpc/latest/userguide/endpoint-services-overview.html

        :param vpc_endpoint_service_id: - Identifier for the vpcEndpointServiceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsRequestTag() - .ifAwsResourceTag() - .ifAwsTagKeys() - .ifAttribute() - .ifAttribute() - .ifRegion() - .ifResourceTag() - .ifVpceServicePrivateDnsName()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ee39392e59f04822de81372422e3b50c74699cad17581cd739c15cbeac325aa4)
            check_type(argname="argument vpc_endpoint_service_id", value=vpc_endpoint_service_id, expected_type=type_hints["vpc_endpoint_service_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Ec2", jsii.invoke(self, "onVpcEndpointService", [vpc_endpoint_service_id, account, region, partition]))

    @jsii.member(jsii_name="onVpcEndpointServicePermission")
    def on_vpc_endpoint_service_permission(
        self,
        vpc_endpoint_service_permission_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Ec2":
        '''(experimental) Adds a resource of type vpc-endpoint-service-permission to the statement.

        https://docs.aws.amazon.com/vpc/latest/privatelink/vpc-endpoints-access.html#vpc-endpoint-policies

        :param vpc_endpoint_service_permission_id: - Identifier for the vpcEndpointServicePermissionId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsRequestTag() - .ifAwsResourceTag() - .ifAwsTagKeys() - .ifRegion() - .ifResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__72c824a33efc91a7e1bd7ec237acfdd6987ed136ba30752677f0c30696e97bd2)
            check_type(argname="argument vpc_endpoint_service_permission_id", value=vpc_endpoint_service_permission_id, expected_type=type_hints["vpc_endpoint_service_permission_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Ec2", jsii.invoke(self, "onVpcEndpointServicePermission", [vpc_endpoint_service_permission_id, account, region, partition]))

    @jsii.member(jsii_name="onVpcFlowLog")
    def on_vpc_flow_log(
        self,
        vpc_flow_log_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Ec2":
        '''(experimental) Adds a resource of type vpc-flow-log to the statement.

        https://docs.aws.amazon.com/vpc/latest/userguide/flow-logs.html

        :param vpc_flow_log_id: - Identifier for the vpcFlowLogId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsRequestTag() - .ifAwsResourceTag() - .ifAwsTagKeys() - .ifRegion() - .ifResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5a7e8a45fa0132721ae99ff4c5e87c38f3131533e94b2ea49b3f077d49af2e96)
            check_type(argname="argument vpc_flow_log_id", value=vpc_flow_log_id, expected_type=type_hints["vpc_flow_log_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Ec2", jsii.invoke(self, "onVpcFlowLog", [vpc_flow_log_id, account, region, partition]))

    @jsii.member(jsii_name="onVpcPeeringConnection")
    def on_vpc_peering_connection(
        self,
        vpc_peering_connection_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Ec2":
        '''(experimental) Adds a resource of type vpc-peering-connection to the statement.

        https://docs.aws.amazon.com/vpc/latest/peering/what-is-vpc-peering.html

        :param vpc_peering_connection_id: - Identifier for the vpcPeeringConnectionId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsRequestTag() - .ifAwsResourceTag() - .ifAwsTagKeys() - .ifAccepterVpc() - .ifAttribute() - .ifAttribute() - .ifRegion() - .ifRequesterVpc() - .ifResourceTag() - .ifVpcPeeringConnectionID()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__06365d1214510039b34c4e9d18fb8cc3696f2182adf0f8e57d4f5d06c8d37387)
            check_type(argname="argument vpc_peering_connection_id", value=vpc_peering_connection_id, expected_type=type_hints["vpc_peering_connection_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Ec2", jsii.invoke(self, "onVpcPeeringConnection", [vpc_peering_connection_id, account, region, partition]))

    @jsii.member(jsii_name="onVpnConnection")
    def on_vpn_connection(
        self,
        vpn_connection_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Ec2":
        '''(experimental) Adds a resource of type vpn-connection to the statement.

        https://docs.aws.amazon.com/vpn/latest/s2svpn/VPC_VPN.html

        :param vpn_connection_id: - Identifier for the vpnConnectionId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsRequestTag() - .ifAwsResourceTag() - .ifAwsTagKeys() - .ifAttribute() - .ifAttribute() - .ifAuthenticationType() - .ifDPDTimeoutSeconds() - .ifGatewayType() - .ifIKEVersions() - .ifInsideTunnelCidr() - .ifInsideTunnelIpv6Cidr() - .ifPhase1DHGroup() - .ifPhase1EncryptionAlgorithms() - .ifPhase1IntegrityAlgorithms() - .ifPhase1LifetimeSeconds() - .ifPhase2DHGroup() - .ifPhase2EncryptionAlgorithms() - .ifPhase2IntegrityAlgorithms() - .ifPhase2LifetimeSeconds() - .ifPreSharedKeys() - .ifRegion() - .ifRekeyFuzzPercentage() - .ifRekeyMarginTimeSeconds() - .ifReplayWindowSizePackets() - .ifResourceTag() - .ifRoutingType()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1d929f4199cf5061cf65199bf9b9c030168a557a68d441c5a89079b654ac0ca7)
            check_type(argname="argument vpn_connection_id", value=vpn_connection_id, expected_type=type_hints["vpn_connection_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Ec2", jsii.invoke(self, "onVpnConnection", [vpn_connection_id, account, region, partition]))

    @jsii.member(jsii_name="onVpnConnectionDeviceType")
    def on_vpn_connection_device_type(
        self,
        vpn_connection_device_type_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Ec2":
        '''(experimental) Adds a resource of type vpn-connection-device-type to the statement.

        https://docs.aws.amazon.com/vpn/latest/s2svpn/VPC_VPN.html

        :param vpn_connection_device_type_id: - Identifier for the vpnConnectionDeviceTypeId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifRegion()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8b1d23d14cee5fed3990249de75eeee97bee3178129f3ea7eca048edb2c8176f)
            check_type(argname="argument vpn_connection_device_type_id", value=vpn_connection_device_type_id, expected_type=type_hints["vpn_connection_device_type_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Ec2", jsii.invoke(self, "onVpnConnectionDeviceType", [vpn_connection_device_type_id, account, region, partition]))

    @jsii.member(jsii_name="onVpnGateway")
    def on_vpn_gateway(
        self,
        vpn_gateway_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Ec2":
        '''(experimental) Adds a resource of type vpn-gateway to the statement.

        https://docs.aws.amazon.com/vpn/latest/s2svpn/VPC_VPN.html

        :param vpn_gateway_id: - Identifier for the vpnGatewayId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsRequestTag() - .ifAwsResourceTag() - .ifAwsTagKeys() - .ifRegion() - .ifResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__92c64d2bca9a7375052cc86af1c736625648f889867ec44ef81f786d4bedf995)
            check_type(argname="argument vpn_gateway_id", value=vpn_gateway_id, expected_type=type_hints["vpn_gateway_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Ec2", jsii.invoke(self, "onVpnGateway", [vpn_gateway_id, account, region, partition]))

    @jsii.member(jsii_name="toAcceptAddressTransfer")
    def to_accept_address_transfer(self) -> "Ec2":
        '''(experimental) Grants permission to accept an Elastic IP address transfer.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifRegion()

        Dependent actions:

        - ec2:CreateTags

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_AcceptAddressTransfer.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toAcceptAddressTransfer", []))

    @jsii.member(jsii_name="toAcceptReservedInstancesExchangeQuote")
    def to_accept_reserved_instances_exchange_quote(self) -> "Ec2":
        '''(experimental) Grants permission to accept a Convertible Reserved Instance exchange quote.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_AcceptReservedInstancesExchangeQuote.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toAcceptReservedInstancesExchangeQuote", []))

    @jsii.member(jsii_name="toAcceptTransitGatewayMulticastDomainAssociations")
    def to_accept_transit_gateway_multicast_domain_associations(self) -> "Ec2":
        '''(experimental) Grants permission to accept a request to associate subnets with a transit gateway multicast domain.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_AcceptTransitGatewayMulticastDomainAssociations.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toAcceptTransitGatewayMulticastDomainAssociations", []))

    @jsii.member(jsii_name="toAcceptTransitGatewayPeeringAttachment")
    def to_accept_transit_gateway_peering_attachment(self) -> "Ec2":
        '''(experimental) Grants permission to accept a transit gateway peering attachment request.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_AcceptTransitGatewayPeeringAttachment.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toAcceptTransitGatewayPeeringAttachment", []))

    @jsii.member(jsii_name="toAcceptTransitGatewayVpcAttachment")
    def to_accept_transit_gateway_vpc_attachment(self) -> "Ec2":
        '''(experimental) Grants permission to accept a request to attach a VPC to a transit gateway.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_AcceptTransitGatewayVpcAttachment.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toAcceptTransitGatewayVpcAttachment", []))

    @jsii.member(jsii_name="toAcceptVpcEndpointConnections")
    def to_accept_vpc_endpoint_connections(self) -> "Ec2":
        '''(experimental) Grants permission to accept one or more interface VPC endpoint connections to your VPC endpoint service.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_AcceptVpcEndpointConnections.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toAcceptVpcEndpointConnections", []))

    @jsii.member(jsii_name="toAcceptVpcPeeringConnection")
    def to_accept_vpc_peering_connection(self) -> "Ec2":
        '''(experimental) Grants permission to accept a VPC peering connection request.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_AcceptVpcPeeringConnection.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toAcceptVpcPeeringConnection", []))

    @jsii.member(jsii_name="toAdvertiseByoipCidr")
    def to_advertise_byoip_cidr(self) -> "Ec2":
        '''(experimental) Grants permission to advertise an IP address range that is provisioned for use in AWS through bring your own IP addresses (BYOIP).

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_AdvertiseByoipCidr.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toAdvertiseByoipCidr", []))

    @jsii.member(jsii_name="toAllocateAddress")
    def to_allocate_address(self) -> "Ec2":
        '''(experimental) Grants permission to allocate an Elastic IP address (EIP) to your account.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifRegion()

        Dependent actions:

        - ec2:CreateTags

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_AllocateAddress.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toAllocateAddress", []))

    @jsii.member(jsii_name="toAllocateHosts")
    def to_allocate_hosts(self) -> "Ec2":
        '''(experimental) Grants permission to allocate a Dedicated Host to your account.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifRegion()

        Dependent actions:

        - ec2:CreateTags

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_AllocateHosts.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toAllocateHosts", []))

    @jsii.member(jsii_name="toAllocateIpamPoolCidr")
    def to_allocate_ipam_pool_cidr(self) -> "Ec2":
        '''(experimental) Grants permission to allocate a CIDR from an Amazon VPC IP Address Manager (IPAM) pool.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_AllocateIpamPoolCidr.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toAllocateIpamPoolCidr", []))

    @jsii.member(jsii_name="toApplySecurityGroupsToClientVpnTargetNetwork")
    def to_apply_security_groups_to_client_vpn_target_network(self) -> "Ec2":
        '''(experimental) Grants permission to apply a security group to the association between a Client VPN endpoint and a target network.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ApplySecurityGroupsToClientVpnTargetNetwork.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toApplySecurityGroupsToClientVpnTargetNetwork", []))

    @jsii.member(jsii_name="toAssignIpv6Addresses")
    def to_assign_ipv6_addresses(self) -> "Ec2":
        '''(experimental) Grants permission to assign one or more IPv6 addresses to a network interface.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_AssignIpv6Addresses.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toAssignIpv6Addresses", []))

    @jsii.member(jsii_name="toAssignPrivateIpAddresses")
    def to_assign_private_ip_addresses(self) -> "Ec2":
        '''(experimental) Grants permission to assign one or more secondary private IP addresses to a network interface.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_AssignPrivateIpAddresses.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toAssignPrivateIpAddresses", []))

    @jsii.member(jsii_name="toAssociateAddress")
    def to_associate_address(self) -> "Ec2":
        '''(experimental) Grants permission to associate an Elastic IP address (EIP) with an instance or a network interface.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_AssociateAddress.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toAssociateAddress", []))

    @jsii.member(jsii_name="toAssociateClientVpnTargetNetwork")
    def to_associate_client_vpn_target_network(self) -> "Ec2":
        '''(experimental) Grants permission to associate a target network with a Client VPN endpoint.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_AssociateClientVpnTargetNetwork.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toAssociateClientVpnTargetNetwork", []))

    @jsii.member(jsii_name="toAssociateDhcpOptions")
    def to_associate_dhcp_options(self) -> "Ec2":
        '''(experimental) Grants permission to associate or disassociate a set of DHCP options with a VPC.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_AssociateDhcpOptions.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toAssociateDhcpOptions", []))

    @jsii.member(jsii_name="toAssociateEnclaveCertificateIamRole")
    def to_associate_enclave_certificate_iam_role(self) -> "Ec2":
        '''(experimental) Grants permission to associate an ACM certificate with an IAM role to be used in an EC2 Enclave.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_AssociateEnclaveCertificateIamRole.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toAssociateEnclaveCertificateIamRole", []))

    @jsii.member(jsii_name="toAssociateIamInstanceProfile")
    def to_associate_iam_instance_profile(self) -> "Ec2":
        '''(experimental) Grants permission to associate an IAM instance profile with a running or stopped instance.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        Dependent actions:

        - iam:PassRole

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_AssociateIamInstanceProfile.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toAssociateIamInstanceProfile", []))

    @jsii.member(jsii_name="toAssociateInstanceEventWindow")
    def to_associate_instance_event_window(self) -> "Ec2":
        '''(experimental) Grants permission to associate one or more targets with an event window.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_AssociateInstanceEventWindow.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toAssociateInstanceEventWindow", []))

    @jsii.member(jsii_name="toAssociateRouteTable")
    def to_associate_route_table(self) -> "Ec2":
        '''(experimental) Grants permission to associate a subnet or gateway with a route table.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_AssociateRouteTable.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toAssociateRouteTable", []))

    @jsii.member(jsii_name="toAssociateSubnetCidrBlock")
    def to_associate_subnet_cidr_block(self) -> "Ec2":
        '''(experimental) Grants permission to associate a CIDR block with a subnet.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_AssociateSubnetCidrBlock.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toAssociateSubnetCidrBlock", []))

    @jsii.member(jsii_name="toAssociateTransitGatewayMulticastDomain")
    def to_associate_transit_gateway_multicast_domain(self) -> "Ec2":
        '''(experimental) Grants permission to associate an attachment and list of subnets with a transit gateway multicast domain.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_AssociateTransitGatewayMulticastDomain.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toAssociateTransitGatewayMulticastDomain", []))

    @jsii.member(jsii_name="toAssociateTransitGatewayPolicyTable")
    def to_associate_transit_gateway_policy_table(self) -> "Ec2":
        '''(experimental) Grants permission to associate a policy table with a transit gateway attachment.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_AssociateTransitGatewayPolicyTable.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toAssociateTransitGatewayPolicyTable", []))

    @jsii.member(jsii_name="toAssociateTransitGatewayRouteTable")
    def to_associate_transit_gateway_route_table(self) -> "Ec2":
        '''(experimental) Grants permission to associate an attachment with a transit gateway route table.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_AssociateTransitGatewayRouteTable.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toAssociateTransitGatewayRouteTable", []))

    @jsii.member(jsii_name="toAssociateTrunkInterface")
    def to_associate_trunk_interface(self) -> "Ec2":
        '''(experimental) Grants permission to associate a branch network interface with a trunk network interface.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_AssociateTrunkInterface.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toAssociateTrunkInterface", []))

    @jsii.member(jsii_name="toAssociateVpcCidrBlock")
    def to_associate_vpc_cidr_block(self) -> "Ec2":
        '''(experimental) Grants permission to associate a CIDR block with a VPC.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_AssociateVpcCidrBlock.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toAssociateVpcCidrBlock", []))

    @jsii.member(jsii_name="toAttachClassicLinkVpc")
    def to_attach_classic_link_vpc(self) -> "Ec2":
        '''(experimental) Grants permission to link an EC2-Classic instance to a ClassicLink-enabled VPC through one or more of the VPC's security groups.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_AttachClassicLinkVpc.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toAttachClassicLinkVpc", []))

    @jsii.member(jsii_name="toAttachInternetGateway")
    def to_attach_internet_gateway(self) -> "Ec2":
        '''(experimental) Grants permission to attach an internet gateway to a VPC.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_AttachInternetGateway.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toAttachInternetGateway", []))

    @jsii.member(jsii_name="toAttachNetworkInterface")
    def to_attach_network_interface(self) -> "Ec2":
        '''(experimental) Grants permission to attach a network interface to an instance.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_AttachNetworkInterface.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toAttachNetworkInterface", []))

    @jsii.member(jsii_name="toAttachVerifiedAccessTrustProvider")
    def to_attach_verified_access_trust_provider(self) -> "Ec2":
        '''(experimental) Grants permission to attach a trust provider to a Verified Access instance.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_AttachVerifiedAccessTrustProvider.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toAttachVerifiedAccessTrustProvider", []))

    @jsii.member(jsii_name="toAttachVolume")
    def to_attach_volume(self) -> "Ec2":
        '''(experimental) Grants permission to attach an EBS volume to a running or stopped instance and expose it to the instance with the specified device name.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_AttachVolume.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toAttachVolume", []))

    @jsii.member(jsii_name="toAttachVpnGateway")
    def to_attach_vpn_gateway(self) -> "Ec2":
        '''(experimental) Grants permission to attach a virtual private gateway to a VPC.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_AttachVpnGateway.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toAttachVpnGateway", []))

    @jsii.member(jsii_name="toAuthorizeClientVpnIngress")
    def to_authorize_client_vpn_ingress(self) -> "Ec2":
        '''(experimental) Grants permission to add an inbound authorization rule to a Client VPN endpoint.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_AuthorizeClientVpnIngress.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toAuthorizeClientVpnIngress", []))

    @jsii.member(jsii_name="toAuthorizeSecurityGroupEgress")
    def to_authorize_security_group_egress(self) -> "Ec2":
        '''(experimental) Grants permission to add one or more outbound rules to a VPC security group.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifRegion()

        Dependent actions:

        - ec2:CreateTags

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_AuthorizeSecurityGroupEgress.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toAuthorizeSecurityGroupEgress", []))

    @jsii.member(jsii_name="toAuthorizeSecurityGroupIngress")
    def to_authorize_security_group_ingress(self) -> "Ec2":
        '''(experimental) Grants permission to add one or more inbound rules to a security group.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifRegion()

        Dependent actions:

        - ec2:CreateTags

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_AuthorizeSecurityGroupIngress.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toAuthorizeSecurityGroupIngress", []))

    @jsii.member(jsii_name="toBundleInstance")
    def to_bundle_instance(self) -> "Ec2":
        '''(experimental) Grants permission to bundle an instance store-backed Windows instance.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_BundleInstance.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toBundleInstance", []))

    @jsii.member(jsii_name="toCancelBundleTask")
    def to_cancel_bundle_task(self) -> "Ec2":
        '''(experimental) Grants permission to cancel a bundling operation.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CancelBundleTask.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toCancelBundleTask", []))

    @jsii.member(jsii_name="toCancelCapacityReservation")
    def to_cancel_capacity_reservation(self) -> "Ec2":
        '''(experimental) Grants permission to cancel a Capacity Reservation and release the reserved capacity.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CancelCapacityReservation.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toCancelCapacityReservation", []))

    @jsii.member(jsii_name="toCancelCapacityReservationFleets")
    def to_cancel_capacity_reservation_fleets(self) -> "Ec2":
        '''(experimental) Grants permission to cancel one or more Capacity Reservation Fleets.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CancelCapacityReservationFleets.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toCancelCapacityReservationFleets", []))

    @jsii.member(jsii_name="toCancelConversionTask")
    def to_cancel_conversion_task(self) -> "Ec2":
        '''(experimental) Grants permission to cancel an active conversion task.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CancelConversionTask.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toCancelConversionTask", []))

    @jsii.member(jsii_name="toCancelExportTask")
    def to_cancel_export_task(self) -> "Ec2":
        '''(experimental) Grants permission to cancel an active export task.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CancelExportTask.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toCancelExportTask", []))

    @jsii.member(jsii_name="toCancelImageLaunchPermission")
    def to_cancel_image_launch_permission(self) -> "Ec2":
        '''(experimental) Grants permission to remove your AWS account from the launch permissions for the specified AMI.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CancelImageLaunchPermission.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toCancelImageLaunchPermission", []))

    @jsii.member(jsii_name="toCancelImportTask")
    def to_cancel_import_task(self) -> "Ec2":
        '''(experimental) Grants permission to cancel an in-process import virtual machine or import snapshot task.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CancelImportTask.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toCancelImportTask", []))

    @jsii.member(jsii_name="toCancelReservedInstancesListing")
    def to_cancel_reserved_instances_listing(self) -> "Ec2":
        '''(experimental) Grants permission to cancel a Reserved Instance listing on the Reserved Instance Marketplace.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CancelReservedInstancesListing.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toCancelReservedInstancesListing", []))

    @jsii.member(jsii_name="toCancelSpotFleetRequests")
    def to_cancel_spot_fleet_requests(self) -> "Ec2":
        '''(experimental) Grants permission to cancel one or more Spot Fleet requests.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CancelSpotFleetRequests.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toCancelSpotFleetRequests", []))

    @jsii.member(jsii_name="toCancelSpotInstanceRequests")
    def to_cancel_spot_instance_requests(self) -> "Ec2":
        '''(experimental) Grants permission to cancel one or more Spot Instance requests.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CancelSpotInstanceRequests.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toCancelSpotInstanceRequests", []))

    @jsii.member(jsii_name="toConfirmProductInstance")
    def to_confirm_product_instance(self) -> "Ec2":
        '''(experimental) Grants permission to determine whether an owned product code is associated with an instance.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ConfirmProductInstance.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toConfirmProductInstance", []))

    @jsii.member(jsii_name="toCopyFpgaImage")
    def to_copy_fpga_image(self) -> "Ec2":
        '''(experimental) Grants permission to copy a source Amazon FPGA image (AFI) to the current Region.

        Resource-level permissions specified for this action apply to the new AFI only. They do not apply to the source AFI

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CopyFpgaImage.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toCopyFpgaImage", []))

    @jsii.member(jsii_name="toCopyImage")
    def to_copy_image(self) -> "Ec2":
        '''(experimental) Grants permission to copy an Amazon Machine Image (AMI) from a source Region to the current Region.

        Resource-level permissions specified for this action apply to the new AMI only. They do not apply to the source AMI

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CopyImage.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toCopyImage", []))

    @jsii.member(jsii_name="toCopySnapshot")
    def to_copy_snapshot(self) -> "Ec2":
        '''(experimental) Grants permission to copy a point-in-time snapshot of an EBS volume and store it in Amazon S3.

        Resource-level permissions specified for this action apply to the new snapshot only. They do not apply to the source snapshot

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifRegion()

        Dependent actions:

        - ec2:CreateTags

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CopySnapshot.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toCopySnapshot", []))

    @jsii.member(jsii_name="toCreateCapacityReservation")
    def to_create_capacity_reservation(self) -> "Ec2":
        '''(experimental) Grants permission to create a Capacity Reservation.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifRegion()

        Dependent actions:

        - ec2:CreateTags

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateCapacityReservation.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toCreateCapacityReservation", []))

    @jsii.member(jsii_name="toCreateCapacityReservationFleet")
    def to_create_capacity_reservation_fleet(self) -> "Ec2":
        '''(experimental) Grants permission to create a Capacity Reservation Fleet.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifRegion()

        Dependent actions:

        - ec2:CreateTags

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateCapacityReservationFleet.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toCreateCapacityReservationFleet", []))

    @jsii.member(jsii_name="toCreateCarrierGateway")
    def to_create_carrier_gateway(self) -> "Ec2":
        '''(experimental) Grants permission to create a carrier gateway and provides CSP connectivity to VPC customers.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifRegion()

        Dependent actions:

        - ec2:CreateTags

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateCarrierGateway.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toCreateCarrierGateway", []))

    @jsii.member(jsii_name="toCreateClientVpnEndpoint")
    def to_create_client_vpn_endpoint(self) -> "Ec2":
        '''(experimental) Grants permission to create a Client VPN endpoint.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifRegion()

        Dependent actions:

        - ec2:CreateTags

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateClientVpnEndpoint.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toCreateClientVpnEndpoint", []))

    @jsii.member(jsii_name="toCreateClientVpnRoute")
    def to_create_client_vpn_route(self) -> "Ec2":
        '''(experimental) Grants permission to add a network route to a Client VPN endpoint's route table.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateClientVpnRoute.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toCreateClientVpnRoute", []))

    @jsii.member(jsii_name="toCreateCoipCidr")
    def to_create_coip_cidr(self) -> "Ec2":
        '''(experimental) Grants permission to create a range of customer-owned IP (CoIP) addresses.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateCoipCidr.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toCreateCoipCidr", []))

    @jsii.member(jsii_name="toCreateCoipPool")
    def to_create_coip_pool(self) -> "Ec2":
        '''(experimental) Grants permission to create a pool of customer-owned IP (CoIP) addresses.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        Dependent actions:

        - ec2:CreateTags

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateCoipPool.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toCreateCoipPool", []))

    @jsii.member(jsii_name="toCreateCoipPoolPermission")
    def to_create_coip_pool_permission(self) -> "Ec2":
        '''(experimental) Grants permission to allow a service to access a customer-owned IP (CoIP) pool.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/outposts/latest/userguide/identity-access-management.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toCreateCoipPoolPermission", []))

    @jsii.member(jsii_name="toCreateCustomerGateway")
    def to_create_customer_gateway(self) -> "Ec2":
        '''(experimental) Grants permission to create a customer gateway, which provides information to AWS about your customer gateway device.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifRegion()

        Dependent actions:

        - ec2:CreateTags

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateCustomerGateway.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toCreateCustomerGateway", []))

    @jsii.member(jsii_name="toCreateDefaultSubnet")
    def to_create_default_subnet(self) -> "Ec2":
        '''(experimental) Grants permission to create a default subnet in a specified Availability Zone in a default VPC.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateDefaultSubnet.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toCreateDefaultSubnet", []))

    @jsii.member(jsii_name="toCreateDefaultVpc")
    def to_create_default_vpc(self) -> "Ec2":
        '''(experimental) Grants permission to create a default VPC with a default subnet in each Availability Zone.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateDefaultVpc.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toCreateDefaultVpc", []))

    @jsii.member(jsii_name="toCreateDhcpOptions")
    def to_create_dhcp_options(self) -> "Ec2":
        '''(experimental) Grants permission to create a set of DHCP options for a VPC.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifRegion()

        Dependent actions:

        - ec2:CreateTags

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateDhcpOptions.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toCreateDhcpOptions", []))

    @jsii.member(jsii_name="toCreateEgressOnlyInternetGateway")
    def to_create_egress_only_internet_gateway(self) -> "Ec2":
        '''(experimental) Grants permission to create an egress-only internet gateway for a VPC.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifRegion()

        Dependent actions:

        - ec2:CreateTags

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateEgressOnlyInternetGateway.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toCreateEgressOnlyInternetGateway", []))

    @jsii.member(jsii_name="toCreateFleet")
    def to_create_fleet(self) -> "Ec2":
        '''(experimental) Grants permission to launch an EC2 Fleet.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifRegion()

        Dependent actions:

        - ec2:CreateTags

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateFleet.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toCreateFleet", []))

    @jsii.member(jsii_name="toCreateFlowLogs")
    def to_create_flow_logs(self) -> "Ec2":
        '''(experimental) Grants permission to create one or more flow logs to capture IP traffic for a network interface.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifRegion()

        Dependent actions:

        - ec2:CreateTags
        - iam:PassRole

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateFlowLogs.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toCreateFlowLogs", []))

    @jsii.member(jsii_name="toCreateFpgaImage")
    def to_create_fpga_image(self) -> "Ec2":
        '''(experimental) Grants permission to create an Amazon FPGA Image (AFI) from a design checkpoint (DCP).

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifRegion()

        Dependent actions:

        - ec2:CreateTags

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateFpgaImage.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toCreateFpgaImage", []))

    @jsii.member(jsii_name="toCreateImage")
    def to_create_image(self) -> "Ec2":
        '''(experimental) Grants permission to create an Amazon EBS-backed AMI from a stopped or running Amazon EBS-backed instance.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifRegion()

        Dependent actions:

        - ec2:CreateTags

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateImage.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toCreateImage", []))

    @jsii.member(jsii_name="toCreateInstanceEventWindow")
    def to_create_instance_event_window(self) -> "Ec2":
        '''(experimental) Grants permission to create an event window in which scheduled events for the associated Amazon EC2 instances can run.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifRegion()

        Dependent actions:

        - ec2:CreateTags

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateInstanceEventWindow.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toCreateInstanceEventWindow", []))

    @jsii.member(jsii_name="toCreateInstanceExportTask")
    def to_create_instance_export_task(self) -> "Ec2":
        '''(experimental) Grants permission to export a running or stopped instance to an Amazon S3 bucket.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifRegion()

        Dependent actions:

        - ec2:CreateTags

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateInstanceExportTask.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toCreateInstanceExportTask", []))

    @jsii.member(jsii_name="toCreateInternetGateway")
    def to_create_internet_gateway(self) -> "Ec2":
        '''(experimental) Grants permission to create an internet gateway for a VPC.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifRegion()

        Dependent actions:

        - ec2:CreateTags

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateInternetGateway.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toCreateInternetGateway", []))

    @jsii.member(jsii_name="toCreateIpam")
    def to_create_ipam(self) -> "Ec2":
        '''(experimental) Grants permission to create an Amazon VPC IP Address Manager (IPAM).

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifRegion()

        Dependent actions:

        - ec2:CreateTags
        - iam:CreateServiceLinkedRole

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateIpam.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toCreateIpam", []))

    @jsii.member(jsii_name="toCreateIpamPool")
    def to_create_ipam_pool(self) -> "Ec2":
        '''(experimental) Grants permission to create an IP address pool for Amazon VPC IP Address Manager (IPAM), which is a collection of contiguous IP address CIDRs.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifRegion()

        Dependent actions:

        - ec2:CreateTags

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateIpamPool.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toCreateIpamPool", []))

    @jsii.member(jsii_name="toCreateIpamScope")
    def to_create_ipam_scope(self) -> "Ec2":
        '''(experimental) Grants permission to create an Amazon VPC IP Address Manager (IPAM) scope, which is the highest-level container within IPAM.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifRegion()

        Dependent actions:

        - ec2:CreateTags

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateIpamScope.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toCreateIpamScope", []))

    @jsii.member(jsii_name="toCreateKeyPair")
    def to_create_key_pair(self) -> "Ec2":
        '''(experimental) Grants permission to create a 2048-bit RSA key pair.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifRegion()

        Dependent actions:

        - ec2:CreateTags

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateKeyPair.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toCreateKeyPair", []))

    @jsii.member(jsii_name="toCreateLaunchTemplate")
    def to_create_launch_template(self) -> "Ec2":
        '''(experimental) Grants permission to create a launch template.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifRegion()

        Dependent actions:

        - ec2:CreateTags

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateLaunchTemplate.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toCreateLaunchTemplate", []))

    @jsii.member(jsii_name="toCreateLaunchTemplateVersion")
    def to_create_launch_template_version(self) -> "Ec2":
        '''(experimental) Grants permission to create a new version of a launch template.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateLaunchTemplateVersion.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toCreateLaunchTemplateVersion", []))

    @jsii.member(jsii_name="toCreateLocalGatewayRoute")
    def to_create_local_gateway_route(self) -> "Ec2":
        '''(experimental) Grants permission to create a static route for a local gateway route table.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateLocalGatewayRoute.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toCreateLocalGatewayRoute", []))

    @jsii.member(jsii_name="toCreateLocalGatewayRouteTable")
    def to_create_local_gateway_route_table(self) -> "Ec2":
        '''(experimental) Grants permission to create a local gateway route table.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifRegion()

        Dependent actions:

        - ec2:CreateTags

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toCreateLocalGatewayRouteTable", []))

    @jsii.member(jsii_name="toCreateLocalGatewayRouteTablePermission")
    def to_create_local_gateway_route_table_permission(self) -> "Ec2":
        '''(experimental) Grants permission to allow a service to access a local gateway route table.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/outposts/latest/userguide/identity-access-management.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toCreateLocalGatewayRouteTablePermission", []))

    @jsii.member(jsii_name="toCreateLocalGatewayRouteTableVirtualInterfaceGroupAssociation")
    def to_create_local_gateway_route_table_virtual_interface_group_association(
        self,
    ) -> "Ec2":
        '''(experimental) Grants permission to create a local gateway route table virtual interface group association.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifRegion()

        Dependent actions:

        - ec2:CreateTags

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateLocalGatewayRouteTableVirtualInterfaceGroupAssociation.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toCreateLocalGatewayRouteTableVirtualInterfaceGroupAssociation", []))

    @jsii.member(jsii_name="toCreateLocalGatewayRouteTableVpcAssociation")
    def to_create_local_gateway_route_table_vpc_association(self) -> "Ec2":
        '''(experimental) Grants permission to associate a VPC with a local gateway route table.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifRegion()

        Dependent actions:

        - ec2:CreateTags

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateLocalGatewayRouteTableVpcAssociation.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toCreateLocalGatewayRouteTableVpcAssociation", []))

    @jsii.member(jsii_name="toCreateManagedPrefixList")
    def to_create_managed_prefix_list(self) -> "Ec2":
        '''(experimental) Grants permission to create a managed prefix list.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifRegion()

        Dependent actions:

        - ec2:CreateTags

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateManagedPrefixList.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toCreateManagedPrefixList", []))

    @jsii.member(jsii_name="toCreateNatGateway")
    def to_create_nat_gateway(self) -> "Ec2":
        '''(experimental) Grants permission to create a NAT gateway in a subnet.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifRegion()

        Dependent actions:

        - ec2:CreateTags

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateNatGateway.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toCreateNatGateway", []))

    @jsii.member(jsii_name="toCreateNetworkAcl")
    def to_create_network_acl(self) -> "Ec2":
        '''(experimental) Grants permission to create a network ACL in a VPC.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifRegion()

        Dependent actions:

        - ec2:CreateTags

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateNetworkAcl.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toCreateNetworkAcl", []))

    @jsii.member(jsii_name="toCreateNetworkAclEntry")
    def to_create_network_acl_entry(self) -> "Ec2":
        '''(experimental) Grants permission to create a numbered entry (a rule) in a network ACL.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateNetworkAclEntry.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toCreateNetworkAclEntry", []))

    @jsii.member(jsii_name="toCreateNetworkInsightsAccessScope")
    def to_create_network_insights_access_scope(self) -> "Ec2":
        '''(experimental) Grants permission to create a Network Access Scope.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifRegion()

        Dependent actions:

        - ec2:CreateTags

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateNetworkInsightsAccessScope.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toCreateNetworkInsightsAccessScope", []))

    @jsii.member(jsii_name="toCreateNetworkInsightsPath")
    def to_create_network_insights_path(self) -> "Ec2":
        '''(experimental) Grants permission to create a path to analyze for reachability.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifRegion()

        Dependent actions:

        - ec2:CreateTags

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateNetworkInsightsPath.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toCreateNetworkInsightsPath", []))

    @jsii.member(jsii_name="toCreateNetworkInterface")
    def to_create_network_interface(self) -> "Ec2":
        '''(experimental) Grants permission to create a network interface in a subnet.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifRegion()

        Dependent actions:

        - ec2:CreateTags

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateNetworkInterface.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toCreateNetworkInterface", []))

    @jsii.member(jsii_name="toCreateNetworkInterfacePermission")
    def to_create_network_interface_permission(self) -> "Ec2":
        '''(experimental) Grants permission to create a permission for an AWS-authorized user to perform certain operations on a network interface.

        Access Level: Permissions management

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateNetworkInterfacePermission.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toCreateNetworkInterfacePermission", []))

    @jsii.member(jsii_name="toCreatePlacementGroup")
    def to_create_placement_group(self) -> "Ec2":
        '''(experimental) Grants permission to create a placement group.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifRegion()

        Dependent actions:

        - ec2:CreateTags

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreatePlacementGroup.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toCreatePlacementGroup", []))

    @jsii.member(jsii_name="toCreatePublicIpv4Pool")
    def to_create_public_ipv4_pool(self) -> "Ec2":
        '''(experimental) Grants permission to create a public IPv4 address pool for public IPv4 CIDRs that you own and bring to Amazon to manage with Amazon VPC IP Address Manager (IPAM).

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifRegion()

        Dependent actions:

        - ec2:CreateTags

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreatePublicIpv4Pool.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toCreatePublicIpv4Pool", []))

    @jsii.member(jsii_name="toCreateReplaceRootVolumeTask")
    def to_create_replace_root_volume_task(self) -> "Ec2":
        '''(experimental) Grants permission to create a root volume replacement task.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifRegion()

        Dependent actions:

        - ec2:CreateTags

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateReplaceRootVolumeTask.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toCreateReplaceRootVolumeTask", []))

    @jsii.member(jsii_name="toCreateReservedInstancesListing")
    def to_create_reserved_instances_listing(self) -> "Ec2":
        '''(experimental) Grants permission to create a listing for Standard Reserved Instances to be sold in the Reserved Instance Marketplace.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateReservedInstancesListing.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toCreateReservedInstancesListing", []))

    @jsii.member(jsii_name="toCreateRestoreImageTask")
    def to_create_restore_image_task(self) -> "Ec2":
        '''(experimental) Grants permission to start a task that restores an AMI from an S3 object previously created by using CreateStoreImageTask.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifRegion()

        Dependent actions:

        - ec2:CreateTags

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateRestoreImageTask.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toCreateRestoreImageTask", []))

    @jsii.member(jsii_name="toCreateRoute")
    def to_create_route(self) -> "Ec2":
        '''(experimental) Grants permission to create a route in a VPC route table.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateRoute.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toCreateRoute", []))

    @jsii.member(jsii_name="toCreateRouteTable")
    def to_create_route_table(self) -> "Ec2":
        '''(experimental) Grants permission to create a route table for a VPC.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifRegion()

        Dependent actions:

        - ec2:CreateTags

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateRouteTable.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toCreateRouteTable", []))

    @jsii.member(jsii_name="toCreateSecurityGroup")
    def to_create_security_group(self) -> "Ec2":
        '''(experimental) Grants permission to create a security group.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifRegion()

        Dependent actions:

        - ec2:CreateTags

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateSecurityGroup.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toCreateSecurityGroup", []))

    @jsii.member(jsii_name="toCreateSnapshot")
    def to_create_snapshot(self) -> "Ec2":
        '''(experimental) Grants permission to create a snapshot of an EBS volume and store it in Amazon S3.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifRegion()

        Dependent actions:

        - ec2:CreateTags

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateSnapshot.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toCreateSnapshot", []))

    @jsii.member(jsii_name="toCreateSnapshots")
    def to_create_snapshots(self) -> "Ec2":
        '''(experimental) Grants permission to create crash-consistent snapshots of multiple EBS volumes and store them in Amazon S3.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifRegion()

        Dependent actions:

        - ec2:CreateTags

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateSnapshots.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toCreateSnapshots", []))

    @jsii.member(jsii_name="toCreateSpotDatafeedSubscription")
    def to_create_spot_datafeed_subscription(self) -> "Ec2":
        '''(experimental) Grants permission to create a data feed for Spot Instances to view Spot Instance usage logs.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateSpotDatafeedSubscription.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toCreateSpotDatafeedSubscription", []))

    @jsii.member(jsii_name="toCreateStoreImageTask")
    def to_create_store_image_task(self) -> "Ec2":
        '''(experimental) Grants permission to store an AMI as a single object in an S3 bucket.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateStoreImageTask.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toCreateStoreImageTask", []))

    @jsii.member(jsii_name="toCreateSubnet")
    def to_create_subnet(self) -> "Ec2":
        '''(experimental) Grants permission to create a subnet in a VPC.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifRegion()

        Dependent actions:

        - ec2:CreateTags

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateSubnet.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toCreateSubnet", []))

    @jsii.member(jsii_name="toCreateSubnetCidrReservation")
    def to_create_subnet_cidr_reservation(self) -> "Ec2":
        '''(experimental) Grants permission to create a subnet CIDR reservation.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateSubnetCidrReservation.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toCreateSubnetCidrReservation", []))

    @jsii.member(jsii_name="toCreateTags")
    def to_create_tags(self) -> "Ec2":
        '''(experimental) Grants permission to add or overwrite one or more tags for Amazon EC2 resources.

        Access Level: Tagging

        Possible conditions:

        - .ifCreateAction()
        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateTags.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toCreateTags", []))

    @jsii.member(jsii_name="toCreateTrafficMirrorFilter")
    def to_create_traffic_mirror_filter(self) -> "Ec2":
        '''(experimental) Grants permission to create a traffic mirror filter.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifRegion()

        Dependent actions:

        - ec2:CreateTags

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateTrafficMirrorFilter.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toCreateTrafficMirrorFilter", []))

    @jsii.member(jsii_name="toCreateTrafficMirrorFilterRule")
    def to_create_traffic_mirror_filter_rule(self) -> "Ec2":
        '''(experimental) Grants permission to create a traffic mirror filter rule.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateTrafficMirrorFilterRule.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toCreateTrafficMirrorFilterRule", []))

    @jsii.member(jsii_name="toCreateTrafficMirrorSession")
    def to_create_traffic_mirror_session(self) -> "Ec2":
        '''(experimental) Grants permission to create a traffic mirror session.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifRegion()

        Dependent actions:

        - ec2:CreateTags

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateTrafficMirrorSession.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toCreateTrafficMirrorSession", []))

    @jsii.member(jsii_name="toCreateTrafficMirrorTarget")
    def to_create_traffic_mirror_target(self) -> "Ec2":
        '''(experimental) Grants permission to create a traffic mirror target.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifRegion()

        Dependent actions:

        - ec2:CreateTags

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateTrafficMirrorTarget.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toCreateTrafficMirrorTarget", []))

    @jsii.member(jsii_name="toCreateTransitGateway")
    def to_create_transit_gateway(self) -> "Ec2":
        '''(experimental) Grants permission to create a transit gateway.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifRegion()

        Dependent actions:

        - ec2:CreateTags

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateTransitGateway.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toCreateTransitGateway", []))

    @jsii.member(jsii_name="toCreateTransitGatewayConnect")
    def to_create_transit_gateway_connect(self) -> "Ec2":
        '''(experimental) Grants permission to create a Connect attachment from a specified transit gateway attachment.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifRegion()

        Dependent actions:

        - ec2:CreateTags

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateTransitGatewayConnect.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toCreateTransitGatewayConnect", []))

    @jsii.member(jsii_name="toCreateTransitGatewayConnectPeer")
    def to_create_transit_gateway_connect_peer(self) -> "Ec2":
        '''(experimental) Grants permission to create a Connect peer between a transit gateway and an appliance.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifRegion()

        Dependent actions:

        - ec2:CreateTags

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateTransitGatewayConnectPeer.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toCreateTransitGatewayConnectPeer", []))

    @jsii.member(jsii_name="toCreateTransitGatewayMulticastDomain")
    def to_create_transit_gateway_multicast_domain(self) -> "Ec2":
        '''(experimental) Grants permission to create a multicast domain for a transit gateway.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifRegion()

        Dependent actions:

        - ec2:CreateTags

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateTransitGatewayMulticastDomain.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toCreateTransitGatewayMulticastDomain", []))

    @jsii.member(jsii_name="toCreateTransitGatewayPeeringAttachment")
    def to_create_transit_gateway_peering_attachment(self) -> "Ec2":
        '''(experimental) Grants permission to request a transit gateway peering attachment between a requester and accepter transit gateway.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifRegion()

        Dependent actions:

        - ec2:CreateTags

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateTransitGatewayPeeringAttachment.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toCreateTransitGatewayPeeringAttachment", []))

    @jsii.member(jsii_name="toCreateTransitGatewayPolicyTable")
    def to_create_transit_gateway_policy_table(self) -> "Ec2":
        '''(experimental) Grants permission to create a transit gateway policy table.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifRegion()

        Dependent actions:

        - ec2:CreateTags

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateTransitGatewayPolicyTable.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toCreateTransitGatewayPolicyTable", []))

    @jsii.member(jsii_name="toCreateTransitGatewayPrefixListReference")
    def to_create_transit_gateway_prefix_list_reference(self) -> "Ec2":
        '''(experimental) Grants permission to create a transit gateway prefix list reference.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateTransitGatewayPrefixListReference.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toCreateTransitGatewayPrefixListReference", []))

    @jsii.member(jsii_name="toCreateTransitGatewayRoute")
    def to_create_transit_gateway_route(self) -> "Ec2":
        '''(experimental) Grants permission to create a static route for a transit gateway route table.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateTransitGatewayRoute.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toCreateTransitGatewayRoute", []))

    @jsii.member(jsii_name="toCreateTransitGatewayRouteTable")
    def to_create_transit_gateway_route_table(self) -> "Ec2":
        '''(experimental) Grants permission to create a route table for a transit gateway.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifRegion()

        Dependent actions:

        - ec2:CreateTags

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateTransitGatewayRouteTable.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toCreateTransitGatewayRouteTable", []))

    @jsii.member(jsii_name="toCreateTransitGatewayRouteTableAnnouncement")
    def to_create_transit_gateway_route_table_announcement(self) -> "Ec2":
        '''(experimental) Grants permission to create an announcement for a transit gateway route table.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifRegion()

        Dependent actions:

        - ec2:CreateTags

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateTransitGatewayRouteTableAnnouncement.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toCreateTransitGatewayRouteTableAnnouncement", []))

    @jsii.member(jsii_name="toCreateTransitGatewayVpcAttachment")
    def to_create_transit_gateway_vpc_attachment(self) -> "Ec2":
        '''(experimental) Grants permission to attach a VPC to a transit gateway.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifRegion()

        Dependent actions:

        - ec2:CreateTags

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateTransitGatewayVpcAttachment.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toCreateTransitGatewayVpcAttachment", []))

    @jsii.member(jsii_name="toCreateVerifiedAccessEndpoint")
    def to_create_verified_access_endpoint(self) -> "Ec2":
        '''(experimental) Grants permission to create a Verified Access endpoint.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifRegion()

        Dependent actions:

        - ec2:CreateTags

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateVerifiedAccessEndpoint.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toCreateVerifiedAccessEndpoint", []))

    @jsii.member(jsii_name="toCreateVerifiedAccessGroup")
    def to_create_verified_access_group(self) -> "Ec2":
        '''(experimental) Grants permission to create a Verified Access group.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifRegion()

        Dependent actions:

        - ec2:CreateTags

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateVerifiedAccessGroup.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toCreateVerifiedAccessGroup", []))

    @jsii.member(jsii_name="toCreateVerifiedAccessInstance")
    def to_create_verified_access_instance(self) -> "Ec2":
        '''(experimental) Grants permission to create a Verified Access instance.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifRegion()

        Dependent actions:

        - ec2:CreateTags

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateVerifiedAccessInstance.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toCreateVerifiedAccessInstance", []))

    @jsii.member(jsii_name="toCreateVerifiedAccessTrustProvider")
    def to_create_verified_access_trust_provider(self) -> "Ec2":
        '''(experimental) Grants permission to create a verified trust provider.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifRegion()

        Dependent actions:

        - ec2:CreateTags

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateVerifiedAccessTrustProvider.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toCreateVerifiedAccessTrustProvider", []))

    @jsii.member(jsii_name="toCreateVolume")
    def to_create_volume(self) -> "Ec2":
        '''(experimental) Grants permission to create an EBS volume.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifRegion()

        Dependent actions:

        - ec2:CreateTags

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateVolume.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toCreateVolume", []))

    @jsii.member(jsii_name="toCreateVpc")
    def to_create_vpc(self) -> "Ec2":
        '''(experimental) Grants permission to create a VPC with a specified CIDR block.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifRegion()

        Dependent actions:

        - ec2:CreateTags

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateVpc.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toCreateVpc", []))

    @jsii.member(jsii_name="toCreateVpcEndpoint")
    def to_create_vpc_endpoint(self) -> "Ec2":
        '''(experimental) Grants permission to create a VPC endpoint for an AWS service.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifRegion()

        Dependent actions:

        - ec2:CreateTags
        - route53:AssociateVPCWithHostedZone

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateVpcEndpoint.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toCreateVpcEndpoint", []))

    @jsii.member(jsii_name="toCreateVpcEndpointConnectionNotification")
    def to_create_vpc_endpoint_connection_notification(self) -> "Ec2":
        '''(experimental) Grants permission to create a connection notification for a VPC endpoint or VPC endpoint service.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateVpcEndpointConnectionNotification.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toCreateVpcEndpointConnectionNotification", []))

    @jsii.member(jsii_name="toCreateVpcEndpointServiceConfiguration")
    def to_create_vpc_endpoint_service_configuration(self) -> "Ec2":
        '''(experimental) Grants permission to create a VPC endpoint service configuration to which service consumers (AWS accounts, IAM users, and IAM roles) can connect.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifRegion()

        Dependent actions:

        - ec2:CreateTags

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateVpcEndpointServiceConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toCreateVpcEndpointServiceConfiguration", []))

    @jsii.member(jsii_name="toCreateVpcPeeringConnection")
    def to_create_vpc_peering_connection(self) -> "Ec2":
        '''(experimental) Grants permission to request a VPC peering connection between two VPCs.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifRegion()

        Dependent actions:

        - ec2:CreateTags

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateVpcPeeringConnection.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toCreateVpcPeeringConnection", []))

    @jsii.member(jsii_name="toCreateVpnConnection")
    def to_create_vpn_connection(self) -> "Ec2":
        '''(experimental) Grants permission to create a VPN connection between a virtual private gateway or transit gateway and a customer gateway.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifRegion()

        Dependent actions:

        - ec2:CreateTags

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateVpnConnection.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toCreateVpnConnection", []))

    @jsii.member(jsii_name="toCreateVpnConnectionRoute")
    def to_create_vpn_connection_route(self) -> "Ec2":
        '''(experimental) Grants permission to create a static route for a VPN connection between a virtual private gateway and a customer gateway.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateVpnConnectionRoute.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toCreateVpnConnectionRoute", []))

    @jsii.member(jsii_name="toCreateVpnGateway")
    def to_create_vpn_gateway(self) -> "Ec2":
        '''(experimental) Grants permission to create a virtual private gateway.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifRegion()

        Dependent actions:

        - ec2:CreateTags

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateVpnGateway.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toCreateVpnGateway", []))

    @jsii.member(jsii_name="toDeleteCarrierGateway")
    def to_delete_carrier_gateway(self) -> "Ec2":
        '''(experimental) Grants permission to delete a carrier gateway.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DeleteCarrierGateway.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDeleteCarrierGateway", []))

    @jsii.member(jsii_name="toDeleteClientVpnEndpoint")
    def to_delete_client_vpn_endpoint(self) -> "Ec2":
        '''(experimental) Grants permission to delete a Client VPN endpoint.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DeleteClientVpnEndpoint.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDeleteClientVpnEndpoint", []))

    @jsii.member(jsii_name="toDeleteClientVpnRoute")
    def to_delete_client_vpn_route(self) -> "Ec2":
        '''(experimental) Grants permission to delete a route from a Client VPN endpoint.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DeleteClientVpnRoute.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDeleteClientVpnRoute", []))

    @jsii.member(jsii_name="toDeleteCoipCidr")
    def to_delete_coip_cidr(self) -> "Ec2":
        '''(experimental) Grants permission to delete a range of customer-owned IP (CoIP) addresses.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDeleteCoipCidr", []))

    @jsii.member(jsii_name="toDeleteCoipPool")
    def to_delete_coip_pool(self) -> "Ec2":
        '''(experimental) Grants permission to delete a pool of customer-owned IP (CoIP) addresses.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDeleteCoipPool", []))

    @jsii.member(jsii_name="toDeleteCoipPoolPermission")
    def to_delete_coip_pool_permission(self) -> "Ec2":
        '''(experimental) Grants permission to deny a service from accessing a customer-owned IP (CoIP) pool.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/outposts/latest/userguide/identity-access-management.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDeleteCoipPoolPermission", []))

    @jsii.member(jsii_name="toDeleteCustomerGateway")
    def to_delete_customer_gateway(self) -> "Ec2":
        '''(experimental) Grants permission to delete a customer gateway.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DeleteCustomerGateway.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDeleteCustomerGateway", []))

    @jsii.member(jsii_name="toDeleteDhcpOptions")
    def to_delete_dhcp_options(self) -> "Ec2":
        '''(experimental) Grants permission to delete a set of DHCP options.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DeleteDhcpOptions.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDeleteDhcpOptions", []))

    @jsii.member(jsii_name="toDeleteEgressOnlyInternetGateway")
    def to_delete_egress_only_internet_gateway(self) -> "Ec2":
        '''(experimental) Grants permission to delete an egress-only internet gateway.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DeleteEgressOnlyInternetGateway.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDeleteEgressOnlyInternetGateway", []))

    @jsii.member(jsii_name="toDeleteFleets")
    def to_delete_fleets(self) -> "Ec2":
        '''(experimental) Grants permission to delete one or more EC2 Fleets.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DeleteFleets.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDeleteFleets", []))

    @jsii.member(jsii_name="toDeleteFlowLogs")
    def to_delete_flow_logs(self) -> "Ec2":
        '''(experimental) Grants permission to delete one or more flow logs.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DeleteFlowLogs.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDeleteFlowLogs", []))

    @jsii.member(jsii_name="toDeleteFpgaImage")
    def to_delete_fpga_image(self) -> "Ec2":
        '''(experimental) Grants permission to delete an Amazon FPGA Image (AFI).

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DeleteFpgaImage.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDeleteFpgaImage", []))

    @jsii.member(jsii_name="toDeleteInstanceEventWindow")
    def to_delete_instance_event_window(self) -> "Ec2":
        '''(experimental) Grants permission to delete the specified event window.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DeleteInstanceEventWindow.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDeleteInstanceEventWindow", []))

    @jsii.member(jsii_name="toDeleteInternetGateway")
    def to_delete_internet_gateway(self) -> "Ec2":
        '''(experimental) Grants permission to delete an internet gateway.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DeleteInternetGateway.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDeleteInternetGateway", []))

    @jsii.member(jsii_name="toDeleteIpam")
    def to_delete_ipam(self) -> "Ec2":
        '''(experimental) Grants permission to delete an Amazon VPC IP Address Manager (IPAM) and remove all monitored data associated with the IPAM including the historical data for CIDRs.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DeleteIpam.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDeleteIpam", []))

    @jsii.member(jsii_name="toDeleteIpamPool")
    def to_delete_ipam_pool(self) -> "Ec2":
        '''(experimental) Grants permission to delete an Amazon VPC IP Address Manager (IPAM) pool.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DeleteIpamPool.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDeleteIpamPool", []))

    @jsii.member(jsii_name="toDeleteIpamScope")
    def to_delete_ipam_scope(self) -> "Ec2":
        '''(experimental) Grants permission to delete the scope for an Amazon VPC IP Address Manager (IPAM).

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DeleteIpamScope.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDeleteIpamScope", []))

    @jsii.member(jsii_name="toDeleteKeyPair")
    def to_delete_key_pair(self) -> "Ec2":
        '''(experimental) Grants permission to delete a key pair by removing the public key from Amazon EC2.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DeleteKeyPair.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDeleteKeyPair", []))

    @jsii.member(jsii_name="toDeleteLaunchTemplate")
    def to_delete_launch_template(self) -> "Ec2":
        '''(experimental) Grants permission to delete a launch template and its associated versions.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DeleteLaunchTemplate.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDeleteLaunchTemplate", []))

    @jsii.member(jsii_name="toDeleteLaunchTemplateVersions")
    def to_delete_launch_template_versions(self) -> "Ec2":
        '''(experimental) Grants permission to delete one or more versions of a launch template.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DeleteLaunchTemplateVersions.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDeleteLaunchTemplateVersions", []))

    @jsii.member(jsii_name="toDeleteLocalGatewayRoute")
    def to_delete_local_gateway_route(self) -> "Ec2":
        '''(experimental) Grants permission to delete a route from a local gateway route table.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DeleteLocalGatewayRoute.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDeleteLocalGatewayRoute", []))

    @jsii.member(jsii_name="toDeleteLocalGatewayRouteTable")
    def to_delete_local_gateway_route_table(self) -> "Ec2":
        '''(experimental) Grants permission to delete a local gateway route table.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDeleteLocalGatewayRouteTable", []))

    @jsii.member(jsii_name="toDeleteLocalGatewayRouteTablePermission")
    def to_delete_local_gateway_route_table_permission(self) -> "Ec2":
        '''(experimental) Grants permission to deny a service from accessing a local gateway route table.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/outposts/latest/userguide/identity-access-management.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDeleteLocalGatewayRouteTablePermission", []))

    @jsii.member(jsii_name="toDeleteLocalGatewayRouteTableVirtualInterfaceGroupAssociation")
    def to_delete_local_gateway_route_table_virtual_interface_group_association(
        self,
    ) -> "Ec2":
        '''(experimental) Grants permission to delete a local gateway route table virtual interface group association.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DeleteLocalGatewayRouteTableVirtualInterfaceGroupAssociation.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDeleteLocalGatewayRouteTableVirtualInterfaceGroupAssociation", []))

    @jsii.member(jsii_name="toDeleteLocalGatewayRouteTableVpcAssociation")
    def to_delete_local_gateway_route_table_vpc_association(self) -> "Ec2":
        '''(experimental) Grants permission to delete an association between a VPC and local gateway route table.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DeleteLocalGatewayRouteTableVpcAssociation.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDeleteLocalGatewayRouteTableVpcAssociation", []))

    @jsii.member(jsii_name="toDeleteManagedPrefixList")
    def to_delete_managed_prefix_list(self) -> "Ec2":
        '''(experimental) Grants permission to delete a managed prefix list.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DeleteManagedPrefixList.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDeleteManagedPrefixList", []))

    @jsii.member(jsii_name="toDeleteNatGateway")
    def to_delete_nat_gateway(self) -> "Ec2":
        '''(experimental) Grants permission to delete a NAT gateway.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DeleteNatGateway.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDeleteNatGateway", []))

    @jsii.member(jsii_name="toDeleteNetworkAcl")
    def to_delete_network_acl(self) -> "Ec2":
        '''(experimental) Grants permission to delete a network ACL.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DeleteNetworkAcl.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDeleteNetworkAcl", []))

    @jsii.member(jsii_name="toDeleteNetworkAclEntry")
    def to_delete_network_acl_entry(self) -> "Ec2":
        '''(experimental) Grants permission to delete an inbound or outbound entry (rule) from a network ACL.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DeleteNetworkAclEntry.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDeleteNetworkAclEntry", []))

    @jsii.member(jsii_name="toDeleteNetworkInsightsAccessScope")
    def to_delete_network_insights_access_scope(self) -> "Ec2":
        '''(experimental) Grants permission to delete a Network Access Scope.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DeleteNetworkInsightsAccessScope.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDeleteNetworkInsightsAccessScope", []))

    @jsii.member(jsii_name="toDeleteNetworkInsightsAccessScopeAnalysis")
    def to_delete_network_insights_access_scope_analysis(self) -> "Ec2":
        '''(experimental) Grants permission to delete a Network Access Scope analysis.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DeleteNetworkInsightsAccessScopeAnalysis.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDeleteNetworkInsightsAccessScopeAnalysis", []))

    @jsii.member(jsii_name="toDeleteNetworkInsightsAnalysis")
    def to_delete_network_insights_analysis(self) -> "Ec2":
        '''(experimental) Grants permission to delete a network insights analysis.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DeleteNetworkInsightsAnalysis.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDeleteNetworkInsightsAnalysis", []))

    @jsii.member(jsii_name="toDeleteNetworkInsightsPath")
    def to_delete_network_insights_path(self) -> "Ec2":
        '''(experimental) Grants permission to delete a network insights path.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DeleteNetworkInsightsPath.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDeleteNetworkInsightsPath", []))

    @jsii.member(jsii_name="toDeleteNetworkInterface")
    def to_delete_network_interface(self) -> "Ec2":
        '''(experimental) Grants permission to delete a detached network interface.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DeleteNetworkInterface.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDeleteNetworkInterface", []))

    @jsii.member(jsii_name="toDeleteNetworkInterfacePermission")
    def to_delete_network_interface_permission(self) -> "Ec2":
        '''(experimental) Grants permission to delete a permission that is associated with a network interface.

        Access Level: Permissions management

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DeleteNetworkInterfacePermission.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDeleteNetworkInterfacePermission", []))

    @jsii.member(jsii_name="toDeletePlacementGroup")
    def to_delete_placement_group(self) -> "Ec2":
        '''(experimental) Grants permission to delete a placement group.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DeletePlacementGroup.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDeletePlacementGroup", []))

    @jsii.member(jsii_name="toDeletePublicIpv4Pool")
    def to_delete_public_ipv4_pool(self) -> "Ec2":
        '''(experimental) Grants permission to delete a public IPv4 address pool for public IPv4 CIDRs that you own and brought to Amazon to manage with Amazon VPC IP Address Manager (IPAM).

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DeletePublicIpv4Pool.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDeletePublicIpv4Pool", []))

    @jsii.member(jsii_name="toDeleteQueuedReservedInstances")
    def to_delete_queued_reserved_instances(self) -> "Ec2":
        '''(experimental) Grants permission to delete the queued purchases for the specified Reserved Instances.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DeleteQueuedReservedInstances.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDeleteQueuedReservedInstances", []))

    @jsii.member(jsii_name="toDeleteResourcePolicy")
    def to_delete_resource_policy(self) -> "Ec2":
        '''(experimental) Grants permission to remove an IAM policy that enables cross-account sharing from a resource.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/vpc/latest/ipam/share-pool-ipam.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDeleteResourcePolicy", []))

    @jsii.member(jsii_name="toDeleteRoute")
    def to_delete_route(self) -> "Ec2":
        '''(experimental) Grants permission to delete a route from a route table.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DeleteRoute.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDeleteRoute", []))

    @jsii.member(jsii_name="toDeleteRouteTable")
    def to_delete_route_table(self) -> "Ec2":
        '''(experimental) Grants permission to delete a route table.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DeleteRouteTable.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDeleteRouteTable", []))

    @jsii.member(jsii_name="toDeleteSecurityGroup")
    def to_delete_security_group(self) -> "Ec2":
        '''(experimental) Grants permission to delete a security group.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DeleteSecurityGroup.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDeleteSecurityGroup", []))

    @jsii.member(jsii_name="toDeleteSnapshot")
    def to_delete_snapshot(self) -> "Ec2":
        '''(experimental) Grants permission to delete a snapshot of an EBS volume.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DeleteSnapshot.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDeleteSnapshot", []))

    @jsii.member(jsii_name="toDeleteSpotDatafeedSubscription")
    def to_delete_spot_datafeed_subscription(self) -> "Ec2":
        '''(experimental) Grants permission to delete a data feed for Spot Instances.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DeleteSpotDatafeedSubscription.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDeleteSpotDatafeedSubscription", []))

    @jsii.member(jsii_name="toDeleteSubnet")
    def to_delete_subnet(self) -> "Ec2":
        '''(experimental) Grants permission to delete a subnet.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DeleteSubnet.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDeleteSubnet", []))

    @jsii.member(jsii_name="toDeleteSubnetCidrReservation")
    def to_delete_subnet_cidr_reservation(self) -> "Ec2":
        '''(experimental) Grants permission to delete a subnet CIDR reservation.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DeleteSubnetCidrReservation.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDeleteSubnetCidrReservation", []))

    @jsii.member(jsii_name="toDeleteTags")
    def to_delete_tags(self) -> "Ec2":
        '''(experimental) Grants permission to delete one or more tags from Amazon EC2 resources.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DeleteTags.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDeleteTags", []))

    @jsii.member(jsii_name="toDeleteTrafficMirrorFilter")
    def to_delete_traffic_mirror_filter(self) -> "Ec2":
        '''(experimental) Grants permission to delete a traffic mirror filter.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DeleteTrafficMirrorFilter.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDeleteTrafficMirrorFilter", []))

    @jsii.member(jsii_name="toDeleteTrafficMirrorFilterRule")
    def to_delete_traffic_mirror_filter_rule(self) -> "Ec2":
        '''(experimental) Grants permission to delete a traffic mirror filter rule.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DeleteTrafficMirrorFilterRule.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDeleteTrafficMirrorFilterRule", []))

    @jsii.member(jsii_name="toDeleteTrafficMirrorSession")
    def to_delete_traffic_mirror_session(self) -> "Ec2":
        '''(experimental) Grants permission to delete a traffic mirror session.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DeleteTrafficMirrorSession.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDeleteTrafficMirrorSession", []))

    @jsii.member(jsii_name="toDeleteTrafficMirrorTarget")
    def to_delete_traffic_mirror_target(self) -> "Ec2":
        '''(experimental) Grants permission to delete a traffic mirror target.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DeleteTrafficMirrorTarget.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDeleteTrafficMirrorTarget", []))

    @jsii.member(jsii_name="toDeleteTransitGateway")
    def to_delete_transit_gateway(self) -> "Ec2":
        '''(experimental) Grants permission to delete a transit gateway.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DeleteTransitGateway.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDeleteTransitGateway", []))

    @jsii.member(jsii_name="toDeleteTransitGatewayConnect")
    def to_delete_transit_gateway_connect(self) -> "Ec2":
        '''(experimental) Grants permission to delete a transit gateway connect attachment.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DeleteTransitGatewayConnect.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDeleteTransitGatewayConnect", []))

    @jsii.member(jsii_name="toDeleteTransitGatewayConnectPeer")
    def to_delete_transit_gateway_connect_peer(self) -> "Ec2":
        '''(experimental) Grants permission to delete a transit gateway connect peer.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DeleteTransitGatewayConnectPeer.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDeleteTransitGatewayConnectPeer", []))

    @jsii.member(jsii_name="toDeleteTransitGatewayMulticastDomain")
    def to_delete_transit_gateway_multicast_domain(self) -> "Ec2":
        '''(experimental) Grants permission to delete a transit gateway multicast domain.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DeleteTransitGatewayMulticastDomain.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDeleteTransitGatewayMulticastDomain", []))

    @jsii.member(jsii_name="toDeleteTransitGatewayPeeringAttachment")
    def to_delete_transit_gateway_peering_attachment(self) -> "Ec2":
        '''(experimental) Grants permission to delete a peering attachment from a transit gateway.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DeleteTransitGatewayPeeringAttachment.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDeleteTransitGatewayPeeringAttachment", []))

    @jsii.member(jsii_name="toDeleteTransitGatewayPolicyTable")
    def to_delete_transit_gateway_policy_table(self) -> "Ec2":
        '''(experimental) Grants permission to delete a transit gateway policy table.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DeleteTransitGatewayPolicyTable.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDeleteTransitGatewayPolicyTable", []))

    @jsii.member(jsii_name="toDeleteTransitGatewayPrefixListReference")
    def to_delete_transit_gateway_prefix_list_reference(self) -> "Ec2":
        '''(experimental) Grants permission to delete a transit gateway prefix list reference.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DeleteTransitGatewayPrefixListReference.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDeleteTransitGatewayPrefixListReference", []))

    @jsii.member(jsii_name="toDeleteTransitGatewayRoute")
    def to_delete_transit_gateway_route(self) -> "Ec2":
        '''(experimental) Grants permission to delete a route from a transit gateway route table.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DeleteTransitGatewayRoute.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDeleteTransitGatewayRoute", []))

    @jsii.member(jsii_name="toDeleteTransitGatewayRouteTable")
    def to_delete_transit_gateway_route_table(self) -> "Ec2":
        '''(experimental) Grants permission to delete a transit gateway route table.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DeleteTransitGatewayRouteTable.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDeleteTransitGatewayRouteTable", []))

    @jsii.member(jsii_name="toDeleteTransitGatewayRouteTableAnnouncement")
    def to_delete_transit_gateway_route_table_announcement(self) -> "Ec2":
        '''(experimental) Grants permission to delete a transit gateway route table announcement.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DeleteTransitGatewayRouteTableAnnouncement.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDeleteTransitGatewayRouteTableAnnouncement", []))

    @jsii.member(jsii_name="toDeleteTransitGatewayVpcAttachment")
    def to_delete_transit_gateway_vpc_attachment(self) -> "Ec2":
        '''(experimental) Grants permission to delete a VPC attachment from a transit gateway.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DeleteTransitGatewayVpcAttachment.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDeleteTransitGatewayVpcAttachment", []))

    @jsii.member(jsii_name="toDeleteVerifiedAccessEndpoint")
    def to_delete_verified_access_endpoint(self) -> "Ec2":
        '''(experimental) Grants permission to delete a Verified Access endpoint.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DeleteVerifiedAccessEndpoint.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDeleteVerifiedAccessEndpoint", []))

    @jsii.member(jsii_name="toDeleteVerifiedAccessGroup")
    def to_delete_verified_access_group(self) -> "Ec2":
        '''(experimental) Grants permission to delete a Verified Access group.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DeleteVerifiedAccessGroup.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDeleteVerifiedAccessGroup", []))

    @jsii.member(jsii_name="toDeleteVerifiedAccessInstance")
    def to_delete_verified_access_instance(self) -> "Ec2":
        '''(experimental) Grants permission to delete a Verified Access instance.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DeleteVerifiedAccessInstance.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDeleteVerifiedAccessInstance", []))

    @jsii.member(jsii_name="toDeleteVerifiedAccessTrustProvider")
    def to_delete_verified_access_trust_provider(self) -> "Ec2":
        '''(experimental) Grants permission to delete a verified trust provider.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DeleteVerifiedAccessTrustProvider.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDeleteVerifiedAccessTrustProvider", []))

    @jsii.member(jsii_name="toDeleteVolume")
    def to_delete_volume(self) -> "Ec2":
        '''(experimental) Grants permission to delete an EBS volume.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DeleteVolume.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDeleteVolume", []))

    @jsii.member(jsii_name="toDeleteVpc")
    def to_delete_vpc(self) -> "Ec2":
        '''(experimental) Grants permission to delete a VPC.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DeleteVpc.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDeleteVpc", []))

    @jsii.member(jsii_name="toDeleteVpcEndpointConnectionNotifications")
    def to_delete_vpc_endpoint_connection_notifications(self) -> "Ec2":
        '''(experimental) Grants permission to delete one or more VPC endpoint connection notifications.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DeleteVpcEndpointConnectionNotifications.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDeleteVpcEndpointConnectionNotifications", []))

    @jsii.member(jsii_name="toDeleteVpcEndpoints")
    def to_delete_vpc_endpoints(self) -> "Ec2":
        '''(experimental) Grants permission to delete one or more VPC endpoints.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DeleteVpcEndpoints.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDeleteVpcEndpoints", []))

    @jsii.member(jsii_name="toDeleteVpcEndpointServiceConfigurations")
    def to_delete_vpc_endpoint_service_configurations(self) -> "Ec2":
        '''(experimental) Grants permission to delete one or more VPC endpoint service configurations.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DeleteVpcEndpointServiceConfigurations.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDeleteVpcEndpointServiceConfigurations", []))

    @jsii.member(jsii_name="toDeleteVpcPeeringConnection")
    def to_delete_vpc_peering_connection(self) -> "Ec2":
        '''(experimental) Grants permission to delete a VPC peering connection.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DeleteVpcPeeringConnection.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDeleteVpcPeeringConnection", []))

    @jsii.member(jsii_name="toDeleteVpnConnection")
    def to_delete_vpn_connection(self) -> "Ec2":
        '''(experimental) Grants permission to delete a VPN connection.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DeleteVpnConnection.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDeleteVpnConnection", []))

    @jsii.member(jsii_name="toDeleteVpnConnectionRoute")
    def to_delete_vpn_connection_route(self) -> "Ec2":
        '''(experimental) Grants permission to delete a static route for a VPN connection between a virtual private gateway and a customer gateway.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DeleteVpnConnectionRoute.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDeleteVpnConnectionRoute", []))

    @jsii.member(jsii_name="toDeleteVpnGateway")
    def to_delete_vpn_gateway(self) -> "Ec2":
        '''(experimental) Grants permission to delete a virtual private gateway.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DeleteVpnGateway.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDeleteVpnGateway", []))

    @jsii.member(jsii_name="toDeprovisionByoipCidr")
    def to_deprovision_byoip_cidr(self) -> "Ec2":
        '''(experimental) Grants permission to release an IP address range that was provisioned through bring your own IP addresses (BYOIP), and to delete the corresponding address pool.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DeprovisionByoipCidr.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDeprovisionByoipCidr", []))

    @jsii.member(jsii_name="toDeprovisionIpamPoolCidr")
    def to_deprovision_ipam_pool_cidr(self) -> "Ec2":
        '''(experimental) Grants permission to deprovision a CIDR provisioned from an Amazon VPC IP Address Manager (IPAM) pool.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DeprovisionIpamPoolCidr.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDeprovisionIpamPoolCidr", []))

    @jsii.member(jsii_name="toDeprovisionPublicIpv4PoolCidr")
    def to_deprovision_public_ipv4_pool_cidr(self) -> "Ec2":
        '''(experimental) Grants permission to deprovision a CIDR from a public IPv4 pool.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DeprovisionPublicIpv4PoolCidr.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDeprovisionPublicIpv4PoolCidr", []))

    @jsii.member(jsii_name="toDeregisterImage")
    def to_deregister_image(self) -> "Ec2":
        '''(experimental) Grants permission to deregister an Amazon Machine Image (AMI).

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DeregisterImage.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDeregisterImage", []))

    @jsii.member(jsii_name="toDeregisterInstanceEventNotificationAttributes")
    def to_deregister_instance_event_notification_attributes(self) -> "Ec2":
        '''(experimental) Grants permission to remove tags from the set of tags to include in notifications about scheduled events for your instances.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DeregisterInstanceEventNotificationAttributes.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDeregisterInstanceEventNotificationAttributes", []))

    @jsii.member(jsii_name="toDeregisterTransitGatewayMulticastGroupMembers")
    def to_deregister_transit_gateway_multicast_group_members(self) -> "Ec2":
        '''(experimental) Grants permission to deregister one or more network interface members from a group IP address in a transit gateway multicast domain.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DeregisterTransitGatewayMulticastGroupMembers.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDeregisterTransitGatewayMulticastGroupMembers", []))

    @jsii.member(jsii_name="toDeregisterTransitGatewayMulticastGroupSources")
    def to_deregister_transit_gateway_multicast_group_sources(self) -> "Ec2":
        '''(experimental) Grants permission to deregister one or more network interface sources from a group IP address in a transit gateway multicast domain.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DeregisterTransitGatewayMulticastGroupSources.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDeregisterTransitGatewayMulticastGroupSources", []))

    @jsii.member(jsii_name="toDescribeAccountAttributes")
    def to_describe_account_attributes(self) -> "Ec2":
        '''(experimental) Grants permission to describe the attributes of the AWS account.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeAccountAttributes.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDescribeAccountAttributes", []))

    @jsii.member(jsii_name="toDescribeAddresses")
    def to_describe_addresses(self) -> "Ec2":
        '''(experimental) Grants permission to describe one or more Elastic IP addresses.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeAddresses.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDescribeAddresses", []))

    @jsii.member(jsii_name="toDescribeAddressesAttribute")
    def to_describe_addresses_attribute(self) -> "Ec2":
        '''(experimental) Grants permission to describe the attributes of the specified Elastic IP addresses.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeAddressesAttribute.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDescribeAddressesAttribute", []))

    @jsii.member(jsii_name="toDescribeAddressTransfers")
    def to_describe_address_transfers(self) -> "Ec2":
        '''(experimental) Grants permission to describe an Elastic IP address transfer.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeAddressTransfers.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDescribeAddressTransfers", []))

    @jsii.member(jsii_name="toDescribeAggregateIdFormat")
    def to_describe_aggregate_id_format(self) -> "Ec2":
        '''(experimental) Grants permission to describe the longer ID format settings for all resource types.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeAggregateIdFormat.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDescribeAggregateIdFormat", []))

    @jsii.member(jsii_name="toDescribeAvailabilityZones")
    def to_describe_availability_zones(self) -> "Ec2":
        '''(experimental) Grants permission to describe one or more of the Availability Zones that are available to you.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeAvailabilityZones.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDescribeAvailabilityZones", []))

    @jsii.member(jsii_name="toDescribeAwsNetworkPerformanceMetricSubscriptions")
    def to_describe_aws_network_performance_metric_subscriptions(self) -> "Ec2":
        '''(experimental) Grants permission to describe the current infrastructure performance metric subscriptions.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeAwsNetworkPerformanceMetricSubscriptions.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDescribeAwsNetworkPerformanceMetricSubscriptions", []))

    @jsii.member(jsii_name="toDescribeBundleTasks")
    def to_describe_bundle_tasks(self) -> "Ec2":
        '''(experimental) Grants permission to describe one or more bundling tasks.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeBundleTasks.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDescribeBundleTasks", []))

    @jsii.member(jsii_name="toDescribeByoipCidrs")
    def to_describe_byoip_cidrs(self) -> "Ec2":
        '''(experimental) Grants permission to describe the IP address ranges that were provisioned through bring your own IP addresses (BYOIP).

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeByoipCidrs.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDescribeByoipCidrs", []))

    @jsii.member(jsii_name="toDescribeCapacityReservationFleets")
    def to_describe_capacity_reservation_fleets(self) -> "Ec2":
        '''(experimental) Grants permission to describe one or more Capacity Reservation Fleets.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeCapacityReservationFleets.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDescribeCapacityReservationFleets", []))

    @jsii.member(jsii_name="toDescribeCapacityReservations")
    def to_describe_capacity_reservations(self) -> "Ec2":
        '''(experimental) Grants permission to describe one or more Capacity Reservations.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeCapacityReservations.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDescribeCapacityReservations", []))

    @jsii.member(jsii_name="toDescribeCarrierGateways")
    def to_describe_carrier_gateways(self) -> "Ec2":
        '''(experimental) Grants permission to describe one or more Carrier Gateways.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeCarrierGateways.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDescribeCarrierGateways", []))

    @jsii.member(jsii_name="toDescribeClassicLinkInstances")
    def to_describe_classic_link_instances(self) -> "Ec2":
        '''(experimental) Grants permission to describe one or more linked EC2-Classic instances.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeClassicLinkInstances.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDescribeClassicLinkInstances", []))

    @jsii.member(jsii_name="toDescribeClientVpnAuthorizationRules")
    def to_describe_client_vpn_authorization_rules(self) -> "Ec2":
        '''(experimental) Grants permission to describe the authorization rules for a Client VPN endpoint.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeClientVpnAuthorizationRules.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDescribeClientVpnAuthorizationRules", []))

    @jsii.member(jsii_name="toDescribeClientVpnConnections")
    def to_describe_client_vpn_connections(self) -> "Ec2":
        '''(experimental) Grants permission to describe active client connections and connections that have been terminated within the last 60 minutes for a Client VPN endpoint.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeClientVpnConnections.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDescribeClientVpnConnections", []))

    @jsii.member(jsii_name="toDescribeClientVpnEndpoints")
    def to_describe_client_vpn_endpoints(self) -> "Ec2":
        '''(experimental) Grants permission to describe one or more Client VPN endpoints.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeClientVpnEndpoints.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDescribeClientVpnEndpoints", []))

    @jsii.member(jsii_name="toDescribeClientVpnRoutes")
    def to_describe_client_vpn_routes(self) -> "Ec2":
        '''(experimental) Grants permission to describe the routes for a Client VPN endpoint.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeClientVpnRoutes.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDescribeClientVpnRoutes", []))

    @jsii.member(jsii_name="toDescribeClientVpnTargetNetworks")
    def to_describe_client_vpn_target_networks(self) -> "Ec2":
        '''(experimental) Grants permission to describe the target networks that are associated with a Client VPN endpoint.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeClientVpnTargetNetworks.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDescribeClientVpnTargetNetworks", []))

    @jsii.member(jsii_name="toDescribeCoipPools")
    def to_describe_coip_pools(self) -> "Ec2":
        '''(experimental) Grants permission to describe the specified customer-owned address pools or all of your customer-owned address pools.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeCoipPools.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDescribeCoipPools", []))

    @jsii.member(jsii_name="toDescribeConversionTasks")
    def to_describe_conversion_tasks(self) -> "Ec2":
        '''(experimental) Grants permission to describe one or more conversion tasks.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeConversionTasks.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDescribeConversionTasks", []))

    @jsii.member(jsii_name="toDescribeCustomerGateways")
    def to_describe_customer_gateways(self) -> "Ec2":
        '''(experimental) Grants permission to describe one or more customer gateways.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeCustomerGateways.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDescribeCustomerGateways", []))

    @jsii.member(jsii_name="toDescribeDhcpOptions")
    def to_describe_dhcp_options(self) -> "Ec2":
        '''(experimental) Grants permission to describe one or more DHCP options sets.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeDhcpOptions.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDescribeDhcpOptions", []))

    @jsii.member(jsii_name="toDescribeEgressOnlyInternetGateways")
    def to_describe_egress_only_internet_gateways(self) -> "Ec2":
        '''(experimental) Grants permission to describe one or more egress-only internet gateways.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeEgressOnlyInternetGateways.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDescribeEgressOnlyInternetGateways", []))

    @jsii.member(jsii_name="toDescribeElasticGpus")
    def to_describe_elastic_gpus(self) -> "Ec2":
        '''(experimental) Grants permission to describe an Elastic Graphics accelerator that is associated with an instance.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeElasticGpus.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDescribeElasticGpus", []))

    @jsii.member(jsii_name="toDescribeExportImageTasks")
    def to_describe_export_image_tasks(self) -> "Ec2":
        '''(experimental) Grants permission to describe one or more export image tasks.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeExportImageTasks.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDescribeExportImageTasks", []))

    @jsii.member(jsii_name="toDescribeExportTasks")
    def to_describe_export_tasks(self) -> "Ec2":
        '''(experimental) Grants permission to describe one or more export instance tasks.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeExportTasks.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDescribeExportTasks", []))

    @jsii.member(jsii_name="toDescribeFastLaunchImages")
    def to_describe_fast_launch_images(self) -> "Ec2":
        '''(experimental) Grants permission to describe fast-launch enabled Windows AMIs.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeFastLaunchImages.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDescribeFastLaunchImages", []))

    @jsii.member(jsii_name="toDescribeFastSnapshotRestores")
    def to_describe_fast_snapshot_restores(self) -> "Ec2":
        '''(experimental) Grants permission to describe the state of fast snapshot restores for snapshots.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeFastSnapshotRestores.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDescribeFastSnapshotRestores", []))

    @jsii.member(jsii_name="toDescribeFleetHistory")
    def to_describe_fleet_history(self) -> "Ec2":
        '''(experimental) Grants permission to describe the events for an EC2 Fleet during a specified time.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeFleetHistory.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDescribeFleetHistory", []))

    @jsii.member(jsii_name="toDescribeFleetInstances")
    def to_describe_fleet_instances(self) -> "Ec2":
        '''(experimental) Grants permission to describe the running instances for an EC2 Fleet.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeFleetInstances.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDescribeFleetInstances", []))

    @jsii.member(jsii_name="toDescribeFleets")
    def to_describe_fleets(self) -> "Ec2":
        '''(experimental) Grants permission to describe one or more EC2 Fleets.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeFleets.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDescribeFleets", []))

    @jsii.member(jsii_name="toDescribeFlowLogs")
    def to_describe_flow_logs(self) -> "Ec2":
        '''(experimental) Grants permission to describe one or more flow logs.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeFlowLogs.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDescribeFlowLogs", []))

    @jsii.member(jsii_name="toDescribeFpgaImageAttribute")
    def to_describe_fpga_image_attribute(self) -> "Ec2":
        '''(experimental) Grants permission to describe the attributes of an Amazon FPGA Image (AFI).

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeFpgaImageAttribute.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDescribeFpgaImageAttribute", []))

    @jsii.member(jsii_name="toDescribeFpgaImages")
    def to_describe_fpga_images(self) -> "Ec2":
        '''(experimental) Grants permission to describe one or more Amazon FPGA Images (AFIs).

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeFpgaImages.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDescribeFpgaImages", []))

    @jsii.member(jsii_name="toDescribeHostReservationOfferings")
    def to_describe_host_reservation_offerings(self) -> "Ec2":
        '''(experimental) Grants permission to describe the Dedicated Host Reservations that are available to purchase.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeHostReservationOfferings.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDescribeHostReservationOfferings", []))

    @jsii.member(jsii_name="toDescribeHostReservations")
    def to_describe_host_reservations(self) -> "Ec2":
        '''(experimental) Grants permission to describe the Dedicated Host Reservations that are associated with Dedicated Hosts in the AWS account.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeHostReservations.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDescribeHostReservations", []))

    @jsii.member(jsii_name="toDescribeHosts")
    def to_describe_hosts(self) -> "Ec2":
        '''(experimental) Grants permission to describe one or more Dedicated Hosts.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeHosts.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDescribeHosts", []))

    @jsii.member(jsii_name="toDescribeIamInstanceProfileAssociations")
    def to_describe_iam_instance_profile_associations(self) -> "Ec2":
        '''(experimental) Grants permission to describe the IAM instance profile associations.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeIamInstanceProfileAssociations.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDescribeIamInstanceProfileAssociations", []))

    @jsii.member(jsii_name="toDescribeIdentityIdFormat")
    def to_describe_identity_id_format(self) -> "Ec2":
        '''(experimental) Grants permission to describe the ID format settings for resources for an IAM user, IAM role, or root user.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeIdentityIdFormat.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDescribeIdentityIdFormat", []))

    @jsii.member(jsii_name="toDescribeIdFormat")
    def to_describe_id_format(self) -> "Ec2":
        '''(experimental) Grants permission to describe the ID format settings for resources.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeIdFormat.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDescribeIdFormat", []))

    @jsii.member(jsii_name="toDescribeImageAttribute")
    def to_describe_image_attribute(self) -> "Ec2":
        '''(experimental) Grants permission to describe an attribute of an Amazon Machine Image (AMI).

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeImageAttribute.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDescribeImageAttribute", []))

    @jsii.member(jsii_name="toDescribeImages")
    def to_describe_images(self) -> "Ec2":
        '''(experimental) Grants permission to describe one or more images (AMIs, AKIs, and ARIs).

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeImages.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDescribeImages", []))

    @jsii.member(jsii_name="toDescribeImportImageTasks")
    def to_describe_import_image_tasks(self) -> "Ec2":
        '''(experimental) Grants permission to describe import virtual machine or import snapshot tasks.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeImportImageTasks.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDescribeImportImageTasks", []))

    @jsii.member(jsii_name="toDescribeImportSnapshotTasks")
    def to_describe_import_snapshot_tasks(self) -> "Ec2":
        '''(experimental) Grants permission to describe import snapshot tasks.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeImportSnapshotTasks.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDescribeImportSnapshotTasks", []))

    @jsii.member(jsii_name="toDescribeInstanceAttribute")
    def to_describe_instance_attribute(self) -> "Ec2":
        '''(experimental) Grants permission to describe the attributes of an instance.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeInstanceAttribute.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDescribeInstanceAttribute", []))

    @jsii.member(jsii_name="toDescribeInstanceCreditSpecifications")
    def to_describe_instance_credit_specifications(self) -> "Ec2":
        '''(experimental) Grants permission to describe the credit option for CPU usage of one or more burstable performance instances.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeInstanceCreditSpecifications.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDescribeInstanceCreditSpecifications", []))

    @jsii.member(jsii_name="toDescribeInstanceEventNotificationAttributes")
    def to_describe_instance_event_notification_attributes(self) -> "Ec2":
        '''(experimental) Grants permission to describe the set of tags to include in notifications about scheduled events for your instances.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeInstanceEventNotificationAttributes.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDescribeInstanceEventNotificationAttributes", []))

    @jsii.member(jsii_name="toDescribeInstanceEventWindows")
    def to_describe_instance_event_windows(self) -> "Ec2":
        '''(experimental) Grants permission to describe the specified event windows or all event windows.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeInstanceEventWindows.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDescribeInstanceEventWindows", []))

    @jsii.member(jsii_name="toDescribeInstances")
    def to_describe_instances(self) -> "Ec2":
        '''(experimental) Grants permission to describe one or more instances.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeInstances.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDescribeInstances", []))

    @jsii.member(jsii_name="toDescribeInstanceStatus")
    def to_describe_instance_status(self) -> "Ec2":
        '''(experimental) Grants permission to describe the status of one or more instances.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeInstanceStatus.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDescribeInstanceStatus", []))

    @jsii.member(jsii_name="toDescribeInstanceTypeOfferings")
    def to_describe_instance_type_offerings(self) -> "Ec2":
        '''(experimental) Grants permission to describe the set of instance types that are offered in a location.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeInstanceTypeOfferings.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDescribeInstanceTypeOfferings", []))

    @jsii.member(jsii_name="toDescribeInstanceTypes")
    def to_describe_instance_types(self) -> "Ec2":
        '''(experimental) Grants permission to describe the details of instance types that are offered in a location.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeInstanceTypes.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDescribeInstanceTypes", []))

    @jsii.member(jsii_name="toDescribeInternetGateways")
    def to_describe_internet_gateways(self) -> "Ec2":
        '''(experimental) Grants permission to describe one or more internet gateways.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeInternetGateways.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDescribeInternetGateways", []))

    @jsii.member(jsii_name="toDescribeIpamPools")
    def to_describe_ipam_pools(self) -> "Ec2":
        '''(experimental) Grants permission to describe Amazon VPC IP Address Manager (IPAM) pools.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeIpamPools.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDescribeIpamPools", []))

    @jsii.member(jsii_name="toDescribeIpams")
    def to_describe_ipams(self) -> "Ec2":
        '''(experimental) Grants permission to describe an Amazon VPC IP Address Manager (IPAM).

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeIpams.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDescribeIpams", []))

    @jsii.member(jsii_name="toDescribeIpamScopes")
    def to_describe_ipam_scopes(self) -> "Ec2":
        '''(experimental) Grants permission to describe Amazon VPC IP Address Manager (IPAM) scopes.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeIpamScopes.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDescribeIpamScopes", []))

    @jsii.member(jsii_name="toDescribeIpv6Pools")
    def to_describe_ipv6_pools(self) -> "Ec2":
        '''(experimental) Grants permission to describe one or more IPv6 address pools.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeIpv6Pools.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDescribeIpv6Pools", []))

    @jsii.member(jsii_name="toDescribeKeyPairs")
    def to_describe_key_pairs(self) -> "Ec2":
        '''(experimental) Grants permission to describe one or more key pairs.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeKeyPairs.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDescribeKeyPairs", []))

    @jsii.member(jsii_name="toDescribeLaunchTemplates")
    def to_describe_launch_templates(self) -> "Ec2":
        '''(experimental) Grants permission to describe one or more launch templates.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeLaunchTemplates.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDescribeLaunchTemplates", []))

    @jsii.member(jsii_name="toDescribeLaunchTemplateVersions")
    def to_describe_launch_template_versions(self) -> "Ec2":
        '''(experimental) Grants permission to describe one or more launch template versions.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeLaunchTemplateVersions.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDescribeLaunchTemplateVersions", []))

    @jsii.member(jsii_name="toDescribeLocalGatewayRouteTablePermissions")
    def to_describe_local_gateway_route_table_permissions(self) -> "Ec2":
        '''(experimental) Grants permission to allow a service to describe local gateway route table permissions.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/outposts/latest/userguide/identity-access-management.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDescribeLocalGatewayRouteTablePermissions", []))

    @jsii.member(jsii_name="toDescribeLocalGatewayRouteTables")
    def to_describe_local_gateway_route_tables(self) -> "Ec2":
        '''(experimental) Grants permission to describe one or more local gateway route tables.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeLocalGatewayRouteTables.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDescribeLocalGatewayRouteTables", []))

    @jsii.member(jsii_name="toDescribeLocalGatewayRouteTableVirtualInterfaceGroupAssociations")
    def to_describe_local_gateway_route_table_virtual_interface_group_associations(
        self,
    ) -> "Ec2":
        '''(experimental) Grants permission to describe the associations between virtual interface groups and local gateway route tables.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeLocalGatewayRouteTableVirtualInterfaceGroupAssociations.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDescribeLocalGatewayRouteTableVirtualInterfaceGroupAssociations", []))

    @jsii.member(jsii_name="toDescribeLocalGatewayRouteTableVpcAssociations")
    def to_describe_local_gateway_route_table_vpc_associations(self) -> "Ec2":
        '''(experimental) Grants permission to describe an association between VPCs and local gateway route tables.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeLocalGatewayRouteTableVpcAssociations.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDescribeLocalGatewayRouteTableVpcAssociations", []))

    @jsii.member(jsii_name="toDescribeLocalGateways")
    def to_describe_local_gateways(self) -> "Ec2":
        '''(experimental) Grants permission to describe one or more local gateways.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeLocalGateways.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDescribeLocalGateways", []))

    @jsii.member(jsii_name="toDescribeLocalGatewayVirtualInterfaceGroups")
    def to_describe_local_gateway_virtual_interface_groups(self) -> "Ec2":
        '''(experimental) Grants permission to describe local gateway virtual interface groups.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeLocalGatewayVirtualInterfaceGroups.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDescribeLocalGatewayVirtualInterfaceGroups", []))

    @jsii.member(jsii_name="toDescribeLocalGatewayVirtualInterfaces")
    def to_describe_local_gateway_virtual_interfaces(self) -> "Ec2":
        '''(experimental) Grants permission to describe local gateway virtual interfaces.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeLocalGatewayVirtualInterfaces.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDescribeLocalGatewayVirtualInterfaces", []))

    @jsii.member(jsii_name="toDescribeManagedPrefixLists")
    def to_describe_managed_prefix_lists(self) -> "Ec2":
        '''(experimental) Grants permission to describe your managed prefix lists and any AWS-managed prefix lists.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeManagedPrefixLists.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDescribeManagedPrefixLists", []))

    @jsii.member(jsii_name="toDescribeMovingAddresses")
    def to_describe_moving_addresses(self) -> "Ec2":
        '''(experimental) Grants permission to describe Elastic IP addresses that are being moved to the EC2-VPC platform.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeMovingAddresses.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDescribeMovingAddresses", []))

    @jsii.member(jsii_name="toDescribeNatGateways")
    def to_describe_nat_gateways(self) -> "Ec2":
        '''(experimental) Grants permission to describe one or more NAT gateways.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeNatGateways.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDescribeNatGateways", []))

    @jsii.member(jsii_name="toDescribeNetworkAcls")
    def to_describe_network_acls(self) -> "Ec2":
        '''(experimental) Grants permission to describe one or more network ACLs.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeNetworkAcls.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDescribeNetworkAcls", []))

    @jsii.member(jsii_name="toDescribeNetworkInsightsAccessScopeAnalyses")
    def to_describe_network_insights_access_scope_analyses(self) -> "Ec2":
        '''(experimental) Grants permission to describe one or more Network Access Scope analyses.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeNetworkInsightsAccessScopeAnalyses.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDescribeNetworkInsightsAccessScopeAnalyses", []))

    @jsii.member(jsii_name="toDescribeNetworkInsightsAccessScopes")
    def to_describe_network_insights_access_scopes(self) -> "Ec2":
        '''(experimental) Grants permission to describe the Network Access Scopes.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeNetworkInsightsAccessScopes.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDescribeNetworkInsightsAccessScopes", []))

    @jsii.member(jsii_name="toDescribeNetworkInsightsAnalyses")
    def to_describe_network_insights_analyses(self) -> "Ec2":
        '''(experimental) Grants permission to describe one or more network insights analyses.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeNetworkInsightsAnalyses.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDescribeNetworkInsightsAnalyses", []))

    @jsii.member(jsii_name="toDescribeNetworkInsightsPaths")
    def to_describe_network_insights_paths(self) -> "Ec2":
        '''(experimental) Grants permission to describe one or more network insights paths.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeNetworkInsightsPaths.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDescribeNetworkInsightsPaths", []))

    @jsii.member(jsii_name="toDescribeNetworkInterfaceAttribute")
    def to_describe_network_interface_attribute(self) -> "Ec2":
        '''(experimental) Grants permission to describe a network interface attribute.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeNetworkInterfaceAttribute.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDescribeNetworkInterfaceAttribute", []))

    @jsii.member(jsii_name="toDescribeNetworkInterfacePermissions")
    def to_describe_network_interface_permissions(self) -> "Ec2":
        '''(experimental) Grants permission to describe the permissions that are associated with a network interface.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeNetworkInterfacePermissions.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDescribeNetworkInterfacePermissions", []))

    @jsii.member(jsii_name="toDescribeNetworkInterfaces")
    def to_describe_network_interfaces(self) -> "Ec2":
        '''(experimental) Grants permission to describe one or more network interfaces.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeNetworkInterfaces.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDescribeNetworkInterfaces", []))

    @jsii.member(jsii_name="toDescribePlacementGroups")
    def to_describe_placement_groups(self) -> "Ec2":
        '''(experimental) Grants permission to describe one or more placement groups.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribePlacementGroups.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDescribePlacementGroups", []))

    @jsii.member(jsii_name="toDescribePrefixLists")
    def to_describe_prefix_lists(self) -> "Ec2":
        '''(experimental) Grants permission to describe available AWS services in a prefix list format.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribePrefixLists.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDescribePrefixLists", []))

    @jsii.member(jsii_name="toDescribePrincipalIdFormat")
    def to_describe_principal_id_format(self) -> "Ec2":
        '''(experimental) Grants permission to describe the ID format settings for the root user and all IAM roles and IAM users that have explicitly specified a longer ID (17-character ID) preference.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribePrincipalIdFormat.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDescribePrincipalIdFormat", []))

    @jsii.member(jsii_name="toDescribePublicIpv4Pools")
    def to_describe_public_ipv4_pools(self) -> "Ec2":
        '''(experimental) Grants permission to describe one or more IPv4 address pools.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribePublicIpv4Pools.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDescribePublicIpv4Pools", []))

    @jsii.member(jsii_name="toDescribeRegions")
    def to_describe_regions(self) -> "Ec2":
        '''(experimental) Grants permission to describe one or more AWS Regions that are currently available in your account.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeRegions.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDescribeRegions", []))

    @jsii.member(jsii_name="toDescribeReplaceRootVolumeTasks")
    def to_describe_replace_root_volume_tasks(self) -> "Ec2":
        '''(experimental) Grants permission to describe a root volume replacement task.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeReplaceRootVolumeTasks.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDescribeReplaceRootVolumeTasks", []))

    @jsii.member(jsii_name="toDescribeReservedInstances")
    def to_describe_reserved_instances(self) -> "Ec2":
        '''(experimental) Grants permission to describe one or more purchased Reserved Instances in your account.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeReservedInstances.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDescribeReservedInstances", []))

    @jsii.member(jsii_name="toDescribeReservedInstancesListings")
    def to_describe_reserved_instances_listings(self) -> "Ec2":
        '''(experimental) Grants permission to describe your account's Reserved Instance listings in the Reserved Instance Marketplace.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeReservedInstancesListings.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDescribeReservedInstancesListings", []))

    @jsii.member(jsii_name="toDescribeReservedInstancesModifications")
    def to_describe_reserved_instances_modifications(self) -> "Ec2":
        '''(experimental) Grants permission to describe the modifications made to one or more Reserved Instances.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeReservedInstancesModifications.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDescribeReservedInstancesModifications", []))

    @jsii.member(jsii_name="toDescribeReservedInstancesOfferings")
    def to_describe_reserved_instances_offerings(self) -> "Ec2":
        '''(experimental) Grants permission to describe the Reserved Instance offerings that are available for purchase.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeReservedInstancesOfferings.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDescribeReservedInstancesOfferings", []))

    @jsii.member(jsii_name="toDescribeRouteTables")
    def to_describe_route_tables(self) -> "Ec2":
        '''(experimental) Grants permission to describe one or more route tables.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeRouteTables.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDescribeRouteTables", []))

    @jsii.member(jsii_name="toDescribeScheduledInstanceAvailability")
    def to_describe_scheduled_instance_availability(self) -> "Ec2":
        '''(experimental) Grants permission to find available schedules for Scheduled Instances.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeScheduledInstanceAvailability.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDescribeScheduledInstanceAvailability", []))

    @jsii.member(jsii_name="toDescribeScheduledInstances")
    def to_describe_scheduled_instances(self) -> "Ec2":
        '''(experimental) Grants permission to describe one or more Scheduled Instances in your account.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeScheduledInstances.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDescribeScheduledInstances", []))

    @jsii.member(jsii_name="toDescribeSecurityGroupReferences")
    def to_describe_security_group_references(self) -> "Ec2":
        '''(experimental) Grants permission to describe the VPCs on the other side of a VPC peering connection that are referencing specified VPC security groups.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeSecurityGroupReferences.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDescribeSecurityGroupReferences", []))

    @jsii.member(jsii_name="toDescribeSecurityGroupRules")
    def to_describe_security_group_rules(self) -> "Ec2":
        '''(experimental) Grants permission to describe one or more of your security group rules.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeSecurityGroupRules.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDescribeSecurityGroupRules", []))

    @jsii.member(jsii_name="toDescribeSecurityGroups")
    def to_describe_security_groups(self) -> "Ec2":
        '''(experimental) Grants permission to describe one or more security groups.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeSecurityGroups.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDescribeSecurityGroups", []))

    @jsii.member(jsii_name="toDescribeSnapshotAttribute")
    def to_describe_snapshot_attribute(self) -> "Ec2":
        '''(experimental) Grants permission to describe an attribute of a snapshot.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeSnapshotAttribute.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDescribeSnapshotAttribute", []))

    @jsii.member(jsii_name="toDescribeSnapshots")
    def to_describe_snapshots(self) -> "Ec2":
        '''(experimental) Grants permission to describe one or more EBS snapshots.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeSnapshots.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDescribeSnapshots", []))

    @jsii.member(jsii_name="toDescribeSnapshotTierStatus")
    def to_describe_snapshot_tier_status(self) -> "Ec2":
        '''(experimental) Grants permission to describe the storage tier status for Amazon EBS snapshots.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeSnapshotTierStatus.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDescribeSnapshotTierStatus", []))

    @jsii.member(jsii_name="toDescribeSpotDatafeedSubscription")
    def to_describe_spot_datafeed_subscription(self) -> "Ec2":
        '''(experimental) Grants permission to describe the data feed for Spot Instances.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeSpotDatafeedSubscription.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDescribeSpotDatafeedSubscription", []))

    @jsii.member(jsii_name="toDescribeSpotFleetInstances")
    def to_describe_spot_fleet_instances(self) -> "Ec2":
        '''(experimental) Grants permission to describe the running instances for a Spot Fleet.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeSpotFleetInstances.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDescribeSpotFleetInstances", []))

    @jsii.member(jsii_name="toDescribeSpotFleetRequestHistory")
    def to_describe_spot_fleet_request_history(self) -> "Ec2":
        '''(experimental) Grants permission to describe the events for a Spot Fleet request during a specified time.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeSpotFleetRequestHistory.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDescribeSpotFleetRequestHistory", []))

    @jsii.member(jsii_name="toDescribeSpotFleetRequests")
    def to_describe_spot_fleet_requests(self) -> "Ec2":
        '''(experimental) Grants permission to describe one or more Spot Fleet requests.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeSpotFleetRequests.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDescribeSpotFleetRequests", []))

    @jsii.member(jsii_name="toDescribeSpotInstanceRequests")
    def to_describe_spot_instance_requests(self) -> "Ec2":
        '''(experimental) Grants permission to describe one or more Spot Instance requests.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeSpotInstanceRequests.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDescribeSpotInstanceRequests", []))

    @jsii.member(jsii_name="toDescribeSpotPriceHistory")
    def to_describe_spot_price_history(self) -> "Ec2":
        '''(experimental) Grants permission to describe the Spot Instance price history.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeSpotPriceHistory.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDescribeSpotPriceHistory", []))

    @jsii.member(jsii_name="toDescribeStaleSecurityGroups")
    def to_describe_stale_security_groups(self) -> "Ec2":
        '''(experimental) Grants permission to describe the stale security group rules for security groups in a specified VPC.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeStaleSecurityGroups.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDescribeStaleSecurityGroups", []))

    @jsii.member(jsii_name="toDescribeStoreImageTasks")
    def to_describe_store_image_tasks(self) -> "Ec2":
        '''(experimental) Grants permission to describe the progress of the AMI store tasks.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeStoreImageTasks.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDescribeStoreImageTasks", []))

    @jsii.member(jsii_name="toDescribeSubnets")
    def to_describe_subnets(self) -> "Ec2":
        '''(experimental) Grants permission to describe one or more subnets.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeSubnets.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDescribeSubnets", []))

    @jsii.member(jsii_name="toDescribeTags")
    def to_describe_tags(self) -> "Ec2":
        '''(experimental) Grants permission to describe one or more tags for an Amazon EC2 resource.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeTags.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDescribeTags", []))

    @jsii.member(jsii_name="toDescribeTrafficMirrorFilters")
    def to_describe_traffic_mirror_filters(self) -> "Ec2":
        '''(experimental) Grants permission to describe one or more traffic mirror filters.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeTrafficMirrorFilters.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDescribeTrafficMirrorFilters", []))

    @jsii.member(jsii_name="toDescribeTrafficMirrorSessions")
    def to_describe_traffic_mirror_sessions(self) -> "Ec2":
        '''(experimental) Grants permission to describe one or more traffic mirror sessions.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeTrafficMirrorSessions.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDescribeTrafficMirrorSessions", []))

    @jsii.member(jsii_name="toDescribeTrafficMirrorTargets")
    def to_describe_traffic_mirror_targets(self) -> "Ec2":
        '''(experimental) Grants permission to describe one or more traffic mirror targets.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeTrafficMirrorTargets.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDescribeTrafficMirrorTargets", []))

    @jsii.member(jsii_name="toDescribeTransitGatewayAttachments")
    def to_describe_transit_gateway_attachments(self) -> "Ec2":
        '''(experimental) Grants permission to describe one or more attachments between resources and transit gateways.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeTransitGatewayAttachments.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDescribeTransitGatewayAttachments", []))

    @jsii.member(jsii_name="toDescribeTransitGatewayConnectPeers")
    def to_describe_transit_gateway_connect_peers(self) -> "Ec2":
        '''(experimental) Grants permission to describe one or more transit gateway connect peers.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeTransitGatewayConnectPeers.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDescribeTransitGatewayConnectPeers", []))

    @jsii.member(jsii_name="toDescribeTransitGatewayConnects")
    def to_describe_transit_gateway_connects(self) -> "Ec2":
        '''(experimental) Grants permission to describe one or more transit gateway connect attachments.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeTransitGatewayConnects.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDescribeTransitGatewayConnects", []))

    @jsii.member(jsii_name="toDescribeTransitGatewayMulticastDomains")
    def to_describe_transit_gateway_multicast_domains(self) -> "Ec2":
        '''(experimental) Grants permission to describe one or more transit gateway multicast domains.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeTransitGatewayMulticastDomains.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDescribeTransitGatewayMulticastDomains", []))

    @jsii.member(jsii_name="toDescribeTransitGatewayPeeringAttachments")
    def to_describe_transit_gateway_peering_attachments(self) -> "Ec2":
        '''(experimental) Grants permission to describe one or more transit gateway peering attachments.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeTransitGatewayPeeringAttachments.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDescribeTransitGatewayPeeringAttachments", []))

    @jsii.member(jsii_name="toDescribeTransitGatewayPolicyTables")
    def to_describe_transit_gateway_policy_tables(self) -> "Ec2":
        '''(experimental) Grants permission to describe a transit gateway policy table.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeTransitGatewayPolicyTables.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDescribeTransitGatewayPolicyTables", []))

    @jsii.member(jsii_name="toDescribeTransitGatewayRouteTableAnnouncements")
    def to_describe_transit_gateway_route_table_announcements(self) -> "Ec2":
        '''(experimental) Grants permission to describe a transit gateway route table announcement.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeTransitGatewayRouteTableAnnouncements.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDescribeTransitGatewayRouteTableAnnouncements", []))

    @jsii.member(jsii_name="toDescribeTransitGatewayRouteTables")
    def to_describe_transit_gateway_route_tables(self) -> "Ec2":
        '''(experimental) Grants permission to describe one or more transit gateway route tables.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeTransitGatewayRouteTables.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDescribeTransitGatewayRouteTables", []))

    @jsii.member(jsii_name="toDescribeTransitGateways")
    def to_describe_transit_gateways(self) -> "Ec2":
        '''(experimental) Grants permission to describe one or more transit gateways.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeTransitGateways.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDescribeTransitGateways", []))

    @jsii.member(jsii_name="toDescribeTransitGatewayVpcAttachments")
    def to_describe_transit_gateway_vpc_attachments(self) -> "Ec2":
        '''(experimental) Grants permission to describe one or more VPC attachments on a transit gateway.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeTransitGatewayVpcAttachments.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDescribeTransitGatewayVpcAttachments", []))

    @jsii.member(jsii_name="toDescribeTrunkInterfaceAssociations")
    def to_describe_trunk_interface_associations(self) -> "Ec2":
        '''(experimental) Grants permission to describe one or more network interface trunk associations.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeTrunkInterfaceAssociations.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDescribeTrunkInterfaceAssociations", []))

    @jsii.member(jsii_name="toDescribeVerifiedAccessEndpoints")
    def to_describe_verified_access_endpoints(self) -> "Ec2":
        '''(experimental) Grants permission to describe the specified Verified Access endpoints or all Verified Access endpoints.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeVerifiedAccessEndpoints.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDescribeVerifiedAccessEndpoints", []))

    @jsii.member(jsii_name="toDescribeVerifiedAccessGroups")
    def to_describe_verified_access_groups(self) -> "Ec2":
        '''(experimental) Grants permission to describe the specified Verified Access groups or all Verified Access groups.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeVerifiedAccessGroups.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDescribeVerifiedAccessGroups", []))

    @jsii.member(jsii_name="toDescribeVerifiedAccessInstanceLoggingConfigurations")
    def to_describe_verified_access_instance_logging_configurations(self) -> "Ec2":
        '''(experimental) Grants permission to describe the current logging configuration for the Verified Access instances.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeVerifiedAccessInstanceLoggingConfigurations.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDescribeVerifiedAccessInstanceLoggingConfigurations", []))

    @jsii.member(jsii_name="toDescribeVerifiedAccessInstances")
    def to_describe_verified_access_instances(self) -> "Ec2":
        '''(experimental) Grants permission to describe the specified Verified Access instances or all Verified Access instances.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeVerifiedAccessInstances.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDescribeVerifiedAccessInstances", []))

    @jsii.member(jsii_name="toDescribeVerifiedAccessTrustProviders")
    def to_describe_verified_access_trust_providers(self) -> "Ec2":
        '''(experimental) Grants permission to describe details of existing Verified Access trust providers.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeVerifiedAccessTrustProviders.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDescribeVerifiedAccessTrustProviders", []))

    @jsii.member(jsii_name="toDescribeVolumeAttribute")
    def to_describe_volume_attribute(self) -> "Ec2":
        '''(experimental) Grants permission to describe an attribute of an EBS volume.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeVolumeAttribute.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDescribeVolumeAttribute", []))

    @jsii.member(jsii_name="toDescribeVolumes")
    def to_describe_volumes(self) -> "Ec2":
        '''(experimental) Grants permission to describe one or more EBS volumes.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeVolumes.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDescribeVolumes", []))

    @jsii.member(jsii_name="toDescribeVolumesModifications")
    def to_describe_volumes_modifications(self) -> "Ec2":
        '''(experimental) Grants permission to describe the current modification status of one or more EBS volumes.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeVolumesModifications.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDescribeVolumesModifications", []))

    @jsii.member(jsii_name="toDescribeVolumeStatus")
    def to_describe_volume_status(self) -> "Ec2":
        '''(experimental) Grants permission to describe the status of one or more EBS volumes.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeVolumeStatus.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDescribeVolumeStatus", []))

    @jsii.member(jsii_name="toDescribeVpcAttribute")
    def to_describe_vpc_attribute(self) -> "Ec2":
        '''(experimental) Grants permission to describe an attribute of a VPC.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeVpcAttribute.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDescribeVpcAttribute", []))

    @jsii.member(jsii_name="toDescribeVpcClassicLink")
    def to_describe_vpc_classic_link(self) -> "Ec2":
        '''(experimental) Grants permission to describe the ClassicLink status of one or more VPCs.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeVpcClassicLink.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDescribeVpcClassicLink", []))

    @jsii.member(jsii_name="toDescribeVpcClassicLinkDnsSupport")
    def to_describe_vpc_classic_link_dns_support(self) -> "Ec2":
        '''(experimental) Grants permission to describe the ClassicLink DNS support status of one or more VPCs.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeVpcClassicLinkDnsSupport.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDescribeVpcClassicLinkDnsSupport", []))

    @jsii.member(jsii_name="toDescribeVpcEndpointConnectionNotifications")
    def to_describe_vpc_endpoint_connection_notifications(self) -> "Ec2":
        '''(experimental) Grants permission to describe the connection notifications for VPC endpoints and VPC endpoint services.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeVpcEndpointConnectionNotifications.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDescribeVpcEndpointConnectionNotifications", []))

    @jsii.member(jsii_name="toDescribeVpcEndpointConnections")
    def to_describe_vpc_endpoint_connections(self) -> "Ec2":
        '''(experimental) Grants permission to describe the VPC endpoint connections to your VPC endpoint services.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeVpcEndpointConnections.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDescribeVpcEndpointConnections", []))

    @jsii.member(jsii_name="toDescribeVpcEndpoints")
    def to_describe_vpc_endpoints(self) -> "Ec2":
        '''(experimental) Grants permission to describe one or more VPC endpoints.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeVpcEndpoints.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDescribeVpcEndpoints", []))

    @jsii.member(jsii_name="toDescribeVpcEndpointServiceConfigurations")
    def to_describe_vpc_endpoint_service_configurations(self) -> "Ec2":
        '''(experimental) Grants permission to describe VPC endpoint service configurations (your services).

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeVpcEndpointServiceConfigurations.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDescribeVpcEndpointServiceConfigurations", []))

    @jsii.member(jsii_name="toDescribeVpcEndpointServicePermissions")
    def to_describe_vpc_endpoint_service_permissions(self) -> "Ec2":
        '''(experimental) Grants permission to describe the principals (service consumers) that are permitted to discover your VPC endpoint service.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeVpcEndpointServicePermissions.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDescribeVpcEndpointServicePermissions", []))

    @jsii.member(jsii_name="toDescribeVpcEndpointServices")
    def to_describe_vpc_endpoint_services(self) -> "Ec2":
        '''(experimental) Grants permission to describe all supported AWS services that can be specified when creating a VPC endpoint.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeVpcEndpointServices.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDescribeVpcEndpointServices", []))

    @jsii.member(jsii_name="toDescribeVpcPeeringConnections")
    def to_describe_vpc_peering_connections(self) -> "Ec2":
        '''(experimental) Grants permission to describe one or more VPC peering connections.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeVpcPeeringConnections.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDescribeVpcPeeringConnections", []))

    @jsii.member(jsii_name="toDescribeVpcs")
    def to_describe_vpcs(self) -> "Ec2":
        '''(experimental) Grants permission to describe one or more VPCs.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeVpcs.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDescribeVpcs", []))

    @jsii.member(jsii_name="toDescribeVpnConnections")
    def to_describe_vpn_connections(self) -> "Ec2":
        '''(experimental) Grants permission to describe one or more VPN connections.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeVpnConnections.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDescribeVpnConnections", []))

    @jsii.member(jsii_name="toDescribeVpnGateways")
    def to_describe_vpn_gateways(self) -> "Ec2":
        '''(experimental) Grants permission to describe one or more virtual private gateways.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeVpnGateways.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDescribeVpnGateways", []))

    @jsii.member(jsii_name="toDetachClassicLinkVpc")
    def to_detach_classic_link_vpc(self) -> "Ec2":
        '''(experimental) Grants permission to unlink (detach) a linked EC2-Classic instance from a VPC.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DetachClassicLinkVpc.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDetachClassicLinkVpc", []))

    @jsii.member(jsii_name="toDetachInternetGateway")
    def to_detach_internet_gateway(self) -> "Ec2":
        '''(experimental) Grants permission to detach an internet gateway from a VPC.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DetachInternetGateway.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDetachInternetGateway", []))

    @jsii.member(jsii_name="toDetachNetworkInterface")
    def to_detach_network_interface(self) -> "Ec2":
        '''(experimental) Grants permission to detach a network interface from an instance.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DetachNetworkInterface.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDetachNetworkInterface", []))

    @jsii.member(jsii_name="toDetachVerifiedAccessTrustProvider")
    def to_detach_verified_access_trust_provider(self) -> "Ec2":
        '''(experimental) Grants permission to detach a trust provider from a Verified Access instance.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DetachVerifiedAccessTrustProvider.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDetachVerifiedAccessTrustProvider", []))

    @jsii.member(jsii_name="toDetachVolume")
    def to_detach_volume(self) -> "Ec2":
        '''(experimental) Grants permission to detach an EBS volume from an instance.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DetachVolume.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDetachVolume", []))

    @jsii.member(jsii_name="toDetachVpnGateway")
    def to_detach_vpn_gateway(self) -> "Ec2":
        '''(experimental) Grants permission to detach a virtual private gateway from a VPC.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DetachVpnGateway.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDetachVpnGateway", []))

    @jsii.member(jsii_name="toDisableAddressTransfer")
    def to_disable_address_transfer(self) -> "Ec2":
        '''(experimental) Grants permission to disable Elastic IP address transfer.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DisableAddressTransfer.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDisableAddressTransfer", []))

    @jsii.member(jsii_name="toDisableAwsNetworkPerformanceMetricSubscription")
    def to_disable_aws_network_performance_metric_subscription(self) -> "Ec2":
        '''(experimental) Grants permission to disable infrastructure performance metric subscriptions.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DisableAwsNetworkPerformanceMetricSubscription.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDisableAwsNetworkPerformanceMetricSubscription", []))

    @jsii.member(jsii_name="toDisableEbsEncryptionByDefault")
    def to_disable_ebs_encryption_by_default(self) -> "Ec2":
        '''(experimental) Grants permission to disable EBS encryption by default for your account.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DisableEbsEncryptionByDefault.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDisableEbsEncryptionByDefault", []))

    @jsii.member(jsii_name="toDisableFastLaunch")
    def to_disable_fast_launch(self) -> "Ec2":
        '''(experimental) Grants permission to disable faster launching for Windows AMIs.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DisableFastLaunch.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDisableFastLaunch", []))

    @jsii.member(jsii_name="toDisableFastSnapshotRestores")
    def to_disable_fast_snapshot_restores(self) -> "Ec2":
        '''(experimental) Grants permission to disable fast snapshot restores for one or more snapshots in specified Availability Zones.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DisableFastSnapshotRestores.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDisableFastSnapshotRestores", []))

    @jsii.member(jsii_name="toDisableImageDeprecation")
    def to_disable_image_deprecation(self) -> "Ec2":
        '''(experimental) Grants permission to cancel the deprecation of the specified AMI.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DisableImageDeprecation.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDisableImageDeprecation", []))

    @jsii.member(jsii_name="toDisableIpamOrganizationAdminAccount")
    def to_disable_ipam_organization_admin_account(self) -> "Ec2":
        '''(experimental) Grants permission to disable an AWS Organizations member account as an Amazon VPC IP Address Manager (IPAM) admin account.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        Dependent actions:

        - organizations:DeregisterDelegatedAdministrator

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DisableIpamOrganizationAdminAccount.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDisableIpamOrganizationAdminAccount", []))

    @jsii.member(jsii_name="toDisableSerialConsoleAccess")
    def to_disable_serial_console_access(self) -> "Ec2":
        '''(experimental) Grants permission to disable access to the EC2 serial console of all instances for your account.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DisableSerialConsoleAccess.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDisableSerialConsoleAccess", []))

    @jsii.member(jsii_name="toDisableTransitGatewayRouteTablePropagation")
    def to_disable_transit_gateway_route_table_propagation(self) -> "Ec2":
        '''(experimental) Grants permission to disable a resource attachment from propagating routes to the specified propagation route table.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DisableTransitGatewayRouteTablePropagation.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDisableTransitGatewayRouteTablePropagation", []))

    @jsii.member(jsii_name="toDisableVgwRoutePropagation")
    def to_disable_vgw_route_propagation(self) -> "Ec2":
        '''(experimental) Grants permission to disable a virtual private gateway from propagating routes to a specified route table of a VPC.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DisableVgwRoutePropagation.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDisableVgwRoutePropagation", []))

    @jsii.member(jsii_name="toDisableVpcClassicLink")
    def to_disable_vpc_classic_link(self) -> "Ec2":
        '''(experimental) Grants permission to disable ClassicLink for a VPC.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DisableVpcClassicLink.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDisableVpcClassicLink", []))

    @jsii.member(jsii_name="toDisableVpcClassicLinkDnsSupport")
    def to_disable_vpc_classic_link_dns_support(self) -> "Ec2":
        '''(experimental) Grants permission to disable ClassicLink DNS support for a VPC.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DisableVpcClassicLinkDnsSupport.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDisableVpcClassicLinkDnsSupport", []))

    @jsii.member(jsii_name="toDisassociateAddress")
    def to_disassociate_address(self) -> "Ec2":
        '''(experimental) Grants permission to disassociate an Elastic IP address from an instance or network interface.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DisassociateAddress.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDisassociateAddress", []))

    @jsii.member(jsii_name="toDisassociateClientVpnTargetNetwork")
    def to_disassociate_client_vpn_target_network(self) -> "Ec2":
        '''(experimental) Grants permission to disassociate a target network from a Client VPN endpoint.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DisassociateClientVpnTargetNetwork.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDisassociateClientVpnTargetNetwork", []))

    @jsii.member(jsii_name="toDisassociateEnclaveCertificateIamRole")
    def to_disassociate_enclave_certificate_iam_role(self) -> "Ec2":
        '''(experimental) Grants permission to disassociate an ACM certificate from a IAM role.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DisassociateEnclaveCertificateIamRole.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDisassociateEnclaveCertificateIamRole", []))

    @jsii.member(jsii_name="toDisassociateIamInstanceProfile")
    def to_disassociate_iam_instance_profile(self) -> "Ec2":
        '''(experimental) Grants permission to disassociate an IAM instance profile from a running or stopped instance.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DisassociateIamInstanceProfile.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDisassociateIamInstanceProfile", []))

    @jsii.member(jsii_name="toDisassociateInstanceEventWindow")
    def to_disassociate_instance_event_window(self) -> "Ec2":
        '''(experimental) Grants permission to disassociate one or more targets from an event window.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DisassociateInstanceEventWindow.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDisassociateInstanceEventWindow", []))

    @jsii.member(jsii_name="toDisassociateRouteTable")
    def to_disassociate_route_table(self) -> "Ec2":
        '''(experimental) Grants permission to disassociate a subnet from a route table.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DisassociateRouteTable.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDisassociateRouteTable", []))

    @jsii.member(jsii_name="toDisassociateSubnetCidrBlock")
    def to_disassociate_subnet_cidr_block(self) -> "Ec2":
        '''(experimental) Grants permission to disassociate a CIDR block from a subnet.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DisassociateSubnetCidrBlock.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDisassociateSubnetCidrBlock", []))

    @jsii.member(jsii_name="toDisassociateTransitGatewayMulticastDomain")
    def to_disassociate_transit_gateway_multicast_domain(self) -> "Ec2":
        '''(experimental) Grants permission to disassociate one or more subnets from a transit gateway multicast domain.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DisassociateTransitGatewayMulticastDomain.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDisassociateTransitGatewayMulticastDomain", []))

    @jsii.member(jsii_name="toDisassociateTransitGatewayPolicyTable")
    def to_disassociate_transit_gateway_policy_table(self) -> "Ec2":
        '''(experimental) Grants permission to disassociate a policy table from a transit gateway.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DisassociateTransitGatewayPolicyTable.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDisassociateTransitGatewayPolicyTable", []))

    @jsii.member(jsii_name="toDisassociateTransitGatewayRouteTable")
    def to_disassociate_transit_gateway_route_table(self) -> "Ec2":
        '''(experimental) Grants permission to disassociate a resource attachment from a transit gateway route table.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DisassociateTransitGatewayRouteTable.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDisassociateTransitGatewayRouteTable", []))

    @jsii.member(jsii_name="toDisassociateTrunkInterface")
    def to_disassociate_trunk_interface(self) -> "Ec2":
        '''(experimental) Grants permission to disassociate a branch network interface to a trunk network interface.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DisassociateTrunkInterface.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDisassociateTrunkInterface", []))

    @jsii.member(jsii_name="toDisassociateVpcCidrBlock")
    def to_disassociate_vpc_cidr_block(self) -> "Ec2":
        '''(experimental) Grants permission to disassociate a CIDR block from a VPC.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DisassociateVpcCidrBlock.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toDisassociateVpcCidrBlock", []))

    @jsii.member(jsii_name="toEnableAddressTransfer")
    def to_enable_address_transfer(self) -> "Ec2":
        '''(experimental) Grants permission to enable Elastic IP address transfer.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_EnableAddressTransfer.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toEnableAddressTransfer", []))

    @jsii.member(jsii_name="toEnableAwsNetworkPerformanceMetricSubscription")
    def to_enable_aws_network_performance_metric_subscription(self) -> "Ec2":
        '''(experimental) Grants permission to enable infrastructure performance subscriptions.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_EnableAwsNetworkPerformanceMetricSubscription.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toEnableAwsNetworkPerformanceMetricSubscription", []))

    @jsii.member(jsii_name="toEnableEbsEncryptionByDefault")
    def to_enable_ebs_encryption_by_default(self) -> "Ec2":
        '''(experimental) Grants permission to enable EBS encryption by default for your account.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_EnableEbsEncryptionByDefault.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toEnableEbsEncryptionByDefault", []))

    @jsii.member(jsii_name="toEnableFastLaunch")
    def to_enable_fast_launch(self) -> "Ec2":
        '''(experimental) Grants permission to enable faster launching for Windows AMIs.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_EnableFastLaunch.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toEnableFastLaunch", []))

    @jsii.member(jsii_name="toEnableFastSnapshotRestores")
    def to_enable_fast_snapshot_restores(self) -> "Ec2":
        '''(experimental) Grants permission to enable fast snapshot restores for one or more snapshots in specified Availability Zones.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_EnableFastSnapshotRestores.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toEnableFastSnapshotRestores", []))

    @jsii.member(jsii_name="toEnableImageDeprecation")
    def to_enable_image_deprecation(self) -> "Ec2":
        '''(experimental) Grants permission to enable deprecation of the specified AMI at the specified date and time.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_EnableImageDeprecation.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toEnableImageDeprecation", []))

    @jsii.member(jsii_name="toEnableIpamOrganizationAdminAccount")
    def to_enable_ipam_organization_admin_account(self) -> "Ec2":
        '''(experimental) Grants permission to enable an AWS Organizations member account as an Amazon VPC IP Address Manager (IPAM) admin account.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        Dependent actions:

        - iam:CreateServiceLinkedRole
        - organizations:EnableAWSServiceAccess
        - organizations:RegisterDelegatedAdministrator

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_EnableIpamOrganizationAdminAccount.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toEnableIpamOrganizationAdminAccount", []))

    @jsii.member(jsii_name="toEnableReachabilityAnalyzerOrganizationSharing")
    def to_enable_reachability_analyzer_organization_sharing(self) -> "Ec2":
        '''(experimental) Grants permission to enable organization sharing of reachability analyzer.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_EnableReachabilityAnalyzerOrganizationSharing.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toEnableReachabilityAnalyzerOrganizationSharing", []))

    @jsii.member(jsii_name="toEnableSerialConsoleAccess")
    def to_enable_serial_console_access(self) -> "Ec2":
        '''(experimental) Grants permission to enable access to the EC2 serial console of all instances for your account.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_EnableSerialConsoleAccess.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toEnableSerialConsoleAccess", []))

    @jsii.member(jsii_name="toEnableTransitGatewayRouteTablePropagation")
    def to_enable_transit_gateway_route_table_propagation(self) -> "Ec2":
        '''(experimental) Grants permission to enable an attachment to propagate routes to a propagation route table.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_EnableTransitGatewayRouteTablePropagation.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toEnableTransitGatewayRouteTablePropagation", []))

    @jsii.member(jsii_name="toEnableVgwRoutePropagation")
    def to_enable_vgw_route_propagation(self) -> "Ec2":
        '''(experimental) Grants permission to enable a virtual private gateway to propagate routes to a VPC route table.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_EnableVgwRoutePropagation.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toEnableVgwRoutePropagation", []))

    @jsii.member(jsii_name="toEnableVolumeIO")
    def to_enable_volume_io(self) -> "Ec2":
        '''(experimental) Grants permission to enable I/O operations for a volume that had I/O operations disabled.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_EnableVolumeIO.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toEnableVolumeIO", []))

    @jsii.member(jsii_name="toEnableVpcClassicLink")
    def to_enable_vpc_classic_link(self) -> "Ec2":
        '''(experimental) Grants permission to enable a VPC for ClassicLink.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_EnableVpcClassicLink.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toEnableVpcClassicLink", []))

    @jsii.member(jsii_name="toEnableVpcClassicLinkDnsSupport")
    def to_enable_vpc_classic_link_dns_support(self) -> "Ec2":
        '''(experimental) Grants permission to enable a VPC to support DNS hostname resolution for ClassicLink.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_EnableVpcClassicLinkDnsSupport.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toEnableVpcClassicLinkDnsSupport", []))

    @jsii.member(jsii_name="toExportClientVpnClientCertificateRevocationList")
    def to_export_client_vpn_client_certificate_revocation_list(self) -> "Ec2":
        '''(experimental) Grants permission to download the client certificate revocation list for a Client VPN endpoint.

        Access Level: Read

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ExportClientVpnClientCertificateRevocationList.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toExportClientVpnClientCertificateRevocationList", []))

    @jsii.member(jsii_name="toExportClientVpnClientConfiguration")
    def to_export_client_vpn_client_configuration(self) -> "Ec2":
        '''(experimental) Grants permission to download the contents of the Client VPN endpoint configuration file for a Client VPN endpoint.

        Access Level: Read

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ExportClientVpnClientConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toExportClientVpnClientConfiguration", []))

    @jsii.member(jsii_name="toExportImage")
    def to_export_image(self) -> "Ec2":
        '''(experimental) Grants permission to export an Amazon Machine Image (AMI) to a VM file.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifRegion()

        Dependent actions:

        - ec2:CreateTags

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ExportImage.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toExportImage", []))

    @jsii.member(jsii_name="toExportTransitGatewayRoutes")
    def to_export_transit_gateway_routes(self) -> "Ec2":
        '''(experimental) Grants permission to export routes from a transit gateway route table to an Amazon S3 bucket.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ExportTransitGatewayRoutes.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toExportTransitGatewayRoutes", []))

    @jsii.member(jsii_name="toGetAssociatedEnclaveCertificateIamRoles")
    def to_get_associated_enclave_certificate_iam_roles(self) -> "Ec2":
        '''(experimental) Grants permission to get the list of roles associated with an ACM certificate.

        Access Level: Read

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_GetAssociatedEnclaveCertificateIamRoles.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toGetAssociatedEnclaveCertificateIamRoles", []))

    @jsii.member(jsii_name="toGetAssociatedIpv6PoolCidrs")
    def to_get_associated_ipv6_pool_cidrs(self) -> "Ec2":
        '''(experimental) Grants permission to get information about the IPv6 CIDR block associations for a specified IPv6 address pool.

        Access Level: Read

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_GetAssociatedIpv6PoolCidrs.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toGetAssociatedIpv6PoolCidrs", []))

    @jsii.member(jsii_name="toGetAwsNetworkPerformanceData")
    def to_get_aws_network_performance_data(self) -> "Ec2":
        '''(experimental) Grants permission to get network performance data.

        Access Level: Read

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_GetAwsNetworkPerformanceData.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toGetAwsNetworkPerformanceData", []))

    @jsii.member(jsii_name="toGetCapacityReservationUsage")
    def to_get_capacity_reservation_usage(self) -> "Ec2":
        '''(experimental) Grants permission to get usage information about a Capacity Reservation.

        Access Level: Read

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_GetCapacityReservationUsage.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toGetCapacityReservationUsage", []))

    @jsii.member(jsii_name="toGetCoipPoolUsage")
    def to_get_coip_pool_usage(self) -> "Ec2":
        '''(experimental) Grants permission to describe the allocations from the specified customer-owned address pool.

        Access Level: Read

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_GetCoipPoolUsage.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toGetCoipPoolUsage", []))

    @jsii.member(jsii_name="toGetConsoleOutput")
    def to_get_console_output(self) -> "Ec2":
        '''(experimental) Grants permission to get the console output for an instance.

        Access Level: Read

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_GetConsoleOutput.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toGetConsoleOutput", []))

    @jsii.member(jsii_name="toGetConsoleScreenshot")
    def to_get_console_screenshot(self) -> "Ec2":
        '''(experimental) Grants permission to retrieve a JPG-format screenshot of a running instance.

        Access Level: Read

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_GetConsoleScreenshot.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toGetConsoleScreenshot", []))

    @jsii.member(jsii_name="toGetDefaultCreditSpecification")
    def to_get_default_credit_specification(self) -> "Ec2":
        '''(experimental) Grants permission to get the default credit option for CPU usage of a burstable performance instance family.

        Access Level: Read

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_GetDefaultCreditSpecification.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toGetDefaultCreditSpecification", []))

    @jsii.member(jsii_name="toGetEbsDefaultKmsKeyId")
    def to_get_ebs_default_kms_key_id(self) -> "Ec2":
        '''(experimental) Grants permission to get the ID of the default customer master key (CMK) for EBS encryption by default.

        Access Level: Read

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_GetEbsDefaultKmsKeyId.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toGetEbsDefaultKmsKeyId", []))

    @jsii.member(jsii_name="toGetEbsEncryptionByDefault")
    def to_get_ebs_encryption_by_default(self) -> "Ec2":
        '''(experimental) Grants permission to describe whether EBS encryption by default is enabled for your account.

        Access Level: Read

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_GetEbsEncryptionByDefault.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toGetEbsEncryptionByDefault", []))

    @jsii.member(jsii_name="toGetFlowLogsIntegrationTemplate")
    def to_get_flow_logs_integration_template(self) -> "Ec2":
        '''(experimental) Grants permission to generate a CloudFormation template to streamline the integration of VPC flow logs with Amazon Athena.

        Access Level: Read

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_GetFlowLogsIntegrationTemplate.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toGetFlowLogsIntegrationTemplate", []))

    @jsii.member(jsii_name="toGetGroupsForCapacityReservation")
    def to_get_groups_for_capacity_reservation(self) -> "Ec2":
        '''(experimental) Grants permission to list the resource groups to which a Capacity Reservation has been added.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_GetGroupsForCapacityReservation.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toGetGroupsForCapacityReservation", []))

    @jsii.member(jsii_name="toGetHostReservationPurchasePreview")
    def to_get_host_reservation_purchase_preview(self) -> "Ec2":
        '''(experimental) Grants permission to preview a reservation purchase with configurations that match those of a Dedicated Host.

        Access Level: Read

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_GetHostReservationPurchasePreview.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toGetHostReservationPurchasePreview", []))

    @jsii.member(jsii_name="toGetInstanceTypesFromInstanceRequirements")
    def to_get_instance_types_from_instance_requirements(self) -> "Ec2":
        '''(experimental) Grants permission to view a list of instance types with specified instance attributes.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_GetInstanceTypesFromInstanceRequirements.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toGetInstanceTypesFromInstanceRequirements", []))

    @jsii.member(jsii_name="toGetInstanceUefiData")
    def to_get_instance_uefi_data(self) -> "Ec2":
        '''(experimental) Grants permission to retrieve the binary representation of the UEFI variable store.

        Access Level: Read

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_GetInstanceUefiData.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toGetInstanceUefiData", []))

    @jsii.member(jsii_name="toGetIpamAddressHistory")
    def to_get_ipam_address_history(self) -> "Ec2":
        '''(experimental) Grants permission to retrieve historical information about a CIDR within an Amazon VPC IP Address Manager (IPAM) scope.

        Access Level: Read

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_GetIpamAddressHistory.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toGetIpamAddressHistory", []))

    @jsii.member(jsii_name="toGetIpamPoolAllocations")
    def to_get_ipam_pool_allocations(self) -> "Ec2":
        '''(experimental) Grants permission to get a list of all the CIDR allocations in an Amazon VPC IP Address Manager (IPAM) pool.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_GetIpamPoolAllocations.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toGetIpamPoolAllocations", []))

    @jsii.member(jsii_name="toGetIpamPoolCidrs")
    def to_get_ipam_pool_cidrs(self) -> "Ec2":
        '''(experimental) Grants permission to get the CIDRs provisioned to an Amazon VPC IP Address Manager (IPAM) pool.

        Access Level: Read

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_GetIpamPoolCidrs.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toGetIpamPoolCidrs", []))

    @jsii.member(jsii_name="toGetIpamResourceCidrs")
    def to_get_ipam_resource_cidrs(self) -> "Ec2":
        '''(experimental) Grants permission to get information about the resources in an Amazon VPC IP Address Manager (IPAM) scope.

        Access Level: Read

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_GetIpamResourceCidrs.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toGetIpamResourceCidrs", []))

    @jsii.member(jsii_name="toGetLaunchTemplateData")
    def to_get_launch_template_data(self) -> "Ec2":
        '''(experimental) Grants permission to get the configuration data of the specified instance for use with a new launch template or launch template version.

        Access Level: Read

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_GetLaunchTemplateData.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toGetLaunchTemplateData", []))

    @jsii.member(jsii_name="toGetManagedPrefixListAssociations")
    def to_get_managed_prefix_list_associations(self) -> "Ec2":
        '''(experimental) Grants permission to get information about the resources that are associated with the specified managed prefix list.

        Access Level: Read

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_GetManagedPrefixListAssociations.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toGetManagedPrefixListAssociations", []))

    @jsii.member(jsii_name="toGetManagedPrefixListEntries")
    def to_get_managed_prefix_list_entries(self) -> "Ec2":
        '''(experimental) Grants permission to get information about the entries for a specified managed prefix list.

        Access Level: Read

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_GetManagedPrefixListEntries.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toGetManagedPrefixListEntries", []))

    @jsii.member(jsii_name="toGetNetworkInsightsAccessScopeAnalysisFindings")
    def to_get_network_insights_access_scope_analysis_findings(self) -> "Ec2":
        '''(experimental) Grants permission to get the findings for one or more Network Access Scope analyses.

        Access Level: Read

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_GetNetworkInsightsAccessScopeAnalysisFindings.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toGetNetworkInsightsAccessScopeAnalysisFindings", []))

    @jsii.member(jsii_name="toGetNetworkInsightsAccessScopeContent")
    def to_get_network_insights_access_scope_content(self) -> "Ec2":
        '''(experimental) Grants permission to get the content for a specified Network Access Scope.

        Access Level: Read

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_GetNetworkInsightsAccessScopeContent.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toGetNetworkInsightsAccessScopeContent", []))

    @jsii.member(jsii_name="toGetPasswordData")
    def to_get_password_data(self) -> "Ec2":
        '''(experimental) Grants permission to retrieve the encrypted administrator password for a running Windows instance.

        Access Level: Read

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_GetPasswordData.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toGetPasswordData", []))

    @jsii.member(jsii_name="toGetReservedInstancesExchangeQuote")
    def to_get_reserved_instances_exchange_quote(self) -> "Ec2":
        '''(experimental) Grants permission to return a quote and exchange information for exchanging one or more Convertible Reserved Instances for a new Convertible Reserved Instance.

        Access Level: Read

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_GetReservedInstancesExchangeQuote.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toGetReservedInstancesExchangeQuote", []))

    @jsii.member(jsii_name="toGetResourcePolicy")
    def to_get_resource_policy(self) -> "Ec2":
        '''(experimental) Grants permission to describe an IAM policy that enables cross-account sharing.

        Access Level: Read

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/vpc/latest/ipam/share-pool-ipam.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toGetResourcePolicy", []))

    @jsii.member(jsii_name="toGetSerialConsoleAccessStatus")
    def to_get_serial_console_access_status(self) -> "Ec2":
        '''(experimental) Grants permission to retrieve the access status of your account to the EC2 serial console of all instances.

        Access Level: Read

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_GetSerialConsoleAccessStatus.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toGetSerialConsoleAccessStatus", []))

    @jsii.member(jsii_name="toGetSpotPlacementScores")
    def to_get_spot_placement_scores(self) -> "Ec2":
        '''(experimental) Grants permission to calculate the Spot placement score for a Region or Availability Zone based on the specified target capacity and compute requirements.

        Access Level: Read

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_GetSpotPlacementScores.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toGetSpotPlacementScores", []))

    @jsii.member(jsii_name="toGetSubnetCidrReservations")
    def to_get_subnet_cidr_reservations(self) -> "Ec2":
        '''(experimental) Grants permission to retrieve information about the subnet CIDR reservations.

        Access Level: Read

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_GetSubnetCidrReservations.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toGetSubnetCidrReservations", []))

    @jsii.member(jsii_name="toGetTransitGatewayAttachmentPropagations")
    def to_get_transit_gateway_attachment_propagations(self) -> "Ec2":
        '''(experimental) Grants permission to list the route tables to which a resource attachment propagates routes.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_GetTransitGatewayAttachmentPropagations.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toGetTransitGatewayAttachmentPropagations", []))

    @jsii.member(jsii_name="toGetTransitGatewayMulticastDomainAssociations")
    def to_get_transit_gateway_multicast_domain_associations(self) -> "Ec2":
        '''(experimental) Grants permission to get information about the associations for a transit gateway multicast domain.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_GetTransitGatewayMulticastDomainAssociations.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toGetTransitGatewayMulticastDomainAssociations", []))

    @jsii.member(jsii_name="toGetTransitGatewayPolicyTableAssociations")
    def to_get_transit_gateway_policy_table_associations(self) -> "Ec2":
        '''(experimental) Grants permission to get information about associations for a transit gateway policy table.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_GetTransitGatewayPolicyTableAssociations.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toGetTransitGatewayPolicyTableAssociations", []))

    @jsii.member(jsii_name="toGetTransitGatewayPolicyTableEntries")
    def to_get_transit_gateway_policy_table_entries(self) -> "Ec2":
        '''(experimental) Grants permission to get information about associations for a transit gateway policy table entry.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_GetTransitGatewayPolicyTableEntries.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toGetTransitGatewayPolicyTableEntries", []))

    @jsii.member(jsii_name="toGetTransitGatewayPrefixListReferences")
    def to_get_transit_gateway_prefix_list_references(self) -> "Ec2":
        '''(experimental) Grants permission to get information about prefix list references for a transit gateway route table.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_GetTransitGatewayPrefixListReferences.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toGetTransitGatewayPrefixListReferences", []))

    @jsii.member(jsii_name="toGetTransitGatewayRouteTableAssociations")
    def to_get_transit_gateway_route_table_associations(self) -> "Ec2":
        '''(experimental) Grants permission to get information about associations for a transit gateway route table.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_GetTransitGatewayRouteTableAssociations.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toGetTransitGatewayRouteTableAssociations", []))

    @jsii.member(jsii_name="toGetTransitGatewayRouteTablePropagations")
    def to_get_transit_gateway_route_table_propagations(self) -> "Ec2":
        '''(experimental) Grants permission to get information about the route table propagations for a transit gateway route table.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_GetTransitGatewayRouteTablePropagations.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toGetTransitGatewayRouteTablePropagations", []))

    @jsii.member(jsii_name="toGetVerifiedAccessEndpointPolicy")
    def to_get_verified_access_endpoint_policy(self) -> "Ec2":
        '''(experimental) Grants permission to show the Verified Access policy associated with the endpoint.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_GetVerifiedAccessEndpointPolicy.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toGetVerifiedAccessEndpointPolicy", []))

    @jsii.member(jsii_name="toGetVerifiedAccessGroupPolicy")
    def to_get_verified_access_group_policy(self) -> "Ec2":
        '''(experimental) Grants permission to show the contents of the Verified Access policy associated with the group.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_GetVerifiedAccessGroupPolicy.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toGetVerifiedAccessGroupPolicy", []))

    @jsii.member(jsii_name="toGetVpnConnectionDeviceSampleConfiguration")
    def to_get_vpn_connection_device_sample_configuration(self) -> "Ec2":
        '''(experimental) Grants permission to download an AWS-provided sample configuration file to be used with the customer gateway device.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_GetVpnConnectionDeviceSampleConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toGetVpnConnectionDeviceSampleConfiguration", []))

    @jsii.member(jsii_name="toGetVpnConnectionDeviceTypes")
    def to_get_vpn_connection_device_types(self) -> "Ec2":
        '''(experimental) Grants permission to obtain a list of customer gateway devices for which sample configuration files can be provided.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_GetVpnConnectionDeviceTypes.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toGetVpnConnectionDeviceTypes", []))

    @jsii.member(jsii_name="toImportClientVpnClientCertificateRevocationList")
    def to_import_client_vpn_client_certificate_revocation_list(self) -> "Ec2":
        '''(experimental) Grants permission to upload a client certificate revocation list to a Client VPN endpoint.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ImportClientVpnClientCertificateRevocationList.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toImportClientVpnClientCertificateRevocationList", []))

    @jsii.member(jsii_name="toImportImage")
    def to_import_image(self) -> "Ec2":
        '''(experimental) Grants permission to import single or multi-volume disk images or EBS snapshots into an Amazon Machine Image (AMI).

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifRegion()

        Dependent actions:

        - ec2:CreateTags

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ImportImage.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toImportImage", []))

    @jsii.member(jsii_name="toImportInstance")
    def to_import_instance(self) -> "Ec2":
        '''(experimental) Grants permission to create an import instance task using metadata from a disk image.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ImportInstance.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toImportInstance", []))

    @jsii.member(jsii_name="toImportKeyPair")
    def to_import_key_pair(self) -> "Ec2":
        '''(experimental) Grants permission to import a public key from an RSA key pair that was created with a third-party tool.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifRegion()

        Dependent actions:

        - ec2:CreateTags

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ImportKeyPair.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toImportKeyPair", []))

    @jsii.member(jsii_name="toImportSnapshot")
    def to_import_snapshot(self) -> "Ec2":
        '''(experimental) Grants permission to import a disk into an EBS snapshot.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifRegion()

        Dependent actions:

        - ec2:CreateTags

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ImportSnapshot.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toImportSnapshot", []))

    @jsii.member(jsii_name="toImportVolume")
    def to_import_volume(self) -> "Ec2":
        '''(experimental) Grants permission to create an import volume task using metadata from a disk image.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ImportVolume.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toImportVolume", []))

    @jsii.member(jsii_name="toListImagesInRecycleBin")
    def to_list_images_in_recycle_bin(self) -> "Ec2":
        '''(experimental) Grants permission to list Amazon Machine Images (AMIs) that are currently in the Recycle Bin.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ListImagesInRecycleBin.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toListImagesInRecycleBin", []))

    @jsii.member(jsii_name="toListSnapshotsInRecycleBin")
    def to_list_snapshots_in_recycle_bin(self) -> "Ec2":
        '''(experimental) Grants permission to list the Amazon EBS snapshots that are currently in the Recycle Bin.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ListSnapshotsInRecycleBin.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toListSnapshotsInRecycleBin", []))

    @jsii.member(jsii_name="toModifyAddressAttribute")
    def to_modify_address_attribute(self) -> "Ec2":
        '''(experimental) Grants permission to modify an attribute of the specified Elastic IP address.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ModifyAddressAttribute.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toModifyAddressAttribute", []))

    @jsii.member(jsii_name="toModifyAvailabilityZoneGroup")
    def to_modify_availability_zone_group(self) -> "Ec2":
        '''(experimental) Grants permission to modify the opt-in status of the Local Zone and Wavelength Zone group for your account.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ModifyAvailabilityZoneGroup.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toModifyAvailabilityZoneGroup", []))

    @jsii.member(jsii_name="toModifyCapacityReservation")
    def to_modify_capacity_reservation(self) -> "Ec2":
        '''(experimental) Grants permission to modify a Capacity Reservation's capacity and the conditions under which it is to be released.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ModifyCapacityReservation.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toModifyCapacityReservation", []))

    @jsii.member(jsii_name="toModifyCapacityReservationFleet")
    def to_modify_capacity_reservation_fleet(self) -> "Ec2":
        '''(experimental) Grants permission to modify a Capacity Reservation Fleet.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ModifyCapacityReservationFleet.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toModifyCapacityReservationFleet", []))

    @jsii.member(jsii_name="toModifyClientVpnEndpoint")
    def to_modify_client_vpn_endpoint(self) -> "Ec2":
        '''(experimental) Grants permission to modify a Client VPN endpoint.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ModifyClientVpnEndpoint.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toModifyClientVpnEndpoint", []))

    @jsii.member(jsii_name="toModifyDefaultCreditSpecification")
    def to_modify_default_credit_specification(self) -> "Ec2":
        '''(experimental) Grants permission to change the account level default credit option for CPU usage of burstable performance instances.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ModifyDefaultCreditSpecification.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toModifyDefaultCreditSpecification", []))

    @jsii.member(jsii_name="toModifyEbsDefaultKmsKeyId")
    def to_modify_ebs_default_kms_key_id(self) -> "Ec2":
        '''(experimental) Grants permission to change the default customer master key (CMK) for EBS encryption by default for your account.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ModifyEbsDefaultKmsKeyId.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toModifyEbsDefaultKmsKeyId", []))

    @jsii.member(jsii_name="toModifyFleet")
    def to_modify_fleet(self) -> "Ec2":
        '''(experimental) Grants permission to modify an EC2 Fleet.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ModifyFleet.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toModifyFleet", []))

    @jsii.member(jsii_name="toModifyFpgaImageAttribute")
    def to_modify_fpga_image_attribute(self) -> "Ec2":
        '''(experimental) Grants permission to modify an attribute of an Amazon FPGA Image (AFI).

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ModifyFpgaImageAttribute.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toModifyFpgaImageAttribute", []))

    @jsii.member(jsii_name="toModifyHosts")
    def to_modify_hosts(self) -> "Ec2":
        '''(experimental) Grants permission to modify a Dedicated Host.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ModifyHosts.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toModifyHosts", []))

    @jsii.member(jsii_name="toModifyIdentityIdFormat")
    def to_modify_identity_id_format(self) -> "Ec2":
        '''(experimental) Grants permission to modify the ID format of a resource for a specific principal in your account.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ModifyIdentityIdFormat.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toModifyIdentityIdFormat", []))

    @jsii.member(jsii_name="toModifyIdFormat")
    def to_modify_id_format(self) -> "Ec2":
        '''(experimental) Grants permission to modify the ID format for a resource.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ModifyIdFormat.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toModifyIdFormat", []))

    @jsii.member(jsii_name="toModifyImageAttribute")
    def to_modify_image_attribute(self) -> "Ec2":
        '''(experimental) Grants permission to modify an attribute of an Amazon Machine Image (AMI).

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ModifyImageAttribute.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toModifyImageAttribute", []))

    @jsii.member(jsii_name="toModifyInstanceAttribute")
    def to_modify_instance_attribute(self) -> "Ec2":
        '''(experimental) Grants permission to modify an attribute of an instance.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ModifyInstanceAttribute.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toModifyInstanceAttribute", []))

    @jsii.member(jsii_name="toModifyInstanceCapacityReservationAttributes")
    def to_modify_instance_capacity_reservation_attributes(self) -> "Ec2":
        '''(experimental) Grants permission to modify the Capacity Reservation settings for a stopped instance.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ModifyInstanceCapacityReservationAttributes.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toModifyInstanceCapacityReservationAttributes", []))

    @jsii.member(jsii_name="toModifyInstanceCreditSpecification")
    def to_modify_instance_credit_specification(self) -> "Ec2":
        '''(experimental) Grants permission to modify the credit option for CPU usage on an instance.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ModifyInstanceCreditSpecification.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toModifyInstanceCreditSpecification", []))

    @jsii.member(jsii_name="toModifyInstanceEventStartTime")
    def to_modify_instance_event_start_time(self) -> "Ec2":
        '''(experimental) Grants permission to modify the start time for a scheduled EC2 instance event.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ModifyInstanceEventStartTime.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toModifyInstanceEventStartTime", []))

    @jsii.member(jsii_name="toModifyInstanceEventWindow")
    def to_modify_instance_event_window(self) -> "Ec2":
        '''(experimental) Grants permission to modify the specified event window.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ModifyInstanceEventWindow.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toModifyInstanceEventWindow", []))

    @jsii.member(jsii_name="toModifyInstanceMaintenanceOptions")
    def to_modify_instance_maintenance_options(self) -> "Ec2":
        '''(experimental) Grants permission to modify the recovery behaviour for an instance.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ModifyInstanceMaintenanceOptions.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toModifyInstanceMaintenanceOptions", []))

    @jsii.member(jsii_name="toModifyInstanceMetadataOptions")
    def to_modify_instance_metadata_options(self) -> "Ec2":
        '''(experimental) Grants permission to modify the metadata options for an instance.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ModifyInstanceMetadataOptions.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toModifyInstanceMetadataOptions", []))

    @jsii.member(jsii_name="toModifyInstancePlacement")
    def to_modify_instance_placement(self) -> "Ec2":
        '''(experimental) Grants permission to modify the placement attributes for an instance.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ModifyInstancePlacement.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toModifyInstancePlacement", []))

    @jsii.member(jsii_name="toModifyIpam")
    def to_modify_ipam(self) -> "Ec2":
        '''(experimental) Grants permission to modify the configurations of an Amazon VPC IP Address Manager (IPAM).

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ModifyIpam.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toModifyIpam", []))

    @jsii.member(jsii_name="toModifyIpamPool")
    def to_modify_ipam_pool(self) -> "Ec2":
        '''(experimental) Grants permission to modify the configurations of an Amazon VPC IP Address Manager (IPAM) pool.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ModifyIpamPool.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toModifyIpamPool", []))

    @jsii.member(jsii_name="toModifyIpamResourceCidr")
    def to_modify_ipam_resource_cidr(self) -> "Ec2":
        '''(experimental) Grants permission to modify the configurations of an Amazon VPC IP Address Manager (IPAM) resource CIDR.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ModifyIpamResourceCidr.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toModifyIpamResourceCidr", []))

    @jsii.member(jsii_name="toModifyIpamScope")
    def to_modify_ipam_scope(self) -> "Ec2":
        '''(experimental) Grants permission to modify the configurations of an Amazon VPC IP Address Manager (IPAM) scope.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ModifyIpamScope.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toModifyIpamScope", []))

    @jsii.member(jsii_name="toModifyLaunchTemplate")
    def to_modify_launch_template(self) -> "Ec2":
        '''(experimental) Grants permission to modify a launch template.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ModifyLaunchTemplate.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toModifyLaunchTemplate", []))

    @jsii.member(jsii_name="toModifyLocalGatewayRoute")
    def to_modify_local_gateway_route(self) -> "Ec2":
        '''(experimental) Grants permission to modify a local gateway route.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ModifyLocalGatewayRoute.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toModifyLocalGatewayRoute", []))

    @jsii.member(jsii_name="toModifyManagedPrefixList")
    def to_modify_managed_prefix_list(self) -> "Ec2":
        '''(experimental) Grants permission to modify a managed prefix list.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ModifyManagedPrefixList.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toModifyManagedPrefixList", []))

    @jsii.member(jsii_name="toModifyNetworkInterfaceAttribute")
    def to_modify_network_interface_attribute(self) -> "Ec2":
        '''(experimental) Grants permission to modify an attribute of a network interface.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ModifyNetworkInterfaceAttribute.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toModifyNetworkInterfaceAttribute", []))

    @jsii.member(jsii_name="toModifyPrivateDnsNameOptions")
    def to_modify_private_dns_name_options(self) -> "Ec2":
        '''(experimental) Grants permission to modify the options for instance hostnames for the specified instance.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ModifyPrivateDnsNameOptions.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toModifyPrivateDnsNameOptions", []))

    @jsii.member(jsii_name="toModifyReservedInstances")
    def to_modify_reserved_instances(self) -> "Ec2":
        '''(experimental) Grants permission to modify attributes of one or more Reserved Instances.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ModifyReservedInstances.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toModifyReservedInstances", []))

    @jsii.member(jsii_name="toModifySecurityGroupRules")
    def to_modify_security_group_rules(self) -> "Ec2":
        '''(experimental) Grants permission to modify the rules of a security group.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ModifySecurityGroupRules.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toModifySecurityGroupRules", []))

    @jsii.member(jsii_name="toModifySnapshotAttribute")
    def to_modify_snapshot_attribute(self) -> "Ec2":
        '''(experimental) Grants permission to add or remove permission settings for a snapshot.

        Access Level: Permissions management

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ModifySnapshotAttribute.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toModifySnapshotAttribute", []))

    @jsii.member(jsii_name="toModifySnapshotTier")
    def to_modify_snapshot_tier(self) -> "Ec2":
        '''(experimental) Grants permission to archive Amazon EBS snapshots.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ModifySnapshotTier.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toModifySnapshotTier", []))

    @jsii.member(jsii_name="toModifySpotFleetRequest")
    def to_modify_spot_fleet_request(self) -> "Ec2":
        '''(experimental) Grants permission to modify a Spot Fleet request.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ModifySpotFleetRequest.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toModifySpotFleetRequest", []))

    @jsii.member(jsii_name="toModifySubnetAttribute")
    def to_modify_subnet_attribute(self) -> "Ec2":
        '''(experimental) Grants permission to modify an attribute of a subnet.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ModifySubnetAttribute.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toModifySubnetAttribute", []))

    @jsii.member(jsii_name="toModifyTrafficMirrorFilterNetworkServices")
    def to_modify_traffic_mirror_filter_network_services(self) -> "Ec2":
        '''(experimental) Grants permission to allow or restrict mirroring network services.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ModifyTrafficMirrorFilterNetworkServices.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toModifyTrafficMirrorFilterNetworkServices", []))

    @jsii.member(jsii_name="toModifyTrafficMirrorFilterRule")
    def to_modify_traffic_mirror_filter_rule(self) -> "Ec2":
        '''(experimental) Grants permission to modify a traffic mirror rule.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ModifyTrafficMirrorFilterRule.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toModifyTrafficMirrorFilterRule", []))

    @jsii.member(jsii_name="toModifyTrafficMirrorSession")
    def to_modify_traffic_mirror_session(self) -> "Ec2":
        '''(experimental) Grants permission to modify a traffic mirror session.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ModifyTrafficMirrorSession.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toModifyTrafficMirrorSession", []))

    @jsii.member(jsii_name="toModifyTransitGateway")
    def to_modify_transit_gateway(self) -> "Ec2":
        '''(experimental) Grants permission to modify a transit gateway.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ModifyTransitGateway.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toModifyTransitGateway", []))

    @jsii.member(jsii_name="toModifyTransitGatewayPrefixListReference")
    def to_modify_transit_gateway_prefix_list_reference(self) -> "Ec2":
        '''(experimental) Grants permission to modify a transit gateway prefix list reference.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ModifyTransitGatewayPrefixListReference.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toModifyTransitGatewayPrefixListReference", []))

    @jsii.member(jsii_name="toModifyTransitGatewayVpcAttachment")
    def to_modify_transit_gateway_vpc_attachment(self) -> "Ec2":
        '''(experimental) Grants permission to modify a VPC attachment on a transit gateway.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ModifyTransitGatewayVpcAttachment.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toModifyTransitGatewayVpcAttachment", []))

    @jsii.member(jsii_name="toModifyVerifiedAccessEndpoint")
    def to_modify_verified_access_endpoint(self) -> "Ec2":
        '''(experimental) Grants permission to modify the configuration of a Verified Access endpoint.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ModifyVerifiedAccessEndpoint.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toModifyVerifiedAccessEndpoint", []))

    @jsii.member(jsii_name="toModifyVerifiedAccessEndpointPolicy")
    def to_modify_verified_access_endpoint_policy(self) -> "Ec2":
        '''(experimental) Grants permission to modify the specified Verified Access endpoint policy.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ModifyVerifiedAccessEndpointPolicy.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toModifyVerifiedAccessEndpointPolicy", []))

    @jsii.member(jsii_name="toModifyVerifiedAccessGroup")
    def to_modify_verified_access_group(self) -> "Ec2":
        '''(experimental) Grants permission to modify the specified Verified Access Group configuration.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ModifyVerifiedAccessGroup.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toModifyVerifiedAccessGroup", []))

    @jsii.member(jsii_name="toModifyVerifiedAccessGroupPolicy")
    def to_modify_verified_access_group_policy(self) -> "Ec2":
        '''(experimental) Grants permission to modify the specified Verified Access group policy.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ModifyVerifiedAccessGroupPolicy.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toModifyVerifiedAccessGroupPolicy", []))

    @jsii.member(jsii_name="toModifyVerifiedAccessInstance")
    def to_modify_verified_access_instance(self) -> "Ec2":
        '''(experimental) Grants permission to modify the configuration of the specified Verified Access instance.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ModifyVerifiedAccessInstance.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toModifyVerifiedAccessInstance", []))

    @jsii.member(jsii_name="toModifyVerifiedAccessInstanceLoggingConfiguration")
    def to_modify_verified_access_instance_logging_configuration(self) -> "Ec2":
        '''(experimental) Grants permission to modify the logging configuration for the specified Verified Access instance.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ModifyVerifiedAccessInstanceLoggingConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toModifyVerifiedAccessInstanceLoggingConfiguration", []))

    @jsii.member(jsii_name="toModifyVerifiedAccessTrustProvider")
    def to_modify_verified_access_trust_provider(self) -> "Ec2":
        '''(experimental) Grants permission to modify the configuration of the specified Verified Access trust provider.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ModifyVerifiedAccessTrustProvider.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toModifyVerifiedAccessTrustProvider", []))

    @jsii.member(jsii_name="toModifyVolume")
    def to_modify_volume(self) -> "Ec2":
        '''(experimental) Grants permission to modify the parameters of an EBS volume.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ModifyVolume.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toModifyVolume", []))

    @jsii.member(jsii_name="toModifyVolumeAttribute")
    def to_modify_volume_attribute(self) -> "Ec2":
        '''(experimental) Grants permission to modify an attribute of a volume.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ModifyVolumeAttribute.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toModifyVolumeAttribute", []))

    @jsii.member(jsii_name="toModifyVpcAttribute")
    def to_modify_vpc_attribute(self) -> "Ec2":
        '''(experimental) Grants permission to modify an attribute of a VPC.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ModifyVpcAttribute.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toModifyVpcAttribute", []))

    @jsii.member(jsii_name="toModifyVpcEndpoint")
    def to_modify_vpc_endpoint(self) -> "Ec2":
        '''(experimental) Grants permission to modify an attribute of a VPC endpoint.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ModifyVpcEndpoint.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toModifyVpcEndpoint", []))

    @jsii.member(jsii_name="toModifyVpcEndpointConnectionNotification")
    def to_modify_vpc_endpoint_connection_notification(self) -> "Ec2":
        '''(experimental) Grants permission to modify a connection notification for a VPC endpoint or VPC endpoint service.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ModifyVpcEndpointConnectionNotification.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toModifyVpcEndpointConnectionNotification", []))

    @jsii.member(jsii_name="toModifyVpcEndpointServiceConfiguration")
    def to_modify_vpc_endpoint_service_configuration(self) -> "Ec2":
        '''(experimental) Grants permission to modify the attributes of a VPC endpoint service configuration.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ModifyVpcEndpointServiceConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toModifyVpcEndpointServiceConfiguration", []))

    @jsii.member(jsii_name="toModifyVpcEndpointServicePayerResponsibility")
    def to_modify_vpc_endpoint_service_payer_responsibility(self) -> "Ec2":
        '''(experimental) Grants permission to modify the payer responsibility for a VPC endpoint service.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ModifyVpcEndpointServicePayerResponsibility.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toModifyVpcEndpointServicePayerResponsibility", []))

    @jsii.member(jsii_name="toModifyVpcEndpointServicePermissions")
    def to_modify_vpc_endpoint_service_permissions(self) -> "Ec2":
        '''(experimental) Grants permission to modify the permissions for a VPC endpoint service.

        Access Level: Permissions management

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ModifyVpcEndpointServicePermissions.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toModifyVpcEndpointServicePermissions", []))

    @jsii.member(jsii_name="toModifyVpcPeeringConnectionOptions")
    def to_modify_vpc_peering_connection_options(self) -> "Ec2":
        '''(experimental) Grants permission to modify the VPC peering connection options on one side of a VPC peering connection.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ModifyVpcPeeringConnectionOptions.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toModifyVpcPeeringConnectionOptions", []))

    @jsii.member(jsii_name="toModifyVpcTenancy")
    def to_modify_vpc_tenancy(self) -> "Ec2":
        '''(experimental) Grants permission to modify the instance tenancy attribute of a VPC.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ModifyVpcTenancy.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toModifyVpcTenancy", []))

    @jsii.member(jsii_name="toModifyVpnConnection")
    def to_modify_vpn_connection(self) -> "Ec2":
        '''(experimental) Grants permission to modify the target gateway of a Site-to-Site VPN connection.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ModifyVpnConnection.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toModifyVpnConnection", []))

    @jsii.member(jsii_name="toModifyVpnConnectionOptions")
    def to_modify_vpn_connection_options(self) -> "Ec2":
        '''(experimental) Grants permission to modify the connection options for your Site-to-Site VPN connection.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ModifyVpnConnectionOptions.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toModifyVpnConnectionOptions", []))

    @jsii.member(jsii_name="toModifyVpnTunnelCertificate")
    def to_modify_vpn_tunnel_certificate(self) -> "Ec2":
        '''(experimental) Grants permission to modify the certificate for a Site-to-Site VPN connection.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ModifyVpnTunnelCertificate.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toModifyVpnTunnelCertificate", []))

    @jsii.member(jsii_name="toModifyVpnTunnelOptions")
    def to_modify_vpn_tunnel_options(self) -> "Ec2":
        '''(experimental) Grants permission to modify the options for a Site-to-Site VPN connection.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ModifyVpnTunnelOptions.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toModifyVpnTunnelOptions", []))

    @jsii.member(jsii_name="toMonitorInstances")
    def to_monitor_instances(self) -> "Ec2":
        '''(experimental) Grants permission to enable detailed monitoring for a running instance.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_MonitorInstances.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toMonitorInstances", []))

    @jsii.member(jsii_name="toMoveAddressToVpc")
    def to_move_address_to_vpc(self) -> "Ec2":
        '''(experimental) Grants permission to move an Elastic IP address from the EC2-Classic platform to the EC2-VPC platform.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_MoveAddressToVpc.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toMoveAddressToVpc", []))

    @jsii.member(jsii_name="toMoveByoipCidrToIpam")
    def to_move_byoip_cidr_to_ipam(self) -> "Ec2":
        '''(experimental) Grants permission to move a BYOIP IPv4 CIDR to Amazon VPC IP Address Manager (IPAM) from a public IPv4 pool.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_MoveByoipCidrToIpam.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toMoveByoipCidrToIpam", []))

    @jsii.member(jsii_name="toProvisionByoipCidr")
    def to_provision_byoip_cidr(self) -> "Ec2":
        '''(experimental) Grants permission to provision an address range for use in AWS through bring your own IP addresses (BYOIP), and to create a corresponding address pool.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ProvisionByoipCidr.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toProvisionByoipCidr", []))

    @jsii.member(jsii_name="toProvisionIpamPoolCidr")
    def to_provision_ipam_pool_cidr(self) -> "Ec2":
        '''(experimental) Grants permission to provision a CIDR to an Amazon VPC IP Address Manager (IPAM) pool.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ProvisionIpamPoolCidr.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toProvisionIpamPoolCidr", []))

    @jsii.member(jsii_name="toProvisionPublicIpv4PoolCidr")
    def to_provision_public_ipv4_pool_cidr(self) -> "Ec2":
        '''(experimental) Grants permission to provision a CIDR to a public IPv4 pool.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ProvisionPublicIpv4PoolCidr.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toProvisionPublicIpv4PoolCidr", []))

    @jsii.member(jsii_name="toPurchaseHostReservation")
    def to_purchase_host_reservation(self) -> "Ec2":
        '''(experimental) Grants permission to purchase a reservation with configurations that match those of a Dedicated Host.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        Dependent actions:

        - ec2:CreateTags

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_PurchaseHostReservation.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toPurchaseHostReservation", []))

    @jsii.member(jsii_name="toPurchaseReservedInstancesOffering")
    def to_purchase_reserved_instances_offering(self) -> "Ec2":
        '''(experimental) Grants permission to purchase a Reserved Instance offering.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_PurchaseReservedInstancesOffering.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toPurchaseReservedInstancesOffering", []))

    @jsii.member(jsii_name="toPurchaseScheduledInstances")
    def to_purchase_scheduled_instances(self) -> "Ec2":
        '''(experimental) Grants permission to purchase one or more Scheduled Instances with a specified schedule.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_PurchaseScheduledInstances.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toPurchaseScheduledInstances", []))

    @jsii.member(jsii_name="toPutResourcePolicy")
    def to_put_resource_policy(self) -> "Ec2":
        '''(experimental) Grants permission to attach an IAM policy that enables cross-account sharing to a resource.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/vpc/latest/ipam/share-pool-ipam.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toPutResourcePolicy", []))

    @jsii.member(jsii_name="toRebootInstances")
    def to_reboot_instances(self) -> "Ec2":
        '''(experimental) Grants permission to request a reboot of one or more instances.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_RebootInstances.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toRebootInstances", []))

    @jsii.member(jsii_name="toRegisterImage")
    def to_register_image(self) -> "Ec2":
        '''(experimental) Grants permission to register an Amazon Machine Image (AMI).

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_RegisterImage.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toRegisterImage", []))

    @jsii.member(jsii_name="toRegisterInstanceEventNotificationAttributes")
    def to_register_instance_event_notification_attributes(self) -> "Ec2":
        '''(experimental) Grants permission to add tags to the set of tags to include in notifications about scheduled events for your instances.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_RegisterInstanceEventNotificationAttributes.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toRegisterInstanceEventNotificationAttributes", []))

    @jsii.member(jsii_name="toRegisterTransitGatewayMulticastGroupMembers")
    def to_register_transit_gateway_multicast_group_members(self) -> "Ec2":
        '''(experimental) Grants permission to register one or more network interfaces as a member of a group IP address in a transit gateway multicast domain.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_RegisterTransitGatewayMulticastGroupMembers.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toRegisterTransitGatewayMulticastGroupMembers", []))

    @jsii.member(jsii_name="toRegisterTransitGatewayMulticastGroupSources")
    def to_register_transit_gateway_multicast_group_sources(self) -> "Ec2":
        '''(experimental) Grants permission to register one or more network interfaces as a source of a group IP address in a transit gateway multicast domain.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_RegisterTransitGatewayMulticastGroupSources.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toRegisterTransitGatewayMulticastGroupSources", []))

    @jsii.member(jsii_name="toRejectTransitGatewayMulticastDomainAssociations")
    def to_reject_transit_gateway_multicast_domain_associations(self) -> "Ec2":
        '''(experimental) Grants permission to reject requests to associate cross-account subnets with a transit gateway multicast domain.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_RejectTransitGatewayMulticastDomainAssociations.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toRejectTransitGatewayMulticastDomainAssociations", []))

    @jsii.member(jsii_name="toRejectTransitGatewayPeeringAttachment")
    def to_reject_transit_gateway_peering_attachment(self) -> "Ec2":
        '''(experimental) Grants permission to reject a transit gateway peering attachment request.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_RejectTransitGatewayPeeringAttachment.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toRejectTransitGatewayPeeringAttachment", []))

    @jsii.member(jsii_name="toRejectTransitGatewayVpcAttachment")
    def to_reject_transit_gateway_vpc_attachment(self) -> "Ec2":
        '''(experimental) Grants permission to reject a request to attach a VPC to a transit gateway.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_RejectTransitGatewayVpcAttachment.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toRejectTransitGatewayVpcAttachment", []))

    @jsii.member(jsii_name="toRejectVpcEndpointConnections")
    def to_reject_vpc_endpoint_connections(self) -> "Ec2":
        '''(experimental) Grants permission to reject one or more VPC endpoint connection requests to a VPC endpoint service.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_RejectVpcEndpointConnections.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toRejectVpcEndpointConnections", []))

    @jsii.member(jsii_name="toRejectVpcPeeringConnection")
    def to_reject_vpc_peering_connection(self) -> "Ec2":
        '''(experimental) Grants permission to reject a VPC peering connection request.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_RejectVpcPeeringConnection.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toRejectVpcPeeringConnection", []))

    @jsii.member(jsii_name="toReleaseAddress")
    def to_release_address(self) -> "Ec2":
        '''(experimental) Grants permission to release an Elastic IP address.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ReleaseAddress.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toReleaseAddress", []))

    @jsii.member(jsii_name="toReleaseHosts")
    def to_release_hosts(self) -> "Ec2":
        '''(experimental) Grants permission to release one or more On-Demand Dedicated Hosts.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ReleaseHosts.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toReleaseHosts", []))

    @jsii.member(jsii_name="toReleaseIpamPoolAllocation")
    def to_release_ipam_pool_allocation(self) -> "Ec2":
        '''(experimental) Grants permission to release an allocation within an Amazon VPC IP Address Manager (IPAM) pool.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ReleaseIpamPoolAllocation.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toReleaseIpamPoolAllocation", []))

    @jsii.member(jsii_name="toReplaceIamInstanceProfileAssociation")
    def to_replace_iam_instance_profile_association(self) -> "Ec2":
        '''(experimental) Grants permission to replace an IAM instance profile for an instance.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        Dependent actions:

        - iam:PassRole

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ReplaceIamInstanceProfileAssociation.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toReplaceIamInstanceProfileAssociation", []))

    @jsii.member(jsii_name="toReplaceNetworkAclAssociation")
    def to_replace_network_acl_association(self) -> "Ec2":
        '''(experimental) Grants permission to change which network ACL a subnet is associated with.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ReplaceNetworkAclAssociation.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toReplaceNetworkAclAssociation", []))

    @jsii.member(jsii_name="toReplaceNetworkAclEntry")
    def to_replace_network_acl_entry(self) -> "Ec2":
        '''(experimental) Grants permission to replace an entry (rule) in a network ACL.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ReplaceNetworkAclEntry.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toReplaceNetworkAclEntry", []))

    @jsii.member(jsii_name="toReplaceRoute")
    def to_replace_route(self) -> "Ec2":
        '''(experimental) Grants permission to replace a route within a route table in a VPC.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ReplaceRoute.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toReplaceRoute", []))

    @jsii.member(jsii_name="toReplaceRouteTableAssociation")
    def to_replace_route_table_association(self) -> "Ec2":
        '''(experimental) Grants permission to change the route table that is associated with a subnet.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ReplaceRouteTableAssociation.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toReplaceRouteTableAssociation", []))

    @jsii.member(jsii_name="toReplaceTransitGatewayRoute")
    def to_replace_transit_gateway_route(self) -> "Ec2":
        '''(experimental) Grants permission to replace a route in a transit gateway route table.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ReplaceTransitGatewayRoute.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toReplaceTransitGatewayRoute", []))

    @jsii.member(jsii_name="toReportInstanceStatus")
    def to_report_instance_status(self) -> "Ec2":
        '''(experimental) Grants permission to submit feedback about the status of an instance.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ReportInstanceStatus.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toReportInstanceStatus", []))

    @jsii.member(jsii_name="toRequestSpotFleet")
    def to_request_spot_fleet(self) -> "Ec2":
        '''(experimental) Grants permission to create a Spot Fleet request.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_RequestSpotFleet.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toRequestSpotFleet", []))

    @jsii.member(jsii_name="toRequestSpotInstances")
    def to_request_spot_instances(self) -> "Ec2":
        '''(experimental) Grants permission to create a Spot Instance request.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifRegion()

        Dependent actions:

        - ec2:CreateTags

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_RequestSpotInstances.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toRequestSpotInstances", []))

    @jsii.member(jsii_name="toResetAddressAttribute")
    def to_reset_address_attribute(self) -> "Ec2":
        '''(experimental) Grants permission to reset the attribute of the specified IP address.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ResetAddressAttribute.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toResetAddressAttribute", []))

    @jsii.member(jsii_name="toResetEbsDefaultKmsKeyId")
    def to_reset_ebs_default_kms_key_id(self) -> "Ec2":
        '''(experimental) Grants permission to reset the default customer master key (CMK) for EBS encryption for your account to use the AWS-managed CMK for EBS.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ResetEbsDefaultKmsKeyId.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toResetEbsDefaultKmsKeyId", []))

    @jsii.member(jsii_name="toResetFpgaImageAttribute")
    def to_reset_fpga_image_attribute(self) -> "Ec2":
        '''(experimental) Grants permission to reset an attribute of an Amazon FPGA Image (AFI) to its default value.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ResetFpgaImageAttribute.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toResetFpgaImageAttribute", []))

    @jsii.member(jsii_name="toResetImageAttribute")
    def to_reset_image_attribute(self) -> "Ec2":
        '''(experimental) Grants permission to reset an attribute of an Amazon Machine Image (AMI) to its default value.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ResetImageAttribute.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toResetImageAttribute", []))

    @jsii.member(jsii_name="toResetInstanceAttribute")
    def to_reset_instance_attribute(self) -> "Ec2":
        '''(experimental) Grants permission to reset an attribute of an instance to its default value.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ResetInstanceAttribute.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toResetInstanceAttribute", []))

    @jsii.member(jsii_name="toResetNetworkInterfaceAttribute")
    def to_reset_network_interface_attribute(self) -> "Ec2":
        '''(experimental) Grants permission to reset an attribute of a network interface.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ResetNetworkInterfaceAttribute.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toResetNetworkInterfaceAttribute", []))

    @jsii.member(jsii_name="toResetSnapshotAttribute")
    def to_reset_snapshot_attribute(self) -> "Ec2":
        '''(experimental) Grants permission to reset permission settings for a snapshot.

        Access Level: Permissions management

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ResetSnapshotAttribute.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toResetSnapshotAttribute", []))

    @jsii.member(jsii_name="toRestoreAddressToClassic")
    def to_restore_address_to_classic(self) -> "Ec2":
        '''(experimental) Grants permission to restore an Elastic IP address that was previously moved to the EC2-VPC platform back to the EC2-Classic platform.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_RestoreAddressToClassic.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toRestoreAddressToClassic", []))

    @jsii.member(jsii_name="toRestoreImageFromRecycleBin")
    def to_restore_image_from_recycle_bin(self) -> "Ec2":
        '''(experimental) Grants permission to restore an Amazon Machine Image (AMI) from the Recycle Bin.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_RestoreImageFromRecycleBin.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toRestoreImageFromRecycleBin", []))

    @jsii.member(jsii_name="toRestoreManagedPrefixListVersion")
    def to_restore_managed_prefix_list_version(self) -> "Ec2":
        '''(experimental) Grants permission to restore the entries from a previous version of a managed prefix list to a new version of the prefix list.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_RestoreManagedPrefixListVersion.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toRestoreManagedPrefixListVersion", []))

    @jsii.member(jsii_name="toRestoreSnapshotFromRecycleBin")
    def to_restore_snapshot_from_recycle_bin(self) -> "Ec2":
        '''(experimental) Grants permission to restore an Amazon EBS snapshot from the Recycle Bin.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_RestoreSnapshotFromRecycleBin.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toRestoreSnapshotFromRecycleBin", []))

    @jsii.member(jsii_name="toRestoreSnapshotTier")
    def to_restore_snapshot_tier(self) -> "Ec2":
        '''(experimental) Grants permission to restore an archived Amazon EBS snapshot for use temporarily or permanently, or modify the restore period or restore type for a snapshot that was previously temporarily restored.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_RestoreSnapshotTier.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toRestoreSnapshotTier", []))

    @jsii.member(jsii_name="toRevokeClientVpnIngress")
    def to_revoke_client_vpn_ingress(self) -> "Ec2":
        '''(experimental) Grants permission to remove an inbound authorization rule from a Client VPN endpoint.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_RevokeClientVpnIngress.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toRevokeClientVpnIngress", []))

    @jsii.member(jsii_name="toRevokeSecurityGroupEgress")
    def to_revoke_security_group_egress(self) -> "Ec2":
        '''(experimental) Grants permission to remove one or more outbound rules from a VPC security group.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_RevokeSecurityGroupEgress.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toRevokeSecurityGroupEgress", []))

    @jsii.member(jsii_name="toRevokeSecurityGroupIngress")
    def to_revoke_security_group_ingress(self) -> "Ec2":
        '''(experimental) Grants permission to remove one or more inbound rules from a security group.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_RevokeSecurityGroupIngress.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toRevokeSecurityGroupIngress", []))

    @jsii.member(jsii_name="toRunInstances")
    def to_run_instances(self) -> "Ec2":
        '''(experimental) Grants permission to launch one or more instances.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifRegion()

        Dependent actions:

        - ec2:CreateTags

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_RunInstances.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toRunInstances", []))

    @jsii.member(jsii_name="toRunScheduledInstances")
    def to_run_scheduled_instances(self) -> "Ec2":
        '''(experimental) Grants permission to launch one or more Scheduled Instances.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_RunScheduledInstances.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toRunScheduledInstances", []))

    @jsii.member(jsii_name="toSearchLocalGatewayRoutes")
    def to_search_local_gateway_routes(self) -> "Ec2":
        '''(experimental) Grants permission to search for routes in a local gateway route table.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_SearchLocalGatewayRoutes.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toSearchLocalGatewayRoutes", []))

    @jsii.member(jsii_name="toSearchTransitGatewayMulticastGroups")
    def to_search_transit_gateway_multicast_groups(self) -> "Ec2":
        '''(experimental) Grants permission to search for groups, sources, and members in a transit gateway multicast domain.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_SearchTransitGatewayMulticastGroups.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toSearchTransitGatewayMulticastGroups", []))

    @jsii.member(jsii_name="toSearchTransitGatewayRoutes")
    def to_search_transit_gateway_routes(self) -> "Ec2":
        '''(experimental) Grants permission to search for routes in a transit gateway route table.

        Access Level: List

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_SearchTransitGatewayRoutes.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toSearchTransitGatewayRoutes", []))

    @jsii.member(jsii_name="toSendDiagnosticInterrupt")
    def to_send_diagnostic_interrupt(self) -> "Ec2":
        '''(experimental) Grants permission to send a diagnostic interrupt to an Amazon EC2 instance.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_SendDiagnosticInterrupt.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toSendDiagnosticInterrupt", []))

    @jsii.member(jsii_name="toSendSpotInstanceInterruptions")
    def to_send_spot_instance_interruptions(self) -> "Ec2":
        '''(experimental) Grants permission to interrupt a Spot Instance.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/fis/latest/userguide/fis-actions-reference.html#send-spot-instance-interruptions

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toSendSpotInstanceInterruptions", []))

    @jsii.member(jsii_name="toStartInstances")
    def to_start_instances(self) -> "Ec2":
        '''(experimental) Grants permission to start a stopped instance.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_StartInstances.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toStartInstances", []))

    @jsii.member(jsii_name="toStartNetworkInsightsAccessScopeAnalysis")
    def to_start_network_insights_access_scope_analysis(self) -> "Ec2":
        '''(experimental) Grants permission to start a Network Access Scope analysis.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifRegion()

        Dependent actions:

        - ec2:CreateTags

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_StartNetworkInsightsAccessScopeAnalysis.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toStartNetworkInsightsAccessScopeAnalysis", []))

    @jsii.member(jsii_name="toStartNetworkInsightsAnalysis")
    def to_start_network_insights_analysis(self) -> "Ec2":
        '''(experimental) Grants permission to start analyzing a specified path.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifRegion()

        Dependent actions:

        - ec2:CreateTags

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_StartNetworkInsightsAnalysis.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toStartNetworkInsightsAnalysis", []))

    @jsii.member(jsii_name="toStartVpcEndpointServicePrivateDnsVerification")
    def to_start_vpc_endpoint_service_private_dns_verification(self) -> "Ec2":
        '''(experimental) Grants permission to start the private DNS verification process for a VPC endpoint service.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_StartVpcEndpointServicePrivateDnsVerification.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toStartVpcEndpointServicePrivateDnsVerification", []))

    @jsii.member(jsii_name="toStopInstances")
    def to_stop_instances(self) -> "Ec2":
        '''(experimental) Grants permission to stop an Amazon EBS-backed instance.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_StopInstances.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toStopInstances", []))

    @jsii.member(jsii_name="toTerminateClientVpnConnections")
    def to_terminate_client_vpn_connections(self) -> "Ec2":
        '''(experimental) Grants permission to terminate active Client VPN endpoint connections.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_TerminateClientVpnConnections.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toTerminateClientVpnConnections", []))

    @jsii.member(jsii_name="toTerminateInstances")
    def to_terminate_instances(self) -> "Ec2":
        '''(experimental) Grants permission to shut down one or more instances.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_TerminateInstances.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toTerminateInstances", []))

    @jsii.member(jsii_name="toUnassignIpv6Addresses")
    def to_unassign_ipv6_addresses(self) -> "Ec2":
        '''(experimental) Grants permission to unassign one or more IPv6 addresses from a network interface.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_UnassignIpv6Addresses.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toUnassignIpv6Addresses", []))

    @jsii.member(jsii_name="toUnassignPrivateIpAddresses")
    def to_unassign_private_ip_addresses(self) -> "Ec2":
        '''(experimental) Grants permission to unassign one or more secondary private IP addresses from a network interface.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_UnassignPrivateIpAddresses.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toUnassignPrivateIpAddresses", []))

    @jsii.member(jsii_name="toUnmonitorInstances")
    def to_unmonitor_instances(self) -> "Ec2":
        '''(experimental) Grants permission to disable detailed monitoring for a running instance.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_UnmonitorInstances.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toUnmonitorInstances", []))

    @jsii.member(jsii_name="toUpdateSecurityGroupRuleDescriptionsEgress")
    def to_update_security_group_rule_descriptions_egress(self) -> "Ec2":
        '''(experimental) Grants permission to update descriptions for one or more outbound rules in a VPC security group.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_UpdateSecurityGroupRuleDescriptionsEgress.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toUpdateSecurityGroupRuleDescriptionsEgress", []))

    @jsii.member(jsii_name="toUpdateSecurityGroupRuleDescriptionsIngress")
    def to_update_security_group_rule_descriptions_ingress(self) -> "Ec2":
        '''(experimental) Grants permission to update descriptions for one or more inbound rules in a security group.

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_UpdateSecurityGroupRuleDescriptionsIngress.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toUpdateSecurityGroupRuleDescriptionsIngress", []))

    @jsii.member(jsii_name="toWithdrawByoipCidr")
    def to_withdraw_byoip_cidr(self) -> "Ec2":
        '''(experimental) Grants permission to stop advertising an address range that was provisioned for use in AWS through bring your own IP addresses (BYOIP).

        Access Level: Write

        Possible conditions:

        - .ifRegion()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_WithdrawByoipCidr.html

        :stability: experimental
        '''
        return typing.cast("Ec2", jsii.invoke(self, "toWithdrawByoipCidr", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__934037fbaa163c3c48b4e6312318ea22d6db7bcc004feb143ab3b2f17f47dd71)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f426f94791b9de3a14746d9cd30b4d4c64ad648a8f5c46eb2e87e5cdbf5a4da1)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Ec2InstanceConnect(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Ec2InstanceConnect",
):
    '''(experimental) Statement provider for service `ec2-instance-connect <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonec2instanceconnect.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `ec2-instance-connect <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonec2instanceconnect.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="ifEc2Osuser")
    def if_ec2_osuser(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Ec2InstanceConnect":
        '''(experimental) Filters access by specifying the default user name for the AMI that you used to launch your instance.

        https://docs.aws.amazon.com/ec2-instance-connect/latest/APIReference/API_SendSSHPublicKey.html

        Applies to actions:

        - .toSendSSHPublicKey()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__eae3ac954eb3390081bbae9f93a5e468e81e10bd4ec969617cb96001197c3a02)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Ec2InstanceConnect", jsii.invoke(self, "ifEc2Osuser", [value, operator]))

    @jsii.member(jsii_name="ifEc2ResourceTag")
    def if_ec2_resource_tag(
        self,
        tag_key: builtins.str,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Ec2InstanceConnect":
        '''(experimental) Filters access based on the tags associated with the resource.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_condition-keys.html#condition-keys-resourcetag

        Applies to resource types:

        - instance

        :param tag_key: The tag key to check.
        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1e3017e2027eeb0ecb935ececd4d2e36dc82d42dc7eb0839c55f8076c4988da3)
            check_type(argname="argument tag_key", value=tag_key, expected_type=type_hints["tag_key"])
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Ec2InstanceConnect", jsii.invoke(self, "ifEc2ResourceTag", [tag_key, value, operator]))

    @jsii.member(jsii_name="onInstance")
    def on_instance(
        self,
        instance_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Ec2InstanceConnect":
        '''(experimental) Adds a resource of type instance to the statement.

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/iam-policy-structure.html#EC2_ARN_Format

        :param instance_id: - Identifier for the instanceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag() - .ifEc2ResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__daf41b792ad9ae13292e3de0339a494a3815190867eac3a953b6a9a9e2d0d9a2)
            check_type(argname="argument instance_id", value=instance_id, expected_type=type_hints["instance_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Ec2InstanceConnect", jsii.invoke(self, "onInstance", [instance_id, account, region, partition]))

    @jsii.member(jsii_name="toSendSerialConsoleSSHPublicKey")
    def to_send_serial_console_ssh_public_key(self) -> "Ec2InstanceConnect":
        '''(experimental) Grants access to push an SSH public key to the specified EC2 instance to be used for serial console SSH.

        Access Level: Write

        https://docs.aws.amazon.com/ec2-instance-connect/latest/APIReference/API_SendSerialConsoleSSHPublicKey.html

        :stability: experimental
        '''
        return typing.cast("Ec2InstanceConnect", jsii.invoke(self, "toSendSerialConsoleSSHPublicKey", []))

    @jsii.member(jsii_name="toSendSSHPublicKey")
    def to_send_ssh_public_key(self) -> "Ec2InstanceConnect":
        '''(experimental) Grants access to push an SSH public key to the specified EC2 instance to be used for standard SSH.

        Access Level: Write

        Possible conditions:

        - .ifEc2Osuser()

        https://docs.aws.amazon.com/ec2-instance-connect/latest/APIReference/API_SendSSHPublicKey.html

        :stability: experimental
        '''
        return typing.cast("Ec2InstanceConnect", jsii.invoke(self, "toSendSSHPublicKey", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__33fe7fe208ff1bd6aefb43f8171995f5483ea9819beed597af82f225fd40e608)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8c386bae476d9f891da573d9700636fc8e06b6900b89662385f7117551223a23)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Ec2messages(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Ec2messages",
):
    '''(experimental) Statement provider for service `ec2messages <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonmessagedeliveryservice.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `ec2messages <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonmessagedeliveryservice.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="ifSsmSourceInstanceARN")
    def if_ssm_source_instance_arn(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Ec2messages":
        '''(experimental) Filters access by verifying the Amazon Resource Name (ARN) of the AWS Systems Manager's managed instance from which the request is made.

        This key is not present when the request comes from the managed instance authenticated with an IAM role associated with EC2 instance profile

        https://docs.aws.amazon.com/service-authorization/latest/reference/list_awssystemsmanager.html#awssystemsmanager-policy-keys

        Applies to actions:

        - .toGetMessages()
        - .toSendReply()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8abf628d70a5145dee6086bcb4075aa9b9006eae8c8979298f243bc6c97623fd)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Ec2messages", jsii.invoke(self, "ifSsmSourceInstanceARN", [value, operator]))

    @jsii.member(jsii_name="toAcknowledgeMessage")
    def to_acknowledge_message(self) -> "Ec2messages":
        '''(experimental) Grants permission to acknowledge a message, ensuring it will not be delivered again.

        Access Level: Write

        https://docs.aws.amazon.com/systems-manager/latest/userguide/systems-manager-setting-up-messageAPIs.html

        :stability: experimental
        '''
        return typing.cast("Ec2messages", jsii.invoke(self, "toAcknowledgeMessage", []))

    @jsii.member(jsii_name="toDeleteMessage")
    def to_delete_message(self) -> "Ec2messages":
        '''(experimental) Grants permission to delete a message.

        Access Level: Write

        https://docs.aws.amazon.com/systems-manager/latest/userguide/systems-manager-setting-up-messageAPIs.html

        :stability: experimental
        '''
        return typing.cast("Ec2messages", jsii.invoke(self, "toDeleteMessage", []))

    @jsii.member(jsii_name="toFailMessage")
    def to_fail_message(self) -> "Ec2messages":
        '''(experimental) Grants permission to fail a message, signifying the message could not be processed successfully, ensuring it cannot be replied to or delivered again.

        Access Level: Write

        https://docs.aws.amazon.com/systems-manager/latest/userguide/systems-manager-setting-up-messageAPIs.html

        :stability: experimental
        '''
        return typing.cast("Ec2messages", jsii.invoke(self, "toFailMessage", []))

    @jsii.member(jsii_name="toGetEndpoint")
    def to_get_endpoint(self) -> "Ec2messages":
        '''(experimental) Grants permission to route traffic to the correct endpoint based on the given destination for the messages.

        Access Level: Read

        https://docs.aws.amazon.com/systems-manager/latest/userguide/systems-manager-setting-up-messageAPIs.html

        :stability: experimental
        '''
        return typing.cast("Ec2messages", jsii.invoke(self, "toGetEndpoint", []))

    @jsii.member(jsii_name="toGetMessages")
    def to_get_messages(self) -> "Ec2messages":
        '''(experimental) Grants permission to deliver messages to clients/instances using long polling.

        Access Level: Read

        Possible conditions:

        - .ifSsmSourceInstanceARN()

        https://docs.aws.amazon.com/systems-manager/latest/userguide/systems-manager-setting-up-messageAPIs.html

        :stability: experimental
        '''
        return typing.cast("Ec2messages", jsii.invoke(self, "toGetMessages", []))

    @jsii.member(jsii_name="toSendReply")
    def to_send_reply(self) -> "Ec2messages":
        '''(experimental) Grants permission to send replies from clients/instances to upstream service.

        Access Level: Write

        Possible conditions:

        - .ifSsmSourceInstanceARN()

        https://docs.aws.amazon.com/systems-manager/latest/userguide/systems-manager-setting-up-messageAPIs.html

        :stability: experimental
        '''
        return typing.cast("Ec2messages", jsii.invoke(self, "toSendReply", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bf1b0f754e4e017feb207e51773566d9ca5a3bd2e7a83e91710b0e43c1f1e92e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7ba4889f0a3e7b0504ee75e9dd278ae12478acf931487d4e6ba9cce22d0dd0d0)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Ecr(PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Ecr"):
    '''(experimental) Statement provider for service `ecr <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonelasticcontainerregistry.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `ecr <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonelasticcontainerregistry.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="ifResourceTag")
    def if_resource_tag(
        self,
        tag_key: builtins.str,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Ecr":
        '''(experimental) Filters access by tag-value associated with the resource.

        https://docs.aws.amazon.com/AmazonECR/latest/userguide/security_iam_service-with-iam.html#security_iam_service-with-iam-id-based-policies-conditionkeys

        Applies to resource types:

        - repository

        :param tag_key: The tag key to check.
        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__92139a868bf4d6bd5a50a1dd2a8de6a0c9c61e2ee49d26dc7c29bbdbc5f048e6)
            check_type(argname="argument tag_key", value=tag_key, expected_type=type_hints["tag_key"])
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Ecr", jsii.invoke(self, "ifResourceTag", [tag_key, value, operator]))

    @jsii.member(jsii_name="onRepository")
    def on_repository(
        self,
        repository_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Ecr":
        '''(experimental) Adds a resource of type repository to the statement.

        https://docs.aws.amazon.com/AmazonECR/latest/userguide/Repositories.html

        :param repository_name: - Identifier for the repositoryName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag() - .ifResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8a05455eb7d980b2f463b6ce6aa39b6eda81dc515ee7ccaa2c39bfc157d80290)
            check_type(argname="argument repository_name", value=repository_name, expected_type=type_hints["repository_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Ecr", jsii.invoke(self, "onRepository", [repository_name, account, region, partition]))

    @jsii.member(jsii_name="toBatchCheckLayerAvailability")
    def to_batch_check_layer_availability(self) -> "Ecr":
        '''(experimental) Grants permission to check the availability of multiple image layers in a specified registry and repository.

        Access Level: Read

        https://docs.aws.amazon.com/AmazonECR/latest/APIReference/API_BatchCheckLayerAvailability.html

        :stability: experimental
        '''
        return typing.cast("Ecr", jsii.invoke(self, "toBatchCheckLayerAvailability", []))

    @jsii.member(jsii_name="toBatchDeleteImage")
    def to_batch_delete_image(self) -> "Ecr":
        '''(experimental) Grants permission to delete a list of specified images within a specified repository.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonECR/latest/APIReference/API_BatchDeleteImage.html

        :stability: experimental
        '''
        return typing.cast("Ecr", jsii.invoke(self, "toBatchDeleteImage", []))

    @jsii.member(jsii_name="toBatchGetImage")
    def to_batch_get_image(self) -> "Ecr":
        '''(experimental) Grants permission to get detailed information for specified images within a specified repository.

        Access Level: Read

        https://docs.aws.amazon.com/AmazonECR/latest/APIReference/API_BatchGetImage.html

        :stability: experimental
        '''
        return typing.cast("Ecr", jsii.invoke(self, "toBatchGetImage", []))

    @jsii.member(jsii_name="toBatchGetRepositoryScanningConfiguration")
    def to_batch_get_repository_scanning_configuration(self) -> "Ecr":
        '''(experimental) Grants permission to retrieve repository scanning configuration for a list of repositories.

        Access Level: Read

        https://docs.aws.amazon.com/AmazonECR/latest/APIReference/API_BatchGetRepositoryScanningConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Ecr", jsii.invoke(self, "toBatchGetRepositoryScanningConfiguration", []))

    @jsii.member(jsii_name="toBatchImportUpstreamImage")
    def to_batch_import_upstream_image(self) -> "Ecr":
        '''(experimental) Grants permission to retrieve the image from the upstream registry and import it to your private registry.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonECR/latest/APIReference/API_BatchImportUpstreamImage.html

        :stability: experimental
        '''
        return typing.cast("Ecr", jsii.invoke(self, "toBatchImportUpstreamImage", []))

    @jsii.member(jsii_name="toCompleteLayerUpload")
    def to_complete_layer_upload(self) -> "Ecr":
        '''(experimental) Grants permission to inform Amazon ECR that the image layer upload for a specified registry, repository name, and upload ID, has completed.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonECR/latest/APIReference/API_CompleteLayerUpload.html

        :stability: experimental
        '''
        return typing.cast("Ecr", jsii.invoke(self, "toCompleteLayerUpload", []))

    @jsii.member(jsii_name="toCreatePullThroughCacheRule")
    def to_create_pull_through_cache_rule(self) -> "Ecr":
        '''(experimental) Grants permission to create new pull-through cache rule.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonECR/latest/APIReference/API_CreatePullThroughCacheRule.html

        :stability: experimental
        '''
        return typing.cast("Ecr", jsii.invoke(self, "toCreatePullThroughCacheRule", []))

    @jsii.member(jsii_name="toCreateRepository")
    def to_create_repository(self) -> "Ecr":
        '''(experimental) Grants permission to create an image repository.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/AmazonECR/latest/APIReference/API_CreateRepository.html

        :stability: experimental
        '''
        return typing.cast("Ecr", jsii.invoke(self, "toCreateRepository", []))

    @jsii.member(jsii_name="toDeleteLifecyclePolicy")
    def to_delete_lifecycle_policy(self) -> "Ecr":
        '''(experimental) Grants permission to delete the specified lifecycle policy.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonECR/latest/APIReference/API_DeleteLifecyclePolicy.html

        :stability: experimental
        '''
        return typing.cast("Ecr", jsii.invoke(self, "toDeleteLifecyclePolicy", []))

    @jsii.member(jsii_name="toDeletePullThroughCacheRule")
    def to_delete_pull_through_cache_rule(self) -> "Ecr":
        '''(experimental) Grants permission to delete the pull-through cache rule.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonECR/latest/APIReference/API_DeletePullThroughCacheRule.html

        :stability: experimental
        '''
        return typing.cast("Ecr", jsii.invoke(self, "toDeletePullThroughCacheRule", []))

    @jsii.member(jsii_name="toDeleteRegistryPolicy")
    def to_delete_registry_policy(self) -> "Ecr":
        '''(experimental) Grants permission to delete the registry policy.

        Access Level: Permissions management

        https://docs.aws.amazon.com/AmazonECR/latest/APIReference/API_DeleteRegistryPolicy.html

        :stability: experimental
        '''
        return typing.cast("Ecr", jsii.invoke(self, "toDeleteRegistryPolicy", []))

    @jsii.member(jsii_name="toDeleteRepository")
    def to_delete_repository(self) -> "Ecr":
        '''(experimental) Grants permission to delete an existing image repository.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonECR/latest/APIReference/API_DeleteRepository.html

        :stability: experimental
        '''
        return typing.cast("Ecr", jsii.invoke(self, "toDeleteRepository", []))

    @jsii.member(jsii_name="toDeleteRepositoryPolicy")
    def to_delete_repository_policy(self) -> "Ecr":
        '''(experimental) Grants permission to delete the repository policy from a specified repository.

        Access Level: Permissions management

        https://docs.aws.amazon.com/AmazonECR/latest/APIReference/API_DeleteRepositoryPolicy.html

        :stability: experimental
        '''
        return typing.cast("Ecr", jsii.invoke(self, "toDeleteRepositoryPolicy", []))

    @jsii.member(jsii_name="toDescribeImageReplicationStatus")
    def to_describe_image_replication_status(self) -> "Ecr":
        '''(experimental) Grants permission to retrieve replication status about an image in a registry, including failure reason if replication fails.

        Access Level: Read

        https://docs.aws.amazon.com/AmazonECR/latest/APIReference/API_DescribeImageReplicationStatus.html

        :stability: experimental
        '''
        return typing.cast("Ecr", jsii.invoke(self, "toDescribeImageReplicationStatus", []))

    @jsii.member(jsii_name="toDescribeImages")
    def to_describe_images(self) -> "Ecr":
        '''(experimental) Grants permission to get metadata about the images in a repository, including image size, image tags, and creation date.

        Access Level: List

        https://docs.aws.amazon.com/AmazonECR/latest/APIReference/API_DescribeImages.html

        :stability: experimental
        '''
        return typing.cast("Ecr", jsii.invoke(self, "toDescribeImages", []))

    @jsii.member(jsii_name="toDescribeImageScanFindings")
    def to_describe_image_scan_findings(self) -> "Ecr":
        '''(experimental) Grants permission to describe the image scan findings for the specified image.

        Access Level: Read

        https://docs.aws.amazon.com/AmazonECR/latest/APIReference/API_DescribeImageScanFindings.html

        :stability: experimental
        '''
        return typing.cast("Ecr", jsii.invoke(self, "toDescribeImageScanFindings", []))

    @jsii.member(jsii_name="toDescribePullThroughCacheRules")
    def to_describe_pull_through_cache_rules(self) -> "Ecr":
        '''(experimental) Grants permission to describe the pull-through cache rules.

        Access Level: List

        https://docs.aws.amazon.com/AmazonECR/latest/APIReference/API_DescribePullThroughCacheRules.html

        :stability: experimental
        '''
        return typing.cast("Ecr", jsii.invoke(self, "toDescribePullThroughCacheRules", []))

    @jsii.member(jsii_name="toDescribeRegistry")
    def to_describe_registry(self) -> "Ecr":
        '''(experimental) Grants permission to describe the registry settings.

        Access Level: Read

        https://docs.aws.amazon.com/AmazonECR/latest/APIReference/API_DescribeRegistry.html

        :stability: experimental
        '''
        return typing.cast("Ecr", jsii.invoke(self, "toDescribeRegistry", []))

    @jsii.member(jsii_name="toDescribeRepositories")
    def to_describe_repositories(self) -> "Ecr":
        '''(experimental) Grants permission to describe image repositories in a registry.

        Access Level: Read

        https://docs.aws.amazon.com/AmazonECR/latest/APIReference/API_DescribeRepositories.html

        :stability: experimental
        '''
        return typing.cast("Ecr", jsii.invoke(self, "toDescribeRepositories", []))

    @jsii.member(jsii_name="toGetAuthorizationToken")
    def to_get_authorization_token(self) -> "Ecr":
        '''(experimental) Grants permission to retrieve a token that is valid for a specified registry for 12 hours.

        Access Level: Read

        https://docs.aws.amazon.com/AmazonECR/latest/APIReference/API_GetAuthorizationToken.html

        :stability: experimental
        '''
        return typing.cast("Ecr", jsii.invoke(self, "toGetAuthorizationToken", []))

    @jsii.member(jsii_name="toGetDownloadUrlForLayer")
    def to_get_download_url_for_layer(self) -> "Ecr":
        '''(experimental) Grants permission to retrieve the download URL corresponding to an image layer.

        Access Level: Read

        https://docs.aws.amazon.com/AmazonECR/latest/APIReference/API_GetDownloadUrlForLayer.html

        :stability: experimental
        '''
        return typing.cast("Ecr", jsii.invoke(self, "toGetDownloadUrlForLayer", []))

    @jsii.member(jsii_name="toGetLifecyclePolicy")
    def to_get_lifecycle_policy(self) -> "Ecr":
        '''(experimental) Grants permission to retrieve the specified lifecycle policy.

        Access Level: Read

        https://docs.aws.amazon.com/AmazonECR/latest/APIReference/API_GetLifecyclePolicy.html

        :stability: experimental
        '''
        return typing.cast("Ecr", jsii.invoke(self, "toGetLifecyclePolicy", []))

    @jsii.member(jsii_name="toGetLifecyclePolicyPreview")
    def to_get_lifecycle_policy_preview(self) -> "Ecr":
        '''(experimental) Grants permission to retrieve the results of the specified lifecycle policy preview request.

        Access Level: Read

        https://docs.aws.amazon.com/AmazonECR/latest/APIReference/API_GetLifecyclePolicyPreview.html

        :stability: experimental
        '''
        return typing.cast("Ecr", jsii.invoke(self, "toGetLifecyclePolicyPreview", []))

    @jsii.member(jsii_name="toGetRegistryPolicy")
    def to_get_registry_policy(self) -> "Ecr":
        '''(experimental) Grants permission to retrieve the registry policy.

        Access Level: Read

        https://docs.aws.amazon.com/AmazonECR/latest/APIReference/API_GetRegistryPolicy.html

        :stability: experimental
        '''
        return typing.cast("Ecr", jsii.invoke(self, "toGetRegistryPolicy", []))

    @jsii.member(jsii_name="toGetRegistryScanningConfiguration")
    def to_get_registry_scanning_configuration(self) -> "Ecr":
        '''(experimental) Grants permission to retrieve registry scanning configuration.

        Access Level: Read

        https://docs.aws.amazon.com/AmazonECR/latest/APIReference/API_GetRegistryScanningConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Ecr", jsii.invoke(self, "toGetRegistryScanningConfiguration", []))

    @jsii.member(jsii_name="toGetRepositoryPolicy")
    def to_get_repository_policy(self) -> "Ecr":
        '''(experimental) Grants permission to retrieve the repository policy for a specified repository.

        Access Level: Read

        https://docs.aws.amazon.com/AmazonECR/latest/APIReference/API_GetRepositoryPolicy.html

        :stability: experimental
        '''
        return typing.cast("Ecr", jsii.invoke(self, "toGetRepositoryPolicy", []))

    @jsii.member(jsii_name="toInitiateLayerUpload")
    def to_initiate_layer_upload(self) -> "Ecr":
        '''(experimental) Grants permission to notify Amazon ECR that you intend to upload an image layer.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonECR/latest/APIReference/API_InitiateLayerUpload.html

        :stability: experimental
        '''
        return typing.cast("Ecr", jsii.invoke(self, "toInitiateLayerUpload", []))

    @jsii.member(jsii_name="toListImages")
    def to_list_images(self) -> "Ecr":
        '''(experimental) Grants permission to list all the image IDs for a given repository.

        Access Level: List

        https://docs.aws.amazon.com/AmazonECR/latest/APIReference/API_ListImages.html

        :stability: experimental
        '''
        return typing.cast("Ecr", jsii.invoke(self, "toListImages", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Ecr":
        '''(experimental) Grants permission to list the tags for an Amazon ECR resource.

        Access Level: Read

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/AmazonECR/latest/APIReference/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("Ecr", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toPutImage")
    def to_put_image(self) -> "Ecr":
        '''(experimental) Grants permission to create or update the image manifest associated with an image.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonECR/latest/APIReference/API_PutImage.html

        :stability: experimental
        '''
        return typing.cast("Ecr", jsii.invoke(self, "toPutImage", []))

    @jsii.member(jsii_name="toPutImageScanningConfiguration")
    def to_put_image_scanning_configuration(self) -> "Ecr":
        '''(experimental) Grants permission to update the image scanning configuration for a repository.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonECR/latest/APIReference/API_PutImageScanningConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Ecr", jsii.invoke(self, "toPutImageScanningConfiguration", []))

    @jsii.member(jsii_name="toPutImageTagMutability")
    def to_put_image_tag_mutability(self) -> "Ecr":
        '''(experimental) Grants permission to update the image tag mutability settings for a repository.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonECR/latest/APIReference/API_PutImageTagMutability.html

        :stability: experimental
        '''
        return typing.cast("Ecr", jsii.invoke(self, "toPutImageTagMutability", []))

    @jsii.member(jsii_name="toPutLifecyclePolicy")
    def to_put_lifecycle_policy(self) -> "Ecr":
        '''(experimental) Grants permission to create or update a lifecycle policy.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonECR/latest/APIReference/API_PutLifecyclePolicy.html

        :stability: experimental
        '''
        return typing.cast("Ecr", jsii.invoke(self, "toPutLifecyclePolicy", []))

    @jsii.member(jsii_name="toPutRegistryPolicy")
    def to_put_registry_policy(self) -> "Ecr":
        '''(experimental) Grants permission to update the registry policy.

        Access Level: Permissions management

        https://docs.aws.amazon.com/AmazonECR/latest/APIReference/API_PutRegistryPolicy.html

        :stability: experimental
        '''
        return typing.cast("Ecr", jsii.invoke(self, "toPutRegistryPolicy", []))

    @jsii.member(jsii_name="toPutRegistryScanningConfiguration")
    def to_put_registry_scanning_configuration(self) -> "Ecr":
        '''(experimental) Grants permission to update registry scanning configuration.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonECR/latest/APIReference/API_PutRegistryScanningConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Ecr", jsii.invoke(self, "toPutRegistryScanningConfiguration", []))

    @jsii.member(jsii_name="toPutReplicationConfiguration")
    def to_put_replication_configuration(self) -> "Ecr":
        '''(experimental) Grants permission to update the replication configuration for the registry.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonECR/latest/APIReference/API_PutReplicationConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Ecr", jsii.invoke(self, "toPutReplicationConfiguration", []))

    @jsii.member(jsii_name="toReplicateImage")
    def to_replicate_image(self) -> "Ecr":
        '''(experimental) Grants permission to replicate images to the destination registry.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonECR/latest/userguide/registry-permissions.html

        :stability: experimental
        '''
        return typing.cast("Ecr", jsii.invoke(self, "toReplicateImage", []))

    @jsii.member(jsii_name="toSetRepositoryPolicy")
    def to_set_repository_policy(self) -> "Ecr":
        '''(experimental) Grants permission to apply a repository policy on a specified repository to control access permissions.

        Access Level: Permissions management

        https://docs.aws.amazon.com/AmazonECR/latest/APIReference/API_SetRepositoryPolicy.html

        :stability: experimental
        '''
        return typing.cast("Ecr", jsii.invoke(self, "toSetRepositoryPolicy", []))

    @jsii.member(jsii_name="toStartImageScan")
    def to_start_image_scan(self) -> "Ecr":
        '''(experimental) Grants permission to start an image scan.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonECR/latest/APIReference/API_StartImageScan.html

        :stability: experimental
        '''
        return typing.cast("Ecr", jsii.invoke(self, "toStartImageScan", []))

    @jsii.member(jsii_name="toStartLifecyclePolicyPreview")
    def to_start_lifecycle_policy_preview(self) -> "Ecr":
        '''(experimental) Grants permission to start a preview of the specified lifecycle policy.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonECR/latest/APIReference/API_StartLifecyclePolicyPreview.html

        :stability: experimental
        '''
        return typing.cast("Ecr", jsii.invoke(self, "toStartLifecyclePolicyPreview", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Ecr":
        '''(experimental) Grants permission to tag an Amazon ECR resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/AmazonECR/latest/APIReference/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("Ecr", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Ecr":
        '''(experimental) Grants permission to untag an Amazon ECR resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/AmazonECR/latest/APIReference/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("Ecr", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUploadLayerPart")
    def to_upload_layer_part(self) -> "Ecr":
        '''(experimental) Grants permission to upload an image layer part to Amazon ECR.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonECR/latest/APIReference/API_UploadLayerPart.html

        :stability: experimental
        '''
        return typing.cast("Ecr", jsii.invoke(self, "toUploadLayerPart", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0aa8078743b1b7ffb24a3f26294ef9f895511d79bc537ef660e64842c6519dcb)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2243377a86dd36a7a90dbe794efa0262f23177d22d4672f59f2e514fb2c726b6)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class EcrPublic(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.EcrPublic",
):
    '''(experimental) Statement provider for service `ecr-public <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonelasticcontainerregistrypublic.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `ecr-public <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonelasticcontainerregistrypublic.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="ifResourceTag")
    def if_resource_tag(
        self,
        tag_key: builtins.str,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "EcrPublic":
        '''(experimental) Filters actions based on tag-value associated with the resource.

        https://docs.aws.amazon.com/AmazonECR/latest/userguide/security_iam_service-with-iam.html#security_iam_service-with-iam-id-based-policies-conditionkeys

        Applies to resource types:

        - repository

        :param tag_key: The tag key to check.
        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__659da8b62b1a343729c493e445d0d7d41b4c69f2148e7203f870b0142baa1971)
            check_type(argname="argument tag_key", value=tag_key, expected_type=type_hints["tag_key"])
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("EcrPublic", jsii.invoke(self, "ifResourceTag", [tag_key, value, operator]))

    @jsii.member(jsii_name="onRegistry")
    def on_registry(
        self,
        registry_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "EcrPublic":
        '''(experimental) Adds a resource of type registry to the statement.

        https://docs.aws.amazon.com/AmazonECR/latest/userguide/iam-policy-structure.html#ECR-Public_ARN_Format

        :param registry_id: - Identifier for the registryId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b187664643c8446b8020c6328ba73ecb3f7d3662d7e2ffa983779d06ac58837a)
            check_type(argname="argument registry_id", value=registry_id, expected_type=type_hints["registry_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("EcrPublic", jsii.invoke(self, "onRegistry", [registry_id, account, partition]))

    @jsii.member(jsii_name="onRepository")
    def on_repository(
        self,
        repository_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "EcrPublic":
        '''(experimental) Adds a resource of type repository to the statement.

        https://docs.aws.amazon.com/AmazonECR/latest/userguide/iam-policy-structure.html#ECR-Public_ARN_Format

        :param repository_name: - Identifier for the repositoryName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag() - .ifResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__dcf3e2aa288eedaba36cc8786b12e8914757c5b51b24778edb99fc46dcd6b13c)
            check_type(argname="argument repository_name", value=repository_name, expected_type=type_hints["repository_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("EcrPublic", jsii.invoke(self, "onRepository", [repository_name, account, partition]))

    @jsii.member(jsii_name="toBatchCheckLayerAvailability")
    def to_batch_check_layer_availability(self) -> "EcrPublic":
        '''(experimental) Grants permission to check the availability of multiple image layers in a specified registry and repository.

        Access Level: Read

        https://docs.aws.amazon.com/AmazonECRPublic/latest/APIReference/API_BatchCheckLayerAvailability.html

        :stability: experimental
        '''
        return typing.cast("EcrPublic", jsii.invoke(self, "toBatchCheckLayerAvailability", []))

    @jsii.member(jsii_name="toBatchDeleteImage")
    def to_batch_delete_image(self) -> "EcrPublic":
        '''(experimental) Grants permission to delete a list of specified images within a specified repository.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonECRPublic/latest/APIReference/API_BatchDeleteImage.html

        :stability: experimental
        '''
        return typing.cast("EcrPublic", jsii.invoke(self, "toBatchDeleteImage", []))

    @jsii.member(jsii_name="toCompleteLayerUpload")
    def to_complete_layer_upload(self) -> "EcrPublic":
        '''(experimental) Grants permission to inform Amazon ECR that the image layer upload for a specified registry, repository name, and upload ID, has completed.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonECRPublic/latest/APIReference/API_CompleteLayerUpload.html

        :stability: experimental
        '''
        return typing.cast("EcrPublic", jsii.invoke(self, "toCompleteLayerUpload", []))

    @jsii.member(jsii_name="toCreateRepository")
    def to_create_repository(self) -> "EcrPublic":
        '''(experimental) Grants permission to create an image repository.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/AmazonECRPublic/latest/APIReference/API_CreateRepository.html

        :stability: experimental
        '''
        return typing.cast("EcrPublic", jsii.invoke(self, "toCreateRepository", []))

    @jsii.member(jsii_name="toDeleteRepository")
    def to_delete_repository(self) -> "EcrPublic":
        '''(experimental) Grants permission to delete an existing image repository.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonECRPublic/latest/APIReference/API_DeleteRepository.html

        :stability: experimental
        '''
        return typing.cast("EcrPublic", jsii.invoke(self, "toDeleteRepository", []))

    @jsii.member(jsii_name="toDeleteRepositoryPolicy")
    def to_delete_repository_policy(self) -> "EcrPublic":
        '''(experimental) Grants permission to delete the repository policy from a specified repository.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonECRPublic/latest/APIReference/API_DeleteRepositoryPolicy.html

        :stability: experimental
        '''
        return typing.cast("EcrPublic", jsii.invoke(self, "toDeleteRepositoryPolicy", []))

    @jsii.member(jsii_name="toDescribeImages")
    def to_describe_images(self) -> "EcrPublic":
        '''(experimental) Grants permission to get metadata about the images in a repository, including image size, image tags, and creation date.

        Access Level: Read

        https://docs.aws.amazon.com/AmazonECRPublic/latest/APIReference/API_DescribeImages.html

        :stability: experimental
        '''
        return typing.cast("EcrPublic", jsii.invoke(self, "toDescribeImages", []))

    @jsii.member(jsii_name="toDescribeImageTags")
    def to_describe_image_tags(self) -> "EcrPublic":
        '''(experimental) Grants permission to describe all the image tags for a given repository.

        Access Level: List

        https://docs.aws.amazon.com/AmazonECRPublic/latest/APIReference/API_DescribeImageTags.html

        :stability: experimental
        '''
        return typing.cast("EcrPublic", jsii.invoke(self, "toDescribeImageTags", []))

    @jsii.member(jsii_name="toDescribeRegistries")
    def to_describe_registries(self) -> "EcrPublic":
        '''(experimental) Grants permission to retrieve the catalog data associated with a registry.

        Access Level: List

        https://docs.aws.amazon.com/AmazonECRPublic/latest/APIReference/API_DescribeRegistries.html

        :stability: experimental
        '''
        return typing.cast("EcrPublic", jsii.invoke(self, "toDescribeRegistries", []))

    @jsii.member(jsii_name="toDescribeRepositories")
    def to_describe_repositories(self) -> "EcrPublic":
        '''(experimental) Grants permission to describe image repositories in a registry.

        Access Level: List

        https://docs.aws.amazon.com/AmazonECRPublic/latest/APIReference/API_DescribeRepositories.html

        :stability: experimental
        '''
        return typing.cast("EcrPublic", jsii.invoke(self, "toDescribeRepositories", []))

    @jsii.member(jsii_name="toGetAuthorizationToken")
    def to_get_authorization_token(self) -> "EcrPublic":
        '''(experimental) Grants permission to retrieve a token that is valid for a specified registry for 12 hours.

        Access Level: Read

        https://docs.aws.amazon.com/AmazonECRPublic/latest/APIReference/API_GetAuthorizationToken.html

        :stability: experimental
        '''
        return typing.cast("EcrPublic", jsii.invoke(self, "toGetAuthorizationToken", []))

    @jsii.member(jsii_name="toGetRegistryCatalogData")
    def to_get_registry_catalog_data(self) -> "EcrPublic":
        '''(experimental) Grants permission to retrieve the catalog data associated with a registry.

        Access Level: Read

        https://docs.aws.amazon.com/AmazonECRPublic/latest/APIReference/API_GetRegistryCatalogData.html

        :stability: experimental
        '''
        return typing.cast("EcrPublic", jsii.invoke(self, "toGetRegistryCatalogData", []))

    @jsii.member(jsii_name="toGetRepositoryCatalogData")
    def to_get_repository_catalog_data(self) -> "EcrPublic":
        '''(experimental) Grants permission to retrieve the catalog data associated with a repository.

        Access Level: Read

        https://docs.aws.amazon.com/AmazonECRPublic/latest/APIReference/API_GetRepositoryCatalogData.html

        :stability: experimental
        '''
        return typing.cast("EcrPublic", jsii.invoke(self, "toGetRepositoryCatalogData", []))

    @jsii.member(jsii_name="toGetRepositoryPolicy")
    def to_get_repository_policy(self) -> "EcrPublic":
        '''(experimental) Grants permission to retrieve the repository policy for a specified repository.

        Access Level: Read

        https://docs.aws.amazon.com/AmazonECRPublic/latest/APIReference/API_GetRepositoryPolicy.html

        :stability: experimental
        '''
        return typing.cast("EcrPublic", jsii.invoke(self, "toGetRepositoryPolicy", []))

    @jsii.member(jsii_name="toInitiateLayerUpload")
    def to_initiate_layer_upload(self) -> "EcrPublic":
        '''(experimental) Grants permission to notify Amazon ECR that you intend to upload an image layer.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonECRPublic/latest/APIReference/API_InitiateLayerUpload.html

        :stability: experimental
        '''
        return typing.cast("EcrPublic", jsii.invoke(self, "toInitiateLayerUpload", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "EcrPublic":
        '''(experimental) Grants permission to list the tags for an Amazon ECR resource.

        Access Level: Read

        https://docs.aws.amazon.com/AmazonECRPublic/latest/APIReference/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("EcrPublic", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toPutImage")
    def to_put_image(self) -> "EcrPublic":
        '''(experimental) Grants permission to create or update the image manifest associated with an image.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonECRPublic/latest/APIReference/API_PutImage.html

        :stability: experimental
        '''
        return typing.cast("EcrPublic", jsii.invoke(self, "toPutImage", []))

    @jsii.member(jsii_name="toPutRegistryCatalogData")
    def to_put_registry_catalog_data(self) -> "EcrPublic":
        '''(experimental) Grants permission to create and update the catalog data associated with a registry.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonECRPublic/latest/APIReference/API_PutRegistryCatalogData.html

        :stability: experimental
        '''
        return typing.cast("EcrPublic", jsii.invoke(self, "toPutRegistryCatalogData", []))

    @jsii.member(jsii_name="toPutRepositoryCatalogData")
    def to_put_repository_catalog_data(self) -> "EcrPublic":
        '''(experimental) Grants permission to update the catalog data associated with a repository.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonECRPublic/latest/APIReference/API_PutRepositoryCatalogData.html

        :stability: experimental
        '''
        return typing.cast("EcrPublic", jsii.invoke(self, "toPutRepositoryCatalogData", []))

    @jsii.member(jsii_name="toSetRepositoryPolicy")
    def to_set_repository_policy(self) -> "EcrPublic":
        '''(experimental) Grants permission to apply a repository policy on a specified repository to control access permissions.

        Access Level: Permissions management

        https://docs.aws.amazon.com/AmazonECRPublic/latest/APIReference/API_SetRepositoryPolicy.html

        :stability: experimental
        '''
        return typing.cast("EcrPublic", jsii.invoke(self, "toSetRepositoryPolicy", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "EcrPublic":
        '''(experimental) Grants permission to tag an Amazon ECR resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/AmazonECRPublic/latest/APIReference/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("EcrPublic", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "EcrPublic":
        '''(experimental) Grants permission to untag an Amazon ECR resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/AmazonECRPublic/latest/APIReference/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("EcrPublic", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUploadLayerPart")
    def to_upload_layer_part(self) -> "EcrPublic":
        '''(experimental) Grants permission to upload an image layer part to Amazon ECR Public.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonECRPublic/latest/APIReference/API_UploadLayerPart.html

        :stability: experimental
        '''
        return typing.cast("EcrPublic", jsii.invoke(self, "toUploadLayerPart", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__18dedbc65712202df1a92b10ff4ccbc3e11144e0e19de68d672fad3d83e7c80f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9a2a0c67082e56de81ff4dc916c628f1e49ac720eefddede07266b9d12c0766b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Ecs(PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Ecs"):
    '''(experimental) Statement provider for service `ecs <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonelasticcontainerservice.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `ecs <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonelasticcontainerservice.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="ifCapacityProvider")
    def if_capacity_provider(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Ecs":
        '''(experimental) Filters access by the ARN of an Amazon ECS capacity provider.

        https://docs.aws.amazon.com/AmazonECS/latest/developerguide/security_iam_service-with-iam.html#security_iam_service-with-iam-id-based-policies-conditionkeys

        Applies to actions:

        - .toCreateCluster()
        - .toCreateService()
        - .toCreateTaskSet()
        - .toPutClusterCapacityProviders()
        - .toRunTask()
        - .toUpdateService()

        :param value: The value(s) to check.
        :param operator: Works with `arn operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_ARN>`_. **Default:** ``ArnLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1a6e1271c981e154e6624ae3f634f08582ed7e0d531b18560e0e1718256757e8)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Ecs", jsii.invoke(self, "ifCapacityProvider", [value, operator]))

    @jsii.member(jsii_name="ifCluster")
    def if_cluster(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Ecs":
        '''(experimental) Filters access by the ARN of an Amazon ECS cluster.

        https://docs.aws.amazon.com/AmazonECS/latest/developerguide/security_iam_service-with-iam.html#security_iam_service-with-iam-id-based-policies-conditionkeys

        Applies to actions:

        - .toCreateService()
        - .toCreateTaskSet()
        - .toDeleteAttributes()
        - .toDeleteService()
        - .toDeleteTaskSet()
        - .toDescribeContainerInstances()
        - .toDescribeServices()
        - .toDescribeTaskSets()
        - .toDescribeTasks()
        - .toExecuteCommand()
        - .toListServices()
        - .toListTasks()
        - .toPoll()
        - .toPutAttributes()
        - .toRunTask()
        - .toStartTask()
        - .toStartTelemetrySession()
        - .toStopTask()
        - .toUpdateContainerAgent()
        - .toUpdateContainerInstancesState()
        - .toUpdateService()
        - .toUpdateServicePrimaryTaskSet()
        - .toUpdateTaskSet()

        :param value: The value(s) to check.
        :param operator: Works with `arn operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_ARN>`_. **Default:** ``ArnLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8fc53746a3aa57feabc246edc190d7d8b836d71145cf79364567d2575fbc89d1)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Ecs", jsii.invoke(self, "ifCluster", [value, operator]))

    @jsii.member(jsii_name="ifContainerInstances")
    def if_container_instances(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Ecs":
        '''(experimental) Filters access by the ARN of an Amazon ECS container instance.

        https://docs.aws.amazon.com/AmazonECS/latest/developerguide/security_iam_service-with-iam.html#security_iam_service-with-iam-id-based-policies-conditionkeys

        Applies to actions:

        - .toStartTask()

        :param value: The value(s) to check.
        :param operator: Works with `arn operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_ARN>`_. **Default:** ``ArnLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2f8898c7b9f06f7a4e64875e6fb2567913d69b79d1d6080d92cd3968cdda1c66)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Ecs", jsii.invoke(self, "ifContainerInstances", [value, operator]))

    @jsii.member(jsii_name="ifContainerName")
    def if_container_name(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Ecs":
        '''(experimental) Filters access by the name of an Amazon ECS container which is defined in the ECS task definition.

        https://docs.aws.amazon.com/AmazonECS/latest/developerguide/security_iam_service-with-iam.html#security_iam_service-with-iam-id-based-policies-conditionkeys

        Applies to actions:

        - .toExecuteCommand()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__813e7535c90adacf401e71d8549da45e6eb13bffe697485c6ac782a0f2a3d737)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Ecs", jsii.invoke(self, "ifContainerName", [value, operator]))

    @jsii.member(jsii_name="ifEnableExecuteCommand")
    def if_enable_execute_command(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Ecs":
        '''(experimental) Filters access by the execute-command capability of your Amazon ECS task or Amazon ECS service.

        https://docs.aws.amazon.com/AmazonECS/latest/developerguide/security_iam_service-with-iam.html#security_iam_service-with-iam-id-based-policies-conditionkeys

        Applies to actions:

        - .toCreateService()
        - .toRunTask()
        - .toStartTask()
        - .toUpdateService()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4112aeae2eaa543c52aafdb5944feeb8e1db6f351c6c829e945a311f2ebb85a5)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Ecs", jsii.invoke(self, "ifEnableExecuteCommand", [value, operator]))

    @jsii.member(jsii_name="ifEnableServiceConnect")
    def if_enable_service_connect(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Ecs":
        '''(experimental) Filters access by the enable field value in the Service Connect configuration.

        https://docs.aws.amazon.com/AmazonECS/latest/developerguide/security_iam_service-with-iam.html#security_iam_service-with-iam-id-based-policies-conditionkeys

        Applies to actions:

        - .toCreateService()
        - .toUpdateService()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__73d6553d8e0dbc16de56444edbd65741ae781cb1bf23e65c3ce8e5d5d1f65934)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Ecs", jsii.invoke(self, "ifEnableServiceConnect", [value, operator]))

    @jsii.member(jsii_name="ifNamespace")
    def if_namespace(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Ecs":
        '''(experimental) Filters access by the ARN of AWS Cloud Map namespace which is defined in the Service Connect Configuration.

        https://docs.aws.amazon.com/AmazonECS/latest/developerguide/security_iam_service-with-iam.html#security_iam_service-with-iam-id-based-policies-conditionkeys

        Applies to actions:

        - .toCreateService()
        - .toListServicesByNamespace()
        - .toUpdateService()

        :param value: The value(s) to check.
        :param operator: Works with `arn operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_ARN>`_. **Default:** ``ArnLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3828d03e165e1e934d4016d0d050d2234e9fb8f4070fea25a36100208838fbdc)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Ecs", jsii.invoke(self, "ifNamespace", [value, operator]))

    @jsii.member(jsii_name="ifResourceTag")
    def if_resource_tag(
        self,
        tag_key: builtins.str,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Ecs":
        '''(experimental) Filters access by the tag key-value pairs attached to the resource.

        https://docs.aws.amazon.com/AmazonECS/latest/developerguide/security_iam_service-with-iam.html#security_iam_service-with-iam-id-based-policies

        Applies to resource types:

        - cluster
        - container-instance
        - service
        - task
        - task-definition
        - capacity-provider
        - task-set

        :param tag_key: The tag key to check.
        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__de8cedd2bf64be021af1ef3e5ed6efbcf163a6c74c31b0527c6503a27c58fbce)
            check_type(argname="argument tag_key", value=tag_key, expected_type=type_hints["tag_key"])
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Ecs", jsii.invoke(self, "ifResourceTag", [tag_key, value, operator]))

    @jsii.member(jsii_name="ifService")
    def if_service(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Ecs":
        '''(experimental) Filters access by the ARN of an Amazon ECS service.

        https://docs.aws.amazon.com/AmazonECS/latest/developerguide/security_iam_service-with-iam.html#security_iam_service-with-iam-id-based-policies-conditionkeys

        Applies to actions:

        - .toCreateTaskSet()
        - .toDeleteTaskSet()
        - .toDescribeTaskSets()
        - .toUpdateTaskSet()

        :param value: The value(s) to check.
        :param operator: Works with `arn operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_ARN>`_. **Default:** ``ArnLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f3bf55f495c823835e1477dc3d616fddc3f39024da0f664d388cd695c028cb84)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Ecs", jsii.invoke(self, "ifService", [value, operator]))

    @jsii.member(jsii_name="ifTask")
    def if_task(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Ecs":
        '''(experimental) Filters access by the ARN of an Amazon ECS task.

        https://docs.aws.amazon.com/AmazonECS/latest/developerguide/security_iam_service-with-iam.html#security_iam_service-with-iam-id-based-policies-conditionkeys

        Applies to actions:

        - .toExecuteCommand()

        :param value: The value(s) to check.
        :param operator: Works with `arn operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_ARN>`_. **Default:** ``ArnLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__36e05dd7b01a95d726aadbd8593ba7948c1c4c6199eeccc57c13cf1cef76ae9b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Ecs", jsii.invoke(self, "ifTask", [value, operator]))

    @jsii.member(jsii_name="ifTaskDefinition")
    def if_task_definition(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Ecs":
        '''(experimental) Filters access by the ARN of an Amazon ECS task definition.

        https://docs.aws.amazon.com/AmazonECS/latest/developerguide/security_iam_service-with-iam.html#security_iam_service-with-iam-id-based-policies-conditionkeys

        Applies to actions:

        - .toCreateService()
        - .toCreateTaskSet()
        - .toUpdateService()

        :param value: The value(s) to check.
        :param operator: Works with `arn operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_ARN>`_. **Default:** ``ArnLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__befe98286e060b0504dbca133964faeca26f622b1ecd759afce4033921d7d55e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Ecs", jsii.invoke(self, "ifTaskDefinition", [value, operator]))

    @jsii.member(jsii_name="onCapacityProvider")
    def on_capacity_provider(
        self,
        capacity_provider_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Ecs":
        '''(experimental) Adds a resource of type capacity-provider to the statement.

        https://docs.aws.amazon.com/AmazonECS/latest/developerguide/cluster-capacity-providers.html

        :param capacity_provider_name: - Identifier for the capacityProviderName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag() - .ifResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1bc3498a41bab90aab11408ccbf3edfd189e724a9045044c8eef26fde83c4f95)
            check_type(argname="argument capacity_provider_name", value=capacity_provider_name, expected_type=type_hints["capacity_provider_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Ecs", jsii.invoke(self, "onCapacityProvider", [capacity_provider_name, account, region, partition]))

    @jsii.member(jsii_name="onCluster")
    def on_cluster(
        self,
        cluster_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Ecs":
        '''(experimental) Adds a resource of type cluster to the statement.

        https://docs.aws.amazon.com/AmazonECS/latest/developerguide/clusters.html

        :param cluster_name: - Identifier for the clusterName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag() - .ifResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__04a10e736fa25d2f2279afffcbf8e707e593efb86f85efcb18cad53d5a1f8ead)
            check_type(argname="argument cluster_name", value=cluster_name, expected_type=type_hints["cluster_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Ecs", jsii.invoke(self, "onCluster", [cluster_name, account, region, partition]))

    @jsii.member(jsii_name="onContainerInstance")
    def on_container_instance(
        self,
        cluster_name: builtins.str,
        container_instance_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Ecs":
        '''(experimental) Adds a resource of type container-instance to the statement.

        https://docs.aws.amazon.com/AmazonECS/latest/developerguide/ECS_instances.html

        :param cluster_name: - Identifier for the clusterName.
        :param container_instance_id: - Identifier for the containerInstanceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag() - .ifResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a2924602e19a37f5378d772467e919e117d3990e46f3f196240000197c7056ad)
            check_type(argname="argument cluster_name", value=cluster_name, expected_type=type_hints["cluster_name"])
            check_type(argname="argument container_instance_id", value=container_instance_id, expected_type=type_hints["container_instance_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Ecs", jsii.invoke(self, "onContainerInstance", [cluster_name, container_instance_id, account, region, partition]))

    @jsii.member(jsii_name="onService")
    def on_service(
        self,
        cluster_name: builtins.str,
        service_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Ecs":
        '''(experimental) Adds a resource of type service to the statement.

        https://docs.aws.amazon.com/AmazonECS/latest/developerguide/ecs_services.html

        :param cluster_name: - Identifier for the clusterName.
        :param service_name: - Identifier for the serviceName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag() - .ifResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__49e7b14897cbf2795acc7d89daa2f2f76325ffa40479f8bd01297e170c4a91cc)
            check_type(argname="argument cluster_name", value=cluster_name, expected_type=type_hints["cluster_name"])
            check_type(argname="argument service_name", value=service_name, expected_type=type_hints["service_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Ecs", jsii.invoke(self, "onService", [cluster_name, service_name, account, region, partition]))

    @jsii.member(jsii_name="onTask")
    def on_task(
        self,
        cluster_name: builtins.str,
        task_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Ecs":
        '''(experimental) Adds a resource of type task to the statement.

        https://docs.aws.amazon.com/AmazonECS/latest/developerguide/scheduling_tasks.html

        :param cluster_name: - Identifier for the clusterName.
        :param task_id: - Identifier for the taskId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag() - .ifResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__add31618cd9b5b5ae87161a1fe19926e20b1aafa2ae2087352ea4b8c2528d4bd)
            check_type(argname="argument cluster_name", value=cluster_name, expected_type=type_hints["cluster_name"])
            check_type(argname="argument task_id", value=task_id, expected_type=type_hints["task_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Ecs", jsii.invoke(self, "onTask", [cluster_name, task_id, account, region, partition]))

    @jsii.member(jsii_name="onTaskDefinition")
    def on_task_definition(
        self,
        task_definition_family_name: builtins.str,
        task_definition_revision_number: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Ecs":
        '''(experimental) Adds a resource of type task-definition to the statement.

        https://docs.aws.amazon.com/AmazonECS/latest/developerguide/task_definitions.html

        :param task_definition_family_name: - Identifier for the taskDefinitionFamilyName.
        :param task_definition_revision_number: - Identifier for the taskDefinitionRevisionNumber.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag() - .ifResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__eabba7ca268ddda152db4635b97704b39c77c8cdbfc7a43de3d74fba91b54cd5)
            check_type(argname="argument task_definition_family_name", value=task_definition_family_name, expected_type=type_hints["task_definition_family_name"])
            check_type(argname="argument task_definition_revision_number", value=task_definition_revision_number, expected_type=type_hints["task_definition_revision_number"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Ecs", jsii.invoke(self, "onTaskDefinition", [task_definition_family_name, task_definition_revision_number, account, region, partition]))

    @jsii.member(jsii_name="onTaskSet")
    def on_task_set(
        self,
        cluster_name: builtins.str,
        service_name: builtins.str,
        task_set_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Ecs":
        '''(experimental) Adds a resource of type task-set to the statement.

        https://docs.aws.amazon.com/AmazonECS/latest/developerguide/deployment-type-external.html

        :param cluster_name: - Identifier for the clusterName.
        :param service_name: - Identifier for the serviceName.
        :param task_set_id: - Identifier for the taskSetId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag() - .ifResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4cee2f38404fdaac5ca13090f70d66567136e9ed86d09008153cd0fc5b2cf110)
            check_type(argname="argument cluster_name", value=cluster_name, expected_type=type_hints["cluster_name"])
            check_type(argname="argument service_name", value=service_name, expected_type=type_hints["service_name"])
            check_type(argname="argument task_set_id", value=task_set_id, expected_type=type_hints["task_set_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Ecs", jsii.invoke(self, "onTaskSet", [cluster_name, service_name, task_set_id, account, region, partition]))

    @jsii.member(jsii_name="toCreateCapacityProvider")
    def to_create_capacity_provider(self) -> "Ecs":
        '''(experimental) Grants permission to create a new capacity provider.

        Capacity providers are associated with an Amazon ECS cluster and are used in capacity provider strategies to facilitate cluster auto scaling

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/AmazonECS/latest/APIReference/API_CreateCapacityProvider.html

        :stability: experimental
        '''
        return typing.cast("Ecs", jsii.invoke(self, "toCreateCapacityProvider", []))

    @jsii.member(jsii_name="toCreateCluster")
    def to_create_cluster(self) -> "Ecs":
        '''(experimental) Grants permission to create a new Amazon ECS cluster.

        Access Level: Write

        Possible conditions:

        - .ifCapacityProvider()
        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/AmazonECS/latest/APIReference/API_CreateCluster.html

        :stability: experimental
        '''
        return typing.cast("Ecs", jsii.invoke(self, "toCreateCluster", []))

    @jsii.member(jsii_name="toCreateService")
    def to_create_service(self) -> "Ecs":
        '''(experimental) Grants permission to run and maintain a desired number of tasks from a specified task definition via service creation.

        Access Level: Write

        Possible conditions:

        - .ifCluster()
        - .ifCapacityProvider()
        - .ifTaskDefinition()
        - .ifEnableExecuteCommand()
        - .ifEnableServiceConnect()
        - .ifNamespace()
        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/AmazonECS/latest/APIReference/API_CreateService.html

        :stability: experimental
        '''
        return typing.cast("Ecs", jsii.invoke(self, "toCreateService", []))

    @jsii.member(jsii_name="toCreateTaskSet")
    def to_create_task_set(self) -> "Ecs":
        '''(experimental) Grants permission to create a new Amazon ECS task set.

        Access Level: Write

        Possible conditions:

        - .ifCluster()
        - .ifCapacityProvider()
        - .ifService()
        - .ifTaskDefinition()
        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/AmazonECS/latest/APIReference/API_CreateTaskSet.html

        :stability: experimental
        '''
        return typing.cast("Ecs", jsii.invoke(self, "toCreateTaskSet", []))

    @jsii.member(jsii_name="toDeleteAccountSetting")
    def to_delete_account_setting(self) -> "Ecs":
        '''(experimental) Grants permission to modify the ARN and resource ID format of a resource for a specified IAM user, IAM role, or the root user for an account.

        You can specify whether the new ARN and resource ID format are disabled for new resources that are created

        Access Level: Write

        https://docs.aws.amazon.com/AmazonECS/latest/APIReference/API_DeleteAccountSetting.html

        :stability: experimental
        '''
        return typing.cast("Ecs", jsii.invoke(self, "toDeleteAccountSetting", []))

    @jsii.member(jsii_name="toDeleteAttributes")
    def to_delete_attributes(self) -> "Ecs":
        '''(experimental) Grants permission to delete one or more custom attributes from an Amazon ECS resource.

        Access Level: Write

        Possible conditions:

        - .ifCluster()

        https://docs.aws.amazon.com/AmazonECS/latest/APIReference/API_DeleteAttributes.html

        :stability: experimental
        '''
        return typing.cast("Ecs", jsii.invoke(self, "toDeleteAttributes", []))

    @jsii.member(jsii_name="toDeleteCapacityProvider")
    def to_delete_capacity_provider(self) -> "Ecs":
        '''(experimental) Grants permission to delete the specified capacity provider.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonECS/latest/APIReference/API_DeleteCapacityProvider.html

        :stability: experimental
        '''
        return typing.cast("Ecs", jsii.invoke(self, "toDeleteCapacityProvider", []))

    @jsii.member(jsii_name="toDeleteCluster")
    def to_delete_cluster(self) -> "Ecs":
        '''(experimental) Grants permission to delete the specified cluster.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonECS/latest/APIReference/API_DeleteCluster.html

        :stability: experimental
        '''
        return typing.cast("Ecs", jsii.invoke(self, "toDeleteCluster", []))

    @jsii.member(jsii_name="toDeleteService")
    def to_delete_service(self) -> "Ecs":
        '''(experimental) Grants permission to delete a specified service within a cluster.

        Access Level: Write

        Possible conditions:

        - .ifCluster()

        https://docs.aws.amazon.com/AmazonECS/latest/APIReference/API_DeleteService.html

        :stability: experimental
        '''
        return typing.cast("Ecs", jsii.invoke(self, "toDeleteService", []))

    @jsii.member(jsii_name="toDeleteTaskSet")
    def to_delete_task_set(self) -> "Ecs":
        '''(experimental) Grants permission to delete the specified task set.

        Access Level: Write

        Possible conditions:

        - .ifCluster()
        - .ifService()

        https://docs.aws.amazon.com/AmazonECS/latest/APIReference/API_DeleteTaskSet.html

        :stability: experimental
        '''
        return typing.cast("Ecs", jsii.invoke(self, "toDeleteTaskSet", []))

    @jsii.member(jsii_name="toDeregisterContainerInstance")
    def to_deregister_container_instance(self) -> "Ecs":
        '''(experimental) Grants permission to deregister an Amazon ECS container instance from the specified cluster.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonECS/latest/APIReference/API_DeregisterContainerInstance.html

        :stability: experimental
        '''
        return typing.cast("Ecs", jsii.invoke(self, "toDeregisterContainerInstance", []))

    @jsii.member(jsii_name="toDeregisterTaskDefinition")
    def to_deregister_task_definition(self) -> "Ecs":
        '''(experimental) Grants permission to deregister the specified task definition by family and revision.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonECS/latest/APIReference/API_DeregisterTaskDefinition.html

        :stability: experimental
        '''
        return typing.cast("Ecs", jsii.invoke(self, "toDeregisterTaskDefinition", []))

    @jsii.member(jsii_name="toDescribeCapacityProviders")
    def to_describe_capacity_providers(self) -> "Ecs":
        '''(experimental) Grants permission to describe one or more Amazon ECS capacity providers.

        Access Level: Read

        https://docs.aws.amazon.com/AmazonECS/latest/APIReference/API_DescribeCapacityProviders.html

        :stability: experimental
        '''
        return typing.cast("Ecs", jsii.invoke(self, "toDescribeCapacityProviders", []))

    @jsii.member(jsii_name="toDescribeClusters")
    def to_describe_clusters(self) -> "Ecs":
        '''(experimental) Grants permission to describes one or more of your clusters.

        Access Level: Read

        https://docs.aws.amazon.com/AmazonECS/latest/APIReference/API_DescribeClusters.html

        :stability: experimental
        '''
        return typing.cast("Ecs", jsii.invoke(self, "toDescribeClusters", []))

    @jsii.member(jsii_name="toDescribeContainerInstances")
    def to_describe_container_instances(self) -> "Ecs":
        '''(experimental) Grants permission to describes Amazon ECS container instances.

        Access Level: Read

        Possible conditions:

        - .ifCluster()

        https://docs.aws.amazon.com/AmazonECS/latest/APIReference/API_DescribeContainerInstances.html

        :stability: experimental
        '''
        return typing.cast("Ecs", jsii.invoke(self, "toDescribeContainerInstances", []))

    @jsii.member(jsii_name="toDescribeServices")
    def to_describe_services(self) -> "Ecs":
        '''(experimental) Grants permission to describe the specified services running in your cluster.

        Access Level: Read

        Possible conditions:

        - .ifCluster()

        https://docs.aws.amazon.com/AmazonECS/latest/APIReference/API_DescribeServices.html

        :stability: experimental
        '''
        return typing.cast("Ecs", jsii.invoke(self, "toDescribeServices", []))

    @jsii.member(jsii_name="toDescribeTaskDefinition")
    def to_describe_task_definition(self) -> "Ecs":
        '''(experimental) Grants permission to describe a task definition.

        You can specify a family and revision to find information about a specific task definition, or you can simply specify the family to find the latest ACTIVE revision in that family

        Access Level: Read

        https://docs.aws.amazon.com/AmazonECS/latest/APIReference/API_DescribeTaskDefinition.html

        :stability: experimental
        '''
        return typing.cast("Ecs", jsii.invoke(self, "toDescribeTaskDefinition", []))

    @jsii.member(jsii_name="toDescribeTasks")
    def to_describe_tasks(self) -> "Ecs":
        '''(experimental) Grants permission to describe a specified task or tasks.

        Access Level: Read

        Possible conditions:

        - .ifCluster()

        https://docs.aws.amazon.com/AmazonECS/latest/APIReference/API_DescribeTasks.html

        :stability: experimental
        '''
        return typing.cast("Ecs", jsii.invoke(self, "toDescribeTasks", []))

    @jsii.member(jsii_name="toDescribeTaskSets")
    def to_describe_task_sets(self) -> "Ecs":
        '''(experimental) Grants permission to describe Amazon ECS task sets.

        Access Level: Read

        Possible conditions:

        - .ifCluster()
        - .ifService()

        https://docs.aws.amazon.com/AmazonECS/latest/APIReference/API_DescribeTaskSets.html

        :stability: experimental
        '''
        return typing.cast("Ecs", jsii.invoke(self, "toDescribeTaskSets", []))

    @jsii.member(jsii_name="toDiscoverPollEndpoint")
    def to_discover_poll_endpoint(self) -> "Ecs":
        '''(experimental) Grants permission to get an endpoint for the Amazon ECS agent to poll for updates.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonECS/latest/APIReference/API_DiscoverPollEndpoint.html

        :stability: experimental
        '''
        return typing.cast("Ecs", jsii.invoke(self, "toDiscoverPollEndpoint", []))

    @jsii.member(jsii_name="toExecuteCommand")
    def to_execute_command(self) -> "Ecs":
        '''(experimental) Grants permission to run a command remotely on an Amazon ECS container.

        Access Level: Write

        Possible conditions:

        - .ifCluster()
        - .ifContainerName()
        - .ifTask()

        https://docs.aws.amazon.com/AmazonECS/latest/APIReference/API_ExecuteCommand.html

        :stability: experimental
        '''
        return typing.cast("Ecs", jsii.invoke(self, "toExecuteCommand", []))

    @jsii.member(jsii_name="toListAccountSettings")
    def to_list_account_settings(self) -> "Ecs":
        '''(experimental) Grants permission to list the account settings for an Amazon ECS resource for a specified principal.

        Access Level: Read

        https://docs.aws.amazon.com/AmazonECS/latest/APIReference/API_ListAccountSettings.html

        :stability: experimental
        '''
        return typing.cast("Ecs", jsii.invoke(self, "toListAccountSettings", []))

    @jsii.member(jsii_name="toListAttributes")
    def to_list_attributes(self) -> "Ecs":
        '''(experimental) Grants permission to lists the attributes for Amazon ECS resources within a specified target type and cluster.

        Access Level: List

        https://docs.aws.amazon.com/AmazonECS/latest/APIReference/API_ListAttributes.html

        :stability: experimental
        '''
        return typing.cast("Ecs", jsii.invoke(self, "toListAttributes", []))

    @jsii.member(jsii_name="toListClusters")
    def to_list_clusters(self) -> "Ecs":
        '''(experimental) Grants permission to get a list of existing clusters.

        Access Level: List

        https://docs.aws.amazon.com/AmazonECS/latest/APIReference/API_ListClusters.html

        :stability: experimental
        '''
        return typing.cast("Ecs", jsii.invoke(self, "toListClusters", []))

    @jsii.member(jsii_name="toListContainerInstances")
    def to_list_container_instances(self) -> "Ecs":
        '''(experimental) Grants permission to get a list of container instances in a specified cluster.

        Access Level: List

        https://docs.aws.amazon.com/AmazonECS/latest/APIReference/API_ListContainerInstances.html

        :stability: experimental
        '''
        return typing.cast("Ecs", jsii.invoke(self, "toListContainerInstances", []))

    @jsii.member(jsii_name="toListServices")
    def to_list_services(self) -> "Ecs":
        '''(experimental) Grants permission to get a list of services that are running in a specified cluster.

        Access Level: List

        Possible conditions:

        - .ifCluster()

        https://docs.aws.amazon.com/AmazonECS/latest/APIReference/API_ListServices.html

        :stability: experimental
        '''
        return typing.cast("Ecs", jsii.invoke(self, "toListServices", []))

    @jsii.member(jsii_name="toListServicesByNamespace")
    def to_list_services_by_namespace(self) -> "Ecs":
        '''(experimental) Grants permission to get a list of services that are running in a specified AWS Cloud Map Namespace.

        Access Level: List

        Possible conditions:

        - .ifNamespace()

        https://docs.aws.amazon.com/AmazonECS/latest/APIReference/API_ListServicesByNamespace.html

        :stability: experimental
        '''
        return typing.cast("Ecs", jsii.invoke(self, "toListServicesByNamespace", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Ecs":
        '''(experimental) Grants permission to get a list of tags for the specified resource.

        Access Level: Read

        https://docs.aws.amazon.com/AmazonECS/latest/APIReference/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("Ecs", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toListTaskDefinitionFamilies")
    def to_list_task_definition_families(self) -> "Ecs":
        '''(experimental) Grants permission to get a list of task definition families that are registered to your account (which may include task definition families that no longer have any ACTIVE task definitions).

        Access Level: List

        https://docs.aws.amazon.com/AmazonECS/latest/APIReference/API_ListServices.html

        :stability: experimental
        '''
        return typing.cast("Ecs", jsii.invoke(self, "toListTaskDefinitionFamilies", []))

    @jsii.member(jsii_name="toListTaskDefinitions")
    def to_list_task_definitions(self) -> "Ecs":
        '''(experimental) Grants permission to get a list of task definitions that are registered to your account.

        Access Level: List

        https://docs.aws.amazon.com/AmazonECS/latest/APIReference/API_ListTaskDefinitions.html

        :stability: experimental
        '''
        return typing.cast("Ecs", jsii.invoke(self, "toListTaskDefinitions", []))

    @jsii.member(jsii_name="toListTasks")
    def to_list_tasks(self) -> "Ecs":
        '''(experimental) Grants permission to get a list of tasks for a specified cluster.

        Access Level: List

        Possible conditions:

        - .ifCluster()

        https://docs.aws.amazon.com/AmazonECS/latest/APIReference/API_ListTasks.html

        :stability: experimental
        '''
        return typing.cast("Ecs", jsii.invoke(self, "toListTasks", []))

    @jsii.member(jsii_name="toPoll")
    def to_poll(self) -> "Ecs":
        '''(experimental) Grants permission to an agent to connect with the Amazon ECS service to report status and get commands.

        Access Level: Write

        Possible conditions:

        - .ifCluster()

        https://docs.aws.amazon.com/AmazonECS/latest/developerguide/instance_IAM_role.html

        :stability: experimental
        '''
        return typing.cast("Ecs", jsii.invoke(self, "toPoll", []))

    @jsii.member(jsii_name="toPutAccountSetting")
    def to_put_account_setting(self) -> "Ecs":
        '''(experimental) Grants permission to modify the ARN and resource ID format of a resource for a specified IAM user, IAM role, or the root user for an account.

        You can specify whether the new ARN and resource ID format are enabled for new resources that are created. Enabling this setting is required to use new Amazon ECS features such as resource tagging

        Access Level: Write

        https://docs.aws.amazon.com/AmazonECS/latest/APIReference/API_PutAccountSetting.html

        :stability: experimental
        '''
        return typing.cast("Ecs", jsii.invoke(self, "toPutAccountSetting", []))

    @jsii.member(jsii_name="toPutAccountSettingDefault")
    def to_put_account_setting_default(self) -> "Ecs":
        '''(experimental) Grants permission to modify the ARN and resource ID format of a resource type for all IAM users on an account for which no individual account setting has been set.

        Enabling this setting is required to use new Amazon ECS features such as resource tagging

        Access Level: Write

        https://docs.aws.amazon.com/AmazonECS/latest/APIReference/API_PutAccountSettingDefault.html

        :stability: experimental
        '''
        return typing.cast("Ecs", jsii.invoke(self, "toPutAccountSettingDefault", []))

    @jsii.member(jsii_name="toPutAttributes")
    def to_put_attributes(self) -> "Ecs":
        '''(experimental) Grants permission to create or update an attribute on an Amazon ECS resource.

        Access Level: Write

        Possible conditions:

        - .ifCluster()

        https://docs.aws.amazon.com/AmazonECS/latest/APIReference/API_PutAttributes.html

        :stability: experimental
        '''
        return typing.cast("Ecs", jsii.invoke(self, "toPutAttributes", []))

    @jsii.member(jsii_name="toPutClusterCapacityProviders")
    def to_put_cluster_capacity_providers(self) -> "Ecs":
        '''(experimental) Grants permission to modify the available capacity providers and the default capacity provider strategy for a cluster.

        Access Level: Write

        Possible conditions:

        - .ifCapacityProvider()

        https://docs.aws.amazon.com/AmazonECS/latest/APIReference/API_PutClusterCapacityProviders.html

        :stability: experimental
        '''
        return typing.cast("Ecs", jsii.invoke(self, "toPutClusterCapacityProviders", []))

    @jsii.member(jsii_name="toRegisterContainerInstance")
    def to_register_container_instance(self) -> "Ecs":
        '''(experimental) Grants permission to register an EC2 instance into the specified cluster.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/AmazonECS/latest/APIReference/API_RegisterContainerInstance.html

        :stability: experimental
        '''
        return typing.cast("Ecs", jsii.invoke(self, "toRegisterContainerInstance", []))

    @jsii.member(jsii_name="toRegisterTaskDefinition")
    def to_register_task_definition(self) -> "Ecs":
        '''(experimental) Grants permission to register a new task definition from the supplied family and containerDefinitions.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/AmazonECS/latest/APIReference/API_RegisterTaskDefinition.html

        :stability: experimental
        '''
        return typing.cast("Ecs", jsii.invoke(self, "toRegisterTaskDefinition", []))

    @jsii.member(jsii_name="toRunTask")
    def to_run_task(self) -> "Ecs":
        '''(experimental) Grants permission to start a task using random placement and the default Amazon ECS scheduler.

        Access Level: Write

        Possible conditions:

        - .ifCluster()
        - .ifCapacityProvider()
        - .ifEnableExecuteCommand()
        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/AmazonECS/latest/APIReference/API_RunTask.html

        :stability: experimental
        '''
        return typing.cast("Ecs", jsii.invoke(self, "toRunTask", []))

    @jsii.member(jsii_name="toStartTask")
    def to_start_task(self) -> "Ecs":
        '''(experimental) Grants permission to start a new task from the specified task definition on the specified container instance or instances.

        Access Level: Write

        Possible conditions:

        - .ifCluster()
        - .ifContainerInstances()
        - .ifEnableExecuteCommand()
        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/AmazonECS/latest/APIReference/API_StartTask.html

        :stability: experimental
        '''
        return typing.cast("Ecs", jsii.invoke(self, "toStartTask", []))

    @jsii.member(jsii_name="toStartTelemetrySession")
    def to_start_telemetry_session(self) -> "Ecs":
        '''(experimental) Grants permission to start a telemetry session.

        Access Level: Write

        Possible conditions:

        - .ifCluster()

        https://docs.aws.amazon.com/AmazonECS/latest/developerguide/cloudwatch-metrics.html#enable_cloudwatch

        :stability: experimental
        '''
        return typing.cast("Ecs", jsii.invoke(self, "toStartTelemetrySession", []))

    @jsii.member(jsii_name="toStopTask")
    def to_stop_task(self) -> "Ecs":
        '''(experimental) Grants permission to stop a running task.

        Access Level: Write

        Possible conditions:

        - .ifCluster()

        https://docs.aws.amazon.com/AmazonECS/latest/APIReference/API_StopTask.html

        :stability: experimental
        '''
        return typing.cast("Ecs", jsii.invoke(self, "toStopTask", []))

    @jsii.member(jsii_name="toSubmitAttachmentStateChanges")
    def to_submit_attachment_state_changes(self) -> "Ecs":
        '''(experimental) Grants permission to send an acknowledgement that attachments changed states.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonECS/latest/APIReference/API_SubmitAttachmentStateChanges.html

        :stability: experimental
        '''
        return typing.cast("Ecs", jsii.invoke(self, "toSubmitAttachmentStateChanges", []))

    @jsii.member(jsii_name="toSubmitContainerStateChange")
    def to_submit_container_state_change(self) -> "Ecs":
        '''(experimental) Grants permission to send an acknowledgement that a container changed states.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonECS/latest/APIReference/API_SubmitContainerStateChange.html

        :stability: experimental
        '''
        return typing.cast("Ecs", jsii.invoke(self, "toSubmitContainerStateChange", []))

    @jsii.member(jsii_name="toSubmitTaskStateChange")
    def to_submit_task_state_change(self) -> "Ecs":
        '''(experimental) Grants permission to send an acknowledgement that a task changed states.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonECS/latest/APIReference/API_SubmitTaskStateChange.html

        :stability: experimental
        '''
        return typing.cast("Ecs", jsii.invoke(self, "toSubmitTaskStateChange", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Ecs":
        '''(experimental) Grants permission to tag the specified resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/AmazonECS/latest/APIReference/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("Ecs", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Ecs":
        '''(experimental) Grants permission to untag the specified resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/AmazonECS/latest/APIReference/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("Ecs", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateCapacityProvider")
    def to_update_capacity_provider(self) -> "Ecs":
        '''(experimental) Grants permission to update the specified capacity provider.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonECS/latest/APIReference/API_UpdateCapacityProvider.html

        :stability: experimental
        '''
        return typing.cast("Ecs", jsii.invoke(self, "toUpdateCapacityProvider", []))

    @jsii.member(jsii_name="toUpdateCluster")
    def to_update_cluster(self) -> "Ecs":
        '''(experimental) Grants permission to modify the configuration or settings to use for a cluster.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonECS/latest/APIReference/API_UpdateCluster.html

        :stability: experimental
        '''
        return typing.cast("Ecs", jsii.invoke(self, "toUpdateCluster", []))

    @jsii.member(jsii_name="toUpdateClusterSettings")
    def to_update_cluster_settings(self) -> "Ecs":
        '''(experimental) Grants permission to modify the settings to use for a cluster.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonECS/latest/APIReference/API_UpdateClusterSettings.html

        :stability: experimental
        '''
        return typing.cast("Ecs", jsii.invoke(self, "toUpdateClusterSettings", []))

    @jsii.member(jsii_name="toUpdateContainerAgent")
    def to_update_container_agent(self) -> "Ecs":
        '''(experimental) Grants permission to update the Amazon ECS container agent on a specified container instance.

        Access Level: Write

        Possible conditions:

        - .ifCluster()

        https://docs.aws.amazon.com/AmazonECS/latest/APIReference/API_UpdateContainerAgent.html

        :stability: experimental
        '''
        return typing.cast("Ecs", jsii.invoke(self, "toUpdateContainerAgent", []))

    @jsii.member(jsii_name="toUpdateContainerInstancesState")
    def to_update_container_instances_state(self) -> "Ecs":
        '''(experimental) Grants permission to the user to modify the status of an Amazon ECS container instance.

        Access Level: Write

        Possible conditions:

        - .ifCluster()

        https://docs.aws.amazon.com/AmazonECS/latest/APIReference/API_UpdateContainerInstancesState.html

        :stability: experimental
        '''
        return typing.cast("Ecs", jsii.invoke(self, "toUpdateContainerInstancesState", []))

    @jsii.member(jsii_name="toUpdateService")
    def to_update_service(self) -> "Ecs":
        '''(experimental) Grants permission to modify the parameters of a service.

        Access Level: Write

        Possible conditions:

        - .ifCluster()
        - .ifCapacityProvider()
        - .ifEnableExecuteCommand()
        - .ifEnableServiceConnect()
        - .ifNamespace()
        - .ifTaskDefinition()

        https://docs.aws.amazon.com/AmazonECS/latest/APIReference/API_UpdateService.html

        :stability: experimental
        '''
        return typing.cast("Ecs", jsii.invoke(self, "toUpdateService", []))

    @jsii.member(jsii_name="toUpdateServicePrimaryTaskSet")
    def to_update_service_primary_task_set(self) -> "Ecs":
        '''(experimental) Grants permission to modify the primary task set used in a service.

        Access Level: Write

        Possible conditions:

        - .ifCluster()

        https://docs.aws.amazon.com/AmazonECS/latest/APIReference/API_UpdateServicePrimaryTaskSet.html

        :stability: experimental
        '''
        return typing.cast("Ecs", jsii.invoke(self, "toUpdateServicePrimaryTaskSet", []))

    @jsii.member(jsii_name="toUpdateTaskSet")
    def to_update_task_set(self) -> "Ecs":
        '''(experimental) Grants permission to update the specified task set.

        Access Level: Write

        Possible conditions:

        - .ifCluster()
        - .ifService()

        https://docs.aws.amazon.com/AmazonECS/latest/APIReference/API_UpdateTaskSet.html

        :stability: experimental
        '''
        return typing.cast("Ecs", jsii.invoke(self, "toUpdateTaskSet", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__58f6d8a08788c3f432c57a1708c69f4a10a65e6d6675f886f6ce6fb00abe6c0c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b35443e45f47e33a6c50444f5573fed0a8f3663835848c1d4913d074e0d71ddf)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Eks(PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Eks"):
    '''(experimental) Statement provider for service `eks <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonelastickubernetesservice.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `eks <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonelastickubernetesservice.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="ifClientId")
    def if_client_id(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Eks":
        '''(experimental) Filters access by the clientId present in the associateIdentityProviderConfig request the user makes to the EKS service.

        https://docs.aws.amazon.com/eks/latest/userguide/security_iam_service-with-iam.html#security_iam_service-with-iam-id-based-policies

        Applies to actions:

        - .toAssociateIdentityProviderConfig()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e82c7b902d6d2d43be10b74ec49f343c07c2b0d4d056beaa746b0ab7c9ecb2ea)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Eks", jsii.invoke(self, "ifClientId", [value, operator]))

    @jsii.member(jsii_name="ifIssuerUrl")
    def if_issuer_url(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Eks":
        '''(experimental) Filters access by the issuerUrl present in the associateIdentityProviderConfig request the user makes to the EKS service.

        https://docs.aws.amazon.com/eks/latest/userguide/security_iam_service-with-iam.html#security_iam_service-with-iam-id-based-policies

        Applies to actions:

        - .toAssociateIdentityProviderConfig()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6c2933c5b14da3bf46f1248362ea8547bb26403962b2ed12a7050eb18ab00e89)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Eks", jsii.invoke(self, "ifIssuerUrl", [value, operator]))

    @jsii.member(jsii_name="onAddon")
    def on_addon(
        self,
        cluster_name: builtins.str,
        addon_name: builtins.str,
        u_uid: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Eks":
        '''(experimental) Adds a resource of type addon to the statement.

        https://docs.aws.amazon.com/eks/latest/userguide/managed-addons.html

        :param cluster_name: - Identifier for the clusterName.
        :param addon_name: - Identifier for the addonName.
        :param u_uid: - Identifier for the uUID.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9ae32778e4314d268e8bc8a7cf70cca6f8aa556f5388763085dd0015e77352d8)
            check_type(argname="argument cluster_name", value=cluster_name, expected_type=type_hints["cluster_name"])
            check_type(argname="argument addon_name", value=addon_name, expected_type=type_hints["addon_name"])
            check_type(argname="argument u_uid", value=u_uid, expected_type=type_hints["u_uid"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Eks", jsii.invoke(self, "onAddon", [cluster_name, addon_name, u_uid, account, region, partition]))

    @jsii.member(jsii_name="onCluster")
    def on_cluster(
        self,
        cluster_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Eks":
        '''(experimental) Adds a resource of type cluster to the statement.

        https://docs.aws.amazon.com/eks/latest/userguide/clusters.html

        :param cluster_name: - Identifier for the clusterName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9f1826aa4b08d47232341ee48d1eb555dce722244ff25cb429d9f3aadc975cf4)
            check_type(argname="argument cluster_name", value=cluster_name, expected_type=type_hints["cluster_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Eks", jsii.invoke(self, "onCluster", [cluster_name, account, region, partition]))

    @jsii.member(jsii_name="onFargateprofile")
    def on_fargateprofile(
        self,
        cluster_name: builtins.str,
        fargate_profile_name: builtins.str,
        u_uid: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Eks":
        '''(experimental) Adds a resource of type fargateprofile to the statement.

        https://docs.aws.amazon.com/eks/latest/userguide/fargate-profile.html

        :param cluster_name: - Identifier for the clusterName.
        :param fargate_profile_name: - Identifier for the fargateProfileName.
        :param u_uid: - Identifier for the uUID.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2423bcc9f9bcb834c52d4d73094159699d7e9b393159c8daba3e2dc37814a209)
            check_type(argname="argument cluster_name", value=cluster_name, expected_type=type_hints["cluster_name"])
            check_type(argname="argument fargate_profile_name", value=fargate_profile_name, expected_type=type_hints["fargate_profile_name"])
            check_type(argname="argument u_uid", value=u_uid, expected_type=type_hints["u_uid"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Eks", jsii.invoke(self, "onFargateprofile", [cluster_name, fargate_profile_name, u_uid, account, region, partition]))

    @jsii.member(jsii_name="onIdentityproviderconfig")
    def on_identityproviderconfig(
        self,
        cluster_name: builtins.str,
        identity_provider_type: builtins.str,
        identity_provider_config_name: builtins.str,
        u_uid: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Eks":
        '''(experimental) Adds a resource of type identityproviderconfig to the statement.

        https://docs.aws.amazon.com/eks/latest/userguide/authenticate-oidc-identity-provider.html

        :param cluster_name: - Identifier for the clusterName.
        :param identity_provider_type: - Identifier for the identityProviderType.
        :param identity_provider_config_name: - Identifier for the identityProviderConfigName.
        :param u_uid: - Identifier for the uUID.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1e553a7b8c66b2ff7b315d00ba5480c57606bdd67eb1ed11b30df42547343810)
            check_type(argname="argument cluster_name", value=cluster_name, expected_type=type_hints["cluster_name"])
            check_type(argname="argument identity_provider_type", value=identity_provider_type, expected_type=type_hints["identity_provider_type"])
            check_type(argname="argument identity_provider_config_name", value=identity_provider_config_name, expected_type=type_hints["identity_provider_config_name"])
            check_type(argname="argument u_uid", value=u_uid, expected_type=type_hints["u_uid"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Eks", jsii.invoke(self, "onIdentityproviderconfig", [cluster_name, identity_provider_type, identity_provider_config_name, u_uid, account, region, partition]))

    @jsii.member(jsii_name="onNodegroup")
    def on_nodegroup(
        self,
        cluster_name: builtins.str,
        nodegroup_name: builtins.str,
        u_uid: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Eks":
        '''(experimental) Adds a resource of type nodegroup to the statement.

        https://docs.aws.amazon.com/eks/latest/userguide/managed-node-groups.html

        :param cluster_name: - Identifier for the clusterName.
        :param nodegroup_name: - Identifier for the nodegroupName.
        :param u_uid: - Identifier for the uUID.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4b18c1ed890e4a14119e1486282bcfb0eee941dfc2438a432688780bee11f8c1)
            check_type(argname="argument cluster_name", value=cluster_name, expected_type=type_hints["cluster_name"])
            check_type(argname="argument nodegroup_name", value=nodegroup_name, expected_type=type_hints["nodegroup_name"])
            check_type(argname="argument u_uid", value=u_uid, expected_type=type_hints["u_uid"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Eks", jsii.invoke(self, "onNodegroup", [cluster_name, nodegroup_name, u_uid, account, region, partition]))

    @jsii.member(jsii_name="toAccessKubernetesApi")
    def to_access_kubernetes_api(self) -> "Eks":
        '''(experimental) Grants permission to view Kubernetes objects via AWS EKS console.

        Access Level: Read

        https://docs.aws.amazon.com/eks/latest/userguide/view-workloads.html

        :stability: experimental
        '''
        return typing.cast("Eks", jsii.invoke(self, "toAccessKubernetesApi", []))

    @jsii.member(jsii_name="toAssociateEncryptionConfig")
    def to_associate_encryption_config(self) -> "Eks":
        '''(experimental) Grants permission to associate encryption configuration to a cluster.

        Access Level: Write

        https://docs.aws.amazon.com/eks/latest/APIReference/API_AssociateEncryptionConfig.html

        :stability: experimental
        '''
        return typing.cast("Eks", jsii.invoke(self, "toAssociateEncryptionConfig", []))

    @jsii.member(jsii_name="toAssociateIdentityProviderConfig")
    def to_associate_identity_provider_config(self) -> "Eks":
        '''(experimental) Grants permission to associate an identity provider configuration to a cluster.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifClientId()
        - .ifIssuerUrl()

        https://docs.aws.amazon.com/eks/latest/APIReference/API_AssociateIdentityProviderConfig.html

        :stability: experimental
        '''
        return typing.cast("Eks", jsii.invoke(self, "toAssociateIdentityProviderConfig", []))

    @jsii.member(jsii_name="toCreateAddon")
    def to_create_addon(self) -> "Eks":
        '''(experimental) Grants permission to create an Amazon EKS add-on.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/eks/latest/APIReference/API_CreateAddon.html

        :stability: experimental
        '''
        return typing.cast("Eks", jsii.invoke(self, "toCreateAddon", []))

    @jsii.member(jsii_name="toCreateCluster")
    def to_create_cluster(self) -> "Eks":
        '''(experimental) Grants permission to create an Amazon EKS cluster.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/eks/latest/APIReference/API_CreateCluster.html

        :stability: experimental
        '''
        return typing.cast("Eks", jsii.invoke(self, "toCreateCluster", []))

    @jsii.member(jsii_name="toCreateFargateProfile")
    def to_create_fargate_profile(self) -> "Eks":
        '''(experimental) Grants permission to create an AWS Fargate profile.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/eks/latest/APIReference/API_CreateFargateProfile.html

        :stability: experimental
        '''
        return typing.cast("Eks", jsii.invoke(self, "toCreateFargateProfile", []))

    @jsii.member(jsii_name="toCreateNodegroup")
    def to_create_nodegroup(self) -> "Eks":
        '''(experimental) Grants permission to create an Amazon EKS Nodegroup.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/eks/latest/APIReference/API_CreateNodegroup.html

        :stability: experimental
        '''
        return typing.cast("Eks", jsii.invoke(self, "toCreateNodegroup", []))

    @jsii.member(jsii_name="toDeleteAddon")
    def to_delete_addon(self) -> "Eks":
        '''(experimental) Grants permission to delete an Amazon EKS add-on.

        Access Level: Write

        https://docs.aws.amazon.com/eks/latest/APIReference/API_DeleteAddon.html

        :stability: experimental
        '''
        return typing.cast("Eks", jsii.invoke(self, "toDeleteAddon", []))

    @jsii.member(jsii_name="toDeleteCluster")
    def to_delete_cluster(self) -> "Eks":
        '''(experimental) Grants permission to delete an Amazon EKS cluster.

        Access Level: Write

        https://docs.aws.amazon.com/eks/latest/APIReference/API_DeleteCluster.html

        :stability: experimental
        '''
        return typing.cast("Eks", jsii.invoke(self, "toDeleteCluster", []))

    @jsii.member(jsii_name="toDeleteFargateProfile")
    def to_delete_fargate_profile(self) -> "Eks":
        '''(experimental) Grants permission to delete an AWS Fargate profile.

        Access Level: Write

        https://docs.aws.amazon.com/eks/latest/APIReference/API_DeleteFargateProfile.html

        :stability: experimental
        '''
        return typing.cast("Eks", jsii.invoke(self, "toDeleteFargateProfile", []))

    @jsii.member(jsii_name="toDeleteNodegroup")
    def to_delete_nodegroup(self) -> "Eks":
        '''(experimental) Grants permission to delete an Amazon EKS Nodegroup.

        Access Level: Write

        https://docs.aws.amazon.com/eks/latest/APIReference/API_DeleteNodegroup.html

        :stability: experimental
        '''
        return typing.cast("Eks", jsii.invoke(self, "toDeleteNodegroup", []))

    @jsii.member(jsii_name="toDeregisterCluster")
    def to_deregister_cluster(self) -> "Eks":
        '''(experimental) Grants permission to deregister an External cluster.

        Access Level: Write

        https://docs.aws.amazon.com/eks/latest/APIReference/API_DeregisterCluster.html

        :stability: experimental
        '''
        return typing.cast("Eks", jsii.invoke(self, "toDeregisterCluster", []))

    @jsii.member(jsii_name="toDescribeAddon")
    def to_describe_addon(self) -> "Eks":
        '''(experimental) Grants permission to retrieve descriptive information about an Amazon EKS add-on.

        Access Level: Read

        https://docs.aws.amazon.com/eks/latest/APIReference/API_DescribeAddon.html

        :stability: experimental
        '''
        return typing.cast("Eks", jsii.invoke(self, "toDescribeAddon", []))

    @jsii.member(jsii_name="toDescribeAddonVersions")
    def to_describe_addon_versions(self) -> "Eks":
        '''(experimental) Grants permission to retrieve descriptive version information about the add-ons that Amazon EKS Add-ons supports.

        Access Level: Read

        https://docs.aws.amazon.com/eks/latest/APIReference/API_DescribeAddonVersions.html

        :stability: experimental
        '''
        return typing.cast("Eks", jsii.invoke(self, "toDescribeAddonVersions", []))

    @jsii.member(jsii_name="toDescribeCluster")
    def to_describe_cluster(self) -> "Eks":
        '''(experimental) Grants permission to retrieve descriptive information about an Amazon EKS cluster.

        Access Level: Read

        https://docs.aws.amazon.com/eks/latest/APIReference/API_DescribeCluster.html

        :stability: experimental
        '''
        return typing.cast("Eks", jsii.invoke(self, "toDescribeCluster", []))

    @jsii.member(jsii_name="toDescribeFargateProfile")
    def to_describe_fargate_profile(self) -> "Eks":
        '''(experimental) Grants permission to retrieve descriptive information about an AWS Fargate profile associated with a cluster.

        Access Level: Read

        https://docs.aws.amazon.com/eks/latest/APIReference/API_DescribeFargateProfile.html

        :stability: experimental
        '''
        return typing.cast("Eks", jsii.invoke(self, "toDescribeFargateProfile", []))

    @jsii.member(jsii_name="toDescribeIdentityProviderConfig")
    def to_describe_identity_provider_config(self) -> "Eks":
        '''(experimental) Grants permission to retrieve descriptive information about an Idp config associated with a cluster.

        Access Level: Read

        https://docs.aws.amazon.com/eks/latest/APIReference/API_DescribeIdentityProviderConfig.html

        :stability: experimental
        '''
        return typing.cast("Eks", jsii.invoke(self, "toDescribeIdentityProviderConfig", []))

    @jsii.member(jsii_name="toDescribeNodegroup")
    def to_describe_nodegroup(self) -> "Eks":
        '''(experimental) Grants permission to retrieve descriptive information about an Amazon EKS nodegroup.

        Access Level: Read

        https://docs.aws.amazon.com/eks/latest/APIReference/API_DescribeNodegroup.html

        :stability: experimental
        '''
        return typing.cast("Eks", jsii.invoke(self, "toDescribeNodegroup", []))

    @jsii.member(jsii_name="toDescribeUpdate")
    def to_describe_update(self) -> "Eks":
        '''(experimental) Grants permission to retrieve a given update for a given Amazon EKS cluster/nodegroup/add-on (in the specified or default region).

        Access Level: Read

        https://docs.aws.amazon.com/eks/latest/APIReference/API_DescribeUpdate.html

        :stability: experimental
        '''
        return typing.cast("Eks", jsii.invoke(self, "toDescribeUpdate", []))

    @jsii.member(jsii_name="toDisassociateIdentityProviderConfig")
    def to_disassociate_identity_provider_config(self) -> "Eks":
        '''(experimental) Grants permission to delete an asssociated Idp config.

        Access Level: Write

        https://docs.aws.amazon.com/eks/latest/APIReference/API_DisassociateIdentityProviderConfig.html

        :stability: experimental
        '''
        return typing.cast("Eks", jsii.invoke(self, "toDisassociateIdentityProviderConfig", []))

    @jsii.member(jsii_name="toListAddons")
    def to_list_addons(self) -> "Eks":
        '''(experimental) Grants permission to list the Amazon EKS add-ons in your AWS account (in the specified or default region) for a given cluster.

        Access Level: List

        https://docs.aws.amazon.com/eks/latest/APIReference/API_ListAddons.html

        :stability: experimental
        '''
        return typing.cast("Eks", jsii.invoke(self, "toListAddons", []))

    @jsii.member(jsii_name="toListClusters")
    def to_list_clusters(self) -> "Eks":
        '''(experimental) Grants permission to list the Amazon EKS clusters in your AWS account (in the specified or default region).

        Access Level: List

        https://docs.aws.amazon.com/eks/latest/APIReference/API_ListClusters.html

        :stability: experimental
        '''
        return typing.cast("Eks", jsii.invoke(self, "toListClusters", []))

    @jsii.member(jsii_name="toListFargateProfiles")
    def to_list_fargate_profiles(self) -> "Eks":
        '''(experimental) Grants permission to list the AWS Fargate profiles in your AWS account (in the specified or default region) associated with a given cluster.

        Access Level: List

        https://docs.aws.amazon.com/eks/latest/APIReference/API_ListFargateProfiles.html

        :stability: experimental
        '''
        return typing.cast("Eks", jsii.invoke(self, "toListFargateProfiles", []))

    @jsii.member(jsii_name="toListIdentityProviderConfigs")
    def to_list_identity_provider_configs(self) -> "Eks":
        '''(experimental) Grants permission to list the Idp configs in your AWS account (in the specified or default region) associated with a given cluster.

        Access Level: List

        https://docs.aws.amazon.com/eks/latest/APIReference/API_ListIdentityProviderConfigs.html

        :stability: experimental
        '''
        return typing.cast("Eks", jsii.invoke(self, "toListIdentityProviderConfigs", []))

    @jsii.member(jsii_name="toListNodegroups")
    def to_list_nodegroups(self) -> "Eks":
        '''(experimental) Grants permission to list the Amazon EKS nodegroups in your AWS account (in the specified or default region) attached to given cluster.

        Access Level: List

        https://docs.aws.amazon.com/eks/latest/APIReference/API_ListNodegroups.html

        :stability: experimental
        '''
        return typing.cast("Eks", jsii.invoke(self, "toListNodegroups", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Eks":
        '''(experimental) Grants permission to list tags for the specified resource.

        Access Level: Read

        https://docs.aws.amazon.com/eks/latest/APIReference/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("Eks", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toListUpdates")
    def to_list_updates(self) -> "Eks":
        '''(experimental) Grants permission to list the updates for a given Amazon EKS cluster/nodegroup/add-on (in the specified or default region).

        Access Level: List

        https://docs.aws.amazon.com/eks/latest/APIReference/API_ListUpdates.html

        :stability: experimental
        '''
        return typing.cast("Eks", jsii.invoke(self, "toListUpdates", []))

    @jsii.member(jsii_name="toRegisterCluster")
    def to_register_cluster(self) -> "Eks":
        '''(experimental) Grants permission to register an External cluster.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/eks/latest/APIReference/API_RegisterCluster.html

        :stability: experimental
        '''
        return typing.cast("Eks", jsii.invoke(self, "toRegisterCluster", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Eks":
        '''(experimental) Grants permission to tag the specified resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/eks/latest/APIReference/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("Eks", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Eks":
        '''(experimental) Grants permission to untag the specified resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/eks/latest/APIReference/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("Eks", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateAddon")
    def to_update_addon(self) -> "Eks":
        '''(experimental) Grants permission to update Amazon EKS add-on configurations, such as the VPC-CNI version.

        Access Level: Write

        https://docs.aws.amazon.com/eks/latest/APIReference/API_UpdateAddon.html

        :stability: experimental
        '''
        return typing.cast("Eks", jsii.invoke(self, "toUpdateAddon", []))

    @jsii.member(jsii_name="toUpdateClusterConfig")
    def to_update_cluster_config(self) -> "Eks":
        '''(experimental) Grants permission to update Amazon EKS cluster configurations (eg: API server endpoint access).

        Access Level: Write

        https://docs.aws.amazon.com/eks/latest/APIReference/API_UpdateClusterConfig.html

        :stability: experimental
        '''
        return typing.cast("Eks", jsii.invoke(self, "toUpdateClusterConfig", []))

    @jsii.member(jsii_name="toUpdateClusterVersion")
    def to_update_cluster_version(self) -> "Eks":
        '''(experimental) Grants permission to update the Kubernetes version of an Amazon EKS cluster.

        Access Level: Write

        https://docs.aws.amazon.com/eks/latest/APIReference/API_UpdateClusterVersion.html

        :stability: experimental
        '''
        return typing.cast("Eks", jsii.invoke(self, "toUpdateClusterVersion", []))

    @jsii.member(jsii_name="toUpdateNodegroupConfig")
    def to_update_nodegroup_config(self) -> "Eks":
        '''(experimental) Grants permission to update Amazon EKS nodegroup configurations (eg: min/max/desired capacity or labels).

        Access Level: Write

        https://docs.aws.amazon.com/eks/latest/APIReference/API_UpdateNodegroupConfig.html

        :stability: experimental
        '''
        return typing.cast("Eks", jsii.invoke(self, "toUpdateNodegroupConfig", []))

    @jsii.member(jsii_name="toUpdateNodegroupVersion")
    def to_update_nodegroup_version(self) -> "Eks":
        '''(experimental) Grants permission to update the Kubernetes version of an Amazon EKS nodegroup.

        Access Level: Write

        https://docs.aws.amazon.com/eks/latest/APIReference/API_UpdateNodegroupVersion.html

        :stability: experimental
        '''
        return typing.cast("Eks", jsii.invoke(self, "toUpdateNodegroupVersion", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__63f441a42f90093ae340329085a9e4a668e292a2cc69b84a803e0fd8be6e9235)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f0d7716049faf0b47b23775ab3be5e07b777dba20db61a94e51eb4268e82dcc0)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class ElasticInference(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.ElasticInference",
):
    '''(experimental) Statement provider for service `elastic-inference <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonelasticinference.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `elastic-inference <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonelasticinference.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onAccelerator")
    def on_accelerator(
        self,
        accelerator_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "ElasticInference":
        '''(experimental) Adds a resource of type accelerator to the statement.

        :param accelerator_id: - Identifier for the acceleratorId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0cbaae26bf5c741593cd6022213bc8ae0276d1d01be38715a3bfc7c353f17322)
            check_type(argname="argument accelerator_id", value=accelerator_id, expected_type=type_hints["accelerator_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("ElasticInference", jsii.invoke(self, "onAccelerator", [accelerator_id, account, region, partition]))

    @jsii.member(jsii_name="toConnect")
    def to_connect(self) -> "ElasticInference":
        '''(experimental) Grants permission to customer for connecting to Elastic Inference accelerator.

        Access Level: Write

        :stability: experimental
        '''
        return typing.cast("ElasticInference", jsii.invoke(self, "toConnect", []))

    @jsii.member(jsii_name="toDescribeAcceleratorOfferings")
    def to_describe_accelerator_offerings(self) -> "ElasticInference":
        '''(experimental) Grants permission to describe the locations in which a given accelerator type or set of types is present in a given region.

        Access Level: List

        :stability: experimental
        '''
        return typing.cast("ElasticInference", jsii.invoke(self, "toDescribeAcceleratorOfferings", []))

    @jsii.member(jsii_name="toDescribeAccelerators")
    def to_describe_accelerators(self) -> "ElasticInference":
        '''(experimental) Grants permission to describe information over a provided set of accelerators belonging to an account.

        Access Level: List

        :stability: experimental
        '''
        return typing.cast("ElasticInference", jsii.invoke(self, "toDescribeAccelerators", []))

    @jsii.member(jsii_name="toDescribeAcceleratorTypes")
    def to_describe_accelerator_types(self) -> "ElasticInference":
        '''(experimental) Grants permission to describe the accelerator types available in a given region, as well as their characteristics, such as memory and throughput.

        Access Level: List

        :stability: experimental
        '''
        return typing.cast("ElasticInference", jsii.invoke(self, "toDescribeAcceleratorTypes", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "ElasticInference":
        '''(experimental) Grants permission to list all tags on an Amazon RDS resource.

        Access Level: Read

        :stability: experimental
        '''
        return typing.cast("ElasticInference", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "ElasticInference":
        '''(experimental) Grants permission to assign one or more tags (key-value pairs) to the specified QuickSight resource.

        Access Level: Tagging

        :stability: experimental
        '''
        return typing.cast("ElasticInference", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "ElasticInference":
        '''(experimental) Grants permission to remove a tag or tags from a resource.

        Access Level: Tagging

        :stability: experimental
        '''
        return typing.cast("ElasticInference", jsii.invoke(self, "toUntagResource", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__943bd6f53e166e7969331fb8ca6cf46dcedf9e2ec2bd2eaffa4df06e9733a408)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2552e528898307836fd1e3578668a93e06771d3e61892f0ed768c0381b325889)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Elasticache(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Elasticache",
):
    '''(experimental) Statement provider for service `elasticache <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonelasticache.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `elasticache <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonelasticache.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="ifAtRestEncryptionEnabled")
    def if_at_rest_encryption_enabled(
        self,
        value: typing.Optional[builtins.bool] = None,
    ) -> "Elasticache":
        '''(experimental) Filters access by the AtRestEncryptionEnabled parameter present in the request or default false value if parameter is not present.

        https://docs.aws.amazon.com/AmazonElastiCache/latest/red-ug/IAM.ConditionKeys.html#IAM.SpecifyingConditions

        Applies to actions:

        - .toCreateReplicationGroup()

        Applies to resource types:

        - replicationgroup
        - globalreplicationgroup

        :param value: ``true`` or ``false``. **Default:** ``true``

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__963add2154c2b0d73199871d72c352073138b0999d2c216f0ed512026256648b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast("Elasticache", jsii.invoke(self, "ifAtRestEncryptionEnabled", [value]))

    @jsii.member(jsii_name="ifAuthTokenEnabled")
    def if_auth_token_enabled(
        self,
        value: typing.Optional[builtins.bool] = None,
    ) -> "Elasticache":
        '''(experimental) Filters access by the presence of non empty AuthToken parameter in the request.

        https://docs.aws.amazon.com/AmazonElastiCache/latest/red-ug/IAM.ConditionKeys.html#IAM.SpecifyingConditions

        Applies to actions:

        - .toCreateCacheCluster()
        - .toCreateReplicationGroup()
        - .toModifyCacheCluster()
        - .toModifyReplicationGroup()

        Applies to resource types:

        - replicationgroup
        - cluster
        - globalreplicationgroup

        :param value: ``true`` or ``false``. **Default:** ``true``

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__80d7095e4e1fb864367e246e95efeac4248e83e22bed95b4d51f132593e847e9)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast("Elasticache", jsii.invoke(self, "ifAuthTokenEnabled", [value]))

    @jsii.member(jsii_name="ifAutomaticFailoverEnabled")
    def if_automatic_failover_enabled(
        self,
        value: typing.Optional[builtins.bool] = None,
    ) -> "Elasticache":
        '''(experimental) Filters access by the AutomaticFailoverEnabled parameter in the request.

        https://docs.aws.amazon.com/AmazonElastiCache/latest/red-ug/IAM.ConditionKeys.html#IAM.SpecifyingConditions

        Applies to actions:

        - .toCreateReplicationGroup()
        - .toModifyGlobalReplicationGroup()
        - .toModifyReplicationGroup()

        Applies to resource types:

        - replicationgroup
        - globalreplicationgroup

        :param value: ``true`` or ``false``. **Default:** ``true``

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c0fb04b2405ff9922cc07adf47c4e995053a79568808578db4abc0c6dd3a57ee)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast("Elasticache", jsii.invoke(self, "ifAutomaticFailoverEnabled", [value]))

    @jsii.member(jsii_name="ifCacheNodeType")
    def if_cache_node_type(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Elasticache":
        '''(experimental) Filters access by the cacheNodeType parameter present in the request.

        This key can be used to restrict which cache node types can be used on cluster creation or scaling operations

        https://docs.aws.amazon.com/AmazonElastiCache/latest/red-ug/IAM.ConditionKeys.html#IAM.SpecifyingConditions

        Applies to actions:

        - .toCreateCacheCluster()
        - .toCreateReplicationGroup()
        - .toModifyCacheCluster()
        - .toModifyGlobalReplicationGroup()
        - .toModifyReplicationGroup()

        Applies to resource types:

        - replicationgroup
        - cluster
        - globalreplicationgroup

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c1bc9283cbec2f0353ea2e17b6f12d6a3c17c2c62ce92dc49d6176a8d066cc61)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Elasticache", jsii.invoke(self, "ifCacheNodeType", [value, operator]))

    @jsii.member(jsii_name="ifCacheParameterGroupName")
    def if_cache_parameter_group_name(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Elasticache":
        '''(experimental) Filters access by the CacheParameterGroupName parameter in the request.

        https://docs.aws.amazon.com/AmazonElastiCache/latest/red-ug/IAM.ConditionKeys.html#IAM.SpecifyingConditions

        Applies to actions:

        - .toCreateCacheCluster()
        - .toCreateCacheParameterGroup()
        - .toCreateReplicationGroup()
        - .toDeleteCacheParameterGroup()
        - .toModifyCacheCluster()
        - .toModifyCacheParameterGroup()
        - .toModifyReplicationGroup()
        - .toResetCacheParameterGroup()

        Applies to resource types:

        - parametergroup
        - replicationgroup
        - cluster
        - globalreplicationgroup

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8f78d5158078d0eaba779f775a994d15f65f29eb56779d4ac56470ebe8289e94)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Elasticache", jsii.invoke(self, "ifCacheParameterGroupName", [value, operator]))

    @jsii.member(jsii_name="ifClusterModeEnabled")
    def if_cluster_mode_enabled(
        self,
        value: typing.Optional[builtins.bool] = None,
    ) -> "Elasticache":
        '''(experimental) Filters access by the cluster mode parameter present in the request.

        Default value for single node group (shard) creations is false

        https://docs.aws.amazon.com/AmazonElastiCache/latest/red-ug/IAM.ConditionKeys.html#IAM.SpecifyingConditions

        Applies to actions:

        - .toCreateReplicationGroup()

        Applies to resource types:

        - replicationgroup
        - globalreplicationgroup

        :param value: ``true`` or ``false``. **Default:** ``true``

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__843ca009e66c8d2c54572ba6344058f4ec810cb259733b7270fc550938a76e98)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast("Elasticache", jsii.invoke(self, "ifClusterModeEnabled", [value]))

    @jsii.member(jsii_name="ifEngineType")
    def if_engine_type(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Elasticache":
        '''(experimental) Filters access by the engine type present in creation requests.

        For replication group creations, default engine 'redis' is used as key if parameter is not present

        https://docs.aws.amazon.com/AmazonElastiCache/latest/red-ug/IAM.ConditionKeys.html#IAM.SpecifyingConditions

        Applies to actions:

        - .toCreateCacheCluster()
        - .toCreateReplicationGroup()

        Applies to resource types:

        - replicationgroup
        - cluster
        - globalreplicationgroup

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bfd939b1e37e42ddb7b8a14a485039bd432464edc309a9892e1a89f9d26bf332)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Elasticache", jsii.invoke(self, "ifEngineType", [value, operator]))

    @jsii.member(jsii_name="ifEngineVersion")
    def if_engine_version(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Elasticache":
        '''(experimental) Filters access by the engineVersion parameter present in creation or cluster modification requests.

        https://docs.aws.amazon.com/AmazonElastiCache/latest/red-ug/IAM.ConditionKeys.html#IAM.SpecifyingConditions

        Applies to actions:

        - .toCreateCacheCluster()
        - .toCreateReplicationGroup()
        - .toModifyCacheCluster()
        - .toModifyGlobalReplicationGroup()
        - .toModifyReplicationGroup()

        Applies to resource types:

        - replicationgroup
        - cluster
        - globalreplicationgroup

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__51166d5ecdac368ef24a28dbdaaff9d764c12a56c2b2c687c77bd43b122b8013)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Elasticache", jsii.invoke(self, "ifEngineVersion", [value, operator]))

    @jsii.member(jsii_name="ifKmsKeyId")
    def if_kms_key_id(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Elasticache":
        '''(experimental) Filters access by the KmsKeyId parameter in the request.

        https://docs.aws.amazon.com/AmazonElastiCache/latest/red-ug/IAM.ConditionKeys.html#IAM.SpecifyingConditions

        Applies to actions:

        - .toCopySnapshot()
        - .toCreateReplicationGroup()
        - .toCreateSnapshot()

        Applies to resource types:

        - replicationgroup
        - snapshot
        - globalreplicationgroup

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__11726947c5e06eda4b58d8fada5cc770319061001ee62c518138fa0d6f73139c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Elasticache", jsii.invoke(self, "ifKmsKeyId", [value, operator]))

    @jsii.member(jsii_name="ifMultiAZEnabled")
    def if_multi_az_enabled(
        self,
        value: typing.Optional[builtins.bool] = None,
    ) -> "Elasticache":
        '''(experimental) Filters access by the AZMode parameter, MultiAZEnabled parameter or the number of availability zones that the cluster or replication group can be placed in.

        https://docs.aws.amazon.com/AmazonElastiCache/latest/red-ug/IAM.ConditionKeys.html#IAM.SpecifyingConditions

        Applies to actions:

        - .toCreateCacheCluster()
        - .toCreateReplicationGroup()
        - .toModifyCacheCluster()
        - .toModifyReplicationGroup()

        Applies to resource types:

        - replicationgroup
        - cluster
        - globalreplicationgroup

        :param value: ``true`` or ``false``. **Default:** ``true``

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a0adb4d74de9beb2c5110d64ec23f3f8dc44f641f06ad33de079ff5b9bbaa30d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast("Elasticache", jsii.invoke(self, "ifMultiAZEnabled", [value]))

    @jsii.member(jsii_name="ifNumNodeGroups")
    def if_num_node_groups(
        self,
        value: typing.Union[jsii.Number, typing.Sequence[jsii.Number]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Elasticache":
        '''(experimental) Filters access by the NumNodeGroups or NodeGroupCount parameter specified in the request.

        This key can be used to restrict the number of node groups (shards) clusters can have after creation or scaling operations

        https://docs.aws.amazon.com/AmazonElastiCache/latest/red-ug/IAM.ConditionKeys.html#IAM.SpecifyingConditions

        Applies to actions:

        - .toCreateReplicationGroup()
        - .toDecreaseNodeGroupsInGlobalReplicationGroup()
        - .toIncreaseNodeGroupsInGlobalReplicationGroup()
        - .toModifyReplicationGroupShardConfiguration()

        Applies to resource types:

        - replicationgroup
        - globalreplicationgroup

        :param value: The value(s) to check.
        :param operator: Works with `numeric operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_Numeric>`_. **Default:** ``NumericEquals``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__774563aac950e5b77e966d9597f5b93c7129b3bced7a2d3c0eb246bdd27216de)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Elasticache", jsii.invoke(self, "ifNumNodeGroups", [value, operator]))

    @jsii.member(jsii_name="ifReplicasPerNodeGroup")
    def if_replicas_per_node_group(
        self,
        value: typing.Union[jsii.Number, typing.Sequence[jsii.Number]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Elasticache":
        '''(experimental) Filters access by the number of replicas per node group (shards) specified in creations or scaling requests.

        https://docs.aws.amazon.com/AmazonElastiCache/latest/red-ug/IAM.ConditionKeys.html#IAM.SpecifyingConditions

        Applies to actions:

        - .toCreateReplicationGroup()
        - .toDecreaseReplicaCount()
        - .toIncreaseReplicaCount()

        Applies to resource types:

        - replicationgroup
        - globalreplicationgroup

        :param value: The value(s) to check.
        :param operator: Works with `numeric operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_Numeric>`_. **Default:** ``NumericEquals``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f88c4372275bdc5733126df5536df54f4628a0aff44ef9dff6c436e742fec1a5)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Elasticache", jsii.invoke(self, "ifReplicasPerNodeGroup", [value, operator]))

    @jsii.member(jsii_name="ifSnapshotRetentionLimit")
    def if_snapshot_retention_limit(
        self,
        value: typing.Union[jsii.Number, typing.Sequence[jsii.Number]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Elasticache":
        '''(experimental) Filters access by the SnapshotRetentionLimit parameter in the request.

        https://docs.aws.amazon.com/AmazonElastiCache/latest/red-ug/IAM.ConditionKeys.html#IAM.SpecifyingConditions

        Applies to actions:

        - .toCreateCacheCluster()
        - .toCreateReplicationGroup()
        - .toModifyCacheCluster()
        - .toModifyReplicationGroup()

        Applies to resource types:

        - replicationgroup
        - cluster
        - globalreplicationgroup

        :param value: The value(s) to check.
        :param operator: Works with `numeric operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_Numeric>`_. **Default:** ``NumericEquals``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e4cfe7b2650043dbe34820f0e244258f9e9f51e2c7f69d0f60000845907fcb1d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Elasticache", jsii.invoke(self, "ifSnapshotRetentionLimit", [value, operator]))

    @jsii.member(jsii_name="ifTransitEncryptionEnabled")
    def if_transit_encryption_enabled(
        self,
        value: typing.Optional[builtins.bool] = None,
    ) -> "Elasticache":
        '''(experimental) Filters access by the TransitEncryptionEnabled parameter present in the request or default false value if parameter is not present.

        https://docs.aws.amazon.com/AmazonElastiCache/latest/red-ug/IAM.ConditionKeys.html#IAM.SpecifyingConditions

        Applies to actions:

        - .toCreateReplicationGroup()

        Applies to resource types:

        - replicationgroup
        - globalreplicationgroup

        :param value: ``true`` or ``false``. **Default:** ``true``

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d42151a1f6545779a48da094feee4eae72ddf38003247cdd2edd27badce126cd)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast("Elasticache", jsii.invoke(self, "ifTransitEncryptionEnabled", [value]))

    @jsii.member(jsii_name="ifUserAuthenticationMode")
    def if_user_authentication_mode(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Elasticache":
        '''(experimental) Filters access by the UserAuthenticationMode parameter in the request.

        https://docs.aws.amazon.com/AmazonElastiCache/latest/red-ug/IAM.ConditionKeys.html#IAM.SpecifyingConditions

        Applies to actions:

        - .toCreateUser()
        - .toModifyUser()

        Applies to resource types:

        - user

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__33c6968810c7b315ea50e43538fca57fb4e447e506dfbc5b47247264d3d9af9b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Elasticache", jsii.invoke(self, "ifUserAuthenticationMode", [value, operator]))

    @jsii.member(jsii_name="onCluster")
    def on_cluster(
        self,
        cache_cluster_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Elasticache":
        '''(experimental) Adds a resource of type cluster to the statement.

        https://docs.aws.amazon.com/AmazonElastiCache/latest/red-ug/WhatIs.Components.html#WhatIs.Components.Clusters

        :param cache_cluster_id: - Identifier for the cacheClusterId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsRequestTag() - .ifAwsResourceTag() - .ifAwsTagKeys() - .ifAuthTokenEnabled() - .ifCacheNodeType() - .ifCacheParameterGroupName() - .ifEngineType() - .ifEngineVersion() - .ifMultiAZEnabled() - .ifSnapshotRetentionLimit()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__206494a77537414da56a8a8d95bb4c46fa0e2be1ddebbe3f78fb927fceb10f5a)
            check_type(argname="argument cache_cluster_id", value=cache_cluster_id, expected_type=type_hints["cache_cluster_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Elasticache", jsii.invoke(self, "onCluster", [cache_cluster_id, account, region, partition]))

    @jsii.member(jsii_name="onGlobalreplicationgroup")
    def on_globalreplicationgroup(
        self,
        global_replication_group_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Elasticache":
        '''(experimental) Adds a resource of type globalreplicationgroup to the statement.

        https://docs.aws.amazon.com/AmazonElastiCache/latest/red-ug/Redis-Global-Datastore.html

        :param global_replication_group_id: - Identifier for the globalReplicationGroupId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAtRestEncryptionEnabled() - .ifAuthTokenEnabled() - .ifAutomaticFailoverEnabled() - .ifCacheNodeType() - .ifCacheParameterGroupName() - .ifClusterModeEnabled() - .ifEngineType() - .ifEngineVersion() - .ifKmsKeyId() - .ifMultiAZEnabled() - .ifNumNodeGroups() - .ifReplicasPerNodeGroup() - .ifSnapshotRetentionLimit() - .ifTransitEncryptionEnabled()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__40565920bee846bec4d1f8549c35d98d0f97d3bbd03913479e696365f869e870)
            check_type(argname="argument global_replication_group_id", value=global_replication_group_id, expected_type=type_hints["global_replication_group_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Elasticache", jsii.invoke(self, "onGlobalreplicationgroup", [global_replication_group_id, account, partition]))

    @jsii.member(jsii_name="onParametergroup")
    def on_parametergroup(
        self,
        cache_parameter_group_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Elasticache":
        '''(experimental) Adds a resource of type parametergroup to the statement.

        https://docs.aws.amazon.com/AmazonElastiCache/latest/red-ug/WhatIs.Components.html#WhatIs.Components.ParameterGroups

        :param cache_parameter_group_name: - Identifier for the cacheParameterGroupName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsRequestTag() - .ifAwsResourceTag() - .ifAwsTagKeys() - .ifCacheParameterGroupName()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ed7ed72994d643b05b573a284d5475565928c007bfd9db439fff23dad9601794)
            check_type(argname="argument cache_parameter_group_name", value=cache_parameter_group_name, expected_type=type_hints["cache_parameter_group_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Elasticache", jsii.invoke(self, "onParametergroup", [cache_parameter_group_name, account, region, partition]))

    @jsii.member(jsii_name="onReplicationgroup")
    def on_replicationgroup(
        self,
        replication_group_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Elasticache":
        '''(experimental) Adds a resource of type replicationgroup to the statement.

        https://docs.aws.amazon.com/AmazonElastiCache/latest/red-ug/WhatIs.Components.html#WhatIs.Components.ReplicationGroups

        :param replication_group_id: - Identifier for the replicationGroupId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsRequestTag() - .ifAwsResourceTag() - .ifAwsTagKeys() - .ifAtRestEncryptionEnabled() - .ifAuthTokenEnabled() - .ifAutomaticFailoverEnabled() - .ifCacheNodeType() - .ifCacheParameterGroupName() - .ifClusterModeEnabled() - .ifEngineType() - .ifEngineVersion() - .ifKmsKeyId() - .ifMultiAZEnabled() - .ifNumNodeGroups() - .ifReplicasPerNodeGroup() - .ifSnapshotRetentionLimit() - .ifTransitEncryptionEnabled()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__284e0dda55a80e1908cf6f8120647392e86324e688c0cb296fa3ba6ef398e082)
            check_type(argname="argument replication_group_id", value=replication_group_id, expected_type=type_hints["replication_group_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Elasticache", jsii.invoke(self, "onReplicationgroup", [replication_group_id, account, region, partition]))

    @jsii.member(jsii_name="onReservedInstance")
    def on_reserved_instance(
        self,
        reserved_cache_node_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Elasticache":
        '''(experimental) Adds a resource of type reserved-instance to the statement.

        https://docs.aws.amazon.com/AmazonElastiCache/latest/red-ug/reserved-nodes.html

        :param reserved_cache_node_id: - Identifier for the reservedCacheNodeId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsRequestTag() - .ifAwsResourceTag() - .ifAwsTagKeys()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d5ee6fbc27a1f20dae155e3b3a687ff144f76a6dd0bfe4c57899deeb1ff22442)
            check_type(argname="argument reserved_cache_node_id", value=reserved_cache_node_id, expected_type=type_hints["reserved_cache_node_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Elasticache", jsii.invoke(self, "onReservedInstance", [reserved_cache_node_id, account, region, partition]))

    @jsii.member(jsii_name="onSecuritygroup")
    def on_securitygroup(
        self,
        cache_security_group_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Elasticache":
        '''(experimental) Adds a resource of type securitygroup to the statement.

        https://docs.aws.amazon.com/AmazonElastiCache/latest/red-ug/WhatIs.Components.html#WhatIs.Components.SecurityGroups

        :param cache_security_group_name: - Identifier for the cacheSecurityGroupName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsRequestTag() - .ifAwsResourceTag() - .ifAwsTagKeys()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b8a889d07c385cfe78dfe37c97be5d937b4e8b62268976a3f3d5d2d04054aff9)
            check_type(argname="argument cache_security_group_name", value=cache_security_group_name, expected_type=type_hints["cache_security_group_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Elasticache", jsii.invoke(self, "onSecuritygroup", [cache_security_group_name, account, region, partition]))

    @jsii.member(jsii_name="onSnapshot")
    def on_snapshot(
        self,
        snapshot_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Elasticache":
        '''(experimental) Adds a resource of type snapshot to the statement.

        https://docs.aws.amazon.com/AmazonElastiCache/latest/red-ug/WhatIs.Components.html#WhatIs.Components.Snapshots

        :param snapshot_name: - Identifier for the snapshotName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsRequestTag() - .ifAwsResourceTag() - .ifAwsTagKeys() - .ifKmsKeyId()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9eefe285efe0aa84e1b005b87a5a991d7256953ea342d708b0c81aa9063110e0)
            check_type(argname="argument snapshot_name", value=snapshot_name, expected_type=type_hints["snapshot_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Elasticache", jsii.invoke(self, "onSnapshot", [snapshot_name, account, region, partition]))

    @jsii.member(jsii_name="onSubnetgroup")
    def on_subnetgroup(
        self,
        cache_subnet_group_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Elasticache":
        '''(experimental) Adds a resource of type subnetgroup to the statement.

        https://docs.aws.amazon.com/AmazonElastiCache/latest/red-ug/WhatIs.Components.html#WhatIs.Components.SubnetGroups

        :param cache_subnet_group_name: - Identifier for the cacheSubnetGroupName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsRequestTag() - .ifAwsResourceTag() - .ifAwsTagKeys()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fe4041f1c485b1ad799d9d8c1f1576cf7322239ecae537bde857dfecf559b06b)
            check_type(argname="argument cache_subnet_group_name", value=cache_subnet_group_name, expected_type=type_hints["cache_subnet_group_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Elasticache", jsii.invoke(self, "onSubnetgroup", [cache_subnet_group_name, account, region, partition]))

    @jsii.member(jsii_name="onUser")
    def on_user(
        self,
        user_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Elasticache":
        '''(experimental) Adds a resource of type user to the statement.

        https://docs.aws.amazon.com/AmazonElastiCache/latest/red-ug/Clusters.RBAC.html

        :param user_id: - Identifier for the userId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsRequestTag() - .ifAwsResourceTag() - .ifAwsTagKeys() - .ifUserAuthenticationMode()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6f0f2a9ec7e1dc7d181ab65607bfc44f6caf602502942abfecf6a06e1510eeb4)
            check_type(argname="argument user_id", value=user_id, expected_type=type_hints["user_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Elasticache", jsii.invoke(self, "onUser", [user_id, account, region, partition]))

    @jsii.member(jsii_name="onUsergroup")
    def on_usergroup(
        self,
        user_group_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Elasticache":
        '''(experimental) Adds a resource of type usergroup to the statement.

        https://docs.aws.amazon.com/AmazonElastiCache/latest/red-ug/Clusters.RBAC.html

        :param user_group_id: - Identifier for the userGroupId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsRequestTag() - .ifAwsResourceTag() - .ifAwsTagKeys()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5c916e02c1b48453a7d31f8a6b5cf24a32607478fee0c35a173b555d3c408f0b)
            check_type(argname="argument user_group_id", value=user_group_id, expected_type=type_hints["user_group_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Elasticache", jsii.invoke(self, "onUsergroup", [user_group_id, account, region, partition]))

    @jsii.member(jsii_name="toAddTagsToResource")
    def to_add_tags_to_resource(self) -> "Elasticache":
        '''(experimental) Grants permission to add tags to an ElastiCache resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()
        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/AmazonElastiCache/latest/APIReference/API_AddTagsToResource.html

        :stability: experimental
        '''
        return typing.cast("Elasticache", jsii.invoke(self, "toAddTagsToResource", []))

    @jsii.member(jsii_name="toAuthorizeCacheSecurityGroupIngress")
    def to_authorize_cache_security_group_ingress(self) -> "Elasticache":
        '''(experimental) Grants permission to authorize an EC2 security group on a ElastiCache security group.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        Dependent actions:

        - ec2:AuthorizeSecurityGroupIngress

        https://docs.aws.amazon.com/AmazonElastiCache/latest/APIReference/API_AuthorizeCacheSecurityGroupIngress.html

        :stability: experimental
        '''
        return typing.cast("Elasticache", jsii.invoke(self, "toAuthorizeCacheSecurityGroupIngress", []))

    @jsii.member(jsii_name="toBatchApplyUpdateAction")
    def to_batch_apply_update_action(self) -> "Elasticache":
        '''(experimental) Grants permission to apply ElastiCache service updates to sets of clusters and replication groups.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        Dependent actions:

        - ec2:CreateNetworkInterface
        - ec2:DeleteNetworkInterface
        - ec2:DescribeNetworkInterfaces
        - ec2:DescribeSubnets
        - ec2:DescribeVpcs
        - s3:GetObject

        https://docs.aws.amazon.com/AmazonElastiCache/latest/APIReference/API_BatchApplyUpdateAction.html

        :stability: experimental
        '''
        return typing.cast("Elasticache", jsii.invoke(self, "toBatchApplyUpdateAction", []))

    @jsii.member(jsii_name="toBatchStopUpdateAction")
    def to_batch_stop_update_action(self) -> "Elasticache":
        '''(experimental) Grants permission to stop ElastiCache service updates from being executed on a set of clusters.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/AmazonElastiCache/latest/APIReference/API_BatchStopUpdateAction.html

        :stability: experimental
        '''
        return typing.cast("Elasticache", jsii.invoke(self, "toBatchStopUpdateAction", []))

    @jsii.member(jsii_name="toCompleteMigration")
    def to_complete_migration(self) -> "Elasticache":
        '''(experimental) Grants permission to complete an online migration of data from hosted Redis on Amazon EC2 to ElastiCache.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/AmazonElastiCache/latest/APIReference/API_CompleteMigration.html

        :stability: experimental
        '''
        return typing.cast("Elasticache", jsii.invoke(self, "toCompleteMigration", []))

    @jsii.member(jsii_name="toConnect")
    def to_connect(self) -> "Elasticache":
        '''(experimental) Allows an IAM user or role to connect as a specified EliastCache user to a node in a replication group.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/AmazonElastiCache/latest/red-ug/auth-iam.html

        :stability: experimental
        '''
        return typing.cast("Elasticache", jsii.invoke(self, "toConnect", []))

    @jsii.member(jsii_name="toCopySnapshot")
    def to_copy_snapshot(self) -> "Elasticache":
        '''(experimental) Grants permission to make a copy of an existing snapshot.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()
        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifKmsKeyId()

        Dependent actions:

        - elasticache:AddTagsToResource
        - s3:DeleteObject
        - s3:GetBucketAcl
        - s3:PutObject

        https://docs.aws.amazon.com/AmazonElastiCache/latest/APIReference/API_CopySnapshot.html

        :stability: experimental
        '''
        return typing.cast("Elasticache", jsii.invoke(self, "toCopySnapshot", []))

    @jsii.member(jsii_name="toCreateCacheCluster")
    def to_create_cache_cluster(self) -> "Elasticache":
        '''(experimental) Grants permission to create a cache cluster.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        Dependent actions:

        - ec2:CreateNetworkInterface
        - ec2:DeleteNetworkInterface
        - ec2:DescribeNetworkInterfaces
        - ec2:DescribeSubnets
        - ec2:DescribeVpcs
        - elasticache:AddTagsToResource
        - s3:GetObject

        https://docs.aws.amazon.com/AmazonElastiCache/latest/APIReference/API_CreateCacheCluster.html

        :stability: experimental
        '''
        return typing.cast("Elasticache", jsii.invoke(self, "toCreateCacheCluster", []))

    @jsii.member(jsii_name="toCreateCacheParameterGroup")
    def to_create_cache_parameter_group(self) -> "Elasticache":
        '''(experimental) Grants permission to create a parameter group.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()
        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifCacheParameterGroupName()

        Dependent actions:

        - elasticache:AddTagsToResource

        https://docs.aws.amazon.com/AmazonElastiCache/latest/APIReference/API_CreateCacheParameterGroup.html

        :stability: experimental
        '''
        return typing.cast("Elasticache", jsii.invoke(self, "toCreateCacheParameterGroup", []))

    @jsii.member(jsii_name="toCreateCacheSecurityGroup")
    def to_create_cache_security_group(self) -> "Elasticache":
        '''(experimental) Grants permission to create a cache security group.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()
        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - elasticache:AddTagsToResource

        https://docs.aws.amazon.com/AmazonElastiCache/latest/APIReference/API_CreateCacheSecurityGroup.html

        :stability: experimental
        '''
        return typing.cast("Elasticache", jsii.invoke(self, "toCreateCacheSecurityGroup", []))

    @jsii.member(jsii_name="toCreateCacheSubnetGroup")
    def to_create_cache_subnet_group(self) -> "Elasticache":
        '''(experimental) Grants permission to create a cache subnet group.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()
        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - elasticache:AddTagsToResource

        https://docs.aws.amazon.com/AmazonElastiCache/latest/APIReference/API_CreateCacheSubnetGroup.html

        :stability: experimental
        '''
        return typing.cast("Elasticache", jsii.invoke(self, "toCreateCacheSubnetGroup", []))

    @jsii.member(jsii_name="toCreateGlobalReplicationGroup")
    def to_create_global_replication_group(self) -> "Elasticache":
        '''(experimental) Grants permission to create a global replication group.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/AmazonElastiCache/latest/APIReference/API_CreateGlobalReplicationGroup.html

        :stability: experimental
        '''
        return typing.cast("Elasticache", jsii.invoke(self, "toCreateGlobalReplicationGroup", []))

    @jsii.member(jsii_name="toCreateReplicationGroup")
    def to_create_replication_group(self) -> "Elasticache":
        '''(experimental) Grants permission to create a replication group.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        Dependent actions:

        - ec2:CreateNetworkInterface
        - ec2:DeleteNetworkInterface
        - ec2:DescribeNetworkInterfaces
        - ec2:DescribeSubnets
        - ec2:DescribeVpcs
        - elasticache:AddTagsToResource
        - s3:GetObject

        https://docs.aws.amazon.com/AmazonElastiCache/latest/APIReference/API_CreateReplicationGroup.html

        :stability: experimental
        '''
        return typing.cast("Elasticache", jsii.invoke(self, "toCreateReplicationGroup", []))

    @jsii.member(jsii_name="toCreateSnapshot")
    def to_create_snapshot(self) -> "Elasticache":
        '''(experimental) Grants permission to create a copy of an entire Redis cluster at a specific moment in time.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        Dependent actions:

        - elasticache:AddTagsToResource
        - s3:DeleteObject
        - s3:GetBucketAcl
        - s3:PutObject

        https://docs.aws.amazon.com/AmazonElastiCache/latest/APIReference/API_CreateSnapshot.html

        :stability: experimental
        '''
        return typing.cast("Elasticache", jsii.invoke(self, "toCreateSnapshot", []))

    @jsii.member(jsii_name="toCreateUser")
    def to_create_user(self) -> "Elasticache":
        '''(experimental) Grants permission to create a user for Redis. Users are supported from Redis 6.0 onwards.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()
        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifUserAuthenticationMode()

        Dependent actions:

        - elasticache:AddTagsToResource

        https://docs.aws.amazon.com/AmazonElastiCache/latest/APIReference/API_CreateUser.html

        :stability: experimental
        '''
        return typing.cast("Elasticache", jsii.invoke(self, "toCreateUser", []))

    @jsii.member(jsii_name="toCreateUserGroup")
    def to_create_user_group(self) -> "Elasticache":
        '''(experimental) Grants permission to create a user group for Redis. Groups are supported from Redis 6.0 onwards.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        Dependent actions:

        - elasticache:AddTagsToResource

        https://docs.aws.amazon.com/AmazonElastiCache/latest/APIReference/API_CreateUserGroup.html

        :stability: experimental
        '''
        return typing.cast("Elasticache", jsii.invoke(self, "toCreateUserGroup", []))

    @jsii.member(jsii_name="toDecreaseNodeGroupsInGlobalReplicationGroup")
    def to_decrease_node_groups_in_global_replication_group(self) -> "Elasticache":
        '''(experimental) Grants permission to decrease the number of node groups in global replication groups.

        Access Level: Write

        Possible conditions:

        - .ifNumNodeGroups()

        https://docs.aws.amazon.com/AmazonElastiCache/latest/APIReference/API_DecreaseNodeGroupsInGlobalReplicationGroup.html

        :stability: experimental
        '''
        return typing.cast("Elasticache", jsii.invoke(self, "toDecreaseNodeGroupsInGlobalReplicationGroup", []))

    @jsii.member(jsii_name="toDecreaseReplicaCount")
    def to_decrease_replica_count(self) -> "Elasticache":
        '''(experimental) Grants permission to decrease the number of replicas in a Redis (cluster mode disabled) replication group or the number of replica nodes in one or more node groups (shards) of a Redis (cluster mode enabled) replication group.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()
        - .ifReplicasPerNodeGroup()

        Dependent actions:

        - ec2:CreateNetworkInterface
        - ec2:DeleteNetworkInterface
        - ec2:DescribeNetworkInterfaces
        - ec2:DescribeSubnets
        - ec2:DescribeVpcs

        https://docs.aws.amazon.com/AmazonElastiCache/latest/APIReference/API_DecreaseReplicaCount.html

        :stability: experimental
        '''
        return typing.cast("Elasticache", jsii.invoke(self, "toDecreaseReplicaCount", []))

    @jsii.member(jsii_name="toDeleteCacheCluster")
    def to_delete_cache_cluster(self) -> "Elasticache":
        '''(experimental) Grants permission to delete a previously provisioned cluster.

        Access Level: Write

        Dependent actions:

        - ec2:CreateNetworkInterface
        - ec2:DeleteNetworkInterface
        - ec2:DescribeNetworkInterfaces
        - ec2:DescribeSubnets
        - ec2:DescribeVpcs

        https://docs.aws.amazon.com/AmazonElastiCache/latest/APIReference/API_DeleteCacheCluster.html

        :stability: experimental
        '''
        return typing.cast("Elasticache", jsii.invoke(self, "toDeleteCacheCluster", []))

    @jsii.member(jsii_name="toDeleteCacheParameterGroup")
    def to_delete_cache_parameter_group(self) -> "Elasticache":
        '''(experimental) Grants permission to delete the specified cache parameter group.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()
        - .ifCacheParameterGroupName()

        https://docs.aws.amazon.com/AmazonElastiCache/latest/APIReference/API_DeleteCacheParameterGroup.html

        :stability: experimental
        '''
        return typing.cast("Elasticache", jsii.invoke(self, "toDeleteCacheParameterGroup", []))

    @jsii.member(jsii_name="toDeleteCacheSecurityGroup")
    def to_delete_cache_security_group(self) -> "Elasticache":
        '''(experimental) Grants permission to delete a cache security group.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/AmazonElastiCache/latest/APIReference/API_DeleteCacheSecurityGroup.html

        :stability: experimental
        '''
        return typing.cast("Elasticache", jsii.invoke(self, "toDeleteCacheSecurityGroup", []))

    @jsii.member(jsii_name="toDeleteCacheSubnetGroup")
    def to_delete_cache_subnet_group(self) -> "Elasticache":
        '''(experimental) Grants permission to delete a cache subnet group.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        Dependent actions:

        - ec2:CreateNetworkInterface
        - ec2:DeleteNetworkInterface
        - ec2:DescribeNetworkInterfaces
        - ec2:DescribeSubnets
        - ec2:DescribeVpcs

        https://docs.aws.amazon.com/AmazonElastiCache/latest/APIReference/API_DeleteCacheSubnetGroup.html

        :stability: experimental
        '''
        return typing.cast("Elasticache", jsii.invoke(self, "toDeleteCacheSubnetGroup", []))

    @jsii.member(jsii_name="toDeleteGlobalReplicationGroup")
    def to_delete_global_replication_group(self) -> "Elasticache":
        '''(experimental) Grants permission to delete an existing global replication group.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonElastiCache/latest/APIReference/API_DeleteGlobalReplicationGroup.html

        :stability: experimental
        '''
        return typing.cast("Elasticache", jsii.invoke(self, "toDeleteGlobalReplicationGroup", []))

    @jsii.member(jsii_name="toDeleteReplicationGroup")
    def to_delete_replication_group(self) -> "Elasticache":
        '''(experimental) Grants permission to delete an existing replication group.

        Access Level: Write

        Dependent actions:

        - ec2:CreateNetworkInterface
        - ec2:DeleteNetworkInterface
        - ec2:DescribeNetworkInterfaces
        - ec2:DescribeSubnets
        - ec2:DescribeVpcs

        https://docs.aws.amazon.com/AmazonElastiCache/latest/APIReference/API_DeleteReplicationGroup.html

        :stability: experimental
        '''
        return typing.cast("Elasticache", jsii.invoke(self, "toDeleteReplicationGroup", []))

    @jsii.member(jsii_name="toDeleteSnapshot")
    def to_delete_snapshot(self) -> "Elasticache":
        '''(experimental) Grants permission to delete an existing snapshot.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/AmazonElastiCache/latest/APIReference/API_DeleteSnapshot.html

        :stability: experimental
        '''
        return typing.cast("Elasticache", jsii.invoke(self, "toDeleteSnapshot", []))

    @jsii.member(jsii_name="toDeleteUser")
    def to_delete_user(self) -> "Elasticache":
        '''(experimental) Grants permission to delete an existing user and thus remove it from all user groups and replication groups where it was assigned.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/AmazonElastiCache/latest/APIReference/API_DeleteUser.html

        :stability: experimental
        '''
        return typing.cast("Elasticache", jsii.invoke(self, "toDeleteUser", []))

    @jsii.member(jsii_name="toDeleteUserGroup")
    def to_delete_user_group(self) -> "Elasticache":
        '''(experimental) Grants permission to delete an existing user group.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/AmazonElastiCache/latest/APIReference/API_DeleteUserGroup.html

        :stability: experimental
        '''
        return typing.cast("Elasticache", jsii.invoke(self, "toDeleteUserGroup", []))

    @jsii.member(jsii_name="toDescribeCacheClusters")
    def to_describe_cache_clusters(self) -> "Elasticache":
        '''(experimental) Grants permission to list information about provisioned cache clusters.

        Access Level: List

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/AmazonElastiCache/latest/APIReference/API_DescribeCacheClusters.html

        :stability: experimental
        '''
        return typing.cast("Elasticache", jsii.invoke(self, "toDescribeCacheClusters", []))

    @jsii.member(jsii_name="toDescribeCacheEngineVersions")
    def to_describe_cache_engine_versions(self) -> "Elasticache":
        '''(experimental) Grants permission to list available cache engines and their versions.

        Access Level: List

        https://docs.aws.amazon.com/AmazonElastiCache/latest/APIReference/API_DescribeCacheEngineVersions.html

        :stability: experimental
        '''
        return typing.cast("Elasticache", jsii.invoke(self, "toDescribeCacheEngineVersions", []))

    @jsii.member(jsii_name="toDescribeCacheParameterGroups")
    def to_describe_cache_parameter_groups(self) -> "Elasticache":
        '''(experimental) Grants permission to list cache parameter group descriptions.

        Access Level: List

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/AmazonElastiCache/latest/APIReference/API_DescribeCacheParameterGroups.html

        :stability: experimental
        '''
        return typing.cast("Elasticache", jsii.invoke(self, "toDescribeCacheParameterGroups", []))

    @jsii.member(jsii_name="toDescribeCacheParameters")
    def to_describe_cache_parameters(self) -> "Elasticache":
        '''(experimental) Grants permission to retrieve the detailed parameter list for a particular cache parameter group.

        Access Level: List

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/AmazonElastiCache/latest/APIReference/API_DescribeCacheParameters.html

        :stability: experimental
        '''
        return typing.cast("Elasticache", jsii.invoke(self, "toDescribeCacheParameters", []))

    @jsii.member(jsii_name="toDescribeCacheSecurityGroups")
    def to_describe_cache_security_groups(self) -> "Elasticache":
        '''(experimental) Grants permission to list cache security group descriptions.

        Access Level: List

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/AmazonElastiCache/latest/APIReference/API_DescribeCacheSecurityGroups.html

        :stability: experimental
        '''
        return typing.cast("Elasticache", jsii.invoke(self, "toDescribeCacheSecurityGroups", []))

    @jsii.member(jsii_name="toDescribeCacheSubnetGroups")
    def to_describe_cache_subnet_groups(self) -> "Elasticache":
        '''(experimental) Grants permission to list cache subnet group descriptions.

        Access Level: List

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/AmazonElastiCache/latest/APIReference/API_DescribeCacheSubnetGroups.html

        :stability: experimental
        '''
        return typing.cast("Elasticache", jsii.invoke(self, "toDescribeCacheSubnetGroups", []))

    @jsii.member(jsii_name="toDescribeEngineDefaultParameters")
    def to_describe_engine_default_parameters(self) -> "Elasticache":
        '''(experimental) Grants permission to retrieve the default engine and system parameter information for the specified cache engine.

        Access Level: List

        https://docs.aws.amazon.com/AmazonElastiCache/latest/APIReference/API_DescribeEngineDefaultParameters.html

        :stability: experimental
        '''
        return typing.cast("Elasticache", jsii.invoke(self, "toDescribeEngineDefaultParameters", []))

    @jsii.member(jsii_name="toDescribeEvents")
    def to_describe_events(self) -> "Elasticache":
        '''(experimental) Grants permission to list events related to clusters, cache security groups, and cache parameter groups.

        Access Level: List

        https://docs.aws.amazon.com/AmazonElastiCache/latest/APIReference/API_DescribeEvents.html

        :stability: experimental
        '''
        return typing.cast("Elasticache", jsii.invoke(self, "toDescribeEvents", []))

    @jsii.member(jsii_name="toDescribeGlobalReplicationGroups")
    def to_describe_global_replication_groups(self) -> "Elasticache":
        '''(experimental) Grants permission to list information about global replication groups.

        Access Level: List

        https://docs.aws.amazon.com/AmazonElastiCache/latest/APIReference/API_DescribeGlobalReplicationGroups.html

        :stability: experimental
        '''
        return typing.cast("Elasticache", jsii.invoke(self, "toDescribeGlobalReplicationGroups", []))

    @jsii.member(jsii_name="toDescribeReplicationGroups")
    def to_describe_replication_groups(self) -> "Elasticache":
        '''(experimental) Grants permission to list information about provisioned replication groups.

        Access Level: List

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/AmazonElastiCache/latest/APIReference/API_DescribeReplicationGroups.html

        :stability: experimental
        '''
        return typing.cast("Elasticache", jsii.invoke(self, "toDescribeReplicationGroups", []))

    @jsii.member(jsii_name="toDescribeReservedCacheNodes")
    def to_describe_reserved_cache_nodes(self) -> "Elasticache":
        '''(experimental) Grants permission to list information about purchased reserved cache nodes.

        Access Level: List

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/AmazonElastiCache/latest/APIReference/API_DescribeReservedCacheNodes.html

        :stability: experimental
        '''
        return typing.cast("Elasticache", jsii.invoke(self, "toDescribeReservedCacheNodes", []))

    @jsii.member(jsii_name="toDescribeReservedCacheNodesOfferings")
    def to_describe_reserved_cache_nodes_offerings(self) -> "Elasticache":
        '''(experimental) Grants permission to list available reserved cache node offerings.

        Access Level: List

        https://docs.aws.amazon.com/AmazonElastiCache/latest/APIReference/API_DescribeReservedCacheNodesOfferings.html

        :stability: experimental
        '''
        return typing.cast("Elasticache", jsii.invoke(self, "toDescribeReservedCacheNodesOfferings", []))

    @jsii.member(jsii_name="toDescribeServiceUpdates")
    def to_describe_service_updates(self) -> "Elasticache":
        '''(experimental) Grants permission to list details of the service updates.

        Access Level: List

        https://docs.aws.amazon.com/AmazonElastiCache/latest/APIReference/API_DescribeServiceUpdates.html

        :stability: experimental
        '''
        return typing.cast("Elasticache", jsii.invoke(self, "toDescribeServiceUpdates", []))

    @jsii.member(jsii_name="toDescribeSnapshots")
    def to_describe_snapshots(self) -> "Elasticache":
        '''(experimental) Grants permission to list information about cluster or replication group snapshots.

        Access Level: List

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/AmazonElastiCache/latest/APIReference/API_DescribeSnapshots.html

        :stability: experimental
        '''
        return typing.cast("Elasticache", jsii.invoke(self, "toDescribeSnapshots", []))

    @jsii.member(jsii_name="toDescribeUpdateActions")
    def to_describe_update_actions(self) -> "Elasticache":
        '''(experimental) Grants permission to list details of the update actions for a set of clusters or replication groups.

        Access Level: List

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/AmazonElastiCache/latest/APIReference/API_DescribeUpdateActions.html

        :stability: experimental
        '''
        return typing.cast("Elasticache", jsii.invoke(self, "toDescribeUpdateActions", []))

    @jsii.member(jsii_name="toDescribeUserGroups")
    def to_describe_user_groups(self) -> "Elasticache":
        '''(experimental) Grants permission to list information about Redis user groups.

        Access Level: List

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/AmazonElastiCache/latest/APIReference/API_DescribeUserGroups.html

        :stability: experimental
        '''
        return typing.cast("Elasticache", jsii.invoke(self, "toDescribeUserGroups", []))

    @jsii.member(jsii_name="toDescribeUsers")
    def to_describe_users(self) -> "Elasticache":
        '''(experimental) Grants permission to list information about Redis users.

        Access Level: List

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/AmazonElastiCache/latest/APIReference/API_DescribeUsers.html

        :stability: experimental
        '''
        return typing.cast("Elasticache", jsii.invoke(self, "toDescribeUsers", []))

    @jsii.member(jsii_name="toDisassociateGlobalReplicationGroup")
    def to_disassociate_global_replication_group(self) -> "Elasticache":
        '''(experimental) Grants permission to remove a secondary replication group from the global replication group.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonElastiCache/latest/APIReference/API_DisassociateGlobalReplicationGroup.html

        :stability: experimental
        '''
        return typing.cast("Elasticache", jsii.invoke(self, "toDisassociateGlobalReplicationGroup", []))

    @jsii.member(jsii_name="toFailoverGlobalReplicationGroup")
    def to_failover_global_replication_group(self) -> "Elasticache":
        '''(experimental) Grants permission to failover the primary region to a selected secondary region of a global replication group.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonElastiCache/latest/APIReference/API_FailoverGlobalReplicationGroup.html

        :stability: experimental
        '''
        return typing.cast("Elasticache", jsii.invoke(self, "toFailoverGlobalReplicationGroup", []))

    @jsii.member(jsii_name="toIncreaseNodeGroupsInGlobalReplicationGroup")
    def to_increase_node_groups_in_global_replication_group(self) -> "Elasticache":
        '''(experimental) Grants permission to increase the number of node groups in a global replication group.

        Access Level: Write

        Possible conditions:

        - .ifNumNodeGroups()

        https://docs.aws.amazon.com/AmazonElastiCache/latest/APIReference/API_IncreaseNodeGroupsInGlobalReplicationGroup.html

        :stability: experimental
        '''
        return typing.cast("Elasticache", jsii.invoke(self, "toIncreaseNodeGroupsInGlobalReplicationGroup", []))

    @jsii.member(jsii_name="toIncreaseReplicaCount")
    def to_increase_replica_count(self) -> "Elasticache":
        '''(experimental) Grants permission to increase the number of replicas in a Redis (cluster mode disabled) replication group or the number of replica nodes in one or more node groups (shards) of a Redis (cluster mode enabled) replication group.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()
        - .ifReplicasPerNodeGroup()

        Dependent actions:

        - ec2:CreateNetworkInterface
        - ec2:DeleteNetworkInterface
        - ec2:DescribeNetworkInterfaces
        - ec2:DescribeSubnets
        - ec2:DescribeVpcs

        https://docs.aws.amazon.com/AmazonElastiCache/latest/APIReference/API_IncreaseReplicaCount.html

        :stability: experimental
        '''
        return typing.cast("Elasticache", jsii.invoke(self, "toIncreaseReplicaCount", []))

    @jsii.member(jsii_name="toListAllowedNodeTypeModifications")
    def to_list_allowed_node_type_modifications(self) -> "Elasticache":
        '''(experimental) Grants permission to list available node type that can be used to scale a particular Redis cluster or replication group.

        Access Level: List

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/AmazonElastiCache/latest/APIReference/API_ListAllowedNodeTypeModifications.html

        :stability: experimental
        '''
        return typing.cast("Elasticache", jsii.invoke(self, "toListAllowedNodeTypeModifications", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Elasticache":
        '''(experimental) Grants permission to list tags for an ElastiCache resource.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/AmazonElastiCache/latest/APIReference/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("Elasticache", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toModifyCacheCluster")
    def to_modify_cache_cluster(self) -> "Elasticache":
        '''(experimental) Grants permission to modify settings for a cluster.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/AmazonElastiCache/latest/APIReference/API_ModifyCacheCluster.html

        :stability: experimental
        '''
        return typing.cast("Elasticache", jsii.invoke(self, "toModifyCacheCluster", []))

    @jsii.member(jsii_name="toModifyCacheParameterGroup")
    def to_modify_cache_parameter_group(self) -> "Elasticache":
        '''(experimental) Grants permission to modify parameters of a cache parameter group.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()
        - .ifCacheParameterGroupName()

        https://docs.aws.amazon.com/AmazonElastiCache/latest/APIReference/API_ModifyCacheParameterGroup.html

        :stability: experimental
        '''
        return typing.cast("Elasticache", jsii.invoke(self, "toModifyCacheParameterGroup", []))

    @jsii.member(jsii_name="toModifyCacheSubnetGroup")
    def to_modify_cache_subnet_group(self) -> "Elasticache":
        '''(experimental) Grants permission to modify an existing cache subnet group.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/AmazonElastiCache/latest/APIReference/API_ModifyCacheSubnetGroup.html

        :stability: experimental
        '''
        return typing.cast("Elasticache", jsii.invoke(self, "toModifyCacheSubnetGroup", []))

    @jsii.member(jsii_name="toModifyGlobalReplicationGroup")
    def to_modify_global_replication_group(self) -> "Elasticache":
        '''(experimental) Grants permission to modify settings for a global replication group.

        Access Level: Write

        Possible conditions:

        - .ifCacheNodeType()
        - .ifEngineVersion()
        - .ifAutomaticFailoverEnabled()

        https://docs.aws.amazon.com/AmazonElastiCache/latest/APIReference/API_ModifyGlobalReplicationGroup.html

        :stability: experimental
        '''
        return typing.cast("Elasticache", jsii.invoke(self, "toModifyGlobalReplicationGroup", []))

    @jsii.member(jsii_name="toModifyReplicationGroup")
    def to_modify_replication_group(self) -> "Elasticache":
        '''(experimental) Grants permission to modify the settings for a replication group.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        Dependent actions:

        - ec2:CreateNetworkInterface
        - ec2:DeleteNetworkInterface
        - ec2:DescribeNetworkInterfaces
        - ec2:DescribeSubnets
        - ec2:DescribeVpcs

        https://docs.aws.amazon.com/AmazonElastiCache/latest/APIReference/API_ModifyReplicationGroup.html

        :stability: experimental
        '''
        return typing.cast("Elasticache", jsii.invoke(self, "toModifyReplicationGroup", []))

    @jsii.member(jsii_name="toModifyReplicationGroupShardConfiguration")
    def to_modify_replication_group_shard_configuration(self) -> "Elasticache":
        '''(experimental) Grants permission to add shards, remove shards, or rebalance the keyspaces among existing shards of a replication group.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()
        - .ifNumNodeGroups()

        Dependent actions:

        - ec2:CreateNetworkInterface
        - ec2:DeleteNetworkInterface
        - ec2:DescribeNetworkInterfaces
        - ec2:DescribeSubnets
        - ec2:DescribeVpcs

        https://docs.aws.amazon.com/AmazonElastiCache/latest/APIReference/API_ModifyReplicationGroupShardConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Elasticache", jsii.invoke(self, "toModifyReplicationGroupShardConfiguration", []))

    @jsii.member(jsii_name="toModifyUser")
    def to_modify_user(self) -> "Elasticache":
        '''(experimental) Grants permission to change Redis user password(s) and/or access string.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()
        - .ifUserAuthenticationMode()

        https://docs.aws.amazon.com/AmazonElastiCache/latest/APIReference/API_ModifyUser.html

        :stability: experimental
        '''
        return typing.cast("Elasticache", jsii.invoke(self, "toModifyUser", []))

    @jsii.member(jsii_name="toModifyUserGroup")
    def to_modify_user_group(self) -> "Elasticache":
        '''(experimental) Grants permission to change list of users that belong to the user group.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/AmazonElastiCache/latest/APIReference/API_ModifyUserGroup.html

        :stability: experimental
        '''
        return typing.cast("Elasticache", jsii.invoke(self, "toModifyUserGroup", []))

    @jsii.member(jsii_name="toPurchaseReservedCacheNodesOffering")
    def to_purchase_reserved_cache_nodes_offering(self) -> "Elasticache":
        '''(experimental) Grants permission to purchase a reserved cache node offering.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()
        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - elasticache:AddTagsToResource

        https://docs.aws.amazon.com/AmazonElastiCache/latest/APIReference/API_PurchaseReservedCacheNodesOffering.html

        :stability: experimental
        '''
        return typing.cast("Elasticache", jsii.invoke(self, "toPurchaseReservedCacheNodesOffering", []))

    @jsii.member(jsii_name="toRebalanceSlotsInGlobalReplicationGroup")
    def to_rebalance_slots_in_global_replication_group(self) -> "Elasticache":
        '''(experimental) Grants permission to perform a key space rebalance operation to redistribute slots and ensure uniform key distribution across existing shards in a global replication group.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonElastiCache/latest/APIReference/API_RebalanceSlotsInGlobalReplicationGroup.html

        :stability: experimental
        '''
        return typing.cast("Elasticache", jsii.invoke(self, "toRebalanceSlotsInGlobalReplicationGroup", []))

    @jsii.member(jsii_name="toRebootCacheCluster")
    def to_reboot_cache_cluster(self) -> "Elasticache":
        '''(experimental) Grants permission to reboot some, or all, of the cache nodes within a provisioned cache cluster or replication group (cluster mode disabled).

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/AmazonElastiCache/latest/APIReference/API_RebootCacheCluster.html

        :stability: experimental
        '''
        return typing.cast("Elasticache", jsii.invoke(self, "toRebootCacheCluster", []))

    @jsii.member(jsii_name="toRemoveTagsFromResource")
    def to_remove_tags_from_resource(self) -> "Elasticache":
        '''(experimental) Grants permission to remove tags from a ElastiCache resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/AmazonElastiCache/latest/APIReference/API_RemoveTagsFromResource.html

        :stability: experimental
        '''
        return typing.cast("Elasticache", jsii.invoke(self, "toRemoveTagsFromResource", []))

    @jsii.member(jsii_name="toResetCacheParameterGroup")
    def to_reset_cache_parameter_group(self) -> "Elasticache":
        '''(experimental) Grants permission to modify parameters of a cache parameter group back to their default values.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()
        - .ifCacheParameterGroupName()

        https://docs.aws.amazon.com/AmazonElastiCache/latest/APIReference/API_ResetCacheParameterGroup.html

        :stability: experimental
        '''
        return typing.cast("Elasticache", jsii.invoke(self, "toResetCacheParameterGroup", []))

    @jsii.member(jsii_name="toRevokeCacheSecurityGroupIngress")
    def to_revoke_cache_security_group_ingress(self) -> "Elasticache":
        '''(experimental) Grants permission to remove an EC2 security group ingress from a ElastiCache security group.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/AmazonElastiCache/latest/APIReference/API_RevokeCacheSecurityGroupIngress.html

        :stability: experimental
        '''
        return typing.cast("Elasticache", jsii.invoke(self, "toRevokeCacheSecurityGroupIngress", []))

    @jsii.member(jsii_name="toStartMigration")
    def to_start_migration(self) -> "Elasticache":
        '''(experimental) Grants permission to start a migration of data from hosted Redis on Amazon EC2 to ElastiCache for Redis.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/AmazonElastiCache/latest/APIReference/API_StartMigration.html

        :stability: experimental
        '''
        return typing.cast("Elasticache", jsii.invoke(self, "toStartMigration", []))

    @jsii.member(jsii_name="toTestFailover")
    def to_test_failover(self) -> "Elasticache":
        '''(experimental) Grants permission to test automatic failover on a specified node group in a replication group.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        Dependent actions:

        - ec2:CreateNetworkInterface
        - ec2:DeleteNetworkInterface
        - ec2:DescribeNetworkInterfaces
        - ec2:DescribeSubnets
        - ec2:DescribeVpcs

        https://docs.aws.amazon.com/AmazonElastiCache/latest/APIReference/API_TestFailover.html

        :stability: experimental
        '''
        return typing.cast("Elasticache", jsii.invoke(self, "toTestFailover", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3f71a6da1056307b1ef4de1df3b131a2eb54105635fa0c427de367dc6ed85cde)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__98af9d0e0f3285c67fc05a441c7e02905737a3b1c61009543cec05b5394b54ad)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Elasticbeanstalk(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Elasticbeanstalk",
):
    '''(experimental) Statement provider for service `elasticbeanstalk <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awselasticbeanstalk.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `elasticbeanstalk <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awselasticbeanstalk.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="ifFromApplication")
    def if_from_application(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Elasticbeanstalk":
        '''(experimental) Filters access by an application as a dependency or a constraint on an input parameter.

        https://docs.aws.amazon.com/elasticbeanstalk/latest/dg/AWSHowTo.iam.policies.actions.html#AWSHowTo.iam.policies.conditions

        Applies to actions:

        - .toCreateConfigurationTemplate()
        - .toUpdateConfigurationTemplate()

        :param value: The value(s) to check.
        :param operator: Works with `arn operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_ARN>`_. **Default:** ``ArnLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2011df58cf62c621ff013e91fd7aad29782efd8a2696a9c62202664d22fd79d2)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Elasticbeanstalk", jsii.invoke(self, "ifFromApplication", [value, operator]))

    @jsii.member(jsii_name="ifFromApplicationVersion")
    def if_from_application_version(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Elasticbeanstalk":
        '''(experimental) Filters access by an application version as a dependency or a constraint on an input parameter.

        https://docs.aws.amazon.com/elasticbeanstalk/latest/dg/AWSHowTo.iam.policies.actions.html#AWSHowTo.iam.policies.conditions

        Applies to actions:

        - .toCreateConfigurationTemplate()
        - .toCreateEnvironment()
        - .toUpdateConfigurationTemplate()
        - .toUpdateEnvironment()

        :param value: The value(s) to check.
        :param operator: Works with `arn operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_ARN>`_. **Default:** ``ArnLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d76c73ed21ea7ad730e35ab7f1f2d2fc1e58ab80f4c43534bba2e79fe4a8334a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Elasticbeanstalk", jsii.invoke(self, "ifFromApplicationVersion", [value, operator]))

    @jsii.member(jsii_name="ifFromConfigurationTemplate")
    def if_from_configuration_template(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Elasticbeanstalk":
        '''(experimental) Filters access by a configuration template as a dependency or a constraint on an input parameter.

        https://docs.aws.amazon.com/elasticbeanstalk/latest/dg/AWSHowTo.iam.policies.actions.html#AWSHowTo.iam.policies.conditions

        Applies to actions:

        - .toCreateConfigurationTemplate()
        - .toCreateEnvironment()
        - .toUpdateConfigurationTemplate()
        - .toUpdateEnvironment()

        :param value: The value(s) to check.
        :param operator: Works with `arn operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_ARN>`_. **Default:** ``ArnLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e83817dfb14166fa6ea7aba13897dcb127eb4a0d2d0daa709c284dadd5120724)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Elasticbeanstalk", jsii.invoke(self, "ifFromConfigurationTemplate", [value, operator]))

    @jsii.member(jsii_name="ifFromEnvironment")
    def if_from_environment(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Elasticbeanstalk":
        '''(experimental) Filters access by an environment as a dependency or a constraint on an input parameter.

        https://docs.aws.amazon.com/elasticbeanstalk/latest/dg/AWSHowTo.iam.policies.actions.html#AWSHowTo.iam.policies.conditions

        Applies to actions:

        - .toCreateConfigurationTemplate()
        - .toSwapEnvironmentCNAMEs()
        - .toUpdateConfigurationTemplate()

        :param value: The value(s) to check.
        :param operator: Works with `arn operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_ARN>`_. **Default:** ``ArnLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__111f6b9019cb1f0b12d48fa9ec492163984db7f00079813eed7b4351a63be836)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Elasticbeanstalk", jsii.invoke(self, "ifFromEnvironment", [value, operator]))

    @jsii.member(jsii_name="ifFromPlatform")
    def if_from_platform(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Elasticbeanstalk":
        '''(experimental) Filters access by a platform as a dependency or a constraint on an input parameter.

        https://docs.aws.amazon.com/elasticbeanstalk/latest/dg/AWSHowTo.iam.policies.actions.html#AWSHowTo.iam.policies.conditions

        Applies to actions:

        - .toCreateConfigurationTemplate()
        - .toCreateEnvironment()
        - .toUpdateConfigurationTemplate()
        - .toUpdateEnvironment()

        :param value: The value(s) to check.
        :param operator: Works with `arn operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_ARN>`_. **Default:** ``ArnLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__07bf47c7224058dc72cfa9ebab5369c7edc0c73b646a01c35e006f3bdf491d07)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Elasticbeanstalk", jsii.invoke(self, "ifFromPlatform", [value, operator]))

    @jsii.member(jsii_name="ifFromSolutionStack")
    def if_from_solution_stack(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Elasticbeanstalk":
        '''(experimental) Filters access by a solution stack as a dependency or a constraint on an input parameter.

        https://docs.aws.amazon.com/elasticbeanstalk/latest/dg/AWSHowTo.iam.policies.actions.html#AWSHowTo.iam.policies.conditions

        Applies to actions:

        - .toCreateConfigurationTemplate()
        - .toCreateEnvironment()
        - .toUpdateConfigurationTemplate()
        - .toUpdateEnvironment()

        :param value: The value(s) to check.
        :param operator: Works with `arn operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_ARN>`_. **Default:** ``ArnLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7b55b4aba8e412aa41ceb2918c7438af64639f318237fa97e796d305f878ba03)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Elasticbeanstalk", jsii.invoke(self, "ifFromSolutionStack", [value, operator]))

    @jsii.member(jsii_name="ifInApplication")
    def if_in_application(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Elasticbeanstalk":
        '''(experimental) Filters access by the application that contains the resource that the action operates on.

        https://docs.aws.amazon.com/elasticbeanstalk/latest/dg/AWSHowTo.iam.policies.actions.html#AWSHowTo.iam.policies.conditions

        Applies to actions:

        - .toAbortEnvironmentUpdate()
        - .toApplyEnvironmentManagedAction()
        - .toComposeEnvironments()
        - .toCreateApplicationVersion()
        - .toCreateConfigurationTemplate()
        - .toCreateEnvironment()
        - .toDeleteApplicationVersion()
        - .toDeleteConfigurationTemplate()
        - .toDeleteEnvironmentConfiguration()
        - .toDescribeApplicationVersions()
        - .toDescribeConfigurationOptions()
        - .toDescribeConfigurationSettings()
        - .toDescribeEnvironmentManagedActionHistory()
        - .toDescribeEnvironmentManagedActions()
        - .toDescribeEnvironmentResources()
        - .toDescribeEnvironments()
        - .toDescribeEvents()
        - .toRebuildEnvironment()
        - .toRequestEnvironmentInfo()
        - .toRestartAppServer()
        - .toRetrieveEnvironmentInfo()
        - .toSwapEnvironmentCNAMEs()
        - .toTerminateEnvironment()
        - .toUpdateApplicationVersion()
        - .toUpdateConfigurationTemplate()
        - .toUpdateEnvironment()
        - .toValidateConfigurationSettings()

        Applies to resource types:

        - applicationversion
        - configurationtemplate
        - environment

        :param value: The value(s) to check.
        :param operator: Works with `arn operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_ARN>`_. **Default:** ``ArnLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__18eadeceef791625b103bb6edc7ab13bde64bf06b5a9afa4f3b16cb74e9a5136)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Elasticbeanstalk", jsii.invoke(self, "ifInApplication", [value, operator]))

    @jsii.member(jsii_name="onApplication")
    def on_application(
        self,
        application_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Elasticbeanstalk":
        '''(experimental) Adds a resource of type application to the statement.

        https://docs.aws.amazon.com/elasticbeanstalk/latest/dg/AWSHowTo.iam.policies.arn.html

        :param application_name: - Identifier for the applicationName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__936993d5bd6842d66199f34726d366509e0bd18b6747e5bb615c8b9195368d00)
            check_type(argname="argument application_name", value=application_name, expected_type=type_hints["application_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Elasticbeanstalk", jsii.invoke(self, "onApplication", [application_name, account, region, partition]))

    @jsii.member(jsii_name="onApplicationversion")
    def on_applicationversion(
        self,
        application_name: builtins.str,
        version_label: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Elasticbeanstalk":
        '''(experimental) Adds a resource of type applicationversion to the statement.

        https://docs.aws.amazon.com/elasticbeanstalk/latest/dg/AWSHowTo.iam.policies.arn.html

        :param application_name: - Identifier for the applicationName.
        :param version_label: - Identifier for the versionLabel.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag() - .ifInApplication()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__30f4e6264e6695e51c78204fb4b11936d5f390e77baaa5c91c42debbcf9e43a1)
            check_type(argname="argument application_name", value=application_name, expected_type=type_hints["application_name"])
            check_type(argname="argument version_label", value=version_label, expected_type=type_hints["version_label"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Elasticbeanstalk", jsii.invoke(self, "onApplicationversion", [application_name, version_label, account, region, partition]))

    @jsii.member(jsii_name="onConfigurationtemplate")
    def on_configurationtemplate(
        self,
        application_name: builtins.str,
        template_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Elasticbeanstalk":
        '''(experimental) Adds a resource of type configurationtemplate to the statement.

        https://docs.aws.amazon.com/elasticbeanstalk/latest/dg/AWSHowTo.iam.policies.arn.html

        :param application_name: - Identifier for the applicationName.
        :param template_name: - Identifier for the templateName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag() - .ifInApplication()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8037b4af3572c3e8a2d7b8ca3b8758b0c23c31742ec7255a2aa6379742c647d6)
            check_type(argname="argument application_name", value=application_name, expected_type=type_hints["application_name"])
            check_type(argname="argument template_name", value=template_name, expected_type=type_hints["template_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Elasticbeanstalk", jsii.invoke(self, "onConfigurationtemplate", [application_name, template_name, account, region, partition]))

    @jsii.member(jsii_name="onEnvironment")
    def on_environment(
        self,
        application_name: builtins.str,
        environment_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Elasticbeanstalk":
        '''(experimental) Adds a resource of type environment to the statement.

        https://docs.aws.amazon.com/elasticbeanstalk/latest/dg/AWSHowTo.iam.policies.arn.html

        :param application_name: - Identifier for the applicationName.
        :param environment_name: - Identifier for the environmentName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag() - .ifInApplication()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8562f8d9604468025293d2d7cd145e5c95dfc46a00d4ceea60ccd1fd8e6562b3)
            check_type(argname="argument application_name", value=application_name, expected_type=type_hints["application_name"])
            check_type(argname="argument environment_name", value=environment_name, expected_type=type_hints["environment_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Elasticbeanstalk", jsii.invoke(self, "onEnvironment", [application_name, environment_name, account, region, partition]))

    @jsii.member(jsii_name="onPlatform")
    def on_platform(
        self,
        platform_name_with_version: builtins.str,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Elasticbeanstalk":
        '''(experimental) Adds a resource of type platform to the statement.

        https://docs.aws.amazon.com/elasticbeanstalk/latest/dg/AWSHowTo.iam.policies.arn.html

        :param platform_name_with_version: - Identifier for the platformNameWithVersion.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c436402e4cc93c70a7d1621de0eeebb7974119d7281227dea97458bdd98d3700)
            check_type(argname="argument platform_name_with_version", value=platform_name_with_version, expected_type=type_hints["platform_name_with_version"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Elasticbeanstalk", jsii.invoke(self, "onPlatform", [platform_name_with_version, region, partition]))

    @jsii.member(jsii_name="onSolutionstack")
    def on_solutionstack(
        self,
        solution_stack_name: builtins.str,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Elasticbeanstalk":
        '''(experimental) Adds a resource of type solutionstack to the statement.

        https://docs.aws.amazon.com/elasticbeanstalk/latest/dg/AWSHowTo.iam.policies.arn.html

        :param solution_stack_name: - Identifier for the solutionStackName.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__47c28976ab644b571f4edb464c4d0c76c1052af93d26faf8c3192e4d72eb7741)
            check_type(argname="argument solution_stack_name", value=solution_stack_name, expected_type=type_hints["solution_stack_name"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Elasticbeanstalk", jsii.invoke(self, "onSolutionstack", [solution_stack_name, region, partition]))

    @jsii.member(jsii_name="toAbortEnvironmentUpdate")
    def to_abort_environment_update(self) -> "Elasticbeanstalk":
        '''(experimental) Grants permission to cancel in-progress environment configuration update or application version deployment.

        Access Level: Write

        https://docs.aws.amazon.com/elasticbeanstalk/latest/api/API_AbortEnvironmentUpdate.html

        :stability: experimental
        '''
        return typing.cast("Elasticbeanstalk", jsii.invoke(self, "toAbortEnvironmentUpdate", []))

    @jsii.member(jsii_name="toAddTags")
    def to_add_tags(self) -> "Elasticbeanstalk":
        '''(experimental) Grants permission to add tags to an Elastic Beanstalk resource and to update tag values.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/elasticbeanstalk/latest/api/API_UpdateTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("Elasticbeanstalk", jsii.invoke(self, "toAddTags", []))

    @jsii.member(jsii_name="toApplyEnvironmentManagedAction")
    def to_apply_environment_managed_action(self) -> "Elasticbeanstalk":
        '''(experimental) Grants permission to apply a scheduled managed action immediately.

        Access Level: Write

        https://docs.aws.amazon.com/elasticbeanstalk/latest/api/API_ApplyEnvironmentManagedAction.html

        :stability: experimental
        '''
        return typing.cast("Elasticbeanstalk", jsii.invoke(self, "toApplyEnvironmentManagedAction", []))

    @jsii.member(jsii_name="toAssociateEnvironmentOperationsRole")
    def to_associate_environment_operations_role(self) -> "Elasticbeanstalk":
        '''(experimental) Grants permission to associate an operations role with an environment.

        Access Level: Write

        https://docs.aws.amazon.com/elasticbeanstalk/latest/api/API_AssociateEnvironmentOperationsRole.html

        :stability: experimental
        '''
        return typing.cast("Elasticbeanstalk", jsii.invoke(self, "toAssociateEnvironmentOperationsRole", []))

    @jsii.member(jsii_name="toCheckDNSAvailability")
    def to_check_dns_availability(self) -> "Elasticbeanstalk":
        '''(experimental) Grants permission to check CNAME availability.

        Access Level: Read

        https://docs.aws.amazon.com/elasticbeanstalk/latest/api/API_CheckDNSAvailability.html

        :stability: experimental
        '''
        return typing.cast("Elasticbeanstalk", jsii.invoke(self, "toCheckDNSAvailability", []))

    @jsii.member(jsii_name="toComposeEnvironments")
    def to_compose_environments(self) -> "Elasticbeanstalk":
        '''(experimental) Grants permission to create or update a group of environments, each running a separate component of a single application.

        Access Level: Write

        https://docs.aws.amazon.com/elasticbeanstalk/latest/api/API_ComposeEnvironments.html

        :stability: experimental
        '''
        return typing.cast("Elasticbeanstalk", jsii.invoke(self, "toComposeEnvironments", []))

    @jsii.member(jsii_name="toCreateApplication")
    def to_create_application(self) -> "Elasticbeanstalk":
        '''(experimental) Grants permission to create a new application.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/elasticbeanstalk/latest/api/API_CreateApplication.html

        :stability: experimental
        '''
        return typing.cast("Elasticbeanstalk", jsii.invoke(self, "toCreateApplication", []))

    @jsii.member(jsii_name="toCreateApplicationVersion")
    def to_create_application_version(self) -> "Elasticbeanstalk":
        '''(experimental) Grants permission to create an application version for an application.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/elasticbeanstalk/latest/api/API_CreateApplicationVersion.html

        :stability: experimental
        '''
        return typing.cast("Elasticbeanstalk", jsii.invoke(self, "toCreateApplicationVersion", []))

    @jsii.member(jsii_name="toCreateConfigurationTemplate")
    def to_create_configuration_template(self) -> "Elasticbeanstalk":
        '''(experimental) Grants permission to create a configuration template.

        Access Level: Write

        Possible conditions:

        - .ifFromApplication()
        - .ifFromApplicationVersion()
        - .ifFromConfigurationTemplate()
        - .ifFromEnvironment()
        - .ifFromSolutionStack()
        - .ifFromPlatform()
        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/elasticbeanstalk/latest/api/API_CreateConfigurationTemplate.html

        :stability: experimental
        '''
        return typing.cast("Elasticbeanstalk", jsii.invoke(self, "toCreateConfigurationTemplate", []))

    @jsii.member(jsii_name="toCreateEnvironment")
    def to_create_environment(self) -> "Elasticbeanstalk":
        '''(experimental) Grants permission to launch an environment for an application.

        Access Level: Write

        Possible conditions:

        - .ifFromApplicationVersion()
        - .ifFromConfigurationTemplate()
        - .ifFromSolutionStack()
        - .ifFromPlatform()
        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/elasticbeanstalk/latest/api/API_CreateEnvironment.html

        :stability: experimental
        '''
        return typing.cast("Elasticbeanstalk", jsii.invoke(self, "toCreateEnvironment", []))

    @jsii.member(jsii_name="toCreatePlatformVersion")
    def to_create_platform_version(self) -> "Elasticbeanstalk":
        '''(experimental) Grants permission to create a new version of a custom platform.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/elasticbeanstalk/latest/api/API_CreatePlatformVersion.html

        :stability: experimental
        '''
        return typing.cast("Elasticbeanstalk", jsii.invoke(self, "toCreatePlatformVersion", []))

    @jsii.member(jsii_name="toCreateStorageLocation")
    def to_create_storage_location(self) -> "Elasticbeanstalk":
        '''(experimental) Grants permission to create the Amazon S3 storage location for the account.

        Access Level: Write

        https://docs.aws.amazon.com/elasticbeanstalk/latest/api/API_CreateStorageLocation.html

        :stability: experimental
        '''
        return typing.cast("Elasticbeanstalk", jsii.invoke(self, "toCreateStorageLocation", []))

    @jsii.member(jsii_name="toDeleteApplication")
    def to_delete_application(self) -> "Elasticbeanstalk":
        '''(experimental) Grants permission to delete an application along with all associated versions and configurations.

        Access Level: Write

        https://docs.aws.amazon.com/elasticbeanstalk/latest/api/API_DeleteApplication.html

        :stability: experimental
        '''
        return typing.cast("Elasticbeanstalk", jsii.invoke(self, "toDeleteApplication", []))

    @jsii.member(jsii_name="toDeleteApplicationVersion")
    def to_delete_application_version(self) -> "Elasticbeanstalk":
        '''(experimental) Grants permission to delete an application version from an application.

        Access Level: Write

        https://docs.aws.amazon.com/elasticbeanstalk/latest/api/API_DeleteApplicationVersion.html

        :stability: experimental
        '''
        return typing.cast("Elasticbeanstalk", jsii.invoke(self, "toDeleteApplicationVersion", []))

    @jsii.member(jsii_name="toDeleteConfigurationTemplate")
    def to_delete_configuration_template(self) -> "Elasticbeanstalk":
        '''(experimental) Grants permission to delete a configuration template.

        Access Level: Write

        https://docs.aws.amazon.com/elasticbeanstalk/latest/api/API_DeleteConfigurationTemplate.html

        :stability: experimental
        '''
        return typing.cast("Elasticbeanstalk", jsii.invoke(self, "toDeleteConfigurationTemplate", []))

    @jsii.member(jsii_name="toDeleteEnvironmentConfiguration")
    def to_delete_environment_configuration(self) -> "Elasticbeanstalk":
        '''(experimental) Grants permission to delete the draft configuration associated with the running environment.

        Access Level: Write

        https://docs.aws.amazon.com/elasticbeanstalk/latest/api/API_DeleteEnvironmentConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Elasticbeanstalk", jsii.invoke(self, "toDeleteEnvironmentConfiguration", []))

    @jsii.member(jsii_name="toDeletePlatformVersion")
    def to_delete_platform_version(self) -> "Elasticbeanstalk":
        '''(experimental) Grants permission to delete a version of a custom platform.

        Access Level: Write

        https://docs.aws.amazon.com/elasticbeanstalk/latest/api/API_DeletePlatformVersion.html

        :stability: experimental
        '''
        return typing.cast("Elasticbeanstalk", jsii.invoke(self, "toDeletePlatformVersion", []))

    @jsii.member(jsii_name="toDescribeAccountAttributes")
    def to_describe_account_attributes(self) -> "Elasticbeanstalk":
        '''(experimental) Grants permission to retrieve a list of account attributes, including resource quotas.

        Access Level: Read

        https://docs.aws.amazon.com/elasticbeanstalk/latest/api/API_DescribeAccountAttributes.html

        :stability: experimental
        '''
        return typing.cast("Elasticbeanstalk", jsii.invoke(self, "toDescribeAccountAttributes", []))

    @jsii.member(jsii_name="toDescribeApplications")
    def to_describe_applications(self) -> "Elasticbeanstalk":
        '''(experimental) Grants permission to retrieve the descriptions of existing applications.

        Access Level: List

        https://docs.aws.amazon.com/elasticbeanstalk/latest/api/API_DescribeApplications.html

        :stability: experimental
        '''
        return typing.cast("Elasticbeanstalk", jsii.invoke(self, "toDescribeApplications", []))

    @jsii.member(jsii_name="toDescribeApplicationVersions")
    def to_describe_application_versions(self) -> "Elasticbeanstalk":
        '''(experimental) Grants permission to retrieve a list of application versions stored in an AWS Elastic Beanstalk storage bucket.

        Access Level: List

        https://docs.aws.amazon.com/elasticbeanstalk/latest/api/API_DescribeApplicationVersions.html

        :stability: experimental
        '''
        return typing.cast("Elasticbeanstalk", jsii.invoke(self, "toDescribeApplicationVersions", []))

    @jsii.member(jsii_name="toDescribeConfigurationOptions")
    def to_describe_configuration_options(self) -> "Elasticbeanstalk":
        '''(experimental) Grants permission to retrieve descriptions of environment configuration options.

        Access Level: Read

        https://docs.aws.amazon.com/elasticbeanstalk/latest/api/API_DescribeConfigurationOptions.html

        :stability: experimental
        '''
        return typing.cast("Elasticbeanstalk", jsii.invoke(self, "toDescribeConfigurationOptions", []))

    @jsii.member(jsii_name="toDescribeConfigurationSettings")
    def to_describe_configuration_settings(self) -> "Elasticbeanstalk":
        '''(experimental) Grants permission to retrieve a description of the settings for a configuration set.

        Access Level: Read

        https://docs.aws.amazon.com/elasticbeanstalk/latest/api/API_DescribeConfigurationSettings.html

        :stability: experimental
        '''
        return typing.cast("Elasticbeanstalk", jsii.invoke(self, "toDescribeConfigurationSettings", []))

    @jsii.member(jsii_name="toDescribeEnvironmentHealth")
    def to_describe_environment_health(self) -> "Elasticbeanstalk":
        '''(experimental) Grants permission to retrieve information about the overall health of an environment.

        Access Level: Read

        https://docs.aws.amazon.com/elasticbeanstalk/latest/api/API_DescribeEnvironmentHealth.html

        :stability: experimental
        '''
        return typing.cast("Elasticbeanstalk", jsii.invoke(self, "toDescribeEnvironmentHealth", []))

    @jsii.member(jsii_name="toDescribeEnvironmentManagedActionHistory")
    def to_describe_environment_managed_action_history(self) -> "Elasticbeanstalk":
        '''(experimental) Grants permission to retrieve a list of an environment's completed and failed managed actions.

        Access Level: Read

        https://docs.aws.amazon.com/elasticbeanstalk/latest/api/API_DescribeEnvironmentManagedActionHistory.html

        :stability: experimental
        '''
        return typing.cast("Elasticbeanstalk", jsii.invoke(self, "toDescribeEnvironmentManagedActionHistory", []))

    @jsii.member(jsii_name="toDescribeEnvironmentManagedActions")
    def to_describe_environment_managed_actions(self) -> "Elasticbeanstalk":
        '''(experimental) Grants permission to retrieve a list of an environment's upcoming and in-progress managed actions.

        Access Level: Read

        https://docs.aws.amazon.com/elasticbeanstalk/latest/api/API_DescribeEnvironmentManagedActions.html

        :stability: experimental
        '''
        return typing.cast("Elasticbeanstalk", jsii.invoke(self, "toDescribeEnvironmentManagedActions", []))

    @jsii.member(jsii_name="toDescribeEnvironmentResources")
    def to_describe_environment_resources(self) -> "Elasticbeanstalk":
        '''(experimental) Grants permission to retrieve a list of AWS resources for an environment.

        Access Level: Read

        https://docs.aws.amazon.com/elasticbeanstalk/latest/api/API_DescribeEnvironmentResources.html

        :stability: experimental
        '''
        return typing.cast("Elasticbeanstalk", jsii.invoke(self, "toDescribeEnvironmentResources", []))

    @jsii.member(jsii_name="toDescribeEnvironments")
    def to_describe_environments(self) -> "Elasticbeanstalk":
        '''(experimental) Grants permission to retrieve descriptions for existing environments.

        Access Level: List

        https://docs.aws.amazon.com/elasticbeanstalk/latest/api/API_DescribeEnvironments.html

        :stability: experimental
        '''
        return typing.cast("Elasticbeanstalk", jsii.invoke(self, "toDescribeEnvironments", []))

    @jsii.member(jsii_name="toDescribeEvents")
    def to_describe_events(self) -> "Elasticbeanstalk":
        '''(experimental) Grants permission to retrieve a list of event descriptions matching a set of criteria.

        Access Level: Read

        https://docs.aws.amazon.com/elasticbeanstalk/latest/api/API_DescribeEvents.html

        :stability: experimental
        '''
        return typing.cast("Elasticbeanstalk", jsii.invoke(self, "toDescribeEvents", []))

    @jsii.member(jsii_name="toDescribeInstancesHealth")
    def to_describe_instances_health(self) -> "Elasticbeanstalk":
        '''(experimental) Grants permission to retrieve more detailed information about the health of environment instances.

        Access Level: Read

        https://docs.aws.amazon.com/elasticbeanstalk/latest/api/API_DescribeInstancesHealth.html

        :stability: experimental
        '''
        return typing.cast("Elasticbeanstalk", jsii.invoke(self, "toDescribeInstancesHealth", []))

    @jsii.member(jsii_name="toDescribePlatformVersion")
    def to_describe_platform_version(self) -> "Elasticbeanstalk":
        '''(experimental) Grants permission to retrieve a description of a platform version.

        Access Level: Read

        https://docs.aws.amazon.com/elasticbeanstalk/latest/api/API_DescribePlatformVersion.html

        :stability: experimental
        '''
        return typing.cast("Elasticbeanstalk", jsii.invoke(self, "toDescribePlatformVersion", []))

    @jsii.member(jsii_name="toDisassociateEnvironmentOperationsRole")
    def to_disassociate_environment_operations_role(self) -> "Elasticbeanstalk":
        '''(experimental) Grants permission to disassociate an operations role with an environment.

        Access Level: Write

        https://docs.aws.amazon.com/elasticbeanstalk/latest/api/API_DisassociateEnvironmentOperationsRole.html

        :stability: experimental
        '''
        return typing.cast("Elasticbeanstalk", jsii.invoke(self, "toDisassociateEnvironmentOperationsRole", []))

    @jsii.member(jsii_name="toListAvailableSolutionStacks")
    def to_list_available_solution_stacks(self) -> "Elasticbeanstalk":
        '''(experimental) Grants permission to retrieve a list of the available solution stack names.

        Access Level: List

        https://docs.aws.amazon.com/elasticbeanstalk/latest/api/API_ListAvailableSolutionStacks.html

        :stability: experimental
        '''
        return typing.cast("Elasticbeanstalk", jsii.invoke(self, "toListAvailableSolutionStacks", []))

    @jsii.member(jsii_name="toListPlatformBranches")
    def to_list_platform_branches(self) -> "Elasticbeanstalk":
        '''(experimental) Grants permission to retrieve a list of the available platform branches.

        Access Level: List

        https://docs.aws.amazon.com/elasticbeanstalk/latest/api/API_ListPlatformBranches.html

        :stability: experimental
        '''
        return typing.cast("Elasticbeanstalk", jsii.invoke(self, "toListPlatformBranches", []))

    @jsii.member(jsii_name="toListPlatformVersions")
    def to_list_platform_versions(self) -> "Elasticbeanstalk":
        '''(experimental) Grants permission to retrieve a list of the available platforms.

        Access Level: List

        https://docs.aws.amazon.com/elasticbeanstalk/latest/api/API_ListPlatformVersions.html

        :stability: experimental
        '''
        return typing.cast("Elasticbeanstalk", jsii.invoke(self, "toListPlatformVersions", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Elasticbeanstalk":
        '''(experimental) Grants permission to retrieve a list of tags of an Elastic Beanstalk resource.

        Access Level: Read

        https://docs.aws.amazon.com/elasticbeanstalk/latest/api/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("Elasticbeanstalk", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toPutInstanceStatistics")
    def to_put_instance_statistics(self) -> "Elasticbeanstalk":
        '''(experimental) Grants permission to submit instance statistics for enhanced health.

        Access Level: Write

        https://docs.aws.amazon.com/elasticbeanstalk/latest/dg/health-enhanced.html#health-enhanced-authz

        :stability: experimental
        '''
        return typing.cast("Elasticbeanstalk", jsii.invoke(self, "toPutInstanceStatistics", []))

    @jsii.member(jsii_name="toRebuildEnvironment")
    def to_rebuild_environment(self) -> "Elasticbeanstalk":
        '''(experimental) Grants permission to delete and recreate all of the AWS resources for an environment and to force a restart.

        Access Level: Write

        https://docs.aws.amazon.com/elasticbeanstalk/latest/api/API_RebuildEnvironment.html

        :stability: experimental
        '''
        return typing.cast("Elasticbeanstalk", jsii.invoke(self, "toRebuildEnvironment", []))

    @jsii.member(jsii_name="toRemoveTags")
    def to_remove_tags(self) -> "Elasticbeanstalk":
        '''(experimental) Grants permission to remove tags from an Elastic Beanstalk resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/elasticbeanstalk/latest/api/API_UpdateTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("Elasticbeanstalk", jsii.invoke(self, "toRemoveTags", []))

    @jsii.member(jsii_name="toRequestEnvironmentInfo")
    def to_request_environment_info(self) -> "Elasticbeanstalk":
        '''(experimental) Grants permission to initiate a request to compile information of the deployed environment.

        Access Level: Read

        https://docs.aws.amazon.com/elasticbeanstalk/latest/api/API_RequestEnvironmentInfo.html

        :stability: experimental
        '''
        return typing.cast("Elasticbeanstalk", jsii.invoke(self, "toRequestEnvironmentInfo", []))

    @jsii.member(jsii_name="toRestartAppServer")
    def to_restart_app_server(self) -> "Elasticbeanstalk":
        '''(experimental) Grants permission to request an environment to restart the application container server running on each Amazon EC2 instance.

        Access Level: Write

        https://docs.aws.amazon.com/elasticbeanstalk/latest/api/API_RestartAppServer.html

        :stability: experimental
        '''
        return typing.cast("Elasticbeanstalk", jsii.invoke(self, "toRestartAppServer", []))

    @jsii.member(jsii_name="toRetrieveEnvironmentInfo")
    def to_retrieve_environment_info(self) -> "Elasticbeanstalk":
        '''(experimental) Grants permission to retrieve the compiled information from a RequestEnvironmentInfo request.

        Access Level: Read

        https://docs.aws.amazon.com/elasticbeanstalk/latest/api/API_RetrieveEnvironmentInfo.html

        :stability: experimental
        '''
        return typing.cast("Elasticbeanstalk", jsii.invoke(self, "toRetrieveEnvironmentInfo", []))

    @jsii.member(jsii_name="toSwapEnvironmentCNAMEs")
    def to_swap_environment_cnam_es(self) -> "Elasticbeanstalk":
        '''(experimental) Grants permission to swap the CNAMEs of two environments.

        Access Level: Write

        Possible conditions:

        - .ifFromEnvironment()

        https://docs.aws.amazon.com/elasticbeanstalk/latest/api/API_SwapEnvironmentCNAMEs.html

        :stability: experimental
        '''
        return typing.cast("Elasticbeanstalk", jsii.invoke(self, "toSwapEnvironmentCNAMEs", []))

    @jsii.member(jsii_name="toTerminateEnvironment")
    def to_terminate_environment(self) -> "Elasticbeanstalk":
        '''(experimental) Grants permission to terminate an environment.

        Access Level: Write

        https://docs.aws.amazon.com/elasticbeanstalk/latest/api/API_TerminateEnvironment.html

        :stability: experimental
        '''
        return typing.cast("Elasticbeanstalk", jsii.invoke(self, "toTerminateEnvironment", []))

    @jsii.member(jsii_name="toUpdateApplication")
    def to_update_application(self) -> "Elasticbeanstalk":
        '''(experimental) Grants permission to update an application with specified properties.

        Access Level: Write

        https://docs.aws.amazon.com/elasticbeanstalk/latest/api/API_UpdateApplication.html

        :stability: experimental
        '''
        return typing.cast("Elasticbeanstalk", jsii.invoke(self, "toUpdateApplication", []))

    @jsii.member(jsii_name="toUpdateApplicationResourceLifecycle")
    def to_update_application_resource_lifecycle(self) -> "Elasticbeanstalk":
        '''(experimental) Grants permission to update the application version lifecycle policy associated with the application.

        Access Level: Write

        https://docs.aws.amazon.com/elasticbeanstalk/latest/api/API_UpdateApplicationResourceLifecycle.html

        :stability: experimental
        '''
        return typing.cast("Elasticbeanstalk", jsii.invoke(self, "toUpdateApplicationResourceLifecycle", []))

    @jsii.member(jsii_name="toUpdateApplicationVersion")
    def to_update_application_version(self) -> "Elasticbeanstalk":
        '''(experimental) Grants permission to update an application version with specified properties.

        Access Level: Write

        https://docs.aws.amazon.com/elasticbeanstalk/latest/api/API_UpdateApplicationVersion.html

        :stability: experimental
        '''
        return typing.cast("Elasticbeanstalk", jsii.invoke(self, "toUpdateApplicationVersion", []))

    @jsii.member(jsii_name="toUpdateConfigurationTemplate")
    def to_update_configuration_template(self) -> "Elasticbeanstalk":
        '''(experimental) Grants permission to update a configuration template with specified properties or configuration option values.

        Access Level: Write

        Possible conditions:

        - .ifFromApplication()
        - .ifFromApplicationVersion()
        - .ifFromConfigurationTemplate()
        - .ifFromEnvironment()
        - .ifFromSolutionStack()
        - .ifFromPlatform()

        https://docs.aws.amazon.com/elasticbeanstalk/latest/api/API_UpdateConfigurationTemplate.html

        :stability: experimental
        '''
        return typing.cast("Elasticbeanstalk", jsii.invoke(self, "toUpdateConfigurationTemplate", []))

    @jsii.member(jsii_name="toUpdateEnvironment")
    def to_update_environment(self) -> "Elasticbeanstalk":
        '''(experimental) Grants permission to update an environment.

        Access Level: Write

        Possible conditions:

        - .ifFromApplicationVersion()
        - .ifFromConfigurationTemplate()
        - .ifFromSolutionStack()
        - .ifFromPlatform()

        https://docs.aws.amazon.com/elasticbeanstalk/latest/api/API_UpdateEnvironment.html

        :stability: experimental
        '''
        return typing.cast("Elasticbeanstalk", jsii.invoke(self, "toUpdateEnvironment", []))

    @jsii.member(jsii_name="toUpdateTagsForResource")
    def to_update_tags_for_resource(self) -> "Elasticbeanstalk":
        '''(experimental) Grants permission to add tags to an Elastic Beanstalk resource, remove tags, and to update tag values.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/elasticbeanstalk/latest/api/API_UpdateTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("Elasticbeanstalk", jsii.invoke(self, "toUpdateTagsForResource", []))

    @jsii.member(jsii_name="toValidateConfigurationSettings")
    def to_validate_configuration_settings(self) -> "Elasticbeanstalk":
        '''(experimental) Grants permission to check the validity of a set of configuration settings for a configuration template or an environment.

        Access Level: Read

        https://docs.aws.amazon.com/elasticbeanstalk/latest/api/API_ValidateConfigurationSettings.html

        :stability: experimental
        '''
        return typing.cast("Elasticbeanstalk", jsii.invoke(self, "toValidateConfigurationSettings", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b3df372293686453a4cd663fce609bf3b2ee0c9a2492d0295aeb99cfbacecef7)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5ffec6d1af9e2efd573049637f946ade360d961869b3e60b7e1542851d02d822)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Elasticfilesystem(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Elasticfilesystem",
):
    '''(experimental) Statement provider for service `elasticfilesystem <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonelasticfilesystem.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `elasticfilesystem <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonelasticfilesystem.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="ifAccessedViaMountTarget")
    def if_accessed_via_mount_target(
        self,
        value: typing.Optional[builtins.bool] = None,
    ) -> "Elasticfilesystem":
        '''(experimental) Filters access by whether the file system is accessed via mount targets.

        https://docs.aws.amazon.com/efs/latest/ug/mounting-fs.html

        Applies to actions:

        - .toClientMount()
        - .toClientRootAccess()
        - .toClientWrite()

        :param value: ``true`` or ``false``. **Default:** ``true``

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__29e2907ebbf46520d1ad5cb529fb9877fa2762231e74c19537b39238c772137a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast("Elasticfilesystem", jsii.invoke(self, "ifAccessedViaMountTarget", [value]))

    @jsii.member(jsii_name="ifAccessPointArn")
    def if_access_point_arn(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Elasticfilesystem":
        '''(experimental) Filters access by the ARN of the access point used to mount the file system.

        https://docs.aws.amazon.com/efs/latest/ug/efs-access-points.html

        Applies to actions:

        - .toClientMount()
        - .toClientRootAccess()
        - .toClientWrite()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__67f5a0193c1b2881bd82e10402bbf056d4f1f76bdcfcb33b5b8658e1dfb1a1ad)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Elasticfilesystem", jsii.invoke(self, "ifAccessPointArn", [value, operator]))

    @jsii.member(jsii_name="ifEncrypted")
    def if_encrypted(
        self,
        value: typing.Optional[builtins.bool] = None,
    ) -> "Elasticfilesystem":
        '''(experimental) Filters access by whether users can create only encrypted or unencrypted file systems.

        https://docs.aws.amazon.com/efs/latest/ug/encryption.html

        Applies to actions:

        - .toCreateFileSystem()

        :param value: ``true`` or ``false``. **Default:** ``true``

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ad515cfe78fe1ca67a6d14160e04d97e23fab51296a3abccb3b3083d2fb56c9a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast("Elasticfilesystem", jsii.invoke(self, "ifEncrypted", [value]))

    @jsii.member(jsii_name="onAccessPoint")
    def on_access_point(
        self,
        access_point_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Elasticfilesystem":
        '''(experimental) Adds a resource of type access-point to the statement.

        https://docs.aws.amazon.com/efs/latest/ug/access-control-overview.html#access-control-resources

        :param access_point_id: - Identifier for the accessPointId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__747ff12390746bc038203b3dabf8876a73a498f0d00d85d87583bfb407273a7e)
            check_type(argname="argument access_point_id", value=access_point_id, expected_type=type_hints["access_point_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Elasticfilesystem", jsii.invoke(self, "onAccessPoint", [access_point_id, account, region, partition]))

    @jsii.member(jsii_name="onFileSystem")
    def on_file_system(
        self,
        file_system_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Elasticfilesystem":
        '''(experimental) Adds a resource of type file-system to the statement.

        https://docs.aws.amazon.com/efs/latest/ug/access-control-overview.html#access-control-resources

        :param file_system_id: - Identifier for the fileSystemId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__233e8627c3247c5165d833a6b7c604f7411531d79b497680c758cd68d3e4bf51)
            check_type(argname="argument file_system_id", value=file_system_id, expected_type=type_hints["file_system_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Elasticfilesystem", jsii.invoke(self, "onFileSystem", [file_system_id, account, region, partition]))

    @jsii.member(jsii_name="toBackup")
    def to_backup(self) -> "Elasticfilesystem":
        '''(experimental) Grants permission to start a backup job for an existing file system.

        Access Level: Write

        https://docs.aws.amazon.com/efs/latest/ug/efs-backup-solutions.html

        :stability: experimental
        '''
        return typing.cast("Elasticfilesystem", jsii.invoke(self, "toBackup", []))

    @jsii.member(jsii_name="toClientMount")
    def to_client_mount(self) -> "Elasticfilesystem":
        '''(experimental) Grants permission to allow an NFS client read-access to a file system.

        Access Level: Read

        Possible conditions:

        - .ifAccessPointArn()
        - .ifAccessedViaMountTarget()

        https://docs.aws.amazon.com/efs/latest/ug/efs-client-authorization.html

        :stability: experimental
        '''
        return typing.cast("Elasticfilesystem", jsii.invoke(self, "toClientMount", []))

    @jsii.member(jsii_name="toClientRootAccess")
    def to_client_root_access(self) -> "Elasticfilesystem":
        '''(experimental) Grants permission to allow an NFS client root-access to a file system.

        Access Level: Write

        Possible conditions:

        - .ifAccessPointArn()
        - .ifAccessedViaMountTarget()

        https://docs.aws.amazon.com/efs/latest/ug/efs-client-authorization.html

        :stability: experimental
        '''
        return typing.cast("Elasticfilesystem", jsii.invoke(self, "toClientRootAccess", []))

    @jsii.member(jsii_name="toClientWrite")
    def to_client_write(self) -> "Elasticfilesystem":
        '''(experimental) Grants permission to allow an NFS client write-access to a file system.

        Access Level: Write

        Possible conditions:

        - .ifAccessPointArn()
        - .ifAccessedViaMountTarget()

        https://docs.aws.amazon.com/efs/latest/ug/efs-client-authorization.html

        :stability: experimental
        '''
        return typing.cast("Elasticfilesystem", jsii.invoke(self, "toClientWrite", []))

    @jsii.member(jsii_name="toCreateAccessPoint")
    def to_create_access_point(self) -> "Elasticfilesystem":
        '''(experimental) Grants permission to create an access point for the specified file system.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/efs/latest/ug/API_CreateAccessPoint.html

        :stability: experimental
        '''
        return typing.cast("Elasticfilesystem", jsii.invoke(self, "toCreateAccessPoint", []))

    @jsii.member(jsii_name="toCreateFileSystem")
    def to_create_file_system(self) -> "Elasticfilesystem":
        '''(experimental) Grants permission to create a new, empty file system.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifEncrypted()

        https://docs.aws.amazon.com/efs/latest/ug/API_CreateFileSystem.html

        :stability: experimental
        '''
        return typing.cast("Elasticfilesystem", jsii.invoke(self, "toCreateFileSystem", []))

    @jsii.member(jsii_name="toCreateMountTarget")
    def to_create_mount_target(self) -> "Elasticfilesystem":
        '''(experimental) Grants permission to create a mount target for a file system.

        Access Level: Write

        https://docs.aws.amazon.com/efs/latest/ug/API_CreateMountTarget.html

        :stability: experimental
        '''
        return typing.cast("Elasticfilesystem", jsii.invoke(self, "toCreateMountTarget", []))

    @jsii.member(jsii_name="toCreateReplicationConfiguration")
    def to_create_replication_configuration(self) -> "Elasticfilesystem":
        '''(experimental) Grants permission to create a new replication configuration.

        Access Level: Write

        https://docs.aws.amazon.com/efs/latest/ug/API_CreateReplicationConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Elasticfilesystem", jsii.invoke(self, "toCreateReplicationConfiguration", []))

    @jsii.member(jsii_name="toCreateTags")
    def to_create_tags(self) -> "Elasticfilesystem":
        '''(experimental) Grants permission to create or overwrite tags associated with a file system; deprecated, see TagResource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/efs/latest/ug/API_CreateTags.html

        :stability: experimental
        '''
        return typing.cast("Elasticfilesystem", jsii.invoke(self, "toCreateTags", []))

    @jsii.member(jsii_name="toDeleteAccessPoint")
    def to_delete_access_point(self) -> "Elasticfilesystem":
        '''(experimental) Grants permission to delete the specified access point.

        Access Level: Write

        https://docs.aws.amazon.com/efs/latest/ug/API_DeleteAccessPoint.html

        :stability: experimental
        '''
        return typing.cast("Elasticfilesystem", jsii.invoke(self, "toDeleteAccessPoint", []))

    @jsii.member(jsii_name="toDeleteFileSystem")
    def to_delete_file_system(self) -> "Elasticfilesystem":
        '''(experimental) Grants permission to delete a file system, permanently severing access to its contents.

        Access Level: Write

        https://docs.aws.amazon.com/efs/latest/ug/API_DeleteFileSystem.html

        :stability: experimental
        '''
        return typing.cast("Elasticfilesystem", jsii.invoke(self, "toDeleteFileSystem", []))

    @jsii.member(jsii_name="toDeleteFileSystemPolicy")
    def to_delete_file_system_policy(self) -> "Elasticfilesystem":
        '''(experimental) Grants permission to delete the resource-level policy for a file system.

        Access Level: Permissions management

        https://docs.aws.amazon.com/efs/latest/ug/API_DeleteFileSystemPolicy.html

        :stability: experimental
        '''
        return typing.cast("Elasticfilesystem", jsii.invoke(self, "toDeleteFileSystemPolicy", []))

    @jsii.member(jsii_name="toDeleteMountTarget")
    def to_delete_mount_target(self) -> "Elasticfilesystem":
        '''(experimental) Grants permission to delete the specified mount target.

        Access Level: Write

        https://docs.aws.amazon.com/efs/latest/ug/API_DeleteMountTarget.html

        :stability: experimental
        '''
        return typing.cast("Elasticfilesystem", jsii.invoke(self, "toDeleteMountTarget", []))

    @jsii.member(jsii_name="toDeleteReplicationConfiguration")
    def to_delete_replication_configuration(self) -> "Elasticfilesystem":
        '''(experimental) Grants permission to delete a replication configuration.

        Access Level: Write

        https://docs.aws.amazon.com/efs/latest/ug/API_DeleteReplicationConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Elasticfilesystem", jsii.invoke(self, "toDeleteReplicationConfiguration", []))

    @jsii.member(jsii_name="toDeleteTags")
    def to_delete_tags(self) -> "Elasticfilesystem":
        '''(experimental) Grants permission to delete the specified tags from a file system; deprecated, see UntagResource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/efs/latest/ug/API_DeleteTags.html

        :stability: experimental
        '''
        return typing.cast("Elasticfilesystem", jsii.invoke(self, "toDeleteTags", []))

    @jsii.member(jsii_name="toDescribeAccessPoints")
    def to_describe_access_points(self) -> "Elasticfilesystem":
        '''(experimental) Grants permission to view the descriptions of Amazon EFS access points.

        Access Level: List

        https://docs.aws.amazon.com/efs/latest/ug/API_DescribeAccessPoints.html

        :stability: experimental
        '''
        return typing.cast("Elasticfilesystem", jsii.invoke(self, "toDescribeAccessPoints", []))

    @jsii.member(jsii_name="toDescribeAccountPreferences")
    def to_describe_account_preferences(self) -> "Elasticfilesystem":
        '''(experimental) Grants permission to view the account preferences in effect for an account.

        Access Level: List

        https://docs.aws.amazon.com/efs/latest/ug/API_DescribeAccountPreferences.html

        :stability: experimental
        '''
        return typing.cast("Elasticfilesystem", jsii.invoke(self, "toDescribeAccountPreferences", []))

    @jsii.member(jsii_name="toDescribeBackupPolicy")
    def to_describe_backup_policy(self) -> "Elasticfilesystem":
        '''(experimental) Grants permission to view the BackupPolicy object for an Amazon EFS file system.

        Access Level: Read

        https://docs.aws.amazon.com/efs/latest/ug/API_DescribeBackupPolicy.html

        :stability: experimental
        '''
        return typing.cast("Elasticfilesystem", jsii.invoke(self, "toDescribeBackupPolicy", []))

    @jsii.member(jsii_name="toDescribeFileSystemPolicy")
    def to_describe_file_system_policy(self) -> "Elasticfilesystem":
        '''(experimental) Grants permission to view the resource-level policy for an Amazon EFS file system.

        Access Level: Read

        https://docs.aws.amazon.com/efs/latest/ug/API_DescribeFileSystemPolicy.html

        :stability: experimental
        '''
        return typing.cast("Elasticfilesystem", jsii.invoke(self, "toDescribeFileSystemPolicy", []))

    @jsii.member(jsii_name="toDescribeFileSystems")
    def to_describe_file_systems(self) -> "Elasticfilesystem":
        '''(experimental) Grants permission to view the description of an Amazon EFS file system specified by file system CreationToken or FileSystemId;

        or to view the description of all file systems owned by the caller's AWS account in the AWS region of the endpoint that is being called

        Access Level: List

        https://docs.aws.amazon.com/efs/latest/ug/API_DescribeFileSystems.html

        :stability: experimental
        '''
        return typing.cast("Elasticfilesystem", jsii.invoke(self, "toDescribeFileSystems", []))

    @jsii.member(jsii_name="toDescribeLifecycleConfiguration")
    def to_describe_lifecycle_configuration(self) -> "Elasticfilesystem":
        '''(experimental) Grants permission to view the LifecycleConfiguration object for an Amazon EFS file system.

        Access Level: Read

        https://docs.aws.amazon.com/efs/latest/ug/API_DescribeLifecycleConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Elasticfilesystem", jsii.invoke(self, "toDescribeLifecycleConfiguration", []))

    @jsii.member(jsii_name="toDescribeMountTargets")
    def to_describe_mount_targets(self) -> "Elasticfilesystem":
        '''(experimental) Grants permission to view the descriptions of all mount targets, or a specific mount target, for a file system.

        Access Level: Read

        https://docs.aws.amazon.com/efs/latest/ug/API_DescribeMountTargets.html

        :stability: experimental
        '''
        return typing.cast("Elasticfilesystem", jsii.invoke(self, "toDescribeMountTargets", []))

    @jsii.member(jsii_name="toDescribeMountTargetSecurityGroups")
    def to_describe_mount_target_security_groups(self) -> "Elasticfilesystem":
        '''(experimental) Grants permission to view the security groups in effect for a mount target.

        Access Level: Read

        https://docs.aws.amazon.com/efs/latest/ug/API_DescribeMountTargetSecurityGroups.html

        :stability: experimental
        '''
        return typing.cast("Elasticfilesystem", jsii.invoke(self, "toDescribeMountTargetSecurityGroups", []))

    @jsii.member(jsii_name="toDescribeReplicationConfigurations")
    def to_describe_replication_configurations(self) -> "Elasticfilesystem":
        '''(experimental) Grants permission to view the description of an Amazon EFS replication configuration specified by FileSystemId;

        or to view the description of all replication configurations owned by the caller's AWS account in the AWS region of the endpoint that is being called

        Access Level: List

        https://docs.aws.amazon.com/efs/latest/ug/API_DescribeReplicationConfigurations.html

        :stability: experimental
        '''
        return typing.cast("Elasticfilesystem", jsii.invoke(self, "toDescribeReplicationConfigurations", []))

    @jsii.member(jsii_name="toDescribeTags")
    def to_describe_tags(self) -> "Elasticfilesystem":
        '''(experimental) Grants permission to view the tags associated with a file system.

        Access Level: Read

        https://docs.aws.amazon.com/efs/latest/ug/API_DescribeTags.html

        :stability: experimental
        '''
        return typing.cast("Elasticfilesystem", jsii.invoke(self, "toDescribeTags", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Elasticfilesystem":
        '''(experimental) Grants permission to view the tags associated with the specified Amazon EFS resource.

        Access Level: Read

        https://docs.aws.amazon.com/efs/latest/ug/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("Elasticfilesystem", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toModifyMountTargetSecurityGroups")
    def to_modify_mount_target_security_groups(self) -> "Elasticfilesystem":
        '''(experimental) Grants permission to modify the set of security groups in effect for a mount target.

        Access Level: Write

        https://docs.aws.amazon.com/efs/latest/ug/API_ModifyMountTargetSecurityGroups.html

        :stability: experimental
        '''
        return typing.cast("Elasticfilesystem", jsii.invoke(self, "toModifyMountTargetSecurityGroups", []))

    @jsii.member(jsii_name="toPutAccountPreferences")
    def to_put_account_preferences(self) -> "Elasticfilesystem":
        '''(experimental) Grants permission to set the account preferences of an account.

        Access Level: Write

        https://docs.aws.amazon.com/efs/latest/ug/API_PutAccountPreferences.html

        :stability: experimental
        '''
        return typing.cast("Elasticfilesystem", jsii.invoke(self, "toPutAccountPreferences", []))

    @jsii.member(jsii_name="toPutBackupPolicy")
    def to_put_backup_policy(self) -> "Elasticfilesystem":
        '''(experimental) Grants permission to enable or disable automatic backups with AWS Backup by creating a new BackupPolicy object.

        Access Level: Write

        https://docs.aws.amazon.com/efs/latest/ug/API_PutBackupPolicy.html

        :stability: experimental
        '''
        return typing.cast("Elasticfilesystem", jsii.invoke(self, "toPutBackupPolicy", []))

    @jsii.member(jsii_name="toPutFileSystemPolicy")
    def to_put_file_system_policy(self) -> "Elasticfilesystem":
        '''(experimental) Grants permission to apply a resource-level policy that defines the actions allowed or denied from given actors for the specified file system.

        Access Level: Permissions management

        https://docs.aws.amazon.com/efs/latest/ug/API_PutFileSystemPolicy.html

        :stability: experimental
        '''
        return typing.cast("Elasticfilesystem", jsii.invoke(self, "toPutFileSystemPolicy", []))

    @jsii.member(jsii_name="toPutLifecycleConfiguration")
    def to_put_lifecycle_configuration(self) -> "Elasticfilesystem":
        '''(experimental) Grants permission to enable lifecycle management by creating a new LifecycleConfiguration object.

        Access Level: Write

        https://docs.aws.amazon.com/efs/latest/ug/API_PutLifecycleConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Elasticfilesystem", jsii.invoke(self, "toPutLifecycleConfiguration", []))

    @jsii.member(jsii_name="toRestore")
    def to_restore(self) -> "Elasticfilesystem":
        '''(experimental) Grants permission to start a restore job for a backup of a file system.

        Access Level: Write

        https://docs.aws.amazon.com/efs/latest/ug/efs-backup-solutions.html

        :stability: experimental
        '''
        return typing.cast("Elasticfilesystem", jsii.invoke(self, "toRestore", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Elasticfilesystem":
        '''(experimental) Grants permission to create or overwrite tags associated with the specified Amazon EFS resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/efs/latest/ug/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("Elasticfilesystem", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Elasticfilesystem":
        '''(experimental) Grants permission to delete the specified tags from an Amazon EFS resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/efs/latest/ug/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("Elasticfilesystem", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateFileSystem")
    def to_update_file_system(self) -> "Elasticfilesystem":
        '''(experimental) Grants permission to update the throughput mode or the amount of provisioned throughput of an existing file system.

        Access Level: Write

        https://docs.aws.amazon.com/efs/latest/ug/API_UpdateFileSystem.html

        :stability: experimental
        '''
        return typing.cast("Elasticfilesystem", jsii.invoke(self, "toUpdateFileSystem", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f7590aadb5782e0484b9462e6b8f4a87b2b91d91eb2697cf5f3e8b09acbe5f3d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3d10f0ae79373119dbac8600c6ecf92e6a8cfdb4825f7759753835a5367660af)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Elasticloadbalancing(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Elasticloadbalancing",
):
    '''(experimental) Statement provider for service `elasticloadbalancing <https://docs.aws.amazon.com/service-authorization/latest/reference/list_elasticloadbalancing.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `elasticloadbalancing <https://docs.aws.amazon.com/service-authorization/latest/reference/list_elasticloadbalancing.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="ifResourceTag")
    def if_resource_tag(
        self,
        tag_key: builtins.str,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Elasticloadbalancing":
        '''(experimental) A tag key and value pair.

        Applies to resource types:

        - loadbalancer

        :param tag_key: The tag key to check.
        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b9ff21dbda62427423edb12fdb5f35035a25b6b4678cc79eed8b4980875457b4)
            check_type(argname="argument tag_key", value=tag_key, expected_type=type_hints["tag_key"])
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Elasticloadbalancing", jsii.invoke(self, "ifResourceTag", [tag_key, value, operator]))

    @jsii.member(jsii_name="ifResourceTagExists")
    def if_resource_tag_exists(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Elasticloadbalancing":
        '''(experimental) The preface string for a tag key and value pair attached to a resource.

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ed8f08bf7206e73ec4430867cb33010dcf92ee9dd02d7e674560234b02be8c5b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Elasticloadbalancing", jsii.invoke(self, "ifResourceTagExists", [value, operator]))

    @jsii.member(jsii_name="onLoadbalancer")
    def on_loadbalancer(
        self,
        load_balancer_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Elasticloadbalancing":
        '''(experimental) Adds a resource of type loadbalancer to the statement.

        https://docs.aws.amazon.com/elasticloadbalancing/latest/userguide/what-is-load-balancing.html

        :param load_balancer_name: - Identifier for the loadBalancerName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag() - .ifResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ab7532a7903dd6ed3901721a076300fbd89ac8adc5f538627c83695afdfe3456)
            check_type(argname="argument load_balancer_name", value=load_balancer_name, expected_type=type_hints["load_balancer_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Elasticloadbalancing", jsii.invoke(self, "onLoadbalancer", [load_balancer_name, account, region, partition]))

    @jsii.member(jsii_name="toAddTags")
    def to_add_tags(self) -> "Elasticloadbalancing":
        '''(experimental) Grants permission to add the specified tags to the specified load balancer.

        Each load balancer can have a maximum of 10 tags

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/elasticloadbalancing/2012-06-01/APIReference/API_AddTags.html

        :stability: experimental
        '''
        return typing.cast("Elasticloadbalancing", jsii.invoke(self, "toAddTags", []))

    @jsii.member(jsii_name="toApplySecurityGroupsToLoadBalancer")
    def to_apply_security_groups_to_load_balancer(self) -> "Elasticloadbalancing":
        '''(experimental) Grants permission to associate one or more security groups with your load balancer in a virtual private cloud (VPC).

        Access Level: Write

        https://docs.aws.amazon.com/elasticloadbalancing/2012-06-01/APIReference/API_ApplySecurityGroupsToLoadBalancer.html

        :stability: experimental
        '''
        return typing.cast("Elasticloadbalancing", jsii.invoke(self, "toApplySecurityGroupsToLoadBalancer", []))

    @jsii.member(jsii_name="toAttachLoadBalancerToSubnets")
    def to_attach_load_balancer_to_subnets(self) -> "Elasticloadbalancing":
        '''(experimental) Grants permission to add one or more subnets to the set of configured subnets for the specified load balancer.

        Access Level: Write

        https://docs.aws.amazon.com/elasticloadbalancing/2012-06-01/APIReference/API_AttachLoadBalancerToSubnets.html

        :stability: experimental
        '''
        return typing.cast("Elasticloadbalancing", jsii.invoke(self, "toAttachLoadBalancerToSubnets", []))

    @jsii.member(jsii_name="toConfigureHealthCheck")
    def to_configure_health_check(self) -> "Elasticloadbalancing":
        '''(experimental) Grants permission to specify the health check settings to use when evaluating the health state of your back-end instances.

        Access Level: Write

        https://docs.aws.amazon.com/elasticloadbalancing/2012-06-01/APIReference/API_ConfigureHealthCheck.html

        :stability: experimental
        '''
        return typing.cast("Elasticloadbalancing", jsii.invoke(self, "toConfigureHealthCheck", []))

    @jsii.member(jsii_name="toCreateAppCookieStickinessPolicy")
    def to_create_app_cookie_stickiness_policy(self) -> "Elasticloadbalancing":
        '''(experimental) Grants permission to generate a stickiness policy with sticky session lifetimes that follow that of an application-generated cookie.

        Access Level: Write

        https://docs.aws.amazon.com/elasticloadbalancing/2012-06-01/APIReference/API_CreateAppCookieStickinessPolicy.html

        :stability: experimental
        '''
        return typing.cast("Elasticloadbalancing", jsii.invoke(self, "toCreateAppCookieStickinessPolicy", []))

    @jsii.member(jsii_name="toCreateLBCookieStickinessPolicy")
    def to_create_lb_cookie_stickiness_policy(self) -> "Elasticloadbalancing":
        '''(experimental) Grants permission to generate a stickiness policy with sticky session lifetimes controlled by the lifetime of the browser (user-agent) or a specified expiration period.

        Access Level: Write

        https://docs.aws.amazon.com/elasticloadbalancing/2012-06-01/APIReference/API_CreateLBCookieStickinessPolicy.html

        :stability: experimental
        '''
        return typing.cast("Elasticloadbalancing", jsii.invoke(self, "toCreateLBCookieStickinessPolicy", []))

    @jsii.member(jsii_name="toCreateLoadBalancer")
    def to_create_load_balancer(self) -> "Elasticloadbalancing":
        '''(experimental) Grants permission to create a load balancer.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/elasticloadbalancing/2012-06-01/APIReference/API_CreateLoadBalancer.html

        :stability: experimental
        '''
        return typing.cast("Elasticloadbalancing", jsii.invoke(self, "toCreateLoadBalancer", []))

    @jsii.member(jsii_name="toCreateLoadBalancerListeners")
    def to_create_load_balancer_listeners(self) -> "Elasticloadbalancing":
        '''(experimental) Grants permission to create one or more listeners for the specified load balancer.

        Access Level: Write

        https://docs.aws.amazon.com/elasticloadbalancing/2012-06-01/APIReference/API_CreateLoadBalancerListeners.html

        :stability: experimental
        '''
        return typing.cast("Elasticloadbalancing", jsii.invoke(self, "toCreateLoadBalancerListeners", []))

    @jsii.member(jsii_name="toCreateLoadBalancerPolicy")
    def to_create_load_balancer_policy(self) -> "Elasticloadbalancing":
        '''(experimental) Grants permission to create a policy with the specified attributes for the specified load balancer.

        Access Level: Write

        https://docs.aws.amazon.com/elasticloadbalancing/2012-06-01/APIReference/API_CreateLoadBalancerPolicy.html

        :stability: experimental
        '''
        return typing.cast("Elasticloadbalancing", jsii.invoke(self, "toCreateLoadBalancerPolicy", []))

    @jsii.member(jsii_name="toDeleteLoadBalancer")
    def to_delete_load_balancer(self) -> "Elasticloadbalancing":
        '''(experimental) Grants permission to delete the specified load balancer.

        Access Level: Write

        https://docs.aws.amazon.com/elasticloadbalancing/2012-06-01/APIReference/API_DeleteLoadBalancer.html

        :stability: experimental
        '''
        return typing.cast("Elasticloadbalancing", jsii.invoke(self, "toDeleteLoadBalancer", []))

    @jsii.member(jsii_name="toDeleteLoadBalancerListeners")
    def to_delete_load_balancer_listeners(self) -> "Elasticloadbalancing":
        '''(experimental) Grants permission to delete the specified listeners from the specified load balancer.

        Access Level: Write

        https://docs.aws.amazon.com/elasticloadbalancing/2012-06-01/APIReference/API_DeleteLoadBalancerListeners.html

        :stability: experimental
        '''
        return typing.cast("Elasticloadbalancing", jsii.invoke(self, "toDeleteLoadBalancerListeners", []))

    @jsii.member(jsii_name="toDeleteLoadBalancerPolicy")
    def to_delete_load_balancer_policy(self) -> "Elasticloadbalancing":
        '''(experimental) Grants permission to delete the specified policy from the specified load balancer.

        This policy must not be enabled for any listeners

        Access Level: Write

        https://docs.aws.amazon.com/elasticloadbalancing/2012-06-01/APIReference/API_DeleteLoadBalancerPolicy.html

        :stability: experimental
        '''
        return typing.cast("Elasticloadbalancing", jsii.invoke(self, "toDeleteLoadBalancerPolicy", []))

    @jsii.member(jsii_name="toDeregisterInstancesFromLoadBalancer")
    def to_deregister_instances_from_load_balancer(self) -> "Elasticloadbalancing":
        '''(experimental) Grants permission to deregister the specified instances from the specified load balancer.

        Access Level: Write

        https://docs.aws.amazon.com/elasticloadbalancing/2012-06-01/APIReference/API_DeregisterInstancesFromLoadBalancer.html

        :stability: experimental
        '''
        return typing.cast("Elasticloadbalancing", jsii.invoke(self, "toDeregisterInstancesFromLoadBalancer", []))

    @jsii.member(jsii_name="toDescribeInstanceHealth")
    def to_describe_instance_health(self) -> "Elasticloadbalancing":
        '''(experimental) Grants permission to describe the state of the specified instances with respect to the specified load balancer.

        Access Level: Read

        https://docs.aws.amazon.com/elasticloadbalancing/2012-06-01/APIReference/API_DescribeInstanceHealth.html

        :stability: experimental
        '''
        return typing.cast("Elasticloadbalancing", jsii.invoke(self, "toDescribeInstanceHealth", []))

    @jsii.member(jsii_name="toDescribeLoadBalancerAttributes")
    def to_describe_load_balancer_attributes(self) -> "Elasticloadbalancing":
        '''(experimental) Grants permission to describe the attributes for the specified load balancer.

        Access Level: Read

        https://docs.aws.amazon.com/elasticloadbalancing/2012-06-01/APIReference/API_DescribeLoadBalancerAttributes.html

        :stability: experimental
        '''
        return typing.cast("Elasticloadbalancing", jsii.invoke(self, "toDescribeLoadBalancerAttributes", []))

    @jsii.member(jsii_name="toDescribeLoadBalancerPolicies")
    def to_describe_load_balancer_policies(self) -> "Elasticloadbalancing":
        '''(experimental) Grants permission to describe the specified policies.

        Access Level: Read

        https://docs.aws.amazon.com/elasticloadbalancing/2012-06-01/APIReference/API_DescribeLoadBalancerPolicies.html

        :stability: experimental
        '''
        return typing.cast("Elasticloadbalancing", jsii.invoke(self, "toDescribeLoadBalancerPolicies", []))

    @jsii.member(jsii_name="toDescribeLoadBalancerPolicyTypes")
    def to_describe_load_balancer_policy_types(self) -> "Elasticloadbalancing":
        '''(experimental) Grants permission to describe the specified load balancer policy types.

        Access Level: Read

        https://docs.aws.amazon.com/elasticloadbalancing/2012-06-01/APIReference/API_DescribeLoadBalancerPolicyTypes.html

        :stability: experimental
        '''
        return typing.cast("Elasticloadbalancing", jsii.invoke(self, "toDescribeLoadBalancerPolicyTypes", []))

    @jsii.member(jsii_name="toDescribeLoadBalancers")
    def to_describe_load_balancers(self) -> "Elasticloadbalancing":
        '''(experimental) Grants permission to describe the specified the load balancers.

        If no load balancers are specified, the call describes all of your load balancers

        Access Level: List

        https://docs.aws.amazon.com/elasticloadbalancing/2012-06-01/APIReference/API_DescribeLoadBalancers.html

        :stability: experimental
        '''
        return typing.cast("Elasticloadbalancing", jsii.invoke(self, "toDescribeLoadBalancers", []))

    @jsii.member(jsii_name="toDescribeTags")
    def to_describe_tags(self) -> "Elasticloadbalancing":
        '''(experimental) Grants permission to describe the tags associated with the specified load balancers.

        Access Level: Read

        https://docs.aws.amazon.com/elasticloadbalancing/2012-06-01/APIReference/API_DescribeTags.html

        :stability: experimental
        '''
        return typing.cast("Elasticloadbalancing", jsii.invoke(self, "toDescribeTags", []))

    @jsii.member(jsii_name="toDetachLoadBalancerFromSubnets")
    def to_detach_load_balancer_from_subnets(self) -> "Elasticloadbalancing":
        '''(experimental) Grants permission to remove the specified subnets from the set of configured subnets for the load balancer.

        Access Level: Write

        https://docs.aws.amazon.com/elasticloadbalancing/2012-06-01/APIReference/API_DetachLoadBalancerFromSubnets.html

        :stability: experimental
        '''
        return typing.cast("Elasticloadbalancing", jsii.invoke(self, "toDetachLoadBalancerFromSubnets", []))

    @jsii.member(jsii_name="toDisableAvailabilityZonesForLoadBalancer")
    def to_disable_availability_zones_for_load_balancer(self) -> "Elasticloadbalancing":
        '''(experimental) Grants permission to remove the specified Availability Zones from the set of Availability Zones for the specified load balancer.

        Access Level: Write

        https://docs.aws.amazon.com/elasticloadbalancing/2012-06-01/APIReference/API_DisableAvailabilityZonesForLoadBalancer.html

        :stability: experimental
        '''
        return typing.cast("Elasticloadbalancing", jsii.invoke(self, "toDisableAvailabilityZonesForLoadBalancer", []))

    @jsii.member(jsii_name="toEnableAvailabilityZonesForLoadBalancer")
    def to_enable_availability_zones_for_load_balancer(self) -> "Elasticloadbalancing":
        '''(experimental) Grants permission to add the specified Availability Zones to the set of Availability Zones for the specified load balancer.

        Access Level: Write

        https://docs.aws.amazon.com/elasticloadbalancing/2012-06-01/APIReference/API_EnableAvailabilityZonesForLoadBalancer.html

        :stability: experimental
        '''
        return typing.cast("Elasticloadbalancing", jsii.invoke(self, "toEnableAvailabilityZonesForLoadBalancer", []))

    @jsii.member(jsii_name="toModifyLoadBalancerAttributes")
    def to_modify_load_balancer_attributes(self) -> "Elasticloadbalancing":
        '''(experimental) Grants permission to modify the attributes of the specified load balancer.

        Access Level: Write

        https://docs.aws.amazon.com/elasticloadbalancing/2012-06-01/APIReference/API_ModifyLoadBalancerAttributes.html

        :stability: experimental
        '''
        return typing.cast("Elasticloadbalancing", jsii.invoke(self, "toModifyLoadBalancerAttributes", []))

    @jsii.member(jsii_name="toRegisterInstancesWithLoadBalancer")
    def to_register_instances_with_load_balancer(self) -> "Elasticloadbalancing":
        '''(experimental) Grants permission to add the specified instances to the specified load balancer.

        Access Level: Write

        https://docs.aws.amazon.com/elasticloadbalancing/2012-06-01/APIReference/API_RegisterInstancesWithLoadBalancer.html

        :stability: experimental
        '''
        return typing.cast("Elasticloadbalancing", jsii.invoke(self, "toRegisterInstancesWithLoadBalancer", []))

    @jsii.member(jsii_name="toRemoveTags")
    def to_remove_tags(self) -> "Elasticloadbalancing":
        '''(experimental) Grants permission to remove one or more tags from the specified load balancer.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/elasticloadbalancing/2012-06-01/APIReference/API_RemoveTags.html

        :stability: experimental
        '''
        return typing.cast("Elasticloadbalancing", jsii.invoke(self, "toRemoveTags", []))

    @jsii.member(jsii_name="toSetLoadBalancerListenerSSLCertificate")
    def to_set_load_balancer_listener_ssl_certificate(self) -> "Elasticloadbalancing":
        '''(experimental) Grants permission to set the certificate that terminates the specified listener's SSL connections.

        Access Level: Write

        https://docs.aws.amazon.com/elasticloadbalancing/2012-06-01/APIReference/API_SetLoadBalancerListenerSSLCertificate.html

        :stability: experimental
        '''
        return typing.cast("Elasticloadbalancing", jsii.invoke(self, "toSetLoadBalancerListenerSSLCertificate", []))

    @jsii.member(jsii_name="toSetLoadBalancerPoliciesForBackendServer")
    def to_set_load_balancer_policies_for_backend_server(
        self,
    ) -> "Elasticloadbalancing":
        '''(experimental) Grants permission to replace the set of policies associated with the specified port on which the back-end server is listening with a new set of policies.

        Access Level: Write

        https://docs.aws.amazon.com/elasticloadbalancing/2012-06-01/APIReference/API_SetLoadBalancerPoliciesForBackendServer.html

        :stability: experimental
        '''
        return typing.cast("Elasticloadbalancing", jsii.invoke(self, "toSetLoadBalancerPoliciesForBackendServer", []))

    @jsii.member(jsii_name="toSetLoadBalancerPoliciesOfListener")
    def to_set_load_balancer_policies_of_listener(self) -> "Elasticloadbalancing":
        '''(experimental) Grants permission to replace the current set of policies for the specified load balancer port with the specified set of policies.

        Access Level: Write

        https://docs.aws.amazon.com/elasticloadbalancing/2012-06-01/APIReference/API_SetLoadBalancerPoliciesOfListener.html

        :stability: experimental
        '''
        return typing.cast("Elasticloadbalancing", jsii.invoke(self, "toSetLoadBalancerPoliciesOfListener", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e3efd3565d5f771b9b1232658d5f50f376f065e13599a4f752ca12042b8a8e49)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__79a6af40dc8d322239ce088b149a8d5bbfc210403b1e91b47ed291e4f9e2569a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class ElasticloadbalancingV2(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.ElasticloadbalancingV2",
):
    '''(experimental) Statement provider for service `elasticloadbalancing-v2 <https://docs.aws.amazon.com/service-authorization/latest/reference/list_elasticloadbalancingv2.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `elasticloadbalancing-v2 <https://docs.aws.amazon.com/service-authorization/latest/reference/list_elasticloadbalancingv2.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="ifResourceTag")
    def if_resource_tag(
        self,
        tag_key: builtins.str,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "ElasticloadbalancingV2":
        '''(experimental) A tag key and value pair.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_condition-keys.html#condition-keys-resourcetag

        Applies to resource types:

        - listener/app
        - listener-rule/app
        - listener/net
        - listener-rule/net
        - loadbalancer/app/
        - loadbalancer/net/
        - targetgroup

        :param tag_key: The tag key to check.
        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fcfdc04d43df14a3729a9a902714c1f11afe728a2830f133b2a05ae5755b6416)
            check_type(argname="argument tag_key", value=tag_key, expected_type=type_hints["tag_key"])
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("ElasticloadbalancingV2", jsii.invoke(self, "ifResourceTag", [tag_key, value, operator]))

    @jsii.member(jsii_name="onListenerApp")
    def on_listener_app(
        self,
        load_balancer_name: builtins.str,
        load_balancer_id: builtins.str,
        listener_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "ElasticloadbalancingV2":
        '''(experimental) Adds a resource of type listener/app to the statement.

        https://docs.aws.amazon.com/elasticloadbalancing/latest/application/load-balancer-listeners.html

        :param load_balancer_name: - Identifier for the loadBalancerName.
        :param load_balancer_id: - Identifier for the loadBalancerId.
        :param listener_id: - Identifier for the listenerId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag() - .ifResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a62b7a527eef8275c168c94a5f135c72a4a8c6136c7f6bee4c6815bd3b94fb99)
            check_type(argname="argument load_balancer_name", value=load_balancer_name, expected_type=type_hints["load_balancer_name"])
            check_type(argname="argument load_balancer_id", value=load_balancer_id, expected_type=type_hints["load_balancer_id"])
            check_type(argname="argument listener_id", value=listener_id, expected_type=type_hints["listener_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("ElasticloadbalancingV2", jsii.invoke(self, "onListenerApp", [load_balancer_name, load_balancer_id, listener_id, account, region, partition]))

    @jsii.member(jsii_name="onListenerNet")
    def on_listener_net(
        self,
        load_balancer_name: builtins.str,
        load_balancer_id: builtins.str,
        listener_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "ElasticloadbalancingV2":
        '''(experimental) Adds a resource of type listener/net to the statement.

        https://docs.aws.amazon.com/elasticloadbalancing/latest/application/load-balancer-listeners.html

        :param load_balancer_name: - Identifier for the loadBalancerName.
        :param load_balancer_id: - Identifier for the loadBalancerId.
        :param listener_id: - Identifier for the listenerId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag() - .ifResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d6c856a0be69757e272f0e3eb8973a757047562272219da97ac535008c4748f5)
            check_type(argname="argument load_balancer_name", value=load_balancer_name, expected_type=type_hints["load_balancer_name"])
            check_type(argname="argument load_balancer_id", value=load_balancer_id, expected_type=type_hints["load_balancer_id"])
            check_type(argname="argument listener_id", value=listener_id, expected_type=type_hints["listener_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("ElasticloadbalancingV2", jsii.invoke(self, "onListenerNet", [load_balancer_name, load_balancer_id, listener_id, account, region, partition]))

    @jsii.member(jsii_name="onListenerRuleApp")
    def on_listener_rule_app(
        self,
        load_balancer_name: builtins.str,
        load_balancer_id: builtins.str,
        listener_id: builtins.str,
        listener_rule_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "ElasticloadbalancingV2":
        '''(experimental) Adds a resource of type listener-rule/app to the statement.

        https://docs.aws.amazon.com/elasticloadbalancing/latest/application/listener-update-rules.html

        :param load_balancer_name: - Identifier for the loadBalancerName.
        :param load_balancer_id: - Identifier for the loadBalancerId.
        :param listener_id: - Identifier for the listenerId.
        :param listener_rule_id: - Identifier for the listenerRuleId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag() - .ifResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__153bc26c619ed6176278d4929d0930c08e80e9c934f9b4734c0ac57ea36011d5)
            check_type(argname="argument load_balancer_name", value=load_balancer_name, expected_type=type_hints["load_balancer_name"])
            check_type(argname="argument load_balancer_id", value=load_balancer_id, expected_type=type_hints["load_balancer_id"])
            check_type(argname="argument listener_id", value=listener_id, expected_type=type_hints["listener_id"])
            check_type(argname="argument listener_rule_id", value=listener_rule_id, expected_type=type_hints["listener_rule_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("ElasticloadbalancingV2", jsii.invoke(self, "onListenerRuleApp", [load_balancer_name, load_balancer_id, listener_id, listener_rule_id, account, region, partition]))

    @jsii.member(jsii_name="onListenerRuleNet")
    def on_listener_rule_net(
        self,
        load_balancer_name: builtins.str,
        load_balancer_id: builtins.str,
        listener_id: builtins.str,
        listener_rule_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "ElasticloadbalancingV2":
        '''(experimental) Adds a resource of type listener-rule/net to the statement.

        https://docs.aws.amazon.com/elasticloadbalancing/latest/application/listener-update-rules.html

        :param load_balancer_name: - Identifier for the loadBalancerName.
        :param load_balancer_id: - Identifier for the loadBalancerId.
        :param listener_id: - Identifier for the listenerId.
        :param listener_rule_id: - Identifier for the listenerRuleId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag() - .ifResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2195043758de34d79182db0278aedf161d4eef60b36c5b08ed67a40f759b870c)
            check_type(argname="argument load_balancer_name", value=load_balancer_name, expected_type=type_hints["load_balancer_name"])
            check_type(argname="argument load_balancer_id", value=load_balancer_id, expected_type=type_hints["load_balancer_id"])
            check_type(argname="argument listener_id", value=listener_id, expected_type=type_hints["listener_id"])
            check_type(argname="argument listener_rule_id", value=listener_rule_id, expected_type=type_hints["listener_rule_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("ElasticloadbalancingV2", jsii.invoke(self, "onListenerRuleNet", [load_balancer_name, load_balancer_id, listener_id, listener_rule_id, account, region, partition]))

    @jsii.member(jsii_name="onLoadbalancerApp")
    def on_loadbalancer_app(
        self,
        load_balancer_name: builtins.str,
        load_balancer_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "ElasticloadbalancingV2":
        '''(experimental) Adds a resource of type loadbalancer/app/ to the statement.

        https://docs.aws.amazon.com/elasticloadbalancing/latest/application/introduction.html#application-load-balancer-overview

        :param load_balancer_name: - Identifier for the loadBalancerName.
        :param load_balancer_id: - Identifier for the loadBalancerId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag() - .ifResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__47ca3b0c9f61e8c7ef8ed39a52f1566ea77cc03ee3b7fd15444b54db7a50a442)
            check_type(argname="argument load_balancer_name", value=load_balancer_name, expected_type=type_hints["load_balancer_name"])
            check_type(argname="argument load_balancer_id", value=load_balancer_id, expected_type=type_hints["load_balancer_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("ElasticloadbalancingV2", jsii.invoke(self, "onLoadbalancerApp", [load_balancer_name, load_balancer_id, account, region, partition]))

    @jsii.member(jsii_name="onLoadbalancerNet")
    def on_loadbalancer_net(
        self,
        load_balancer_name: builtins.str,
        load_balancer_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "ElasticloadbalancingV2":
        '''(experimental) Adds a resource of type loadbalancer/net/ to the statement.

        https://docs.aws.amazon.com/elasticloadbalancing/latest/network/introduction.html#network-load-balancer-overview

        :param load_balancer_name: - Identifier for the loadBalancerName.
        :param load_balancer_id: - Identifier for the loadBalancerId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag() - .ifResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b96664d929e1e7f26bdcae56651d0c8ffa97ab7e3f92b8a900ae8ef71bbc0954)
            check_type(argname="argument load_balancer_name", value=load_balancer_name, expected_type=type_hints["load_balancer_name"])
            check_type(argname="argument load_balancer_id", value=load_balancer_id, expected_type=type_hints["load_balancer_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("ElasticloadbalancingV2", jsii.invoke(self, "onLoadbalancerNet", [load_balancer_name, load_balancer_id, account, region, partition]))

    @jsii.member(jsii_name="onTargetgroup")
    def on_targetgroup(
        self,
        target_group_name: builtins.str,
        target_group_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "ElasticloadbalancingV2":
        '''(experimental) Adds a resource of type targetgroup to the statement.

        https://docs.aws.amazon.com/elasticloadbalancing/latest/application/load-balancer-target-groups.html

        :param target_group_name: - Identifier for the targetGroupName.
        :param target_group_id: - Identifier for the targetGroupId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag() - .ifResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__29017740b879ce500ba27d999dc5d77ccb9f7a27a9c208f64babcd6fb2e3940c)
            check_type(argname="argument target_group_name", value=target_group_name, expected_type=type_hints["target_group_name"])
            check_type(argname="argument target_group_id", value=target_group_id, expected_type=type_hints["target_group_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("ElasticloadbalancingV2", jsii.invoke(self, "onTargetgroup", [target_group_name, target_group_id, account, region, partition]))

    @jsii.member(jsii_name="toAddListenerCertificates")
    def to_add_listener_certificates(self) -> "ElasticloadbalancingV2":
        '''(experimental) Grants permission to add the specified certificates to the specified secure listener.

        Access Level: Write

        https://docs.aws.amazon.com/elasticloadbalancing/latest/APIReference/API_AddListenerCertificates.html

        :stability: experimental
        '''
        return typing.cast("ElasticloadbalancingV2", jsii.invoke(self, "toAddListenerCertificates", []))

    @jsii.member(jsii_name="toAddTags")
    def to_add_tags(self) -> "ElasticloadbalancingV2":
        '''(experimental) Grants permission to add the specified tags to the specified load balancer.

        Each load balancer can have a maximum of 10 tags

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/elasticloadbalancing/latest/APIReference/API_AddTags.html

        :stability: experimental
        '''
        return typing.cast("ElasticloadbalancingV2", jsii.invoke(self, "toAddTags", []))

    @jsii.member(jsii_name="toCreateListener")
    def to_create_listener(self) -> "ElasticloadbalancingV2":
        '''(experimental) Grants permission to create a listener for the specified Application Load Balancer.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/elasticloadbalancing/latest/APIReference/API_CreateListener.html

        :stability: experimental
        '''
        return typing.cast("ElasticloadbalancingV2", jsii.invoke(self, "toCreateListener", []))

    @jsii.member(jsii_name="toCreateLoadBalancer")
    def to_create_load_balancer(self) -> "ElasticloadbalancingV2":
        '''(experimental) Grants permission to create a load balancer.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/elasticloadbalancing/latest/APIReference/API_CreateLoadBalancer.html

        :stability: experimental
        '''
        return typing.cast("ElasticloadbalancingV2", jsii.invoke(self, "toCreateLoadBalancer", []))

    @jsii.member(jsii_name="toCreateRule")
    def to_create_rule(self) -> "ElasticloadbalancingV2":
        '''(experimental) Grants permission to create a rule for the specified listener.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/elasticloadbalancing/latest/APIReference/API_CreateRule.html

        :stability: experimental
        '''
        return typing.cast("ElasticloadbalancingV2", jsii.invoke(self, "toCreateRule", []))

    @jsii.member(jsii_name="toCreateTargetGroup")
    def to_create_target_group(self) -> "ElasticloadbalancingV2":
        '''(experimental) Grants permission to create a target group.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/elasticloadbalancing/latest/APIReference/API_CreateTargetGroup.html

        :stability: experimental
        '''
        return typing.cast("ElasticloadbalancingV2", jsii.invoke(self, "toCreateTargetGroup", []))

    @jsii.member(jsii_name="toDeleteListener")
    def to_delete_listener(self) -> "ElasticloadbalancingV2":
        '''(experimental) Grants permission to delete the specified listener.

        Access Level: Write

        https://docs.aws.amazon.com/elasticloadbalancing/latest/APIReference/API_DeleteListener.html

        :stability: experimental
        '''
        return typing.cast("ElasticloadbalancingV2", jsii.invoke(self, "toDeleteListener", []))

    @jsii.member(jsii_name="toDeleteLoadBalancer")
    def to_delete_load_balancer(self) -> "ElasticloadbalancingV2":
        '''(experimental) Grants permission to delete the specified load balancer.

        Access Level: Write

        https://docs.aws.amazon.com/elasticloadbalancing/latest/APIReference/API_DeleteLoadBalancer.html

        :stability: experimental
        '''
        return typing.cast("ElasticloadbalancingV2", jsii.invoke(self, "toDeleteLoadBalancer", []))

    @jsii.member(jsii_name="toDeleteRule")
    def to_delete_rule(self) -> "ElasticloadbalancingV2":
        '''(experimental) Grants permission to delete the specified rule.

        Access Level: Write

        https://docs.aws.amazon.com/elasticloadbalancing/latest/APIReference/API_DeleteRule.html

        :stability: experimental
        '''
        return typing.cast("ElasticloadbalancingV2", jsii.invoke(self, "toDeleteRule", []))

    @jsii.member(jsii_name="toDeleteTargetGroup")
    def to_delete_target_group(self) -> "ElasticloadbalancingV2":
        '''(experimental) Grants permission to delete the specified target group.

        Access Level: Write

        https://docs.aws.amazon.com/elasticloadbalancing/latest/APIReference/API_DeleteTargetGroup.html

        :stability: experimental
        '''
        return typing.cast("ElasticloadbalancingV2", jsii.invoke(self, "toDeleteTargetGroup", []))

    @jsii.member(jsii_name="toDeregisterTargets")
    def to_deregister_targets(self) -> "ElasticloadbalancingV2":
        '''(experimental) Grants permission to deregister the specified targets from the specified target group.

        Access Level: Write

        https://docs.aws.amazon.com/elasticloadbalancing/latest/APIReference/API_DeregisterTargets.html

        :stability: experimental
        '''
        return typing.cast("ElasticloadbalancingV2", jsii.invoke(self, "toDeregisterTargets", []))

    @jsii.member(jsii_name="toDescribeAccountLimits")
    def to_describe_account_limits(self) -> "ElasticloadbalancingV2":
        '''(experimental) Grants permission to describe the Elastic Load Balancing resource limits for the AWS account.

        Access Level: Read

        https://docs.aws.amazon.com/elasticloadbalancing/latest/APIReference/API_DescribeAccountLimits.html

        :stability: experimental
        '''
        return typing.cast("ElasticloadbalancingV2", jsii.invoke(self, "toDescribeAccountLimits", []))

    @jsii.member(jsii_name="toDescribeListenerCertificates")
    def to_describe_listener_certificates(self) -> "ElasticloadbalancingV2":
        '''(experimental) Grants permission to describe the certificates for the specified secure listener.

        Access Level: Read

        https://docs.aws.amazon.com/elasticloadbalancing/latest/APIReference/API_DescribeListenerCertificates.html

        :stability: experimental
        '''
        return typing.cast("ElasticloadbalancingV2", jsii.invoke(self, "toDescribeListenerCertificates", []))

    @jsii.member(jsii_name="toDescribeListeners")
    def to_describe_listeners(self) -> "ElasticloadbalancingV2":
        '''(experimental) Grants permission to describe the specified listeners or the listeners for the specified Application Load Balancer.

        Access Level: Read

        https://docs.aws.amazon.com/elasticloadbalancing/latest/APIReference/API_DescribeListeners.html

        :stability: experimental
        '''
        return typing.cast("ElasticloadbalancingV2", jsii.invoke(self, "toDescribeListeners", []))

    @jsii.member(jsii_name="toDescribeLoadBalancerAttributes")
    def to_describe_load_balancer_attributes(self) -> "ElasticloadbalancingV2":
        '''(experimental) Grants permission to describe the attributes for the specified load balancer.

        Access Level: Read

        https://docs.aws.amazon.com/elasticloadbalancing/latest/APIReference/API_DescribeLoadBalancerAttributes.html

        :stability: experimental
        '''
        return typing.cast("ElasticloadbalancingV2", jsii.invoke(self, "toDescribeLoadBalancerAttributes", []))

    @jsii.member(jsii_name="toDescribeLoadBalancers")
    def to_describe_load_balancers(self) -> "ElasticloadbalancingV2":
        '''(experimental) Grants permission to describe the specified the load balancers.

        If no load balancers are specified, the call describes all of your load balancers

        Access Level: Read

        https://docs.aws.amazon.com/elasticloadbalancing/latest/APIReference/API_DescribeLoadBalancers.html

        :stability: experimental
        '''
        return typing.cast("ElasticloadbalancingV2", jsii.invoke(self, "toDescribeLoadBalancers", []))

    @jsii.member(jsii_name="toDescribeRules")
    def to_describe_rules(self) -> "ElasticloadbalancingV2":
        '''(experimental) Grants permission to describe the specified rules or the rules for the specified listener.

        Access Level: Read

        https://docs.aws.amazon.com/elasticloadbalancing/latest/APIReference/API_DescribeRules.html

        :stability: experimental
        '''
        return typing.cast("ElasticloadbalancingV2", jsii.invoke(self, "toDescribeRules", []))

    @jsii.member(jsii_name="toDescribeSSLPolicies")
    def to_describe_ssl_policies(self) -> "ElasticloadbalancingV2":
        '''(experimental) Grants permission to describe the specified policies or all policies used for SSL negotiation.

        Access Level: Read

        https://docs.aws.amazon.com/elasticloadbalancing/latest/APIReference/API_DescribeSSLPolicies.html

        :stability: experimental
        '''
        return typing.cast("ElasticloadbalancingV2", jsii.invoke(self, "toDescribeSSLPolicies", []))

    @jsii.member(jsii_name="toDescribeTags")
    def to_describe_tags(self) -> "ElasticloadbalancingV2":
        '''(experimental) Grants permission to describe the tags associated with the specified resource.

        Access Level: Read

        https://docs.aws.amazon.com/elasticloadbalancing/latest/APIReference/API_DescribeTags.html

        :stability: experimental
        '''
        return typing.cast("ElasticloadbalancingV2", jsii.invoke(self, "toDescribeTags", []))

    @jsii.member(jsii_name="toDescribeTargetGroupAttributes")
    def to_describe_target_group_attributes(self) -> "ElasticloadbalancingV2":
        '''(experimental) Grants permission to describe the attributes for the specified target group.

        Access Level: Read

        https://docs.aws.amazon.com/elasticloadbalancing/latest/APIReference/API_DescribeTargetGroupAttributes.html

        :stability: experimental
        '''
        return typing.cast("ElasticloadbalancingV2", jsii.invoke(self, "toDescribeTargetGroupAttributes", []))

    @jsii.member(jsii_name="toDescribeTargetGroups")
    def to_describe_target_groups(self) -> "ElasticloadbalancingV2":
        '''(experimental) Grants permission to describe the specified target groups or all of your target groups.

        Access Level: Read

        https://docs.aws.amazon.com/elasticloadbalancing/latest/APIReference/API_DescribeTargetGroups.html

        :stability: experimental
        '''
        return typing.cast("ElasticloadbalancingV2", jsii.invoke(self, "toDescribeTargetGroups", []))

    @jsii.member(jsii_name="toDescribeTargetHealth")
    def to_describe_target_health(self) -> "ElasticloadbalancingV2":
        '''(experimental) Grants permission to describe the health of the specified targets or all of your targets.

        Access Level: Read

        https://docs.aws.amazon.com/elasticloadbalancing/latest/APIReference/API_DescribeTargetHealth.html

        :stability: experimental
        '''
        return typing.cast("ElasticloadbalancingV2", jsii.invoke(self, "toDescribeTargetHealth", []))

    @jsii.member(jsii_name="toModifyListener")
    def to_modify_listener(self) -> "ElasticloadbalancingV2":
        '''(experimental) Grants permission to modify the specified properties of the specified listener.

        Access Level: Write

        https://docs.aws.amazon.com/elasticloadbalancing/latest/APIReference/API_ModifyListener.html

        :stability: experimental
        '''
        return typing.cast("ElasticloadbalancingV2", jsii.invoke(self, "toModifyListener", []))

    @jsii.member(jsii_name="toModifyLoadBalancerAttributes")
    def to_modify_load_balancer_attributes(self) -> "ElasticloadbalancingV2":
        '''(experimental) Grants permission to modify the attributes of the specified load balancer.

        Access Level: Write

        https://docs.aws.amazon.com/elasticloadbalancing/latest/APIReference/API_ModifyLoadBalancerAttributes.html

        :stability: experimental
        '''
        return typing.cast("ElasticloadbalancingV2", jsii.invoke(self, "toModifyLoadBalancerAttributes", []))

    @jsii.member(jsii_name="toModifyRule")
    def to_modify_rule(self) -> "ElasticloadbalancingV2":
        '''(experimental) Grants permission to modify the specified rule.

        Access Level: Write

        https://docs.aws.amazon.com/elasticloadbalancing/latest/APIReference/API_ModifyRule.html

        :stability: experimental
        '''
        return typing.cast("ElasticloadbalancingV2", jsii.invoke(self, "toModifyRule", []))

    @jsii.member(jsii_name="toModifyTargetGroup")
    def to_modify_target_group(self) -> "ElasticloadbalancingV2":
        '''(experimental) Grants permission to modify the health checks used when evaluating the health state of the targets in the specified target group.

        Access Level: Write

        https://docs.aws.amazon.com/elasticloadbalancing/latest/APIReference/API_ModifyTargetGroup.html

        :stability: experimental
        '''
        return typing.cast("ElasticloadbalancingV2", jsii.invoke(self, "toModifyTargetGroup", []))

    @jsii.member(jsii_name="toModifyTargetGroupAttributes")
    def to_modify_target_group_attributes(self) -> "ElasticloadbalancingV2":
        '''(experimental) Grants permission to modify the specified attributes of the specified target group.

        Access Level: Write

        https://docs.aws.amazon.com/elasticloadbalancing/latest/APIReference/API_ModifyTargetGroupAttributes.html

        :stability: experimental
        '''
        return typing.cast("ElasticloadbalancingV2", jsii.invoke(self, "toModifyTargetGroupAttributes", []))

    @jsii.member(jsii_name="toRegisterTargets")
    def to_register_targets(self) -> "ElasticloadbalancingV2":
        '''(experimental) Grants permission to register the specified targets with the specified target group.

        Access Level: Write

        https://docs.aws.amazon.com/elasticloadbalancing/latest/APIReference/API_RegisterTargets.html

        :stability: experimental
        '''
        return typing.cast("ElasticloadbalancingV2", jsii.invoke(self, "toRegisterTargets", []))

    @jsii.member(jsii_name="toRemoveListenerCertificates")
    def to_remove_listener_certificates(self) -> "ElasticloadbalancingV2":
        '''(experimental) Grants permission to remove the specified certificates of the specified secure listener.

        Access Level: Write

        https://docs.aws.amazon.com/elasticloadbalancing/latest/APIReference/API_RemoveListenerCertificates.html

        :stability: experimental
        '''
        return typing.cast("ElasticloadbalancingV2", jsii.invoke(self, "toRemoveListenerCertificates", []))

    @jsii.member(jsii_name="toRemoveTags")
    def to_remove_tags(self) -> "ElasticloadbalancingV2":
        '''(experimental) Grants permission to remove one or more tags from the specified load balancer.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/elasticloadbalancing/latest/APIReference/API_RemoveTags.html

        :stability: experimental
        '''
        return typing.cast("ElasticloadbalancingV2", jsii.invoke(self, "toRemoveTags", []))

    @jsii.member(jsii_name="toSetIpAddressType")
    def to_set_ip_address_type(self) -> "ElasticloadbalancingV2":
        '''(experimental) Grants permission to set the type of IP addresses used by the subnets of the specified load balancer.

        Access Level: Write

        https://docs.aws.amazon.com/elasticloadbalancing/latest/APIReference/API_SetIpAddressType.html

        :stability: experimental
        '''
        return typing.cast("ElasticloadbalancingV2", jsii.invoke(self, "toSetIpAddressType", []))

    @jsii.member(jsii_name="toSetRulePriorities")
    def to_set_rule_priorities(self) -> "ElasticloadbalancingV2":
        '''(experimental) Grants permission to set the priorities of the specified rules.

        Access Level: Write

        https://docs.aws.amazon.com/elasticloadbalancing/latest/APIReference/API_SetRulePriorities.html

        :stability: experimental
        '''
        return typing.cast("ElasticloadbalancingV2", jsii.invoke(self, "toSetRulePriorities", []))

    @jsii.member(jsii_name="toSetSecurityGroups")
    def to_set_security_groups(self) -> "ElasticloadbalancingV2":
        '''(experimental) Grants permission to associate the specified security groups with the specified load balancer.

        Access Level: Write

        https://docs.aws.amazon.com/elasticloadbalancing/latest/APIReference/API_SetSecurityGroups.html

        :stability: experimental
        '''
        return typing.cast("ElasticloadbalancingV2", jsii.invoke(self, "toSetSecurityGroups", []))

    @jsii.member(jsii_name="toSetSubnets")
    def to_set_subnets(self) -> "ElasticloadbalancingV2":
        '''(experimental) Grants permission to enable the Availability Zone for the specified subnets for the specified load balancer.

        Access Level: Write

        https://docs.aws.amazon.com/elasticloadbalancing/latest/APIReference/API_SetSubnets.html

        :stability: experimental
        '''
        return typing.cast("ElasticloadbalancingV2", jsii.invoke(self, "toSetSubnets", []))

    @jsii.member(jsii_name="toSetWebAcl")
    def to_set_web_acl(self) -> "ElasticloadbalancingV2":
        '''(experimental) Grants permission to give WebAcl permission to WAF.

        Access Level: Write

        https://docs.aws.amazon.com/elasticloadbalancing/latest/APIReference/API_SetWebAcl.html

        :stability: experimental
        '''
        return typing.cast("ElasticloadbalancingV2", jsii.invoke(self, "toSetWebAcl", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d201e6a2da5e5d8b4556c4b371aae7c5cc83bc6c3124823ba390024e4857358f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2448acc8ce4ac22ba32fab0b45095c326ce3490cde73fd9913aec374bac49b0b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Elasticmapreduce(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Elasticmapreduce",
):
    '''(experimental) Statement provider for service `elasticmapreduce <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonelasticmapreduce.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `elasticmapreduce <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonelasticmapreduce.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="ifExecutionRoleArn")
    def if_execution_role_arn(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Elasticmapreduce":
        '''(experimental) Filters access by whether the execution role ARN is provided with the action.

        https://docs.aws.amazon.com/emr/latest/ManagementGuide/emr-plan-access-iam.html#emr-security

        Applies to actions:

        - .toAddJobFlowSteps()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6104a31f9170a249ff517e2a9fc655de5ac435438918a76ae6c792cab1556217)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Elasticmapreduce", jsii.invoke(self, "ifExecutionRoleArn", [value, operator]))

    @jsii.member(jsii_name="ifRequestTag")
    def if_request_tag(
        self,
        tag_key: builtins.str,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Elasticmapreduce":
        '''(experimental) Filters access by whether the tag and value pair is provided with the action.

        https://docs.aws.amazon.com/emr/latest/ManagementGuide/emr-plan-access-iam.html#emr-fine-grained-cluster-access

        Applies to actions:

        - .toAddTags()
        - .toCreateEditor()
        - .toCreateStudio()
        - .toRunJobFlow()
        - .toStartNotebookExecution()

        :param tag_key: The tag key to check.
        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2b12ea0c4f2d3c9de0f37287d816dbf5b6ad0169d429f5285107c80da3665d06)
            check_type(argname="argument tag_key", value=tag_key, expected_type=type_hints["tag_key"])
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Elasticmapreduce", jsii.invoke(self, "ifRequestTag", [tag_key, value, operator]))

    @jsii.member(jsii_name="ifResourceTag")
    def if_resource_tag(
        self,
        tag_key: builtins.str,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Elasticmapreduce":
        '''(experimental) Filters access by the tag and value pair associated with an Amazon EMR resource.

        https://docs.aws.amazon.com/emr/latest/ManagementGuide/emr-plan-access-iam.html#emr-fine-grained-cluster-access

        Applies to resource types:

        - cluster
        - editor
        - notebook-execution
        - studio

        :param tag_key: The tag key to check.
        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1cbd9fec3bd855ad50d052b3058a6471aa971ebe28c41433b8c6ca043f87f59c)
            check_type(argname="argument tag_key", value=tag_key, expected_type=type_hints["tag_key"])
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Elasticmapreduce", jsii.invoke(self, "ifResourceTag", [tag_key, value, operator]))

    @jsii.member(jsii_name="onCluster")
    def on_cluster(
        self,
        cluster_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Elasticmapreduce":
        '''(experimental) Adds a resource of type cluster to the statement.

        https://docs.aws.amazon.com/emr/latest/ManagementGuide/emr-overview.html

        :param cluster_id: - Identifier for the clusterId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag() - .ifResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__661b7b9c828e9d3f6de522f8c8bb456bf0c1102bb5eee38d91fd8c3090675bf0)
            check_type(argname="argument cluster_id", value=cluster_id, expected_type=type_hints["cluster_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Elasticmapreduce", jsii.invoke(self, "onCluster", [cluster_id, account, region, partition]))

    @jsii.member(jsii_name="onEditor")
    def on_editor(
        self,
        editor_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Elasticmapreduce":
        '''(experimental) Adds a resource of type editor to the statement.

        https://docs.aws.amazon.com/emr/latest/ManagementGuide/emr-managed-notebooks.html

        :param editor_id: - Identifier for the editorId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag() - .ifResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__388d529508539639f9f091e3b3b00858e3e008d74f484c21110fe0d123a1f18b)
            check_type(argname="argument editor_id", value=editor_id, expected_type=type_hints["editor_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Elasticmapreduce", jsii.invoke(self, "onEditor", [editor_id, account, region, partition]))

    @jsii.member(jsii_name="onNotebookExecution")
    def on_notebook_execution(
        self,
        notebook_execution_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Elasticmapreduce":
        '''(experimental) Adds a resource of type notebook-execution to the statement.

        https://docs.aws.amazon.com/emr/latest/ManagementGuide/emr-managed-notebooks-headless.html

        :param notebook_execution_id: - Identifier for the notebookExecutionId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag() - .ifResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1a41a79ded636f77365677eb1501e74a3d577648e4f3b2ba3c83981e75d7854b)
            check_type(argname="argument notebook_execution_id", value=notebook_execution_id, expected_type=type_hints["notebook_execution_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Elasticmapreduce", jsii.invoke(self, "onNotebookExecution", [notebook_execution_id, account, region, partition]))

    @jsii.member(jsii_name="onStudio")
    def on_studio(
        self,
        studio_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Elasticmapreduce":
        '''(experimental) Adds a resource of type studio to the statement.

        https://docs.aws.amazon.com/emr/latest/ManagementGuide/emr-studio.html

        :param studio_id: - Identifier for the studioId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag() - .ifResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__62396292432362cb60a36530f48dd5849be053d3c29336f8e58630cae4d96f0e)
            check_type(argname="argument studio_id", value=studio_id, expected_type=type_hints["studio_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Elasticmapreduce", jsii.invoke(self, "onStudio", [studio_id, account, region, partition]))

    @jsii.member(jsii_name="toAddInstanceFleet")
    def to_add_instance_fleet(self) -> "Elasticmapreduce":
        '''(experimental) Grants permission to add an instance fleet to a running cluster.

        Access Level: Write

        https://docs.aws.amazon.com/emr/latest/APIReference/API_AddInstanceFleet.html

        :stability: experimental
        '''
        return typing.cast("Elasticmapreduce", jsii.invoke(self, "toAddInstanceFleet", []))

    @jsii.member(jsii_name="toAddInstanceGroups")
    def to_add_instance_groups(self) -> "Elasticmapreduce":
        '''(experimental) Grants permission to add instance groups to a running cluster.

        Access Level: Write

        https://docs.aws.amazon.com/emr/latest/APIReference/API_AddInstanceGroups.html

        :stability: experimental
        '''
        return typing.cast("Elasticmapreduce", jsii.invoke(self, "toAddInstanceGroups", []))

    @jsii.member(jsii_name="toAddJobFlowSteps")
    def to_add_job_flow_steps(self) -> "Elasticmapreduce":
        '''(experimental) Grants permission to add new steps to a running cluster.

        Access Level: Write

        Possible conditions:

        - .ifExecutionRoleArn()

        https://docs.aws.amazon.com/emr/latest/APIReference/API_AddJobFlowSteps.html

        :stability: experimental
        '''
        return typing.cast("Elasticmapreduce", jsii.invoke(self, "toAddJobFlowSteps", []))

    @jsii.member(jsii_name="toAddTags")
    def to_add_tags(self) -> "Elasticmapreduce":
        '''(experimental) Grants permission to add tags to an Amazon EMR resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifRequestTag()

        https://docs.aws.amazon.com/emr/latest/APIReference/API_AddTags.html

        :stability: experimental
        '''
        return typing.cast("Elasticmapreduce", jsii.invoke(self, "toAddTags", []))

    @jsii.member(jsii_name="toAttachEditor")
    def to_attach_editor(self) -> "Elasticmapreduce":
        '''(experimental) Grants permission to attach an EMR notebook to a compute engine.

        Access Level: Write

        https://docs.aws.amazon.com/emr/latest/ManagementGuide/emr-managed-notebooks-working-with.html

        :stability: experimental
        '''
        return typing.cast("Elasticmapreduce", jsii.invoke(self, "toAttachEditor", []))

    @jsii.member(jsii_name="toCancelSteps")
    def to_cancel_steps(self) -> "Elasticmapreduce":
        '''(experimental) Grants permission to cancel a pending step or steps in a running cluster.

        Access Level: Write

        https://docs.aws.amazon.com/emr/latest/APIReference/API_CancelSteps.html

        :stability: experimental
        '''
        return typing.cast("Elasticmapreduce", jsii.invoke(self, "toCancelSteps", []))

    @jsii.member(jsii_name="toCreateEditor")
    def to_create_editor(self) -> "Elasticmapreduce":
        '''(experimental) Grants permission to create an EMR notebook.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifRequestTag()

        https://docs.aws.amazon.com/emr/latest/ManagementGuide/emr-managed-notebooks-create.html

        :stability: experimental
        '''
        return typing.cast("Elasticmapreduce", jsii.invoke(self, "toCreateEditor", []))

    @jsii.member(jsii_name="toCreatePersistentAppUI")
    def to_create_persistent_app_ui(self) -> "Elasticmapreduce":
        '''(experimental) Grants permission to create a persistent application history server.

        Access Level: Write

        https://docs.aws.amazon.com/emr/latest/ManagementGuide/emr-studio-debug.html

        :stability: experimental
        '''
        return typing.cast("Elasticmapreduce", jsii.invoke(self, "toCreatePersistentAppUI", []))

    @jsii.member(jsii_name="toCreateRepository")
    def to_create_repository(self) -> "Elasticmapreduce":
        '''(experimental) Grants permission to create an EMR notebook repository.

        Access Level: Write

        https://docs.aws.amazon.com/emr/latest/ManagementGuide/emr-managed-notebooks.html#emr-managed-notebooks-editor

        :stability: experimental
        '''
        return typing.cast("Elasticmapreduce", jsii.invoke(self, "toCreateRepository", []))

    @jsii.member(jsii_name="toCreateSecurityConfiguration")
    def to_create_security_configuration(self) -> "Elasticmapreduce":
        '''(experimental) Grants permission to create a security configuration.

        Access Level: Write

        https://docs.aws.amazon.com/emr/latest/APIReference/API_CreateSecurityConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Elasticmapreduce", jsii.invoke(self, "toCreateSecurityConfiguration", []))

    @jsii.member(jsii_name="toCreateStudio")
    def to_create_studio(self) -> "Elasticmapreduce":
        '''(experimental) Grants permission to create an EMR Studio.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifRequestTag()

        https://docs.aws.amazon.com/emr/latest/ManagementGuide/emr-studio.html

        :stability: experimental
        '''
        return typing.cast("Elasticmapreduce", jsii.invoke(self, "toCreateStudio", []))

    @jsii.member(jsii_name="toCreateStudioPresignedUrl")
    def to_create_studio_presigned_url(self) -> "Elasticmapreduce":
        '''(experimental) Grants permission to launch an EMR Studio using IAM authentication mode.

        Access Level: Write

        https://docs.aws.amazon.com/emr/latest/ManagementGuide/emr-studio.html

        :stability: experimental
        '''
        return typing.cast("Elasticmapreduce", jsii.invoke(self, "toCreateStudioPresignedUrl", []))

    @jsii.member(jsii_name="toCreateStudioSessionMapping")
    def to_create_studio_session_mapping(self) -> "Elasticmapreduce":
        '''(experimental) Grants permission to create an EMR Studio session mapping.

        Access Level: Write

        https://docs.aws.amazon.com/emr/latest/ManagementGuide/emr-studio.html

        :stability: experimental
        '''
        return typing.cast("Elasticmapreduce", jsii.invoke(self, "toCreateStudioSessionMapping", []))

    @jsii.member(jsii_name="toDeleteEditor")
    def to_delete_editor(self) -> "Elasticmapreduce":
        '''(experimental) Grants permission to delete an EMR notebook.

        Access Level: Write

        https://docs.aws.amazon.com/emr/latest/ManagementGuide/emr-managed-notebooks.html#emr-managed-notebooks-deleting

        :stability: experimental
        '''
        return typing.cast("Elasticmapreduce", jsii.invoke(self, "toDeleteEditor", []))

    @jsii.member(jsii_name="toDeleteRepository")
    def to_delete_repository(self) -> "Elasticmapreduce":
        '''(experimental) Grants permission to delete an EMR notebook repository.

        Access Level: Write

        https://docs.aws.amazon.com/emr/latest/ManagementGuide/emr-managed-notebooks.html#emr-managed-notebooks-editor

        :stability: experimental
        '''
        return typing.cast("Elasticmapreduce", jsii.invoke(self, "toDeleteRepository", []))

    @jsii.member(jsii_name="toDeleteSecurityConfiguration")
    def to_delete_security_configuration(self) -> "Elasticmapreduce":
        '''(experimental) Grants permission to delete a security configuration.

        Access Level: Write

        https://docs.aws.amazon.com/emr/latest/APIReference/API_DeleteSecurityConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Elasticmapreduce", jsii.invoke(self, "toDeleteSecurityConfiguration", []))

    @jsii.member(jsii_name="toDeleteStudio")
    def to_delete_studio(self) -> "Elasticmapreduce":
        '''(experimental) Grants permission to delete an EMR Studio.

        Access Level: Write

        https://docs.aws.amazon.com/emr/latest/ManagementGuide/emr-studio.html

        :stability: experimental
        '''
        return typing.cast("Elasticmapreduce", jsii.invoke(self, "toDeleteStudio", []))

    @jsii.member(jsii_name="toDeleteStudioSessionMapping")
    def to_delete_studio_session_mapping(self) -> "Elasticmapreduce":
        '''(experimental) Grants permission to delete an EMR Studio session mapping.

        Access Level: Write

        https://docs.aws.amazon.com/emr/latest/ManagementGuide/emr-studio.html

        :stability: experimental
        '''
        return typing.cast("Elasticmapreduce", jsii.invoke(self, "toDeleteStudioSessionMapping", []))

    @jsii.member(jsii_name="toDeleteWorkspaceAccess")
    def to_delete_workspace_access(self) -> "Elasticmapreduce":
        '''(experimental) Grants permission to block an identity from opening a collaborative workspace.

        Access Level: Permissions management

        https://docs.aws.amazon.com/emr/latest/ManagementGuide/emr-managed-notebooks-working-with.html

        :stability: experimental
        '''
        return typing.cast("Elasticmapreduce", jsii.invoke(self, "toDeleteWorkspaceAccess", []))

    @jsii.member(jsii_name="toDescribeCluster")
    def to_describe_cluster(self) -> "Elasticmapreduce":
        '''(experimental) Grants permission to get details about a cluster, including status, hardware and software configuration, VPC settings, and so on.

        Access Level: Read

        https://docs.aws.amazon.com/emr/latest/APIReference/API_DescribeCluster.html

        :stability: experimental
        '''
        return typing.cast("Elasticmapreduce", jsii.invoke(self, "toDescribeCluster", []))

    @jsii.member(jsii_name="toDescribeEditor")
    def to_describe_editor(self) -> "Elasticmapreduce":
        '''(experimental) Grants permission to view information about a notebook, including status, user, role, tags, location, and more.

        Access Level: Read

        https://docs.aws.amazon.com/emr/latest/ManagementGuide/emr-managed-notebooks-working-with.html

        :stability: experimental
        '''
        return typing.cast("Elasticmapreduce", jsii.invoke(self, "toDescribeEditor", []))

    @jsii.member(jsii_name="toDescribeJobFlows")
    def to_describe_job_flows(self) -> "Elasticmapreduce":
        '''(experimental) Grants permission to describe details of clusters (job flows).

        This API is deprecated and will eventually be removed. We recommend you use ListClusters, DescribeCluster, ListSteps, ListInstanceGroups and ListBootstrapActions instead

        Access Level: Read

        https://docs.aws.amazon.com/emr/latest/APIReference/API_DescribeJobFlows.html

        :stability: experimental
        '''
        return typing.cast("Elasticmapreduce", jsii.invoke(self, "toDescribeJobFlows", []))

    @jsii.member(jsii_name="toDescribeNotebookExecution")
    def to_describe_notebook_execution(self) -> "Elasticmapreduce":
        '''(experimental) Grants permission to view information about a notebook execution.

        Access Level: Read

        https://docs.aws.amazon.com/emr/latest/ManagementGuide/emr-managed-notebooks-headless.html

        :stability: experimental
        '''
        return typing.cast("Elasticmapreduce", jsii.invoke(self, "toDescribeNotebookExecution", []))

    @jsii.member(jsii_name="toDescribePersistentAppUI")
    def to_describe_persistent_app_ui(self) -> "Elasticmapreduce":
        '''(experimental) Grants permission to describe a persistent application history server.

        Access Level: Read

        https://docs.aws.amazon.com/emr/latest/ManagementGuide/emr-studio-debug.html

        :stability: experimental
        '''
        return typing.cast("Elasticmapreduce", jsii.invoke(self, "toDescribePersistentAppUI", []))

    @jsii.member(jsii_name="toDescribeReleaseLabel")
    def to_describe_release_label(self) -> "Elasticmapreduce":
        '''(experimental) Grants permission to view information about an EMR release, such as which applications are supported.

        Access Level: Read

        https://docs.aws.amazon.com/emr/latest/APIReference/API_DescribeReleaseLabel.html

        :stability: experimental
        '''
        return typing.cast("Elasticmapreduce", jsii.invoke(self, "toDescribeReleaseLabel", []))

    @jsii.member(jsii_name="toDescribeRepository")
    def to_describe_repository(self) -> "Elasticmapreduce":
        '''(experimental) Grants permission to describe an EMR notebook repository.

        Access Level: Read

        https://docs.aws.amazon.com/emr/latest/ManagementGuide/emr-managed-notebooks.html#emr-managed-notebooks-editor

        :stability: experimental
        '''
        return typing.cast("Elasticmapreduce", jsii.invoke(self, "toDescribeRepository", []))

    @jsii.member(jsii_name="toDescribeSecurityConfiguration")
    def to_describe_security_configuration(self) -> "Elasticmapreduce":
        '''(experimental) Grants permission to get details of a security configuration.

        Access Level: Read

        https://docs.aws.amazon.com/emr/latest/APIReference/API_DescribeSecurityConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Elasticmapreduce", jsii.invoke(self, "toDescribeSecurityConfiguration", []))

    @jsii.member(jsii_name="toDescribeStep")
    def to_describe_step(self) -> "Elasticmapreduce":
        '''(experimental) Grants permission to get details about a cluster step.

        Access Level: Read

        https://docs.aws.amazon.com/emr/latest/APIReference/API_DescribeStep.html

        :stability: experimental
        '''
        return typing.cast("Elasticmapreduce", jsii.invoke(self, "toDescribeStep", []))

    @jsii.member(jsii_name="toDescribeStudio")
    def to_describe_studio(self) -> "Elasticmapreduce":
        '''(experimental) Grants permission to view information about an EMR Studio.

        Access Level: Read

        https://docs.aws.amazon.com/emr/latest/ManagementGuide/emr-studio.html

        :stability: experimental
        '''
        return typing.cast("Elasticmapreduce", jsii.invoke(self, "toDescribeStudio", []))

    @jsii.member(jsii_name="toDetachEditor")
    def to_detach_editor(self) -> "Elasticmapreduce":
        '''(experimental) Grants permission to detach an EMR notebook from a compute engine.

        Access Level: Write

        https://docs.aws.amazon.com/emr/latest/ManagementGuide/emr-managed-notebooks-working-with.html

        :stability: experimental
        '''
        return typing.cast("Elasticmapreduce", jsii.invoke(self, "toDetachEditor", []))

    @jsii.member(jsii_name="toGetAutoTerminationPolicy")
    def to_get_auto_termination_policy(self) -> "Elasticmapreduce":
        '''(experimental) Grants permission to retrieve the auto-termination policy associated with a cluster.

        Access Level: Read

        https://docs.aws.amazon.com/emr/latest/APIReference/API_GetAutoTerminationPolicy.html

        :stability: experimental
        '''
        return typing.cast("Elasticmapreduce", jsii.invoke(self, "toGetAutoTerminationPolicy", []))

    @jsii.member(jsii_name="toGetBlockPublicAccessConfiguration")
    def to_get_block_public_access_configuration(self) -> "Elasticmapreduce":
        '''(experimental) Grants permission to retrieve the EMR block public access configuration for the AWS account in the Region.

        Access Level: Read

        https://docs.aws.amazon.com/emr/latest/APIReference/API_GetBlockPublicAccessConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Elasticmapreduce", jsii.invoke(self, "toGetBlockPublicAccessConfiguration", []))

    @jsii.member(jsii_name="toGetManagedScalingPolicy")
    def to_get_managed_scaling_policy(self) -> "Elasticmapreduce":
        '''(experimental) Grants permission to retrieve the managed scaling policy associated with a cluster.

        Access Level: Read

        https://docs.aws.amazon.com/emr/latest/APIReference/API_GetManagedScalingPolicy.html

        :stability: experimental
        '''
        return typing.cast("Elasticmapreduce", jsii.invoke(self, "toGetManagedScalingPolicy", []))

    @jsii.member(jsii_name="toGetOnClusterAppUIPresignedURL")
    def to_get_on_cluster_app_ui_presigned_url(self) -> "Elasticmapreduce":
        '''(experimental) Grants permission to get a presigned URL for an application history server running on the cluster.

        Access Level: Write

        https://docs.aws.amazon.com/emr/latest/ManagementGuide/emr-studio-debug.html

        :stability: experimental
        '''
        return typing.cast("Elasticmapreduce", jsii.invoke(self, "toGetOnClusterAppUIPresignedURL", []))

    @jsii.member(jsii_name="toGetPersistentAppUIPresignedURL")
    def to_get_persistent_app_ui_presigned_url(self) -> "Elasticmapreduce":
        '''(experimental) Grants permission to get a presigned URL for a persistent application history server.

        Access Level: Write

        https://docs.aws.amazon.com/emr/latest/ManagementGuide/emr-studio-debug.html

        :stability: experimental
        '''
        return typing.cast("Elasticmapreduce", jsii.invoke(self, "toGetPersistentAppUIPresignedURL", []))

    @jsii.member(jsii_name="toGetStudioSessionMapping")
    def to_get_studio_session_mapping(self) -> "Elasticmapreduce":
        '''(experimental) Grants permission to view information about an EMR Studio session mapping.

        Access Level: Read

        https://docs.aws.amazon.com/emr/latest/ManagementGuide/emr-studio.html

        :stability: experimental
        '''
        return typing.cast("Elasticmapreduce", jsii.invoke(self, "toGetStudioSessionMapping", []))

    @jsii.member(jsii_name="toLinkRepository")
    def to_link_repository(self) -> "Elasticmapreduce":
        '''(experimental) Grants permission to link an EMR notebook repository to EMR notebooks.

        Access Level: Write

        https://docs.aws.amazon.com/emr/latest/ManagementGuide/emr-managed-notebooks.html#emr-managed-notebooks-editor

        :stability: experimental
        '''
        return typing.cast("Elasticmapreduce", jsii.invoke(self, "toLinkRepository", []))

    @jsii.member(jsii_name="toListBootstrapActions")
    def to_list_bootstrap_actions(self) -> "Elasticmapreduce":
        '''(experimental) Grants permission to get details about the bootstrap actions associated with a cluster.

        Access Level: Read

        https://docs.aws.amazon.com/emr/latest/APIReference/API_ListBootstrapActions.html

        :stability: experimental
        '''
        return typing.cast("Elasticmapreduce", jsii.invoke(self, "toListBootstrapActions", []))

    @jsii.member(jsii_name="toListClusters")
    def to_list_clusters(self) -> "Elasticmapreduce":
        '''(experimental) Grants permission to get the status of accessible clusters.

        Access Level: List

        https://docs.aws.amazon.com/emr/latest/APIReference/API_ListClusters.html

        :stability: experimental
        '''
        return typing.cast("Elasticmapreduce", jsii.invoke(self, "toListClusters", []))

    @jsii.member(jsii_name="toListEditors")
    def to_list_editors(self) -> "Elasticmapreduce":
        '''(experimental) Grants permission to list summary information for accessible EMR notebooks.

        Access Level: List

        https://docs.aws.amazon.com/emr/latest/ManagementGuide/emr-managed-notebooks-working-with.html

        :stability: experimental
        '''
        return typing.cast("Elasticmapreduce", jsii.invoke(self, "toListEditors", []))

    @jsii.member(jsii_name="toListInstanceFleets")
    def to_list_instance_fleets(self) -> "Elasticmapreduce":
        '''(experimental) Grants permission to get details of instance fleets in a cluster.

        Access Level: Read

        https://docs.aws.amazon.com/emr/latest/APIReference/API_ListInstanceFleets.html

        :stability: experimental
        '''
        return typing.cast("Elasticmapreduce", jsii.invoke(self, "toListInstanceFleets", []))

    @jsii.member(jsii_name="toListInstanceGroups")
    def to_list_instance_groups(self) -> "Elasticmapreduce":
        '''(experimental) Grants permission to get details of instance groups in a cluster.

        Access Level: Read

        https://docs.aws.amazon.com/emr/latest/APIReference/API_ListInstanceGroups.html

        :stability: experimental
        '''
        return typing.cast("Elasticmapreduce", jsii.invoke(self, "toListInstanceGroups", []))

    @jsii.member(jsii_name="toListInstances")
    def to_list_instances(self) -> "Elasticmapreduce":
        '''(experimental) Grants permission to get details about the Amazon EC2 instances in a cluster.

        Access Level: Read

        https://docs.aws.amazon.com/emr/latest/APIReference/API_ListInstances.html

        :stability: experimental
        '''
        return typing.cast("Elasticmapreduce", jsii.invoke(self, "toListInstances", []))

    @jsii.member(jsii_name="toListNotebookExecutions")
    def to_list_notebook_executions(self) -> "Elasticmapreduce":
        '''(experimental) Grants permission to list summary information for notebook executions.

        Access Level: List

        https://docs.aws.amazon.com/emr/latest/ManagementGuide/emr-managed-notebooks-headless.html

        :stability: experimental
        '''
        return typing.cast("Elasticmapreduce", jsii.invoke(self, "toListNotebookExecutions", []))

    @jsii.member(jsii_name="toListReleaseLabels")
    def to_list_release_labels(self) -> "Elasticmapreduce":
        '''(experimental) Grants permission to list and filter the available EMR releases in the current region.

        Access Level: List

        https://docs.aws.amazon.com/emr/latest/APIReference/API_ListReleaseLabels.html

        :stability: experimental
        '''
        return typing.cast("Elasticmapreduce", jsii.invoke(self, "toListReleaseLabels", []))

    @jsii.member(jsii_name="toListRepositories")
    def to_list_repositories(self) -> "Elasticmapreduce":
        '''(experimental) Grants permission to list existing EMR notebook repositories.

        Access Level: List

        https://docs.aws.amazon.com/emr/latest/ManagementGuide/emr-managed-notebooks.html#emr-managed-notebooks-editor

        :stability: experimental
        '''
        return typing.cast("Elasticmapreduce", jsii.invoke(self, "toListRepositories", []))

    @jsii.member(jsii_name="toListSecurityConfigurations")
    def to_list_security_configurations(self) -> "Elasticmapreduce":
        '''(experimental) Grants permission to list available security configurations in this account by name, along with creation dates and times.

        Access Level: List

        https://docs.aws.amazon.com/emr/latest/APIReference/API_ListSecurityConfigurations.html

        :stability: experimental
        '''
        return typing.cast("Elasticmapreduce", jsii.invoke(self, "toListSecurityConfigurations", []))

    @jsii.member(jsii_name="toListSteps")
    def to_list_steps(self) -> "Elasticmapreduce":
        '''(experimental) Grants permission to list steps associated with a cluster.

        Access Level: Read

        https://docs.aws.amazon.com/emr/latest/APIReference/API_ListSteps.html

        :stability: experimental
        '''
        return typing.cast("Elasticmapreduce", jsii.invoke(self, "toListSteps", []))

    @jsii.member(jsii_name="toListStudios")
    def to_list_studios(self) -> "Elasticmapreduce":
        '''(experimental) Grants permission to list summary information about EMR Studios.

        Access Level: List

        https://docs.aws.amazon.com/emr/latest/ManagementGuide/emr-studio.html

        :stability: experimental
        '''
        return typing.cast("Elasticmapreduce", jsii.invoke(self, "toListStudios", []))

    @jsii.member(jsii_name="toListStudioSessionMappings")
    def to_list_studio_session_mappings(self) -> "Elasticmapreduce":
        '''(experimental) Grants permission to list summary information about EMR Studio session mappings.

        Access Level: List

        https://docs.aws.amazon.com/emr/latest/ManagementGuide/emr-studio.html

        :stability: experimental
        '''
        return typing.cast("Elasticmapreduce", jsii.invoke(self, "toListStudioSessionMappings", []))

    @jsii.member(jsii_name="toListWorkspaceAccessIdentities")
    def to_list_workspace_access_identities(self) -> "Elasticmapreduce":
        '''(experimental) Grants permission to list identities that are granted access to a workspace.

        Access Level: List

        https://docs.aws.amazon.com/emr/latest/ManagementGuide/emr-managed-notebooks-working-with.html

        :stability: experimental
        '''
        return typing.cast("Elasticmapreduce", jsii.invoke(self, "toListWorkspaceAccessIdentities", []))

    @jsii.member(jsii_name="toModifyCluster")
    def to_modify_cluster(self) -> "Elasticmapreduce":
        '''(experimental) Grants permission to change cluster settings such as number of steps that can be executed concurrently for a cluster.

        Access Level: Write

        https://docs.aws.amazon.com/emr/latest/APIReference/API_ModifyCluster.html

        :stability: experimental
        '''
        return typing.cast("Elasticmapreduce", jsii.invoke(self, "toModifyCluster", []))

    @jsii.member(jsii_name="toModifyInstanceFleet")
    def to_modify_instance_fleet(self) -> "Elasticmapreduce":
        '''(experimental) Grants permission to change the target On-Demand and target Spot capacities for a instance fleet.

        Access Level: Write

        https://docs.aws.amazon.com/emr/latest/APIReference/API_ModifyInstanceFleet.html

        :stability: experimental
        '''
        return typing.cast("Elasticmapreduce", jsii.invoke(self, "toModifyInstanceFleet", []))

    @jsii.member(jsii_name="toModifyInstanceGroups")
    def to_modify_instance_groups(self) -> "Elasticmapreduce":
        '''(experimental) Grants permission to change the number and configuration of EC2 instances for an instance group.

        Access Level: Write

        https://docs.aws.amazon.com/emr/latest/APIReference/API_ModifyInstanceGroups.html

        :stability: experimental
        '''
        return typing.cast("Elasticmapreduce", jsii.invoke(self, "toModifyInstanceGroups", []))

    @jsii.member(jsii_name="toOpenEditorInConsole")
    def to_open_editor_in_console(self) -> "Elasticmapreduce":
        '''(experimental) Grants permission to launch the Jupyter notebook editor for an EMR notebook from within the console.

        Access Level: Write

        https://docs.aws.amazon.com/emr/latest/ManagementGuide/emr-managed-notebooks.html#emr-managed-notebooks-editor

        :stability: experimental
        '''
        return typing.cast("Elasticmapreduce", jsii.invoke(self, "toOpenEditorInConsole", []))

    @jsii.member(jsii_name="toPutAutoScalingPolicy")
    def to_put_auto_scaling_policy(self) -> "Elasticmapreduce":
        '''(experimental) Grants permission to create or update an automatic scaling policy for a core instance group or task instance group.

        Access Level: Write

        https://docs.aws.amazon.com/emr/latest/APIReference/API_PutAutoScalingPolicy.html

        :stability: experimental
        '''
        return typing.cast("Elasticmapreduce", jsii.invoke(self, "toPutAutoScalingPolicy", []))

    @jsii.member(jsii_name="toPutAutoTerminationPolicy")
    def to_put_auto_termination_policy(self) -> "Elasticmapreduce":
        '''(experimental) Grants permission to create or update the auto-termination policy associated with a cluster.

        Access Level: Write

        https://docs.aws.amazon.com/emr/latest/APIReference/API_PutAutoTerminationPolicy.html

        :stability: experimental
        '''
        return typing.cast("Elasticmapreduce", jsii.invoke(self, "toPutAutoTerminationPolicy", []))

    @jsii.member(jsii_name="toPutBlockPublicAccessConfiguration")
    def to_put_block_public_access_configuration(self) -> "Elasticmapreduce":
        '''(experimental) Grants permission to create or update the EMR block public access configuration for the AWS account in the Region.

        Access Level: Permissions management

        https://docs.aws.amazon.com/emr/latest/APIReference/API_PutBlockPublicAccessConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Elasticmapreduce", jsii.invoke(self, "toPutBlockPublicAccessConfiguration", []))

    @jsii.member(jsii_name="toPutManagedScalingPolicy")
    def to_put_managed_scaling_policy(self) -> "Elasticmapreduce":
        '''(experimental) Grants permission to create or update the managed scaling policy associated with a cluster.

        Access Level: Write

        https://docs.aws.amazon.com/emr/latest/APIReference/API_PutManagedScalingPolicy.html

        :stability: experimental
        '''
        return typing.cast("Elasticmapreduce", jsii.invoke(self, "toPutManagedScalingPolicy", []))

    @jsii.member(jsii_name="toPutWorkspaceAccess")
    def to_put_workspace_access(self) -> "Elasticmapreduce":
        '''(experimental) Grants permission to allow an identity to open a collaborative workspace.

        Access Level: Permissions management

        https://docs.aws.amazon.com/emr/latest/ManagementGuide/emr-managed-notebooks-working-with.html

        :stability: experimental
        '''
        return typing.cast("Elasticmapreduce", jsii.invoke(self, "toPutWorkspaceAccess", []))

    @jsii.member(jsii_name="toRemoveAutoScalingPolicy")
    def to_remove_auto_scaling_policy(self) -> "Elasticmapreduce":
        '''(experimental) Grants permission to remove an automatic scaling policy from an instance group.

        Access Level: Write

        https://docs.aws.amazon.com/emr/latest/APIReference/API_RemoveAutoScalingPolicy.html

        :stability: experimental
        '''
        return typing.cast("Elasticmapreduce", jsii.invoke(self, "toRemoveAutoScalingPolicy", []))

    @jsii.member(jsii_name="toRemoveAutoTerminationPolicy")
    def to_remove_auto_termination_policy(self) -> "Elasticmapreduce":
        '''(experimental) Grants permission to remove the auto-termination policy associated with a cluster.

        Access Level: Write

        https://docs.aws.amazon.com/emr/latest/APIReference/API_RemoveAutoTerminationPolicy.html

        :stability: experimental
        '''
        return typing.cast("Elasticmapreduce", jsii.invoke(self, "toRemoveAutoTerminationPolicy", []))

    @jsii.member(jsii_name="toRemoveManagedScalingPolicy")
    def to_remove_managed_scaling_policy(self) -> "Elasticmapreduce":
        '''(experimental) Grants permission to remove the managed scaling policy associated with a cluster.

        Access Level: Write

        https://docs.aws.amazon.com/emr/latest/APIReference/API_RemoveManagedScalingPolicy.html

        :stability: experimental
        '''
        return typing.cast("Elasticmapreduce", jsii.invoke(self, "toRemoveManagedScalingPolicy", []))

    @jsii.member(jsii_name="toRemoveTags")
    def to_remove_tags(self) -> "Elasticmapreduce":
        '''(experimental) Grants permission to remove tags from an Amazon EMR resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/emr/latest/APIReference/API_RemoveTags.html

        :stability: experimental
        '''
        return typing.cast("Elasticmapreduce", jsii.invoke(self, "toRemoveTags", []))

    @jsii.member(jsii_name="toRunJobFlow")
    def to_run_job_flow(self) -> "Elasticmapreduce":
        '''(experimental) Grants permission to create and launch a cluster (job flow).

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifRequestTag()

        https://docs.aws.amazon.com/emr/latest/APIReference/API_RunJobFlow.html

        :stability: experimental
        '''
        return typing.cast("Elasticmapreduce", jsii.invoke(self, "toRunJobFlow", []))

    @jsii.member(jsii_name="toSetTerminationProtection")
    def to_set_termination_protection(self) -> "Elasticmapreduce":
        '''(experimental) Grants permission to add and remove termination protection for a cluster.

        Access Level: Write

        https://docs.aws.amazon.com/emr/latest/APIReference/API_SetTerminationProtection.html

        :stability: experimental
        '''
        return typing.cast("Elasticmapreduce", jsii.invoke(self, "toSetTerminationProtection", []))

    @jsii.member(jsii_name="toStartEditor")
    def to_start_editor(self) -> "Elasticmapreduce":
        '''(experimental) Grants permission to start an EMR notebook.

        Access Level: Write

        https://docs.aws.amazon.com/emr/latest/ManagementGuide/emr-managed-notebooks-working-with.html

        :stability: experimental
        '''
        return typing.cast("Elasticmapreduce", jsii.invoke(self, "toStartEditor", []))

    @jsii.member(jsii_name="toStartNotebookExecution")
    def to_start_notebook_execution(self) -> "Elasticmapreduce":
        '''(experimental) Grants permission to start an EMR notebook execution.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifRequestTag()

        https://docs.aws.amazon.com/emr/latest/ManagementGuide/emr-managed-notebooks-headless.html

        :stability: experimental
        '''
        return typing.cast("Elasticmapreduce", jsii.invoke(self, "toStartNotebookExecution", []))

    @jsii.member(jsii_name="toStopEditor")
    def to_stop_editor(self) -> "Elasticmapreduce":
        '''(experimental) Grants permission to shut down an EMR notebook.

        Access Level: Write

        https://docs.aws.amazon.com/emr/latest/ManagementGuide/emr-managed-notebooks.html

        :stability: experimental
        '''
        return typing.cast("Elasticmapreduce", jsii.invoke(self, "toStopEditor", []))

    @jsii.member(jsii_name="toStopNotebookExecution")
    def to_stop_notebook_execution(self) -> "Elasticmapreduce":
        '''(experimental) Grants permission to stop notebook execution.

        Access Level: Write

        https://docs.aws.amazon.com/emr/latest/ManagementGuide/emr-managed-notebooks-headless.html

        :stability: experimental
        '''
        return typing.cast("Elasticmapreduce", jsii.invoke(self, "toStopNotebookExecution", []))

    @jsii.member(jsii_name="toTerminateJobFlows")
    def to_terminate_job_flows(self) -> "Elasticmapreduce":
        '''(experimental) Grants permission to terminate a cluster (job flow).

        Access Level: Write

        https://docs.aws.amazon.com/emr/latest/APIReference/API_TerminateJobFlows.html

        :stability: experimental
        '''
        return typing.cast("Elasticmapreduce", jsii.invoke(self, "toTerminateJobFlows", []))

    @jsii.member(jsii_name="toUnlinkRepository")
    def to_unlink_repository(self) -> "Elasticmapreduce":
        '''(experimental) Grants permission to unlink an EMR notebook repository from EMR notebooks.

        Access Level: Write

        https://docs.aws.amazon.com/emr/latest/ManagementGuide/emr-managed-notebooks.html#emr-managed-notebooks-editor

        :stability: experimental
        '''
        return typing.cast("Elasticmapreduce", jsii.invoke(self, "toUnlinkRepository", []))

    @jsii.member(jsii_name="toUpdateEditor")
    def to_update_editor(self) -> "Elasticmapreduce":
        '''(experimental) Grants permission to update an EMR notebook.

        Access Level: Write

        https://docs.aws.amazon.com/emr/latest/ManagementGuide/emr-managed-notebooks-working-with.html

        :stability: experimental
        '''
        return typing.cast("Elasticmapreduce", jsii.invoke(self, "toUpdateEditor", []))

    @jsii.member(jsii_name="toUpdateRepository")
    def to_update_repository(self) -> "Elasticmapreduce":
        '''(experimental) Grants permission to update an EMR notebook repository.

        Access Level: Write

        https://docs.aws.amazon.com/emr/latest/ManagementGuide/emr-managed-notebooks.html#emr-managed-notebooks-editor

        :stability: experimental
        '''
        return typing.cast("Elasticmapreduce", jsii.invoke(self, "toUpdateRepository", []))

    @jsii.member(jsii_name="toUpdateStudio")
    def to_update_studio(self) -> "Elasticmapreduce":
        '''(experimental) Grants permission to update information about an EMR Studio.

        Access Level: Write

        https://docs.aws.amazon.com/emr/latest/ManagementGuide/emr-studio.html

        :stability: experimental
        '''
        return typing.cast("Elasticmapreduce", jsii.invoke(self, "toUpdateStudio", []))

    @jsii.member(jsii_name="toUpdateStudioSessionMapping")
    def to_update_studio_session_mapping(self) -> "Elasticmapreduce":
        '''(experimental) Grants permission to update an EMR Studio session mapping.

        Access Level: Write

        https://docs.aws.amazon.com/emr/latest/ManagementGuide/emr-studio.html

        :stability: experimental
        '''
        return typing.cast("Elasticmapreduce", jsii.invoke(self, "toUpdateStudioSessionMapping", []))

    @jsii.member(jsii_name="toViewEventsFromAllClustersInConsole")
    def to_view_events_from_all_clusters_in_console(self) -> "Elasticmapreduce":
        '''(experimental) Grants permission to use the EMR console to view events from all clusters.

        Access Level: List

        :stability: experimental
        '''
        return typing.cast("Elasticmapreduce", jsii.invoke(self, "toViewEventsFromAllClustersInConsole", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4ca7125703b0a6a346c839ae83248b6b515347a2fa2bec7ca8626c658c3bda6d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e5a3fd616a1900d7106b12e52a3a47f9e62e6a7179a4cc70ab0baab682c0dd1d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Elastictranscoder(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Elastictranscoder",
):
    '''(experimental) Statement provider for service `elastictranscoder <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonelastictranscoder.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `elastictranscoder <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonelastictranscoder.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onJob")
    def on_job(
        self,
        job_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Elastictranscoder":
        '''(experimental) Adds a resource of type job to the statement.

        https://docs.aws.amazon.com/elastictranscoder/latest/developerguide/operations-jobs.html

        :param job_id: - Identifier for the jobId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a89d793b863568adddaf64b0a343b89101a533814fcfc4cc16cb31503853cfaf)
            check_type(argname="argument job_id", value=job_id, expected_type=type_hints["job_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Elastictranscoder", jsii.invoke(self, "onJob", [job_id, account, region, partition]))

    @jsii.member(jsii_name="onPipeline")
    def on_pipeline(
        self,
        pipeline_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Elastictranscoder":
        '''(experimental) Adds a resource of type pipeline to the statement.

        https://docs.aws.amazon.com/elastictranscoder/latest/developerguide/operations-pipelines.html

        :param pipeline_id: - Identifier for the pipelineId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__92af13ebe78c7baf89062e744d5bdff280acebda330f3fd095c44dff964466fe)
            check_type(argname="argument pipeline_id", value=pipeline_id, expected_type=type_hints["pipeline_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Elastictranscoder", jsii.invoke(self, "onPipeline", [pipeline_id, account, region, partition]))

    @jsii.member(jsii_name="onPreset")
    def on_preset(
        self,
        preset_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Elastictranscoder":
        '''(experimental) Adds a resource of type preset to the statement.

        https://docs.aws.amazon.com/elastictranscoder/latest/developerguide/operations-presets.html

        :param preset_id: - Identifier for the presetId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__aca9fc6be099103403beca3c2919b9fb10c21d0b0ca323583176e8afcb792117)
            check_type(argname="argument preset_id", value=preset_id, expected_type=type_hints["preset_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Elastictranscoder", jsii.invoke(self, "onPreset", [preset_id, account, region, partition]))

    @jsii.member(jsii_name="toCancelJob")
    def to_cancel_job(self) -> "Elastictranscoder":
        '''(experimental) Cancel a job that Elastic Transcoder has not begun to process.

        Access Level: Write

        https://docs.aws.amazon.com/elastictranscoder/latest/developerguide/cancel-job.html

        :stability: experimental
        '''
        return typing.cast("Elastictranscoder", jsii.invoke(self, "toCancelJob", []))

    @jsii.member(jsii_name="toCreateJob")
    def to_create_job(self) -> "Elastictranscoder":
        '''(experimental) Create a job.

        Access Level: Write

        https://docs.aws.amazon.com/elastictranscoder/latest/developerguide/create-job.html

        :stability: experimental
        '''
        return typing.cast("Elastictranscoder", jsii.invoke(self, "toCreateJob", []))

    @jsii.member(jsii_name="toCreatePipeline")
    def to_create_pipeline(self) -> "Elastictranscoder":
        '''(experimental) Create a pipeline.

        Access Level: Write

        https://docs.aws.amazon.com/elastictranscoder/latest/developerguide/create-pipeline.html

        :stability: experimental
        '''
        return typing.cast("Elastictranscoder", jsii.invoke(self, "toCreatePipeline", []))

    @jsii.member(jsii_name="toCreatePreset")
    def to_create_preset(self) -> "Elastictranscoder":
        '''(experimental) Create a preset.

        Access Level: Write

        https://docs.aws.amazon.com/elastictranscoder/latest/developerguide/create-preset.html

        :stability: experimental
        '''
        return typing.cast("Elastictranscoder", jsii.invoke(self, "toCreatePreset", []))

    @jsii.member(jsii_name="toDeletePipeline")
    def to_delete_pipeline(self) -> "Elastictranscoder":
        '''(experimental) Delete a pipeline.

        Access Level: Write

        https://docs.aws.amazon.com/elastictranscoder/latest/developerguide/delete-pipeline.html

        :stability: experimental
        '''
        return typing.cast("Elastictranscoder", jsii.invoke(self, "toDeletePipeline", []))

    @jsii.member(jsii_name="toDeletePreset")
    def to_delete_preset(self) -> "Elastictranscoder":
        '''(experimental) Delete a preset.

        Access Level: Write

        https://docs.aws.amazon.com/elastictranscoder/latest/developerguide/delete-preset.html

        :stability: experimental
        '''
        return typing.cast("Elastictranscoder", jsii.invoke(self, "toDeletePreset", []))

    @jsii.member(jsii_name="toListJobsByPipeline")
    def to_list_jobs_by_pipeline(self) -> "Elastictranscoder":
        '''(experimental) Get a list of the jobs that you assigned to a pipeline.

        Access Level: List

        https://docs.aws.amazon.com/elastictranscoder/latest/developerguide/list-jobs-by-pipeline.html

        :stability: experimental
        '''
        return typing.cast("Elastictranscoder", jsii.invoke(self, "toListJobsByPipeline", []))

    @jsii.member(jsii_name="toListJobsByStatus")
    def to_list_jobs_by_status(self) -> "Elastictranscoder":
        '''(experimental) Get information about all of the jobs associated with the current AWS account that have a specified status.

        Access Level: List

        https://docs.aws.amazon.com/elastictranscoder/latest/developerguide/list-jobs-by-status.html

        :stability: experimental
        '''
        return typing.cast("Elastictranscoder", jsii.invoke(self, "toListJobsByStatus", []))

    @jsii.member(jsii_name="toListPipelines")
    def to_list_pipelines(self) -> "Elastictranscoder":
        '''(experimental) Get a list of the pipelines associated with the current AWS account.

        Access Level: List

        https://docs.aws.amazon.com/elastictranscoder/latest/developerguide/list-pipelines.html

        :stability: experimental
        '''
        return typing.cast("Elastictranscoder", jsii.invoke(self, "toListPipelines", []))

    @jsii.member(jsii_name="toListPresets")
    def to_list_presets(self) -> "Elastictranscoder":
        '''(experimental) Get a list of all presets associated with the current AWS account.

        Access Level: List

        https://docs.aws.amazon.com/elastictranscoder/latest/developerguide/list-presets.html

        :stability: experimental
        '''
        return typing.cast("Elastictranscoder", jsii.invoke(self, "toListPresets", []))

    @jsii.member(jsii_name="toReadJob")
    def to_read_job(self) -> "Elastictranscoder":
        '''(experimental) Get detailed information about a job.

        Access Level: Read

        https://docs.aws.amazon.com/elastictranscoder/latest/developerguide/get-job.html

        :stability: experimental
        '''
        return typing.cast("Elastictranscoder", jsii.invoke(self, "toReadJob", []))

    @jsii.member(jsii_name="toReadPipeline")
    def to_read_pipeline(self) -> "Elastictranscoder":
        '''(experimental) Get detailed information about a pipeline.

        Access Level: Read

        https://docs.aws.amazon.com/elastictranscoder/latest/developerguide/get-pipeline.html

        :stability: experimental
        '''
        return typing.cast("Elastictranscoder", jsii.invoke(self, "toReadPipeline", []))

    @jsii.member(jsii_name="toReadPreset")
    def to_read_preset(self) -> "Elastictranscoder":
        '''(experimental) Get detailed information about a preset.

        Access Level: Read

        https://docs.aws.amazon.com/elastictranscoder/latest/developerguide/get-preset.html

        :stability: experimental
        '''
        return typing.cast("Elastictranscoder", jsii.invoke(self, "toReadPreset", []))

    @jsii.member(jsii_name="toTestRole")
    def to_test_role(self) -> "Elastictranscoder":
        '''(experimental) Test the settings for a pipeline to ensure that Elastic Transcoder can create and process jobs.

        Access Level: Write

        https://docs.aws.amazon.com/elastictranscoder/latest/developerguide/test-pipeline-role.html

        :stability: experimental
        '''
        return typing.cast("Elastictranscoder", jsii.invoke(self, "toTestRole", []))

    @jsii.member(jsii_name="toUpdatePipeline")
    def to_update_pipeline(self) -> "Elastictranscoder":
        '''(experimental) Update settings for a pipeline.

        Access Level: Write

        https://docs.aws.amazon.com/elastictranscoder/latest/developerguide/update-pipeline.html

        :stability: experimental
        '''
        return typing.cast("Elastictranscoder", jsii.invoke(self, "toUpdatePipeline", []))

    @jsii.member(jsii_name="toUpdatePipelineNotifications")
    def to_update_pipeline_notifications(self) -> "Elastictranscoder":
        '''(experimental) Update only Amazon Simple Notification Service (Amazon SNS) notifications for a pipeline.

        Access Level: Write

        https://docs.aws.amazon.com/elastictranscoder/latest/developerguide/update-pipeline-notifications.html

        :stability: experimental
        '''
        return typing.cast("Elastictranscoder", jsii.invoke(self, "toUpdatePipelineNotifications", []))

    @jsii.member(jsii_name="toUpdatePipelineStatus")
    def to_update_pipeline_status(self) -> "Elastictranscoder":
        '''(experimental) Pause or reactivate a pipeline, so the pipeline stops or restarts processing jobs, update the status for the pipeline.

        Access Level: Write

        https://docs.aws.amazon.com/elastictranscoder/latest/developerguide/update-pipeline-status.html

        :stability: experimental
        '''
        return typing.cast("Elastictranscoder", jsii.invoke(self, "toUpdatePipelineStatus", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c26bff5df588aa42555ba49400e3bda1a799b1d0d5f0a34ff32bf09797e9161a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4ad17ca822bce6c6cfbccb9f3d524fcbe6600bce3c85c2751c2b288c48523552)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class ElementalActivations(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.ElementalActivations",
):
    '''(experimental) Statement provider for service `elemental-activations <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awselementalappliancesandsoftwareactivationservice.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `elemental-activations <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awselementalappliancesandsoftwareactivationservice.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onActivation")
    def on_activation(
        self,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "ElementalActivations":
        '''(experimental) Adds a resource of type activation to the statement.

        https://docs.aws.amazon.com/elemental-appliances-software/

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a8ad327aebf338309658f03c2207d19bc7be7f62fa033a2cfd39e597da94de58)
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("ElementalActivations", jsii.invoke(self, "onActivation", [resource_id, account, region, partition]))

    @jsii.member(jsii_name="toCompleteAccountRegistration")
    def to_complete_account_registration(self) -> "ElementalActivations":
        '''(experimental) Grants permission to complete the process of registering customer account for AWS Elemental Appliances and Software Purchases.

        Access Level: Read

        https://docs.aws.amazon.com/elemental-appliances-software/

        :stability: experimental
        '''
        return typing.cast("ElementalActivations", jsii.invoke(self, "toCompleteAccountRegistration", []))

    @jsii.member(jsii_name="toCompleteFileUpload")
    def to_complete_file_upload(self) -> "ElementalActivations":
        '''(experimental) Grants permission to complete the process of uploading a Software file for AWS Elemental Appliances and Software Purchases.

        Access Level: Read

        https://docs.aws.amazon.com/elemental-appliances-software/

        :stability: experimental
        '''
        return typing.cast("ElementalActivations", jsii.invoke(self, "toCompleteFileUpload", []))

    @jsii.member(jsii_name="toDownloadSoftware")
    def to_download_software(self) -> "ElementalActivations":
        '''(experimental) Grants permission to download the Software files for AWS Elemental Appliances and Software Purchases.

        Access Level: Read

        https://docs.aws.amazon.com/elemental-appliances-software/

        :stability: experimental
        '''
        return typing.cast("ElementalActivations", jsii.invoke(self, "toDownloadSoftware", []))

    @jsii.member(jsii_name="toGenerateLicenses")
    def to_generate_licenses(self) -> "ElementalActivations":
        '''(experimental) Grants permission to generate Software Licenses for AWS Elemental Appliances and Software Purchases.

        Access Level: Read

        https://docs.aws.amazon.com/elemental-appliances-software/

        :stability: experimental
        '''
        return typing.cast("ElementalActivations", jsii.invoke(self, "toGenerateLicenses", []))

    @jsii.member(jsii_name="toGetActivation")
    def to_get_activation(self) -> "ElementalActivations":
        '''(experimental) Grants permission to describe an activation.

        Access Level: Read

        https://docs.aws.amazon.com/elemental-appliances-software/

        :stability: experimental
        '''
        return typing.cast("ElementalActivations", jsii.invoke(self, "toGetActivation", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "ElementalActivations":
        '''(experimental) Grants permission to list tags for an AWS Elemental Activations resource.

        Access Level: Read

        https://docs.aws.amazon.com/elemental-appliances-software/

        :stability: experimental
        '''
        return typing.cast("ElementalActivations", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toStartAccountRegistration")
    def to_start_account_registration(self) -> "ElementalActivations":
        '''(experimental) Grants permission to start the process of registering customer account for AWS Elemental Appliances and Software Purchases.

        Access Level: Read

        https://docs.aws.amazon.com/elemental-appliances-software/

        :stability: experimental
        '''
        return typing.cast("ElementalActivations", jsii.invoke(self, "toStartAccountRegistration", []))

    @jsii.member(jsii_name="toStartFileUpload")
    def to_start_file_upload(self) -> "ElementalActivations":
        '''(experimental) Grants permission to start the process of uploading a Software file for AWS Elemental Appliances and Software Purchases.

        Access Level: Read

        https://docs.aws.amazon.com/elemental-appliances-software/

        :stability: experimental
        '''
        return typing.cast("ElementalActivations", jsii.invoke(self, "toStartFileUpload", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "ElementalActivations":
        '''(experimental) Grants permission to add a tag for an AWS Elemental Activations resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()
        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/elemental-appliances-software/

        :stability: experimental
        '''
        return typing.cast("ElementalActivations", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "ElementalActivations":
        '''(experimental) Grants permission to remove a tag from an AWS Elemental Activations resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/elemental-appliances-software/

        :stability: experimental
        '''
        return typing.cast("ElementalActivations", jsii.invoke(self, "toUntagResource", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__47b531f040b8333c863dfcdbbe3fb423f0995ecb932707dceae273c87b8b994a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0b2edc6efcd1855ddfb4a3fe2c3a1d53479f4938e1901fbbcb8f33824f3df48e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class ElementalAppliancesSoftware(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.ElementalAppliancesSoftware",
):
    '''(experimental) Statement provider for service `elemental-appliances-software <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awselementalappliancesandsoftware.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `elemental-appliances-software <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awselementalappliancesandsoftware.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onQuote")
    def on_quote(
        self,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "ElementalAppliancesSoftware":
        '''(experimental) Adds a resource of type quote to the statement.

        https://docs.aws.amazon.com/elemental-appliances-software

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3726430a62433513b9d09a1aa387fe17396a5cffce24c59f3825be0ccf4dc195)
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("ElementalAppliancesSoftware", jsii.invoke(self, "onQuote", [resource_id, account, region, partition]))

    @jsii.member(jsii_name="toCompleteUpload")
    def to_complete_upload(self) -> "ElementalAppliancesSoftware":
        '''(experimental) Grants permission to complete an upload of an attachment for a quote or order.

        Access Level: Write

        https://docs.aws.amazon.com/elemental-appliances-software

        :stability: experimental
        '''
        return typing.cast("ElementalAppliancesSoftware", jsii.invoke(self, "toCompleteUpload", []))

    @jsii.member(jsii_name="toCreateOrderV1")
    def to_create_order_v1(self) -> "ElementalAppliancesSoftware":
        '''(experimental) Grants permission to create an order.

        Access Level: Write

        https://docs.aws.amazon.com/elemental-appliances-software

        :stability: experimental
        '''
        return typing.cast("ElementalAppliancesSoftware", jsii.invoke(self, "toCreateOrderV1", []))

    @jsii.member(jsii_name="toCreateQuote")
    def to_create_quote(self) -> "ElementalAppliancesSoftware":
        '''(experimental) Grants permission to create a quote.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/elemental-appliances-software

        :stability: experimental
        '''
        return typing.cast("ElementalAppliancesSoftware", jsii.invoke(self, "toCreateQuote", []))

    @jsii.member(jsii_name="toGetAvsCorrectAddress")
    def to_get_avs_correct_address(self) -> "ElementalAppliancesSoftware":
        '''(experimental) Grants permission to validate an address.

        Access Level: Read

        https://docs.aws.amazon.com/elemental-appliances-software

        :stability: experimental
        '''
        return typing.cast("ElementalAppliancesSoftware", jsii.invoke(self, "toGetAvsCorrectAddress", []))

    @jsii.member(jsii_name="toGetBillingAddresses")
    def to_get_billing_addresses(self) -> "ElementalAppliancesSoftware":
        '''(experimental) Grants permission to list the billing addresses in the user account.

        Access Level: Read

        https://docs.aws.amazon.com/elemental-appliances-software

        :stability: experimental
        '''
        return typing.cast("ElementalAppliancesSoftware", jsii.invoke(self, "toGetBillingAddresses", []))

    @jsii.member(jsii_name="toGetDeliveryAddressesV2")
    def to_get_delivery_addresses_v2(self) -> "ElementalAppliancesSoftware":
        '''(experimental) Grants permission to list the delivery addresses in the user account.

        Access Level: Read

        https://docs.aws.amazon.com/elemental-appliances-software

        :stability: experimental
        '''
        return typing.cast("ElementalAppliancesSoftware", jsii.invoke(self, "toGetDeliveryAddressesV2", []))

    @jsii.member(jsii_name="toGetOrder")
    def to_get_order(self) -> "ElementalAppliancesSoftware":
        '''(experimental) Grants permission to describe an order.

        Access Level: Read

        https://docs.aws.amazon.com/elemental-appliances-software

        :stability: experimental
        '''
        return typing.cast("ElementalAppliancesSoftware", jsii.invoke(self, "toGetOrder", []))

    @jsii.member(jsii_name="toGetOrdersV2")
    def to_get_orders_v2(self) -> "ElementalAppliancesSoftware":
        '''(experimental) Grants permission to list the orders in the user account.

        Access Level: Read

        https://docs.aws.amazon.com/elemental-appliances-software

        :stability: experimental
        '''
        return typing.cast("ElementalAppliancesSoftware", jsii.invoke(self, "toGetOrdersV2", []))

    @jsii.member(jsii_name="toGetQuote")
    def to_get_quote(self) -> "ElementalAppliancesSoftware":
        '''(experimental) Grants permission to describe a quote.

        Access Level: Read

        https://docs.aws.amazon.com/elemental-appliances-software

        :stability: experimental
        '''
        return typing.cast("ElementalAppliancesSoftware", jsii.invoke(self, "toGetQuote", []))

    @jsii.member(jsii_name="toGetTaxes")
    def to_get_taxes(self) -> "ElementalAppliancesSoftware":
        '''(experimental) Grants permission to calculate taxes for an order.

        Access Level: Read

        https://docs.aws.amazon.com/elemental-appliances-software

        :stability: experimental
        '''
        return typing.cast("ElementalAppliancesSoftware", jsii.invoke(self, "toGetTaxes", []))

    @jsii.member(jsii_name="toListQuotes")
    def to_list_quotes(self) -> "ElementalAppliancesSoftware":
        '''(experimental) Grants permission to list the quotes in the user account.

        Access Level: List

        https://docs.aws.amazon.com/elemental-appliances-software

        :stability: experimental
        '''
        return typing.cast("ElementalAppliancesSoftware", jsii.invoke(self, "toListQuotes", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "ElementalAppliancesSoftware":
        '''(experimental) Grants permission to lists tags for an AWS Elemental Appliances and Software resource.

        Access Level: Read

        https://docs.aws.amazon.com/elemental-appliances-software

        :stability: experimental
        '''
        return typing.cast("ElementalAppliancesSoftware", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toStartUpload")
    def to_start_upload(self) -> "ElementalAppliancesSoftware":
        '''(experimental) Grants permission to start an upload of an attachment for a quote or order.

        Access Level: Write

        https://docs.aws.amazon.com/elemental-appliances-software

        :stability: experimental
        '''
        return typing.cast("ElementalAppliancesSoftware", jsii.invoke(self, "toStartUpload", []))

    @jsii.member(jsii_name="toSubmitOrderV1")
    def to_submit_order_v1(self) -> "ElementalAppliancesSoftware":
        '''(experimental) Grants permission to submit an order.

        Access Level: Write

        https://docs.aws.amazon.com/elemental-appliances-software

        :stability: experimental
        '''
        return typing.cast("ElementalAppliancesSoftware", jsii.invoke(self, "toSubmitOrderV1", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "ElementalAppliancesSoftware":
        '''(experimental) Grants permission to tag an AWS Elemental Appliances and Software resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/elemental-appliances-software

        :stability: experimental
        '''
        return typing.cast("ElementalAppliancesSoftware", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "ElementalAppliancesSoftware":
        '''(experimental) Grants permission to remove a tag from an AWS Elemental Appliances and Software resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/elemental-appliances-software

        :stability: experimental
        '''
        return typing.cast("ElementalAppliancesSoftware", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateQuote")
    def to_update_quote(self) -> "ElementalAppliancesSoftware":
        '''(experimental) Grants permission to modify a quote.

        Access Level: Write

        https://docs.aws.amazon.com/elemental-appliances-software

        :stability: experimental
        '''
        return typing.cast("ElementalAppliancesSoftware", jsii.invoke(self, "toUpdateQuote", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ae22720ecc6790686bd579af64b1a8d12a4bb1add566a0d95c7e33e1e20982e7)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d4a75e13805734336f037d40ae34aab7ec2c281b1f72ad0160d33104131a9d42)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class ElementalSupportCases(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.ElementalSupportCases",
):
    '''(experimental) Statement provider for service `elemental-support-cases <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awselementalsupportcases.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `elemental-support-cases <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awselementalsupportcases.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="toCheckCasePermission")
    def to_check_case_permission(self) -> "ElementalSupportCases":
        '''(experimental) Grants permission to verify whether the caller has the permissions to perform support case operations.

        Access Level: Write

        https://docs.aws.amazon.com/elemental-appliances-software

        :stability: experimental
        '''
        return typing.cast("ElementalSupportCases", jsii.invoke(self, "toCheckCasePermission", []))

    @jsii.member(jsii_name="toCreateCase")
    def to_create_case(self) -> "ElementalSupportCases":
        '''(experimental) Grants permission to create a support case.

        Access Level: Write

        https://docs.aws.amazon.com/elemental-appliances-software

        :stability: experimental
        '''
        return typing.cast("ElementalSupportCases", jsii.invoke(self, "toCreateCase", []))

    @jsii.member(jsii_name="toGetCase")
    def to_get_case(self) -> "ElementalSupportCases":
        '''(experimental) Grants permission to describe a support case in your account.

        Access Level: Read

        https://docs.aws.amazon.com/elemental-appliances-software

        :stability: experimental
        '''
        return typing.cast("ElementalSupportCases", jsii.invoke(self, "toGetCase", []))

    @jsii.member(jsii_name="toGetCases")
    def to_get_cases(self) -> "ElementalSupportCases":
        '''(experimental) Grants permission to list the support cases in your account.

        Access Level: Read

        https://docs.aws.amazon.com/elemental-appliances-software

        :stability: experimental
        '''
        return typing.cast("ElementalSupportCases", jsii.invoke(self, "toGetCases", []))

    @jsii.member(jsii_name="toUpdateCase")
    def to_update_case(self) -> "ElementalSupportCases":
        '''(experimental) Grants permission to update a support case.

        Access Level: Write

        https://docs.aws.amazon.com/elemental-appliances-software

        :stability: experimental
        '''
        return typing.cast("ElementalSupportCases", jsii.invoke(self, "toUpdateCase", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2158913393069dde7f720590760f7c079a7e116fd54e10b543e485b3498780b3)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d6eb4add344444b62ae4c046d429f0b20be421e7d7a278d91b4dadea22973f7d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class ElementalSupportContent(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.ElementalSupportContent",
):
    '''(experimental) Statement provider for service `elemental-support-content <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awselementalsupportcontent.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `elemental-support-content <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awselementalsupportcontent.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="toQuery")
    def to_query(self) -> "ElementalSupportContent":
        '''(experimental) Grants permission to search support content.

        Access Level: Read

        https://docs.aws.amazon.com/elemental-appliances-software

        :stability: experimental
        '''
        return typing.cast("ElementalSupportContent", jsii.invoke(self, "toQuery", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b02730acb3e81f68c0febab3bac40557a6869411b255480f012d4b9378b447d1)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7b6ffaaf04214e77c7ae71c00718f79acfcd3b623e5959235b5f12504fc61fb9)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class EmrContainers(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.EmrContainers",
):
    '''(experimental) Statement provider for service `emr-containers <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonemroneksemrcontainers.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `emr-containers <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonemroneksemrcontainers.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="ifExecutionRoleArn")
    def if_execution_role_arn(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "EmrContainers":
        '''(experimental) Filters access by the execution role arn present in the request.

        https://docs.aws.amazon.com/emr/latest/EMR-on-EKS-DevelopmentGuide/iam-execution-role.html

        Applies to actions:

        - .toCreateManagedEndpoint()
        - .toStartJobRun()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__747f2ea1a47a5f91db7d7e43f6a0fd672bee416b9f0c4f1e6c6c035846483042)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("EmrContainers", jsii.invoke(self, "ifExecutionRoleArn", [value, operator]))

    @jsii.member(jsii_name="ifJobTemplateArn")
    def if_job_template_arn(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "EmrContainers":
        '''(experimental) Filters access by the job template arn present in the request.

        https://docs.aws.amazon.com/emr/latest/EMR-on-EKS-DevelopmentGuide/iam-job-template.html

        Applies to actions:

        - .toStartJobRun()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a4e97ec79c48a9cbddccab27ccd92a5c35b3265fc9a9a07b71cef014cb977442)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("EmrContainers", jsii.invoke(self, "ifJobTemplateArn", [value, operator]))

    @jsii.member(jsii_name="onJobRun")
    def on_job_run(
        self,
        virtual_cluster_id: builtins.str,
        job_run_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "EmrContainers":
        '''(experimental) Adds a resource of type jobRun to the statement.

        https://docs.aws.amazon.com/emr/latest/EMR-on-EKS-DevelopmentGuide/job-runs.html

        :param virtual_cluster_id: - Identifier for the virtualClusterId.
        :param job_run_id: - Identifier for the jobRunId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1e93c23ae6f43d94999b0ec6728df950d801c6084e5a2e42b5a553f56252a946)
            check_type(argname="argument virtual_cluster_id", value=virtual_cluster_id, expected_type=type_hints["virtual_cluster_id"])
            check_type(argname="argument job_run_id", value=job_run_id, expected_type=type_hints["job_run_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("EmrContainers", jsii.invoke(self, "onJobRun", [virtual_cluster_id, job_run_id, account, region, partition]))

    @jsii.member(jsii_name="onJobTemplate")
    def on_job_template(
        self,
        job_template_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "EmrContainers":
        '''(experimental) Adds a resource of type jobTemplate to the statement.

        https://docs.aws.amazon.com/emr/latest/EMR-on-EKS-DevelopmentGuide/job-templates.html

        :param job_template_id: - Identifier for the jobTemplateId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5919fdbba9647301211de3bd118cd5bca50ab9c0f3e109fcb82eebb905730e22)
            check_type(argname="argument job_template_id", value=job_template_id, expected_type=type_hints["job_template_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("EmrContainers", jsii.invoke(self, "onJobTemplate", [job_template_id, account, region, partition]))

    @jsii.member(jsii_name="onManagedEndpoint")
    def on_managed_endpoint(
        self,
        virtual_cluster_id: builtins.str,
        endpoint_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "EmrContainers":
        '''(experimental) Adds a resource of type managedEndpoint to the statement.

        https://docs.aws.amazon.com/emr/latest/ManagementGuide/emr-studio-create-eks-cluster.html#emr-studio-create-managed-endpoint

        :param virtual_cluster_id: - Identifier for the virtualClusterId.
        :param endpoint_id: - Identifier for the endpointId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__dd650b03770c635ecdb5eb79af82772a8cdf2ad139c6387bae7f9d199328f25e)
            check_type(argname="argument virtual_cluster_id", value=virtual_cluster_id, expected_type=type_hints["virtual_cluster_id"])
            check_type(argname="argument endpoint_id", value=endpoint_id, expected_type=type_hints["endpoint_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("EmrContainers", jsii.invoke(self, "onManagedEndpoint", [virtual_cluster_id, endpoint_id, account, region, partition]))

    @jsii.member(jsii_name="onVirtualCluster")
    def on_virtual_cluster(
        self,
        virtual_cluster_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "EmrContainers":
        '''(experimental) Adds a resource of type virtualCluster to the statement.

        https://docs.aws.amazon.com/emr/latest/EMR-on-EKS-DevelopmentGuide/virtual-cluster.html

        :param virtual_cluster_id: - Identifier for the virtualClusterId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e609f6f5b9813124cc8466a0565b06a00f6ce4ae2f12401178e7e96b349bf37c)
            check_type(argname="argument virtual_cluster_id", value=virtual_cluster_id, expected_type=type_hints["virtual_cluster_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("EmrContainers", jsii.invoke(self, "onVirtualCluster", [virtual_cluster_id, account, region, partition]))

    @jsii.member(jsii_name="toCancelJobRun")
    def to_cancel_job_run(self) -> "EmrContainers":
        '''(experimental) Grants permission to cancel a job run.

        Access Level: Write

        https://docs.aws.amazon.com/emr-on-eks/latest/APIReference/API_CancelJobRun.html

        :stability: experimental
        '''
        return typing.cast("EmrContainers", jsii.invoke(self, "toCancelJobRun", []))

    @jsii.member(jsii_name="toCreateJobTemplate")
    def to_create_job_template(self) -> "EmrContainers":
        '''(experimental) Grants permission to create a job template.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/emr-on-eks/latest/APIReference/API_CreateJobTemplate.html

        :stability: experimental
        '''
        return typing.cast("EmrContainers", jsii.invoke(self, "toCreateJobTemplate", []))

    @jsii.member(jsii_name="toCreateManagedEndpoint")
    def to_create_managed_endpoint(self) -> "EmrContainers":
        '''(experimental) Grants permission to create a managed endpoint.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifExecutionRoleArn()

        https://docs.aws.amazon.com/emr-on-eks/latest/APIReference/API_CreateManagedEndpoint.html

        :stability: experimental
        '''
        return typing.cast("EmrContainers", jsii.invoke(self, "toCreateManagedEndpoint", []))

    @jsii.member(jsii_name="toCreateVirtualCluster")
    def to_create_virtual_cluster(self) -> "EmrContainers":
        '''(experimental) Grants permission to create a virtual cluster.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/emr-on-eks/latest/APIReference/API_CreateVirtualCluster.html

        :stability: experimental
        '''
        return typing.cast("EmrContainers", jsii.invoke(self, "toCreateVirtualCluster", []))

    @jsii.member(jsii_name="toDeleteJobTemplate")
    def to_delete_job_template(self) -> "EmrContainers":
        '''(experimental) Grants permission to delete a job template.

        Access Level: Write

        https://docs.aws.amazon.com/emr-on-eks/latest/APIReference/API_DeleteJobTemplate.html

        :stability: experimental
        '''
        return typing.cast("EmrContainers", jsii.invoke(self, "toDeleteJobTemplate", []))

    @jsii.member(jsii_name="toDeleteManagedEndpoint")
    def to_delete_managed_endpoint(self) -> "EmrContainers":
        '''(experimental) Grants permission to delete a managed endpoint.

        Access Level: Write

        https://docs.aws.amazon.com/emr-on-eks/latest/APIReference/API_DeleteManagedEndpoint.html

        :stability: experimental
        '''
        return typing.cast("EmrContainers", jsii.invoke(self, "toDeleteManagedEndpoint", []))

    @jsii.member(jsii_name="toDeleteVirtualCluster")
    def to_delete_virtual_cluster(self) -> "EmrContainers":
        '''(experimental) Grants permission to delete a virtual cluster.

        Access Level: Write

        https://docs.aws.amazon.com/emr-on-eks/latest/APIReference/API_DeleteVirtualCluster.html

        :stability: experimental
        '''
        return typing.cast("EmrContainers", jsii.invoke(self, "toDeleteVirtualCluster", []))

    @jsii.member(jsii_name="toDescribeJobRun")
    def to_describe_job_run(self) -> "EmrContainers":
        '''(experimental) Grants permission to describe a job run.

        Access Level: Read

        https://docs.aws.amazon.com/emr-on-eks/latest/APIReference/API_DescribeJobRun.html

        :stability: experimental
        '''
        return typing.cast("EmrContainers", jsii.invoke(self, "toDescribeJobRun", []))

    @jsii.member(jsii_name="toDescribeJobTemplate")
    def to_describe_job_template(self) -> "EmrContainers":
        '''(experimental) Grants permission to describe a job template.

        Access Level: Read

        https://docs.aws.amazon.com/emr-on-eks/latest/APIReference/API_DescribeJobTemplate.html

        :stability: experimental
        '''
        return typing.cast("EmrContainers", jsii.invoke(self, "toDescribeJobTemplate", []))

    @jsii.member(jsii_name="toDescribeManagedEndpoint")
    def to_describe_managed_endpoint(self) -> "EmrContainers":
        '''(experimental) Grants permission to describe a managed endpoint.

        Access Level: Read

        https://docs.aws.amazon.com/emr-on-eks/latest/APIReference/API_DescribeManagedEndpoint.html

        :stability: experimental
        '''
        return typing.cast("EmrContainers", jsii.invoke(self, "toDescribeManagedEndpoint", []))

    @jsii.member(jsii_name="toDescribeVirtualCluster")
    def to_describe_virtual_cluster(self) -> "EmrContainers":
        '''(experimental) Grants permission to describe a virtual cluster.

        Access Level: Read

        https://docs.aws.amazon.com/emr-on-eks/latest/APIReference/API_DescribeVirtualCluster.html

        :stability: experimental
        '''
        return typing.cast("EmrContainers", jsii.invoke(self, "toDescribeVirtualCluster", []))

    @jsii.member(jsii_name="toListJobRuns")
    def to_list_job_runs(self) -> "EmrContainers":
        '''(experimental) Grants permission to list job runs associated with a virtual cluster.

        Access Level: List

        https://docs.aws.amazon.com/emr-on-eks/latest/APIReference/API_ListJobRuns.html

        :stability: experimental
        '''
        return typing.cast("EmrContainers", jsii.invoke(self, "toListJobRuns", []))

    @jsii.member(jsii_name="toListJobTemplates")
    def to_list_job_templates(self) -> "EmrContainers":
        '''(experimental) Grants permission to list job templates.

        Access Level: List

        https://docs.aws.amazon.com/emr-on-eks/latest/APIReference/API_ListJobTemplates.html

        :stability: experimental
        '''
        return typing.cast("EmrContainers", jsii.invoke(self, "toListJobTemplates", []))

    @jsii.member(jsii_name="toListManagedEndpoints")
    def to_list_managed_endpoints(self) -> "EmrContainers":
        '''(experimental) Grants permission to list managed endpoints associated with a virtual cluster.

        Access Level: List

        https://docs.aws.amazon.com/emr-on-eks/latest/APIReference/API_ListManagedEndpoints.html

        :stability: experimental
        '''
        return typing.cast("EmrContainers", jsii.invoke(self, "toListManagedEndpoints", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "EmrContainers":
        '''(experimental) Grants permission to list tags for the specified resource.

        Access Level: List

        https://docs.aws.amazon.com/emr-on-eks/latest/APIReference/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("EmrContainers", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toListVirtualClusters")
    def to_list_virtual_clusters(self) -> "EmrContainers":
        '''(experimental) Grants permission to list virtual clusters.

        Access Level: List

        https://docs.aws.amazon.com/emr-on-eks/latest/APIReference/API_ListVirtualClusters.html

        :stability: experimental
        '''
        return typing.cast("EmrContainers", jsii.invoke(self, "toListVirtualClusters", []))

    @jsii.member(jsii_name="toStartJobRun")
    def to_start_job_run(self) -> "EmrContainers":
        '''(experimental) Grants permission to start a job run.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifExecutionRoleArn()
        - .ifJobTemplateArn()

        https://docs.aws.amazon.com/emr-on-eks/latest/APIReference/API_StartJobRun.html

        :stability: experimental
        '''
        return typing.cast("EmrContainers", jsii.invoke(self, "toStartJobRun", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "EmrContainers":
        '''(experimental) Grants permission to tag the specified resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/emr-on-eks/latest/APIReference/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("EmrContainers", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "EmrContainers":
        '''(experimental) Grants permission to untag the specified resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/emr-on-eks/latest/APIReference/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("EmrContainers", jsii.invoke(self, "toUntagResource", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ed4528bf93bd68332b5361c973a6100c396b96e7c3edba1521a5048b8eea6801)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e8b3e2d2ac9707ab23accc8546a992bce6e3435224434cb45fd24612c76cc81d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class EmrServerless(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.EmrServerless",
):
    '''(experimental) Statement provider for service `emr-serverless <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonemrserverless.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `emr-serverless <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonemrserverless.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onApplication")
    def on_application(
        self,
        application_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "EmrServerless":
        '''(experimental) Adds a resource of type application to the statement.

        https://docs.aws.amazon.com/emr/latest/EMR-Serverless-UserGuide/emr-serverless.html

        :param application_id: - Identifier for the applicationId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5174d1a196a32ee1e8065ffbfe26e38a3cfda90c1e6f680f21577165fbe81efb)
            check_type(argname="argument application_id", value=application_id, expected_type=type_hints["application_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("EmrServerless", jsii.invoke(self, "onApplication", [application_id, account, region, partition]))

    @jsii.member(jsii_name="onJobRun")
    def on_job_run(
        self,
        application_id: builtins.str,
        job_run_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "EmrServerless":
        '''(experimental) Adds a resource of type jobRun to the statement.

        https://docs.aws.amazon.com/emr/latest/EMR-Serverless-UserGuide/emr-serverless.html

        :param application_id: - Identifier for the applicationId.
        :param job_run_id: - Identifier for the jobRunId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6792e2eba86cc220f6ec49afb721f00e988c4809431cc3a0b785e1e209de71ef)
            check_type(argname="argument application_id", value=application_id, expected_type=type_hints["application_id"])
            check_type(argname="argument job_run_id", value=job_run_id, expected_type=type_hints["job_run_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("EmrServerless", jsii.invoke(self, "onJobRun", [application_id, job_run_id, account, region, partition]))

    @jsii.member(jsii_name="toCancelJobRun")
    def to_cancel_job_run(self) -> "EmrServerless":
        '''(experimental) Grants permission to cancel a job run.

        Access Level: Write

        https://docs.aws.amazon.com/emr-serverless/latest/APIReference/API_CancelJobRun.html

        :stability: experimental
        '''
        return typing.cast("EmrServerless", jsii.invoke(self, "toCancelJobRun", []))

    @jsii.member(jsii_name="toCreateApplication")
    def to_create_application(self) -> "EmrServerless":
        '''(experimental) Grants permission to create an Application.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/emr-serverless/latest/APIReference/API_CreateApplication.html

        :stability: experimental
        '''
        return typing.cast("EmrServerless", jsii.invoke(self, "toCreateApplication", []))

    @jsii.member(jsii_name="toDeleteApplication")
    def to_delete_application(self) -> "EmrServerless":
        '''(experimental) Grants permission to delete an application.

        Access Level: Write

        https://docs.aws.amazon.com/emr-serverless/latest/APIReference/API_DeleteApplication.html

        :stability: experimental
        '''
        return typing.cast("EmrServerless", jsii.invoke(self, "toDeleteApplication", []))

    @jsii.member(jsii_name="toGetApplication")
    def to_get_application(self) -> "EmrServerless":
        '''(experimental) Grants permission to get application.

        Access Level: Read

        https://docs.aws.amazon.com/emr-serverless/latest/APIReference/API_GetApplication.html

        :stability: experimental
        '''
        return typing.cast("EmrServerless", jsii.invoke(self, "toGetApplication", []))

    @jsii.member(jsii_name="toGetDashboardForJobRun")
    def to_get_dashboard_for_job_run(self) -> "EmrServerless":
        '''(experimental) Grants permission to get job run dashboard.

        Access Level: Read

        https://docs.aws.amazon.com/emr-serverless/latest/APIReference/API_GetDashboardForJobRun.html

        :stability: experimental
        '''
        return typing.cast("EmrServerless", jsii.invoke(self, "toGetDashboardForJobRun", []))

    @jsii.member(jsii_name="toGetJobRun")
    def to_get_job_run(self) -> "EmrServerless":
        '''(experimental) Grants permission to get a job run.

        Access Level: Read

        https://docs.aws.amazon.com/emr-serverless/latest/APIReference/API_GetJobRun.html

        :stability: experimental
        '''
        return typing.cast("EmrServerless", jsii.invoke(self, "toGetJobRun", []))

    @jsii.member(jsii_name="toListApplications")
    def to_list_applications(self) -> "EmrServerless":
        '''(experimental) Grants permission to list applications.

        Access Level: List

        https://docs.aws.amazon.com/emr-serverless/latest/APIReference/API_ListApplications.html

        :stability: experimental
        '''
        return typing.cast("EmrServerless", jsii.invoke(self, "toListApplications", []))

    @jsii.member(jsii_name="toListJobRuns")
    def to_list_job_runs(self) -> "EmrServerless":
        '''(experimental) Grants permission to list job runs associated with an application.

        Access Level: List

        https://docs.aws.amazon.com/emr-serverless/latest/APIReference/API_ListJobRuns.html

        :stability: experimental
        '''
        return typing.cast("EmrServerless", jsii.invoke(self, "toListJobRuns", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "EmrServerless":
        '''(experimental) Grants permission to list tags for the specified resource.

        Access Level: Read

        https://docs.aws.amazon.com/emr-serverless/latest/APIReference/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("EmrServerless", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toStartApplication")
    def to_start_application(self) -> "EmrServerless":
        '''(experimental) Grants permission to Start an application.

        Access Level: Write

        https://docs.aws.amazon.com/emr-serverless/latest/APIReference/API_StartApplication.html

        :stability: experimental
        '''
        return typing.cast("EmrServerless", jsii.invoke(self, "toStartApplication", []))

    @jsii.member(jsii_name="toStartJobRun")
    def to_start_job_run(self) -> "EmrServerless":
        '''(experimental) Grants permission to start a job run.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - iam:PassRole

        https://docs.aws.amazon.com/emr-serverless/latest/APIReference/API_StartJobRun.html

        :stability: experimental
        '''
        return typing.cast("EmrServerless", jsii.invoke(self, "toStartJobRun", []))

    @jsii.member(jsii_name="toStopApplication")
    def to_stop_application(self) -> "EmrServerless":
        '''(experimental) Grants permission to Stop an application.

        Access Level: Write

        https://docs.aws.amazon.com/emr-serverless/latest/APIReference/API_StopApplication.html

        :stability: experimental
        '''
        return typing.cast("EmrServerless", jsii.invoke(self, "toStopApplication", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "EmrServerless":
        '''(experimental) Grants permission to tag the specified resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/emr-serverless/latest/APIReference/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("EmrServerless", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "EmrServerless":
        '''(experimental) Grants permission to untag the specified resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/emr-serverless/latest/APIReference/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("EmrServerless", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateApplication")
    def to_update_application(self) -> "EmrServerless":
        '''(experimental) Grants permission to Update an application.

        Access Level: Write

        https://docs.aws.amazon.com/emr-serverless/latest/APIReference/API_UpdateApplication.html

        :stability: experimental
        '''
        return typing.cast("EmrServerless", jsii.invoke(self, "toUpdateApplication", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0899f5ee2f437d926b997ad3deb8869e3b415d16f7c0ecf102090ba672a4b7c2)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__01331fd056fd0209610fca3231639d5a86f0e51e6109527a7501c2b8f9aba937)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Es(PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Es"):
    '''(experimental) Statement provider for service `es <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonopensearchservice.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `es <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonopensearchservice.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onDomain")
    def on_domain(
        self,
        domain_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Es":
        '''(experimental) Adds a resource of type domain to the statement.

        https://docs.aws.amazon.com/opensearch-service/latest/developerguide/ac.html

        :param domain_name: - Identifier for the domainName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e774b9ff04a1d1b291b230274ee222f93eb84c695a69422d4ba1c23f66e73177)
            check_type(argname="argument domain_name", value=domain_name, expected_type=type_hints["domain_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Es", jsii.invoke(self, "onDomain", [domain_name, account, region, partition]))

    @jsii.member(jsii_name="onEsRole")
    def on_es_role(
        self,
        account: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Es":
        '''(experimental) Adds a resource of type es_role to the statement.

        https://docs.aws.amazon.com/opensearch-service/latest/developerguide/slr.html

        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__99300366d58701f04351b7c6db3e47c4a7475f130c4f7cee2a3a1f2fbe5f72ea)
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Es", jsii.invoke(self, "onEsRole", [account, partition]))

    @jsii.member(jsii_name="onOpensearchserviceRole")
    def on_opensearchservice_role(
        self,
        account: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Es":
        '''(experimental) Adds a resource of type opensearchservice_role to the statement.

        https://docs.aws.amazon.com/opensearch-service/latest/developerguide/slr.html

        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2d530e789baa385225837453152c3b704087f4acd282f0fa23b89c76707fddb4)
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Es", jsii.invoke(self, "onOpensearchserviceRole", [account, partition]))

    @jsii.member(jsii_name="toAcceptInboundConnection")
    def to_accept_inbound_connection(self) -> "Es":
        '''(experimental) Grants permission to the destination domain owner to accept an inbound cross-cluster search connection request.

        Access Level: Write

        https://docs.aws.amazon.com/opensearch-service/latest/developerguide/configuration-api.html#configuration-api-actions-accept-inbound-cross-cluster-search-connection

        :stability: experimental
        '''
        return typing.cast("Es", jsii.invoke(self, "toAcceptInboundConnection", []))

    @jsii.member(jsii_name="toAcceptInboundCrossClusterSearchConnection")
    def to_accept_inbound_cross_cluster_search_connection(self) -> "Es":
        '''(experimental) Grants permission to the destination domain owner to accept an inbound cross-cluster search connection request.

        This permission is deprecated. Use AcceptInboundConnection instead

        Access Level: Write

        https://docs.aws.amazon.com/opensearch-service/latest/developerguide/configuration-api.html#configuration-api-actions-accept-inbound-cross-cluster-search-connection

        :stability: experimental
        '''
        return typing.cast("Es", jsii.invoke(self, "toAcceptInboundCrossClusterSearchConnection", []))

    @jsii.member(jsii_name="toAddTags")
    def to_add_tags(self) -> "Es":
        '''(experimental) Grants permission to attach resource tags to an OpenSearch Service domain.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/opensearch-service/latest/developerguide/configuration-api.html#configuration-api-actions-addtags

        :stability: experimental
        '''
        return typing.cast("Es", jsii.invoke(self, "toAddTags", []))

    @jsii.member(jsii_name="toAssociatePackage")
    def to_associate_package(self) -> "Es":
        '''(experimental) Grants permission to associate a package with an OpenSearch Service domain.

        Access Level: Write

        https://docs.aws.amazon.com/opensearch-service/latest/developerguide/configuration-api.html#configuration-api-actions-associatepackage

        :stability: experimental
        '''
        return typing.cast("Es", jsii.invoke(self, "toAssociatePackage", []))

    @jsii.member(jsii_name="toCancelElasticsearchServiceSoftwareUpdate")
    def to_cancel_elasticsearch_service_software_update(self) -> "Es":
        '''(experimental) Grants permission to cancel a service software update of a domain. This permission is deprecated. Use CancelServiceSoftwareUpdate instead.

        Access Level: Write

        https://docs.aws.amazon.com/opensearch-service/latest/developerguide/configuration-api.html#configuration-api-actions-stopupdate

        :stability: experimental
        '''
        return typing.cast("Es", jsii.invoke(self, "toCancelElasticsearchServiceSoftwareUpdate", []))

    @jsii.member(jsii_name="toCancelServiceSoftwareUpdate")
    def to_cancel_service_software_update(self) -> "Es":
        '''(experimental) Grants permission to cancel a service software update of a domain.

        Access Level: Write

        https://docs.aws.amazon.com/opensearch-service/latest/developerguide/configuration-api.html#configuration-api-actions-stopupdate

        :stability: experimental
        '''
        return typing.cast("Es", jsii.invoke(self, "toCancelServiceSoftwareUpdate", []))

    @jsii.member(jsii_name="toCreateDomain")
    def to_create_domain(self) -> "Es":
        '''(experimental) Grants permission to create an Amazon OpenSearch Service domain.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/opensearch-service/latest/developerguide/configuration-api.html#configuration-api-actions-createdomain

        :stability: experimental
        '''
        return typing.cast("Es", jsii.invoke(self, "toCreateDomain", []))

    @jsii.member(jsii_name="toCreateElasticsearchDomain")
    def to_create_elasticsearch_domain(self) -> "Es":
        '''(experimental) Grants permission to create an OpenSearch Service domain. This permission is deprecated. Use CreateDomain instead.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/opensearch-service/latest/developerguide/configuration-api.html#configuration-api-actions-createdomain

        :stability: experimental
        '''
        return typing.cast("Es", jsii.invoke(self, "toCreateElasticsearchDomain", []))

    @jsii.member(jsii_name="toCreateElasticsearchServiceRole")
    def to_create_elasticsearch_service_role(self) -> "Es":
        '''(experimental) Grants permission to create the service-linked role required for OpenSearch Service domains that use VPC access.

        This permission is deprecated. OpenSearch Service creates the service-linked role for you

        Access Level: Write

        https://docs.aws.amazon.com/opensearch-service/latest/developerguide/configuration-api.html#configuration-api-actions-createservicerole

        :stability: experimental
        '''
        return typing.cast("Es", jsii.invoke(self, "toCreateElasticsearchServiceRole", []))

    @jsii.member(jsii_name="toCreateOutboundConnection")
    def to_create_outbound_connection(self) -> "Es":
        '''(experimental) Grants permission to create a new cross-cluster search connection from a source domain to a destination domain.

        Access Level: Write

        https://docs.aws.amazon.com/opensearch-service/latest/developerguide/configuration-api.html#configuration-api-actions-create-outbound-cross-cluster-search-connection

        :stability: experimental
        '''
        return typing.cast("Es", jsii.invoke(self, "toCreateOutboundConnection", []))

    @jsii.member(jsii_name="toCreateOutboundCrossClusterSearchConnection")
    def to_create_outbound_cross_cluster_search_connection(self) -> "Es":
        '''(experimental) Grants permission to create a new cross-cluster search connection from a source domain to a destination domain.

        This permission is deprecated. Use CreateOutboundConnection instead

        Access Level: Write

        https://docs.aws.amazon.com/opensearch-service/latest/developerguide/configuration-api.html#configuration-api-actions-create-outbound-cross-cluster-search-connection

        :stability: experimental
        '''
        return typing.cast("Es", jsii.invoke(self, "toCreateOutboundCrossClusterSearchConnection", []))

    @jsii.member(jsii_name="toCreatePackage")
    def to_create_package(self) -> "Es":
        '''(experimental) Grants permission to add a package for use with OpenSearch Service domains.

        Access Level: Write

        https://docs.aws.amazon.com/opensearch-service/latest/developerguide/configuration-api.html#configuration-api-actions-createpackage

        :stability: experimental
        '''
        return typing.cast("Es", jsii.invoke(self, "toCreatePackage", []))

    @jsii.member(jsii_name="toCreateServiceRole")
    def to_create_service_role(self) -> "Es":
        '''(experimental) Grants permission to create the service-linked role required for Amazon OpenSearch Service domains that use VPC access.

        Access Level: Write

        https://docs.aws.amazon.com/opensearch-service/latest/developerguide/configuration-api.html#configuration-api-actions-createservicerole

        :stability: experimental
        '''
        return typing.cast("Es", jsii.invoke(self, "toCreateServiceRole", []))

    @jsii.member(jsii_name="toDeleteDomain")
    def to_delete_domain(self) -> "Es":
        '''(experimental) Grants permission to delete an Amazon OpenSearch Service domain and all of its data.

        Access Level: Write

        https://docs.aws.amazon.com/opensearch-service/latest/developerguide/configuration-api.html#configuration-api-actions-deletedomain

        :stability: experimental
        '''
        return typing.cast("Es", jsii.invoke(self, "toDeleteDomain", []))

    @jsii.member(jsii_name="toDeleteElasticsearchDomain")
    def to_delete_elasticsearch_domain(self) -> "Es":
        '''(experimental) Grants permission to delete an OpenSearch Service domain and all of its data.

        This permission is deprecated. Use DeleteDomain instead

        Access Level: Write

        https://docs.aws.amazon.com/opensearch-service/latest/developerguide/configuration-api.html#configuration-api-actions-deletedomain

        :stability: experimental
        '''
        return typing.cast("Es", jsii.invoke(self, "toDeleteElasticsearchDomain", []))

    @jsii.member(jsii_name="toDeleteElasticsearchServiceRole")
    def to_delete_elasticsearch_service_role(self) -> "Es":
        '''(experimental) Grants permission to delete the service-linked role required for OpenSearch Service domains that use VPC access.

        This permission is deprecated. Use the IAM API to delete service-linked roles

        Access Level: Write

        https://docs.aws.amazon.com/opensearch-service/latest/developerguide/configuration-api.html#configuration-api-actions-deleteservicerole

        :stability: experimental
        '''
        return typing.cast("Es", jsii.invoke(self, "toDeleteElasticsearchServiceRole", []))

    @jsii.member(jsii_name="toDeleteInboundConnection")
    def to_delete_inbound_connection(self) -> "Es":
        '''(experimental) Grants permission to the destination domain owner to delete an existing inbound cross-cluster search connection.

        Access Level: Write

        https://docs.aws.amazon.com/opensearch-service/latest/developerguide/configuration-api.html#configuration-api-actions-delete-inbound-cross-cluster-search-connection

        :stability: experimental
        '''
        return typing.cast("Es", jsii.invoke(self, "toDeleteInboundConnection", []))

    @jsii.member(jsii_name="toDeleteInboundCrossClusterSearchConnection")
    def to_delete_inbound_cross_cluster_search_connection(self) -> "Es":
        '''(experimental) Grants permission to the destination domain owner to delete an existing inbound cross-cluster search connection.

        This permission is deprecated. Use DeleteInboundConnection instead

        Access Level: Write

        https://docs.aws.amazon.com/opensearch-service/latest/developerguide/configuration-api.html#configuration-api-actions-delete-inbound-cross-cluster-search-connection

        :stability: experimental
        '''
        return typing.cast("Es", jsii.invoke(self, "toDeleteInboundCrossClusterSearchConnection", []))

    @jsii.member(jsii_name="toDeleteOutboundConnection")
    def to_delete_outbound_connection(self) -> "Es":
        '''(experimental) Grants permission to the source domain owner to delete an existing outbound cross-cluster search connection.

        Access Level: Write

        https://docs.aws.amazon.com/opensearch-service/latest/developerguide/configuration-api.html#configuration-api-actions-delete-outbound-cross-cluster-search-connection

        :stability: experimental
        '''
        return typing.cast("Es", jsii.invoke(self, "toDeleteOutboundConnection", []))

    @jsii.member(jsii_name="toDeleteOutboundCrossClusterSearchConnection")
    def to_delete_outbound_cross_cluster_search_connection(self) -> "Es":
        '''(experimental) Grants permission to the source domain owner to delete an existing outbound cross-cluster search connection.

        This permission is deprecated. Use DeleteOutboundConnection instead

        Access Level: Write

        https://docs.aws.amazon.com/opensearch-service/latest/developerguide/configuration-api.html#configuration-api-actions-delete-outbound-cross-cluster-search-connection

        :stability: experimental
        '''
        return typing.cast("Es", jsii.invoke(self, "toDeleteOutboundCrossClusterSearchConnection", []))

    @jsii.member(jsii_name="toDeletePackage")
    def to_delete_package(self) -> "Es":
        '''(experimental) Grants permission to delete a package from OpenSearch Service. The package cannot be associated with any domains.

        Access Level: Write

        https://docs.aws.amazon.com/opensearch-service/latest/developerguide/configuration-api.html#configuration-api-actions-deletepackage

        :stability: experimental
        '''
        return typing.cast("Es", jsii.invoke(self, "toDeletePackage", []))

    @jsii.member(jsii_name="toDescribeDomain")
    def to_describe_domain(self) -> "Es":
        '''(experimental) Grants permission to view a description of the domain configuration for the specified OpenSearch Service domain, including the domain ID, service endpoint, and ARN.

        Access Level: Read

        https://docs.aws.amazon.com/opensearch-service/latest/developerguide/configuration-api.html#configuration-api-actions-describedomain

        :stability: experimental
        '''
        return typing.cast("Es", jsii.invoke(self, "toDescribeDomain", []))

    @jsii.member(jsii_name="toDescribeDomainAutoTunes")
    def to_describe_domain_auto_tunes(self) -> "Es":
        '''(experimental) Grants permission to view the Auto-Tune configuration of the domain for the specified OpenSearch Service domain, including the Auto-Tune state and maintenance schedules.

        Access Level: Read

        https://docs.aws.amazon.com/opensearch-service/latest/developerguide/configuration-api.html#configuration-api-actions-describeautotune

        :stability: experimental
        '''
        return typing.cast("Es", jsii.invoke(self, "toDescribeDomainAutoTunes", []))

    @jsii.member(jsii_name="toDescribeDomainChangeProgress")
    def to_describe_domain_change_progress(self) -> "Es":
        '''(experimental) Grants permission to view detail stage progress of an OpenSearch Service domain.

        Access Level: Read

        https://docs.aws.amazon.com/opensearch-service/latest/developerguide/configuration-api.html#configuration-api-actions-describedomainchangeprogress

        :stability: experimental
        '''
        return typing.cast("Es", jsii.invoke(self, "toDescribeDomainChangeProgress", []))

    @jsii.member(jsii_name="toDescribeDomainConfig")
    def to_describe_domain_config(self) -> "Es":
        '''(experimental) Grants permission to view a description of the configuration options and status of an OpenSearch Service domain.

        Access Level: Read

        https://docs.aws.amazon.com/opensearch-service/latest/developerguide/configuration-api.html#configuration-api-actions-describedomainconfig

        :stability: experimental
        '''
        return typing.cast("Es", jsii.invoke(self, "toDescribeDomainConfig", []))

    @jsii.member(jsii_name="toDescribeDomains")
    def to_describe_domains(self) -> "Es":
        '''(experimental) Grants permission to view a description of the domain configuration for up to five specified OpenSearch Service domains.

        Access Level: List

        https://docs.aws.amazon.com/opensearch-service/latest/developerguide/configuration-api.html#configuration-api-actions-describedomains

        :stability: experimental
        '''
        return typing.cast("Es", jsii.invoke(self, "toDescribeDomains", []))

    @jsii.member(jsii_name="toDescribeElasticsearchDomain")
    def to_describe_elasticsearch_domain(self) -> "Es":
        '''(experimental) Grants permission to view a description of the domain configuration for the specified OpenSearch Service domain, including the domain ID, service endpoint, and ARN.

        This permission is deprecated. Use DescribeDomain instead

        Access Level: Read

        https://docs.aws.amazon.com/opensearch-service/latest/developerguide/configuration-api.html#configuration-api-actions-describedomain

        :stability: experimental
        '''
        return typing.cast("Es", jsii.invoke(self, "toDescribeElasticsearchDomain", []))

    @jsii.member(jsii_name="toDescribeElasticsearchDomainConfig")
    def to_describe_elasticsearch_domain_config(self) -> "Es":
        '''(experimental) Grants permission to view a description of the configuration and status of an OpenSearch Service domain.

        This permission is deprecated. Use DescribeDomainConfig instead

        Access Level: Read

        https://docs.aws.amazon.com/opensearch-service/latest/developerguide/configuration-api.html#configuration-api-actions-describedomainconfig

        :stability: experimental
        '''
        return typing.cast("Es", jsii.invoke(self, "toDescribeElasticsearchDomainConfig", []))

    @jsii.member(jsii_name="toDescribeElasticsearchDomains")
    def to_describe_elasticsearch_domains(self) -> "Es":
        '''(experimental) Grants permission to view a description of the domain configuration for up to five specified Amazon OpenSearch domains.

        This permission is deprecated. Use DescribeDomains instead

        Access Level: List

        https://docs.aws.amazon.com/opensearch-service/latest/developerguide/configuration-api.html#configuration-api-actions-describedomains

        :stability: experimental
        '''
        return typing.cast("Es", jsii.invoke(self, "toDescribeElasticsearchDomains", []))

    @jsii.member(jsii_name="toDescribeElasticsearchInstanceTypeLimits")
    def to_describe_elasticsearch_instance_type_limits(self) -> "Es":
        '''(experimental) Grants permission to view the instance count, storage, and master node limits for a given OpenSearch version and instance type.

        This permission is deprecated. Use DescribeInstanceTypeLimits instead

        Access Level: List

        https://docs.aws.amazon.com/opensearch-service/latest/developerguide/configuration-api.html#configuration-api-actions-describeinstancetypelimits

        :stability: experimental
        '''
        return typing.cast("Es", jsii.invoke(self, "toDescribeElasticsearchInstanceTypeLimits", []))

    @jsii.member(jsii_name="toDescribeInboundConnections")
    def to_describe_inbound_connections(self) -> "Es":
        '''(experimental) Grants permission to list all the inbound cross-cluster search connections for a destination domain.

        Access Level: List

        https://docs.aws.amazon.com/opensearch-service/latest/developerguide/configuration-api.html#configuration-api-actions-describe-inbound-cross-cluster-search-connections

        :stability: experimental
        '''
        return typing.cast("Es", jsii.invoke(self, "toDescribeInboundConnections", []))

    @jsii.member(jsii_name="toDescribeInboundCrossClusterSearchConnections")
    def to_describe_inbound_cross_cluster_search_connections(self) -> "Es":
        '''(experimental) Grants permission to list all the inbound cross-cluster search connections for a destination domain.

        This permission is deprecated. Use DescribeInboundConnections instead

        Access Level: List

        https://docs.aws.amazon.com/opensearch-service/latest/developerguide/configuration-api.html#configuration-api-actions-describe-inbound-cross-cluster-search-connections

        :stability: experimental
        '''
        return typing.cast("Es", jsii.invoke(self, "toDescribeInboundCrossClusterSearchConnections", []))

    @jsii.member(jsii_name="toDescribeInstanceTypeLimits")
    def to_describe_instance_type_limits(self) -> "Es":
        '''(experimental) Grants permission to view the instance count, storage, and master node limits for a given engine version and instance type.

        Access Level: List

        https://docs.aws.amazon.com/opensearch-service/latest/developerguide/configuration-api.html#configuration-api-actions-describeinstancetypelimits

        :stability: experimental
        '''
        return typing.cast("Es", jsii.invoke(self, "toDescribeInstanceTypeLimits", []))

    @jsii.member(jsii_name="toDescribeOutboundConnections")
    def to_describe_outbound_connections(self) -> "Es":
        '''(experimental) Grants permission to list all the outbound cross-cluster search connections for a source domain.

        Access Level: List

        https://docs.aws.amazon.com/opensearch-service/latest/developerguide/configuration-api.html#configuration-api-actions-describe-outbound-cross-cluster-search-connections

        :stability: experimental
        '''
        return typing.cast("Es", jsii.invoke(self, "toDescribeOutboundConnections", []))

    @jsii.member(jsii_name="toDescribeOutboundCrossClusterSearchConnections")
    def to_describe_outbound_cross_cluster_search_connections(self) -> "Es":
        '''(experimental) Grants permission to list all the outbound cross-cluster search connections for a source domain.

        This permission is deprecated. Use DescribeOutboundConnections instead

        Access Level: List

        https://docs.aws.amazon.com/opensearch-service/latest/developerguide/configuration-api.html#configuration-api-actions-describe-outbound-cross-cluster-search-connections

        :stability: experimental
        '''
        return typing.cast("Es", jsii.invoke(self, "toDescribeOutboundCrossClusterSearchConnections", []))

    @jsii.member(jsii_name="toDescribePackages")
    def to_describe_packages(self) -> "Es":
        '''(experimental) Grants permission to describe all packages available to OpenSearch Service domains.

        Access Level: Read

        https://docs.aws.amazon.com/opensearch-service/latest/developerguide/configuration-api.html#configuration-api-actions-describepackages

        :stability: experimental
        '''
        return typing.cast("Es", jsii.invoke(self, "toDescribePackages", []))

    @jsii.member(jsii_name="toDescribeReservedElasticsearchInstanceOfferings")
    def to_describe_reserved_elasticsearch_instance_offerings(self) -> "Es":
        '''(experimental) Grants permission to fetch Reserved Instance offerings for Amazon OpenSearch Service. This permission is deprecated. Use DescribeReservedInstanceOfferings instead.

        Access Level: List

        https://docs.aws.amazon.com/opensearch-service/latest/developerguide/configuration-api.html#configuration-api-actions-describereservedinstanceofferings

        :stability: experimental
        '''
        return typing.cast("Es", jsii.invoke(self, "toDescribeReservedElasticsearchInstanceOfferings", []))

    @jsii.member(jsii_name="toDescribeReservedElasticsearchInstances")
    def to_describe_reserved_elasticsearch_instances(self) -> "Es":
        '''(experimental) Grants permission to fetch OpenSearch Service Reserved Instances that have already been purchased.

        This permission is deprecated. Use DescribeReservedInstances instead

        Access Level: List

        https://docs.aws.amazon.com/opensearch-service/latest/developerguide/configuration-api.html#configuration-api-actions-describereservedinstances

        :stability: experimental
        '''
        return typing.cast("Es", jsii.invoke(self, "toDescribeReservedElasticsearchInstances", []))

    @jsii.member(jsii_name="toDescribeReservedInstanceOfferings")
    def to_describe_reserved_instance_offerings(self) -> "Es":
        '''(experimental) Grants permission to fetch Reserved Instance offerings for OpenSearch Service.

        Access Level: List

        https://docs.aws.amazon.com/opensearch-service/latest/developerguide/configuration-api.html#configuration-api-actions-describereservedinstanceofferings

        :stability: experimental
        '''
        return typing.cast("Es", jsii.invoke(self, "toDescribeReservedInstanceOfferings", []))

    @jsii.member(jsii_name="toDescribeReservedInstances")
    def to_describe_reserved_instances(self) -> "Es":
        '''(experimental) Grants permission to fetch OpenSearch Service Reserved Instances that have already been purchased.

        Access Level: List

        https://docs.aws.amazon.com/opensearch-service/latest/developerguide/configuration-api.html#configuration-api-actions-describereservedinstances

        :stability: experimental
        '''
        return typing.cast("Es", jsii.invoke(self, "toDescribeReservedInstances", []))

    @jsii.member(jsii_name="toDissociatePackage")
    def to_dissociate_package(self) -> "Es":
        '''(experimental) Grants permission to disassociate a package from the specified OpenSearch Service domain.

        Access Level: Write

        https://docs.aws.amazon.com/opensearch-service/latest/developerguide/configuration-api.html#configuration-api-actions-dissociatepackage

        :stability: experimental
        '''
        return typing.cast("Es", jsii.invoke(self, "toDissociatePackage", []))

    @jsii.member(jsii_name="toESCrossClusterGet")
    def to_es_cross_cluster_get(self) -> "Es":
        '''(experimental) Grants permission to send cross-cluster requests to a destination domain.

        Access Level: Read

        https://docs.aws.amazon.com/opensearch-service/latest/developerguide/ac.html#ac-reference

        :stability: experimental
        '''
        return typing.cast("Es", jsii.invoke(self, "toESCrossClusterGet", []))

    @jsii.member(jsii_name="toESHttpDelete")
    def to_es_http_delete(self) -> "Es":
        '''(experimental) Grants permission to send HTTP DELETE requests to the OpenSearch APIs.

        Access Level: Write

        https://docs.aws.amazon.com/opensearch-service/latest/developerguide/ac.html#ac-reference

        :stability: experimental
        '''
        return typing.cast("Es", jsii.invoke(self, "toESHttpDelete", []))

    @jsii.member(jsii_name="toESHttpGet")
    def to_es_http_get(self) -> "Es":
        '''(experimental) Grants permission to send HTTP GET requests to the OpenSearch APIs.

        Access Level: Read

        https://docs.aws.amazon.com/opensearch-service/latest/developerguide/ac.html#ac-reference

        :stability: experimental
        '''
        return typing.cast("Es", jsii.invoke(self, "toESHttpGet", []))

    @jsii.member(jsii_name="toESHttpHead")
    def to_es_http_head(self) -> "Es":
        '''(experimental) Grants permission to send HTTP HEAD requests to the OpenSearch APIs.

        Access Level: Read

        https://docs.aws.amazon.com/opensearch-service/latest/developerguide/ac.html#ac-reference

        :stability: experimental
        '''
        return typing.cast("Es", jsii.invoke(self, "toESHttpHead", []))

    @jsii.member(jsii_name="toESHttpPatch")
    def to_es_http_patch(self) -> "Es":
        '''(experimental) Grants permission to send HTTP PATCH requests to the OpenSearch APIs.

        Access Level: Write

        https://docs.aws.amazon.com/opensearch-service/latest/developerguide/ac.html#ac-reference

        :stability: experimental
        '''
        return typing.cast("Es", jsii.invoke(self, "toESHttpPatch", []))

    @jsii.member(jsii_name="toESHttpPost")
    def to_es_http_post(self) -> "Es":
        '''(experimental) Grants permission to send HTTP POST requests to the OpenSearch APIs.

        Access Level: Write

        https://docs.aws.amazon.com/opensearch-service/latest/developerguide/ac.html#ac-reference

        :stability: experimental
        '''
        return typing.cast("Es", jsii.invoke(self, "toESHttpPost", []))

    @jsii.member(jsii_name="toESHttpPut")
    def to_es_http_put(self) -> "Es":
        '''(experimental) Grants permission to send HTTP PUT requests to the OpenSearch APIs.

        Access Level: Write

        https://docs.aws.amazon.com/opensearch-service/latest/developerguide/ac.html#ac-reference

        :stability: experimental
        '''
        return typing.cast("Es", jsii.invoke(self, "toESHttpPut", []))

    @jsii.member(jsii_name="toGetCompatibleElasticsearchVersions")
    def to_get_compatible_elasticsearch_versions(self) -> "Es":
        '''(experimental) Grants permission to fetch a list of compatible OpenSearch and Elasticsearch versions to which an OpenSearch Service domain can be upgraded.

        This permission is deprecated. Use GetCompatibleVersions instead

        Access Level: List

        https://docs.aws.amazon.com/opensearch-service/latest/developerguide/configuration-api.html#configuration-api-actions-get-compat-vers

        :stability: experimental
        '''
        return typing.cast("Es", jsii.invoke(self, "toGetCompatibleElasticsearchVersions", []))

    @jsii.member(jsii_name="toGetCompatibleVersions")
    def to_get_compatible_versions(self) -> "Es":
        '''(experimental) Grants permission to fetch list of compatible engine versions to which an OpenSearch Service domain can be upgraded.

        Access Level: List

        https://docs.aws.amazon.com/opensearch-service/latest/developerguide/configuration-api.html#configuration-api-actions-get-compat-vers

        :stability: experimental
        '''
        return typing.cast("Es", jsii.invoke(self, "toGetCompatibleVersions", []))

    @jsii.member(jsii_name="toGetPackageVersionHistory")
    def to_get_package_version_history(self) -> "Es":
        '''(experimental) Grants permission to fetch the version history for a package.

        Access Level: Read

        https://docs.aws.amazon.com/opensearch-service/latest/developerguide/configuration-api.html#configuration-api-actions-get-pac-ver-hist

        :stability: experimental
        '''
        return typing.cast("Es", jsii.invoke(self, "toGetPackageVersionHistory", []))

    @jsii.member(jsii_name="toGetUpgradeHistory")
    def to_get_upgrade_history(self) -> "Es":
        '''(experimental) Grants permission to fetch the upgrade history of a given OpenSearch Service domain.

        Access Level: Read

        https://docs.aws.amazon.com/opensearch-service/latest/developerguide/configuration-api.html#configuration-api-actions-get-upgrade-hist

        :stability: experimental
        '''
        return typing.cast("Es", jsii.invoke(self, "toGetUpgradeHistory", []))

    @jsii.member(jsii_name="toGetUpgradeStatus")
    def to_get_upgrade_status(self) -> "Es":
        '''(experimental) Grants permission to fetch the upgrade status of a given OpenSearch Service domain.

        Access Level: Read

        https://docs.aws.amazon.com/opensearch-service/latest/developerguide/configuration-api.html#configuration-api-actions-get-upgrade-stat

        :stability: experimental
        '''
        return typing.cast("Es", jsii.invoke(self, "toGetUpgradeStatus", []))

    @jsii.member(jsii_name="toListDomainNames")
    def to_list_domain_names(self) -> "Es":
        '''(experimental) Grants permission to display the names of all OpenSearch Service domains that the current user owns.

        Access Level: List

        https://docs.aws.amazon.com/opensearch-service/latest/developerguide/configuration-api.html#configuration-api-actions-listdomainnames

        :stability: experimental
        '''
        return typing.cast("Es", jsii.invoke(self, "toListDomainNames", []))

    @jsii.member(jsii_name="toListDomainsForPackage")
    def to_list_domains_for_package(self) -> "Es":
        '''(experimental) Grants permission to list all OpenSearch Service domains that a package is associated with.

        Access Level: List

        https://docs.aws.amazon.com/opensearch-service/latest/developerguide/configuration-api.html#configuration-api-actions-listdomainsforpackage

        :stability: experimental
        '''
        return typing.cast("Es", jsii.invoke(self, "toListDomainsForPackage", []))

    @jsii.member(jsii_name="toListElasticsearchInstanceTypeDetails")
    def to_list_elasticsearch_instance_type_details(self) -> "Es":
        '''(experimental) Grants permission to list all instance types and available features for a given OpenSearch version.

        This permission is deprecated. Use ListInstanceTypeDetails instead

        Access Level: List

        https://docs.aws.amazon.com/opensearch-service/latest/developerguide/configuration-api.html#configuration-api-actions-listinstancetypedetails

        :stability: experimental
        '''
        return typing.cast("Es", jsii.invoke(self, "toListElasticsearchInstanceTypeDetails", []))

    @jsii.member(jsii_name="toListElasticsearchInstanceTypes")
    def to_list_elasticsearch_instance_types(self) -> "Es":
        '''(experimental) Grants permission to list all EC2 instance types that are supported for a given OpenSearch version.

        Access Level: List

        https://docs.aws.amazon.com/opensearch-service/latest/developerguide/configuration-api.html

        :stability: experimental
        '''
        return typing.cast("Es", jsii.invoke(self, "toListElasticsearchInstanceTypes", []))

    @jsii.member(jsii_name="toListElasticsearchVersions")
    def to_list_elasticsearch_versions(self) -> "Es":
        '''(experimental) Grants permission to list all supported OpenSearch versions on Amazon OpenSearch Service. This permission is deprecated. Use ListVersions instead.

        Access Level: List

        https://docs.aws.amazon.com/opensearch-service/latest/developerguide/configuration-api.html#configuration-api-actions-listversions

        :stability: experimental
        '''
        return typing.cast("Es", jsii.invoke(self, "toListElasticsearchVersions", []))

    @jsii.member(jsii_name="toListInstanceTypeDetails")
    def to_list_instance_type_details(self) -> "Es":
        '''(experimental) Grants permission to list all instance types and available features for a given OpenSearch or Elasticsearch version.

        Access Level: List

        https://docs.aws.amazon.com/opensearch-service/latest/developerguide/configuration-api.html#configuration-api-actions-listinstancetypedetails

        :stability: experimental
        '''
        return typing.cast("Es", jsii.invoke(self, "toListInstanceTypeDetails", []))

    @jsii.member(jsii_name="toListPackagesForDomain")
    def to_list_packages_for_domain(self) -> "Es":
        '''(experimental) Grants permission to list all packages associated with the OpenSearch Service domain.

        Access Level: List

        https://docs.aws.amazon.com/opensearch-service/latest/developerguide/configuration-api.html#configuration-api-actions-listpackagesfordomain

        :stability: experimental
        '''
        return typing.cast("Es", jsii.invoke(self, "toListPackagesForDomain", []))

    @jsii.member(jsii_name="toListTags")
    def to_list_tags(self) -> "Es":
        '''(experimental) Grants permission to display all resource tags for an OpenSearch Service domain.

        Access Level: Read

        https://docs.aws.amazon.com/opensearch-service/latest/developerguide/configuration-api.html#configuration-api-actions-listtags

        :stability: experimental
        '''
        return typing.cast("Es", jsii.invoke(self, "toListTags", []))

    @jsii.member(jsii_name="toListVersions")
    def to_list_versions(self) -> "Es":
        '''(experimental) Grants permission to list all supported OpenSearch and Elasticsearch versions in Amazon OpenSearch Service.

        Access Level: List

        https://docs.aws.amazon.com/opensearch-service/latest/developerguide/configuration-api.html#configuration-api-actions-listversions

        :stability: experimental
        '''
        return typing.cast("Es", jsii.invoke(self, "toListVersions", []))

    @jsii.member(jsii_name="toPurchaseReservedElasticsearchInstanceOffering")
    def to_purchase_reserved_elasticsearch_instance_offering(self) -> "Es":
        '''(experimental) Grants permission to purchase OpenSearch Service Reserved Instances. This permission is deprecated. Use PurchaseReservedInstanceOffering instead.

        Access Level: Write

        https://docs.aws.amazon.com/opensearch-service/latest/developerguide/configuration-api.html#configuration-api-actions-purchasereservedinstance

        :stability: experimental
        '''
        return typing.cast("Es", jsii.invoke(self, "toPurchaseReservedElasticsearchInstanceOffering", []))

    @jsii.member(jsii_name="toPurchaseReservedInstanceOffering")
    def to_purchase_reserved_instance_offering(self) -> "Es":
        '''(experimental) Grants permission to purchase OpenSearch reserved instances.

        Access Level: Write

        https://docs.aws.amazon.com/opensearch-service/latest/developerguide/configuration-api.html#configuration-api-actions-purchasereservedinstance

        :stability: experimental
        '''
        return typing.cast("Es", jsii.invoke(self, "toPurchaseReservedInstanceOffering", []))

    @jsii.member(jsii_name="toRejectInboundConnection")
    def to_reject_inbound_connection(self) -> "Es":
        '''(experimental) Grants permission to the destination domain owner to reject an inbound cross-cluster search connection request.

        Access Level: Write

        https://docs.aws.amazon.com/opensearch-service/latest/developerguide/configuration-api.html#configuration-api-actions-reject-inbound-cross-cluster-search-connection

        :stability: experimental
        '''
        return typing.cast("Es", jsii.invoke(self, "toRejectInboundConnection", []))

    @jsii.member(jsii_name="toRejectInboundCrossClusterSearchConnection")
    def to_reject_inbound_cross_cluster_search_connection(self) -> "Es":
        '''(experimental) Grants permission to the destination domain owner to reject an inbound cross-cluster search connection request.

        This permission is deprecated. Use RejectInboundConnection instead

        Access Level: Write

        https://docs.aws.amazon.com/opensearch-service/latest/developerguide/configuration-api.html#configuration-api-actions-reject-inbound-cross-cluster-search-connection

        :stability: experimental
        '''
        return typing.cast("Es", jsii.invoke(self, "toRejectInboundCrossClusterSearchConnection", []))

    @jsii.member(jsii_name="toRemoveTags")
    def to_remove_tags(self) -> "Es":
        '''(experimental) Grants permission to remove resource tags from an OpenSearch Service domain.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/opensearch-service/latest/developerguide/configuration-api.html#configuration-api-actions-removetags

        :stability: experimental
        '''
        return typing.cast("Es", jsii.invoke(self, "toRemoveTags", []))

    @jsii.member(jsii_name="toStartElasticsearchServiceSoftwareUpdate")
    def to_start_elasticsearch_service_software_update(self) -> "Es":
        '''(experimental) Grants permission to start a service software update of a domain. This permission is deprecated. Use StartServiceSoftwareUpdate instead.

        Access Level: Write

        https://docs.aws.amazon.com/opensearch-service/latest/developerguide/configuration-api.html#configuration-api-actions-startupdate

        :stability: experimental
        '''
        return typing.cast("Es", jsii.invoke(self, "toStartElasticsearchServiceSoftwareUpdate", []))

    @jsii.member(jsii_name="toStartServiceSoftwareUpdate")
    def to_start_service_software_update(self) -> "Es":
        '''(experimental) Grants permission to start a service software update of a domain.

        Access Level: Write

        https://docs.aws.amazon.com/opensearch-service/latest/developerguide/configuration-api.html#configuration-api-actions-startupdate

        :stability: experimental
        '''
        return typing.cast("Es", jsii.invoke(self, "toStartServiceSoftwareUpdate", []))

    @jsii.member(jsii_name="toUpdateDomainConfig")
    def to_update_domain_config(self) -> "Es":
        '''(experimental) Grants permission to modify the configuration of an OpenSearch Service domain, such as the instance type or number of instances.

        Access Level: Write

        https://docs.aws.amazon.com/opensearch-service/latest/developerguide/configuration-api.html#configuration-api-actions-updatedomainconfig

        :stability: experimental
        '''
        return typing.cast("Es", jsii.invoke(self, "toUpdateDomainConfig", []))

    @jsii.member(jsii_name="toUpdateElasticsearchDomainConfig")
    def to_update_elasticsearch_domain_config(self) -> "Es":
        '''(experimental) Grants permission to modify the configuration of an OpenSearch Service domain, such as the instance type or number of instances.

        This permission is deprecated. Use UpdateDomainConfig instead

        Access Level: Write

        https://docs.aws.amazon.com/opensearch-service/latest/developerguide/configuration-api.html#configuration-api-actions-updatedomainconfig

        :stability: experimental
        '''
        return typing.cast("Es", jsii.invoke(self, "toUpdateElasticsearchDomainConfig", []))

    @jsii.member(jsii_name="toUpdatePackage")
    def to_update_package(self) -> "Es":
        '''(experimental) Grants permission to update a package for use with OpenSearch Service domains.

        Access Level: Write

        https://docs.aws.amazon.com/opensearch-service/latest/developerguide/configuration-api.html#configuration-api-actions-updatepackage

        :stability: experimental
        '''
        return typing.cast("Es", jsii.invoke(self, "toUpdatePackage", []))

    @jsii.member(jsii_name="toUpgradeDomain")
    def to_upgrade_domain(self) -> "Es":
        '''(experimental) Grants permission to initiate upgrade of an OpenSearch Service domain to a given version.

        Access Level: Write

        https://docs.aws.amazon.com/opensearch-service/latest/developerguide/configuration-api.html#configuration-api-actions-upgrade-domain

        :stability: experimental
        '''
        return typing.cast("Es", jsii.invoke(self, "toUpgradeDomain", []))

    @jsii.member(jsii_name="toUpgradeElasticsearchDomain")
    def to_upgrade_elasticsearch_domain(self) -> "Es":
        '''(experimental) Grants permission to initiate upgrade of an OpenSearch Service domain to a specified version.

        This permission is deprecated. Use UpgradeDomain instead

        Access Level: Write

        https://docs.aws.amazon.com/opensearch-service/latest/developerguide/configuration-api.html#configuration-api-actions-upgrade-domain

        :stability: experimental
        '''
        return typing.cast("Es", jsii.invoke(self, "toUpgradeElasticsearchDomain", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__afed259c3132f8659c26188474f90e7150c3dd3addb6bfde19ab85f793854f2b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8482d7f9cf7bb183eb2475fc3e3fb351eed291d8681ee412156d9268913e2459)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Events(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Events",
):
    '''(experimental) Statement provider for service `events <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazoneventbridge.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `events <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazoneventbridge.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="ifCreatorAccount")
    def if_creator_account(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Events":
        '''(experimental) Filters access by the account the rule was created in to rule actions.

        https://docs.aws.amazon.com/eventbridge/latest/userguide/policy-keys-eventbridge.html#events-creator-account

        Applies to actions:

        - .toDeleteRule()
        - .toDescribeRule()
        - .toDisableRule()
        - .toEnableRule()
        - .toListTagsForResource()
        - .toListTargetsByRule()
        - .toPutRule()
        - .toPutTargets()
        - .toRemoveTargets()
        - .toTagResource()
        - .toUntagResource()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9170865a8b6e7a8d5a00b893ae49c8e66f8cf57173a13e18cb85b215d3ce122d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Events", jsii.invoke(self, "ifCreatorAccount", [value, operator]))

    @jsii.member(jsii_name="ifDetailEventTypeCode")
    def if_detail_event_type_code(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Events":
        '''(experimental) Filters access by the literal string for the detail.eventTypeCode field of the event to PutRule actions.

        https://docs.aws.amazon.com/eventbridge/latest/userguide/policy-keys-eventbridge.html#limit-rule-by-type-code

        Applies to actions:

        - .toPutRule()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a588258b81abee2f9b6fa6f9f18ebc4a3204e171b14879b7716c7652bcf45d46)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Events", jsii.invoke(self, "ifDetailEventTypeCode", [value, operator]))

    @jsii.member(jsii_name="ifDetailService")
    def if_detail_service(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Events":
        '''(experimental) Filters access by the literal string for the detail.service field of the event to PutRule actions.

        https://docs.aws.amazon.com/eventbridge/latest/userguide/policy-keys-eventbridge.html#limit-rule-by-service

        Applies to actions:

        - .toPutRule()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__99e3bb7ee1c7f20161561a66cc507abcb63ca7c18c50410aa3b31bf369c4eb82)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Events", jsii.invoke(self, "ifDetailService", [value, operator]))

    @jsii.member(jsii_name="ifDetailType")
    def if_detail_type(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Events":
        '''(experimental) Filters access by the literal string of the detail-type of the event to PutEvents and PutRule actions.

        https://docs.aws.amazon.com/eventbridge/latest/userguide/policy-keys-eventbridge.html#events-pattern-detail-type

        Applies to actions:

        - .toPutEvents()
        - .toPutRule()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1e7cf3f8e2f174d138ebea399274835d80a71c8ae9bd6d50e37a02a718728892)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Events", jsii.invoke(self, "ifDetailType", [value, operator]))

    @jsii.member(jsii_name="ifDetailUserIdentityPrincipalId")
    def if_detail_user_identity_principal_id(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Events":
        '''(experimental) Filters access by the literal string for the detail.useridentity.principalid field of the event to PutRule actions.

        https://docs.aws.amazon.com/eventbridge/latest/userguide/policy-keys-eventbridge.html#consume-specific-events

        Applies to actions:

        - .toPutRule()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__24b93bbf56d4c7418e53d36d1f8e0d94785aaf9221394b808dbe10156c4b429d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Events", jsii.invoke(self, "ifDetailUserIdentityPrincipalId", [value, operator]))

    @jsii.member(jsii_name="ifEventBusArn")
    def if_event_bus_arn(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Events":
        '''(experimental) Filters access by the ARN of the event buses that can be associated with an endpoint to CreateEndpoint and UpdateEndpoint actions.

        https://docs.aws.amazon.com/eventbridge/latest/userguide/policy-keys-eventbridge.html#limiting-access-to-event-buses

        Applies to actions:

        - .toCreateEndpoint()
        - .toUpdateEndpoint()

        :param value: The value(s) to check.
        :param operator: Works with `arn operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_ARN>`_. **Default:** ``ArnLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e42672d6ae0854f2445c344cc45c8beff4b6219c9588795787f8ca16502c36c3)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Events", jsii.invoke(self, "ifEventBusArn", [value, operator]))

    @jsii.member(jsii_name="ifEventBusInvocation")
    def if_event_bus_invocation(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Events":
        '''(experimental) Filters access by whether the event was generated via API or cross-account bus invocation to PutEvents actions.

        https://docs.aws.amazon.com/eventbridge/latest/userguide/policy-keys-eventbridge.html#events-bus-invocation

        Applies to actions:

        - .toPutEvents()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f2f3fd8da1616a1f6f87ceff690abb070eaf5d9dad7240b6f9b0e6183961f3ec)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Events", jsii.invoke(self, "ifEventBusInvocation", [value, operator]))

    @jsii.member(jsii_name="ifManagedBy")
    def if_managed_by(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Events":
        '''(experimental) Filters access by AWS services.

        If a rule is created by an AWS service on your behalf, the value is the principal name of the service that created the rule

        https://docs.aws.amazon.com/eventbridge/latest/userguide/policy-keys-eventbridge.html

        Applies to actions:

        - .toDeleteRule()
        - .toDisableRule()
        - .toEnableRule()
        - .toPutRule()
        - .toPutTargets()
        - .toRemoveTargets()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0f86b191e40d6042b07c139559f56b575c51186d87044f0600ff0505e03c6902)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Events", jsii.invoke(self, "ifManagedBy", [value, operator]))

    @jsii.member(jsii_name="ifSource")
    def if_source(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Events":
        '''(experimental) Filters access by the AWS service or AWS partner event source that generated the event to PutEvents and PutRule actions.

        Matches the literal string of the source field of the event

        https://docs.aws.amazon.com/eventbridge/latest/userguide/policy-keys-eventbridge.html#events-limit-access-control

        Applies to actions:

        - .toPutEvents()
        - .toPutRule()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ca685e877653f554af019590038a3517cfa065369e7d67d58e5e5f2ba159ee1a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Events", jsii.invoke(self, "ifSource", [value, operator]))

    @jsii.member(jsii_name="ifTargetArn")
    def if_target_arn(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Events":
        '''(experimental) Filters access by the ARN of a target that can be put to a rule to PutTargets actions.

        https://docs.aws.amazon.com/eventbridge/latest/userguide/policy-keys-eventbridge.html#limiting-access-to-targets

        Applies to actions:

        - .toPutTargets()

        :param value: The value(s) to check.
        :param operator: Works with `arn operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_ARN>`_. **Default:** ``ArnLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0ec2b950fa62e40201e574a73616dba555006de413ef449ea83ca61ac417db9c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Events", jsii.invoke(self, "ifTargetArn", [value, operator]))

    @jsii.member(jsii_name="onApiDestination")
    def on_api_destination(
        self,
        api_destination_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Events":
        '''(experimental) Adds a resource of type api-destination to the statement.

        https://docs.aws.amazon.com/eventbridge/latest/userguide/eb-manage-iam-access.html#eventbridge-arn-format

        :param api_destination_name: - Identifier for the apiDestinationName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__362c7a87acc645d864906a919ee385c58907503d7a2255d346cf8ffae2af2297)
            check_type(argname="argument api_destination_name", value=api_destination_name, expected_type=type_hints["api_destination_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Events", jsii.invoke(self, "onApiDestination", [api_destination_name, account, region, partition]))

    @jsii.member(jsii_name="onArchive")
    def on_archive(
        self,
        archive_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Events":
        '''(experimental) Adds a resource of type archive to the statement.

        https://docs.aws.amazon.com/eventbridge/latest/userguide/eb-manage-iam-access.html#eventbridge-arn-format

        :param archive_name: - Identifier for the archiveName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__49688528c07850fe7db3e7289685aee4e0b482aece6166dff852e98721c89ec7)
            check_type(argname="argument archive_name", value=archive_name, expected_type=type_hints["archive_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Events", jsii.invoke(self, "onArchive", [archive_name, account, region, partition]))

    @jsii.member(jsii_name="onConnection")
    def on_connection(
        self,
        connection_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Events":
        '''(experimental) Adds a resource of type connection to the statement.

        https://docs.aws.amazon.com/eventbridge/latest/userguide/eb-manage-iam-access.html#eventbridge-arn-format

        :param connection_name: - Identifier for the connectionName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9cc143a93ecf3ef26256c122fa6ea57cd3ebf3744c820bc9786041d3dc09d842)
            check_type(argname="argument connection_name", value=connection_name, expected_type=type_hints["connection_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Events", jsii.invoke(self, "onConnection", [connection_name, account, region, partition]))

    @jsii.member(jsii_name="onEndpoint")
    def on_endpoint(
        self,
        endpoint_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Events":
        '''(experimental) Adds a resource of type endpoint to the statement.

        https://docs.aws.amazon.com/eventbridge/latest/userguide/eb-manage-iam-access.html#eventbridge-arn-format

        :param endpoint_name: - Identifier for the endpointName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ded4f20c37113e9b717ef7955d2d6bf48b2aa5beaa3bad73c4f146fcc844936c)
            check_type(argname="argument endpoint_name", value=endpoint_name, expected_type=type_hints["endpoint_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Events", jsii.invoke(self, "onEndpoint", [endpoint_name, account, region, partition]))

    @jsii.member(jsii_name="onEventBus")
    def on_event_bus(
        self,
        event_bus_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Events":
        '''(experimental) Adds a resource of type event-bus to the statement.

        https://docs.aws.amazon.com/eventbridge/latest/userguide/eb-manage-iam-access.html#eventbridge-arn-format

        :param event_bus_name: - Identifier for the eventBusName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7ae18fdaefb29e3cd05b77ff62602f2c6f6cd24db7479297675aab2fc248bb6e)
            check_type(argname="argument event_bus_name", value=event_bus_name, expected_type=type_hints["event_bus_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Events", jsii.invoke(self, "onEventBus", [event_bus_name, account, region, partition]))

    @jsii.member(jsii_name="onEventSource")
    def on_event_source(
        self,
        event_source_name: builtins.str,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Events":
        '''(experimental) Adds a resource of type event-source to the statement.

        https://docs.aws.amazon.com/eventbridge/latest/userguide/eb-manage-iam-access.html#eventbridge-arn-format

        :param event_source_name: - Identifier for the eventSourceName.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__834c7270901ca0ba69e870abf4f38482682c192106f37c86ee0425c46e832500)
            check_type(argname="argument event_source_name", value=event_source_name, expected_type=type_hints["event_source_name"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Events", jsii.invoke(self, "onEventSource", [event_source_name, region, partition]))

    @jsii.member(jsii_name="onReplay")
    def on_replay(
        self,
        replay_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Events":
        '''(experimental) Adds a resource of type replay to the statement.

        https://docs.aws.amazon.com/eventbridge/latest/userguide/eb-manage-iam-access.html#eventbridge-arn-format

        :param replay_name: - Identifier for the replayName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__29f254716ef9cd429a5461d5d964d0ca848e48fd1a22330e516a2b387a39fae4)
            check_type(argname="argument replay_name", value=replay_name, expected_type=type_hints["replay_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Events", jsii.invoke(self, "onReplay", [replay_name, account, region, partition]))

    @jsii.member(jsii_name="onRuleOnCustomEventBus")
    def on_rule_on_custom_event_bus(
        self,
        event_bus_name: builtins.str,
        rule_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Events":
        '''(experimental) Adds a resource of type rule-on-custom-event-bus to the statement.

        https://docs.aws.amazon.com/eventbridge/latest/userguide/eb-manage-iam-access.html#eventbridge-arn-format

        :param event_bus_name: - Identifier for the eventBusName.
        :param rule_name: - Identifier for the ruleName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5c07a869df536322937d2e53fb9383d3ef0a2d75dbdd65d29640c40605537f84)
            check_type(argname="argument event_bus_name", value=event_bus_name, expected_type=type_hints["event_bus_name"])
            check_type(argname="argument rule_name", value=rule_name, expected_type=type_hints["rule_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Events", jsii.invoke(self, "onRuleOnCustomEventBus", [event_bus_name, rule_name, account, region, partition]))

    @jsii.member(jsii_name="onRuleOnDefaultEventBus")
    def on_rule_on_default_event_bus(
        self,
        rule_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Events":
        '''(experimental) Adds a resource of type rule-on-default-event-bus to the statement.

        https://docs.aws.amazon.com/eventbridge/latest/userguide/eb-manage-iam-access.html#eventbridge-arn-format

        :param rule_name: - Identifier for the ruleName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8611e9b8a7d478c29750e26f8882206b7ec3127f80f043dcaa30d3a325a23a9e)
            check_type(argname="argument rule_name", value=rule_name, expected_type=type_hints["rule_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Events", jsii.invoke(self, "onRuleOnDefaultEventBus", [rule_name, account, region, partition]))

    @jsii.member(jsii_name="toActivateEventSource")
    def to_activate_event_source(self) -> "Events":
        '''(experimental) Grants permission to activate partner event sources.

        Access Level: Write

        https://docs.aws.amazon.com/eventbridge/latest/APIReference/API_ActivateEventSource.html

        :stability: experimental
        '''
        return typing.cast("Events", jsii.invoke(self, "toActivateEventSource", []))

    @jsii.member(jsii_name="toCancelReplay")
    def to_cancel_replay(self) -> "Events":
        '''(experimental) Grants permission to cancel a replay.

        Access Level: Write

        https://docs.aws.amazon.com/eventbridge/latest/APIReference/API_CancelReplay.html

        :stability: experimental
        '''
        return typing.cast("Events", jsii.invoke(self, "toCancelReplay", []))

    @jsii.member(jsii_name="toCreateApiDestination")
    def to_create_api_destination(self) -> "Events":
        '''(experimental) Grants permission to create a new api destination.

        Access Level: Write

        https://docs.aws.amazon.com/eventbridge/latest/APIReference/API_CreateApiDestination.html

        :stability: experimental
        '''
        return typing.cast("Events", jsii.invoke(self, "toCreateApiDestination", []))

    @jsii.member(jsii_name="toCreateArchive")
    def to_create_archive(self) -> "Events":
        '''(experimental) Grants permission to create a new archive.

        Access Level: Write

        https://docs.aws.amazon.com/eventbridge/latest/APIReference/API_CreateArchive.html

        :stability: experimental
        '''
        return typing.cast("Events", jsii.invoke(self, "toCreateArchive", []))

    @jsii.member(jsii_name="toCreateConnection")
    def to_create_connection(self) -> "Events":
        '''(experimental) Grants permission to create a new connection.

        Access Level: Write

        https://docs.aws.amazon.com/eventbridge/latest/APIReference/API_CreateConnection.html

        :stability: experimental
        '''
        return typing.cast("Events", jsii.invoke(self, "toCreateConnection", []))

    @jsii.member(jsii_name="toCreateEndpoint")
    def to_create_endpoint(self) -> "Events":
        '''(experimental) Grants permission to create an endpoint.

        Access Level: Write

        Possible conditions:

        - .ifEventBusArn()

        https://docs.aws.amazon.com/eventbridge/latest/APIReference/API_CreateEndpoint.html

        :stability: experimental
        '''
        return typing.cast("Events", jsii.invoke(self, "toCreateEndpoint", []))

    @jsii.member(jsii_name="toCreateEventBus")
    def to_create_event_bus(self) -> "Events":
        '''(experimental) Grants permission to create event buses.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/eventbridge/latest/APIReference/API_CreateEventBus.html

        :stability: experimental
        '''
        return typing.cast("Events", jsii.invoke(self, "toCreateEventBus", []))

    @jsii.member(jsii_name="toCreatePartnerEventSource")
    def to_create_partner_event_source(self) -> "Events":
        '''(experimental) Grants permission to create partner event sources.

        Access Level: Write

        https://docs.aws.amazon.com/eventbridge/latest/APIReference/API_CreatePartnerEventSource.html

        :stability: experimental
        '''
        return typing.cast("Events", jsii.invoke(self, "toCreatePartnerEventSource", []))

    @jsii.member(jsii_name="toDeactivateEventSource")
    def to_deactivate_event_source(self) -> "Events":
        '''(experimental) Grants permission to deactivate event sources.

        Access Level: Write

        https://docs.aws.amazon.com/eventbridge/latest/APIReference/API_DeactivateEventSource.html

        :stability: experimental
        '''
        return typing.cast("Events", jsii.invoke(self, "toDeactivateEventSource", []))

    @jsii.member(jsii_name="toDeauthorizeConnection")
    def to_deauthorize_connection(self) -> "Events":
        '''(experimental) Grants permission to deauthorize a connection, deleting its stored authorization secrets.

        Access Level: Write

        https://docs.aws.amazon.com/eventbridge/latest/APIReference/API_DeauthorizeConnection.html

        :stability: experimental
        '''
        return typing.cast("Events", jsii.invoke(self, "toDeauthorizeConnection", []))

    @jsii.member(jsii_name="toDeleteApiDestination")
    def to_delete_api_destination(self) -> "Events":
        '''(experimental) Grants permission to delete an api destination.

        Access Level: Write

        https://docs.aws.amazon.com/eventbridge/latest/APIReference/API_DeleteApiDestination.html

        :stability: experimental
        '''
        return typing.cast("Events", jsii.invoke(self, "toDeleteApiDestination", []))

    @jsii.member(jsii_name="toDeleteArchive")
    def to_delete_archive(self) -> "Events":
        '''(experimental) Grants permission to delete an archive.

        Access Level: Write

        https://docs.aws.amazon.com/eventbridge/latest/APIReference/API_DeleteArchive.html

        :stability: experimental
        '''
        return typing.cast("Events", jsii.invoke(self, "toDeleteArchive", []))

    @jsii.member(jsii_name="toDeleteConnection")
    def to_delete_connection(self) -> "Events":
        '''(experimental) Grants permission to delete a connection.

        Access Level: Write

        https://docs.aws.amazon.com/eventbridge/latest/APIReference/API_DeleteConnection.html

        :stability: experimental
        '''
        return typing.cast("Events", jsii.invoke(self, "toDeleteConnection", []))

    @jsii.member(jsii_name="toDeleteEndpoint")
    def to_delete_endpoint(self) -> "Events":
        '''(experimental) Grants permission to delete an endpoint.

        Access Level: Write

        https://docs.aws.amazon.com/eventbridge/latest/APIReference/API_DeleteEndpoint.html

        :stability: experimental
        '''
        return typing.cast("Events", jsii.invoke(self, "toDeleteEndpoint", []))

    @jsii.member(jsii_name="toDeleteEventBus")
    def to_delete_event_bus(self) -> "Events":
        '''(experimental) Grants permission to delete event buses.

        Access Level: Write

        https://docs.aws.amazon.com/eventbridge/latest/APIReference/API_DeletePartnerEventSource.html

        :stability: experimental
        '''
        return typing.cast("Events", jsii.invoke(self, "toDeleteEventBus", []))

    @jsii.member(jsii_name="toDeletePartnerEventSource")
    def to_delete_partner_event_source(self) -> "Events":
        '''(experimental) Grants permission to delete partner event sources.

        Access Level: Write

        https://docs.aws.amazon.com/eventbridge/latest/APIReference/API_DeletePartnerEventSource.html

        :stability: experimental
        '''
        return typing.cast("Events", jsii.invoke(self, "toDeletePartnerEventSource", []))

    @jsii.member(jsii_name="toDeleteRule")
    def to_delete_rule(self) -> "Events":
        '''(experimental) Grants permission to delete rules.

        Access Level: Write

        Possible conditions:

        - .ifCreatorAccount()
        - .ifManagedBy()

        https://docs.aws.amazon.com/eventbridge/latest/APIReference/API_DeleteRule.html

        :stability: experimental
        '''
        return typing.cast("Events", jsii.invoke(self, "toDeleteRule", []))

    @jsii.member(jsii_name="toDescribeApiDestination")
    def to_describe_api_destination(self) -> "Events":
        '''(experimental) Grants permission to retrieve details about an api destination.

        Access Level: Read

        https://docs.aws.amazon.com/eventbridge/latest/APIReference/API_DescribeApiDestination.html

        :stability: experimental
        '''
        return typing.cast("Events", jsii.invoke(self, "toDescribeApiDestination", []))

    @jsii.member(jsii_name="toDescribeArchive")
    def to_describe_archive(self) -> "Events":
        '''(experimental) Grants permission to retrieve details about an archive.

        Access Level: Read

        https://docs.aws.amazon.com/eventbridge/latest/APIReference/API_DescribeArchive.html

        :stability: experimental
        '''
        return typing.cast("Events", jsii.invoke(self, "toDescribeArchive", []))

    @jsii.member(jsii_name="toDescribeConnection")
    def to_describe_connection(self) -> "Events":
        '''(experimental) Grants permission to retrieve details about a conection.

        Access Level: Read

        https://docs.aws.amazon.com/eventbridge/latest/APIReference/API_DescribeConnection.html

        :stability: experimental
        '''
        return typing.cast("Events", jsii.invoke(self, "toDescribeConnection", []))

    @jsii.member(jsii_name="toDescribeEndpoint")
    def to_describe_endpoint(self) -> "Events":
        '''(experimental) Grants permission to retrieve details about an endpoint.

        Access Level: Read

        https://docs.aws.amazon.com/eventbridge/latest/APIReference/API_DescribeEndpoint.html

        :stability: experimental
        '''
        return typing.cast("Events", jsii.invoke(self, "toDescribeEndpoint", []))

    @jsii.member(jsii_name="toDescribeEventBus")
    def to_describe_event_bus(self) -> "Events":
        '''(experimental) Grants permission to retrieve details about event buses.

        Access Level: Read

        https://docs.aws.amazon.com/eventbridge/latest/APIReference/API_DescribeEventBus.html

        :stability: experimental
        '''
        return typing.cast("Events", jsii.invoke(self, "toDescribeEventBus", []))

    @jsii.member(jsii_name="toDescribeEventSource")
    def to_describe_event_source(self) -> "Events":
        '''(experimental) Grants permission to retrieve details about event sources.

        Access Level: Read

        https://docs.aws.amazon.com/eventbridge/latest/APIReference/API_DescribeEventSource.html

        :stability: experimental
        '''
        return typing.cast("Events", jsii.invoke(self, "toDescribeEventSource", []))

    @jsii.member(jsii_name="toDescribePartnerEventSource")
    def to_describe_partner_event_source(self) -> "Events":
        '''(experimental) Grants permission to retrieve details about partner event sources.

        Access Level: Read

        https://docs.aws.amazon.com/eventbridge/latest/APIReference/API_DescribePartnerEventSource.html

        :stability: experimental
        '''
        return typing.cast("Events", jsii.invoke(self, "toDescribePartnerEventSource", []))

    @jsii.member(jsii_name="toDescribeReplay")
    def to_describe_replay(self) -> "Events":
        '''(experimental) Grants permission to retrieve the details of a replay.

        Access Level: Read

        https://docs.aws.amazon.com/eventbridge/latest/APIReference/API_DescribeReplay.html

        :stability: experimental
        '''
        return typing.cast("Events", jsii.invoke(self, "toDescribeReplay", []))

    @jsii.member(jsii_name="toDescribeRule")
    def to_describe_rule(self) -> "Events":
        '''(experimental) Grants permission to retrieve details about rules.

        Access Level: Read

        Possible conditions:

        - .ifCreatorAccount()

        https://docs.aws.amazon.com/eventbridge/latest/APIReference/API_DescribeRule.html

        :stability: experimental
        '''
        return typing.cast("Events", jsii.invoke(self, "toDescribeRule", []))

    @jsii.member(jsii_name="toDisableRule")
    def to_disable_rule(self) -> "Events":
        '''(experimental) Grants permission to disable rules.

        Access Level: Write

        Possible conditions:

        - .ifCreatorAccount()
        - .ifManagedBy()

        https://docs.aws.amazon.com/eventbridge/latest/APIReference/API_DisableRule.html

        :stability: experimental
        '''
        return typing.cast("Events", jsii.invoke(self, "toDisableRule", []))

    @jsii.member(jsii_name="toEnableRule")
    def to_enable_rule(self) -> "Events":
        '''(experimental) Grants permission to enable rules.

        Access Level: Write

        Possible conditions:

        - .ifCreatorAccount()
        - .ifManagedBy()

        https://docs.aws.amazon.com/eventbridge/latest/APIReference/API_EnableRule.html

        :stability: experimental
        '''
        return typing.cast("Events", jsii.invoke(self, "toEnableRule", []))

    @jsii.member(jsii_name="toInvokeApiDestination")
    def to_invoke_api_destination(self) -> "Events":
        '''(experimental) Grants permission to invoke an api destination.

        Access Level: Write

        https://docs.aws.amazon.com/eventbridge/latest/userguide/iam-identity-based-access-control-eventbridge.html

        :stability: experimental
        '''
        return typing.cast("Events", jsii.invoke(self, "toInvokeApiDestination", []))

    @jsii.member(jsii_name="toListApiDestinations")
    def to_list_api_destinations(self) -> "Events":
        '''(experimental) Grants permission to retrieve a list of api destinations.

        Access Level: List

        https://docs.aws.amazon.com/eventbridge/latest/APIReference/API_ListApiDestinations.html

        :stability: experimental
        '''
        return typing.cast("Events", jsii.invoke(self, "toListApiDestinations", []))

    @jsii.member(jsii_name="toListArchives")
    def to_list_archives(self) -> "Events":
        '''(experimental) Grants permission to retrieve a list of archives.

        Access Level: List

        https://docs.aws.amazon.com/eventbridge/latest/APIReference/API_ListArchives.html

        :stability: experimental
        '''
        return typing.cast("Events", jsii.invoke(self, "toListArchives", []))

    @jsii.member(jsii_name="toListConnections")
    def to_list_connections(self) -> "Events":
        '''(experimental) Grants permission to retrieve a list of connections.

        Access Level: List

        https://docs.aws.amazon.com/eventbridge/latest/APIReference/API_ListConnections.html

        :stability: experimental
        '''
        return typing.cast("Events", jsii.invoke(self, "toListConnections", []))

    @jsii.member(jsii_name="toListEndpoints")
    def to_list_endpoints(self) -> "Events":
        '''(experimental) Grants permission to retrieve a list of endpoints.

        Access Level: List

        https://docs.aws.amazon.com/eventbridge/latest/APIReference/API_ListEndpoints.html

        :stability: experimental
        '''
        return typing.cast("Events", jsii.invoke(self, "toListEndpoints", []))

    @jsii.member(jsii_name="toListEventBuses")
    def to_list_event_buses(self) -> "Events":
        '''(experimental) Grants permission to retrieve a list of the event buses in your account.

        Access Level: List

        https://docs.aws.amazon.com/eventbridge/latest/APIReference/API_ListEventBuses.html

        :stability: experimental
        '''
        return typing.cast("Events", jsii.invoke(self, "toListEventBuses", []))

    @jsii.member(jsii_name="toListEventSources")
    def to_list_event_sources(self) -> "Events":
        '''(experimental) Grants permission to to retrieve a list of event sources shared with this account.

        Access Level: List

        https://docs.aws.amazon.com/eventbridge/latest/APIReference/API_ListEventSources.html

        :stability: experimental
        '''
        return typing.cast("Events", jsii.invoke(self, "toListEventSources", []))

    @jsii.member(jsii_name="toListPartnerEventSourceAccounts")
    def to_list_partner_event_source_accounts(self) -> "Events":
        '''(experimental) Grants permission to retrieve a list of AWS account IDs associated with an event source.

        Access Level: List

        https://docs.aws.amazon.com/eventbridge/latest/APIReference/API_ListPartnerEventSourceAccounts.html

        :stability: experimental
        '''
        return typing.cast("Events", jsii.invoke(self, "toListPartnerEventSourceAccounts", []))

    @jsii.member(jsii_name="toListPartnerEventSources")
    def to_list_partner_event_sources(self) -> "Events":
        '''(experimental) Grants permission to retrieve a list partner event sources.

        Access Level: List

        https://docs.aws.amazon.com/eventbridge/latest/APIReference/API_ListPartnerEventSources.html

        :stability: experimental
        '''
        return typing.cast("Events", jsii.invoke(self, "toListPartnerEventSources", []))

    @jsii.member(jsii_name="toListReplays")
    def to_list_replays(self) -> "Events":
        '''(experimental) Grants permission to retrieve a list of replays.

        Access Level: List

        https://docs.aws.amazon.com/eventbridge/latest/APIReference/API_ListReplays.html

        :stability: experimental
        '''
        return typing.cast("Events", jsii.invoke(self, "toListReplays", []))

    @jsii.member(jsii_name="toListRuleNamesByTarget")
    def to_list_rule_names_by_target(self) -> "Events":
        '''(experimental) Grants permission to retrieve a list of the names of the rules associated with a target.

        Access Level: List

        https://docs.aws.amazon.com/eventbridge/latest/APIReference/API_ListRuleNamesByTarget.html

        :stability: experimental
        '''
        return typing.cast("Events", jsii.invoke(self, "toListRuleNamesByTarget", []))

    @jsii.member(jsii_name="toListRules")
    def to_list_rules(self) -> "Events":
        '''(experimental) Grants permission to retrieve a list of the Amazon EventBridge rules in the account.

        Access Level: List

        https://docs.aws.amazon.com/eventbridge/latest/APIReference/API_ListRules.html

        :stability: experimental
        '''
        return typing.cast("Events", jsii.invoke(self, "toListRules", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Events":
        '''(experimental) Grants permission to retrieve a list of tags associated with an Amazon EventBridge resource.

        Access Level: List

        Possible conditions:

        - .ifCreatorAccount()

        https://docs.aws.amazon.com/eventbridge/latest/APIReference/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("Events", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toListTargetsByRule")
    def to_list_targets_by_rule(self) -> "Events":
        '''(experimental) Grants permission to retrieve a list of targets defined for a rule.

        Access Level: List

        Possible conditions:

        - .ifCreatorAccount()

        https://docs.aws.amazon.com/eventbridge/latest/APIReference/API_ListTargetsByRule.html

        :stability: experimental
        '''
        return typing.cast("Events", jsii.invoke(self, "toListTargetsByRule", []))

    @jsii.member(jsii_name="toPutEvents")
    def to_put_events(self) -> "Events":
        '''(experimental) Grants permission to send custom events to Amazon EventBridge.

        Access Level: Write

        Possible conditions:

        - .ifDetailType()
        - .ifSource()
        - .ifEventBusInvocation()

        https://docs.aws.amazon.com/eventbridge/latest/APIReference/API_PutEvents.html

        :stability: experimental
        '''
        return typing.cast("Events", jsii.invoke(self, "toPutEvents", []))

    @jsii.member(jsii_name="toPutPartnerEvents")
    def to_put_partner_events(self) -> "Events":
        '''(experimental) Grants permission to sends custom events to Amazon EventBridge.

        Access Level: Write

        https://docs.aws.amazon.com/eventbridge/latest/APIReference/API_PutPartnerEvents.html

        :stability: experimental
        '''
        return typing.cast("Events", jsii.invoke(self, "toPutPartnerEvents", []))

    @jsii.member(jsii_name="toPutPermission")
    def to_put_permission(self) -> "Events":
        '''(experimental) Grants permission to use the PutPermission action to grants permission to another AWS account to put events to your default event bus.

        Access Level: Permissions management

        https://docs.aws.amazon.com/eventbridge/latest/APIReference/API_PutPermission.html

        :stability: experimental
        '''
        return typing.cast("Events", jsii.invoke(self, "toPutPermission", []))

    @jsii.member(jsii_name="toPutRule")
    def to_put_rule(self) -> "Events":
        '''(experimental) Grants permission to create or updates rules.

        Access Level: Write

        Possible conditions:

        - .ifDetailUserIdentityPrincipalId()
        - .ifDetailType()
        - .ifSource()
        - .ifDetailService()
        - .ifDetailEventTypeCode()
        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifCreatorAccount()
        - .ifManagedBy()

        https://docs.aws.amazon.com/eventbridge/latest/APIReference/API_PutRule.html

        :stability: experimental
        '''
        return typing.cast("Events", jsii.invoke(self, "toPutRule", []))

    @jsii.member(jsii_name="toPutTargets")
    def to_put_targets(self) -> "Events":
        '''(experimental) Grants permission to add targets to a rule.

        Access Level: Write

        Possible conditions:

        - .ifTargetArn()
        - .ifCreatorAccount()
        - .ifManagedBy()

        https://docs.aws.amazon.com/eventbridge/latest/APIReference/API_PutTargets.html

        :stability: experimental
        '''
        return typing.cast("Events", jsii.invoke(self, "toPutTargets", []))

    @jsii.member(jsii_name="toRemovePermission")
    def to_remove_permission(self) -> "Events":
        '''(experimental) Grants permission to revoke the permission of another AWS account to put events to your default event bus.

        Access Level: Permissions management

        https://docs.aws.amazon.com/eventbridge/latest/APIReference/API_RemovePermission.html

        :stability: experimental
        '''
        return typing.cast("Events", jsii.invoke(self, "toRemovePermission", []))

    @jsii.member(jsii_name="toRemoveTargets")
    def to_remove_targets(self) -> "Events":
        '''(experimental) Grants permission to removes targets from a rule.

        Access Level: Write

        Possible conditions:

        - .ifCreatorAccount()
        - .ifManagedBy()

        https://docs.aws.amazon.com/eventbridge/latest/APIReference/API_RemoveTargets.html

        :stability: experimental
        '''
        return typing.cast("Events", jsii.invoke(self, "toRemoveTargets", []))

    @jsii.member(jsii_name="toStartReplay")
    def to_start_replay(self) -> "Events":
        '''(experimental) Grants permission to start a replay of an archive.

        Access Level: Write

        https://docs.aws.amazon.com/eventbridge/latest/APIReference/API_StartReplay.html

        :stability: experimental
        '''
        return typing.cast("Events", jsii.invoke(self, "toStartReplay", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Events":
        '''(experimental) Grants permission to add a tag to an Amazon EventBridge resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()
        - .ifCreatorAccount()

        https://docs.aws.amazon.com/eventbridge/latest/APIReference/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("Events", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toTestEventPattern")
    def to_test_event_pattern(self) -> "Events":
        '''(experimental) Grants permission to test whether an event pattern matches the provided event.

        Access Level: Read

        https://docs.aws.amazon.com/eventbridge/latest/APIReference/API_TestEventPattern.html

        :stability: experimental
        '''
        return typing.cast("Events", jsii.invoke(self, "toTestEventPattern", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Events":
        '''(experimental) Grants permission to remove a tag from an Amazon EventBridge resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifCreatorAccount()

        https://docs.aws.amazon.com/eventbridge/latest/APIReference/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("Events", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateApiDestination")
    def to_update_api_destination(self) -> "Events":
        '''(experimental) Grants permission to update an api destination.

        Access Level: Write

        https://docs.aws.amazon.com/eventbridge/latest/APIReference/API_UpdateApiDestination.html

        :stability: experimental
        '''
        return typing.cast("Events", jsii.invoke(self, "toUpdateApiDestination", []))

    @jsii.member(jsii_name="toUpdateArchive")
    def to_update_archive(self) -> "Events":
        '''(experimental) Grants permission to update an archive.

        Access Level: Write

        https://docs.aws.amazon.com/eventbridge/latest/APIReference/API_UpdateArchive.html

        :stability: experimental
        '''
        return typing.cast("Events", jsii.invoke(self, "toUpdateArchive", []))

    @jsii.member(jsii_name="toUpdateConnection")
    def to_update_connection(self) -> "Events":
        '''(experimental) Grants permission to update a connection.

        Access Level: Write

        https://docs.aws.amazon.com/eventbridge/latest/APIReference/API_UpdateConnection.html

        :stability: experimental
        '''
        return typing.cast("Events", jsii.invoke(self, "toUpdateConnection", []))

    @jsii.member(jsii_name="toUpdateEndpoint")
    def to_update_endpoint(self) -> "Events":
        '''(experimental) Grants permission to update an endpoint.

        Access Level: Write

        Possible conditions:

        - .ifEventBusArn()

        https://docs.aws.amazon.com/eventbridge/latest/APIReference/API_UpdateEndpoint.html

        :stability: experimental
        '''
        return typing.cast("Events", jsii.invoke(self, "toUpdateEndpoint", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e2160bd0b4857a26315a4ca0f3f7c2fe5c8bf70cff8f482fcb9c5961c299ad70)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0545f86efcdf0b23e449da7089b4b8d4d13fa274acfe34bdc8f35d1f1d95b3ac)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Evidently(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Evidently",
):
    '''(experimental) Statement provider for service `evidently <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazoncloudwatchevidently.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `evidently <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazoncloudwatchevidently.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onExperiment")
    def on_experiment(
        self,
        project_name: builtins.str,
        experiment_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Evidently":
        '''(experimental) Adds a resource of type Experiment to the statement.

        https://docs.aws.amazon.com/cloudwatchevidently/latest/APIReference/API_Experiment.html

        :param project_name: - Identifier for the projectName.
        :param experiment_name: - Identifier for the experimentName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6edee63b6811a48ce7dcb74f8bbe4619ac5551f0233c862b7c23520c0c8a2447)
            check_type(argname="argument project_name", value=project_name, expected_type=type_hints["project_name"])
            check_type(argname="argument experiment_name", value=experiment_name, expected_type=type_hints["experiment_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Evidently", jsii.invoke(self, "onExperiment", [project_name, experiment_name, account, region, partition]))

    @jsii.member(jsii_name="onFeature")
    def on_feature(
        self,
        project_name: builtins.str,
        feature_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Evidently":
        '''(experimental) Adds a resource of type Feature to the statement.

        https://docs.aws.amazon.com/cloudwatchevidently/latest/APIReference/API_Feature.html

        :param project_name: - Identifier for the projectName.
        :param feature_name: - Identifier for the featureName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f583489fbefec580e099c80f28570a8b2ef1f1c450e20e9d7d744b0d8cd129fb)
            check_type(argname="argument project_name", value=project_name, expected_type=type_hints["project_name"])
            check_type(argname="argument feature_name", value=feature_name, expected_type=type_hints["feature_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Evidently", jsii.invoke(self, "onFeature", [project_name, feature_name, account, region, partition]))

    @jsii.member(jsii_name="onLaunch")
    def on_launch(
        self,
        project_name: builtins.str,
        launch_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Evidently":
        '''(experimental) Adds a resource of type Launch to the statement.

        https://docs.aws.amazon.com/cloudwatchevidently/latest/APIReference/API_Launch.html

        :param project_name: - Identifier for the projectName.
        :param launch_name: - Identifier for the launchName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6af4a7e0be2433578accae3719938e992d9a0deb6ca1ccc2f00bb35dba332bf3)
            check_type(argname="argument project_name", value=project_name, expected_type=type_hints["project_name"])
            check_type(argname="argument launch_name", value=launch_name, expected_type=type_hints["launch_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Evidently", jsii.invoke(self, "onLaunch", [project_name, launch_name, account, region, partition]))

    @jsii.member(jsii_name="onProject")
    def on_project(
        self,
        project_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Evidently":
        '''(experimental) Adds a resource of type Project to the statement.

        https://docs.aws.amazon.com/cloudwatchevidently/latest/APIReference/API_Project.html

        :param project_name: - Identifier for the projectName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e6445fc11bf37de0f1e140afab05a8bbf87e5b77267c7b9108a887a26960e6e5)
            check_type(argname="argument project_name", value=project_name, expected_type=type_hints["project_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Evidently", jsii.invoke(self, "onProject", [project_name, account, region, partition]))

    @jsii.member(jsii_name="onSegment")
    def on_segment(
        self,
        segment_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Evidently":
        '''(experimental) Adds a resource of type Segment to the statement.

        https://docs.aws.amazon.com/cloudwatchevidently/latest/APIReference/API_Segment.html

        :param segment_name: - Identifier for the segmentName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__34177ac64ec87ce5cff594462412f23b2217fc3e98cd5b444862f5bc091aee3a)
            check_type(argname="argument segment_name", value=segment_name, expected_type=type_hints["segment_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Evidently", jsii.invoke(self, "onSegment", [segment_name, account, region, partition]))

    @jsii.member(jsii_name="toBatchEvaluateFeature")
    def to_batch_evaluate_feature(self) -> "Evidently":
        '''(experimental) Grants permission to send a batched evaluate feature request.

        Access Level: Write

        https://docs.aws.amazon.com/cloudwatchevidently/latest/APIReference/API_BatchEvaluateFeature.html

        :stability: experimental
        '''
        return typing.cast("Evidently", jsii.invoke(self, "toBatchEvaluateFeature", []))

    @jsii.member(jsii_name="toCreateExperiment")
    def to_create_experiment(self) -> "Evidently":
        '''(experimental) Grants permission to create an experiment.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/cloudwatchevidently/latest/APIReference/API_CreateExperiment.html

        :stability: experimental
        '''
        return typing.cast("Evidently", jsii.invoke(self, "toCreateExperiment", []))

    @jsii.member(jsii_name="toCreateFeature")
    def to_create_feature(self) -> "Evidently":
        '''(experimental) Grants permission to create a feature.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/cloudwatchevidently/latest/APIReference/API_CreateFeature.html

        :stability: experimental
        '''
        return typing.cast("Evidently", jsii.invoke(self, "toCreateFeature", []))

    @jsii.member(jsii_name="toCreateLaunch")
    def to_create_launch(self) -> "Evidently":
        '''(experimental) Grants permission to create a launch.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/cloudwatchevidently/latest/APIReference/API_CreateLaunch.html

        :stability: experimental
        '''
        return typing.cast("Evidently", jsii.invoke(self, "toCreateLaunch", []))

    @jsii.member(jsii_name="toCreateProject")
    def to_create_project(self) -> "Evidently":
        '''(experimental) Grants permission to create a project.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - iam:CreateServiceLinkedRole
        - iam:GetRole

        https://docs.aws.amazon.com/cloudwatchevidently/latest/APIReference/API_CreateProject.html

        :stability: experimental
        '''
        return typing.cast("Evidently", jsii.invoke(self, "toCreateProject", []))

    @jsii.member(jsii_name="toCreateSegment")
    def to_create_segment(self) -> "Evidently":
        '''(experimental) Grants permission to create a segment.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/cloudwatchevidently/latest/APIReference/API_CreateSegment.html

        :stability: experimental
        '''
        return typing.cast("Evidently", jsii.invoke(self, "toCreateSegment", []))

    @jsii.member(jsii_name="toDeleteExperiment")
    def to_delete_experiment(self) -> "Evidently":
        '''(experimental) Grants permission to delete an experiment.

        Access Level: Write

        https://docs.aws.amazon.com/cloudwatchevidently/latest/APIReference/API_DeleteExperiment.html

        :stability: experimental
        '''
        return typing.cast("Evidently", jsii.invoke(self, "toDeleteExperiment", []))

    @jsii.member(jsii_name="toDeleteFeature")
    def to_delete_feature(self) -> "Evidently":
        '''(experimental) Grants permission to delete a feature.

        Access Level: Write

        https://docs.aws.amazon.com/cloudwatchevidently/latest/APIReference/API_DeleteFeature.html

        :stability: experimental
        '''
        return typing.cast("Evidently", jsii.invoke(self, "toDeleteFeature", []))

    @jsii.member(jsii_name="toDeleteLaunch")
    def to_delete_launch(self) -> "Evidently":
        '''(experimental) Grants permission to delete a launch.

        Access Level: Write

        https://docs.aws.amazon.com/cloudwatchevidently/latest/APIReference/API_DeleteLaunch.html

        :stability: experimental
        '''
        return typing.cast("Evidently", jsii.invoke(self, "toDeleteLaunch", []))

    @jsii.member(jsii_name="toDeleteProject")
    def to_delete_project(self) -> "Evidently":
        '''(experimental) Grants permission to delete a project.

        Access Level: Write

        https://docs.aws.amazon.com/cloudwatchevidently/latest/APIReference/API_DeleteProject.html

        :stability: experimental
        '''
        return typing.cast("Evidently", jsii.invoke(self, "toDeleteProject", []))

    @jsii.member(jsii_name="toDeleteSegment")
    def to_delete_segment(self) -> "Evidently":
        '''(experimental) Grants permission to delete a segment.

        Access Level: Write

        https://docs.aws.amazon.com/cloudwatchevidently/latest/APIReference/API_DeleteSegment.html

        :stability: experimental
        '''
        return typing.cast("Evidently", jsii.invoke(self, "toDeleteSegment", []))

    @jsii.member(jsii_name="toEvaluateFeature")
    def to_evaluate_feature(self) -> "Evidently":
        '''(experimental) Grants permission to send an evaluate feature request.

        Access Level: Write

        https://docs.aws.amazon.com/cloudwatchevidently/latest/APIReference/API_EvaluateFeature.html

        :stability: experimental
        '''
        return typing.cast("Evidently", jsii.invoke(self, "toEvaluateFeature", []))

    @jsii.member(jsii_name="toGetExperiment")
    def to_get_experiment(self) -> "Evidently":
        '''(experimental) Grants permission to get experiment details.

        Access Level: Read

        https://docs.aws.amazon.com/cloudwatchevidently/latest/APIReference/API_GetExperiment.html

        :stability: experimental
        '''
        return typing.cast("Evidently", jsii.invoke(self, "toGetExperiment", []))

    @jsii.member(jsii_name="toGetExperimentResults")
    def to_get_experiment_results(self) -> "Evidently":
        '''(experimental) Grants permission to get experiment result.

        Access Level: Read

        https://docs.aws.amazon.com/cloudwatchevidently/latest/APIReference/API_GetExperimentResults.html

        :stability: experimental
        '''
        return typing.cast("Evidently", jsii.invoke(self, "toGetExperimentResults", []))

    @jsii.member(jsii_name="toGetFeature")
    def to_get_feature(self) -> "Evidently":
        '''(experimental) Grants permission to get feature details.

        Access Level: Read

        https://docs.aws.amazon.com/cloudwatchevidently/latest/APIReference/API_GetFeature.html

        :stability: experimental
        '''
        return typing.cast("Evidently", jsii.invoke(self, "toGetFeature", []))

    @jsii.member(jsii_name="toGetLaunch")
    def to_get_launch(self) -> "Evidently":
        '''(experimental) Grants permission to get launch details.

        Access Level: Read

        https://docs.aws.amazon.com/cloudwatchevidently/latest/APIReference/API_GetLaunch.html

        :stability: experimental
        '''
        return typing.cast("Evidently", jsii.invoke(self, "toGetLaunch", []))

    @jsii.member(jsii_name="toGetProject")
    def to_get_project(self) -> "Evidently":
        '''(experimental) Grants permission to get project details.

        Access Level: Read

        https://docs.aws.amazon.com/cloudwatchevidently/latest/APIReference/API_GetProject.html

        :stability: experimental
        '''
        return typing.cast("Evidently", jsii.invoke(self, "toGetProject", []))

    @jsii.member(jsii_name="toGetSegment")
    def to_get_segment(self) -> "Evidently":
        '''(experimental) Grants permission to get segment details.

        Access Level: Read

        https://docs.aws.amazon.com/cloudwatchevidently/latest/APIReference/API_GetSegment.html

        :stability: experimental
        '''
        return typing.cast("Evidently", jsii.invoke(self, "toGetSegment", []))

    @jsii.member(jsii_name="toListExperiments")
    def to_list_experiments(self) -> "Evidently":
        '''(experimental) Grants permission to list experiments.

        Access Level: Read

        https://docs.aws.amazon.com/cloudwatchevidently/latest/APIReference/API_ListExperiments.html

        :stability: experimental
        '''
        return typing.cast("Evidently", jsii.invoke(self, "toListExperiments", []))

    @jsii.member(jsii_name="toListFeatures")
    def to_list_features(self) -> "Evidently":
        '''(experimental) Grants permission to list features.

        Access Level: Read

        https://docs.aws.amazon.com/cloudwatchevidently/latest/APIReference/API_ListFeatures.html

        :stability: experimental
        '''
        return typing.cast("Evidently", jsii.invoke(self, "toListFeatures", []))

    @jsii.member(jsii_name="toListLaunches")
    def to_list_launches(self) -> "Evidently":
        '''(experimental) Grants permission to list launches.

        Access Level: Read

        https://docs.aws.amazon.com/cloudwatchevidently/latest/APIReference/API_ListLaunches.html

        :stability: experimental
        '''
        return typing.cast("Evidently", jsii.invoke(self, "toListLaunches", []))

    @jsii.member(jsii_name="toListProjects")
    def to_list_projects(self) -> "Evidently":
        '''(experimental) Grants permission to list projects.

        Access Level: Read

        https://docs.aws.amazon.com/cloudwatchevidently/latest/APIReference/API_ListProjects.html

        :stability: experimental
        '''
        return typing.cast("Evidently", jsii.invoke(self, "toListProjects", []))

    @jsii.member(jsii_name="toListSegmentReferences")
    def to_list_segment_references(self) -> "Evidently":
        '''(experimental) Grants permission to list resources referencing a segment.

        Access Level: Read

        https://docs.aws.amazon.com/cloudwatchevidently/latest/APIReference/API_ListSegmentReferences.html

        :stability: experimental
        '''
        return typing.cast("Evidently", jsii.invoke(self, "toListSegmentReferences", []))

    @jsii.member(jsii_name="toListSegments")
    def to_list_segments(self) -> "Evidently":
        '''(experimental) Grants permission to list segments.

        Access Level: Read

        https://docs.aws.amazon.com/cloudwatchevidently/latest/APIReference/API_ListSegments.html

        :stability: experimental
        '''
        return typing.cast("Evidently", jsii.invoke(self, "toListSegments", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Evidently":
        '''(experimental) Grants permission to list tags for resources.

        Access Level: Read

        https://docs.aws.amazon.com/cloudwatchevidently/latest/APIReference/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("Evidently", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toPutProjectEvents")
    def to_put_project_events(self) -> "Evidently":
        '''(experimental) Grants permission to send performance events.

        Access Level: Write

        https://docs.aws.amazon.com/cloudwatchevidently/latest/APIReference/API_PutProjectEvents.html

        :stability: experimental
        '''
        return typing.cast("Evidently", jsii.invoke(self, "toPutProjectEvents", []))

    @jsii.member(jsii_name="toStartExperiment")
    def to_start_experiment(self) -> "Evidently":
        '''(experimental) Grants permission to start an experiment.

        Access Level: Write

        https://docs.aws.amazon.com/cloudwatchevidently/latest/APIReference/API_StartExperiment.html

        :stability: experimental
        '''
        return typing.cast("Evidently", jsii.invoke(self, "toStartExperiment", []))

    @jsii.member(jsii_name="toStartLaunch")
    def to_start_launch(self) -> "Evidently":
        '''(experimental) Grants permission to start a launch.

        Access Level: Write

        https://docs.aws.amazon.com/cloudwatchevidently/latest/APIReference/API_StartLaunch.html

        :stability: experimental
        '''
        return typing.cast("Evidently", jsii.invoke(self, "toStartLaunch", []))

    @jsii.member(jsii_name="toStopExperiment")
    def to_stop_experiment(self) -> "Evidently":
        '''(experimental) Grants permission to stop an experiment.

        Access Level: Write

        https://docs.aws.amazon.com/cloudwatchevidently/latest/APIReference/API_StopExperiment.html

        :stability: experimental
        '''
        return typing.cast("Evidently", jsii.invoke(self, "toStopExperiment", []))

    @jsii.member(jsii_name="toStopLaunch")
    def to_stop_launch(self) -> "Evidently":
        '''(experimental) Grants permission to stop a launch.

        Access Level: Write

        https://docs.aws.amazon.com/cloudwatchevidently/latest/APIReference/API_StopLaunch.html

        :stability: experimental
        '''
        return typing.cast("Evidently", jsii.invoke(self, "toStopLaunch", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Evidently":
        '''(experimental) Grants permission to tag resources.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/cloudwatchevidently/latest/APIReference/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("Evidently", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toTestSegmentPattern")
    def to_test_segment_pattern(self) -> "Evidently":
        '''(experimental) Grants permission to test a segment pattern.

        Access Level: Read

        https://docs.aws.amazon.com/cloudwatchevidently/latest/APIReference/API_TestSegmentPattern.html

        :stability: experimental
        '''
        return typing.cast("Evidently", jsii.invoke(self, "toTestSegmentPattern", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Evidently":
        '''(experimental) Grants permission to untag resources.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/cloudwatchevidently/latest/APIReference/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("Evidently", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateExperiment")
    def to_update_experiment(self) -> "Evidently":
        '''(experimental) Grants permission to update experiment.

        Access Level: Write

        https://docs.aws.amazon.com/cloudwatchevidently/latest/APIReference/API_UpdateExperiment.html

        :stability: experimental
        '''
        return typing.cast("Evidently", jsii.invoke(self, "toUpdateExperiment", []))

    @jsii.member(jsii_name="toUpdateFeature")
    def to_update_feature(self) -> "Evidently":
        '''(experimental) Grants permission to update feature.

        Access Level: Write

        https://docs.aws.amazon.com/cloudwatchevidently/latest/APIReference/API_UpdateFeature.html

        :stability: experimental
        '''
        return typing.cast("Evidently", jsii.invoke(self, "toUpdateFeature", []))

    @jsii.member(jsii_name="toUpdateLaunch")
    def to_update_launch(self) -> "Evidently":
        '''(experimental) Grants permission to update a launch.

        Access Level: Write

        https://docs.aws.amazon.com/cloudwatchevidently/latest/APIReference/API_UpdateLaunch.html

        :stability: experimental
        '''
        return typing.cast("Evidently", jsii.invoke(self, "toUpdateLaunch", []))

    @jsii.member(jsii_name="toUpdateProject")
    def to_update_project(self) -> "Evidently":
        '''(experimental) Grants permission to update project.

        Access Level: Write

        Dependent actions:

        - iam:CreateServiceLinkedRole
        - iam:GetRole

        https://docs.aws.amazon.com/cloudwatchevidently/latest/APIReference/API_UpdateProject.html

        :stability: experimental
        '''
        return typing.cast("Evidently", jsii.invoke(self, "toUpdateProject", []))

    @jsii.member(jsii_name="toUpdateProjectDataDelivery")
    def to_update_project_data_delivery(self) -> "Evidently":
        '''(experimental) Grants permission to update project data delivery.

        Access Level: Write

        https://docs.aws.amazon.com/cloudwatchevidently/latest/APIReference/API_UpdateProjectDataDelivery.html

        :stability: experimental
        '''
        return typing.cast("Evidently", jsii.invoke(self, "toUpdateProjectDataDelivery", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5d17b62698b5158fe13ac90565ec02aa73d41114521da32daa06fbd9805821aa)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1e85e0a651bda46a1125683cfc8f18ce7e841090234dd3e54de3dada41568c48)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class ExecuteApi(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.ExecuteApi",
):
    '''(experimental) Statement provider for service `execute-api <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonapigateway.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `execute-api <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonapigateway.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onExecuteApiGeneral")
    def on_execute_api_general(
        self,
        api_id: builtins.str,
        stage: builtins.str,
        method: builtins.str,
        api_specific_resource_path: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "ExecuteApi":
        '''(experimental) Adds a resource of type execute-api-general to the statement.

        :param api_id: - Identifier for the apiId.
        :param stage: - Identifier for the stage.
        :param method: - Identifier for the method.
        :param api_specific_resource_path: - Identifier for the apiSpecificResourcePath.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9a117a7794e1ae9c51f2095230de8cd78f6dfc40d71ba33b7082e1cae32792ef)
            check_type(argname="argument api_id", value=api_id, expected_type=type_hints["api_id"])
            check_type(argname="argument stage", value=stage, expected_type=type_hints["stage"])
            check_type(argname="argument method", value=method, expected_type=type_hints["method"])
            check_type(argname="argument api_specific_resource_path", value=api_specific_resource_path, expected_type=type_hints["api_specific_resource_path"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("ExecuteApi", jsii.invoke(self, "onExecuteApiGeneral", [api_id, stage, method, api_specific_resource_path, account, region, partition]))

    @jsii.member(jsii_name="toInvalidateCache")
    def to_invalidate_cache(self) -> "ExecuteApi":
        '''(experimental) Used to invalidate API cache upon a client request.

        Access Level: Write

        https://docs.aws.amazon.com/apigateway/api-reference/api-gateway-caching.html

        :stability: experimental
        '''
        return typing.cast("ExecuteApi", jsii.invoke(self, "toInvalidateCache", []))

    @jsii.member(jsii_name="toInvoke")
    def to_invoke(self) -> "ExecuteApi":
        '''(experimental) Used to invoke an API upon a client request.

        Access Level: Write

        https://docs.aws.amazon.com/apigateway/api-reference/how-to-call-api.html

        :stability: experimental
        '''
        return typing.cast("ExecuteApi", jsii.invoke(self, "toInvoke", []))

    @jsii.member(jsii_name="toManageConnections")
    def to_manage_connections(self) -> "ExecuteApi":
        '''(experimental) ManageConnections controls access to the @connections API.

        Access Level: Write

        https://docs.aws.amazon.com/apigateway/api-reference/apigateway-websocket-control-access-iam.html

        :stability: experimental
        '''
        return typing.cast("ExecuteApi", jsii.invoke(self, "toManageConnections", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__92517d91cdf9fc9690a38f1a570bfead630696e54ac33d49c93318c2ce54a1dc)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bbc42eb0aa385a28d0ce99594c8e491651274b65a5fe9076dbd1bdde1f11eb54)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Finspace(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Finspace",
):
    '''(experimental) Statement provider for service `finspace <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonfinspace.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `finspace <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonfinspace.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onEnvironment")
    def on_environment(
        self,
        environment_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Finspace":
        '''(experimental) Adds a resource of type environment to the statement.

        https://docs.aws.amazon.com/finspace/latest/userguide/finspace-example-policies.html

        :param environment_id: - Identifier for the environmentId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7a97c8f51920e4c39c4ba8de94dd475aae0fc10e70e1be1dde836f14a6c1af2c)
            check_type(argname="argument environment_id", value=environment_id, expected_type=type_hints["environment_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Finspace", jsii.invoke(self, "onEnvironment", [environment_id, account, region, partition]))

    @jsii.member(jsii_name="onUser")
    def on_user(
        self,
        user_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Finspace":
        '''(experimental) Adds a resource of type user to the statement.

        https://docs.aws.amazon.com/finspace/latest/userguide/finspace-example-policies.html

        :param user_id: - Identifier for the userId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0e8f91b6f7583b417182536bc5bd2bf4ec633c63b9b8a84c343c1122f4cdb45e)
            check_type(argname="argument user_id", value=user_id, expected_type=type_hints["user_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Finspace", jsii.invoke(self, "onUser", [user_id, account, region, partition]))

    @jsii.member(jsii_name="toCreateEnvironment")
    def to_create_environment(self) -> "Finspace":
        '''(experimental) Grants permission to create a FinSpace environment.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/finspace/latest/management-api/API_CreateEnvironment.html

        :stability: experimental
        '''
        return typing.cast("Finspace", jsii.invoke(self, "toCreateEnvironment", []))

    @jsii.member(jsii_name="toCreateUser")
    def to_create_user(self) -> "Finspace":
        '''(experimental) Grants permission to create a FinSpace user.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/finspace/latest/userguide/finspace-what-is.html

        :stability: experimental
        '''
        return typing.cast("Finspace", jsii.invoke(self, "toCreateUser", []))

    @jsii.member(jsii_name="toDeleteEnvironment")
    def to_delete_environment(self) -> "Finspace":
        '''(experimental) Grants permission to delete a FinSpace environment.

        Access Level: Write

        https://docs.aws.amazon.com/finspace/latest/management-api/API_DeleteEnvironment.html

        :stability: experimental
        '''
        return typing.cast("Finspace", jsii.invoke(self, "toDeleteEnvironment", []))

    @jsii.member(jsii_name="toGetEnvironment")
    def to_get_environment(self) -> "Finspace":
        '''(experimental) Grants permission to describe a FinSpace environment.

        Access Level: Read

        https://docs.aws.amazon.com/finspace/latest/management-api/API_GetEnvironment.html

        :stability: experimental
        '''
        return typing.cast("Finspace", jsii.invoke(self, "toGetEnvironment", []))

    @jsii.member(jsii_name="toGetLoadSampleDataSetGroupIntoEnvironmentStatus")
    def to_get_load_sample_data_set_group_into_environment_status(self) -> "Finspace":
        '''(experimental) Grants permission to request status of the loading of sample data bundle.

        Access Level: Read

        https://docs.aws.amazon.com/finspace/latest/userguide/finspace-what-is.html

        :stability: experimental
        '''
        return typing.cast("Finspace", jsii.invoke(self, "toGetLoadSampleDataSetGroupIntoEnvironmentStatus", []))

    @jsii.member(jsii_name="toGetUser")
    def to_get_user(self) -> "Finspace":
        '''(experimental) Grants permission to describe a FinSpace user.

        Access Level: Read

        https://docs.aws.amazon.com/finspace/latest/userguide/finspace-what-is.html

        :stability: experimental
        '''
        return typing.cast("Finspace", jsii.invoke(self, "toGetUser", []))

    @jsii.member(jsii_name="toListEnvironments")
    def to_list_environments(self) -> "Finspace":
        '''(experimental) Grants permission to list FinSpace environments in the AWS account.

        Access Level: List

        https://docs.aws.amazon.com/finspace/latest/management-api/API_ListEnvironments.html

        :stability: experimental
        '''
        return typing.cast("Finspace", jsii.invoke(self, "toListEnvironments", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Finspace":
        '''(experimental) Grants permission to return a list of tags for a resource.

        Access Level: Read

        https://docs.aws.amazon.com/finspace/latest/management-api/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("Finspace", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toListUsers")
    def to_list_users(self) -> "Finspace":
        '''(experimental) Grants permission to list FinSpace users in an environment.

        Access Level: List

        https://docs.aws.amazon.com/finspace/latest/userguide/finspace-what-is.html

        :stability: experimental
        '''
        return typing.cast("Finspace", jsii.invoke(self, "toListUsers", []))

    @jsii.member(jsii_name="toLoadSampleDataSetGroupIntoEnvironment")
    def to_load_sample_data_set_group_into_environment(self) -> "Finspace":
        '''(experimental) Grants permission to load sample data bundle into your FinSpace environment.

        Access Level: Write

        https://docs.aws.amazon.com/finspace/latest/userguide/finspace-what-is.html

        :stability: experimental
        '''
        return typing.cast("Finspace", jsii.invoke(self, "toLoadSampleDataSetGroupIntoEnvironment", []))

    @jsii.member(jsii_name="toResetUserPassword")
    def to_reset_user_password(self) -> "Finspace":
        '''(experimental) Grants permission to reset the password for a FinSpace user.

        Access Level: Write

        https://docs.aws.amazon.com/finspace/latest/userguide/finspace-what-is.html

        :stability: experimental
        '''
        return typing.cast("Finspace", jsii.invoke(self, "toResetUserPassword", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Finspace":
        '''(experimental) Grants permission to tag a resource.

        Access Level: Tagging

        https://docs.aws.amazon.com/finspace/latest/management-api/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("Finspace", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Finspace":
        '''(experimental) Grants permission to untag a resource.

        Access Level: Tagging

        https://docs.aws.amazon.com/finspace/latest/management-api/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("Finspace", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateEnvironment")
    def to_update_environment(self) -> "Finspace":
        '''(experimental) Grants permission to update a FinSpace environment.

        Access Level: Write

        https://docs.aws.amazon.com/finspace/latest/management-api/API_UpdateEnvironment.html

        :stability: experimental
        '''
        return typing.cast("Finspace", jsii.invoke(self, "toUpdateEnvironment", []))

    @jsii.member(jsii_name="toUpdateUser")
    def to_update_user(self) -> "Finspace":
        '''(experimental) Grants permission to update a FinSpace user.

        Access Level: Write

        https://docs.aws.amazon.com/finspace/latest/userguide/finspace-what-is.html

        :stability: experimental
        '''
        return typing.cast("Finspace", jsii.invoke(self, "toUpdateUser", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2da3b1c366935d8fe64b87668fbab2533787c98bf56c31ebc7a0a79be3900e12)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ecba224902dbd345c6288b85ec86257345bba7f5f5f532370145dbb930f4068e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Firehose(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Firehose",
):
    '''(experimental) Statement provider for service `firehose <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonkinesisfirehose.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `firehose <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonkinesisfirehose.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onDeliverystream")
    def on_deliverystream(
        self,
        delivery_stream_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Firehose":
        '''(experimental) Adds a resource of type deliverystream to the statement.

        https://docs.aws.amazon.com/firehose/latest/dev/basic-create.html

        :param delivery_stream_name: - Identifier for the deliveryStreamName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e1230d4418d95d507d7b8f462b98039e52b5461ecb474df90709c3bd8f6a287d)
            check_type(argname="argument delivery_stream_name", value=delivery_stream_name, expected_type=type_hints["delivery_stream_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Firehose", jsii.invoke(self, "onDeliverystream", [delivery_stream_name, account, region, partition]))

    @jsii.member(jsii_name="toCreateDeliveryStream")
    def to_create_delivery_stream(self) -> "Firehose":
        '''(experimental) Grants permission to create a delivery stream.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/firehose/latest/APIReference/API_CreateDeliveryStream.html

        :stability: experimental
        '''
        return typing.cast("Firehose", jsii.invoke(self, "toCreateDeliveryStream", []))

    @jsii.member(jsii_name="toDeleteDeliveryStream")
    def to_delete_delivery_stream(self) -> "Firehose":
        '''(experimental) Grants permission to delete a delivery stream and its data.

        Access Level: Write

        https://docs.aws.amazon.com/firehose/latest/APIReference/API_DeleteDeliveryStream.html

        :stability: experimental
        '''
        return typing.cast("Firehose", jsii.invoke(self, "toDeleteDeliveryStream", []))

    @jsii.member(jsii_name="toDescribeDeliveryStream")
    def to_describe_delivery_stream(self) -> "Firehose":
        '''(experimental) Grants permission to describe the specified delivery stream and gets the status.

        Access Level: Read

        https://docs.aws.amazon.com/firehose/latest/APIReference/API_DescribeDeliveryStream.html

        :stability: experimental
        '''
        return typing.cast("Firehose", jsii.invoke(self, "toDescribeDeliveryStream", []))

    @jsii.member(jsii_name="toListDeliveryStreams")
    def to_list_delivery_streams(self) -> "Firehose":
        '''(experimental) Grants permission to list your delivery streams.

        Access Level: List

        https://docs.aws.amazon.com/firehose/latest/APIReference/API_ListDeliveryStreams.html

        :stability: experimental
        '''
        return typing.cast("Firehose", jsii.invoke(self, "toListDeliveryStreams", []))

    @jsii.member(jsii_name="toListTagsForDeliveryStream")
    def to_list_tags_for_delivery_stream(self) -> "Firehose":
        '''(experimental) Grants permission to list the tags for the specified delivery stream.

        Access Level: List

        https://docs.aws.amazon.com/firehose/latest/APIReference/API_ListTagsForDeliveryStream.html

        :stability: experimental
        '''
        return typing.cast("Firehose", jsii.invoke(self, "toListTagsForDeliveryStream", []))

    @jsii.member(jsii_name="toPutRecord")
    def to_put_record(self) -> "Firehose":
        '''(experimental) Grants permission to write a single data record into an Amazon Kinesis Firehose delivery stream.

        Access Level: Write

        https://docs.aws.amazon.com/firehose/latest/APIReference/API_PutRecord.html

        :stability: experimental
        '''
        return typing.cast("Firehose", jsii.invoke(self, "toPutRecord", []))

    @jsii.member(jsii_name="toPutRecordBatch")
    def to_put_record_batch(self) -> "Firehose":
        '''(experimental) Grants permission to write multiple data records into a delivery stream in a single call, which can achieve higher throughput per producer than when writing single records.

        Access Level: Write

        https://docs.aws.amazon.com/firehose/latest/APIReference/API_PutRecordBatch.html

        :stability: experimental
        '''
        return typing.cast("Firehose", jsii.invoke(self, "toPutRecordBatch", []))

    @jsii.member(jsii_name="toStartDeliveryStreamEncryption")
    def to_start_delivery_stream_encryption(self) -> "Firehose":
        '''(experimental) Grants permission to enable server-side encryption (SSE) for the delivery stream.

        Access Level: Write

        https://docs.aws.amazon.com/firehose/latest/APIReference/API_StartDeliveryStreamEncryption.html

        :stability: experimental
        '''
        return typing.cast("Firehose", jsii.invoke(self, "toStartDeliveryStreamEncryption", []))

    @jsii.member(jsii_name="toStopDeliveryStreamEncryption")
    def to_stop_delivery_stream_encryption(self) -> "Firehose":
        '''(experimental) Grants permission to disable the specified destination of the specified delivery stream.

        Access Level: Write

        https://docs.aws.amazon.com/firehose/latest/APIReference/API_StopDeliveryStreamEncryption.html

        :stability: experimental
        '''
        return typing.cast("Firehose", jsii.invoke(self, "toStopDeliveryStreamEncryption", []))

    @jsii.member(jsii_name="toTagDeliveryStream")
    def to_tag_delivery_stream(self) -> "Firehose":
        '''(experimental) Grants permission to add or update tags for the specified delivery stream.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/firehose/latest/APIReference/API_TagDeliveryStream.html

        :stability: experimental
        '''
        return typing.cast("Firehose", jsii.invoke(self, "toTagDeliveryStream", []))

    @jsii.member(jsii_name="toUntagDeliveryStream")
    def to_untag_delivery_stream(self) -> "Firehose":
        '''(experimental) Grants permission to remove tags from the specified delivery stream.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/firehose/latest/APIReference/API_UntagDeliveryStream.html

        :stability: experimental
        '''
        return typing.cast("Firehose", jsii.invoke(self, "toUntagDeliveryStream", []))

    @jsii.member(jsii_name="toUpdateDestination")
    def to_update_destination(self) -> "Firehose":
        '''(experimental) Grants permission to update the specified destination of the specified delivery stream.

        Access Level: Write

        https://docs.aws.amazon.com/firehose/latest/APIReference/API_UpdateDestination.html

        :stability: experimental
        '''
        return typing.cast("Firehose", jsii.invoke(self, "toUpdateDestination", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7ba3549f1d6522e9d26d5e814e2e4d8831e989258a64d52d6af8d36fe38ee73a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0e34c35e661d2ee2db4245f4ba0705fbe61ff9f158046630fe80ae71f43fcbfc)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Fis(PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Fis"):
    '''(experimental) Statement provider for service `fis <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsfaultinjectionsimulator.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `fis <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsfaultinjectionsimulator.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="ifOperations")
    def if_operations(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Fis":
        '''(experimental) Filters access by the list of operations on the AWS service that is being affected by the AWS FIS action.

        https://docs.aws.amazon.com/fis/latest/userguide/security_iam_service-with-iam.html

        Applies to actions:

        - .toInjectApiInternalError()
        - .toInjectApiThrottleError()
        - .toInjectApiUnavailableError()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__cf009878962ecf69ec1b0de34de61f1696bba33d54568936c897ff0eec5405e7)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Fis", jsii.invoke(self, "ifOperations", [value, operator]))

    @jsii.member(jsii_name="ifPercentage")
    def if_percentage(
        self,
        value: typing.Union[jsii.Number, typing.Sequence[jsii.Number]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Fis":
        '''(experimental) Filters access by the percentage of calls being affected by the AWS FIS action.

        https://docs.aws.amazon.com/fis/latest/userguide/security_iam_service-with-iam.html

        Applies to actions:

        - .toInjectApiInternalError()
        - .toInjectApiThrottleError()
        - .toInjectApiUnavailableError()

        :param value: The value(s) to check.
        :param operator: Works with `numeric operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_Numeric>`_. **Default:** ``NumericEquals``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__76f17f4cae1716dc20a8297a7a82c2766102bcc76ad27d9d6b36fd619bb9dac8)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Fis", jsii.invoke(self, "ifPercentage", [value, operator]))

    @jsii.member(jsii_name="ifService")
    def if_service(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Fis":
        '''(experimental) Filters access by the AWS service that is being affected by the AWS FIS action.

        https://docs.aws.amazon.com/fis/latest/userguide/security_iam_service-with-iam.html

        Applies to actions:

        - .toInjectApiInternalError()
        - .toInjectApiThrottleError()
        - .toInjectApiUnavailableError()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7a02f5bc9230658e7f0f0742ba08a28778ec6d78b475d2d4ad226cd564010333)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Fis", jsii.invoke(self, "ifService", [value, operator]))

    @jsii.member(jsii_name="ifTargets")
    def if_targets(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Fis":
        '''(experimental) Filters access by the list of resource ARNs being targeted by the AWS FIS action.

        https://docs.aws.amazon.com/fis/latest/userguide/security_iam_service-with-iam.html

        Applies to actions:

        - .toInjectApiInternalError()
        - .toInjectApiThrottleError()
        - .toInjectApiUnavailableError()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2bedab5f588fc70ed1c8652d7c6572a4c7948661d03e03cc3da82d01f8668ec8)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Fis", jsii.invoke(self, "ifTargets", [value, operator]))

    @jsii.member(jsii_name="onAction")
    def on_action(
        self,
        id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Fis":
        '''(experimental) Adds a resource of type action to the statement.

        https://docs.aws.amazon.com/fis/latest/userguide/actions.html

        :param id: - Identifier for the id.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e6c51bfb97928062c415fd443e203309dce7f209cd56d087e8c2b2839de8c096)
            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Fis", jsii.invoke(self, "onAction", [id, account, region, partition]))

    @jsii.member(jsii_name="onExperiment")
    def on_experiment(
        self,
        id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Fis":
        '''(experimental) Adds a resource of type experiment to the statement.

        https://docs.aws.amazon.com/fis/latest/userguide/experiments.html

        :param id: - Identifier for the id.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4b25f1df15fcaaa30a491599b5c9b34041161eb5842c80cdd9ddf26fbb6ec240)
            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Fis", jsii.invoke(self, "onExperiment", [id, account, region, partition]))

    @jsii.member(jsii_name="onExperimentTemplate")
    def on_experiment_template(
        self,
        id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Fis":
        '''(experimental) Adds a resource of type experiment-template to the statement.

        https://docs.aws.amazon.com/fis/latest/userguide/working-with-templates.html

        :param id: - Identifier for the id.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2d9e5c78273e7784b6b7dc323630b3e7bdadc7290532442ba1c1c26aa10bbce7)
            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Fis", jsii.invoke(self, "onExperimentTemplate", [id, account, region, partition]))

    @jsii.member(jsii_name="toCreateExperimentTemplate")
    def to_create_experiment_template(self) -> "Fis":
        '''(experimental) Grants permission to create an AWS FIS experiment template.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/fis/latest/APIReference/API_CreateExperimentTemplate.html

        :stability: experimental
        '''
        return typing.cast("Fis", jsii.invoke(self, "toCreateExperimentTemplate", []))

    @jsii.member(jsii_name="toDeleteExperimentTemplate")
    def to_delete_experiment_template(self) -> "Fis":
        '''(experimental) Grants permission to delete the AWS FIS experiment template.

        Access Level: Write

        https://docs.aws.amazon.com/fis/latest/APIReference/API_DeleteExperimentTemplate.html

        :stability: experimental
        '''
        return typing.cast("Fis", jsii.invoke(self, "toDeleteExperimentTemplate", []))

    @jsii.member(jsii_name="toGetAction")
    def to_get_action(self) -> "Fis":
        '''(experimental) Grants permission to retrieve an AWS FIS action.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/fis/latest/APIReference/API_GetAction.html

        :stability: experimental
        '''
        return typing.cast("Fis", jsii.invoke(self, "toGetAction", []))

    @jsii.member(jsii_name="toGetExperiment")
    def to_get_experiment(self) -> "Fis":
        '''(experimental) Grants permission to retrieve an AWS FIS experiment.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/fis/latest/APIReference/API_GetExperiment.html

        :stability: experimental
        '''
        return typing.cast("Fis", jsii.invoke(self, "toGetExperiment", []))

    @jsii.member(jsii_name="toGetExperimentTemplate")
    def to_get_experiment_template(self) -> "Fis":
        '''(experimental) Grants permission to retrieve an AWS FIS Experiment Template.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/fis/latest/APIReference/API_GetExperimentTemplate.html

        :stability: experimental
        '''
        return typing.cast("Fis", jsii.invoke(self, "toGetExperimentTemplate", []))

    @jsii.member(jsii_name="toGetTargetResourceType")
    def to_get_target_resource_type(self) -> "Fis":
        '''(experimental) Grants permission to get information about the specified resource type.

        Access Level: Read

        https://docs.aws.amazon.com/fis/latest/APIReference/API_GetTargetResourceType.html

        :stability: experimental
        '''
        return typing.cast("Fis", jsii.invoke(self, "toGetTargetResourceType", []))

    @jsii.member(jsii_name="toInjectApiInternalError")
    def to_inject_api_internal_error(self) -> "Fis":
        '''(experimental) Grants permission to inject an API internal error on the provided AWS service from an FIS Experiment.

        Access Level: Write

        Possible conditions:

        - .ifService()
        - .ifOperations()
        - .ifPercentage()
        - .ifTargets()

        https://docs.aws.amazon.com/fis/latest/userguide/fis-actions-reference.html#fis-actions-reference-fis

        :stability: experimental
        '''
        return typing.cast("Fis", jsii.invoke(self, "toInjectApiInternalError", []))

    @jsii.member(jsii_name="toInjectApiThrottleError")
    def to_inject_api_throttle_error(self) -> "Fis":
        '''(experimental) Grants permission to inject an API throttle error on the provided AWS service from an FIS Experiment.

        Access Level: Write

        Possible conditions:

        - .ifService()
        - .ifOperations()
        - .ifPercentage()
        - .ifTargets()

        https://docs.aws.amazon.com/fis/latest/userguide/fis-actions-reference.html#fis-actions-reference-fis

        :stability: experimental
        '''
        return typing.cast("Fis", jsii.invoke(self, "toInjectApiThrottleError", []))

    @jsii.member(jsii_name="toInjectApiUnavailableError")
    def to_inject_api_unavailable_error(self) -> "Fis":
        '''(experimental) Grants permission to inject an API unavailable error on the provided AWS service from an FIS Experiment.

        Access Level: Write

        Possible conditions:

        - .ifService()
        - .ifOperations()
        - .ifPercentage()
        - .ifTargets()

        https://docs.aws.amazon.com/fis/latest/userguide/fis-actions-reference.html#fis-actions-reference-fis

        :stability: experimental
        '''
        return typing.cast("Fis", jsii.invoke(self, "toInjectApiUnavailableError", []))

    @jsii.member(jsii_name="toListActions")
    def to_list_actions(self) -> "Fis":
        '''(experimental) Grants permission to list all available AWS FIS actions.

        Access Level: List

        https://docs.aws.amazon.com/fis/latest/APIReference/API_ListActions.html

        :stability: experimental
        '''
        return typing.cast("Fis", jsii.invoke(self, "toListActions", []))

    @jsii.member(jsii_name="toListExperiments")
    def to_list_experiments(self) -> "Fis":
        '''(experimental) Grants permission to list all available AWS FIS experiments.

        Access Level: List

        https://docs.aws.amazon.com/fis/latest/APIReference/API_ListExperiments.html

        :stability: experimental
        '''
        return typing.cast("Fis", jsii.invoke(self, "toListExperiments", []))

    @jsii.member(jsii_name="toListExperimentTemplates")
    def to_list_experiment_templates(self) -> "Fis":
        '''(experimental) Grants permission to list all available AWS FIS experiment templates.

        Access Level: List

        https://docs.aws.amazon.com/fis/latest/APIReference/API_ListExperimentTemplates.html

        :stability: experimental
        '''
        return typing.cast("Fis", jsii.invoke(self, "toListExperimentTemplates", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Fis":
        '''(experimental) Grants permission to list the tags for an AWS FIS resource.

        Access Level: Read

        https://docs.aws.amazon.com/fis/latest/APIReference/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("Fis", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toListTargetResourceTypes")
    def to_list_target_resource_types(self) -> "Fis":
        '''(experimental) Grants permission to list the resource types.

        Access Level: List

        https://docs.aws.amazon.com/fis/latest/APIReference/API_ListTargetResourceTypes.html

        :stability: experimental
        '''
        return typing.cast("Fis", jsii.invoke(self, "toListTargetResourceTypes", []))

    @jsii.member(jsii_name="toStartExperiment")
    def to_start_experiment(self) -> "Fis":
        '''(experimental) Grants permission to run an AWS FIS experiment.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - iam:CreateServiceLinkedRole

        https://docs.aws.amazon.com/fis/latest/APIReference/API_StartExperiment.html

        :stability: experimental
        '''
        return typing.cast("Fis", jsii.invoke(self, "toStartExperiment", []))

    @jsii.member(jsii_name="toStopExperiment")
    def to_stop_experiment(self) -> "Fis":
        '''(experimental) Grants permission to stop an AWS FIS experiment.

        Access Level: Write

        https://docs.aws.amazon.com/fis/latest/APIReference/API_StopExperiment.html

        :stability: experimental
        '''
        return typing.cast("Fis", jsii.invoke(self, "toStopExperiment", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Fis":
        '''(experimental) Grants permission to tag AWS FIS resources.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/fis/latest/APIReference/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("Fis", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Fis":
        '''(experimental) Grants permission to untag AWS FIS resources.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/fis/latest/APIReference/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("Fis", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateExperimentTemplate")
    def to_update_experiment_template(self) -> "Fis":
        '''(experimental) Grants permission to update the specified AWS FIS experiment template.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/fis/latest/APIReference/API_UpdateExperimentTemplate.html

        :stability: experimental
        '''
        return typing.cast("Fis", jsii.invoke(self, "toUpdateExperimentTemplate", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__29f82d9232ebeb0349f58469014571c7d9f757edd6c4c347c7fa100fb3b917fa)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a0da6b773ccb7afb8878b3a9ede560e4271cadc6c751f314ea5a636d2c2c77c5)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Fms(PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Fms"):
    '''(experimental) Statement provider for service `fms <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsfirewallmanager.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `fms <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsfirewallmanager.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onApplicationsList")
    def on_applications_list(
        self,
        id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Fms":
        '''(experimental) Adds a resource of type applications-list to the statement.

        https://docs.aws.amazon.com/fms/2018-01-01/APIReference/API_AppsListData.html

        :param id: - Identifier for the id.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__02d4ea787813335ac55c32d0e3b330a77c0b530c7d6f8c6a3d32874b9dd92beb)
            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Fms", jsii.invoke(self, "onApplicationsList", [id, account, region, partition]))

    @jsii.member(jsii_name="onPolicy")
    def on_policy(
        self,
        id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Fms":
        '''(experimental) Adds a resource of type policy to the statement.

        https://docs.aws.amazon.com/fms/2018-01-01/APIReference/API_Policy.html

        :param id: - Identifier for the id.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e046583efbec001e98cad66044082a2731b428d8563963bdb60f6e6c68d542d6)
            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Fms", jsii.invoke(self, "onPolicy", [id, account, region, partition]))

    @jsii.member(jsii_name="onProtocolsList")
    def on_protocols_list(
        self,
        id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Fms":
        '''(experimental) Adds a resource of type protocols-list to the statement.

        https://docs.aws.amazon.com/fms/2018-01-01/APIReference/API_ProtocolsListData.html

        :param id: - Identifier for the id.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0166fc75154ba8dbe31bf853c55beb5eca3f22358a51679650da0c8be2e92efc)
            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Fms", jsii.invoke(self, "onProtocolsList", [id, account, region, partition]))

    @jsii.member(jsii_name="onResourceSet")
    def on_resource_set(
        self,
        id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Fms":
        '''(experimental) Adds a resource of type resource-set to the statement.

        https://docs.aws.amazon.com/fms/2018-01-01/APIReference/API_ResourceSet.html

        :param id: - Identifier for the id.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f90238056374d9f2e8f15f6a47cf2b030da27fa262d405573884e9348ab21096)
            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Fms", jsii.invoke(self, "onResourceSet", [id, account, region, partition]))

    @jsii.member(jsii_name="toAssociateAdminAccount")
    def to_associate_admin_account(self) -> "Fms":
        '''(experimental) Grants permission to set the AWS Firewall Manager administrator account and enables the service in all organization accounts.

        Access Level: Write

        https://docs.aws.amazon.com/fms/2018-01-01/APIReference/API_AssociateAdminAccount.html

        :stability: experimental
        '''
        return typing.cast("Fms", jsii.invoke(self, "toAssociateAdminAccount", []))

    @jsii.member(jsii_name="toAssociateThirdPartyFirewall")
    def to_associate_third_party_firewall(self) -> "Fms":
        '''(experimental) Grants permission to set the Firewall Manager administrator as a tenant administrator of a third-party firewall service.

        Access Level: Write

        https://docs.aws.amazon.com/fms/2018-01-01/APIReference/API_AssociateThirdPartyFirewall.html

        :stability: experimental
        '''
        return typing.cast("Fms", jsii.invoke(self, "toAssociateThirdPartyFirewall", []))

    @jsii.member(jsii_name="toBatchAssociateResource")
    def to_batch_associate_resource(self) -> "Fms":
        '''(experimental) Grants permission to associate resources to an AWS Firewall Manager resource set.

        Access Level: Write

        https://docs.aws.amazon.com/fms/2018-01-01/APIReference/API_BatchAssociateResource.html

        :stability: experimental
        '''
        return typing.cast("Fms", jsii.invoke(self, "toBatchAssociateResource", []))

    @jsii.member(jsii_name="toBatchDisassociateResource")
    def to_batch_disassociate_resource(self) -> "Fms":
        '''(experimental) Grants permission to disassociate resources from an AWS Firewall Manager resource set.

        Access Level: Write

        https://docs.aws.amazon.com/fms/2018-01-01/APIReference/API_BatchDisassociateResource.html

        :stability: experimental
        '''
        return typing.cast("Fms", jsii.invoke(self, "toBatchDisassociateResource", []))

    @jsii.member(jsii_name="toDeleteAppsList")
    def to_delete_apps_list(self) -> "Fms":
        '''(experimental) Grants permission to permanently deletes an AWS Firewall Manager applications list.

        Access Level: Write

        https://docs.aws.amazon.com/fms/2018-01-01/APIReference/API_DeleteAppsList.html

        :stability: experimental
        '''
        return typing.cast("Fms", jsii.invoke(self, "toDeleteAppsList", []))

    @jsii.member(jsii_name="toDeleteNotificationChannel")
    def to_delete_notification_channel(self) -> "Fms":
        '''(experimental) Grants permission to delete an AWS Firewall Manager association with the IAM role and the Amazon Simple Notification Service (SNS) topic that is used to notify the FM administrator about major FM events and errors across the organization.

        Access Level: Write

        https://docs.aws.amazon.com/fms/2018-01-01/APIReference/API_DeleteNotificationChannel.html

        :stability: experimental
        '''
        return typing.cast("Fms", jsii.invoke(self, "toDeleteNotificationChannel", []))

    @jsii.member(jsii_name="toDeletePolicy")
    def to_delete_policy(self) -> "Fms":
        '''(experimental) Grants permission to permanently delete an AWS Firewall Manager policy.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/fms/2018-01-01/APIReference/API_DeletePolicy.html

        :stability: experimental
        '''
        return typing.cast("Fms", jsii.invoke(self, "toDeletePolicy", []))

    @jsii.member(jsii_name="toDeleteProtocolsList")
    def to_delete_protocols_list(self) -> "Fms":
        '''(experimental) Grants permission to permanently deletes an AWS Firewall Manager protocols list.

        Access Level: Write

        https://docs.aws.amazon.com/fms/2018-01-01/APIReference/API_DeleteProtocolsList.html

        :stability: experimental
        '''
        return typing.cast("Fms", jsii.invoke(self, "toDeleteProtocolsList", []))

    @jsii.member(jsii_name="toDeleteResourceSet")
    def to_delete_resource_set(self) -> "Fms":
        '''(experimental) Grants permission to permanently delete an AWS Firewall Manager resource set.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/fms/2018-01-01/APIReference/API_DeleteResourceSet.html

        :stability: experimental
        '''
        return typing.cast("Fms", jsii.invoke(self, "toDeleteResourceSet", []))

    @jsii.member(jsii_name="toDisassociateAdminAccount")
    def to_disassociate_admin_account(self) -> "Fms":
        '''(experimental) Grants permission to disassociate the account that has been set as the AWS Firewall Manager administrator account and and disables the service in all organization accounts.

        Access Level: Write

        https://docs.aws.amazon.com/fms/2018-01-01/APIReference/API_DisassociateAdminAccount.html

        :stability: experimental
        '''
        return typing.cast("Fms", jsii.invoke(self, "toDisassociateAdminAccount", []))

    @jsii.member(jsii_name="toDisassociateThirdPartyFirewall")
    def to_disassociate_third_party_firewall(self) -> "Fms":
        '''(experimental) Grants permission to disassociate a Firewall Manager administrator from a third-party firewall tenant.

        Access Level: Write

        https://docs.aws.amazon.com/fms/2018-01-01/APIReference/API_DisassociateThirdPartyFirewall.html

        :stability: experimental
        '''
        return typing.cast("Fms", jsii.invoke(self, "toDisassociateThirdPartyFirewall", []))

    @jsii.member(jsii_name="toGetAdminAccount")
    def to_get_admin_account(self) -> "Fms":
        '''(experimental) Grants permission to retrieve the AWS Organizations master account that is associated with AWS Firewall Manager as the AWS Firewall Manager administrator.

        Access Level: Read

        https://docs.aws.amazon.com/fms/2018-01-01/APIReference/API_GetAdminAccount.html

        :stability: experimental
        '''
        return typing.cast("Fms", jsii.invoke(self, "toGetAdminAccount", []))

    @jsii.member(jsii_name="toGetAppsList")
    def to_get_apps_list(self) -> "Fms":
        '''(experimental) Grants permission to return information about the specified AWS Firewall Manager applications list.

        Access Level: Read

        https://docs.aws.amazon.com/fms/2018-01-01/APIReference/API_GetAppsList.html

        :stability: experimental
        '''
        return typing.cast("Fms", jsii.invoke(self, "toGetAppsList", []))

    @jsii.member(jsii_name="toGetComplianceDetail")
    def to_get_compliance_detail(self) -> "Fms":
        '''(experimental) Grants permission to retrieve detailed compliance information about the specified member account.

        Details include resources that are in and out of compliance with the specified policy

        Access Level: Read

        https://docs.aws.amazon.com/fms/2018-01-01/APIReference/API_GetComplianceDetail.html

        :stability: experimental
        '''
        return typing.cast("Fms", jsii.invoke(self, "toGetComplianceDetail", []))

    @jsii.member(jsii_name="toGetNotificationChannel")
    def to_get_notification_channel(self) -> "Fms":
        '''(experimental) Grants permission to retrieve information about the Amazon Simple Notification Service (SNS) topic that is used to record AWS Firewall Manager SNS logs.

        Access Level: Read

        https://docs.aws.amazon.com/fms/2018-01-01/APIReference/API_GetNotificationChannel.html

        :stability: experimental
        '''
        return typing.cast("Fms", jsii.invoke(self, "toGetNotificationChannel", []))

    @jsii.member(jsii_name="toGetPolicy")
    def to_get_policy(self) -> "Fms":
        '''(experimental) Grants permission to retrieve information about the specified AWS Firewall Manager policy.

        Access Level: Read

        https://docs.aws.amazon.com/fms/2018-01-01/APIReference/API_GetPolicy.html

        :stability: experimental
        '''
        return typing.cast("Fms", jsii.invoke(self, "toGetPolicy", []))

    @jsii.member(jsii_name="toGetProtectionStatus")
    def to_get_protection_status(self) -> "Fms":
        '''(experimental) Grants permission to retrieve policy-level attack summary information in the event of a potential DDoS attack.

        Access Level: Read

        https://docs.aws.amazon.com/fms/2018-01-01/APIReference/API_GetProtectionStatus.html

        :stability: experimental
        '''
        return typing.cast("Fms", jsii.invoke(self, "toGetProtectionStatus", []))

    @jsii.member(jsii_name="toGetProtocolsList")
    def to_get_protocols_list(self) -> "Fms":
        '''(experimental) Grants permission to return information about the specified AWS Firewall Manager protocols list.

        Access Level: Read

        https://docs.aws.amazon.com/fms/2018-01-01/APIReference/API_GetProtocolsList.html

        :stability: experimental
        '''
        return typing.cast("Fms", jsii.invoke(self, "toGetProtocolsList", []))

    @jsii.member(jsii_name="toGetResourceSet")
    def to_get_resource_set(self) -> "Fms":
        '''(experimental) Grants permission to retrieve information about the specified AWS Firewall Manager resource set.

        Access Level: Read

        https://docs.aws.amazon.com/fms/2018-01-01/APIReference/API_GetResourceSet.html

        :stability: experimental
        '''
        return typing.cast("Fms", jsii.invoke(self, "toGetResourceSet", []))

    @jsii.member(jsii_name="toGetThirdPartyFirewallAssociationStatus")
    def to_get_third_party_firewall_association_status(self) -> "Fms":
        '''(experimental) Grants permission to retrieve the onboarding status of a Firewall Manager administrator account to third-party firewall vendor tenant.

        Access Level: Read

        https://docs.aws.amazon.com/fms/2018-01-01/APIReference/API_GetThirdPartyFirewallAssociationStatus.html

        :stability: experimental
        '''
        return typing.cast("Fms", jsii.invoke(self, "toGetThirdPartyFirewallAssociationStatus", []))

    @jsii.member(jsii_name="toGetViolationDetails")
    def to_get_violation_details(self) -> "Fms":
        '''(experimental) Grants permission to retrieve violations for a resource based on the specified AWS Firewall Manager policy and AWS account.

        Access Level: Read

        https://docs.aws.amazon.com/fms/2018-01-01/APIReference/API_GetViolationDetails.html

        :stability: experimental
        '''
        return typing.cast("Fms", jsii.invoke(self, "toGetViolationDetails", []))

    @jsii.member(jsii_name="toListAppsLists")
    def to_list_apps_lists(self) -> "Fms":
        '''(experimental) Grants permission to return an array of AppsListDataSummary objects.

        Access Level: List

        https://docs.aws.amazon.com/fms/2018-01-01/APIReference/API_ListAppsLists.html

        :stability: experimental
        '''
        return typing.cast("Fms", jsii.invoke(self, "toListAppsLists", []))

    @jsii.member(jsii_name="toListComplianceStatus")
    def to_list_compliance_status(self) -> "Fms":
        '''(experimental) Grants permission to retrieve an array of PolicyComplianceStatus objects in the response.

        Use PolicyComplianceStatus to get a summary of which member accounts are protected by the specified policy

        Access Level: List

        https://docs.aws.amazon.com/fms/2018-01-01/APIReference/API_ListComplianceStatus.html

        :stability: experimental
        '''
        return typing.cast("Fms", jsii.invoke(self, "toListComplianceStatus", []))

    @jsii.member(jsii_name="toListDiscoveredResources")
    def to_list_discovered_resources(self) -> "Fms":
        '''(experimental) Grants permission to retrieve an array of resources in the organization's accounts that are available to be associated with a resource set.

        Access Level: List

        https://docs.aws.amazon.com/fms/2018-01-01/APIReference/API_ListDiscoveredResources.html

        :stability: experimental
        '''
        return typing.cast("Fms", jsii.invoke(self, "toListDiscoveredResources", []))

    @jsii.member(jsii_name="toListMemberAccounts")
    def to_list_member_accounts(self) -> "Fms":
        '''(experimental) Grants permission to retrieve an array of member account ids if the caller is FMS admin account.

        Access Level: List

        https://docs.aws.amazon.com/fms/2018-01-01/APIReference/API_ListMemberAccounts.html

        :stability: experimental
        '''
        return typing.cast("Fms", jsii.invoke(self, "toListMemberAccounts", []))

    @jsii.member(jsii_name="toListPolicies")
    def to_list_policies(self) -> "Fms":
        '''(experimental) Grants permission to retrieve an array of PolicySummary objects in the response.

        Access Level: List

        https://docs.aws.amazon.com/fms/2018-01-01/APIReference/API_ListPolicies.html

        :stability: experimental
        '''
        return typing.cast("Fms", jsii.invoke(self, "toListPolicies", []))

    @jsii.member(jsii_name="toListProtocolsLists")
    def to_list_protocols_lists(self) -> "Fms":
        '''(experimental) Grants permission to return an array of ProtocolsListDataSummary objects.

        Access Level: List

        https://docs.aws.amazon.com/fms/2018-01-01/APIReference/API_ListProtocolsLists.html

        :stability: experimental
        '''
        return typing.cast("Fms", jsii.invoke(self, "toListProtocolsLists", []))

    @jsii.member(jsii_name="toListResourceSetResources")
    def to_list_resource_set_resources(self) -> "Fms":
        '''(experimental) Grants permission to retrieve an array of resources that are currently associated to a resource set.

        Access Level: List

        https://docs.aws.amazon.com/fms/2018-01-01/APIReference/API_ListResourceSetResources.html

        :stability: experimental
        '''
        return typing.cast("Fms", jsii.invoke(self, "toListResourceSetResources", []))

    @jsii.member(jsii_name="toListResourceSets")
    def to_list_resource_sets(self) -> "Fms":
        '''(experimental) Grants permission to retrieve an array of ResourceSetSummary objects.

        Access Level: List

        https://docs.aws.amazon.com/fms/2018-01-01/APIReference/API_ListResourceSets.html

        :stability: experimental
        '''
        return typing.cast("Fms", jsii.invoke(self, "toListResourceSets", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Fms":
        '''(experimental) Grants permission to list Tags for a given resource.

        Access Level: Read

        https://docs.aws.amazon.com/fms/2018-01-01/APIReference/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("Fms", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toListThirdPartyFirewallFirewallPolicies")
    def to_list_third_party_firewall_firewall_policies(self) -> "Fms":
        '''(experimental) Grants permission to retrieve a list of all of the third-party firewall policies that are associated with the third-party firewall administrator's account.

        Access Level: List

        https://docs.aws.amazon.com/fms/2018-01-01/APIReference/API_ListThirdPartyFirewallFirewallPolicies.html

        :stability: experimental
        '''
        return typing.cast("Fms", jsii.invoke(self, "toListThirdPartyFirewallFirewallPolicies", []))

    @jsii.member(jsii_name="toPutAppsList")
    def to_put_apps_list(self) -> "Fms":
        '''(experimental) Grants permission to create an AWS Firewall Manager applications list.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/fms/2018-01-01/APIReference/API_PutAppsList.html

        :stability: experimental
        '''
        return typing.cast("Fms", jsii.invoke(self, "toPutAppsList", []))

    @jsii.member(jsii_name="toPutNotificationChannel")
    def to_put_notification_channel(self) -> "Fms":
        '''(experimental) Grants permission to designate the IAM role and Amazon Simple Notification Service (SNS) topic that AWS Firewall Manager (FM) could use to notify the FM administrator about major FM events and errors across the organization.

        Access Level: Write

        https://docs.aws.amazon.com/fms/2018-01-01/APIReference/API_PutNotificationChannel.html

        :stability: experimental
        '''
        return typing.cast("Fms", jsii.invoke(self, "toPutNotificationChannel", []))

    @jsii.member(jsii_name="toPutPolicy")
    def to_put_policy(self) -> "Fms":
        '''(experimental) Grants permission to create an AWS Firewall Manager policy.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/fms/2018-01-01/APIReference/API_PutPolicy.html

        :stability: experimental
        '''
        return typing.cast("Fms", jsii.invoke(self, "toPutPolicy", []))

    @jsii.member(jsii_name="toPutProtocolsList")
    def to_put_protocols_list(self) -> "Fms":
        '''(experimental) Grants permission to creates an AWS Firewall Manager protocols list.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/fms/2018-01-01/APIReference/API_PutProtocolsList.html

        :stability: experimental
        '''
        return typing.cast("Fms", jsii.invoke(self, "toPutProtocolsList", []))

    @jsii.member(jsii_name="toPutResourceSet")
    def to_put_resource_set(self) -> "Fms":
        '''(experimental) Grants permission to create an AWS Firewall Manager resource set.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/fms/2018-01-01/APIReference/API_PutResourceSet.html

        :stability: experimental
        '''
        return typing.cast("Fms", jsii.invoke(self, "toPutResourceSet", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Fms":
        '''(experimental) Grants permission to add a Tag to a given resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/fms/2018-01-01/APIReference/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("Fms", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Fms":
        '''(experimental) Grants permission to remove a Tag from a given resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/fms/2018-01-01/APIReference/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("Fms", jsii.invoke(self, "toUntagResource", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8f0df2a098414874c48ce8f4697641f54e284b3d1dd2c2d0226696ecaab79d4c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8a81b88e42b095bd31df513e665061c3770e4fac310b72cb5a34fa56760d8c84)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Forecast(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Forecast",
):
    '''(experimental) Statement provider for service `forecast <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonforecast.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `forecast <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonforecast.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onAlgorithm")
    def on_algorithm(
        self,
        resource_id: builtins.str,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Forecast":
        '''(experimental) Adds a resource of type algorithm to the statement.

        https://docs.aws.amazon.com/forecast/latest/dg/aws-forecast-choosing-recipes.html

        :param resource_id: - Identifier for the resourceId.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d0461e7397d4f9e00f26b21ed8433b8d333ce5480c8ceb3ee15fcf0276c4e217)
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Forecast", jsii.invoke(self, "onAlgorithm", [resource_id, partition]))

    @jsii.member(jsii_name="onDataset")
    def on_dataset(
        self,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Forecast":
        '''(experimental) Adds a resource of type dataset to the statement.

        https://docs.aws.amazon.com/forecast/latest/dg/API_CreateDataset.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bac8e0539267dd1aed77231158fcb7a88efb5e66fe294caed8c47197fe247f2d)
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Forecast", jsii.invoke(self, "onDataset", [resource_id, account, region, partition]))

    @jsii.member(jsii_name="onDatasetGroup")
    def on_dataset_group(
        self,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Forecast":
        '''(experimental) Adds a resource of type datasetGroup to the statement.

        https://docs.aws.amazon.com/forecast/latest/dg/API_CreateDatasetGroup.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__53a48c6e09c5ebc2e7fd00f7d0df4e5f782c93a72d1c7400a1083d2a7a680b4a)
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Forecast", jsii.invoke(self, "onDatasetGroup", [resource_id, account, region, partition]))

    @jsii.member(jsii_name="onDatasetImportJob")
    def on_dataset_import_job(
        self,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Forecast":
        '''(experimental) Adds a resource of type datasetImportJob to the statement.

        https://docs.aws.amazon.com/forecast/latest/dg/API_CreateDatasetImportJob.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9aeeb568cdfb8cb2736746a962ec0c5abff587202297c5f17abdd9777e47b264)
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Forecast", jsii.invoke(self, "onDatasetImportJob", [resource_id, account, region, partition]))

    @jsii.member(jsii_name="onEndpoint")
    def on_endpoint(
        self,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Forecast":
        '''(experimental) Adds a resource of type endpoint to the statement.

        https://docs.aws.amazon.com/forecast/latest/dg/what-is-forecast.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c1e6ee22a3802aa14400b628c99c4126d57f635408ed82a09bf79ced0a2da979)
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Forecast", jsii.invoke(self, "onEndpoint", [resource_id, account, region, partition]))

    @jsii.member(jsii_name="onExplainability")
    def on_explainability(
        self,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Forecast":
        '''(experimental) Adds a resource of type explainability to the statement.

        https://docs.aws.amazon.com/forecast/latest/dg/API_CreateExplainability.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__dcd5960a3eb0b3977be0a8ec9b73f4497adbf34ce61435c690736d3913e90b25)
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Forecast", jsii.invoke(self, "onExplainability", [resource_id, account, region, partition]))

    @jsii.member(jsii_name="onExplainabilityExport")
    def on_explainability_export(
        self,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Forecast":
        '''(experimental) Adds a resource of type explainabilityExport to the statement.

        https://docs.aws.amazon.com/forecast/latest/dg/API_CreateExplainabilityExport.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7a6d73f87bd50dbea2c56f841370e60fd848c210dd45e6e34fc791bcacc60db5)
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Forecast", jsii.invoke(self, "onExplainabilityExport", [resource_id, account, region, partition]))

    @jsii.member(jsii_name="onForecast")
    def on_forecast(
        self,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Forecast":
        '''(experimental) Adds a resource of type forecast to the statement.

        https://docs.aws.amazon.com/forecast/latest/dg/API_CreateForecast.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__72fbb45bb96418ecc64daa839ad09f81b2dfcacd4cbdbdba66560d3bfaeee9a9)
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Forecast", jsii.invoke(self, "onForecast", [resource_id, account, region, partition]))

    @jsii.member(jsii_name="onForecastExport")
    def on_forecast_export(
        self,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Forecast":
        '''(experimental) Adds a resource of type forecastExport to the statement.

        https://docs.aws.amazon.com/forecast/latest/dg/API_CreateForecastExportJob.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bda4e5b31abf87a2835566d64efc3767bad96a7f4ec8ae913a6642f743ba63cc)
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Forecast", jsii.invoke(self, "onForecastExport", [resource_id, account, region, partition]))

    @jsii.member(jsii_name="onMonitor")
    def on_monitor(
        self,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Forecast":
        '''(experimental) Adds a resource of type monitor to the statement.

        https://docs.aws.amazon.com/forecast/latest/dg/API_CreateMonitor.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0241e29d4a1d7bd4ab4030faad810f7934154f6650e543d1c95cd78c107b9c94)
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Forecast", jsii.invoke(self, "onMonitor", [resource_id, account, region, partition]))

    @jsii.member(jsii_name="onPredictor")
    def on_predictor(
        self,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Forecast":
        '''(experimental) Adds a resource of type predictor to the statement.

        https://docs.aws.amazon.com/forecast/latest/dg/API_CreatePredictor.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b3d71d7e2bd82edbe454653b3c4d1c4318c6685167015f53e4faccf665a757c8)
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Forecast", jsii.invoke(self, "onPredictor", [resource_id, account, region, partition]))

    @jsii.member(jsii_name="onPredictorBacktestExportJob")
    def on_predictor_backtest_export_job(
        self,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Forecast":
        '''(experimental) Adds a resource of type predictorBacktestExportJob to the statement.

        https://docs.aws.amazon.com/forecast/latest/dg/API_CreatePredictorBacktestExportJob.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7b43f746bf9e4a2dae2cc3bf35279d8d590deb01ef9ab04aa1acb5da43a20e09)
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Forecast", jsii.invoke(self, "onPredictorBacktestExportJob", [resource_id, account, region, partition]))

    @jsii.member(jsii_name="onWhatIfAnalysis")
    def on_what_if_analysis(
        self,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Forecast":
        '''(experimental) Adds a resource of type whatIfAnalysis to the statement.

        https://docs.aws.amazon.com/forecast/latest/dg/API_CreateWhatIfAnalysis.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__039070a604c68c4e364e96c94bce2ea230bb7df3816ee4ac8b4d55fae65e83ec)
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Forecast", jsii.invoke(self, "onWhatIfAnalysis", [resource_id, account, region, partition]))

    @jsii.member(jsii_name="onWhatIfForecast")
    def on_what_if_forecast(
        self,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Forecast":
        '''(experimental) Adds a resource of type whatIfForecast to the statement.

        https://docs.aws.amazon.com/forecast/latest/dg/API_CreateWhatIfForecast.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__750ba9d0934c7fdedb79e6011b894abbf4236b42d7f97c180185d97bcc9ffd48)
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Forecast", jsii.invoke(self, "onWhatIfForecast", [resource_id, account, region, partition]))

    @jsii.member(jsii_name="onWhatIfForecastExport")
    def on_what_if_forecast_export(
        self,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Forecast":
        '''(experimental) Adds a resource of type whatIfForecastExport to the statement.

        https://docs.aws.amazon.com/forecast/latest/dg/API_CreateWhatIfForecastExport.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6b9990d4a439d5a3d0606658a727801d752923910f635456a27e5634cc296b2d)
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Forecast", jsii.invoke(self, "onWhatIfForecastExport", [resource_id, account, region, partition]))

    @jsii.member(jsii_name="toCreateAutoPredictor")
    def to_create_auto_predictor(self) -> "Forecast":
        '''(experimental) Grants permission to create an auto predictor.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/forecast/latest/dg/API_CreateAutoPredictor.html

        :stability: experimental
        '''
        return typing.cast("Forecast", jsii.invoke(self, "toCreateAutoPredictor", []))

    @jsii.member(jsii_name="toCreateDataset")
    def to_create_dataset(self) -> "Forecast":
        '''(experimental) Grants permission to create a dataset.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/forecast/latest/dg/API_CreateDataset.html

        :stability: experimental
        '''
        return typing.cast("Forecast", jsii.invoke(self, "toCreateDataset", []))

    @jsii.member(jsii_name="toCreateDatasetGroup")
    def to_create_dataset_group(self) -> "Forecast":
        '''(experimental) Grants permission to create a dataset group.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/forecast/latest/dg/API_CreateDatasetGroup.html

        :stability: experimental
        '''
        return typing.cast("Forecast", jsii.invoke(self, "toCreateDatasetGroup", []))

    @jsii.member(jsii_name="toCreateDatasetImportJob")
    def to_create_dataset_import_job(self) -> "Forecast":
        '''(experimental) Grants permission to create a dataset import job.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/forecast/latest/dg/API_CreateDatasetImportJob.html

        :stability: experimental
        '''
        return typing.cast("Forecast", jsii.invoke(self, "toCreateDatasetImportJob", []))

    @jsii.member(jsii_name="toCreateExplainability")
    def to_create_explainability(self) -> "Forecast":
        '''(experimental) Grants permission to create an explainability.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/forecast/latest/dg/API_CreateExplainability.html

        :stability: experimental
        '''
        return typing.cast("Forecast", jsii.invoke(self, "toCreateExplainability", []))

    @jsii.member(jsii_name="toCreateExplainabilityExport")
    def to_create_explainability_export(self) -> "Forecast":
        '''(experimental) Grants permission to create an explainability export using an explainability resource.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/forecast/latest/dg/API_CreateExplainabilityExport.html

        :stability: experimental
        '''
        return typing.cast("Forecast", jsii.invoke(self, "toCreateExplainabilityExport", []))

    @jsii.member(jsii_name="toCreateForecast")
    def to_create_forecast(self) -> "Forecast":
        '''(experimental) Grants permission to create a forecast.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/forecast/latest/dg/API_CreateForecast.html

        :stability: experimental
        '''
        return typing.cast("Forecast", jsii.invoke(self, "toCreateForecast", []))

    @jsii.member(jsii_name="toCreateForecastEndpoint")
    def to_create_forecast_endpoint(self) -> "Forecast":
        '''(experimental) Grants permission to create an endpoint using a Predictor resource.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/forecast/latest/dg/what-is-forecast.html

        :stability: experimental
        '''
        return typing.cast("Forecast", jsii.invoke(self, "toCreateForecastEndpoint", []))

    @jsii.member(jsii_name="toCreateForecastExportJob")
    def to_create_forecast_export_job(self) -> "Forecast":
        '''(experimental) Grants permission to create a forecast export job using a forecast resource.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/forecast/latest/dg/API_CreateForecastExportJob.html

        :stability: experimental
        '''
        return typing.cast("Forecast", jsii.invoke(self, "toCreateForecastExportJob", []))

    @jsii.member(jsii_name="toCreateMonitor")
    def to_create_monitor(self) -> "Forecast":
        '''(experimental) Grants permission to create an monitor using a Predictor resource.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/forecast/latest/dg/API_CreateMonitor.html

        :stability: experimental
        '''
        return typing.cast("Forecast", jsii.invoke(self, "toCreateMonitor", []))

    @jsii.member(jsii_name="toCreatePredictor")
    def to_create_predictor(self) -> "Forecast":
        '''(experimental) Grants permission to create a predictor.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/forecast/latest/dg/API_CreatePredictor.html

        :stability: experimental
        '''
        return typing.cast("Forecast", jsii.invoke(self, "toCreatePredictor", []))

    @jsii.member(jsii_name="toCreatePredictorBacktestExportJob")
    def to_create_predictor_backtest_export_job(self) -> "Forecast":
        '''(experimental) Grants permission to create a predictor backtest export job using a predictor.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/forecast/latest/dg/API_CreatePredictorBacktestExportJob.html

        :stability: experimental
        '''
        return typing.cast("Forecast", jsii.invoke(self, "toCreatePredictorBacktestExportJob", []))

    @jsii.member(jsii_name="toCreateWhatIfAnalysis")
    def to_create_what_if_analysis(self) -> "Forecast":
        '''(experimental) Grants permission to create a what-if analysis.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/forecast/latest/dg/API_CreateWhatIfAnalysis.html

        :stability: experimental
        '''
        return typing.cast("Forecast", jsii.invoke(self, "toCreateWhatIfAnalysis", []))

    @jsii.member(jsii_name="toCreateWhatIfForecast")
    def to_create_what_if_forecast(self) -> "Forecast":
        '''(experimental) Grants permission to create a what-if forecast.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/forecast/latest/dg/API_CreateWhatIfForecast.html

        :stability: experimental
        '''
        return typing.cast("Forecast", jsii.invoke(self, "toCreateWhatIfForecast", []))

    @jsii.member(jsii_name="toCreateWhatIfForecastExport")
    def to_create_what_if_forecast_export(self) -> "Forecast":
        '''(experimental) Grants permission to create a what-if forecast export using what-if forecast resources.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/forecast/latest/dg/API_CreateWhatIfForecastExport.html

        :stability: experimental
        '''
        return typing.cast("Forecast", jsii.invoke(self, "toCreateWhatIfForecastExport", []))

    @jsii.member(jsii_name="toDeleteDataset")
    def to_delete_dataset(self) -> "Forecast":
        '''(experimental) Grants permission to delete a dataset.

        Access Level: Write

        https://docs.aws.amazon.com/forecast/latest/dg/API_DeleteDataset.html

        :stability: experimental
        '''
        return typing.cast("Forecast", jsii.invoke(self, "toDeleteDataset", []))

    @jsii.member(jsii_name="toDeleteDatasetGroup")
    def to_delete_dataset_group(self) -> "Forecast":
        '''(experimental) Grants permission to delete a dataset group.

        Access Level: Write

        https://docs.aws.amazon.com/forecast/latest/dg/API_DeleteDatasetGroup.html

        :stability: experimental
        '''
        return typing.cast("Forecast", jsii.invoke(self, "toDeleteDatasetGroup", []))

    @jsii.member(jsii_name="toDeleteDatasetImportJob")
    def to_delete_dataset_import_job(self) -> "Forecast":
        '''(experimental) Grants permission to delete a dataset import job.

        Access Level: Write

        https://docs.aws.amazon.com/forecast/latest/dg/API_DeleteDatasetImportJob.html

        :stability: experimental
        '''
        return typing.cast("Forecast", jsii.invoke(self, "toDeleteDatasetImportJob", []))

    @jsii.member(jsii_name="toDeleteExplainability")
    def to_delete_explainability(self) -> "Forecast":
        '''(experimental) Grants permission to delete an explainability.

        Access Level: Write

        https://docs.aws.amazon.com/forecast/latest/dg/API_DeleteExplainability.html

        :stability: experimental
        '''
        return typing.cast("Forecast", jsii.invoke(self, "toDeleteExplainability", []))

    @jsii.member(jsii_name="toDeleteExplainabilityExport")
    def to_delete_explainability_export(self) -> "Forecast":
        '''(experimental) Grants permission to delete an explainability export.

        Access Level: Write

        https://docs.aws.amazon.com/forecast/latest/dg/API_DeleteExplainabilityExport.html

        :stability: experimental
        '''
        return typing.cast("Forecast", jsii.invoke(self, "toDeleteExplainabilityExport", []))

    @jsii.member(jsii_name="toDeleteForecast")
    def to_delete_forecast(self) -> "Forecast":
        '''(experimental) Grants permission to delete a forecast.

        Access Level: Write

        https://docs.aws.amazon.com/forecast/latest/dg/API_DeleteForecast.html

        :stability: experimental
        '''
        return typing.cast("Forecast", jsii.invoke(self, "toDeleteForecast", []))

    @jsii.member(jsii_name="toDeleteForecastEndpoint")
    def to_delete_forecast_endpoint(self) -> "Forecast":
        '''(experimental) Grants permission to delete an endpoint resource.

        Access Level: Write

        https://docs.aws.amazon.com/forecast/latest/dg/what-is-forecast.html

        :stability: experimental
        '''
        return typing.cast("Forecast", jsii.invoke(self, "toDeleteForecastEndpoint", []))

    @jsii.member(jsii_name="toDeleteForecastExportJob")
    def to_delete_forecast_export_job(self) -> "Forecast":
        '''(experimental) Grants permission to delete a forecast export job.

        Access Level: Write

        https://docs.aws.amazon.com/forecast/latest/dg/API_DeleteForecastExportJob.html

        :stability: experimental
        '''
        return typing.cast("Forecast", jsii.invoke(self, "toDeleteForecastExportJob", []))

    @jsii.member(jsii_name="toDeleteMonitor")
    def to_delete_monitor(self) -> "Forecast":
        '''(experimental) Grants permission to delete a monitor resource.

        Access Level: Write

        https://docs.aws.amazon.com/forecast/latest/dg/API_DeleteMonitor.html

        :stability: experimental
        '''
        return typing.cast("Forecast", jsii.invoke(self, "toDeleteMonitor", []))

    @jsii.member(jsii_name="toDeletePredictor")
    def to_delete_predictor(self) -> "Forecast":
        '''(experimental) Grants permission to delete a predictor.

        Access Level: Write

        https://docs.aws.amazon.com/forecast/latest/dg/API_DeletePredictor.html

        :stability: experimental
        '''
        return typing.cast("Forecast", jsii.invoke(self, "toDeletePredictor", []))

    @jsii.member(jsii_name="toDeletePredictorBacktestExportJob")
    def to_delete_predictor_backtest_export_job(self) -> "Forecast":
        '''(experimental) Grants permission to delete a predictor backtest export job.

        Access Level: Write

        https://docs.aws.amazon.com/forecast/latest/dg/API_DeletePredictorBacktestExportJob.html

        :stability: experimental
        '''
        return typing.cast("Forecast", jsii.invoke(self, "toDeletePredictorBacktestExportJob", []))

    @jsii.member(jsii_name="toDeleteResourceTree")
    def to_delete_resource_tree(self) -> "Forecast":
        '''(experimental) Grants permission to delete a resource and its child resources.

        Access Level: Write

        https://docs.aws.amazon.com/forecast/latest/dg/API_DeleteResourceTree.html

        :stability: experimental
        '''
        return typing.cast("Forecast", jsii.invoke(self, "toDeleteResourceTree", []))

    @jsii.member(jsii_name="toDeleteWhatIfAnalysis")
    def to_delete_what_if_analysis(self) -> "Forecast":
        '''(experimental) Grants permission to delete a what-if analysis.

        Access Level: Write

        https://docs.aws.amazon.com/forecast/latest/dg/API_DeleteWhatIfAnalysis.html

        :stability: experimental
        '''
        return typing.cast("Forecast", jsii.invoke(self, "toDeleteWhatIfAnalysis", []))

    @jsii.member(jsii_name="toDeleteWhatIfForecast")
    def to_delete_what_if_forecast(self) -> "Forecast":
        '''(experimental) Grants permission to delete a what-if forecast.

        Access Level: Write

        https://docs.aws.amazon.com/forecast/latest/dg/API_DeleteWhatIfForecast.html

        :stability: experimental
        '''
        return typing.cast("Forecast", jsii.invoke(self, "toDeleteWhatIfForecast", []))

    @jsii.member(jsii_name="toDeleteWhatIfForecastExport")
    def to_delete_what_if_forecast_export(self) -> "Forecast":
        '''(experimental) Grants permission to delete a what-if forecast export.

        Access Level: Write

        https://docs.aws.amazon.com/forecast/latest/dg/API_DeleteWhatIfForecastExport.html

        :stability: experimental
        '''
        return typing.cast("Forecast", jsii.invoke(self, "toDeleteWhatIfForecastExport", []))

    @jsii.member(jsii_name="toDescribeAutoPredictor")
    def to_describe_auto_predictor(self) -> "Forecast":
        '''(experimental) Grants permission to describe an auto predictor.

        Access Level: Read

        https://docs.aws.amazon.com/forecast/latest/dg/API_DescribeAutoPredictor.html

        :stability: experimental
        '''
        return typing.cast("Forecast", jsii.invoke(self, "toDescribeAutoPredictor", []))

    @jsii.member(jsii_name="toDescribeDataset")
    def to_describe_dataset(self) -> "Forecast":
        '''(experimental) Grants permission to describe a dataset.

        Access Level: Read

        https://docs.aws.amazon.com/forecast/latest/dg/API_DescribeDataset.html

        :stability: experimental
        '''
        return typing.cast("Forecast", jsii.invoke(self, "toDescribeDataset", []))

    @jsii.member(jsii_name="toDescribeDatasetGroup")
    def to_describe_dataset_group(self) -> "Forecast":
        '''(experimental) Grants permission to describe a dataset group.

        Access Level: Read

        https://docs.aws.amazon.com/forecast/latest/dg/API_DescribeDatasetGroup.html

        :stability: experimental
        '''
        return typing.cast("Forecast", jsii.invoke(self, "toDescribeDatasetGroup", []))

    @jsii.member(jsii_name="toDescribeDatasetImportJob")
    def to_describe_dataset_import_job(self) -> "Forecast":
        '''(experimental) Grants permission to describe a dataset import job.

        Access Level: Read

        https://docs.aws.amazon.com/forecast/latest/dg/API_DescribeDatasetImportJob.html

        :stability: experimental
        '''
        return typing.cast("Forecast", jsii.invoke(self, "toDescribeDatasetImportJob", []))

    @jsii.member(jsii_name="toDescribeExplainability")
    def to_describe_explainability(self) -> "Forecast":
        '''(experimental) Grants permission to describe an explainability.

        Access Level: Read

        https://docs.aws.amazon.com/forecast/latest/dg/API_DescribeExplainability.html

        :stability: experimental
        '''
        return typing.cast("Forecast", jsii.invoke(self, "toDescribeExplainability", []))

    @jsii.member(jsii_name="toDescribeExplainabilityExport")
    def to_describe_explainability_export(self) -> "Forecast":
        '''(experimental) Grants permission to describe an explainability export.

        Access Level: Read

        https://docs.aws.amazon.com/forecast/latest/dg/API_DescribeExplainabilityExport.html

        :stability: experimental
        '''
        return typing.cast("Forecast", jsii.invoke(self, "toDescribeExplainabilityExport", []))

    @jsii.member(jsii_name="toDescribeForecast")
    def to_describe_forecast(self) -> "Forecast":
        '''(experimental) Grants permission to describe a forecast.

        Access Level: Read

        https://docs.aws.amazon.com/forecast/latest/dg/API_DescribeForecast.html

        :stability: experimental
        '''
        return typing.cast("Forecast", jsii.invoke(self, "toDescribeForecast", []))

    @jsii.member(jsii_name="toDescribeForecastEndpoint")
    def to_describe_forecast_endpoint(self) -> "Forecast":
        '''(experimental) Grants permission to describe an endpoint resource.

        Access Level: Read

        https://docs.aws.amazon.com/forecast/latest/dg/what-is-forecast.html

        :stability: experimental
        '''
        return typing.cast("Forecast", jsii.invoke(self, "toDescribeForecastEndpoint", []))

    @jsii.member(jsii_name="toDescribeForecastExportJob")
    def to_describe_forecast_export_job(self) -> "Forecast":
        '''(experimental) Grants permission to describe a forecast export job.

        Access Level: Read

        https://docs.aws.amazon.com/forecast/latest/dg/API_DescribeForecastExportJob.html

        :stability: experimental
        '''
        return typing.cast("Forecast", jsii.invoke(self, "toDescribeForecastExportJob", []))

    @jsii.member(jsii_name="toDescribeMonitor")
    def to_describe_monitor(self) -> "Forecast":
        '''(experimental) Grants permission to describe an monitor resource.

        Access Level: Read

        https://docs.aws.amazon.com/forecast/latest/dg/API_DescribeMonitor.html

        :stability: experimental
        '''
        return typing.cast("Forecast", jsii.invoke(self, "toDescribeMonitor", []))

    @jsii.member(jsii_name="toDescribePredictor")
    def to_describe_predictor(self) -> "Forecast":
        '''(experimental) Grants permission to describe a predictor.

        Access Level: Read

        https://docs.aws.amazon.com/forecast/latest/dg/API_DescribePredictor.html

        :stability: experimental
        '''
        return typing.cast("Forecast", jsii.invoke(self, "toDescribePredictor", []))

    @jsii.member(jsii_name="toDescribePredictorBacktestExportJob")
    def to_describe_predictor_backtest_export_job(self) -> "Forecast":
        '''(experimental) Grants permission to describe a predictor backtest export job.

        Access Level: Read

        https://docs.aws.amazon.com/forecast/latest/dg/API_DescribePredictorBacktestExportJob.html

        :stability: experimental
        '''
        return typing.cast("Forecast", jsii.invoke(self, "toDescribePredictorBacktestExportJob", []))

    @jsii.member(jsii_name="toDescribeWhatIfAnalysis")
    def to_describe_what_if_analysis(self) -> "Forecast":
        '''(experimental) Grants permission to describe a what-if analysis.

        Access Level: Read

        https://docs.aws.amazon.com/forecast/latest/dg/API_DescribeWhatIfAnalysis.html

        :stability: experimental
        '''
        return typing.cast("Forecast", jsii.invoke(self, "toDescribeWhatIfAnalysis", []))

    @jsii.member(jsii_name="toDescribeWhatIfForecast")
    def to_describe_what_if_forecast(self) -> "Forecast":
        '''(experimental) Grants permission to describe a what-if forecast.

        Access Level: Read

        https://docs.aws.amazon.com/forecast/latest/dg/API_DescribeWhatIfForecast.html

        :stability: experimental
        '''
        return typing.cast("Forecast", jsii.invoke(self, "toDescribeWhatIfForecast", []))

    @jsii.member(jsii_name="toDescribeWhatIfForecastExport")
    def to_describe_what_if_forecast_export(self) -> "Forecast":
        '''(experimental) Grants permission to describe a what-if forecast export.

        Access Level: Read

        https://docs.aws.amazon.com/forecast/latest/dg/API_DescribeWhatIfForecastExport.html

        :stability: experimental
        '''
        return typing.cast("Forecast", jsii.invoke(self, "toDescribeWhatIfForecastExport", []))

    @jsii.member(jsii_name="toGetAccuracyMetrics")
    def to_get_accuracy_metrics(self) -> "Forecast":
        '''(experimental) Grants permission to get the Accuracy Metrics for a predictor.

        Access Level: Read

        https://docs.aws.amazon.com/forecast/latest/dg/API_GetAccuracyMetrics.html

        :stability: experimental
        '''
        return typing.cast("Forecast", jsii.invoke(self, "toGetAccuracyMetrics", []))

    @jsii.member(jsii_name="toGetRecentForecastContext")
    def to_get_recent_forecast_context(self) -> "Forecast":
        '''(experimental) Grants permission to get the forecast context of a timeseries for an endpoint.

        Access Level: Read

        https://docs.aws.amazon.com/forecast/latest/dg/what-is-forecast.html

        :stability: experimental
        '''
        return typing.cast("Forecast", jsii.invoke(self, "toGetRecentForecastContext", []))

    @jsii.member(jsii_name="toInvokeForecastEndpoint")
    def to_invoke_forecast_endpoint(self) -> "Forecast":
        '''(experimental) Grants permission to invoke the endpoint to get forecast for a timeseries.

        Access Level: Read

        https://docs.aws.amazon.com/forecast/latest/dg/what-is-forecast.html

        :stability: experimental
        '''
        return typing.cast("Forecast", jsii.invoke(self, "toInvokeForecastEndpoint", []))

    @jsii.member(jsii_name="toListDatasetGroups")
    def to_list_dataset_groups(self) -> "Forecast":
        '''(experimental) Grants permission to list all the dataset groups.

        Access Level: Read

        https://docs.aws.amazon.com/forecast/latest/dg/API_ListDatasetGroups.html

        :stability: experimental
        '''
        return typing.cast("Forecast", jsii.invoke(self, "toListDatasetGroups", []))

    @jsii.member(jsii_name="toListDatasetImportJobs")
    def to_list_dataset_import_jobs(self) -> "Forecast":
        '''(experimental) Grants permission to list all the dataset import jobs.

        Access Level: Read

        https://docs.aws.amazon.com/forecast/latest/dg/API_ListDatasetImportJobs.html

        :stability: experimental
        '''
        return typing.cast("Forecast", jsii.invoke(self, "toListDatasetImportJobs", []))

    @jsii.member(jsii_name="toListDatasets")
    def to_list_datasets(self) -> "Forecast":
        '''(experimental) Grants permission to list all the datasets.

        Access Level: Read

        https://docs.aws.amazon.com/forecast/latest/dg/API_ListDatasets.html

        :stability: experimental
        '''
        return typing.cast("Forecast", jsii.invoke(self, "toListDatasets", []))

    @jsii.member(jsii_name="toListExplainabilities")
    def to_list_explainabilities(self) -> "Forecast":
        '''(experimental) Grants permission to list all the explainabilities.

        Access Level: Read

        https://docs.aws.amazon.com/forecast/latest/dg/API_ListExplainabilities.html

        :stability: experimental
        '''
        return typing.cast("Forecast", jsii.invoke(self, "toListExplainabilities", []))

    @jsii.member(jsii_name="toListExplainabilityExports")
    def to_list_explainability_exports(self) -> "Forecast":
        '''(experimental) Grants permission to list all the explainability exports.

        Access Level: Read

        https://docs.aws.amazon.com/forecast/latest/dg/API_ListExplainabilityExports.html

        :stability: experimental
        '''
        return typing.cast("Forecast", jsii.invoke(self, "toListExplainabilityExports", []))

    @jsii.member(jsii_name="toListForecastExportJobs")
    def to_list_forecast_export_jobs(self) -> "Forecast":
        '''(experimental) Grants permission to list all the forecast export jobs.

        Access Level: Read

        https://docs.aws.amazon.com/forecast/latest/dg/API_ListForecastExportJobs.html

        :stability: experimental
        '''
        return typing.cast("Forecast", jsii.invoke(self, "toListForecastExportJobs", []))

    @jsii.member(jsii_name="toListForecasts")
    def to_list_forecasts(self) -> "Forecast":
        '''(experimental) Grants permission to list all the forecasts.

        Access Level: Read

        https://docs.aws.amazon.com/forecast/latest/dg/API_ListForecasts.html

        :stability: experimental
        '''
        return typing.cast("Forecast", jsii.invoke(self, "toListForecasts", []))

    @jsii.member(jsii_name="toListMonitorEvaluations")
    def to_list_monitor_evaluations(self) -> "Forecast":
        '''(experimental) Grants permission to list all the monitor evaluation result for a monitor.

        Access Level: Read

        https://docs.aws.amazon.com/forecast/latest/dg/API_ListMonitorEvaluations.html

        :stability: experimental
        '''
        return typing.cast("Forecast", jsii.invoke(self, "toListMonitorEvaluations", []))

    @jsii.member(jsii_name="toListMonitors")
    def to_list_monitors(self) -> "Forecast":
        '''(experimental) Grants permission to list all the monitor resources.

        Access Level: Read

        https://docs.aws.amazon.com/forecast/latest/dg/API_ListMonitors.html

        :stability: experimental
        '''
        return typing.cast("Forecast", jsii.invoke(self, "toListMonitors", []))

    @jsii.member(jsii_name="toListPredictorBacktestExportJobs")
    def to_list_predictor_backtest_export_jobs(self) -> "Forecast":
        '''(experimental) Grants permission to list all the predictor backtest export jobs.

        Access Level: Read

        https://docs.aws.amazon.com/forecast/latest/dg/API_ListPredictorBacktestExportJobs.html

        :stability: experimental
        '''
        return typing.cast("Forecast", jsii.invoke(self, "toListPredictorBacktestExportJobs", []))

    @jsii.member(jsii_name="toListPredictors")
    def to_list_predictors(self) -> "Forecast":
        '''(experimental) Grants permission to list all the predictors.

        Access Level: Read

        https://docs.aws.amazon.com/forecast/latest/dg/API_ListPredictors.html

        :stability: experimental
        '''
        return typing.cast("Forecast", jsii.invoke(self, "toListPredictors", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Forecast":
        '''(experimental) Grants permission to list the tags for an Amazon Forecast resource.

        Access Level: Read

        https://docs.aws.amazon.com/forecast/latest/dg/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("Forecast", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toListWhatIfAnalyses")
    def to_list_what_if_analyses(self) -> "Forecast":
        '''(experimental) Grants permission to list all the what-if analyses.

        Access Level: Read

        https://docs.aws.amazon.com/forecast/latest/dg/API_ListWhatIfAnalyses.html

        :stability: experimental
        '''
        return typing.cast("Forecast", jsii.invoke(self, "toListWhatIfAnalyses", []))

    @jsii.member(jsii_name="toListWhatIfForecastExports")
    def to_list_what_if_forecast_exports(self) -> "Forecast":
        '''(experimental) Grants permission to list all the what-if forecast exports.

        Access Level: Read

        https://docs.aws.amazon.com/forecast/latest/dg/API_ListWhatIfForecastExports.html

        :stability: experimental
        '''
        return typing.cast("Forecast", jsii.invoke(self, "toListWhatIfForecastExports", []))

    @jsii.member(jsii_name="toListWhatIfForecasts")
    def to_list_what_if_forecasts(self) -> "Forecast":
        '''(experimental) Grants permission to list all the what-if forecasts.

        Access Level: Read

        https://docs.aws.amazon.com/forecast/latest/dg/API_ListWhatIfForecasts.html

        :stability: experimental
        '''
        return typing.cast("Forecast", jsii.invoke(self, "toListWhatIfForecasts", []))

    @jsii.member(jsii_name="toQueryForecast")
    def to_query_forecast(self) -> "Forecast":
        '''(experimental) Grants permission to retrieve a forecast for a single item.

        Access Level: Read

        https://docs.aws.amazon.com/forecast/latest/dg/API_forecastquery_QueryForecast.html

        :stability: experimental
        '''
        return typing.cast("Forecast", jsii.invoke(self, "toQueryForecast", []))

    @jsii.member(jsii_name="toQueryWhatIfForecast")
    def to_query_what_if_forecast(self) -> "Forecast":
        '''(experimental) Grants permission to retrieve a what-if forecast for a single item.

        Access Level: Read

        https://docs.aws.amazon.com/forecast/latest/dg/API_forecastquery_QueryWhatIfForecast.html

        :stability: experimental
        '''
        return typing.cast("Forecast", jsii.invoke(self, "toQueryWhatIfForecast", []))

    @jsii.member(jsii_name="toResumeResource")
    def to_resume_resource(self) -> "Forecast":
        '''(experimental) Grants permission to resume Amazon Forecast resource jobs.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/forecast/latest/dg/API_ResumeResource.html

        :stability: experimental
        '''
        return typing.cast("Forecast", jsii.invoke(self, "toResumeResource", []))

    @jsii.member(jsii_name="toStopResource")
    def to_stop_resource(self) -> "Forecast":
        '''(experimental) Grants permission to stop Amazon Forecast resource jobs.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/forecast/latest/dg/API_StopResource.html

        :stability: experimental
        '''
        return typing.cast("Forecast", jsii.invoke(self, "toStopResource", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Forecast":
        '''(experimental) Grants permission to associate the specified tags to a resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/forecast/latest/dg/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("Forecast", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Forecast":
        '''(experimental) Grants permission to delete the specified tags for a resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/forecast/latest/dg/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("Forecast", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateDatasetGroup")
    def to_update_dataset_group(self) -> "Forecast":
        '''(experimental) Grants permission to update a dataset group.

        Access Level: Write

        https://docs.aws.amazon.com/forecast/latest/dg/API_UpdateDatasetGroup.html

        :stability: experimental
        '''
        return typing.cast("Forecast", jsii.invoke(self, "toUpdateDatasetGroup", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__dbf7300a4dec07cdcb2eb9693a59d36ed730b208178b5dd451ccacc13ea1803b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0d976ca44835f5cb1cdef7bd981b8399841a0e9f6c5d2f05ac7a746c246b3924)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Frauddetector(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Frauddetector",
):
    '''(experimental) Statement provider for service `frauddetector <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonfrauddetector.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `frauddetector <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonfrauddetector.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onBatchImport")
    def on_batch_import(
        self,
        resource_path: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Frauddetector":
        '''(experimental) Adds a resource of type batch-import to the statement.

        https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonfrauddetector.html#amazonfrauddetector-resources-for-iam-policies

        :param resource_path: - Identifier for the resourcePath.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a28161c889355fa5146322c4f8da12416086274cb4cc852743f56f3d4ff10c81)
            check_type(argname="argument resource_path", value=resource_path, expected_type=type_hints["resource_path"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Frauddetector", jsii.invoke(self, "onBatchImport", [resource_path, account, region, partition]))

    @jsii.member(jsii_name="onBatchPrediction")
    def on_batch_prediction(
        self,
        resource_path: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Frauddetector":
        '''(experimental) Adds a resource of type batch-prediction to the statement.

        https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonfrauddetector.html#amazonfrauddetector-resources-for-iam-policies

        :param resource_path: - Identifier for the resourcePath.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__649aec5de0afa9c3ef453cded8fffa3737d7fe231b932ff5c68300dde6a4a4ac)
            check_type(argname="argument resource_path", value=resource_path, expected_type=type_hints["resource_path"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Frauddetector", jsii.invoke(self, "onBatchPrediction", [resource_path, account, region, partition]))

    @jsii.member(jsii_name="onDetector")
    def on_detector(
        self,
        resource_path: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Frauddetector":
        '''(experimental) Adds a resource of type detector to the statement.

        https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonfrauddetector.html#amazonfrauddetector-resources-for-iam-policies

        :param resource_path: - Identifier for the resourcePath.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__14db85c2ad7c75cb40182d1df572a08cf5d79ddf47875541b11206f941075236)
            check_type(argname="argument resource_path", value=resource_path, expected_type=type_hints["resource_path"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Frauddetector", jsii.invoke(self, "onDetector", [resource_path, account, region, partition]))

    @jsii.member(jsii_name="onDetectorVersion")
    def on_detector_version(
        self,
        resource_path: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Frauddetector":
        '''(experimental) Adds a resource of type detector-version to the statement.

        https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonfrauddetector.html#amazonfrauddetector-resources-for-iam-policies

        :param resource_path: - Identifier for the resourcePath.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7100a09bdea27a2d7a77907cef9a4428e190cdb629ded71e9c97d4df00f1fe71)
            check_type(argname="argument resource_path", value=resource_path, expected_type=type_hints["resource_path"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Frauddetector", jsii.invoke(self, "onDetectorVersion", [resource_path, account, region, partition]))

    @jsii.member(jsii_name="onEntityType")
    def on_entity_type(
        self,
        resource_path: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Frauddetector":
        '''(experimental) Adds a resource of type entity-type to the statement.

        https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonfrauddetector.html#amazonfrauddetector-resources-for-iam-policies

        :param resource_path: - Identifier for the resourcePath.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3fad7315236a2b3b42a9789ce1f152041032ded5d1c85a7d0a408c5ed1ab1151)
            check_type(argname="argument resource_path", value=resource_path, expected_type=type_hints["resource_path"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Frauddetector", jsii.invoke(self, "onEntityType", [resource_path, account, region, partition]))

    @jsii.member(jsii_name="onEventType")
    def on_event_type(
        self,
        resource_path: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Frauddetector":
        '''(experimental) Adds a resource of type event-type to the statement.

        https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonfrauddetector.html#amazonfrauddetector-resources-for-iam-policies

        :param resource_path: - Identifier for the resourcePath.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__df397acc56197727983c4744b8ff0a93ad7f2de493ff79ddadd71ce87b268fa4)
            check_type(argname="argument resource_path", value=resource_path, expected_type=type_hints["resource_path"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Frauddetector", jsii.invoke(self, "onEventType", [resource_path, account, region, partition]))

    @jsii.member(jsii_name="onExternalModel")
    def on_external_model(
        self,
        resource_path: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Frauddetector":
        '''(experimental) Adds a resource of type external-model to the statement.

        https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonfrauddetector.html#amazonfrauddetector-resources-for-iam-policies

        :param resource_path: - Identifier for the resourcePath.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__933117273b5866566a1bcd2c5e5776bcbb4b919e2e5279e17c6a3ac35576e690)
            check_type(argname="argument resource_path", value=resource_path, expected_type=type_hints["resource_path"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Frauddetector", jsii.invoke(self, "onExternalModel", [resource_path, account, region, partition]))

    @jsii.member(jsii_name="onLabel")
    def on_label(
        self,
        resource_path: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Frauddetector":
        '''(experimental) Adds a resource of type label to the statement.

        https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonfrauddetector.html#amazonfrauddetector-resources-for-iam-policies

        :param resource_path: - Identifier for the resourcePath.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ee3eb3b42e77f968d12b2400c17d72c4fba11a8d4925f1a5ad73442ddcd704ac)
            check_type(argname="argument resource_path", value=resource_path, expected_type=type_hints["resource_path"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Frauddetector", jsii.invoke(self, "onLabel", [resource_path, account, region, partition]))

    @jsii.member(jsii_name="onModel")
    def on_model(
        self,
        resource_path: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Frauddetector":
        '''(experimental) Adds a resource of type model to the statement.

        https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonfrauddetector.html#amazonfrauddetector-resources-for-iam-policies

        :param resource_path: - Identifier for the resourcePath.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3b9ccaac5b8f5e51c78eb5e02131d6079bc87b597a5571fbfba16523eb5e7036)
            check_type(argname="argument resource_path", value=resource_path, expected_type=type_hints["resource_path"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Frauddetector", jsii.invoke(self, "onModel", [resource_path, account, region, partition]))

    @jsii.member(jsii_name="onModelVersion")
    def on_model_version(
        self,
        resource_path: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Frauddetector":
        '''(experimental) Adds a resource of type model-version to the statement.

        https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonfrauddetector.html#amazonfrauddetector-resources-for-iam-policies

        :param resource_path: - Identifier for the resourcePath.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__61e3a6cfa7587ddb043e19b0fb9b62659cbba83cc811b01fc49225ecb56a1602)
            check_type(argname="argument resource_path", value=resource_path, expected_type=type_hints["resource_path"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Frauddetector", jsii.invoke(self, "onModelVersion", [resource_path, account, region, partition]))

    @jsii.member(jsii_name="onOutcome")
    def on_outcome(
        self,
        resource_path: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Frauddetector":
        '''(experimental) Adds a resource of type outcome to the statement.

        https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonfrauddetector.html#amazonfrauddetector-resources-for-iam-policies

        :param resource_path: - Identifier for the resourcePath.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8c9c10e8cc8c3e10ff8b51683220f17cab37ec6c34ffa9d09f8f28649c358edb)
            check_type(argname="argument resource_path", value=resource_path, expected_type=type_hints["resource_path"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Frauddetector", jsii.invoke(self, "onOutcome", [resource_path, account, region, partition]))

    @jsii.member(jsii_name="onRule")
    def on_rule(
        self,
        resource_path: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Frauddetector":
        '''(experimental) Adds a resource of type rule to the statement.

        https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonfrauddetector.html#amazonfrauddetector-resources-for-iam-policies

        :param resource_path: - Identifier for the resourcePath.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__187c41efea89cbe055ac5b7f247a243d4a9a3c7e5af59b8758f62c02ccb7bd8b)
            check_type(argname="argument resource_path", value=resource_path, expected_type=type_hints["resource_path"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Frauddetector", jsii.invoke(self, "onRule", [resource_path, account, region, partition]))

    @jsii.member(jsii_name="onVariable")
    def on_variable(
        self,
        resource_path: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Frauddetector":
        '''(experimental) Adds a resource of type variable to the statement.

        https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonfrauddetector.html#amazonfrauddetector-resources-for-iam-policies

        :param resource_path: - Identifier for the resourcePath.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fea1b8c57ba233d7b4495d764bccc4f0e46b492b0a87a882ff257776b3194173)
            check_type(argname="argument resource_path", value=resource_path, expected_type=type_hints["resource_path"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Frauddetector", jsii.invoke(self, "onVariable", [resource_path, account, region, partition]))

    @jsii.member(jsii_name="toBatchCreateVariable")
    def to_batch_create_variable(self) -> "Frauddetector":
        '''(experimental) Grants permission to create a batch of variables.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/frauddetector/latest/api/API_BatchCreateVariable.html

        :stability: experimental
        '''
        return typing.cast("Frauddetector", jsii.invoke(self, "toBatchCreateVariable", []))

    @jsii.member(jsii_name="toBatchGetVariable")
    def to_batch_get_variable(self) -> "Frauddetector":
        '''(experimental) Grants permission to get a batch of variables.

        Access Level: List

        https://docs.aws.amazon.com/frauddetector/latest/api/API_BatchGetVariable.html

        :stability: experimental
        '''
        return typing.cast("Frauddetector", jsii.invoke(self, "toBatchGetVariable", []))

    @jsii.member(jsii_name="toCancelBatchImportJob")
    def to_cancel_batch_import_job(self) -> "Frauddetector":
        '''(experimental) Grants permission to cancel the specified batch import job.

        Access Level: Write

        https://docs.aws.amazon.com/frauddetector/latest/api/API_CancelBatchImportJob.html

        :stability: experimental
        '''
        return typing.cast("Frauddetector", jsii.invoke(self, "toCancelBatchImportJob", []))

    @jsii.member(jsii_name="toCancelBatchPredictionJob")
    def to_cancel_batch_prediction_job(self) -> "Frauddetector":
        '''(experimental) Grants permission to cancel the specified batch prediction job.

        Access Level: Write

        https://docs.aws.amazon.com/frauddetector/latest/api/API_CancelBatchPredictionJob.html

        :stability: experimental
        '''
        return typing.cast("Frauddetector", jsii.invoke(self, "toCancelBatchPredictionJob", []))

    @jsii.member(jsii_name="toCreateBatchImportJob")
    def to_create_batch_import_job(self) -> "Frauddetector":
        '''(experimental) Grants permission to create a batch import job.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/frauddetector/latest/api/API_CreateBatchImportJob.html

        :stability: experimental
        '''
        return typing.cast("Frauddetector", jsii.invoke(self, "toCreateBatchImportJob", []))

    @jsii.member(jsii_name="toCreateBatchPredictionJob")
    def to_create_batch_prediction_job(self) -> "Frauddetector":
        '''(experimental) Grants permission to create a batch prediction job.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/frauddetector/latest/api/API_CreateBatchPredictionJob.html

        :stability: experimental
        '''
        return typing.cast("Frauddetector", jsii.invoke(self, "toCreateBatchPredictionJob", []))

    @jsii.member(jsii_name="toCreateDetectorVersion")
    def to_create_detector_version(self) -> "Frauddetector":
        '''(experimental) Grants permission to create a detector version. The detector version starts in a DRAFT status.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/frauddetector/latest/api/API_CreateDetectorVersion.html

        :stability: experimental
        '''
        return typing.cast("Frauddetector", jsii.invoke(self, "toCreateDetectorVersion", []))

    @jsii.member(jsii_name="toCreateModel")
    def to_create_model(self) -> "Frauddetector":
        '''(experimental) Grants permission to create a model using the specified model type.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/frauddetector/latest/api/API_CreateModel.html

        :stability: experimental
        '''
        return typing.cast("Frauddetector", jsii.invoke(self, "toCreateModel", []))

    @jsii.member(jsii_name="toCreateModelVersion")
    def to_create_model_version(self) -> "Frauddetector":
        '''(experimental) Grants permission to create a version of the model using the specified model type and model id.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/frauddetector/latest/api/API_CreateModelVersion.html

        :stability: experimental
        '''
        return typing.cast("Frauddetector", jsii.invoke(self, "toCreateModelVersion", []))

    @jsii.member(jsii_name="toCreateRule")
    def to_create_rule(self) -> "Frauddetector":
        '''(experimental) Grants permission to create a rule for use with the specified detector.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/frauddetector/latest/api/API_CreateRule.html

        :stability: experimental
        '''
        return typing.cast("Frauddetector", jsii.invoke(self, "toCreateRule", []))

    @jsii.member(jsii_name="toCreateVariable")
    def to_create_variable(self) -> "Frauddetector":
        '''(experimental) Grants permission to create a variable.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/frauddetector/latest/api/API_CreateVariable.html

        :stability: experimental
        '''
        return typing.cast("Frauddetector", jsii.invoke(self, "toCreateVariable", []))

    @jsii.member(jsii_name="toDeleteBatchImportJob")
    def to_delete_batch_import_job(self) -> "Frauddetector":
        '''(experimental) Grants permission to delete a batch import job.

        Access Level: Write

        https://docs.aws.amazon.com/frauddetector/latest/api/API_DeleteBatchImportJob.html

        :stability: experimental
        '''
        return typing.cast("Frauddetector", jsii.invoke(self, "toDeleteBatchImportJob", []))

    @jsii.member(jsii_name="toDeleteBatchPredictionJob")
    def to_delete_batch_prediction_job(self) -> "Frauddetector":
        '''(experimental) Grants permission to delete a batch prediction job.

        Access Level: Write

        https://docs.aws.amazon.com/frauddetector/latest/api/API_DeleteBatchPredictionJob.html

        :stability: experimental
        '''
        return typing.cast("Frauddetector", jsii.invoke(self, "toDeleteBatchPredictionJob", []))

    @jsii.member(jsii_name="toDeleteDetector")
    def to_delete_detector(self) -> "Frauddetector":
        '''(experimental) Grants permission to delete the detector.

        Before deleting a detector, you must first delete all detector versions and rule versions associated with the detector

        Access Level: Write

        https://docs.aws.amazon.com/frauddetector/latest/api/API_DeleteDetector.html

        :stability: experimental
        '''
        return typing.cast("Frauddetector", jsii.invoke(self, "toDeleteDetector", []))

    @jsii.member(jsii_name="toDeleteDetectorVersion")
    def to_delete_detector_version(self) -> "Frauddetector":
        '''(experimental) Grants permission to delete the detector version. You cannot delete detector versions that are in ACTIVE status.

        Access Level: Write

        https://docs.aws.amazon.com/frauddetector/latest/api/API_DeleteDetectorVersion.html

        :stability: experimental
        '''
        return typing.cast("Frauddetector", jsii.invoke(self, "toDeleteDetectorVersion", []))

    @jsii.member(jsii_name="toDeleteEntityType")
    def to_delete_entity_type(self) -> "Frauddetector":
        '''(experimental) Grants permission to delete an entity type.

        You cannot delete an entity type that is included in an event type

        Access Level: Write

        https://docs.aws.amazon.com/frauddetector/latest/api/API_DeleteEntityType.html

        :stability: experimental
        '''
        return typing.cast("Frauddetector", jsii.invoke(self, "toDeleteEntityType", []))

    @jsii.member(jsii_name="toDeleteEvent")
    def to_delete_event(self) -> "Frauddetector":
        '''(experimental) Grants permission to deletes the specified event.

        Access Level: Write

        https://docs.aws.amazon.com/frauddetector/latest/api/API_DeleteEvent.html

        :stability: experimental
        '''
        return typing.cast("Frauddetector", jsii.invoke(self, "toDeleteEvent", []))

    @jsii.member(jsii_name="toDeleteEventsByEventType")
    def to_delete_events_by_event_type(self) -> "Frauddetector":
        '''(experimental) Grants permission to delete events for the specified event type.

        Access Level: Write

        https://docs.aws.amazon.com/frauddetector/latest/api/API_DeleteEventsByEventType.html

        :stability: experimental
        '''
        return typing.cast("Frauddetector", jsii.invoke(self, "toDeleteEventsByEventType", []))

    @jsii.member(jsii_name="toDeleteEventType")
    def to_delete_event_type(self) -> "Frauddetector":
        '''(experimental) Grants permission to delete an event type.

        You cannot delete an event type that is used in a detector or a model

        Access Level: Write

        https://docs.aws.amazon.com/frauddetector/latest/api/API_DeleteEventType.html

        :stability: experimental
        '''
        return typing.cast("Frauddetector", jsii.invoke(self, "toDeleteEventType", []))

    @jsii.member(jsii_name="toDeleteExternalModel")
    def to_delete_external_model(self) -> "Frauddetector":
        '''(experimental) Grants permission to remove a SageMaker model from Amazon Fraud Detector.

        You can remove an Amazon SageMaker model if it is not associated with a detector version

        Access Level: Write

        https://docs.aws.amazon.com/frauddetector/latest/api/API_DeleteExternalModel.html

        :stability: experimental
        '''
        return typing.cast("Frauddetector", jsii.invoke(self, "toDeleteExternalModel", []))

    @jsii.member(jsii_name="toDeleteLabel")
    def to_delete_label(self) -> "Frauddetector":
        '''(experimental) Grants permission to delete a label.

        You cannot delete labels that are included in an event type in Amazon Fraud Detector. You cannot delete a label assigned to an event ID. You must first delete the relevant event ID

        Access Level: Write

        https://docs.aws.amazon.com/frauddetector/latest/api/API_DeleteLabel.html

        :stability: experimental
        '''
        return typing.cast("Frauddetector", jsii.invoke(self, "toDeleteLabel", []))

    @jsii.member(jsii_name="toDeleteModel")
    def to_delete_model(self) -> "Frauddetector":
        '''(experimental) Grants permission to delete a model.

        You can delete models and model versions in Amazon Fraud Detector, provided that they are not associated with a detector version

        Access Level: Write

        https://docs.aws.amazon.com/frauddetector/latest/api/API_DeleteModel.html

        :stability: experimental
        '''
        return typing.cast("Frauddetector", jsii.invoke(self, "toDeleteModel", []))

    @jsii.member(jsii_name="toDeleteModelVersion")
    def to_delete_model_version(self) -> "Frauddetector":
        '''(experimental) Grants permission to delete a model version.

        You can delete models and model versions in Amazon Fraud Detector, provided that they are not associated with a detector version

        Access Level: Write

        https://docs.aws.amazon.com/frauddetector/latest/api/API_DeleteModelVersion.html

        :stability: experimental
        '''
        return typing.cast("Frauddetector", jsii.invoke(self, "toDeleteModelVersion", []))

    @jsii.member(jsii_name="toDeleteOutcome")
    def to_delete_outcome(self) -> "Frauddetector":
        '''(experimental) Grants permission to delete an outcome. You cannot delete an outcome that is used in a rule version.

        Access Level: Write

        https://docs.aws.amazon.com/frauddetector/latest/api/API_DeleteOutcome.html

        :stability: experimental
        '''
        return typing.cast("Frauddetector", jsii.invoke(self, "toDeleteOutcome", []))

    @jsii.member(jsii_name="toDeleteRule")
    def to_delete_rule(self) -> "Frauddetector":
        '''(experimental) Grants permission to delete the rule.

        You cannot delete a rule if it is used by an ACTIVE or INACTIVE detector version

        Access Level: Write

        https://docs.aws.amazon.com/frauddetector/latest/api/API_DeleteRule.html

        :stability: experimental
        '''
        return typing.cast("Frauddetector", jsii.invoke(self, "toDeleteRule", []))

    @jsii.member(jsii_name="toDeleteVariable")
    def to_delete_variable(self) -> "Frauddetector":
        '''(experimental) Grants permission to delete a variable.

        You cannot delete variables that are included in an event type in Amazon Fraud Detector

        Access Level: Write

        https://docs.aws.amazon.com/frauddetector/latest/api/API_DeleteVariable.html

        :stability: experimental
        '''
        return typing.cast("Frauddetector", jsii.invoke(self, "toDeleteVariable", []))

    @jsii.member(jsii_name="toDescribeDetector")
    def to_describe_detector(self) -> "Frauddetector":
        '''(experimental) Grants permission to get all versions for a specified detector.

        Access Level: Read

        https://docs.aws.amazon.com/frauddetector/latest/api/API_DescribeDetector.html

        :stability: experimental
        '''
        return typing.cast("Frauddetector", jsii.invoke(self, "toDescribeDetector", []))

    @jsii.member(jsii_name="toDescribeModelVersions")
    def to_describe_model_versions(self) -> "Frauddetector":
        '''(experimental) Grants permission to get all of the model versions for the specified model type or for the specified model type and model ID.

        You can also get details for a single, specified model version

        Access Level: Read

        https://docs.aws.amazon.com/frauddetector/latest/api/API_DescribeModelVersions.html

        :stability: experimental
        '''
        return typing.cast("Frauddetector", jsii.invoke(self, "toDescribeModelVersions", []))

    @jsii.member(jsii_name="toGetBatchImportJobs")
    def to_get_batch_import_jobs(self) -> "Frauddetector":
        '''(experimental) Grants permission to get all batch import jobs or a specific job if you specify a job ID.

        Access Level: List

        https://docs.aws.amazon.com/frauddetector/latest/api/API_GetBatchImportJobs.html

        :stability: experimental
        '''
        return typing.cast("Frauddetector", jsii.invoke(self, "toGetBatchImportJobs", []))

    @jsii.member(jsii_name="toGetBatchPredictionJobs")
    def to_get_batch_prediction_jobs(self) -> "Frauddetector":
        '''(experimental) Grants permission to get all batch prediction jobs or a specific job if you specify a job ID.

        This is a paginated API. If you provide a null maxResults, this action retrieves a maximum of 50 records per page. If you provide a maxResults, the value must be between 1 and 50. To get the next page results, provide the pagination token from the GetBatchPredictionJobsResponse as part of your request. A null pagination token fetches the records from the beginning

        Access Level: List

        https://docs.aws.amazon.com/frauddetector/latest/api/API_GetBatchPredictionJobs.html

        :stability: experimental
        '''
        return typing.cast("Frauddetector", jsii.invoke(self, "toGetBatchPredictionJobs", []))

    @jsii.member(jsii_name="toGetDeleteEventsByEventTypeStatus")
    def to_get_delete_events_by_event_type_status(self) -> "Frauddetector":
        '''(experimental) Grants permission to get a specific event type DeleteEventsByEventType API execution status.

        Access Level: Read

        https://docs.aws.amazon.com/frauddetector/latest/api/API_GetDeleteEventsByEventTypeStatus.html

        :stability: experimental
        '''
        return typing.cast("Frauddetector", jsii.invoke(self, "toGetDeleteEventsByEventTypeStatus", []))

    @jsii.member(jsii_name="toGetDetectors")
    def to_get_detectors(self) -> "Frauddetector":
        '''(experimental) Grants permission to get all detectors or a single detector if a detectorId is specified.

        This is a paginated API. If you provide a null maxResults, this action retrieves a maximum of 10 records per page. If you provide a maxResults, the value must be between 5 and 10. To get the next page results, provide the pagination token from the GetDetectorsResponse as part of your request. A null pagination token fetches the records from the beginning

        Access Level: List

        https://docs.aws.amazon.com/frauddetector/latest/api/API_GetDetectors.html

        :stability: experimental
        '''
        return typing.cast("Frauddetector", jsii.invoke(self, "toGetDetectors", []))

    @jsii.member(jsii_name="toGetDetectorVersion")
    def to_get_detector_version(self) -> "Frauddetector":
        '''(experimental) Grants permission to get a particular detector version.

        Access Level: Read

        https://docs.aws.amazon.com/frauddetector/latest/api/API_GetDetectorVersion.html

        :stability: experimental
        '''
        return typing.cast("Frauddetector", jsii.invoke(self, "toGetDetectorVersion", []))

    @jsii.member(jsii_name="toGetEntityTypes")
    def to_get_entity_types(self) -> "Frauddetector":
        '''(experimental) Grants permission to get all entity types or a specific entity type if a name is specified.

        This is a paginated API. If you provide a null maxResults, this action retrieves a maximum of 10 records per page. If you provide a maxResults, the value must be between 5 and 10. To get the next page results, provide the pagination token from the GetEntityTypesResponse as part of your request. A null pagination token fetches the records from the beginning

        Access Level: List

        https://docs.aws.amazon.com/frauddetector/latest/api/API_GetEntityTypes.html

        :stability: experimental
        '''
        return typing.cast("Frauddetector", jsii.invoke(self, "toGetEntityTypes", []))

    @jsii.member(jsii_name="toGetEvent")
    def to_get_event(self) -> "Frauddetector":
        '''(experimental) Grants permission to get the details of the specified event.

        Access Level: Read

        https://docs.aws.amazon.com/frauddetector/latest/api/API_GetEvent.html

        :stability: experimental
        '''
        return typing.cast("Frauddetector", jsii.invoke(self, "toGetEvent", []))

    @jsii.member(jsii_name="toGetEventPrediction")
    def to_get_event_prediction(self) -> "Frauddetector":
        '''(experimental) Grants permission to evaluate an event against a detector version.

        If a version ID is not provided, the detector’s (ACTIVE) version is used

        Access Level: Read

        https://docs.aws.amazon.com/frauddetector/latest/api/API_GetEventPrediction.html

        :stability: experimental
        '''
        return typing.cast("Frauddetector", jsii.invoke(self, "toGetEventPrediction", []))

    @jsii.member(jsii_name="toGetEventPredictionMetadata")
    def to_get_event_prediction_metadata(self) -> "Frauddetector":
        '''(experimental) Grants permission to get more details of a particular prediction.

        Access Level: Read

        https://docs.aws.amazon.com/frauddetector/latest/api/API_GetEventPredictionMetadata.html

        :stability: experimental
        '''
        return typing.cast("Frauddetector", jsii.invoke(self, "toGetEventPredictionMetadata", []))

    @jsii.member(jsii_name="toGetEventTypes")
    def to_get_event_types(self) -> "Frauddetector":
        '''(experimental) Grants permission to get all event types or a specific event type if name is provided.

        This is a paginated API. If you provide a null maxResults, this action retrieves a maximum of 10 records per page. If you provide a maxResults, the value must be between 5 and 10. To get the next page results, provide the pagination token from the GetEventTypesResponse as part of your request. A null pagination token fetches the records from the beginning

        Access Level: List

        https://docs.aws.amazon.com/frauddetector/latest/api/API_GetEventTypes.html

        :stability: experimental
        '''
        return typing.cast("Frauddetector", jsii.invoke(self, "toGetEventTypes", []))

    @jsii.member(jsii_name="toGetExternalModels")
    def to_get_external_models(self) -> "Frauddetector":
        '''(experimental) Grants permission to get the details for one or more Amazon SageMaker models that have been imported into the service.

        This is a paginated API. If you provide a null maxResults, this actions retrieves a maximum of 10 records per page. If you provide a maxResults, the value must be between 5 and 10. To get the next page results, provide the pagination token from the GetExternalModelsResult as part of your request. A null pagination token fetches the records from the beginning

        Access Level: List

        https://docs.aws.amazon.com/frauddetector/latest/api/API_GetExternalModels.html

        :stability: experimental
        '''
        return typing.cast("Frauddetector", jsii.invoke(self, "toGetExternalModels", []))

    @jsii.member(jsii_name="toGetKMSEncryptionKey")
    def to_get_kms_encryption_key(self) -> "Frauddetector":
        '''(experimental) Grants permission to get the encryption key if a Key Management Service (KMS) customer master key (CMK) has been specified to be used to encrypt content in Amazon Fraud Detector.

        Access Level: Read

        https://docs.aws.amazon.com/frauddetector/latest/api/API_GetKMSEncryptionKey.html

        :stability: experimental
        '''
        return typing.cast("Frauddetector", jsii.invoke(self, "toGetKMSEncryptionKey", []))

    @jsii.member(jsii_name="toGetLabels")
    def to_get_labels(self) -> "Frauddetector":
        '''(experimental) Grants permission to get all labels or a specific label if name is provided.

        This is a paginated API. If you provide a null maxResults, this action retrieves a maximum of 50 records per page. If you provide a maxResults, the value must be between 10 and 50. To get the next page results, provide the pagination token from the GetGetLabelsResponse as part of your request. A null pagination token fetches the records from the beginning

        Access Level: List

        https://docs.aws.amazon.com/frauddetector/latest/api/API_GetLabels.html

        :stability: experimental
        '''
        return typing.cast("Frauddetector", jsii.invoke(self, "toGetLabels", []))

    @jsii.member(jsii_name="toGetModels")
    def to_get_models(self) -> "Frauddetector":
        '''(experimental) Grants permission to get one or more models.

        Gets all models for the AWS account if no model type and no model id provided. Gets all models for the AWS account and model type, if the model type is specified but model id is not provided. Gets a specific model if (model type, model id) tuple is specified

        Access Level: List

        https://docs.aws.amazon.com/frauddetector/latest/api/API_GetModels.html

        :stability: experimental
        '''
        return typing.cast("Frauddetector", jsii.invoke(self, "toGetModels", []))

    @jsii.member(jsii_name="toGetModelVersion")
    def to_get_model_version(self) -> "Frauddetector":
        '''(experimental) Grants permission to get the details of the specified model version.

        Access Level: Read

        https://docs.aws.amazon.com/frauddetector/latest/api/API_GetModelVersion.html

        :stability: experimental
        '''
        return typing.cast("Frauddetector", jsii.invoke(self, "toGetModelVersion", []))

    @jsii.member(jsii_name="toGetOutcomes")
    def to_get_outcomes(self) -> "Frauddetector":
        '''(experimental) Grants permission to get one or more outcomes.

        This is a paginated API. If you provide a null maxResults, this actions retrieves a maximum of 100 records per page. If you provide a maxResults, the value must be between 50 and 100. To get the next page results, provide the pagination token from the GetOutcomesResult as part of your request. A null pagination token fetches the records from the beginning

        Access Level: List

        https://docs.aws.amazon.com/frauddetector/latest/api/API_GetOutcomes.html

        :stability: experimental
        '''
        return typing.cast("Frauddetector", jsii.invoke(self, "toGetOutcomes", []))

    @jsii.member(jsii_name="toGetRules")
    def to_get_rules(self) -> "Frauddetector":
        '''(experimental) Grants permission to get all rules for a detector (paginated) if ruleId and ruleVersion are not specified.

        Gets all rules for the detector and the ruleId if present (paginated). Gets a specific rule if both the ruleId and the ruleVersion are specified

        Access Level: List

        https://docs.aws.amazon.com/frauddetector/latest/api/API_GetRules.html

        :stability: experimental
        '''
        return typing.cast("Frauddetector", jsii.invoke(self, "toGetRules", []))

    @jsii.member(jsii_name="toGetVariables")
    def to_get_variables(self) -> "Frauddetector":
        '''(experimental) Grants permission to get all of the variables or the specific variable.

        This is a paginated API. Providing null maxSizePerPage results in retrieving maximum of 100 records per page. If you provide maxSizePerPage the value must be between 50 and 100. To get the next page result, a provide a pagination token from GetVariablesResult as part of your request. Null pagination token fetches the records from the beginning

        Access Level: List

        https://docs.aws.amazon.com/frauddetector/latest/api/API_GetVariables.html

        :stability: experimental
        '''
        return typing.cast("Frauddetector", jsii.invoke(self, "toGetVariables", []))

    @jsii.member(jsii_name="toListEventPredictions")
    def to_list_event_predictions(self) -> "Frauddetector":
        '''(experimental) Grants permission to get a list of past predictions.

        Access Level: List

        https://docs.aws.amazon.com/frauddetector/latest/api/API_ListEventPredictions.html

        :stability: experimental
        '''
        return typing.cast("Frauddetector", jsii.invoke(self, "toListEventPredictions", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Frauddetector":
        '''(experimental) Grants permission to list all tags associated with the resource.

        This is a paginated API. To get the next page results, provide the pagination token from the response as part of your request. A null pagination token fetches the records from the beginning

        Access Level: Read

        https://docs.aws.amazon.com/frauddetector/latest/api/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("Frauddetector", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toPutDetector")
    def to_put_detector(self) -> "Frauddetector":
        '''(experimental) Grants permission to create or update a detector.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/frauddetector/latest/api/API_PutDetector.html

        :stability: experimental
        '''
        return typing.cast("Frauddetector", jsii.invoke(self, "toPutDetector", []))

    @jsii.member(jsii_name="toPutEntityType")
    def to_put_entity_type(self) -> "Frauddetector":
        '''(experimental) Grants permission to create or update an entity type.

        An entity represents who is performing the event. As part of a fraud prediction, you pass the entity ID to indicate the specific entity who performed the event. An entity type classifies the entity. Example classifications include customer, merchant, or account

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/frauddetector/latest/api/API_PutEntityType.html

        :stability: experimental
        '''
        return typing.cast("Frauddetector", jsii.invoke(self, "toPutEntityType", []))

    @jsii.member(jsii_name="toPutEventType")
    def to_put_event_type(self) -> "Frauddetector":
        '''(experimental) Grants permission to create or update an event type.

        An event is a business activity that is evaluated for fraud risk. With Amazon Fraud Detector, you generate fraud predictions for events. An event type defines the structure for an event sent to Amazon Fraud Detector. This includes the variables sent as part of the event, the entity performing the event (such as a customer), and the labels that classify the event. Example event types include online payment transactions, account registrations, and authentications

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/frauddetector/latest/api/API_PutEventType.html

        :stability: experimental
        '''
        return typing.cast("Frauddetector", jsii.invoke(self, "toPutEventType", []))

    @jsii.member(jsii_name="toPutExternalModel")
    def to_put_external_model(self) -> "Frauddetector":
        '''(experimental) Grants permission to create or update an Amazon SageMaker model endpoint.

        You can also use this action to update the configuration of the model endpoint, including the IAM role and/or the mapped variables

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/frauddetector/latest/api/API_PutExternalModel.html

        :stability: experimental
        '''
        return typing.cast("Frauddetector", jsii.invoke(self, "toPutExternalModel", []))

    @jsii.member(jsii_name="toPutKMSEncryptionKey")
    def to_put_kms_encryption_key(self) -> "Frauddetector":
        '''(experimental) Grants permission to specify the Key Management Service (KMS) customer master key (CMK) to be used to encrypt content in Amazon Fraud Detector.

        Access Level: Write

        https://docs.aws.amazon.com/frauddetector/latest/api/API_PutKMSEncryptionKey.html

        :stability: experimental
        '''
        return typing.cast("Frauddetector", jsii.invoke(self, "toPutKMSEncryptionKey", []))

    @jsii.member(jsii_name="toPutLabel")
    def to_put_label(self) -> "Frauddetector":
        '''(experimental) Grants permission to create or update label.

        A label classifies an event as fraudulent or legitimate. Labels are associated with event types and used to train supervised machine learning models in Amazon Fraud Detector

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/frauddetector/latest/api/API_PutLabel.html

        :stability: experimental
        '''
        return typing.cast("Frauddetector", jsii.invoke(self, "toPutLabel", []))

    @jsii.member(jsii_name="toPutOutcome")
    def to_put_outcome(self) -> "Frauddetector":
        '''(experimental) Grants permission to create or update an outcome.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/frauddetector/latest/api/API_PutOutcome.html

        :stability: experimental
        '''
        return typing.cast("Frauddetector", jsii.invoke(self, "toPutOutcome", []))

    @jsii.member(jsii_name="toSendEvent")
    def to_send_event(self) -> "Frauddetector":
        '''(experimental) Grants permission to send event.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/frauddetector/latest/api/API_SendEvent.html

        :stability: experimental
        '''
        return typing.cast("Frauddetector", jsii.invoke(self, "toSendEvent", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Frauddetector":
        '''(experimental) Grants permission to assign tags to a resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/frauddetector/latest/api/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("Frauddetector", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Frauddetector":
        '''(experimental) Grants permission to remove tags from a resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/frauddetector/latest/api/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("Frauddetector", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateDetectorVersion")
    def to_update_detector_version(self) -> "Frauddetector":
        '''(experimental) Grants permission to update a detector version.

        The detector version attributes that you can update include models, external model endpoints, rules, rule execution mode, and description. You can only update a DRAFT detector version

        Access Level: Write

        https://docs.aws.amazon.com/frauddetector/latest/api/API_UpdateDetectorVersion.html

        :stability: experimental
        '''
        return typing.cast("Frauddetector", jsii.invoke(self, "toUpdateDetectorVersion", []))

    @jsii.member(jsii_name="toUpdateDetectorVersionMetadata")
    def to_update_detector_version_metadata(self) -> "Frauddetector":
        '''(experimental) Grants permission to update the detector version's description.

        You can update the metadata for any detector version (DRAFT, ACTIVE, or INACTIVE)

        Access Level: Write

        https://docs.aws.amazon.com/frauddetector/latest/api/API_UpdateDetectorVersionMetadata.html

        :stability: experimental
        '''
        return typing.cast("Frauddetector", jsii.invoke(self, "toUpdateDetectorVersionMetadata", []))

    @jsii.member(jsii_name="toUpdateDetectorVersionStatus")
    def to_update_detector_version_status(self) -> "Frauddetector":
        '''(experimental) Grants permission to update the detector version’s status.

        You can perform the following promotions or demotions using UpdateDetectorVersionStatus: DRAFT to ACTIVE, ACTIVE to INACTIVE, and INACTIVE to ACTIVE

        Access Level: Write

        https://docs.aws.amazon.com/frauddetector/latest/api/API_UpdateDetectorVersionStatus.html

        :stability: experimental
        '''
        return typing.cast("Frauddetector", jsii.invoke(self, "toUpdateDetectorVersionStatus", []))

    @jsii.member(jsii_name="toUpdateEventLabel")
    def to_update_event_label(self) -> "Frauddetector":
        '''(experimental) Grants permission to update an existing event record's label value.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/frauddetector/latest/api/API_UpdateEventLabel.html

        :stability: experimental
        '''
        return typing.cast("Frauddetector", jsii.invoke(self, "toUpdateEventLabel", []))

    @jsii.member(jsii_name="toUpdateModel")
    def to_update_model(self) -> "Frauddetector":
        '''(experimental) Grants permission to update a model. You can update the description attribute using this action.

        Access Level: Write

        https://docs.aws.amazon.com/frauddetector/latest/api/API_UpdateModel.html

        :stability: experimental
        '''
        return typing.cast("Frauddetector", jsii.invoke(self, "toUpdateModel", []))

    @jsii.member(jsii_name="toUpdateModelVersion")
    def to_update_model_version(self) -> "Frauddetector":
        '''(experimental) Grants permission to update a model version.

        Updating a model version retrains an existing model version using updated training data and produces a new minor version of the model. You can update the training data set location and data access role attributes using this action. This action creates and trains a new minor version of the model, for example version 1.01, 1.02, 1.03

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/frauddetector/latest/api/API_UpdateModelVersion.html

        :stability: experimental
        '''
        return typing.cast("Frauddetector", jsii.invoke(self, "toUpdateModelVersion", []))

    @jsii.member(jsii_name="toUpdateModelVersionStatus")
    def to_update_model_version_status(self) -> "Frauddetector":
        '''(experimental) Grants permission to update the status of a model version.

        Access Level: Write

        https://docs.aws.amazon.com/frauddetector/latest/api/API_UpdateModelVersionStatus.html

        :stability: experimental
        '''
        return typing.cast("Frauddetector", jsii.invoke(self, "toUpdateModelVersionStatus", []))

    @jsii.member(jsii_name="toUpdateRuleMetadata")
    def to_update_rule_metadata(self) -> "Frauddetector":
        '''(experimental) Grants permission to update a rule's metadata. The description attribute can be updated.

        Access Level: Write

        https://docs.aws.amazon.com/frauddetector/latest/api/API_UpdateRuleMetadata.html

        :stability: experimental
        '''
        return typing.cast("Frauddetector", jsii.invoke(self, "toUpdateRuleMetadata", []))

    @jsii.member(jsii_name="toUpdateRuleVersion")
    def to_update_rule_version(self) -> "Frauddetector":
        '''(experimental) Grants permission to update a rule version resulting in a new rule version.

        Updates a rule version resulting in a new rule version (version 1, 2, 3 ...)

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/frauddetector/latest/api/API_UpdateRuleVersion.html

        :stability: experimental
        '''
        return typing.cast("Frauddetector", jsii.invoke(self, "toUpdateRuleVersion", []))

    @jsii.member(jsii_name="toUpdateVariable")
    def to_update_variable(self) -> "Frauddetector":
        '''(experimental) Grants permission to update a variable.

        Access Level: Write

        https://docs.aws.amazon.com/frauddetector/latest/api/API_UpdateVariable.html

        :stability: experimental
        '''
        return typing.cast("Frauddetector", jsii.invoke(self, "toUpdateVariable", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__34526e484ddf7e89731da4725419f81726f24f240981bd22e3c86fc2605dd765)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f959fce71652a8cb8fed2a40b2ea7da4d0cbaf499375760ff1b173ce01bf78b8)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Freertos(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Freertos",
):
    '''(experimental) Statement provider for service `freertos <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonfreertos.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `freertos <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonfreertos.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onConfiguration")
    def on_configuration(
        self,
        configuration_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Freertos":
        '''(experimental) Adds a resource of type configuration to the statement.

        https://docs.aws.amazon.com/freertos/latest/userguide/freertos-ocw.html

        :param configuration_name: - Identifier for the configurationName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__156d42df43a963c6ecce9dbace730c047c39982326a5c7b4b81da3aadb837e28)
            check_type(argname="argument configuration_name", value=configuration_name, expected_type=type_hints["configuration_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Freertos", jsii.invoke(self, "onConfiguration", [configuration_name, account, region, partition]))

    @jsii.member(jsii_name="toCreateSoftwareConfiguration")
    def to_create_software_configuration(self) -> "Freertos":
        '''(experimental) Creates a software configuration.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/freertos/latest/userguide/freertos-ocw.html

        :stability: experimental
        '''
        return typing.cast("Freertos", jsii.invoke(self, "toCreateSoftwareConfiguration", []))

    @jsii.member(jsii_name="toDeleteSoftwareConfiguration")
    def to_delete_software_configuration(self) -> "Freertos":
        '''(experimental) Deletes the software configuration.

        Access Level: Write

        https://docs.aws.amazon.com/freertos/latest/userguide/freertos-ocw.html

        :stability: experimental
        '''
        return typing.cast("Freertos", jsii.invoke(self, "toDeleteSoftwareConfiguration", []))

    @jsii.member(jsii_name="toDescribeHardwarePlatform")
    def to_describe_hardware_platform(self) -> "Freertos":
        '''(experimental) Describes the hardware platform.

        Access Level: Read

        https://docs.aws.amazon.com/freertos/latest/userguide/freertos-ocw.html

        :stability: experimental
        '''
        return typing.cast("Freertos", jsii.invoke(self, "toDescribeHardwarePlatform", []))

    @jsii.member(jsii_name="toDescribeSoftwareConfiguration")
    def to_describe_software_configuration(self) -> "Freertos":
        '''(experimental) Describes the software configuration.

        Access Level: Read

        https://docs.aws.amazon.com/freertos/latest/userguide/freertos-ocw.html

        :stability: experimental
        '''
        return typing.cast("Freertos", jsii.invoke(self, "toDescribeSoftwareConfiguration", []))

    @jsii.member(jsii_name="toGetSoftwareURL")
    def to_get_software_url(self) -> "Freertos":
        '''(experimental) Get the URL for Amazon FreeRTOS software download.

        Access Level: Read

        https://docs.aws.amazon.com/freertos/latest/userguide/freertos-ocw.html

        :stability: experimental
        '''
        return typing.cast("Freertos", jsii.invoke(self, "toGetSoftwareURL", []))

    @jsii.member(jsii_name="toGetSoftwareURLForConfiguration")
    def to_get_software_url_for_configuration(self) -> "Freertos":
        '''(experimental) Get the URL for Amazon FreeRTOS software download based on the configuration.

        Access Level: Read

        https://docs.aws.amazon.com/freertos/latest/userguide/freertos-ocw.html

        :stability: experimental
        '''
        return typing.cast("Freertos", jsii.invoke(self, "toGetSoftwareURLForConfiguration", []))

    @jsii.member(jsii_name="toListFreeRTOSVersions")
    def to_list_free_rtos_versions(self) -> "Freertos":
        '''(experimental) Lists versions of AmazonFreeRTOS.

        Access Level: List

        https://docs.aws.amazon.com/freertos/latest/userguide/freertos-ocw.html

        :stability: experimental
        '''
        return typing.cast("Freertos", jsii.invoke(self, "toListFreeRTOSVersions", []))

    @jsii.member(jsii_name="toListHardwarePlatforms")
    def to_list_hardware_platforms(self) -> "Freertos":
        '''(experimental) Lists the hardware platforms.

        Access Level: List

        https://docs.aws.amazon.com/freertos/latest/userguide/freertos-ocw.html

        :stability: experimental
        '''
        return typing.cast("Freertos", jsii.invoke(self, "toListHardwarePlatforms", []))

    @jsii.member(jsii_name="toListHardwareVendors")
    def to_list_hardware_vendors(self) -> "Freertos":
        '''(experimental) Lists the hardware vendors.

        Access Level: List

        https://docs.aws.amazon.com/freertos/latest/userguide/freertos-ocw.html

        :stability: experimental
        '''
        return typing.cast("Freertos", jsii.invoke(self, "toListHardwareVendors", []))

    @jsii.member(jsii_name="toListSoftwareConfigurations")
    def to_list_software_configurations(self) -> "Freertos":
        '''(experimental) Lists the software configurations.

        Access Level: List

        https://docs.aws.amazon.com/freertos/latest/userguide/freertos-ocw.html

        :stability: experimental
        '''
        return typing.cast("Freertos", jsii.invoke(self, "toListSoftwareConfigurations", []))

    @jsii.member(jsii_name="toUpdateSoftwareConfiguration")
    def to_update_software_configuration(self) -> "Freertos":
        '''(experimental) Updates the software configuration.

        Access Level: Write

        https://docs.aws.amazon.com/freertos/latest/userguide/freertos-ocw.html

        :stability: experimental
        '''
        return typing.cast("Freertos", jsii.invoke(self, "toUpdateSoftwareConfiguration", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7f5732a5d91a99f83a772a9f3fb5247f85beb1a71448aed801a5516bdd4bb571)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__44bcad1f8a4364a446d54804c7effd7feb29991db072451dc4c0060443050c5f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Fsx(PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Fsx"):
    '''(experimental) Statement provider for service `fsx <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonfsx.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `fsx <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonfsx.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="ifIsBackupCopyDestination")
    def if_is_backup_copy_destination(
        self,
        value: typing.Optional[builtins.bool] = None,
    ) -> "Fsx":
        '''(experimental) Filters access by whether the backup is a destination backup for a CopyBackup operation.

        https://docs.aws.amazon.com/fsx/latest/WindowsGuide/access-control-manage-access-intro.htmlAPI_CopyBackup.html

        :param value: ``true`` or ``false``. **Default:** ``true``

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c79c01b4ff535df5bd6b8451d222b0911ee58ecfd5639212b888ac64ec125d65)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast("Fsx", jsii.invoke(self, "ifIsBackupCopyDestination", [value]))

    @jsii.member(jsii_name="ifIsBackupCopySource")
    def if_is_backup_copy_source(
        self,
        value: typing.Optional[builtins.bool] = None,
    ) -> "Fsx":
        '''(experimental) Filters access by whether the backup is a source backup for a CopyBackup operation.

        https://docs.aws.amazon.com/fsx/latest/WindowsGuide/access-control-manage-access-intro.htmlAPI_CopyBackup.html

        :param value: ``true`` or ``false``. **Default:** ``true``

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1d51a2e520a7df2f95ce9d981427cfa1d7a5cb72993751ae6350a736d3621c9c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast("Fsx", jsii.invoke(self, "ifIsBackupCopySource", [value]))

    @jsii.member(jsii_name="ifNfsDataRepositoryAuthenticationEnabled")
    def if_nfs_data_repository_authentication_enabled(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Fsx":
        '''(experimental) Filters access by NFS data repositories which support authentication.

        https://docs.aws.amazon.com/fsx/latest/WindowsGuide/access-control-manage-access-intro.htmlAPI_CreateFileCache.html

        Applies to actions:

        - .toCreateFileCache()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e5b03bb2bd7ea8df1afd7279b560e2b2e6812b6fddb0d9429e7cbaf8060bc249)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Fsx", jsii.invoke(self, "ifNfsDataRepositoryAuthenticationEnabled", [value, operator]))

    @jsii.member(jsii_name="ifNfsDataRepositoryEncryptionInTransitEnabled")
    def if_nfs_data_repository_encryption_in_transit_enabled(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Fsx":
        '''(experimental) Filters access by NFS data repositories which support encryption-in-transit.

        https://docs.aws.amazon.com/fsx/latest/WindowsGuide/access-control-manage-access-intro.htmlAPI_CreateFileCache.html

        Applies to actions:

        - .toCreateFileCache()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__502c528a66df81196249b11b20246c0fc7cebce822b6545b54287a37447569f8)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Fsx", jsii.invoke(self, "ifNfsDataRepositoryEncryptionInTransitEnabled", [value, operator]))

    @jsii.member(jsii_name="ifParentVolumeId")
    def if_parent_volume_id(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Fsx":
        '''(experimental) Filters access by the containing parent volume for mutating volume operations.

        https://docs.aws.amazon.com/fsx/latest/WindowsGuide/access-control-manage-access-intro.htmlAPI_CreateVolume.html

        Applies to actions:

        - .toCreateVolume()
        - .toDeleteVolume()
        - .toUpdateVolume()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6c4d52ba321e702e1351829fea6344d5ea2acb0214a3f78f95a9d2a6677097fe)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Fsx", jsii.invoke(self, "ifParentVolumeId", [value, operator]))

    @jsii.member(jsii_name="ifStorageVirtualMachineId")
    def if_storage_virtual_machine_id(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Fsx":
        '''(experimental) Filters access by the containing storage virtual machine for a volume for mutating volume operations.

        https://docs.aws.amazon.com/fsx/latest/WindowsGuide/access-control-manage-access-intro.htmlAPI_CreateVolume.html

        Applies to actions:

        - .toCreateVolume()
        - .toCreateVolumeFromBackup()
        - .toDeleteVolume()
        - .toUpdateVolume()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__13c475ec548b4d05743cc6c546b26c462565e15f1871d4cf0bef0e99cce4d922)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Fsx", jsii.invoke(self, "ifStorageVirtualMachineId", [value, operator]))

    @jsii.member(jsii_name="onAssociation")
    def on_association(
        self,
        file_system_id_or_file_cache_id: builtins.str,
        data_repository_association_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Fsx":
        '''(experimental) Adds a resource of type association to the statement.

        https://docs.aws.amazon.com/fsx/latest/LustreGuide/access-control-overview.html#access-control-resources

        :param file_system_id_or_file_cache_id: - Identifier for the fileSystemIdOrFileCacheId.
        :param data_repository_association_id: - Identifier for the dataRepositoryAssociationId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__dfdc9859f5cb10592bacd64517e90ffad6e702f41ba13ced4f78f4acba43555f)
            check_type(argname="argument file_system_id_or_file_cache_id", value=file_system_id_or_file_cache_id, expected_type=type_hints["file_system_id_or_file_cache_id"])
            check_type(argname="argument data_repository_association_id", value=data_repository_association_id, expected_type=type_hints["data_repository_association_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Fsx", jsii.invoke(self, "onAssociation", [file_system_id_or_file_cache_id, data_repository_association_id, account, region, partition]))

    @jsii.member(jsii_name="onBackup")
    def on_backup(
        self,
        backup_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Fsx":
        '''(experimental) Adds a resource of type backup to the statement.

        https://docs.aws.amazon.com/fsx/latest/WindowsGuide/access-control-overview.html#access-control-resources

        :param backup_id: - Identifier for the backupId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a079a04dffb591dbdf4f3c51144e164a94ded9526bf2bc25576b710a6e69e936)
            check_type(argname="argument backup_id", value=backup_id, expected_type=type_hints["backup_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Fsx", jsii.invoke(self, "onBackup", [backup_id, account, region, partition]))

    @jsii.member(jsii_name="onFileCache")
    def on_file_cache(
        self,
        file_cache_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Fsx":
        '''(experimental) Adds a resource of type file-cache to the statement.

        https://docs.aws.amazon.com/fsx/latest/FileCacheGuide/security-iam.html

        :param file_cache_id: - Identifier for the fileCacheId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8dab6f903f7904914c550035af0a220d1c173adcb769ac4035170cb10625704f)
            check_type(argname="argument file_cache_id", value=file_cache_id, expected_type=type_hints["file_cache_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Fsx", jsii.invoke(self, "onFileCache", [file_cache_id, account, region, partition]))

    @jsii.member(jsii_name="onFileSystem")
    def on_file_system(
        self,
        file_system_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Fsx":
        '''(experimental) Adds a resource of type file-system to the statement.

        https://docs.aws.amazon.com/fsx/latest/WindowsGuide/access-control-overview.html#access-control-resources

        :param file_system_id: - Identifier for the fileSystemId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__72b386c9ba840401b1bf47d48faf9834ffbaca60f7b0e843e4b53929193468ef)
            check_type(argname="argument file_system_id", value=file_system_id, expected_type=type_hints["file_system_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Fsx", jsii.invoke(self, "onFileSystem", [file_system_id, account, region, partition]))

    @jsii.member(jsii_name="onSnapshot")
    def on_snapshot(
        self,
        volume_id: builtins.str,
        snapshot_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Fsx":
        '''(experimental) Adds a resource of type snapshot to the statement.

        https://docs.aws.amazon.com/fsx/latest/OpenFsGuide/access-control-overview.html#access-control-resources

        :param volume_id: - Identifier for the volumeId.
        :param snapshot_id: - Identifier for the snapshotId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__aa8c78ac644df1972a0e26276e3318dc619d438b22682267eb9ca7decf963567)
            check_type(argname="argument volume_id", value=volume_id, expected_type=type_hints["volume_id"])
            check_type(argname="argument snapshot_id", value=snapshot_id, expected_type=type_hints["snapshot_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Fsx", jsii.invoke(self, "onSnapshot", [volume_id, snapshot_id, account, region, partition]))

    @jsii.member(jsii_name="onStorageVirtualMachine")
    def on_storage_virtual_machine(
        self,
        file_system_id: builtins.str,
        storage_virtual_machine_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Fsx":
        '''(experimental) Adds a resource of type storage-virtual-machine to the statement.

        https://docs.aws.amazon.com/fsx/latest/ONTAPGuide/security-iam.html

        :param file_system_id: - Identifier for the fileSystemId.
        :param storage_virtual_machine_id: - Identifier for the storageVirtualMachineId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c94faf3548eb6b569b69163f2794af87364ddbbc546d711527cf2af2d17d30d2)
            check_type(argname="argument file_system_id", value=file_system_id, expected_type=type_hints["file_system_id"])
            check_type(argname="argument storage_virtual_machine_id", value=storage_virtual_machine_id, expected_type=type_hints["storage_virtual_machine_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Fsx", jsii.invoke(self, "onStorageVirtualMachine", [file_system_id, storage_virtual_machine_id, account, region, partition]))

    @jsii.member(jsii_name="onTask")
    def on_task(
        self,
        task_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Fsx":
        '''(experimental) Adds a resource of type task to the statement.

        https://docs.aws.amazon.com/fsx/latest/LustreGuide/access-control-overview.html#access-control-resources

        :param task_id: - Identifier for the taskId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__dd8514f6da428d4ca021c9fed66233a6133cdbe3381db2f5b060d7d5a7be9f18)
            check_type(argname="argument task_id", value=task_id, expected_type=type_hints["task_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Fsx", jsii.invoke(self, "onTask", [task_id, account, region, partition]))

    @jsii.member(jsii_name="onVolume")
    def on_volume(
        self,
        file_system_id: builtins.str,
        volume_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Fsx":
        '''(experimental) Adds a resource of type volume to the statement.

        https://docs.aws.amazon.com/fsx/latest/ONTAPGuide/security-iam.html

        :param file_system_id: - Identifier for the fileSystemId.
        :param volume_id: - Identifier for the volumeId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bde3042b6ddb9bd40f2f5ba6b670d2946dd5baba971d0bf762dafd768d069778)
            check_type(argname="argument file_system_id", value=file_system_id, expected_type=type_hints["file_system_id"])
            check_type(argname="argument volume_id", value=volume_id, expected_type=type_hints["volume_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Fsx", jsii.invoke(self, "onVolume", [file_system_id, volume_id, account, region, partition]))

    @jsii.member(jsii_name="toAssociateFileGateway")
    def to_associate_file_gateway(self) -> "Fsx":
        '''(experimental) Grants permission to associate a File Gateway instance with an Amazon FSx for Windows File Server file system.

        Access Level: Write

        https://docs.aws.amazon.com/filegateway/latest/filefsxw/what-is-file-fsxw.html

        :stability: experimental
        '''
        return typing.cast("Fsx", jsii.invoke(self, "toAssociateFileGateway", []))

    @jsii.member(jsii_name="toAssociateFileSystemAliases")
    def to_associate_file_system_aliases(self) -> "Fsx":
        '''(experimental) Grants permission to associate DNS aliases with an Amazon FSx for Windows File Server file system.

        Access Level: Write

        https://docs.aws.amazon.com/fsx/latest/APIReference/API_AssociateFileSystemAliases.html

        :stability: experimental
        '''
        return typing.cast("Fsx", jsii.invoke(self, "toAssociateFileSystemAliases", []))

    @jsii.member(jsii_name="toCancelDataRepositoryTask")
    def to_cancel_data_repository_task(self) -> "Fsx":
        '''(experimental) Grants permission to cancel a data repository task.

        Access Level: Write

        https://docs.aws.amazon.com/fsx/latest/APIReference/API_CancelDataRepositoryTask.html

        :stability: experimental
        '''
        return typing.cast("Fsx", jsii.invoke(self, "toCancelDataRepositoryTask", []))

    @jsii.member(jsii_name="toCopyBackup")
    def to_copy_backup(self) -> "Fsx":
        '''(experimental) Grants permission to copy a backup.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - fsx:TagResource

        https://docs.aws.amazon.com/fsx/latest/APIReference/API_CopyBackup.html

        :stability: experimental
        '''
        return typing.cast("Fsx", jsii.invoke(self, "toCopyBackup", []))

    @jsii.member(jsii_name="toCreateBackup")
    def to_create_backup(self) -> "Fsx":
        '''(experimental) Grants permission to create a new backup of an Amazon FSx file system or an Amazon FSx volume.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - fsx:TagResource

        https://docs.aws.amazon.com/fsx/latest/APIReference/API_CreateBackup.html

        :stability: experimental
        '''
        return typing.cast("Fsx", jsii.invoke(self, "toCreateBackup", []))

    @jsii.member(jsii_name="toCreateDataRepositoryAssociation")
    def to_create_data_repository_association(self) -> "Fsx":
        '''(experimental) Grants permission to create a new data respository association for an Amazon FSx for Lustre file system.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - fsx:TagResource

        https://docs.aws.amazon.com/fsx/latest/APIReference/API_CreateDataRepositoryAssociation.html

        :stability: experimental
        '''
        return typing.cast("Fsx", jsii.invoke(self, "toCreateDataRepositoryAssociation", []))

    @jsii.member(jsii_name="toCreateDataRepositoryTask")
    def to_create_data_repository_task(self) -> "Fsx":
        '''(experimental) Grants permission to create a new data respository task for an Amazon FSx for Lustre file system.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - fsx:TagResource

        https://docs.aws.amazon.com/fsx/latest/APIReference/API_CreateDataRepositoryTask.html

        :stability: experimental
        '''
        return typing.cast("Fsx", jsii.invoke(self, "toCreateDataRepositoryTask", []))

    @jsii.member(jsii_name="toCreateFileCache")
    def to_create_file_cache(self) -> "Fsx":
        '''(experimental) Grants permission to create a new, empty, Amazon file cache.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - ec2:DescribeSecurityGroups
        - ec2:DescribeSubnets
        - ec2:DescribeVpcs
        - fsx:CreateDataRepositoryAssociation
        - fsx:TagResource
        - logs:CreateLogGroup
        - logs:CreateLogStream
        - logs:PutLogEvents
        - s3:ListBucket

        https://docs.aws.amazon.com/fsx/latest/APIReference/API_CreateFileCache.html

        :stability: experimental
        '''
        return typing.cast("Fsx", jsii.invoke(self, "toCreateFileCache", []))

    @jsii.member(jsii_name="toCreateFileSystem")
    def to_create_file_system(self) -> "Fsx":
        '''(experimental) Grants permission to create a new, empty, Amazon FSx file system.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - fsx:TagResource

        https://docs.aws.amazon.com/fsx/latest/APIReference/API_CreateFileSystem.html

        :stability: experimental
        '''
        return typing.cast("Fsx", jsii.invoke(self, "toCreateFileSystem", []))

    @jsii.member(jsii_name="toCreateFileSystemFromBackup")
    def to_create_file_system_from_backup(self) -> "Fsx":
        '''(experimental) Grants permission to create a new Amazon FSx file system from an existing backup.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - fsx:TagResource

        https://docs.aws.amazon.com/fsx/latest/APIReference/API_CreateFileSystemFromBackup.html

        :stability: experimental
        '''
        return typing.cast("Fsx", jsii.invoke(self, "toCreateFileSystemFromBackup", []))

    @jsii.member(jsii_name="toCreateSnapshot")
    def to_create_snapshot(self) -> "Fsx":
        '''(experimental) Grants permission to create a new snapshot on a volume.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - fsx:TagResource

        https://docs.aws.amazon.com/fsx/latest/APIReference/API_CreateSnapshot.html

        :stability: experimental
        '''
        return typing.cast("Fsx", jsii.invoke(self, "toCreateSnapshot", []))

    @jsii.member(jsii_name="toCreateStorageVirtualMachine")
    def to_create_storage_virtual_machine(self) -> "Fsx":
        '''(experimental) Grants permission to create a new storage virtual machine in an Amazon FSx for Ontap file system.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - fsx:TagResource

        https://docs.aws.amazon.com/fsx/latest/APIReference/API_CreateStorageVirtualMachine.html

        :stability: experimental
        '''
        return typing.cast("Fsx", jsii.invoke(self, "toCreateStorageVirtualMachine", []))

    @jsii.member(jsii_name="toCreateVolume")
    def to_create_volume(self) -> "Fsx":
        '''(experimental) Grants permission to create a new volume.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifStorageVirtualMachineId()
        - .ifParentVolumeId()

        Dependent actions:

        - fsx:TagResource

        https://docs.aws.amazon.com/fsx/latest/APIReference/API_CreateVolume.html

        :stability: experimental
        '''
        return typing.cast("Fsx", jsii.invoke(self, "toCreateVolume", []))

    @jsii.member(jsii_name="toCreateVolumeFromBackup")
    def to_create_volume_from_backup(self) -> "Fsx":
        '''(experimental) Grants permission to create a new volume from backup.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifStorageVirtualMachineId()

        Dependent actions:

        - fsx:TagResource

        https://docs.aws.amazon.com/fsx/latest/APIReference/API_CreateVolumeFromBackup.html

        :stability: experimental
        '''
        return typing.cast("Fsx", jsii.invoke(self, "toCreateVolumeFromBackup", []))

    @jsii.member(jsii_name="toDeleteBackup")
    def to_delete_backup(self) -> "Fsx":
        '''(experimental) Grants permission to delete a backup, deleting its contents.

        After deletion, the backup no longer exists, and its data is no longer available

        Access Level: Write

        https://docs.aws.amazon.com/fsx/latest/APIReference/API_DeleteBackup.html

        :stability: experimental
        '''
        return typing.cast("Fsx", jsii.invoke(self, "toDeleteBackup", []))

    @jsii.member(jsii_name="toDeleteDataRepositoryAssociation")
    def to_delete_data_repository_association(self) -> "Fsx":
        '''(experimental) Grants permission to delete a data repository association.

        Access Level: Write

        https://docs.aws.amazon.com/fsx/latest/APIReference/API_DeleteDataRepositoryAssociation.html

        :stability: experimental
        '''
        return typing.cast("Fsx", jsii.invoke(self, "toDeleteDataRepositoryAssociation", []))

    @jsii.member(jsii_name="toDeleteFileCache")
    def to_delete_file_cache(self) -> "Fsx":
        '''(experimental) Grants permission to delete a file cache, deleting its contents.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - fsx:DeleteDataRepositoryAssociation

        https://docs.aws.amazon.com/fsx/latest/APIReference/API_DeleteFileCache.html

        :stability: experimental
        '''
        return typing.cast("Fsx", jsii.invoke(self, "toDeleteFileCache", []))

    @jsii.member(jsii_name="toDeleteFileSystem")
    def to_delete_file_system(self) -> "Fsx":
        '''(experimental) Grants permission to delete a file system, deleting its contents and any existing automatic backups of the file system.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - fsx:CreateBackup
        - fsx:TagResource

        https://docs.aws.amazon.com/fsx/latest/APIReference/API_DeleteFileSystem.html

        :stability: experimental
        '''
        return typing.cast("Fsx", jsii.invoke(self, "toDeleteFileSystem", []))

    @jsii.member(jsii_name="toDeleteSnapshot")
    def to_delete_snapshot(self) -> "Fsx":
        '''(experimental) Grants permission to delete a snapshot on a volume.

        Access Level: Write

        https://docs.aws.amazon.com/fsx/latest/APIReference/API_DeleteSnapshot.html

        :stability: experimental
        '''
        return typing.cast("Fsx", jsii.invoke(self, "toDeleteSnapshot", []))

    @jsii.member(jsii_name="toDeleteStorageVirtualMachine")
    def to_delete_storage_virtual_machine(self) -> "Fsx":
        '''(experimental) Grants permission to delete a storage virtual machine, deleting its contents.

        Access Level: Write

        https://docs.aws.amazon.com/fsx/latest/APIReference/API_DeleteStorageVirtualMachine.html

        :stability: experimental
        '''
        return typing.cast("Fsx", jsii.invoke(self, "toDeleteStorageVirtualMachine", []))

    @jsii.member(jsii_name="toDeleteVolume")
    def to_delete_volume(self) -> "Fsx":
        '''(experimental) Grants permission to delete a volume, deleting its contents and any existing automatic backups of the volume.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifStorageVirtualMachineId()
        - .ifParentVolumeId()

        Dependent actions:

        - fsx:TagResource

        https://docs.aws.amazon.com/fsx/latest/APIReference/API_DeleteVolume.html

        :stability: experimental
        '''
        return typing.cast("Fsx", jsii.invoke(self, "toDeleteVolume", []))

    @jsii.member(jsii_name="toDescribeAssociatedFileGateways")
    def to_describe_associated_file_gateways(self) -> "Fsx":
        '''(experimental) Grants permission to describe the File Gateway instances associated with an Amazon FSx for Windows File Server file system.

        Access Level: Read

        https://docs.aws.amazon.com/filegateway/latest/filefsxw/what-is-file-fsxw.html

        :stability: experimental
        '''
        return typing.cast("Fsx", jsii.invoke(self, "toDescribeAssociatedFileGateways", []))

    @jsii.member(jsii_name="toDescribeBackups")
    def to_describe_backups(self) -> "Fsx":
        '''(experimental) Grants permission to return the descriptions of all backups owned by your AWS account in the AWS Region of the endpoint that you're calling.

        Access Level: Read

        https://docs.aws.amazon.com/fsx/latest/APIReference/API_DescribeBackups.html

        :stability: experimental
        '''
        return typing.cast("Fsx", jsii.invoke(self, "toDescribeBackups", []))

    @jsii.member(jsii_name="toDescribeDataRepositoryAssociations")
    def to_describe_data_repository_associations(self) -> "Fsx":
        '''(experimental) Grants permission to return the descriptions of all data repository associations owned by your AWS account in the AWS Region of the endpoint that you're calling.

        Access Level: Read

        https://docs.aws.amazon.com/fsx/latest/APIReference/API_DescribeDataRepositoryAssociations.html

        :stability: experimental
        '''
        return typing.cast("Fsx", jsii.invoke(self, "toDescribeDataRepositoryAssociations", []))

    @jsii.member(jsii_name="toDescribeDataRepositoryTasks")
    def to_describe_data_repository_tasks(self) -> "Fsx":
        '''(experimental) Grants permission to return the descriptions of all data repository tasks owned by your AWS account in the AWS Region of the endpoint that you're calling.

        Access Level: Read

        https://docs.aws.amazon.com/fsx/latest/APIReference/API_DescribeDataRepositoryTasks.html

        :stability: experimental
        '''
        return typing.cast("Fsx", jsii.invoke(self, "toDescribeDataRepositoryTasks", []))

    @jsii.member(jsii_name="toDescribeFileCaches")
    def to_describe_file_caches(self) -> "Fsx":
        '''(experimental) Grants permission to return the descriptions of all file caches owned by your AWS account in the AWS Region of the endpoint that you're calling.

        Access Level: Read

        https://docs.aws.amazon.com/fsx/latest/APIReference/API_DescribeFileCaches.html

        :stability: experimental
        '''
        return typing.cast("Fsx", jsii.invoke(self, "toDescribeFileCaches", []))

    @jsii.member(jsii_name="toDescribeFileSystemAliases")
    def to_describe_file_system_aliases(self) -> "Fsx":
        '''(experimental) Grants permission to return the description of all DNS aliases owned by your Amazon FSx for Windows File Server file system.

        Access Level: Read

        https://docs.aws.amazon.com/fsx/latest/APIReference/API_DescribeFileSystemAliases.html

        :stability: experimental
        '''
        return typing.cast("Fsx", jsii.invoke(self, "toDescribeFileSystemAliases", []))

    @jsii.member(jsii_name="toDescribeFileSystems")
    def to_describe_file_systems(self) -> "Fsx":
        '''(experimental) Grants permission to return the descriptions of all file systems owned by your AWS account in the AWS Region of the endpoint that you're calling.

        Access Level: Read

        https://docs.aws.amazon.com/fsx/latest/APIReference/API_DescribeFileSystems.html

        :stability: experimental
        '''
        return typing.cast("Fsx", jsii.invoke(self, "toDescribeFileSystems", []))

    @jsii.member(jsii_name="toDescribeSnapshots")
    def to_describe_snapshots(self) -> "Fsx":
        '''(experimental) Grants permission to return the descriptions of all snapshots owned by your AWS account in the AWS Region of the endpoint you're calling.

        Access Level: Read

        https://docs.aws.amazon.com/fsx/latest/APIReference/API_DescribeSnapshots.html

        :stability: experimental
        '''
        return typing.cast("Fsx", jsii.invoke(self, "toDescribeSnapshots", []))

    @jsii.member(jsii_name="toDescribeStorageVirtualMachines")
    def to_describe_storage_virtual_machines(self) -> "Fsx":
        '''(experimental) Grants permission to return the descriptions of all storage virtual machines owned by your AWS account in the AWS Region of the endpoint that you're calling.

        Access Level: Read

        https://docs.aws.amazon.com/fsx/latest/APIReference/API_DescribeStorageVirtualMachines.html

        :stability: experimental
        '''
        return typing.cast("Fsx", jsii.invoke(self, "toDescribeStorageVirtualMachines", []))

    @jsii.member(jsii_name="toDescribeVolumes")
    def to_describe_volumes(self) -> "Fsx":
        '''(experimental) Grants permission to return the descriptions of all volumes owned by your AWS account in the AWS Region of the endpoint that you're calling.

        Access Level: Read

        https://docs.aws.amazon.com/fsx/latest/APIReference/API_DescribeVolumes.html

        :stability: experimental
        '''
        return typing.cast("Fsx", jsii.invoke(self, "toDescribeVolumes", []))

    @jsii.member(jsii_name="toDisassociateFileGateway")
    def to_disassociate_file_gateway(self) -> "Fsx":
        '''(experimental) Grants permission to disassociate a File Gateway instance from an Amazon FSx for Windows File Server file system.

        Access Level: Write

        https://docs.aws.amazon.com/filegateway/latest/filefsxw/what-is-file-fsxw.html

        :stability: experimental
        '''
        return typing.cast("Fsx", jsii.invoke(self, "toDisassociateFileGateway", []))

    @jsii.member(jsii_name="toDisassociateFileSystemAliases")
    def to_disassociate_file_system_aliases(self) -> "Fsx":
        '''(experimental) Grants permission to disassociate file system aliases with an Amazon FSx for Windows File Server file system.

        Access Level: Write

        https://docs.aws.amazon.com/fsx/latest/APIReference/API_DisassociateFileSystemAliases.html

        :stability: experimental
        '''
        return typing.cast("Fsx", jsii.invoke(self, "toDisassociateFileSystemAliases", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Fsx":
        '''(experimental) Grants permission to list tags for an Amazon FSx resource.

        Access Level: Read

        https://docs.aws.amazon.com/fsx/latest/APIReference/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("Fsx", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toManageBackupPrincipalAssociations")
    def to_manage_backup_principal_associations(self) -> "Fsx":
        '''(experimental) Grants permission to manage backup principal associations through AWS Backup.

        Access Level: Permissions management

        https://docs.aws.amazon.com/fsx/latest/APIReference/API_CopyBackup.html

        :stability: experimental
        '''
        return typing.cast("Fsx", jsii.invoke(self, "toManageBackupPrincipalAssociations", []))

    @jsii.member(jsii_name="toReleaseFileSystemNfsV3Locks")
    def to_release_file_system_nfs_v3_locks(self) -> "Fsx":
        '''(experimental) Grants permission to release file system NFS V3 locks.

        Access Level: Write

        https://docs.aws.amazon.com/fsx/latest/APIReference/API_ReleaseFileSystemNfsV3Locks.html

        :stability: experimental
        '''
        return typing.cast("Fsx", jsii.invoke(self, "toReleaseFileSystemNfsV3Locks", []))

    @jsii.member(jsii_name="toRestoreVolumeFromSnapshot")
    def to_restore_volume_from_snapshot(self) -> "Fsx":
        '''(experimental) Grants permission to restore volume state from a snapshot.

        Access Level: Write

        https://docs.aws.amazon.com/fsx/latest/APIReference/API_RestoreVolumeFromSnapshot.html

        :stability: experimental
        '''
        return typing.cast("Fsx", jsii.invoke(self, "toRestoreVolumeFromSnapshot", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Fsx":
        '''(experimental) Grants permission to tag an Amazon FSx resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/fsx/latest/APIReference/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("Fsx", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Fsx":
        '''(experimental) Grants permission to remove a tag from an Amazon FSx resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/fsx/latest/APIReference/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("Fsx", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateDataRepositoryAssociation")
    def to_update_data_repository_association(self) -> "Fsx":
        '''(experimental) Grants permission to update data repository association configuration.

        Access Level: Write

        https://docs.aws.amazon.com/fsx/latest/APIReference/API_UpdateDataRepositoryAssociation.html

        :stability: experimental
        '''
        return typing.cast("Fsx", jsii.invoke(self, "toUpdateDataRepositoryAssociation", []))

    @jsii.member(jsii_name="toUpdateFileCache")
    def to_update_file_cache(self) -> "Fsx":
        '''(experimental) Grants permission to update file cache configuration.

        Access Level: Write

        https://docs.aws.amazon.com/fsx/latest/APIReference/API_UpdateFileCache.html

        :stability: experimental
        '''
        return typing.cast("Fsx", jsii.invoke(self, "toUpdateFileCache", []))

    @jsii.member(jsii_name="toUpdateFileSystem")
    def to_update_file_system(self) -> "Fsx":
        '''(experimental) Grants permission to update file system configuration.

        Access Level: Write

        https://docs.aws.amazon.com/fsx/latest/APIReference/API_UpdateFileSystem.html

        :stability: experimental
        '''
        return typing.cast("Fsx", jsii.invoke(self, "toUpdateFileSystem", []))

    @jsii.member(jsii_name="toUpdateSnapshot")
    def to_update_snapshot(self) -> "Fsx":
        '''(experimental) Grants permission to update snapshot configuration.

        Access Level: Write

        https://docs.aws.amazon.com/fsx/latest/APIReference/API_UpdateSnapshot.html

        :stability: experimental
        '''
        return typing.cast("Fsx", jsii.invoke(self, "toUpdateSnapshot", []))

    @jsii.member(jsii_name="toUpdateStorageVirtualMachine")
    def to_update_storage_virtual_machine(self) -> "Fsx":
        '''(experimental) Grants permission to update storage virtual machine configuration.

        Access Level: Write

        https://docs.aws.amazon.com/fsx/latest/APIReference/API_UpdateStorageVirtualMachine.html

        :stability: experimental
        '''
        return typing.cast("Fsx", jsii.invoke(self, "toUpdateStorageVirtualMachine", []))

    @jsii.member(jsii_name="toUpdateVolume")
    def to_update_volume(self) -> "Fsx":
        '''(experimental) Grants permission to update volume configuration.

        Access Level: Write

        Possible conditions:

        - .ifStorageVirtualMachineId()
        - .ifParentVolumeId()

        https://docs.aws.amazon.com/fsx/latest/APIReference/API_UpdateVolume.html

        :stability: experimental
        '''
        return typing.cast("Fsx", jsii.invoke(self, "toUpdateVolume", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__496467f7cbdc8e21cea58a7dcb92283dace9d489b6a329db9dc01dd22baed2b0)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__65d590585eaa0520f1c8be9db32f95721ad0767e8ce3b71584c86a8feb8d5bd7)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Gamelift(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Gamelift",
):
    '''(experimental) Statement provider for service `gamelift <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazongamelift.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `gamelift <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazongamelift.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onAlias")
    def on_alias(
        self,
        alias_id: builtins.str,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Gamelift":
        '''(experimental) Adds a resource of type alias to the statement.

        https://docs.aws.amazon.com/gamelift/latest/developerguide/gamelift-console-aliases.html

        :param alias_id: - Identifier for the aliasId.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a0f1a4311ae8c9721165721acfc2198c70f027cb0fd0346708597841b3ad8036)
            check_type(argname="argument alias_id", value=alias_id, expected_type=type_hints["alias_id"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Gamelift", jsii.invoke(self, "onAlias", [alias_id, region, partition]))

    @jsii.member(jsii_name="onBuild")
    def on_build(
        self,
        build_id: builtins.str,
        account_id: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Gamelift":
        '''(experimental) Adds a resource of type build to the statement.

        https://docs.aws.amazon.com/gamelift/latest/developerguide/gamelift-console-builds.html

        :param build_id: - Identifier for the buildId.
        :param account_id: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b44088498e4c6f72bed429972e2ee52b7110c1c3e37ecf41c7d36d0895498ff1)
            check_type(argname="argument build_id", value=build_id, expected_type=type_hints["build_id"])
            check_type(argname="argument account_id", value=account_id, expected_type=type_hints["account_id"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Gamelift", jsii.invoke(self, "onBuild", [build_id, account_id, region, partition]))

    @jsii.member(jsii_name="onFleet")
    def on_fleet(
        self,
        fleet_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Gamelift":
        '''(experimental) Adds a resource of type fleet to the statement.

        https://docs.aws.amazon.com/gamelift/latest/developerguide/gamelift-console-fleets.html

        :param fleet_id: - Identifier for the fleetId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7b94ba1098be79d592a5ae0327335dc667fac4aeef5b8d9c11027ae4bee0cd66)
            check_type(argname="argument fleet_id", value=fleet_id, expected_type=type_hints["fleet_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Gamelift", jsii.invoke(self, "onFleet", [fleet_id, account, region, partition]))

    @jsii.member(jsii_name="onGameServerGroup")
    def on_game_server_group(
        self,
        game_server_group_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Gamelift":
        '''(experimental) Adds a resource of type gameServerGroup to the statement.

        https://docs.aws.amazon.com/gamelift/latest/fleetiqguide/gsg-integrate-gameservergroup.html

        :param game_server_group_name: - Identifier for the gameServerGroupName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__abf1de3960cddcbef1905bf1a7b6491c9e0072d3fb7f1cf64bc93a6fafab6f85)
            check_type(argname="argument game_server_group_name", value=game_server_group_name, expected_type=type_hints["game_server_group_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Gamelift", jsii.invoke(self, "onGameServerGroup", [game_server_group_name, account, region, partition]))

    @jsii.member(jsii_name="onGameSessionQueue")
    def on_game_session_queue(
        self,
        game_session_queue_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Gamelift":
        '''(experimental) Adds a resource of type gameSessionQueue to the statement.

        https://docs.aws.amazon.com/gamelift/latest/developerguide/queues-console.html

        :param game_session_queue_name: - Identifier for the gameSessionQueueName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__52ea4d3ecbb453973f06a4ffabb69be59da479e63c42193846937e0679e3cde9)
            check_type(argname="argument game_session_queue_name", value=game_session_queue_name, expected_type=type_hints["game_session_queue_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Gamelift", jsii.invoke(self, "onGameSessionQueue", [game_session_queue_name, account, region, partition]))

    @jsii.member(jsii_name="onLocation")
    def on_location(
        self,
        location_id: builtins.str,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Gamelift":
        '''(experimental) Adds a resource of type location to the statement.

        https://docs.aws.amazon.com/gamelift/latest/developerguide/locations-console.html

        :param location_id: - Identifier for the locationId.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__929c834604eed8ebe8998469a72cee0cc03c8f79ab723de17166aa359ce3b3cb)
            check_type(argname="argument location_id", value=location_id, expected_type=type_hints["location_id"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Gamelift", jsii.invoke(self, "onLocation", [location_id, region, partition]))

    @jsii.member(jsii_name="onMatchmakingConfiguration")
    def on_matchmaking_configuration(
        self,
        matchmaking_configuration_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Gamelift":
        '''(experimental) Adds a resource of type matchmakingConfiguration to the statement.

        https://docs.aws.amazon.com/gamelift/latest/flexmatchguide/match-create-configuration.html

        :param matchmaking_configuration_name: - Identifier for the matchmakingConfigurationName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__647ecf601dc27fc5139cf0cfefaa37896ffac0da6366c91797367d123e097011)
            check_type(argname="argument matchmaking_configuration_name", value=matchmaking_configuration_name, expected_type=type_hints["matchmaking_configuration_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Gamelift", jsii.invoke(self, "onMatchmakingConfiguration", [matchmaking_configuration_name, account, region, partition]))

    @jsii.member(jsii_name="onMatchmakingRuleSet")
    def on_matchmaking_rule_set(
        self,
        matchmaking_rule_set_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Gamelift":
        '''(experimental) Adds a resource of type matchmakingRuleSet to the statement.

        https://docs.aws.amazon.com/gamelift/latest/flexmatchguide/match-rulesets.html

        :param matchmaking_rule_set_name: - Identifier for the matchmakingRuleSetName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__554f01d5ca130df84126d5fd21dea6975d476f22c870b02fa4d33e433222e216)
            check_type(argname="argument matchmaking_rule_set_name", value=matchmaking_rule_set_name, expected_type=type_hints["matchmaking_rule_set_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Gamelift", jsii.invoke(self, "onMatchmakingRuleSet", [matchmaking_rule_set_name, account, region, partition]))

    @jsii.member(jsii_name="onScript")
    def on_script(
        self,
        script_id: builtins.str,
        account_id: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Gamelift":
        '''(experimental) Adds a resource of type script to the statement.

        https://docs.aws.amazon.com/gamelift/latest/developerguide/gamelift-console-scripts.html

        :param script_id: - Identifier for the scriptId.
        :param account_id: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c64462d2631ab1a95de34782c80857be8715630f5824c02458f5590a94844333)
            check_type(argname="argument script_id", value=script_id, expected_type=type_hints["script_id"])
            check_type(argname="argument account_id", value=account_id, expected_type=type_hints["account_id"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Gamelift", jsii.invoke(self, "onScript", [script_id, account_id, region, partition]))

    @jsii.member(jsii_name="toAcceptMatch")
    def to_accept_match(self) -> "Gamelift":
        '''(experimental) Grants permission to register player acceptance or rejection of a proposed FlexMatch match.

        Access Level: Write

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_AcceptMatch.html

        :stability: experimental
        '''
        return typing.cast("Gamelift", jsii.invoke(self, "toAcceptMatch", []))

    @jsii.member(jsii_name="toClaimGameServer")
    def to_claim_game_server(self) -> "Gamelift":
        '''(experimental) Grants permission to locate and reserve a game server to host a new game session.

        Access Level: Write

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_ClaimGameServer.html

        :stability: experimental
        '''
        return typing.cast("Gamelift", jsii.invoke(self, "toClaimGameServer", []))

    @jsii.member(jsii_name="toCreateAlias")
    def to_create_alias(self) -> "Gamelift":
        '''(experimental) Grants permission to define a new alias for a fleet.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_CreateAlias.html

        :stability: experimental
        '''
        return typing.cast("Gamelift", jsii.invoke(self, "toCreateAlias", []))

    @jsii.member(jsii_name="toCreateBuild")
    def to_create_build(self) -> "Gamelift":
        '''(experimental) Grants permission to create a new game build using files stored in an Amazon S3 bucket.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_CreateBuild.html

        :stability: experimental
        '''
        return typing.cast("Gamelift", jsii.invoke(self, "toCreateBuild", []))

    @jsii.member(jsii_name="toCreateFleet")
    def to_create_fleet(self) -> "Gamelift":
        '''(experimental) Grants permission to create a new fleet of computing resources to run your game servers.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_CreateFleet.html

        :stability: experimental
        '''
        return typing.cast("Gamelift", jsii.invoke(self, "toCreateFleet", []))

    @jsii.member(jsii_name="toCreateFleetLocations")
    def to_create_fleet_locations(self) -> "Gamelift":
        '''(experimental) Grants permission to specify additional locations for a fleet.

        Access Level: Write

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_CreateFleetLocations.html

        :stability: experimental
        '''
        return typing.cast("Gamelift", jsii.invoke(self, "toCreateFleetLocations", []))

    @jsii.member(jsii_name="toCreateGameServerGroup")
    def to_create_game_server_group(self) -> "Gamelift":
        '''(experimental) Grants permission to create a new game server group, set up a corresponding Auto Scaling group, and launche instances to host game servers.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_CreateGameServerGroup.html

        :stability: experimental
        '''
        return typing.cast("Gamelift", jsii.invoke(self, "toCreateGameServerGroup", []))

    @jsii.member(jsii_name="toCreateGameSession")
    def to_create_game_session(self) -> "Gamelift":
        '''(experimental) Grants permission to start a new game session on a specified fleet.

        Access Level: Write

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_CreateGameSession.html

        :stability: experimental
        '''
        return typing.cast("Gamelift", jsii.invoke(self, "toCreateGameSession", []))

    @jsii.member(jsii_name="toCreateGameSessionQueue")
    def to_create_game_session_queue(self) -> "Gamelift":
        '''(experimental) Grants permission to set up a new queue for processing game session placement requests.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_CreateGameSessionQueue.html

        :stability: experimental
        '''
        return typing.cast("Gamelift", jsii.invoke(self, "toCreateGameSessionQueue", []))

    @jsii.member(jsii_name="toCreateLocation")
    def to_create_location(self) -> "Gamelift":
        '''(experimental) Grants permission to define a new location for a fleet.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_CreateLocation.html

        :stability: experimental
        '''
        return typing.cast("Gamelift", jsii.invoke(self, "toCreateLocation", []))

    @jsii.member(jsii_name="toCreateMatchmakingConfiguration")
    def to_create_matchmaking_configuration(self) -> "Gamelift":
        '''(experimental) Grants permission to create a new FlexMatch matchmaker.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_CreateMatchmakingConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Gamelift", jsii.invoke(self, "toCreateMatchmakingConfiguration", []))

    @jsii.member(jsii_name="toCreateMatchmakingRuleSet")
    def to_create_matchmaking_rule_set(self) -> "Gamelift":
        '''(experimental) Grants permission to create a new matchmaking rule set for FlexMatch.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_CreateMatchmakingRuleSet.html

        :stability: experimental
        '''
        return typing.cast("Gamelift", jsii.invoke(self, "toCreateMatchmakingRuleSet", []))

    @jsii.member(jsii_name="toCreatePlayerSession")
    def to_create_player_session(self) -> "Gamelift":
        '''(experimental) Grants permission to reserve an available game session slot for a player.

        Access Level: Write

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_CreatePlayerSession.html

        :stability: experimental
        '''
        return typing.cast("Gamelift", jsii.invoke(self, "toCreatePlayerSession", []))

    @jsii.member(jsii_name="toCreatePlayerSessions")
    def to_create_player_sessions(self) -> "Gamelift":
        '''(experimental) Grants permission to reserve available game session slots for multiple players.

        Access Level: Write

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_CreatePlayerSessions.html

        :stability: experimental
        '''
        return typing.cast("Gamelift", jsii.invoke(self, "toCreatePlayerSessions", []))

    @jsii.member(jsii_name="toCreateScript")
    def to_create_script(self) -> "Gamelift":
        '''(experimental) Grants permission to create a new Realtime Servers script.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_CreateScript.html

        :stability: experimental
        '''
        return typing.cast("Gamelift", jsii.invoke(self, "toCreateScript", []))

    @jsii.member(jsii_name="toCreateVpcPeeringAuthorization")
    def to_create_vpc_peering_authorization(self) -> "Gamelift":
        '''(experimental) Grants permission to allow GameLift to create or delete a peering connection between a GameLift fleet VPC and a VPC on another AWS account.

        Access Level: Write

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_CreateVpcPeeringAuthorization.html

        :stability: experimental
        '''
        return typing.cast("Gamelift", jsii.invoke(self, "toCreateVpcPeeringAuthorization", []))

    @jsii.member(jsii_name="toCreateVpcPeeringConnection")
    def to_create_vpc_peering_connection(self) -> "Gamelift":
        '''(experimental) Grants permission to establish a peering connection between your GameLift fleet VPC and a VPC on another account.

        Access Level: Write

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_CreateVpcPeeringConnection.html

        :stability: experimental
        '''
        return typing.cast("Gamelift", jsii.invoke(self, "toCreateVpcPeeringConnection", []))

    @jsii.member(jsii_name="toDeleteAlias")
    def to_delete_alias(self) -> "Gamelift":
        '''(experimental) Grants permission to delete an alias.

        Access Level: Write

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_DeleteAlias.html

        :stability: experimental
        '''
        return typing.cast("Gamelift", jsii.invoke(self, "toDeleteAlias", []))

    @jsii.member(jsii_name="toDeleteBuild")
    def to_delete_build(self) -> "Gamelift":
        '''(experimental) Grants permission to delete a game build.

        Access Level: Write

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_DeleteBuild.html

        :stability: experimental
        '''
        return typing.cast("Gamelift", jsii.invoke(self, "toDeleteBuild", []))

    @jsii.member(jsii_name="toDeleteFleet")
    def to_delete_fleet(self) -> "Gamelift":
        '''(experimental) Grants permission to delete an empty fleet.

        Access Level: Write

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_DeleteFleet.html

        :stability: experimental
        '''
        return typing.cast("Gamelift", jsii.invoke(self, "toDeleteFleet", []))

    @jsii.member(jsii_name="toDeleteFleetLocations")
    def to_delete_fleet_locations(self) -> "Gamelift":
        '''(experimental) Grants permission to delete locations for a fleet.

        Access Level: Write

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_DeleteFleetLocations.html

        :stability: experimental
        '''
        return typing.cast("Gamelift", jsii.invoke(self, "toDeleteFleetLocations", []))

    @jsii.member(jsii_name="toDeleteGameServerGroup")
    def to_delete_game_server_group(self) -> "Gamelift":
        '''(experimental) Grants permission to permanently delete a game server group and terminate FleetIQ activity for the corresponding Auto Scaling group.

        Access Level: Write

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_DeleteGameServerGroup.html

        :stability: experimental
        '''
        return typing.cast("Gamelift", jsii.invoke(self, "toDeleteGameServerGroup", []))

    @jsii.member(jsii_name="toDeleteGameSessionQueue")
    def to_delete_game_session_queue(self) -> "Gamelift":
        '''(experimental) Grants permission to delete an existing game session queue.

        Access Level: Write

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_DeleteGameSessionQueue.html

        :stability: experimental
        '''
        return typing.cast("Gamelift", jsii.invoke(self, "toDeleteGameSessionQueue", []))

    @jsii.member(jsii_name="toDeleteLocation")
    def to_delete_location(self) -> "Gamelift":
        '''(experimental) Grants permission to delete a location.

        Access Level: Write

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_DeleteLocation.html

        :stability: experimental
        '''
        return typing.cast("Gamelift", jsii.invoke(self, "toDeleteLocation", []))

    @jsii.member(jsii_name="toDeleteMatchmakingConfiguration")
    def to_delete_matchmaking_configuration(self) -> "Gamelift":
        '''(experimental) Grants permission to delete an existing FlexMatch matchmaker.

        Access Level: Write

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_DeleteMatchmakingConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Gamelift", jsii.invoke(self, "toDeleteMatchmakingConfiguration", []))

    @jsii.member(jsii_name="toDeleteMatchmakingRuleSet")
    def to_delete_matchmaking_rule_set(self) -> "Gamelift":
        '''(experimental) Grants permission to delete an existing FlexMatch matchmaking rule set.

        Access Level: Write

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_DeleteMatchmakingRuleSet.html

        :stability: experimental
        '''
        return typing.cast("Gamelift", jsii.invoke(self, "toDeleteMatchmakingRuleSet", []))

    @jsii.member(jsii_name="toDeleteScalingPolicy")
    def to_delete_scaling_policy(self) -> "Gamelift":
        '''(experimental) Grants permission to delete a set of auto-scaling rules.

        Access Level: Write

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_DeleteScalingPolicy.html

        :stability: experimental
        '''
        return typing.cast("Gamelift", jsii.invoke(self, "toDeleteScalingPolicy", []))

    @jsii.member(jsii_name="toDeleteScript")
    def to_delete_script(self) -> "Gamelift":
        '''(experimental) Grants permission to delete a Realtime Servers script.

        Access Level: Write

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_DeleteScript.html

        :stability: experimental
        '''
        return typing.cast("Gamelift", jsii.invoke(self, "toDeleteScript", []))

    @jsii.member(jsii_name="toDeleteVpcPeeringAuthorization")
    def to_delete_vpc_peering_authorization(self) -> "Gamelift":
        '''(experimental) Grants permission to cancel a VPC peering authorization.

        Access Level: Write

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_DeleteVpcPeeringAuthorization.html

        :stability: experimental
        '''
        return typing.cast("Gamelift", jsii.invoke(self, "toDeleteVpcPeeringAuthorization", []))

    @jsii.member(jsii_name="toDeleteVpcPeeringConnection")
    def to_delete_vpc_peering_connection(self) -> "Gamelift":
        '''(experimental) Grants permission to remove a peering connection between VPCs.

        Access Level: Write

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_DeleteVpcPeeringConnection.html

        :stability: experimental
        '''
        return typing.cast("Gamelift", jsii.invoke(self, "toDeleteVpcPeeringConnection", []))

    @jsii.member(jsii_name="toDeregisterCompute")
    def to_deregister_compute(self) -> "Gamelift":
        '''(experimental) Grants permission to deregister a compute against a fleet.

        Access Level: Write

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_DeregisterCompute.html

        :stability: experimental
        '''
        return typing.cast("Gamelift", jsii.invoke(self, "toDeregisterCompute", []))

    @jsii.member(jsii_name="toDeregisterGameServer")
    def to_deregister_game_server(self) -> "Gamelift":
        '''(experimental) Grants permission to remove a game server from a game server group.

        Access Level: Write

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_DeregisterGameServer.html

        :stability: experimental
        '''
        return typing.cast("Gamelift", jsii.invoke(self, "toDeregisterGameServer", []))

    @jsii.member(jsii_name="toDescribeAlias")
    def to_describe_alias(self) -> "Gamelift":
        '''(experimental) Grants permission to retrieve properties for an alias.

        Access Level: Read

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_DescribeAlias.html

        :stability: experimental
        '''
        return typing.cast("Gamelift", jsii.invoke(self, "toDescribeAlias", []))

    @jsii.member(jsii_name="toDescribeBuild")
    def to_describe_build(self) -> "Gamelift":
        '''(experimental) Grants permission to retrieve properties for a game build.

        Access Level: Read

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_DescribeBuild.html

        :stability: experimental
        '''
        return typing.cast("Gamelift", jsii.invoke(self, "toDescribeBuild", []))

    @jsii.member(jsii_name="toDescribeCompute")
    def to_describe_compute(self) -> "Gamelift":
        '''(experimental) Grants permission to retrieve general properties of the compute such as ARN, fleet details, SDK endpoints, and location.

        Access Level: Read

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_DescribeCompute.html

        :stability: experimental
        '''
        return typing.cast("Gamelift", jsii.invoke(self, "toDescribeCompute", []))

    @jsii.member(jsii_name="toDescribeEC2InstanceLimits")
    def to_describe_ec2_instance_limits(self) -> "Gamelift":
        '''(experimental) Grants permission to retrieve the maximum allowed and current usage for EC2 instance types.

        Access Level: Read

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_DescribeEC2InstanceLimits.html

        :stability: experimental
        '''
        return typing.cast("Gamelift", jsii.invoke(self, "toDescribeEC2InstanceLimits", []))

    @jsii.member(jsii_name="toDescribeFleetAttributes")
    def to_describe_fleet_attributes(self) -> "Gamelift":
        '''(experimental) Grants permission to retrieve general properties, including status, for fleets.

        Access Level: Read

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_DescribeFleetAttributes.html

        :stability: experimental
        '''
        return typing.cast("Gamelift", jsii.invoke(self, "toDescribeFleetAttributes", []))

    @jsii.member(jsii_name="toDescribeFleetCapacity")
    def to_describe_fleet_capacity(self) -> "Gamelift":
        '''(experimental) Grants permission to retrieve the current capacity setting for fleets.

        Access Level: Read

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_DescribeFleetCapacity.html

        :stability: experimental
        '''
        return typing.cast("Gamelift", jsii.invoke(self, "toDescribeFleetCapacity", []))

    @jsii.member(jsii_name="toDescribeFleetEvents")
    def to_describe_fleet_events(self) -> "Gamelift":
        '''(experimental) Grants permission to retrieve entries from a fleet's event log.

        Access Level: Read

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_DescribeFleetEvents.html

        :stability: experimental
        '''
        return typing.cast("Gamelift", jsii.invoke(self, "toDescribeFleetEvents", []))

    @jsii.member(jsii_name="toDescribeFleetLocationAttributes")
    def to_describe_fleet_location_attributes(self) -> "Gamelift":
        '''(experimental) Grants permission to retrieve general properties, including statuses, for a fleet's locations.

        Access Level: Read

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_DescribeFleetLocationAttributes.html

        :stability: experimental
        '''
        return typing.cast("Gamelift", jsii.invoke(self, "toDescribeFleetLocationAttributes", []))

    @jsii.member(jsii_name="toDescribeFleetLocationCapacity")
    def to_describe_fleet_location_capacity(self) -> "Gamelift":
        '''(experimental) Grants permission to retrieve the current capacity setting for a fleet's location.

        Access Level: Read

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_DescribeFleetLocationCapacity.html

        :stability: experimental
        '''
        return typing.cast("Gamelift", jsii.invoke(self, "toDescribeFleetLocationCapacity", []))

    @jsii.member(jsii_name="toDescribeFleetLocationUtilization")
    def to_describe_fleet_location_utilization(self) -> "Gamelift":
        '''(experimental) Grants permission to retrieve utilization statistics for fleet's location.

        Access Level: Read

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_DescribeFleetLocationUtilization.html

        :stability: experimental
        '''
        return typing.cast("Gamelift", jsii.invoke(self, "toDescribeFleetLocationUtilization", []))

    @jsii.member(jsii_name="toDescribeFleetPortSettings")
    def to_describe_fleet_port_settings(self) -> "Gamelift":
        '''(experimental) Grants permission to retrieve the inbound connection permissions for a fleet.

        Access Level: Read

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_DescribeFleetPortSettings.html

        :stability: experimental
        '''
        return typing.cast("Gamelift", jsii.invoke(self, "toDescribeFleetPortSettings", []))

    @jsii.member(jsii_name="toDescribeFleetUtilization")
    def to_describe_fleet_utilization(self) -> "Gamelift":
        '''(experimental) Grants permission to retrieve utilization statistics for fleets.

        Access Level: Read

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_DescribeFleetUtilization.html

        :stability: experimental
        '''
        return typing.cast("Gamelift", jsii.invoke(self, "toDescribeFleetUtilization", []))

    @jsii.member(jsii_name="toDescribeGameServer")
    def to_describe_game_server(self) -> "Gamelift":
        '''(experimental) Grants permission to retrieve properties for a game server.

        Access Level: Read

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_DescribeGameServer.html

        :stability: experimental
        '''
        return typing.cast("Gamelift", jsii.invoke(self, "toDescribeGameServer", []))

    @jsii.member(jsii_name="toDescribeGameServerGroup")
    def to_describe_game_server_group(self) -> "Gamelift":
        '''(experimental) Grants permission to retrieve properties for a game server group.

        Access Level: Read

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_DescribeGameServerGroup.html

        :stability: experimental
        '''
        return typing.cast("Gamelift", jsii.invoke(self, "toDescribeGameServerGroup", []))

    @jsii.member(jsii_name="toDescribeGameServerInstances")
    def to_describe_game_server_instances(self) -> "Gamelift":
        '''(experimental) Grants permission to retrieve the status of EC2 instances in a game server group.

        Access Level: Read

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_DescribeGameServerInstances.html

        :stability: experimental
        '''
        return typing.cast("Gamelift", jsii.invoke(self, "toDescribeGameServerInstances", []))

    @jsii.member(jsii_name="toDescribeGameSessionDetails")
    def to_describe_game_session_details(self) -> "Gamelift":
        '''(experimental) Grants permission to retrieve properties for game sessions in a fleet, including the protection policy.

        Access Level: Read

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_DescribeGameSessionDetails.html

        :stability: experimental
        '''
        return typing.cast("Gamelift", jsii.invoke(self, "toDescribeGameSessionDetails", []))

    @jsii.member(jsii_name="toDescribeGameSessionPlacement")
    def to_describe_game_session_placement(self) -> "Gamelift":
        '''(experimental) Grants permission to retrieve details of a game session placement request.

        Access Level: Read

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_DescribeGameSessionPlacement.html

        :stability: experimental
        '''
        return typing.cast("Gamelift", jsii.invoke(self, "toDescribeGameSessionPlacement", []))

    @jsii.member(jsii_name="toDescribeGameSessionQueues")
    def to_describe_game_session_queues(self) -> "Gamelift":
        '''(experimental) Grants permission to retrieve properties for game session queues.

        Access Level: Read

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_DescribeGameSessionQueues.html

        :stability: experimental
        '''
        return typing.cast("Gamelift", jsii.invoke(self, "toDescribeGameSessionQueues", []))

    @jsii.member(jsii_name="toDescribeGameSessions")
    def to_describe_game_sessions(self) -> "Gamelift":
        '''(experimental) Grants permission to retrieve properties for game sessions in a fleet.

        Access Level: Read

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_DescribeGameSessions.html

        :stability: experimental
        '''
        return typing.cast("Gamelift", jsii.invoke(self, "toDescribeGameSessions", []))

    @jsii.member(jsii_name="toDescribeInstances")
    def to_describe_instances(self) -> "Gamelift":
        '''(experimental) Grants permission to retrieve information about instances in a fleet.

        Access Level: Read

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_DescribeInstances.html

        :stability: experimental
        '''
        return typing.cast("Gamelift", jsii.invoke(self, "toDescribeInstances", []))

    @jsii.member(jsii_name="toDescribeMatchmaking")
    def to_describe_matchmaking(self) -> "Gamelift":
        '''(experimental) Grants permission to retrieve details of matchmaking tickets.

        Access Level: Read

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_DescribeMatchmaking.html

        :stability: experimental
        '''
        return typing.cast("Gamelift", jsii.invoke(self, "toDescribeMatchmaking", []))

    @jsii.member(jsii_name="toDescribeMatchmakingConfigurations")
    def to_describe_matchmaking_configurations(self) -> "Gamelift":
        '''(experimental) Grants permission to retrieve properties for FlexMatch matchmakers.

        Access Level: Read

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_DescribeMatchmakingConfigurations.html

        :stability: experimental
        '''
        return typing.cast("Gamelift", jsii.invoke(self, "toDescribeMatchmakingConfigurations", []))

    @jsii.member(jsii_name="toDescribeMatchmakingRuleSets")
    def to_describe_matchmaking_rule_sets(self) -> "Gamelift":
        '''(experimental) Grants permission to retrieve properties for FlexMatch matchmaking rule sets.

        Access Level: Read

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_DescribeMatchmakingRuleSets.html

        :stability: experimental
        '''
        return typing.cast("Gamelift", jsii.invoke(self, "toDescribeMatchmakingRuleSets", []))

    @jsii.member(jsii_name="toDescribePlayerSessions")
    def to_describe_player_sessions(self) -> "Gamelift":
        '''(experimental) Grants permission to retrieve properties for player sessions in a game session.

        Access Level: Read

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_DescribePlayerSessions.html

        :stability: experimental
        '''
        return typing.cast("Gamelift", jsii.invoke(self, "toDescribePlayerSessions", []))

    @jsii.member(jsii_name="toDescribeRuntimeConfiguration")
    def to_describe_runtime_configuration(self) -> "Gamelift":
        '''(experimental) Grants permission to retrieve the current runtime configuration for a fleet.

        Access Level: Read

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_DescribeRuntimeConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Gamelift", jsii.invoke(self, "toDescribeRuntimeConfiguration", []))

    @jsii.member(jsii_name="toDescribeScalingPolicies")
    def to_describe_scaling_policies(self) -> "Gamelift":
        '''(experimental) Grants permission to retrieve all scaling policies that are applied to a fleet.

        Access Level: Read

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_DescribeScalingPolicies.html

        :stability: experimental
        '''
        return typing.cast("Gamelift", jsii.invoke(self, "toDescribeScalingPolicies", []))

    @jsii.member(jsii_name="toDescribeScript")
    def to_describe_script(self) -> "Gamelift":
        '''(experimental) Grants permission to retrieve properties for a Realtime Servers script.

        Access Level: Read

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_DescribeScript.html

        :stability: experimental
        '''
        return typing.cast("Gamelift", jsii.invoke(self, "toDescribeScript", []))

    @jsii.member(jsii_name="toDescribeVpcPeeringAuthorizations")
    def to_describe_vpc_peering_authorizations(self) -> "Gamelift":
        '''(experimental) Grants permission to retrieve valid VPC peering authorizations.

        Access Level: Read

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_DescribeVpcPeeringAuthorizations.html

        :stability: experimental
        '''
        return typing.cast("Gamelift", jsii.invoke(self, "toDescribeVpcPeeringAuthorizations", []))

    @jsii.member(jsii_name="toDescribeVpcPeeringConnections")
    def to_describe_vpc_peering_connections(self) -> "Gamelift":
        '''(experimental) Grants permission to retrieve details on active or pending VPC peering connections.

        Access Level: Read

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_DescribeVpcPeeringConnections.html

        :stability: experimental
        '''
        return typing.cast("Gamelift", jsii.invoke(self, "toDescribeVpcPeeringConnections", []))

    @jsii.member(jsii_name="toGetComputeAccess")
    def to_get_compute_access(self) -> "Gamelift":
        '''(experimental) Grants permission to retrieve access credentials of the compute.

        Access Level: Read

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_GetComputeAccess.html

        :stability: experimental
        '''
        return typing.cast("Gamelift", jsii.invoke(self, "toGetComputeAccess", []))

    @jsii.member(jsii_name="toGetComputeAuthToken")
    def to_get_compute_auth_token(self) -> "Gamelift":
        '''(experimental) Grants permission to retrieve an authorization token for a compute and fleet to use in game server processes.

        Access Level: Read

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_GetComputeAuthToken.html

        :stability: experimental
        '''
        return typing.cast("Gamelift", jsii.invoke(self, "toGetComputeAuthToken", []))

    @jsii.member(jsii_name="toGetGameSessionLogUrl")
    def to_get_game_session_log_url(self) -> "Gamelift":
        '''(experimental) Grants permission to retrieve the location of stored logs for a game session.

        Access Level: Read

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_GetGameSessionLogUrl.html

        :stability: experimental
        '''
        return typing.cast("Gamelift", jsii.invoke(self, "toGetGameSessionLogUrl", []))

    @jsii.member(jsii_name="toGetInstanceAccess")
    def to_get_instance_access(self) -> "Gamelift":
        '''(experimental) Grants permission to request remote access to a specified fleet instance.

        Access Level: Read

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_GetInstanceAccess.html

        :stability: experimental
        '''
        return typing.cast("Gamelift", jsii.invoke(self, "toGetInstanceAccess", []))

    @jsii.member(jsii_name="toListAliases")
    def to_list_aliases(self) -> "Gamelift":
        '''(experimental) Grants permission to retrieve all aliases that are defined in the current Region.

        Access Level: List

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_ListAliases.html

        :stability: experimental
        '''
        return typing.cast("Gamelift", jsii.invoke(self, "toListAliases", []))

    @jsii.member(jsii_name="toListBuilds")
    def to_list_builds(self) -> "Gamelift":
        '''(experimental) Grants permission to retrieve all game build in the current Region.

        Access Level: List

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_ListBuilds.html

        :stability: experimental
        '''
        return typing.cast("Gamelift", jsii.invoke(self, "toListBuilds", []))

    @jsii.member(jsii_name="toListCompute")
    def to_list_compute(self) -> "Gamelift":
        '''(experimental) Grants permission to retrieve all compute resources in the current Region.

        Access Level: List

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_ListCompute.html

        :stability: experimental
        '''
        return typing.cast("Gamelift", jsii.invoke(self, "toListCompute", []))

    @jsii.member(jsii_name="toListFleets")
    def to_list_fleets(self) -> "Gamelift":
        '''(experimental) Grants permission to retrieve a list of fleet IDs for all fleets in the current Region.

        Access Level: List

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_ListFleets.html

        :stability: experimental
        '''
        return typing.cast("Gamelift", jsii.invoke(self, "toListFleets", []))

    @jsii.member(jsii_name="toListGameServerGroups")
    def to_list_game_server_groups(self) -> "Gamelift":
        '''(experimental) Grants permission to retrieve all game server groups that are defined in the current Region.

        Access Level: List

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_ListGameServerGroups.html

        :stability: experimental
        '''
        return typing.cast("Gamelift", jsii.invoke(self, "toListGameServerGroups", []))

    @jsii.member(jsii_name="toListGameServers")
    def to_list_game_servers(self) -> "Gamelift":
        '''(experimental) Grants permission to retrieve all game servers that are currently running in a game server group.

        Access Level: List

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_ListGameServers.html

        :stability: experimental
        '''
        return typing.cast("Gamelift", jsii.invoke(self, "toListGameServers", []))

    @jsii.member(jsii_name="toListLocations")
    def to_list_locations(self) -> "Gamelift":
        '''(experimental) Grants permission to retrieve all locations in this account.

        Access Level: List

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_ListLocations.html

        :stability: experimental
        '''
        return typing.cast("Gamelift", jsii.invoke(self, "toListLocations", []))

    @jsii.member(jsii_name="toListScripts")
    def to_list_scripts(self) -> "Gamelift":
        '''(experimental) Grants permission to retrieve properties for all Realtime Servers scripts in the current region.

        Access Level: List

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_ListScripts.html

        :stability: experimental
        '''
        return typing.cast("Gamelift", jsii.invoke(self, "toListScripts", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Gamelift":
        '''(experimental) Grants permission to retrieve tags for GameLift resources.

        Access Level: Read

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("Gamelift", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toPutScalingPolicy")
    def to_put_scaling_policy(self) -> "Gamelift":
        '''(experimental) Grants permission to create or update a fleet auto-scaling policy.

        Access Level: Write

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_PutScalingPolicy.html

        :stability: experimental
        '''
        return typing.cast("Gamelift", jsii.invoke(self, "toPutScalingPolicy", []))

    @jsii.member(jsii_name="toRegisterCompute")
    def to_register_compute(self) -> "Gamelift":
        '''(experimental) Grants permission to register a compute against a fleet.

        Access Level: Write

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_RegisterCompute.html

        :stability: experimental
        '''
        return typing.cast("Gamelift", jsii.invoke(self, "toRegisterCompute", []))

    @jsii.member(jsii_name="toRegisterGameServer")
    def to_register_game_server(self) -> "Gamelift":
        '''(experimental) Grants permission to notify GameLift FleetIQ when a new game server is ready to host gameplay.

        Access Level: Write

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_RegisterGameServer.html

        :stability: experimental
        '''
        return typing.cast("Gamelift", jsii.invoke(self, "toRegisterGameServer", []))

    @jsii.member(jsii_name="toRequestUploadCredentials")
    def to_request_upload_credentials(self) -> "Gamelift":
        '''(experimental) Grants permission to retrieve fresh upload credentials to use when uploading a new game build.

        Access Level: Read

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_RequestUploadCredentials.html

        :stability: experimental
        '''
        return typing.cast("Gamelift", jsii.invoke(self, "toRequestUploadCredentials", []))

    @jsii.member(jsii_name="toResolveAlias")
    def to_resolve_alias(self) -> "Gamelift":
        '''(experimental) Grants permission to retrieve the fleet ID associated with an alias.

        Access Level: Read

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_ResolveAlias.html

        :stability: experimental
        '''
        return typing.cast("Gamelift", jsii.invoke(self, "toResolveAlias", []))

    @jsii.member(jsii_name="toResumeGameServerGroup")
    def to_resume_game_server_group(self) -> "Gamelift":
        '''(experimental) Grants permission to reinstate suspended FleetIQ activity for a game server group.

        Access Level: Write

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_ResumeGameServerGroup.html

        :stability: experimental
        '''
        return typing.cast("Gamelift", jsii.invoke(self, "toResumeGameServerGroup", []))

    @jsii.member(jsii_name="toSearchGameSessions")
    def to_search_game_sessions(self) -> "Gamelift":
        '''(experimental) Grants permission to retrieve game sessions that match a set of search criteria.

        Access Level: Read

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_SearchGameSessions.html

        :stability: experimental
        '''
        return typing.cast("Gamelift", jsii.invoke(self, "toSearchGameSessions", []))

    @jsii.member(jsii_name="toStartFleetActions")
    def to_start_fleet_actions(self) -> "Gamelift":
        '''(experimental) Grants permission to resume auto-scaling activity on a fleet after it was suspended with StopFleetActions().

        Access Level: Write

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_StartFleetActions.html

        :stability: experimental
        '''
        return typing.cast("Gamelift", jsii.invoke(self, "toStartFleetActions", []))

    @jsii.member(jsii_name="toStartGameSessionPlacement")
    def to_start_game_session_placement(self) -> "Gamelift":
        '''(experimental) Grants permission to send a game session placement request to a game session queue.

        Access Level: Write

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_StartGameSessionPlacement.html

        :stability: experimental
        '''
        return typing.cast("Gamelift", jsii.invoke(self, "toStartGameSessionPlacement", []))

    @jsii.member(jsii_name="toStartMatchBackfill")
    def to_start_match_backfill(self) -> "Gamelift":
        '''(experimental) Grants permission to request FlexMatch matchmaking to fill available player slots in an existing game session.

        Access Level: Write

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_StartMatchBackfill.html

        :stability: experimental
        '''
        return typing.cast("Gamelift", jsii.invoke(self, "toStartMatchBackfill", []))

    @jsii.member(jsii_name="toStartMatchmaking")
    def to_start_matchmaking(self) -> "Gamelift":
        '''(experimental) Grants permission to request FlexMatch matchmaking for one or a group of players and initiate game session placement.

        Access Level: Write

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_StartMatchmaking.html

        :stability: experimental
        '''
        return typing.cast("Gamelift", jsii.invoke(self, "toStartMatchmaking", []))

    @jsii.member(jsii_name="toStopFleetActions")
    def to_stop_fleet_actions(self) -> "Gamelift":
        '''(experimental) Grants permission to suspend auto-scaling activity on a fleet.

        Access Level: Write

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_StopFleetActions.html

        :stability: experimental
        '''
        return typing.cast("Gamelift", jsii.invoke(self, "toStopFleetActions", []))

    @jsii.member(jsii_name="toStopGameSessionPlacement")
    def to_stop_game_session_placement(self) -> "Gamelift":
        '''(experimental) Grants permission to cancel a game session placement request that is in progress.

        Access Level: Write

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_StopGameSessionPlacement.html

        :stability: experimental
        '''
        return typing.cast("Gamelift", jsii.invoke(self, "toStopGameSessionPlacement", []))

    @jsii.member(jsii_name="toStopMatchmaking")
    def to_stop_matchmaking(self) -> "Gamelift":
        '''(experimental) Grants permission to cancel a matchmaking or match backfill request that is in progress.

        Access Level: Write

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_StopMatchmaking.html

        :stability: experimental
        '''
        return typing.cast("Gamelift", jsii.invoke(self, "toStopMatchmaking", []))

    @jsii.member(jsii_name="toSuspendGameServerGroup")
    def to_suspend_game_server_group(self) -> "Gamelift":
        '''(experimental) Grants permission to temporarily stop FleetIQ activity for a game server group.

        Access Level: Write

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_SuspendGameServerGroup.html

        :stability: experimental
        '''
        return typing.cast("Gamelift", jsii.invoke(self, "toSuspendGameServerGroup", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Gamelift":
        '''(experimental) Grants permission to tag GameLift resources.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("Gamelift", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Gamelift":
        '''(experimental) Grants permission to untag GameLift resources.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("Gamelift", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateAlias")
    def to_update_alias(self) -> "Gamelift":
        '''(experimental) Grants permission to update the properties of an existing alias.

        Access Level: Write

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_UpdateAlias.html

        :stability: experimental
        '''
        return typing.cast("Gamelift", jsii.invoke(self, "toUpdateAlias", []))

    @jsii.member(jsii_name="toUpdateBuild")
    def to_update_build(self) -> "Gamelift":
        '''(experimental) Grants permission to update an existing build's metadata.

        Access Level: Write

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_UpdateBuild.html

        :stability: experimental
        '''
        return typing.cast("Gamelift", jsii.invoke(self, "toUpdateBuild", []))

    @jsii.member(jsii_name="toUpdateFleetAttributes")
    def to_update_fleet_attributes(self) -> "Gamelift":
        '''(experimental) Grants permission to update the general properties of an existing fleet.

        Access Level: Write

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_UpdateFleetAttributes.html

        :stability: experimental
        '''
        return typing.cast("Gamelift", jsii.invoke(self, "toUpdateFleetAttributes", []))

    @jsii.member(jsii_name="toUpdateFleetCapacity")
    def to_update_fleet_capacity(self) -> "Gamelift":
        '''(experimental) Grants permission to adjust a fleet's capacity settings.

        Access Level: Write

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_UpdateFleetCapacity.html

        :stability: experimental
        '''
        return typing.cast("Gamelift", jsii.invoke(self, "toUpdateFleetCapacity", []))

    @jsii.member(jsii_name="toUpdateFleetPortSettings")
    def to_update_fleet_port_settings(self) -> "Gamelift":
        '''(experimental) Grants permission to adjust a fleet's port settings.

        Access Level: Write

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_UpdateFleetPortSettings.html

        :stability: experimental
        '''
        return typing.cast("Gamelift", jsii.invoke(self, "toUpdateFleetPortSettings", []))

    @jsii.member(jsii_name="toUpdateGameServer")
    def to_update_game_server(self) -> "Gamelift":
        '''(experimental) Grants permission to change game server properties, health status, or utilization status.

        Access Level: Write

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_UpdateGameServer.html

        :stability: experimental
        '''
        return typing.cast("Gamelift", jsii.invoke(self, "toUpdateGameServer", []))

    @jsii.member(jsii_name="toUpdateGameServerGroup")
    def to_update_game_server_group(self) -> "Gamelift":
        '''(experimental) Grants permission to update properties for game server group, including allowed instance types.

        Access Level: Write

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_UpdateGameServerGroup.html

        :stability: experimental
        '''
        return typing.cast("Gamelift", jsii.invoke(self, "toUpdateGameServerGroup", []))

    @jsii.member(jsii_name="toUpdateGameSession")
    def to_update_game_session(self) -> "Gamelift":
        '''(experimental) Grants permission to update the properties of an existing game session.

        Access Level: Write

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_UpdateGameSession.html

        :stability: experimental
        '''
        return typing.cast("Gamelift", jsii.invoke(self, "toUpdateGameSession", []))

    @jsii.member(jsii_name="toUpdateGameSessionQueue")
    def to_update_game_session_queue(self) -> "Gamelift":
        '''(experimental) Grants permission to update properties of an existing game session queue.

        Access Level: Write

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_UpdateGameSessionQueue.html

        :stability: experimental
        '''
        return typing.cast("Gamelift", jsii.invoke(self, "toUpdateGameSessionQueue", []))

    @jsii.member(jsii_name="toUpdateMatchmakingConfiguration")
    def to_update_matchmaking_configuration(self) -> "Gamelift":
        '''(experimental) Grants permission to update properties of an existing FlexMatch matchmaking configuration.

        Access Level: Write

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_UpdateMatchmakingConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Gamelift", jsii.invoke(self, "toUpdateMatchmakingConfiguration", []))

    @jsii.member(jsii_name="toUpdateRuntimeConfiguration")
    def to_update_runtime_configuration(self) -> "Gamelift":
        '''(experimental) Grants permission to update how server processes are configured on instances in an existing fleet.

        Access Level: Write

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_UpdateRuntimeConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Gamelift", jsii.invoke(self, "toUpdateRuntimeConfiguration", []))

    @jsii.member(jsii_name="toUpdateScript")
    def to_update_script(self) -> "Gamelift":
        '''(experimental) Grants permission to update the metadata and content of an existing Realtime Servers script.

        Access Level: Write

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_UpdateScript.html

        :stability: experimental
        '''
        return typing.cast("Gamelift", jsii.invoke(self, "toUpdateScript", []))

    @jsii.member(jsii_name="toValidateMatchmakingRuleSet")
    def to_validate_matchmaking_rule_set(self) -> "Gamelift":
        '''(experimental) Grants permission to validate the syntax of a FlexMatch matchmaking rule set.

        Access Level: Read

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_ValidateMatchmakingRuleSet.html

        :stability: experimental
        '''
        return typing.cast("Gamelift", jsii.invoke(self, "toValidateMatchmakingRuleSet", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5954a84fddcc1ce275befc7671759e4822b5a2d35919e65bd1ef698b0a04ec80)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__02b2c258dd58a2e05b2dd5d54d8c7cae4cf64b90f31327e797583f852ddc4f1a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Gamesparks(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Gamesparks",
):
    '''(experimental) Statement provider for service `gamesparks <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazongamesparks.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `gamesparks <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazongamesparks.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onGame")
    def on_game(
        self,
        game_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Gamesparks":
        '''(experimental) Adds a resource of type game to the statement.

        https://docs.aws.amazon.com/gamesparks/latest/dg/security-iam-service.html#policy-resources

        :param game_id: - Identifier for the gameId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bd40cfe76be966a0372ad1b86778ea19822fcc1415cbc70f6ca00fcaa9d9675a)
            check_type(argname="argument game_id", value=game_id, expected_type=type_hints["game_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Gamesparks", jsii.invoke(self, "onGame", [game_id, account, region, partition]))

    @jsii.member(jsii_name="onStage")
    def on_stage(
        self,
        game_id: builtins.str,
        stage_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Gamesparks":
        '''(experimental) Adds a resource of type stage to the statement.

        https://docs.aws.amazon.com/gamesparks/latest/dg/security-iam-service.html#policy-resources

        :param game_id: - Identifier for the gameId.
        :param stage_name: - Identifier for the stageName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d2b68af1ee6c587bc8fbd4e46f249e279ffa810f642082fff735206f51161211)
            check_type(argname="argument game_id", value=game_id, expected_type=type_hints["game_id"])
            check_type(argname="argument stage_name", value=stage_name, expected_type=type_hints["stage_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Gamesparks", jsii.invoke(self, "onStage", [game_id, stage_name, account, region, partition]))

    @jsii.member(jsii_name="toCreateGame")
    def to_create_game(self) -> "Gamesparks":
        '''(experimental) Grants permission to create a game.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/gamesparks/latest/api/svc/API_CreateGame.html

        :stability: experimental
        '''
        return typing.cast("Gamesparks", jsii.invoke(self, "toCreateGame", []))

    @jsii.member(jsii_name="toCreateSnapshot")
    def to_create_snapshot(self) -> "Gamesparks":
        '''(experimental) Grants permission to create a snapshot of a game.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/gamesparks/latest/api/svc/API_CreateSnapshot.html

        :stability: experimental
        '''
        return typing.cast("Gamesparks", jsii.invoke(self, "toCreateSnapshot", []))

    @jsii.member(jsii_name="toCreateStage")
    def to_create_stage(self) -> "Gamesparks":
        '''(experimental) Grants permission to create a stage in a game.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/gamesparks/latest/api/svc/API_CreateStage.html

        :stability: experimental
        '''
        return typing.cast("Gamesparks", jsii.invoke(self, "toCreateStage", []))

    @jsii.member(jsii_name="toDeleteGame")
    def to_delete_game(self) -> "Gamesparks":
        '''(experimental) Grants permission to delete a game.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/gamesparks/latest/api/svc/API_DeleteGame.html

        :stability: experimental
        '''
        return typing.cast("Gamesparks", jsii.invoke(self, "toDeleteGame", []))

    @jsii.member(jsii_name="toDeleteStage")
    def to_delete_stage(self) -> "Gamesparks":
        '''(experimental) Grants permission to delete a stage from a game.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/gamesparks/latest/api/svc/API_DeleteStage.html

        :stability: experimental
        '''
        return typing.cast("Gamesparks", jsii.invoke(self, "toDeleteStage", []))

    @jsii.member(jsii_name="toDisconnectPlayer")
    def to_disconnect_player(self) -> "Gamesparks":
        '''(experimental) Grants permission to disconnect a player from the game runtime.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/gamesparks/latest/api/svc/API_DisconnectPlayer.html

        :stability: experimental
        '''
        return typing.cast("Gamesparks", jsii.invoke(self, "toDisconnectPlayer", []))

    @jsii.member(jsii_name="toExportSnapshot")
    def to_export_snapshot(self) -> "Gamesparks":
        '''(experimental) Grants permission to export a snapshot of the game configuration.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/gamesparks/latest/api/svc/API_ExportSnapshot.html

        :stability: experimental
        '''
        return typing.cast("Gamesparks", jsii.invoke(self, "toExportSnapshot", []))

    @jsii.member(jsii_name="toGetExtension")
    def to_get_extension(self) -> "Gamesparks":
        '''(experimental) Grants permission to get details about an extension.

        Access Level: Read

        Possible conditions:

        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/gamesparks/latest/api/svc/API_GetExtension.html

        :stability: experimental
        '''
        return typing.cast("Gamesparks", jsii.invoke(self, "toGetExtension", []))

    @jsii.member(jsii_name="toGetExtensionVersion")
    def to_get_extension_version(self) -> "Gamesparks":
        '''(experimental) Grants permission to get details about an extension version.

        Access Level: Read

        Possible conditions:

        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/gamesparks/latest/api/svc/API_GetExtensionVersion.html

        :stability: experimental
        '''
        return typing.cast("Gamesparks", jsii.invoke(self, "toGetExtensionVersion", []))

    @jsii.member(jsii_name="toGetGame")
    def to_get_game(self) -> "Gamesparks":
        '''(experimental) Grants permission to get details about a game.

        Access Level: Read

        Possible conditions:

        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/gamesparks/latest/api/svc/API_GetGame.html

        :stability: experimental
        '''
        return typing.cast("Gamesparks", jsii.invoke(self, "toGetGame", []))

    @jsii.member(jsii_name="toGetGameConfiguration")
    def to_get_game_configuration(self) -> "Gamesparks":
        '''(experimental) Grants permission to get the configuration for the game.

        Access Level: Read

        Possible conditions:

        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/gamesparks/latest/api/svc/API_GetGameConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Gamesparks", jsii.invoke(self, "toGetGameConfiguration", []))

    @jsii.member(jsii_name="toGetGeneratedCodeJob")
    def to_get_generated_code_job(self) -> "Gamesparks":
        '''(experimental) Grants permission to get details about a job that is generating code for a snapshot.

        Access Level: Read

        Possible conditions:

        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/gamesparks/latest/api/svc/API_GetGeneratedCodeJob.html

        :stability: experimental
        '''
        return typing.cast("Gamesparks", jsii.invoke(self, "toGetGeneratedCodeJob", []))

    @jsii.member(jsii_name="toGetPlayerConnectionStatus")
    def to_get_player_connection_status(self) -> "Gamesparks":
        '''(experimental) Grants permission to get the status of a player connection.

        Access Level: Read

        Possible conditions:

        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/gamesparks/latest/api/svc/API_GetPlayerConnectionStatus.html

        :stability: experimental
        '''
        return typing.cast("Gamesparks", jsii.invoke(self, "toGetPlayerConnectionStatus", []))

    @jsii.member(jsii_name="toGetSnapshot")
    def to_get_snapshot(self) -> "Gamesparks":
        '''(experimental) Grants permission to get a snapshot of the game.

        Access Level: Read

        Possible conditions:

        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/gamesparks/latest/api/svc/API_GetSnapshot.html

        :stability: experimental
        '''
        return typing.cast("Gamesparks", jsii.invoke(self, "toGetSnapshot", []))

    @jsii.member(jsii_name="toGetStage")
    def to_get_stage(self) -> "Gamesparks":
        '''(experimental) Grants permission to gets information about a stage.

        Access Level: Read

        Possible conditions:

        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/gamesparks/latest/api/svc/API_GetStage.html

        :stability: experimental
        '''
        return typing.cast("Gamesparks", jsii.invoke(self, "toGetStage", []))

    @jsii.member(jsii_name="toGetStageDeployment")
    def to_get_stage_deployment(self) -> "Gamesparks":
        '''(experimental) Grants permission to get information about a stage deployment.

        Access Level: Read

        Possible conditions:

        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/gamesparks/latest/api/svc/API_GetStageDeployment.html

        :stability: experimental
        '''
        return typing.cast("Gamesparks", jsii.invoke(self, "toGetStageDeployment", []))

    @jsii.member(jsii_name="toImportGameConfiguration")
    def to_import_game_configuration(self) -> "Gamesparks":
        '''(experimental) Grants permission to import a snapshot of a game configuration.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/gamesparks/latest/api/svc/API_ImportGameConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Gamesparks", jsii.invoke(self, "toImportGameConfiguration", []))

    @jsii.member(jsii_name="toInvokeBackend")
    def to_invoke_backend(self) -> "Gamesparks":
        '''(experimental) Grants permission to invoke backend services for a specific game.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/gamesparks/latest/dg/security-iam-stage-roles.html

        :stability: experimental
        '''
        return typing.cast("Gamesparks", jsii.invoke(self, "toInvokeBackend", []))

    @jsii.member(jsii_name="toListExtensions")
    def to_list_extensions(self) -> "Gamesparks":
        '''(experimental) Grants permission to list the extensions.

        Access Level: List

        https://docs.aws.amazon.com/gamesparks/latest/api/svc/API_ListExtensions.html

        :stability: experimental
        '''
        return typing.cast("Gamesparks", jsii.invoke(self, "toListExtensions", []))

    @jsii.member(jsii_name="toListExtensionVersions")
    def to_list_extension_versions(self) -> "Gamesparks":
        '''(experimental) Grants permission to list the extension versions.

        Access Level: List

        https://docs.aws.amazon.com/gamesparks/latest/api/svc/API_ListExtensionVersions.html

        :stability: experimental
        '''
        return typing.cast("Gamesparks", jsii.invoke(self, "toListExtensionVersions", []))

    @jsii.member(jsii_name="toListGames")
    def to_list_games(self) -> "Gamesparks":
        '''(experimental) Grants permission to list the games.

        Access Level: List

        https://docs.aws.amazon.com/gamesparks/latest/api/svc/API_ListGames.html

        :stability: experimental
        '''
        return typing.cast("Gamesparks", jsii.invoke(self, "toListGames", []))

    @jsii.member(jsii_name="toListGeneratedCodeJobs")
    def to_list_generated_code_jobs(self) -> "Gamesparks":
        '''(experimental) Grants permission to get a list of code generation jobs for a snapshot.

        Access Level: List

        Possible conditions:

        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/gamesparks/latest/api/svc/API_ListGeneratedCodeJobs.html

        :stability: experimental
        '''
        return typing.cast("Gamesparks", jsii.invoke(self, "toListGeneratedCodeJobs", []))

    @jsii.member(jsii_name="toListSnapshots")
    def to_list_snapshots(self) -> "Gamesparks":
        '''(experimental) Grants permission to get a list of snapshot summaries for a game.

        Access Level: List

        Possible conditions:

        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/gamesparks/latest/api/svc/API_ListSnapshots.html

        :stability: experimental
        '''
        return typing.cast("Gamesparks", jsii.invoke(self, "toListSnapshots", []))

    @jsii.member(jsii_name="toListStageDeployments")
    def to_list_stage_deployments(self) -> "Gamesparks":
        '''(experimental) Grants permission to get a list of stage deployment summaries for a game.

        Access Level: List

        Possible conditions:

        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/gamesparks/latest/api/svc/API_ListStageDeployments.html

        :stability: experimental
        '''
        return typing.cast("Gamesparks", jsii.invoke(self, "toListStageDeployments", []))

    @jsii.member(jsii_name="toListStages")
    def to_list_stages(self) -> "Gamesparks":
        '''(experimental) Grants permission to get a list of stage summaries for a game.

        Access Level: List

        Possible conditions:

        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/gamesparks/latest/api/svc/API_ListStages.html

        :stability: experimental
        '''
        return typing.cast("Gamesparks", jsii.invoke(self, "toListStages", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Gamesparks":
        '''(experimental) Grants permission to list the tags associated with a resource.

        Access Level: Read

        https://docs.aws.amazon.com/gamesparks/latest/api/svc/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("Gamesparks", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toStartGeneratedCodeJob")
    def to_start_generated_code_job(self) -> "Gamesparks":
        '''(experimental) Grants permission to start an asynchronous process that generates client code for system-defined and custom messages.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/gamesparks/latest/api/svc/API_StartGeneratedCodeJob.html

        :stability: experimental
        '''
        return typing.cast("Gamesparks", jsii.invoke(self, "toStartGeneratedCodeJob", []))

    @jsii.member(jsii_name="toStartStageDeployment")
    def to_start_stage_deployment(self) -> "Gamesparks":
        '''(experimental) Grants permission to deploy a snapshot to a stage and creates a new game runtime.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/gamesparks/latest/api/svc/API_StartStageDeployment.html

        :stability: experimental
        '''
        return typing.cast("Gamesparks", jsii.invoke(self, "toStartStageDeployment", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Gamesparks":
        '''(experimental) Grants permission to adds tags to a resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/gamesparks/latest/api/svc/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("Gamesparks", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Gamesparks":
        '''(experimental) Grants permission to remove tags from a resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/gamesparks/latest/api/svc/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("Gamesparks", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateGame")
    def to_update_game(self) -> "Gamesparks":
        '''(experimental) Grants permission to change the metadata of a game.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/gamesparks/latest/api/svc/API_UpdateGame.html

        :stability: experimental
        '''
        return typing.cast("Gamesparks", jsii.invoke(self, "toUpdateGame", []))

    @jsii.member(jsii_name="toUpdateGameConfiguration")
    def to_update_game_configuration(self) -> "Gamesparks":
        '''(experimental) Grants permission to change the working copy of the game configuration.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/gamesparks/latest/api/svc/API_UpdateGameConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Gamesparks", jsii.invoke(self, "toUpdateGameConfiguration", []))

    @jsii.member(jsii_name="toUpdateSnapshot")
    def to_update_snapshot(self) -> "Gamesparks":
        '''(experimental) Grants permission to update the metadata of a snapshot.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/gamesparks/latest/api/svc/API_UpdateSnapshot.html

        :stability: experimental
        '''
        return typing.cast("Gamesparks", jsii.invoke(self, "toUpdateSnapshot", []))

    @jsii.member(jsii_name="toUpdateStage")
    def to_update_stage(self) -> "Gamesparks":
        '''(experimental) Grants permission to update the metadata of a stage.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/gamesparks/latest/api/svc/API_UpdateStage.html

        :stability: experimental
        '''
        return typing.cast("Gamesparks", jsii.invoke(self, "toUpdateStage", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d06f94bbdb50f8de7d699b880282cfb14c49f16690d8438e77f677e2cdf7b839)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__483afefb5c8ba5d0b6c62df2b9c06071194af2cec3061fd40d6e2af4013a5d8a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Geo(PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Geo"):
    '''(experimental) Statement provider for service `geo <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonlocation.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `geo <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonlocation.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="ifDeviceIds")
    def if_device_ids(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Geo":
        '''(experimental) Filters access by the presence of device ids in the request.

        https://docs.aws.amazon.com/location/latest/developerguide/security_iam_service-with-iam.html#security_iam_service-with-iam-id-based-policies-conditionkeys

        Applies to actions:

        - .toBatchDeleteDevicePositionHistory()
        - .toBatchGetDevicePosition()
        - .toBatchUpdateDevicePosition()
        - .toGetDevicePosition()
        - .toGetDevicePositionHistory()

        Applies to resource types:

        - tracker

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__18ed1ba5a64bb55fb38342552a512bda4dd9dfc4c4d1c230c895dac11fe61e44)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Geo", jsii.invoke(self, "ifDeviceIds", [value, operator]))

    @jsii.member(jsii_name="ifGeofenceIds")
    def if_geofence_ids(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Geo":
        '''(experimental) Filters access by the presence of geofence ids in the request.

        https://docs.aws.amazon.com/location/latest/developerguide/security_iam_service-with-iam.html#security_iam_service-with-iam-id-based-policies-conditionkeys

        Applies to actions:

        - .toBatchDeleteGeofence()
        - .toBatchPutGeofence()
        - .toGetGeofence()
        - .toPutGeofence()

        Applies to resource types:

        - geofence-collection

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d8b2a3b114ee920a1c8543dfa66a9200efcd63249d712fa8e048614e52ddbae4)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Geo", jsii.invoke(self, "ifGeofenceIds", [value, operator]))

    @jsii.member(jsii_name="onGeofenceCollection")
    def on_geofence_collection(
        self,
        geofence_collection_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Geo":
        '''(experimental) Adds a resource of type geofence-collection to the statement.

        https://docs.aws.amazon.com/location/latest/developerguide/geofence-tracker-concepts.html

        :param geofence_collection_name: - Identifier for the geofenceCollectionName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag() - .ifGeofenceIds()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__842009f3ffd0b6d7e6394efb820446b14ad96687888610ef133a3a2a8239385a)
            check_type(argname="argument geofence_collection_name", value=geofence_collection_name, expected_type=type_hints["geofence_collection_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Geo", jsii.invoke(self, "onGeofenceCollection", [geofence_collection_name, account, region, partition]))

    @jsii.member(jsii_name="onMap")
    def on_map(
        self,
        map_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Geo":
        '''(experimental) Adds a resource of type map to the statement.

        https://docs.aws.amazon.com/location/latest/developerguide/map-concepts.html

        :param map_name: - Identifier for the mapName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d0f598af99d8718689539244d09a90d5c4914a26f921016ab6a025432035db95)
            check_type(argname="argument map_name", value=map_name, expected_type=type_hints["map_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Geo", jsii.invoke(self, "onMap", [map_name, account, region, partition]))

    @jsii.member(jsii_name="onPlaceIndex")
    def on_place_index(
        self,
        index_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Geo":
        '''(experimental) Adds a resource of type place-index to the statement.

        https://docs.aws.amazon.com/location/latest/developerguide/places-concepts.html

        :param index_name: - Identifier for the indexName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6a1ed38a5b86aefad86b55f1f8dd1c28c9ef927c760bfc0d077cbfba15075b1c)
            check_type(argname="argument index_name", value=index_name, expected_type=type_hints["index_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Geo", jsii.invoke(self, "onPlaceIndex", [index_name, account, region, partition]))

    @jsii.member(jsii_name="onRouteCalculator")
    def on_route_calculator(
        self,
        calculator_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Geo":
        '''(experimental) Adds a resource of type route-calculator to the statement.

        https://docs.aws.amazon.com/location/latest/developerguide/route-concepts.html

        :param calculator_name: - Identifier for the calculatorName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d8231577db4f55e9d6a58b02af3f34af66e60581bfd34a4c6b67caecfc2f4f97)
            check_type(argname="argument calculator_name", value=calculator_name, expected_type=type_hints["calculator_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Geo", jsii.invoke(self, "onRouteCalculator", [calculator_name, account, region, partition]))

    @jsii.member(jsii_name="onTracker")
    def on_tracker(
        self,
        tracker_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Geo":
        '''(experimental) Adds a resource of type tracker to the statement.

        https://docs.aws.amazon.com/location/latest/developerguide/geofence-tracker-concepts.html

        :param tracker_name: - Identifier for the trackerName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag() - .ifDeviceIds()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bd84384248f51bddb6241bf1e3ee9cf9ca09f727c396166a315ee6e65a3eb126)
            check_type(argname="argument tracker_name", value=tracker_name, expected_type=type_hints["tracker_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Geo", jsii.invoke(self, "onTracker", [tracker_name, account, region, partition]))

    @jsii.member(jsii_name="toAssociateTrackerConsumer")
    def to_associate_tracker_consumer(self) -> "Geo":
        '''(experimental) Grants permission to create an association between a geofence-collection and a tracker resource.

        Access Level: Write

        https://docs.aws.amazon.com/location/latest/APIReference/API_AssociateTrackerConsumer.html

        :stability: experimental
        '''
        return typing.cast("Geo", jsii.invoke(self, "toAssociateTrackerConsumer", []))

    @jsii.member(jsii_name="toBatchDeleteDevicePositionHistory")
    def to_batch_delete_device_position_history(self) -> "Geo":
        '''(experimental) Grants permission to delete a batch of device position histories from a tracker resource.

        Access Level: Write

        Possible conditions:

        - .ifDeviceIds()

        https://docs.aws.amazon.com/location/latest/APIReference/API_BatchDeleteDevicePositionHistory.html

        :stability: experimental
        '''
        return typing.cast("Geo", jsii.invoke(self, "toBatchDeleteDevicePositionHistory", []))

    @jsii.member(jsii_name="toBatchDeleteGeofence")
    def to_batch_delete_geofence(self) -> "Geo":
        '''(experimental) Grants permission to delete a batch of geofences from a geofence collection.

        Access Level: Write

        Possible conditions:

        - .ifGeofenceIds()

        https://docs.aws.amazon.com/location/latest/APIReference/API_BatchDeleteGeofence.html

        :stability: experimental
        '''
        return typing.cast("Geo", jsii.invoke(self, "toBatchDeleteGeofence", []))

    @jsii.member(jsii_name="toBatchEvaluateGeofences")
    def to_batch_evaluate_geofences(self) -> "Geo":
        '''(experimental) Grants permission to evaluate device positions against the position of geofences in a given geofence collection.

        Access Level: Write

        https://docs.aws.amazon.com/location/latest/APIReference/API_BatchEvaluateGeofences.html

        :stability: experimental
        '''
        return typing.cast("Geo", jsii.invoke(self, "toBatchEvaluateGeofences", []))

    @jsii.member(jsii_name="toBatchGetDevicePosition")
    def to_batch_get_device_position(self) -> "Geo":
        '''(experimental) Grants permission to send a batch request to retrieve device positions.

        Access Level: Read

        Possible conditions:

        - .ifDeviceIds()

        https://docs.aws.amazon.com/location/latest/APIReference/API_BatchGetDevicePosition.html

        :stability: experimental
        '''
        return typing.cast("Geo", jsii.invoke(self, "toBatchGetDevicePosition", []))

    @jsii.member(jsii_name="toBatchPutGeofence")
    def to_batch_put_geofence(self) -> "Geo":
        '''(experimental) Grants permission to send a batch request for adding geofences into a given geofence collection.

        Access Level: Write

        Possible conditions:

        - .ifGeofenceIds()

        https://docs.aws.amazon.com/location/latest/APIReference/API_BatchPutGeofence.html

        :stability: experimental
        '''
        return typing.cast("Geo", jsii.invoke(self, "toBatchPutGeofence", []))

    @jsii.member(jsii_name="toBatchUpdateDevicePosition")
    def to_batch_update_device_position(self) -> "Geo":
        '''(experimental) Grants permission to upload a position update for one or more devices to a tracker resource.

        Access Level: Write

        Possible conditions:

        - .ifDeviceIds()

        https://docs.aws.amazon.com/location/latest/APIReference/API_BatchUpdateDevicePosition.html

        :stability: experimental
        '''
        return typing.cast("Geo", jsii.invoke(self, "toBatchUpdateDevicePosition", []))

    @jsii.member(jsii_name="toCalculateRoute")
    def to_calculate_route(self) -> "Geo":
        '''(experimental) Grants permission to calculate routes using a given route calculator resource.

        Access Level: Read

        https://docs.aws.amazon.com/location/latest/APIReference/API_CalculateRoute.html

        :stability: experimental
        '''
        return typing.cast("Geo", jsii.invoke(self, "toCalculateRoute", []))

    @jsii.member(jsii_name="toCalculateRouteMatrix")
    def to_calculate_route_matrix(self) -> "Geo":
        '''(experimental) Grants permission to calculate a route matrix using a given route calculator resource.

        Access Level: Read

        https://docs.aws.amazon.com/location/latest/APIReference/API_CalculateRouteMatrix.html

        :stability: experimental
        '''
        return typing.cast("Geo", jsii.invoke(self, "toCalculateRouteMatrix", []))

    @jsii.member(jsii_name="toCreateGeofenceCollection")
    def to_create_geofence_collection(self) -> "Geo":
        '''(experimental) Grants permission to create a geofence-collection.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/location/latest/APIReference/API_CreateGeofenceCollection.html

        :stability: experimental
        '''
        return typing.cast("Geo", jsii.invoke(self, "toCreateGeofenceCollection", []))

    @jsii.member(jsii_name="toCreateMap")
    def to_create_map(self) -> "Geo":
        '''(experimental) Grants permission to create a map resource.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/location/latest/APIReference/API_CreateMap.html

        :stability: experimental
        '''
        return typing.cast("Geo", jsii.invoke(self, "toCreateMap", []))

    @jsii.member(jsii_name="toCreatePlaceIndex")
    def to_create_place_index(self) -> "Geo":
        '''(experimental) Grants permission to create a place index resource.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/location/latest/APIReference/API_CreatePlaceIndex.html

        :stability: experimental
        '''
        return typing.cast("Geo", jsii.invoke(self, "toCreatePlaceIndex", []))

    @jsii.member(jsii_name="toCreateRouteCalculator")
    def to_create_route_calculator(self) -> "Geo":
        '''(experimental) Grants permission to create a route calculator resource.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/location/latest/APIReference/API_CreateRouteCalculator.html

        :stability: experimental
        '''
        return typing.cast("Geo", jsii.invoke(self, "toCreateRouteCalculator", []))

    @jsii.member(jsii_name="toCreateTracker")
    def to_create_tracker(self) -> "Geo":
        '''(experimental) Grants permission to create a tracker resource.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/location/latest/APIReference/API_CreateTracker.html

        :stability: experimental
        '''
        return typing.cast("Geo", jsii.invoke(self, "toCreateTracker", []))

    @jsii.member(jsii_name="toDeleteGeofenceCollection")
    def to_delete_geofence_collection(self) -> "Geo":
        '''(experimental) Grants permission to delete a geofence-collection.

        Access Level: Write

        https://docs.aws.amazon.com/location/latest/APIReference/API_DeleteGeofenceCollection.html

        :stability: experimental
        '''
        return typing.cast("Geo", jsii.invoke(self, "toDeleteGeofenceCollection", []))

    @jsii.member(jsii_name="toDeleteMap")
    def to_delete_map(self) -> "Geo":
        '''(experimental) Grants permission to delete a map resource.

        Access Level: Write

        https://docs.aws.amazon.com/location/latest/APIReference/API_DeleteMap.html

        :stability: experimental
        '''
        return typing.cast("Geo", jsii.invoke(self, "toDeleteMap", []))

    @jsii.member(jsii_name="toDeletePlaceIndex")
    def to_delete_place_index(self) -> "Geo":
        '''(experimental) Grants permission to delete a place index resource.

        Access Level: Write

        https://docs.aws.amazon.com/location/latest/APIReference/API_DeletePlaceIndex.html

        :stability: experimental
        '''
        return typing.cast("Geo", jsii.invoke(self, "toDeletePlaceIndex", []))

    @jsii.member(jsii_name="toDeleteRouteCalculator")
    def to_delete_route_calculator(self) -> "Geo":
        '''(experimental) Grants permission to delete a route calculator resource.

        Access Level: Write

        https://docs.aws.amazon.com/location/latest/APIReference/API_DeleteRouteCalculator.html

        :stability: experimental
        '''
        return typing.cast("Geo", jsii.invoke(self, "toDeleteRouteCalculator", []))

    @jsii.member(jsii_name="toDeleteTracker")
    def to_delete_tracker(self) -> "Geo":
        '''(experimental) Grants permission to delete a tracker resource.

        Access Level: Write

        https://docs.aws.amazon.com/location/latest/APIReference/API_DeleteTracker.html

        :stability: experimental
        '''
        return typing.cast("Geo", jsii.invoke(self, "toDeleteTracker", []))

    @jsii.member(jsii_name="toDescribeGeofenceCollection")
    def to_describe_geofence_collection(self) -> "Geo":
        '''(experimental) Grants permission to retrieve geofence collection details.

        Access Level: Read

        https://docs.aws.amazon.com/location/latest/APIReference/API_DescribeGeofenceCollection.html

        :stability: experimental
        '''
        return typing.cast("Geo", jsii.invoke(self, "toDescribeGeofenceCollection", []))

    @jsii.member(jsii_name="toDescribeMap")
    def to_describe_map(self) -> "Geo":
        '''(experimental) Grants permission to retrieve map resource details.

        Access Level: Read

        https://docs.aws.amazon.com/location/latest/APIReference/API_DescribeMap.html

        :stability: experimental
        '''
        return typing.cast("Geo", jsii.invoke(self, "toDescribeMap", []))

    @jsii.member(jsii_name="toDescribePlaceIndex")
    def to_describe_place_index(self) -> "Geo":
        '''(experimental) Grants permission to retrieve place-index resource details.

        Access Level: Read

        https://docs.aws.amazon.com/location/latest/APIReference/API_DescribePlaceIndex.html

        :stability: experimental
        '''
        return typing.cast("Geo", jsii.invoke(self, "toDescribePlaceIndex", []))

    @jsii.member(jsii_name="toDescribeRouteCalculator")
    def to_describe_route_calculator(self) -> "Geo":
        '''(experimental) Grants permission to retrieve route calculator resource details.

        Access Level: Read

        https://docs.aws.amazon.com/location/latest/APIReference/API_DescribeRouteCalculator.html

        :stability: experimental
        '''
        return typing.cast("Geo", jsii.invoke(self, "toDescribeRouteCalculator", []))

    @jsii.member(jsii_name="toDescribeTracker")
    def to_describe_tracker(self) -> "Geo":
        '''(experimental) Grants permission to retrieve a tracker resource details.

        Access Level: Read

        https://docs.aws.amazon.com/location/latest/APIReference/API_DescribeTracker.html

        :stability: experimental
        '''
        return typing.cast("Geo", jsii.invoke(self, "toDescribeTracker", []))

    @jsii.member(jsii_name="toDisassociateTrackerConsumer")
    def to_disassociate_tracker_consumer(self) -> "Geo":
        '''(experimental) Grants permission to remove the association between a tracker resource and a geofence-collection.

        Access Level: Write

        https://docs.aws.amazon.com/location/latest/APIReference/API_DisassociateTrackerConsumer.html

        :stability: experimental
        '''
        return typing.cast("Geo", jsii.invoke(self, "toDisassociateTrackerConsumer", []))

    @jsii.member(jsii_name="toGetDevicePosition")
    def to_get_device_position(self) -> "Geo":
        '''(experimental) Grants permission to retrieve the latest device position.

        Access Level: Read

        Possible conditions:

        - .ifDeviceIds()

        https://docs.aws.amazon.com/location/latest/APIReference/API_GetDevicePosition.html

        :stability: experimental
        '''
        return typing.cast("Geo", jsii.invoke(self, "toGetDevicePosition", []))

    @jsii.member(jsii_name="toGetDevicePositionHistory")
    def to_get_device_position_history(self) -> "Geo":
        '''(experimental) Grants permission to retrieve the device position history.

        Access Level: Read

        Possible conditions:

        - .ifDeviceIds()

        https://docs.aws.amazon.com/location/latest/APIReference/API_GetDevicePositionHistory.html

        :stability: experimental
        '''
        return typing.cast("Geo", jsii.invoke(self, "toGetDevicePositionHistory", []))

    @jsii.member(jsii_name="toGetGeofence")
    def to_get_geofence(self) -> "Geo":
        '''(experimental) Grants permission to retrieve the geofence details from a geofence-collection.

        Access Level: Read

        Possible conditions:

        - .ifGeofenceIds()

        https://docs.aws.amazon.com/location/latest/APIReference/API_GetGeofence.html

        :stability: experimental
        '''
        return typing.cast("Geo", jsii.invoke(self, "toGetGeofence", []))

    @jsii.member(jsii_name="toGetMapGlyphs")
    def to_get_map_glyphs(self) -> "Geo":
        '''(experimental) Grants permission to retrieve the glyph file for a map resource.

        Access Level: Read

        https://docs.aws.amazon.com/location/latest/APIReference/API_GetMapGlyphs.html

        :stability: experimental
        '''
        return typing.cast("Geo", jsii.invoke(self, "toGetMapGlyphs", []))

    @jsii.member(jsii_name="toGetMapSprites")
    def to_get_map_sprites(self) -> "Geo":
        '''(experimental) Grants permission to retrieve the sprite file for a map resource.

        Access Level: Read

        https://docs.aws.amazon.com/location/latest/APIReference/API_GetMapSprites.html

        :stability: experimental
        '''
        return typing.cast("Geo", jsii.invoke(self, "toGetMapSprites", []))

    @jsii.member(jsii_name="toGetMapStyleDescriptor")
    def to_get_map_style_descriptor(self) -> "Geo":
        '''(experimental) Grants permission to retrieve the map style descriptor from a map resource.

        Access Level: Read

        https://docs.aws.amazon.com/location/latest/APIReference/API_GetMapStyleDescriptor.html

        :stability: experimental
        '''
        return typing.cast("Geo", jsii.invoke(self, "toGetMapStyleDescriptor", []))

    @jsii.member(jsii_name="toGetMapTile")
    def to_get_map_tile(self) -> "Geo":
        '''(experimental) Grants permission to retrieve the map tile from the map resource.

        Access Level: Read

        https://docs.aws.amazon.com/location/latest/APIReference/API_GetMapTile.html

        :stability: experimental
        '''
        return typing.cast("Geo", jsii.invoke(self, "toGetMapTile", []))

    @jsii.member(jsii_name="toGetPlace")
    def to_get_place(self) -> "Geo":
        '''(experimental) Grants permission to find a place by its unique ID.

        Access Level: Read

        https://docs.aws.amazon.com/location/latest/APIReference/API_GetPlace.html

        :stability: experimental
        '''
        return typing.cast("Geo", jsii.invoke(self, "toGetPlace", []))

    @jsii.member(jsii_name="toListDevicePositions")
    def to_list_device_positions(self) -> "Geo":
        '''(experimental) Grants permission to retrieve a list of devices and their latest positions from the given tracker resource.

        Access Level: Read

        https://docs.aws.amazon.com/location/latest/APIReference/API_ListDevicePositions.html

        :stability: experimental
        '''
        return typing.cast("Geo", jsii.invoke(self, "toListDevicePositions", []))

    @jsii.member(jsii_name="toListGeofenceCollections")
    def to_list_geofence_collections(self) -> "Geo":
        '''(experimental) Grants permission to lists geofence-collections.

        Access Level: List

        https://docs.aws.amazon.com/location/latest/APIReference/API_ListGeofenceCollections.html

        :stability: experimental
        '''
        return typing.cast("Geo", jsii.invoke(self, "toListGeofenceCollections", []))

    @jsii.member(jsii_name="toListGeofences")
    def to_list_geofences(self) -> "Geo":
        '''(experimental) Grants permission to list geofences stored in a given geofence collection.

        Access Level: Read

        https://docs.aws.amazon.com/location/latest/APIReference/API_ListGeofences.html

        :stability: experimental
        '''
        return typing.cast("Geo", jsii.invoke(self, "toListGeofences", []))

    @jsii.member(jsii_name="toListMaps")
    def to_list_maps(self) -> "Geo":
        '''(experimental) Grants permission to list map resources.

        Access Level: List

        https://docs.aws.amazon.com/location/latest/APIReference/API_ListMaps.html

        :stability: experimental
        '''
        return typing.cast("Geo", jsii.invoke(self, "toListMaps", []))

    @jsii.member(jsii_name="toListPlaceIndexes")
    def to_list_place_indexes(self) -> "Geo":
        '''(experimental) Grants permission to return a list of place index resources.

        Access Level: List

        https://docs.aws.amazon.com/location/latest/APIReference/API_ListPlaceIndexes.html

        :stability: experimental
        '''
        return typing.cast("Geo", jsii.invoke(self, "toListPlaceIndexes", []))

    @jsii.member(jsii_name="toListRouteCalculators")
    def to_list_route_calculators(self) -> "Geo":
        '''(experimental) Grants permission to return a list of route calculator resources.

        Access Level: List

        https://docs.aws.amazon.com/location/latest/APIReference/API_ListRouteCalculators.html

        :stability: experimental
        '''
        return typing.cast("Geo", jsii.invoke(self, "toListRouteCalculators", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Geo":
        '''(experimental) Grants permission to list the tags (metadata) which you have assigned to the resource.

        Access Level: Read

        https://docs.aws.amazon.com/location/latest/APIReference/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("Geo", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toListTrackerConsumers")
    def to_list_tracker_consumers(self) -> "Geo":
        '''(experimental) Grants permission to retrieve a list of geofence collections currently associated to the given tracker resource.

        Access Level: Read

        https://docs.aws.amazon.com/location/latest/APIReference/API_ListTrackerConsumers.html

        :stability: experimental
        '''
        return typing.cast("Geo", jsii.invoke(self, "toListTrackerConsumers", []))

    @jsii.member(jsii_name="toListTrackers")
    def to_list_trackers(self) -> "Geo":
        '''(experimental) Grants permission to return a list of tracker resources.

        Access Level: List

        https://docs.aws.amazon.com/location/latest/APIReference/API_ListTrackers.html

        :stability: experimental
        '''
        return typing.cast("Geo", jsii.invoke(self, "toListTrackers", []))

    @jsii.member(jsii_name="toPutGeofence")
    def to_put_geofence(self) -> "Geo":
        '''(experimental) Grants permission to add a new geofence or update an existing geofence to a given geofence-collection.

        Access Level: Write

        Possible conditions:

        - .ifGeofenceIds()

        https://docs.aws.amazon.com/location/latest/APIReference/API_PutGeofence.html

        :stability: experimental
        '''
        return typing.cast("Geo", jsii.invoke(self, "toPutGeofence", []))

    @jsii.member(jsii_name="toSearchPlaceIndexForPosition")
    def to_search_place_index_for_position(self) -> "Geo":
        '''(experimental) Grants permission to reverse geocodes a given coordinate.

        Access Level: Read

        https://docs.aws.amazon.com/location/latest/APIReference/API_SearchPlaceIndexForPosition.html

        :stability: experimental
        '''
        return typing.cast("Geo", jsii.invoke(self, "toSearchPlaceIndexForPosition", []))

    @jsii.member(jsii_name="toSearchPlaceIndexForSuggestions")
    def to_search_place_index_for_suggestions(self) -> "Geo":
        '''(experimental) Grants permission to generate suggestions for addresses and points of interest based on partial or misspelled free-form text.

        Access Level: Read

        https://docs.aws.amazon.com/location/latest/APIReference/API_SearchPlaceIndexForSuggestions.html

        :stability: experimental
        '''
        return typing.cast("Geo", jsii.invoke(self, "toSearchPlaceIndexForSuggestions", []))

    @jsii.member(jsii_name="toSearchPlaceIndexForText")
    def to_search_place_index_for_text(self) -> "Geo":
        '''(experimental) Grants permission to geocode free-form text, such as an address, name, city or region.

        Access Level: Read

        https://docs.aws.amazon.com/location/latest/APIReference/API_SearchPlaceIndexForText.html

        :stability: experimental
        '''
        return typing.cast("Geo", jsii.invoke(self, "toSearchPlaceIndexForText", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Geo":
        '''(experimental) Grants permission to adds to or modifies the tags of the given resource.

        Tags are metadata which can be used to manage a resource

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/location/latest/APIReference/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("Geo", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Geo":
        '''(experimental) Grants permission to remove the given tags (metadata) from the resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/location/latest/APIReference/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("Geo", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateGeofenceCollection")
    def to_update_geofence_collection(self) -> "Geo":
        '''(experimental) Grants permission to update a geofence collection.

        Access Level: Write

        https://docs.aws.amazon.com/location/latest/APIReference/API_UpdateGeofenceCollection.html

        :stability: experimental
        '''
        return typing.cast("Geo", jsii.invoke(self, "toUpdateGeofenceCollection", []))

    @jsii.member(jsii_name="toUpdateMap")
    def to_update_map(self) -> "Geo":
        '''(experimental) Grants permission to update a map resource.

        Access Level: Write

        https://docs.aws.amazon.com/location/latest/APIReference/API_UpdateMap.html

        :stability: experimental
        '''
        return typing.cast("Geo", jsii.invoke(self, "toUpdateMap", []))

    @jsii.member(jsii_name="toUpdatePlaceIndex")
    def to_update_place_index(self) -> "Geo":
        '''(experimental) Grants permission to update a place index resource.

        Access Level: Write

        https://docs.aws.amazon.com/location/latest/APIReference/API_UpdatePlaceIndex.html

        :stability: experimental
        '''
        return typing.cast("Geo", jsii.invoke(self, "toUpdatePlaceIndex", []))

    @jsii.member(jsii_name="toUpdateRouteCalculator")
    def to_update_route_calculator(self) -> "Geo":
        '''(experimental) Grants permission to update a route calculator resource.

        Access Level: Write

        https://docs.aws.amazon.com/location/latest/APIReference/API_UpdateRouteCalculator.html

        :stability: experimental
        '''
        return typing.cast("Geo", jsii.invoke(self, "toUpdateRouteCalculator", []))

    @jsii.member(jsii_name="toUpdateTracker")
    def to_update_tracker(self) -> "Geo":
        '''(experimental) Grants permission to update a tracker resource.

        Access Level: Write

        https://docs.aws.amazon.com/location/latest/APIReference/API_UpdateTracker.html

        :stability: experimental
        '''
        return typing.cast("Geo", jsii.invoke(self, "toUpdateTracker", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__69547006d5b1e40fe709003c1a443c87a478f77d1a661901376f50aa6b2f995b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__830c0bca08316c01cf5971bb2c16496d0d9776d302365231b0adf70d51e28fbf)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Glacier(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Glacier",
):
    '''(experimental) Statement provider for service `glacier <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazons3glacier.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `glacier <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazons3glacier.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="ifArchiveAgeInDays")
    def if_archive_age_in_days(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Glacier":
        '''(experimental) Filters access by how long an archive has been stored in the vault, in days.

        https://docs.aws.amazon.com/amazonglacier/latest/dev/access-control-overview.html#specifying-conditions

        Applies to actions:

        - .toDeleteArchive()
        - .toInitiateJob()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b1bfa95f6dcc1c055ff72de74b6ac90be1ec02bf6219d1beffc2eac588d40724)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Glacier", jsii.invoke(self, "ifArchiveAgeInDays", [value, operator]))

    @jsii.member(jsii_name="ifResourceTagExists")
    def if_resource_tag_exists(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Glacier":
        '''(experimental) Filters access by a customer-defined tag.

        https://docs.aws.amazon.com/amazonglacier/latest/dev/access-control-overview.html#specifying-conditions

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__02de830d2c7b45d5f0522953684e09224bb9ec92ee39b225c30acfbd4238ebf4)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Glacier", jsii.invoke(self, "ifResourceTagExists", [value, operator]))

    @jsii.member(jsii_name="onVault")
    def on_vault(
        self,
        vault_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Glacier":
        '''(experimental) Adds a resource of type vault to the statement.

        https://docs.aws.amazon.com/amazonglacier/latest/dev/working-with-vaults.html

        :param vault_name: - Identifier for the vaultName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__81e38eda4ea46404cfdb0b770eabfd5c7572c8e6607b54da264f3646f323a1a5)
            check_type(argname="argument vault_name", value=vault_name, expected_type=type_hints["vault_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Glacier", jsii.invoke(self, "onVault", [vault_name, account, region, partition]))

    @jsii.member(jsii_name="toAbortMultipartUpload")
    def to_abort_multipart_upload(self) -> "Glacier":
        '''(experimental) Grants permission to abort a multipart upload identified by the upload ID.

        Access Level: Write

        https://docs.aws.amazon.com/amazonglacier/latest/dev/api-multipart-abort-upload.html

        :stability: experimental
        '''
        return typing.cast("Glacier", jsii.invoke(self, "toAbortMultipartUpload", []))

    @jsii.member(jsii_name="toAbortVaultLock")
    def to_abort_vault_lock(self) -> "Glacier":
        '''(experimental) Grants permission to abort the vault locking process if the vault lock is not in the Locked state.

        Access Level: Permissions management

        https://docs.aws.amazon.com/amazonglacier/latest/dev/api-AbortVaultLock.html

        :stability: experimental
        '''
        return typing.cast("Glacier", jsii.invoke(self, "toAbortVaultLock", []))

    @jsii.member(jsii_name="toAddTagsToVault")
    def to_add_tags_to_vault(self) -> "Glacier":
        '''(experimental) Grants permission to add the specified tags to a vault.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/amazonglacier/latest/dev/api-AddTagsToVault.html

        :stability: experimental
        '''
        return typing.cast("Glacier", jsii.invoke(self, "toAddTagsToVault", []))

    @jsii.member(jsii_name="toCompleteMultipartUpload")
    def to_complete_multipart_upload(self) -> "Glacier":
        '''(experimental) Grants permission to complete a multipart upload process.

        Access Level: Write

        https://docs.aws.amazon.com/amazonglacier/latest/dev/api-multipart-complete-upload.html

        :stability: experimental
        '''
        return typing.cast("Glacier", jsii.invoke(self, "toCompleteMultipartUpload", []))

    @jsii.member(jsii_name="toCompleteVaultLock")
    def to_complete_vault_lock(self) -> "Glacier":
        '''(experimental) Grants permission to complete the vault locking process.

        Access Level: Permissions management

        https://docs.aws.amazon.com/amazonglacier/latest/dev/api-CompleteVaultLock.html

        :stability: experimental
        '''
        return typing.cast("Glacier", jsii.invoke(self, "toCompleteVaultLock", []))

    @jsii.member(jsii_name="toCreateVault")
    def to_create_vault(self) -> "Glacier":
        '''(experimental) Grants permission to create a new vault with the specified name.

        Access Level: Write

        https://docs.aws.amazon.com/amazonglacier/latest/dev/api-vault-put.html

        :stability: experimental
        '''
        return typing.cast("Glacier", jsii.invoke(self, "toCreateVault", []))

    @jsii.member(jsii_name="toDeleteArchive")
    def to_delete_archive(self) -> "Glacier":
        '''(experimental) Grants permission to delete an archive from a vault.

        Access Level: Write

        Possible conditions:

        - .ifArchiveAgeInDays()

        https://docs.aws.amazon.com/amazonglacier/latest/dev/api-archive-delete.html

        :stability: experimental
        '''
        return typing.cast("Glacier", jsii.invoke(self, "toDeleteArchive", []))

    @jsii.member(jsii_name="toDeleteVault")
    def to_delete_vault(self) -> "Glacier":
        '''(experimental) Grants permission to delete a vault.

        Access Level: Write

        https://docs.aws.amazon.com/amazonglacier/latest/dev/api-vault-delete.html

        :stability: experimental
        '''
        return typing.cast("Glacier", jsii.invoke(self, "toDeleteVault", []))

    @jsii.member(jsii_name="toDeleteVaultAccessPolicy")
    def to_delete_vault_access_policy(self) -> "Glacier":
        '''(experimental) Grants permission to delete the access policy associated with the specified vault.

        Access Level: Permissions management

        https://docs.aws.amazon.com/amazonglacier/latest/dev/api-DeleteVaultAccessPolicy.html

        :stability: experimental
        '''
        return typing.cast("Glacier", jsii.invoke(self, "toDeleteVaultAccessPolicy", []))

    @jsii.member(jsii_name="toDeleteVaultNotifications")
    def to_delete_vault_notifications(self) -> "Glacier":
        '''(experimental) Grants permission to delete the notification configuration set for a vault.

        Access Level: Write

        https://docs.aws.amazon.com/amazonglacier/latest/dev/api-vault-notifications-delete.html

        :stability: experimental
        '''
        return typing.cast("Glacier", jsii.invoke(self, "toDeleteVaultNotifications", []))

    @jsii.member(jsii_name="toDescribeJob")
    def to_describe_job(self) -> "Glacier":
        '''(experimental) Grants permission to get information about a job previously initiated.

        Access Level: Read

        https://docs.aws.amazon.com/amazonglacier/latest/dev/api-describe-job-get.html

        :stability: experimental
        '''
        return typing.cast("Glacier", jsii.invoke(self, "toDescribeJob", []))

    @jsii.member(jsii_name="toDescribeVault")
    def to_describe_vault(self) -> "Glacier":
        '''(experimental) Grants permission to get information about a vault.

        Access Level: Read

        https://docs.aws.amazon.com/amazonglacier/latest/dev/api-vault-get.html

        :stability: experimental
        '''
        return typing.cast("Glacier", jsii.invoke(self, "toDescribeVault", []))

    @jsii.member(jsii_name="toGetDataRetrievalPolicy")
    def to_get_data_retrieval_policy(self) -> "Glacier":
        '''(experimental) Grants permission to get the data retrieval policy.

        Access Level: Read

        https://docs.aws.amazon.com/amazonglacier/latest/dev/api-GetDataRetrievalPolicy.html

        :stability: experimental
        '''
        return typing.cast("Glacier", jsii.invoke(self, "toGetDataRetrievalPolicy", []))

    @jsii.member(jsii_name="toGetJobOutput")
    def to_get_job_output(self) -> "Glacier":
        '''(experimental) Grants permission to download the output of the job specified.

        Access Level: Read

        https://docs.aws.amazon.com/amazonglacier/latest/dev/api-job-output-get.html

        :stability: experimental
        '''
        return typing.cast("Glacier", jsii.invoke(self, "toGetJobOutput", []))

    @jsii.member(jsii_name="toGetVaultAccessPolicy")
    def to_get_vault_access_policy(self) -> "Glacier":
        '''(experimental) Grants permission to retrieve the access-policy subresource set on the vault.

        Access Level: Read

        https://docs.aws.amazon.com/amazonglacier/latest/dev/api-GetVaultAccessPolicy.html

        :stability: experimental
        '''
        return typing.cast("Glacier", jsii.invoke(self, "toGetVaultAccessPolicy", []))

    @jsii.member(jsii_name="toGetVaultLock")
    def to_get_vault_lock(self) -> "Glacier":
        '''(experimental) Grants permission to retrieve attributes from the lock-policy subresource set on the specified vault.

        Access Level: Read

        https://docs.aws.amazon.com/amazonglacier/latest/dev/api-GetVaultLock.html

        :stability: experimental
        '''
        return typing.cast("Glacier", jsii.invoke(self, "toGetVaultLock", []))

    @jsii.member(jsii_name="toGetVaultNotifications")
    def to_get_vault_notifications(self) -> "Glacier":
        '''(experimental) Grants permission to retrieve the notification-configuration subresource set on the vault.

        Access Level: Read

        https://docs.aws.amazon.com/amazonglacier/latest/dev/api-vault-notifications-get.html

        :stability: experimental
        '''
        return typing.cast("Glacier", jsii.invoke(self, "toGetVaultNotifications", []))

    @jsii.member(jsii_name="toInitiateJob")
    def to_initiate_job(self) -> "Glacier":
        '''(experimental) Grants permission to initiate a job of the specified type.

        Access Level: Write

        Possible conditions:

        - .ifArchiveAgeInDays()

        https://docs.aws.amazon.com/amazonglacier/latest/dev/api-initiate-job-post.html

        :stability: experimental
        '''
        return typing.cast("Glacier", jsii.invoke(self, "toInitiateJob", []))

    @jsii.member(jsii_name="toInitiateMultipartUpload")
    def to_initiate_multipart_upload(self) -> "Glacier":
        '''(experimental) Grants permission to initiate a multipart upload.

        Access Level: Write

        https://docs.aws.amazon.com/amazonglacier/latest/dev/api-multipart-initiate-upload.html

        :stability: experimental
        '''
        return typing.cast("Glacier", jsii.invoke(self, "toInitiateMultipartUpload", []))

    @jsii.member(jsii_name="toInitiateVaultLock")
    def to_initiate_vault_lock(self) -> "Glacier":
        '''(experimental) Grants permission to initiate the vault locking process.

        Access Level: Permissions management

        https://docs.aws.amazon.com/amazonglacier/latest/dev/api-InitiateVaultLock.html

        :stability: experimental
        '''
        return typing.cast("Glacier", jsii.invoke(self, "toInitiateVaultLock", []))

    @jsii.member(jsii_name="toListJobs")
    def to_list_jobs(self) -> "Glacier":
        '''(experimental) Grants permission to list jobs for a vault that are in-progress and jobs that have recently finished.

        Access Level: List

        https://docs.aws.amazon.com/amazonglacier/latest/dev/api-jobs-get.html

        :stability: experimental
        '''
        return typing.cast("Glacier", jsii.invoke(self, "toListJobs", []))

    @jsii.member(jsii_name="toListMultipartUploads")
    def to_list_multipart_uploads(self) -> "Glacier":
        '''(experimental) Grants permission to list in-progress multipart uploads for the specified vault.

        Access Level: List

        https://docs.aws.amazon.com/amazonglacier/latest/dev/api-multipart-list-uploads.html

        :stability: experimental
        '''
        return typing.cast("Glacier", jsii.invoke(self, "toListMultipartUploads", []))

    @jsii.member(jsii_name="toListParts")
    def to_list_parts(self) -> "Glacier":
        '''(experimental) Grants permission to list the parts of an archive that have been uploaded in a specific multipart upload.

        Access Level: List

        https://docs.aws.amazon.com/amazonglacier/latest/dev/api-multipart-list-parts.html

        :stability: experimental
        '''
        return typing.cast("Glacier", jsii.invoke(self, "toListParts", []))

    @jsii.member(jsii_name="toListProvisionedCapacity")
    def to_list_provisioned_capacity(self) -> "Glacier":
        '''(experimental) Grants permission to list the provisioned capacity for the specified AWS account.

        Access Level: List

        https://docs.aws.amazon.com/amazonglacier/latest/dev/api-ListProvisionedCapacity.html

        :stability: experimental
        '''
        return typing.cast("Glacier", jsii.invoke(self, "toListProvisionedCapacity", []))

    @jsii.member(jsii_name="toListTagsForVault")
    def to_list_tags_for_vault(self) -> "Glacier":
        '''(experimental) Grants permission to list all the tags attached to a vault.

        Access Level: List

        https://docs.aws.amazon.com/amazonglacier/latest/dev/api-ListTagsForVault.html

        :stability: experimental
        '''
        return typing.cast("Glacier", jsii.invoke(self, "toListTagsForVault", []))

    @jsii.member(jsii_name="toListVaults")
    def to_list_vaults(self) -> "Glacier":
        '''(experimental) Grants permission to list all vaults.

        Access Level: List

        https://docs.aws.amazon.com/amazonglacier/latest/dev/api-vaults-get.html

        :stability: experimental
        '''
        return typing.cast("Glacier", jsii.invoke(self, "toListVaults", []))

    @jsii.member(jsii_name="toPurchaseProvisionedCapacity")
    def to_purchase_provisioned_capacity(self) -> "Glacier":
        '''(experimental) Grants permission to purchases a provisioned capacity unit for an AWS account.

        Access Level: Write

        https://docs.aws.amazon.com/amazonglacier/latest/dev/api-PurchaseProvisionedCapacity.html

        :stability: experimental
        '''
        return typing.cast("Glacier", jsii.invoke(self, "toPurchaseProvisionedCapacity", []))

    @jsii.member(jsii_name="toRemoveTagsFromVault")
    def to_remove_tags_from_vault(self) -> "Glacier":
        '''(experimental) Grants permission to remove one or more tags from the set of tags attached to a vault.

        Access Level: Tagging

        https://docs.aws.amazon.com/amazonglacier/latest/dev/api-RemoveTagsFromVault.html

        :stability: experimental
        '''
        return typing.cast("Glacier", jsii.invoke(self, "toRemoveTagsFromVault", []))

    @jsii.member(jsii_name="toSetDataRetrievalPolicy")
    def to_set_data_retrieval_policy(self) -> "Glacier":
        '''(experimental) Grants permission to set and then enacts a data retrieval policy in the region specified in the PUT request.

        Access Level: Permissions management

        https://docs.aws.amazon.com/amazonglacier/latest/dev/api-SetDataRetrievalPolicy.html

        :stability: experimental
        '''
        return typing.cast("Glacier", jsii.invoke(self, "toSetDataRetrievalPolicy", []))

    @jsii.member(jsii_name="toSetVaultAccessPolicy")
    def to_set_vault_access_policy(self) -> "Glacier":
        '''(experimental) Grants permission to configure an access policy for a vault; will overwrite an existing policy.

        Access Level: Permissions management

        https://docs.aws.amazon.com/amazonglacier/latest/dev/api-SetVaultAccessPolicy.html

        :stability: experimental
        '''
        return typing.cast("Glacier", jsii.invoke(self, "toSetVaultAccessPolicy", []))

    @jsii.member(jsii_name="toSetVaultNotifications")
    def to_set_vault_notifications(self) -> "Glacier":
        '''(experimental) Grants permission to configure vault notifications.

        Access Level: Write

        https://docs.aws.amazon.com/amazonglacier/latest/dev/api-vault-notifications-put.html

        :stability: experimental
        '''
        return typing.cast("Glacier", jsii.invoke(self, "toSetVaultNotifications", []))

    @jsii.member(jsii_name="toUploadArchive")
    def to_upload_archive(self) -> "Glacier":
        '''(experimental) Grants permission to upload an archive to a vault.

        Access Level: Write

        https://docs.aws.amazon.com/amazonglacier/latest/dev/api-archive-post.html

        :stability: experimental
        '''
        return typing.cast("Glacier", jsii.invoke(self, "toUploadArchive", []))

    @jsii.member(jsii_name="toUploadMultipartPart")
    def to_upload_multipart_part(self) -> "Glacier":
        '''(experimental) Grants permission to upload a part of an archive.

        Access Level: Write

        https://docs.aws.amazon.com/amazonglacier/latest/dev/api-upload-part.html

        :stability: experimental
        '''
        return typing.cast("Glacier", jsii.invoke(self, "toUploadMultipartPart", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__af74120182f63df7206f8ef537537e946323248cc4334a9d0ff12d0cbfa3d2a6)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__33521ce4206ae4319ac61b5bf79caf18b8984c661fc4fbb3f2e99bc64a7cc76b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Globalaccelerator(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Globalaccelerator",
):
    '''(experimental) Statement provider for service `globalaccelerator <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsglobalaccelerator.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `globalaccelerator <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsglobalaccelerator.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onAccelerator")
    def on_accelerator(
        self,
        accelerator_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Globalaccelerator":
        '''(experimental) Adds a resource of type accelerator to the statement.

        https://docs.aws.amazon.com/global-accelerator/latest/api/API_Accelerator.html

        :param accelerator_id: - Identifier for the acceleratorId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7ca45d712d4dae11fc81207aec4002a50034d32a7e9fd20a573f026dd1f172db)
            check_type(argname="argument accelerator_id", value=accelerator_id, expected_type=type_hints["accelerator_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Globalaccelerator", jsii.invoke(self, "onAccelerator", [accelerator_id, account, partition]))

    @jsii.member(jsii_name="onEndpointgroup")
    def on_endpointgroup(
        self,
        accelerator_id: builtins.str,
        listener_id: builtins.str,
        endpoint_group_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Globalaccelerator":
        '''(experimental) Adds a resource of type endpointgroup to the statement.

        https://docs.aws.amazon.com/global-accelerator/latest/api/API_EndpointGroup.html

        :param accelerator_id: - Identifier for the acceleratorId.
        :param listener_id: - Identifier for the listenerId.
        :param endpoint_group_id: - Identifier for the endpointGroupId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3844e9017be6242275489541a6b625f253c8720f516d11b7af39d140188e459c)
            check_type(argname="argument accelerator_id", value=accelerator_id, expected_type=type_hints["accelerator_id"])
            check_type(argname="argument listener_id", value=listener_id, expected_type=type_hints["listener_id"])
            check_type(argname="argument endpoint_group_id", value=endpoint_group_id, expected_type=type_hints["endpoint_group_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Globalaccelerator", jsii.invoke(self, "onEndpointgroup", [accelerator_id, listener_id, endpoint_group_id, account, partition]))

    @jsii.member(jsii_name="onListener")
    def on_listener(
        self,
        accelerator_id: builtins.str,
        listener_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Globalaccelerator":
        '''(experimental) Adds a resource of type listener to the statement.

        https://docs.aws.amazon.com/global-accelerator/latest/api/API_Listener.html

        :param accelerator_id: - Identifier for the acceleratorId.
        :param listener_id: - Identifier for the listenerId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5245bff08951426b1b7a61fb7358da784b977b18b703ac69353a585e2ed5710a)
            check_type(argname="argument accelerator_id", value=accelerator_id, expected_type=type_hints["accelerator_id"])
            check_type(argname="argument listener_id", value=listener_id, expected_type=type_hints["listener_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Globalaccelerator", jsii.invoke(self, "onListener", [accelerator_id, listener_id, account, partition]))

    @jsii.member(jsii_name="toAddCustomRoutingEndpoints")
    def to_add_custom_routing_endpoints(self) -> "Globalaccelerator":
        '''(experimental) Grants permission to add a virtual private cloud (VPC) subnet endpoint to a custom routing accelerator endpoint group.

        Access Level: Write

        https://docs.aws.amazon.com/global-accelerator/latest/api/API_AddCustomRoutingEndpoints.html

        :stability: experimental
        '''
        return typing.cast("Globalaccelerator", jsii.invoke(self, "toAddCustomRoutingEndpoints", []))

    @jsii.member(jsii_name="toAddEndpoints")
    def to_add_endpoints(self) -> "Globalaccelerator":
        '''(experimental) Grants permission to add an endpoint to a standard accelerator endpoint group.

        Access Level: Write

        https://docs.aws.amazon.com/global-accelerator/latest/api/API_AddEndpoints.html

        :stability: experimental
        '''
        return typing.cast("Globalaccelerator", jsii.invoke(self, "toAddEndpoints", []))

    @jsii.member(jsii_name="toAdvertiseByoipCidr")
    def to_advertise_byoip_cidr(self) -> "Globalaccelerator":
        '''(experimental) Grants permission to advertises an IPv4 address range that is provisioned for use with your accelerator through bring your own IP addresses (BYOIP).

        Access Level: Write

        https://docs.aws.amazon.com/global-accelerator/latest/api/API_AdvertiseByoipCidr.html

        :stability: experimental
        '''
        return typing.cast("Globalaccelerator", jsii.invoke(self, "toAdvertiseByoipCidr", []))

    @jsii.member(jsii_name="toAllowCustomRoutingTraffic")
    def to_allow_custom_routing_traffic(self) -> "Globalaccelerator":
        '''(experimental) Grants permission to allows custom routing of user traffic to a private destination IP:PORT in a specific VPC subnet.

        Access Level: Write

        https://docs.aws.amazon.com/global-accelerator/latest/api/API_AllowCustomRoutingTraffic.html

        :stability: experimental
        '''
        return typing.cast("Globalaccelerator", jsii.invoke(self, "toAllowCustomRoutingTraffic", []))

    @jsii.member(jsii_name="toCreateAccelerator")
    def to_create_accelerator(self) -> "Globalaccelerator":
        '''(experimental) Grants permission to create a standard accelerator.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/global-accelerator/latest/api/API_CreateAccelerator.html

        :stability: experimental
        '''
        return typing.cast("Globalaccelerator", jsii.invoke(self, "toCreateAccelerator", []))

    @jsii.member(jsii_name="toCreateCustomRoutingAccelerator")
    def to_create_custom_routing_accelerator(self) -> "Globalaccelerator":
        '''(experimental) Grants permission to create a Custom Routing accelerator.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/global-accelerator/latest/api/API_CreateCustomRoutingAccelerator.html

        :stability: experimental
        '''
        return typing.cast("Globalaccelerator", jsii.invoke(self, "toCreateCustomRoutingAccelerator", []))

    @jsii.member(jsii_name="toCreateCustomRoutingEndpointGroup")
    def to_create_custom_routing_endpoint_group(self) -> "Globalaccelerator":
        '''(experimental) Grants permission to create an endpoint group for the specified listener for a custom routing accelerator.

        Access Level: Write

        https://docs.aws.amazon.com/global-accelerator/latest/api/API_CreateCustomRoutingEndpointGroup.html

        :stability: experimental
        '''
        return typing.cast("Globalaccelerator", jsii.invoke(self, "toCreateCustomRoutingEndpointGroup", []))

    @jsii.member(jsii_name="toCreateCustomRoutingListener")
    def to_create_custom_routing_listener(self) -> "Globalaccelerator":
        '''(experimental) Grants permission to create a listener to process inbound connections from clients to a custom routing accelerator.

        Access Level: Write

        https://docs.aws.amazon.com/global-accelerator/latest/api/API_CreateCustomRoutingListener.html

        :stability: experimental
        '''
        return typing.cast("Globalaccelerator", jsii.invoke(self, "toCreateCustomRoutingListener", []))

    @jsii.member(jsii_name="toCreateEndpointGroup")
    def to_create_endpoint_group(self) -> "Globalaccelerator":
        '''(experimental) Grants permission to add an endpoint group to a standard accelerator listener.

        Access Level: Write

        https://docs.aws.amazon.com/global-accelerator/latest/api/API_CreateEndpointGroup.html

        :stability: experimental
        '''
        return typing.cast("Globalaccelerator", jsii.invoke(self, "toCreateEndpointGroup", []))

    @jsii.member(jsii_name="toCreateListener")
    def to_create_listener(self) -> "Globalaccelerator":
        '''(experimental) Grants permission to add a listener to a standard accelerator.

        Access Level: Write

        https://docs.aws.amazon.com/global-accelerator/latest/api/API_CreateListener.html

        :stability: experimental
        '''
        return typing.cast("Globalaccelerator", jsii.invoke(self, "toCreateListener", []))

    @jsii.member(jsii_name="toDeleteAccelerator")
    def to_delete_accelerator(self) -> "Globalaccelerator":
        '''(experimental) Grants permission to delete a standard accelerator.

        Access Level: Write

        https://docs.aws.amazon.com/global-accelerator/latest/api/API_DeleteAccelerator.html

        :stability: experimental
        '''
        return typing.cast("Globalaccelerator", jsii.invoke(self, "toDeleteAccelerator", []))

    @jsii.member(jsii_name="toDeleteCustomRoutingAccelerator")
    def to_delete_custom_routing_accelerator(self) -> "Globalaccelerator":
        '''(experimental) Grants permission to delete a custom routing accelerator.

        Access Level: Write

        https://docs.aws.amazon.com/global-accelerator/latest/api/API_DeleteCustomRoutingAccelerator.html

        :stability: experimental
        '''
        return typing.cast("Globalaccelerator", jsii.invoke(self, "toDeleteCustomRoutingAccelerator", []))

    @jsii.member(jsii_name="toDeleteCustomRoutingEndpointGroup")
    def to_delete_custom_routing_endpoint_group(self) -> "Globalaccelerator":
        '''(experimental) Grants permission to delete an endpoint group from a listener for a custom routing accelerator.

        Access Level: Write

        https://docs.aws.amazon.com/global-accelerator/latest/api/API_DeleteCustomRoutingEndpointGroup.html

        :stability: experimental
        '''
        return typing.cast("Globalaccelerator", jsii.invoke(self, "toDeleteCustomRoutingEndpointGroup", []))

    @jsii.member(jsii_name="toDeleteCustomRoutingListener")
    def to_delete_custom_routing_listener(self) -> "Globalaccelerator":
        '''(experimental) Grants permission to delete a listener for a custom routing accelerator.

        Access Level: Write

        https://docs.aws.amazon.com/global-accelerator/latest/api/API_DeleteCustomRoutingListener.html

        :stability: experimental
        '''
        return typing.cast("Globalaccelerator", jsii.invoke(self, "toDeleteCustomRoutingListener", []))

    @jsii.member(jsii_name="toDeleteEndpointGroup")
    def to_delete_endpoint_group(self) -> "Globalaccelerator":
        '''(experimental) Grants permission to delete an endpoint group associated with a standard accelerator listener.

        Access Level: Write

        https://docs.aws.amazon.com/global-accelerator/latest/api/API_DeleteEndpointGroup.html

        :stability: experimental
        '''
        return typing.cast("Globalaccelerator", jsii.invoke(self, "toDeleteEndpointGroup", []))

    @jsii.member(jsii_name="toDeleteListener")
    def to_delete_listener(self) -> "Globalaccelerator":
        '''(experimental) Grants permission to delete a listener from a standard accelerator.

        Access Level: Write

        https://docs.aws.amazon.com/global-accelerator/latest/api/API_DeleteListener.html

        :stability: experimental
        '''
        return typing.cast("Globalaccelerator", jsii.invoke(self, "toDeleteListener", []))

    @jsii.member(jsii_name="toDenyCustomRoutingTraffic")
    def to_deny_custom_routing_traffic(self) -> "Globalaccelerator":
        '''(experimental) Grants permission to disallows custom routing of user traffic to a private destination IP:PORT in a specific VPC subnet.

        Access Level: Write

        https://docs.aws.amazon.com/global-accelerator/latest/api/API_DenyCustomRoutingTraffic.html

        :stability: experimental
        '''
        return typing.cast("Globalaccelerator", jsii.invoke(self, "toDenyCustomRoutingTraffic", []))

    @jsii.member(jsii_name="toDeprovisionByoipCidr")
    def to_deprovision_byoip_cidr(self) -> "Globalaccelerator":
        '''(experimental) Grants permission to releases the specified address range that you provisioned for use with your accelerator through bring your own IP addresses (BYOIP).

        Access Level: Write

        https://docs.aws.amazon.com/global-accelerator/latest/api/API_DeprovisionByoipCidr.html

        :stability: experimental
        '''
        return typing.cast("Globalaccelerator", jsii.invoke(self, "toDeprovisionByoipCidr", []))

    @jsii.member(jsii_name="toDescribeAccelerator")
    def to_describe_accelerator(self) -> "Globalaccelerator":
        '''(experimental) Grants permissions to describe a standard accelerator.

        Access Level: Read

        https://docs.aws.amazon.com/global-accelerator/latest/api/API_DescribeAccelerator.html

        :stability: experimental
        '''
        return typing.cast("Globalaccelerator", jsii.invoke(self, "toDescribeAccelerator", []))

    @jsii.member(jsii_name="toDescribeAcceleratorAttributes")
    def to_describe_accelerator_attributes(self) -> "Globalaccelerator":
        '''(experimental) Grants permission to describe a standard accelerator attributes.

        Access Level: Read

        https://docs.aws.amazon.com/global-accelerator/latest/api/API_DescribeAcceleratorAttributes.html

        :stability: experimental
        '''
        return typing.cast("Globalaccelerator", jsii.invoke(self, "toDescribeAcceleratorAttributes", []))

    @jsii.member(jsii_name="toDescribeCustomRoutingAccelerator")
    def to_describe_custom_routing_accelerator(self) -> "Globalaccelerator":
        '''(experimental) Grants permission to describe a custom routing accelerator.

        Access Level: Read

        https://docs.aws.amazon.com/global-accelerator/latest/api/API_DescribeCustomRoutingAccelerator.html

        :stability: experimental
        '''
        return typing.cast("Globalaccelerator", jsii.invoke(self, "toDescribeCustomRoutingAccelerator", []))

    @jsii.member(jsii_name="toDescribeCustomRoutingAcceleratorAttributes")
    def to_describe_custom_routing_accelerator_attributes(self) -> "Globalaccelerator":
        '''(experimental) Grants permission to describe the attributes of a custom routing accelerator.

        Access Level: Read

        https://docs.aws.amazon.com/global-accelerator/latest/api/API_DescribeCustomRoutingAcceleratorAttributes.html

        :stability: experimental
        '''
        return typing.cast("Globalaccelerator", jsii.invoke(self, "toDescribeCustomRoutingAcceleratorAttributes", []))

    @jsii.member(jsii_name="toDescribeCustomRoutingEndpointGroup")
    def to_describe_custom_routing_endpoint_group(self) -> "Globalaccelerator":
        '''(experimental) Grants permission to describe an endpoint group for a custom routing accelerator.

        Access Level: Read

        https://docs.aws.amazon.com/global-accelerator/latest/api/API_DescribeCustomRoutingEndpointGroup.html

        :stability: experimental
        '''
        return typing.cast("Globalaccelerator", jsii.invoke(self, "toDescribeCustomRoutingEndpointGroup", []))

    @jsii.member(jsii_name="toDescribeCustomRoutingListener")
    def to_describe_custom_routing_listener(self) -> "Globalaccelerator":
        '''(experimental) Grants permission to describe a listener for a custom routing accelerator.

        Access Level: Read

        https://docs.aws.amazon.com/global-accelerator/latest/api/API_DescribeCustomRoutingListener.html

        :stability: experimental
        '''
        return typing.cast("Globalaccelerator", jsii.invoke(self, "toDescribeCustomRoutingListener", []))

    @jsii.member(jsii_name="toDescribeEndpointGroup")
    def to_describe_endpoint_group(self) -> "Globalaccelerator":
        '''(experimental) Grants permission to describe a standard accelerator endpoint group.

        Access Level: Read

        https://docs.aws.amazon.com/global-accelerator/latest/api/API_DescribeEndpointGroup.html

        :stability: experimental
        '''
        return typing.cast("Globalaccelerator", jsii.invoke(self, "toDescribeEndpointGroup", []))

    @jsii.member(jsii_name="toDescribeListener")
    def to_describe_listener(self) -> "Globalaccelerator":
        '''(experimental) Grants permission to describe a standard accelerator listener.

        Access Level: Read

        https://docs.aws.amazon.com/global-accelerator/latest/api/API_DescribeListener.html

        :stability: experimental
        '''
        return typing.cast("Globalaccelerator", jsii.invoke(self, "toDescribeListener", []))

    @jsii.member(jsii_name="toListAccelerators")
    def to_list_accelerators(self) -> "Globalaccelerator":
        '''(experimental) Grants permission to list all standard accelerators.

        Access Level: List

        https://docs.aws.amazon.com/global-accelerator/latest/api/API_ListAccelerators.html

        :stability: experimental
        '''
        return typing.cast("Globalaccelerator", jsii.invoke(self, "toListAccelerators", []))

    @jsii.member(jsii_name="toListByoipCidrs")
    def to_list_byoip_cidrs(self) -> "Globalaccelerator":
        '''(experimental) Grants permission to list the BYOIP cidrs.

        Access Level: List

        https://docs.aws.amazon.com/global-accelerator/latest/api/API_ListByoipCidrs.html

        :stability: experimental
        '''
        return typing.cast("Globalaccelerator", jsii.invoke(self, "toListByoipCidrs", []))

    @jsii.member(jsii_name="toListCustomRoutingAccelerators")
    def to_list_custom_routing_accelerators(self) -> "Globalaccelerator":
        '''(experimental) Grants permission to list the custom routing accelerators for an AWS account.

        Access Level: List

        https://docs.aws.amazon.com/global-accelerator/latest/api/API_ListCustomRoutingAccelerators.html

        :stability: experimental
        '''
        return typing.cast("Globalaccelerator", jsii.invoke(self, "toListCustomRoutingAccelerators", []))

    @jsii.member(jsii_name="toListCustomRoutingEndpointGroups")
    def to_list_custom_routing_endpoint_groups(self) -> "Globalaccelerator":
        '''(experimental) Grants permission to list the endpoint groups that are associated with a listener for a custom routing accelerator.

        Access Level: List

        https://docs.aws.amazon.com/global-accelerator/latest/api/API_ListCustomRoutingEndpointGroups.html

        :stability: experimental
        '''
        return typing.cast("Globalaccelerator", jsii.invoke(self, "toListCustomRoutingEndpointGroups", []))

    @jsii.member(jsii_name="toListCustomRoutingListeners")
    def to_list_custom_routing_listeners(self) -> "Globalaccelerator":
        '''(experimental) Grants permission to list the listeners for a custom routing accelerator.

        Access Level: List

        https://docs.aws.amazon.com/global-accelerator/latest/api/API_ListCustomRoutingListeners.html

        :stability: experimental
        '''
        return typing.cast("Globalaccelerator", jsii.invoke(self, "toListCustomRoutingListeners", []))

    @jsii.member(jsii_name="toListCustomRoutingPortMappings")
    def to_list_custom_routing_port_mappings(self) -> "Globalaccelerator":
        '''(experimental) Grants permission to list the port mappings for a custom routing accelerator.

        Access Level: List

        https://docs.aws.amazon.com/global-accelerator/latest/api/API_ListCustomRoutingPortMappings.html

        :stability: experimental
        '''
        return typing.cast("Globalaccelerator", jsii.invoke(self, "toListCustomRoutingPortMappings", []))

    @jsii.member(jsii_name="toListCustomRoutingPortMappingsByDestination")
    def to_list_custom_routing_port_mappings_by_destination(
        self,
    ) -> "Globalaccelerator":
        '''(experimental) Grants permission to list the port mappings for a specific endpoint IP address (a destination address) in a subnet.

        Access Level: List

        https://docs.aws.amazon.com/global-accelerator/latest/api/API_ListCustomRoutingPortMappingsByDestination.html

        :stability: experimental
        '''
        return typing.cast("Globalaccelerator", jsii.invoke(self, "toListCustomRoutingPortMappingsByDestination", []))

    @jsii.member(jsii_name="toListEndpointGroups")
    def to_list_endpoint_groups(self) -> "Globalaccelerator":
        '''(experimental) Grants permission to list all endpoint groups associated with a standard accelerator listener.

        Access Level: List

        https://docs.aws.amazon.com/global-accelerator/latest/api/API_ListEndpointGroups.html

        :stability: experimental
        '''
        return typing.cast("Globalaccelerator", jsii.invoke(self, "toListEndpointGroups", []))

    @jsii.member(jsii_name="toListListeners")
    def to_list_listeners(self) -> "Globalaccelerator":
        '''(experimental) Grants permission to list all listeners associated with a standard accelerator.

        Access Level: List

        https://docs.aws.amazon.com/global-accelerator/latest/api/API_ListListeners.html

        :stability: experimental
        '''
        return typing.cast("Globalaccelerator", jsii.invoke(self, "toListListeners", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Globalaccelerator":
        '''(experimental) Grants permission to list tags for a globalaccelerator resource.

        Access Level: Read

        https://docs.aws.amazon.com/global-accelerator/latest/api/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("Globalaccelerator", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toProvisionByoipCidr")
    def to_provision_byoip_cidr(self) -> "Globalaccelerator":
        '''(experimental) Grants permission to provisions an address range for use with your accelerator through bring your own IP addresses (BYOIP).

        Access Level: Write

        https://docs.aws.amazon.com/global-accelerator/latest/api/API_ProvisionByoipCidr.html

        :stability: experimental
        '''
        return typing.cast("Globalaccelerator", jsii.invoke(self, "toProvisionByoipCidr", []))

    @jsii.member(jsii_name="toRemoveCustomRoutingEndpoints")
    def to_remove_custom_routing_endpoints(self) -> "Globalaccelerator":
        '''(experimental) Grants permission to remove virtual private cloud (VPC) subnet endpoints from a custom routing accelerator endpoint group.

        Access Level: Write

        https://docs.aws.amazon.com/global-accelerator/latest/api/API_RemoveCustomRoutingEndpoints.html

        :stability: experimental
        '''
        return typing.cast("Globalaccelerator", jsii.invoke(self, "toRemoveCustomRoutingEndpoints", []))

    @jsii.member(jsii_name="toRemoveEndpoints")
    def to_remove_endpoints(self) -> "Globalaccelerator":
        '''(experimental) Grants permission to remove an endpoint from a standard accelerator endpoint group.

        Access Level: Write

        https://docs.aws.amazon.com/global-accelerator/latest/api/API_RemoveEndpoints.html

        :stability: experimental
        '''
        return typing.cast("Globalaccelerator", jsii.invoke(self, "toRemoveEndpoints", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Globalaccelerator":
        '''(experimental) Grants permission to add tags to a globalaccelerator resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/global-accelerator/latest/api/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("Globalaccelerator", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Globalaccelerator":
        '''(experimental) Grants permission to remove tags from a globalaccelerator resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/global-accelerator/latest/api/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("Globalaccelerator", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateAccelerator")
    def to_update_accelerator(self) -> "Globalaccelerator":
        '''(experimental) Grants permission to update a standard accelerator.

        Access Level: Write

        https://docs.aws.amazon.com/global-accelerator/latest/api/API_UpdateAccelerator.html

        :stability: experimental
        '''
        return typing.cast("Globalaccelerator", jsii.invoke(self, "toUpdateAccelerator", []))

    @jsii.member(jsii_name="toUpdateAcceleratorAttributes")
    def to_update_accelerator_attributes(self) -> "Globalaccelerator":
        '''(experimental) Grants permission to update a standard accelerator attributes.

        Access Level: Write

        https://docs.aws.amazon.com/global-accelerator/latest/api/API_UpdateAcceleratorAttributes.html

        :stability: experimental
        '''
        return typing.cast("Globalaccelerator", jsii.invoke(self, "toUpdateAcceleratorAttributes", []))

    @jsii.member(jsii_name="toUpdateCustomRoutingAccelerator")
    def to_update_custom_routing_accelerator(self) -> "Globalaccelerator":
        '''(experimental) Grants permission to update a custom routing accelerator.

        Access Level: Write

        https://docs.aws.amazon.com/global-accelerator/latest/api/API_UpdateCustomRoutingAccelerator.html

        :stability: experimental
        '''
        return typing.cast("Globalaccelerator", jsii.invoke(self, "toUpdateCustomRoutingAccelerator", []))

    @jsii.member(jsii_name="toUpdateCustomRoutingAcceleratorAttributes")
    def to_update_custom_routing_accelerator_attributes(self) -> "Globalaccelerator":
        '''(experimental) Grants permission to update the attributes for a custom routing accelerator.

        Access Level: Write

        https://docs.aws.amazon.com/global-accelerator/latest/api/API_UpdateCustomRoutingAcceleratorAttributes.html

        :stability: experimental
        '''
        return typing.cast("Globalaccelerator", jsii.invoke(self, "toUpdateCustomRoutingAcceleratorAttributes", []))

    @jsii.member(jsii_name="toUpdateCustomRoutingListener")
    def to_update_custom_routing_listener(self) -> "Globalaccelerator":
        '''(experimental) Grants permission to update a listener for a custom routing accelerator.

        Access Level: Write

        https://docs.aws.amazon.com/global-accelerator/latest/api/API_UpdateCustomRoutingListener.html

        :stability: experimental
        '''
        return typing.cast("Globalaccelerator", jsii.invoke(self, "toUpdateCustomRoutingListener", []))

    @jsii.member(jsii_name="toUpdateEndpointGroup")
    def to_update_endpoint_group(self) -> "Globalaccelerator":
        '''(experimental) Grants permission to update an endpoint group on a standard accelerator listener.

        Access Level: Write

        https://docs.aws.amazon.com/global-accelerator/latest/api/API_UpdateEndpointGroup.html

        :stability: experimental
        '''
        return typing.cast("Globalaccelerator", jsii.invoke(self, "toUpdateEndpointGroup", []))

    @jsii.member(jsii_name="toUpdateListener")
    def to_update_listener(self) -> "Globalaccelerator":
        '''(experimental) Grants permission to update a listener on a standard accelerator.

        Access Level: Write

        https://docs.aws.amazon.com/global-accelerator/latest/api/API_UpdateListener.html

        :stability: experimental
        '''
        return typing.cast("Globalaccelerator", jsii.invoke(self, "toUpdateListener", []))

    @jsii.member(jsii_name="toWithdrawByoipCidr")
    def to_withdraw_byoip_cidr(self) -> "Globalaccelerator":
        '''(experimental) Grants permission to stops advertising a BYOIP IPv4 address.

        Access Level: Write

        https://docs.aws.amazon.com/global-accelerator/latest/api/API_WithdrawByoipCidr.html

        :stability: experimental
        '''
        return typing.cast("Globalaccelerator", jsii.invoke(self, "toWithdrawByoipCidr", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d846330db72e0e99af3c5019e0276a81e4aefc20c396543de243577df2a5c6de)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__91816cfca0a9e0d7f3567a2052a2c1530665ddd90d29b5f3e5259ae98cf6f6ba)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Glue(PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Glue"):
    '''(experimental) Statement provider for service `glue <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsglue.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `glue <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsglue.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="ifCredentialIssuingService")
    def if_credential_issuing_service(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Glue":
        '''(experimental) Filters access by the service from which the credentials of the request is issued.

        https://docs.aws.amazon.com/glue/latest/dg/using-identity-based-policies.html#glue-identity-based-policy-condition-keys

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__594d4107737f6394155eab5b8689d9cfb6dfb9fbf8633331e17366f4a70ae9ae)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Glue", jsii.invoke(self, "ifCredentialIssuingService", [value, operator]))

    @jsii.member(jsii_name="ifRoleAssumedBy")
    def if_role_assumed_by(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Glue":
        '''(experimental) Filters access by the service from which the credentials of the request is obtained by assuming the customer role.

        https://docs.aws.amazon.com/glue/latest/dg/using-identity-based-policies.html#glue-identity-based-policy-condition-keys

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e158d4d302aca08c385c1eb71ddb7ea066ad9d49b63040d79028763630bda9f6)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Glue", jsii.invoke(self, "ifRoleAssumedBy", [value, operator]))

    @jsii.member(jsii_name="ifSecurityGroupIds")
    def if_security_group_ids(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Glue":
        '''(experimental) Filters access by the ID of security groups configured for the Glue job.

        https://docs.aws.amazon.com/glue/latest/dg/using-identity-based-policies.html#glue-identity-based-policy-condition-keys

        Applies to actions:

        - .toCreateJob()
        - .toUpdateJob()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__29627e9eac8787ca29df4fb430eb065dbd55f39430ebb500e2770ff2161b697d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Glue", jsii.invoke(self, "ifSecurityGroupIds", [value, operator]))

    @jsii.member(jsii_name="ifSubnetIds")
    def if_subnet_ids(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Glue":
        '''(experimental) Filters access by the ID of subnets configured for the Glue job.

        https://docs.aws.amazon.com/glue/latest/dg/using-identity-based-policies.html#glue-identity-based-policy-condition-keys

        Applies to actions:

        - .toCreateJob()
        - .toUpdateJob()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fd179a452f3d82989c02fe54c0d6531678458a3b9134ec0676a4cf9289b25be6)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Glue", jsii.invoke(self, "ifSubnetIds", [value, operator]))

    @jsii.member(jsii_name="ifVpcIds")
    def if_vpc_ids(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Glue":
        '''(experimental) Filters access by the ID of the VPC configured for the Glue job.

        https://docs.aws.amazon.com/glue/latest/dg/using-identity-based-policies.html#glue-identity-based-policy-condition-keys

        Applies to actions:

        - .toCreateJob()
        - .toUpdateJob()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d44baf9984cb1095ecf93c60e79ba1d4b0a97303b4ce0b851e9725777c5e8d4d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Glue", jsii.invoke(self, "ifVpcIds", [value, operator]))

    @jsii.member(jsii_name="onBlueprint")
    def on_blueprint(
        self,
        blueprint_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Glue":
        '''(experimental) Adds a resource of type blueprint to the statement.

        https://docs.aws.amazon.com/glue/latest/dg/glue-specifying-resource-arns.html

        :param blueprint_name: - Identifier for the blueprintName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__84734956c2f1a093b5936ce5df7b36d12af7597951de961d502ccdc423107393)
            check_type(argname="argument blueprint_name", value=blueprint_name, expected_type=type_hints["blueprint_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Glue", jsii.invoke(self, "onBlueprint", [blueprint_name, account, region, partition]))

    @jsii.member(jsii_name="onCatalog")
    def on_catalog(
        self,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Glue":
        '''(experimental) Adds a resource of type catalog to the statement.

        https://docs.aws.amazon.com/glue/latest/dg/glue-specifying-resource-arns.html

        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6e7dbe56cdb6221f3133256b50b76b9c0cd1f37eb31e0d72a1cd6ca88ff2c403)
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Glue", jsii.invoke(self, "onCatalog", [account, region, partition]))

    @jsii.member(jsii_name="onConnection")
    def on_connection(
        self,
        connection_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Glue":
        '''(experimental) Adds a resource of type connection to the statement.

        https://docs.aws.amazon.com/glue/latest/dg/glue-specifying-resource-arns.html

        :param connection_name: - Identifier for the connectionName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__05d14a8314e27f1effbac4dd4d7e3da52bc211cb958e0645c0b65eee30e3ef56)
            check_type(argname="argument connection_name", value=connection_name, expected_type=type_hints["connection_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Glue", jsii.invoke(self, "onConnection", [connection_name, account, region, partition]))

    @jsii.member(jsii_name="onCrawler")
    def on_crawler(
        self,
        crawler_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Glue":
        '''(experimental) Adds a resource of type crawler to the statement.

        https://docs.aws.amazon.com/glue/latest/dg/glue-specifying-resource-arns.html

        :param crawler_name: - Identifier for the crawlerName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0d501e904c1b5eeba9398709cfa36ffaa8e13750d6ee19b59b3ce9639577ecad)
            check_type(argname="argument crawler_name", value=crawler_name, expected_type=type_hints["crawler_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Glue", jsii.invoke(self, "onCrawler", [crawler_name, account, region, partition]))

    @jsii.member(jsii_name="onDatabase")
    def on_database(
        self,
        database_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Glue":
        '''(experimental) Adds a resource of type database to the statement.

        https://docs.aws.amazon.com/glue/latest/dg/glue-specifying-resource-arns.html

        :param database_name: - Identifier for the databaseName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fe1d471969f84094c292060cd45e8f42625909d71db1f8a0758a9eccf5c4e57d)
            check_type(argname="argument database_name", value=database_name, expected_type=type_hints["database_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Glue", jsii.invoke(self, "onDatabase", [database_name, account, region, partition]))

    @jsii.member(jsii_name="onDataQualityRuleset")
    def on_data_quality_ruleset(
        self,
        ruleset_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Glue":
        '''(experimental) Adds a resource of type dataQualityRuleset to the statement.

        https://docs.aws.amazon.com/glue/latest/dg/glue-specifying-resource-arns.html

        :param ruleset_name: - Identifier for the rulesetName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ed1026510456bf34f5b5cacad4222cd49e51d8aa0f8f0585eb5a1204c3ac5c51)
            check_type(argname="argument ruleset_name", value=ruleset_name, expected_type=type_hints["ruleset_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Glue", jsii.invoke(self, "onDataQualityRuleset", [ruleset_name, account, region, partition]))

    @jsii.member(jsii_name="onDevendpoint")
    def on_devendpoint(
        self,
        dev_endpoint_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Glue":
        '''(experimental) Adds a resource of type devendpoint to the statement.

        https://docs.aws.amazon.com/glue/latest/dg/glue-specifying-resource-arns.html

        :param dev_endpoint_name: - Identifier for the devEndpointName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__dc03bda395fd3b08bf4def032a9ebbe38ee0564b746f8f29ce0d2f6da6bba45b)
            check_type(argname="argument dev_endpoint_name", value=dev_endpoint_name, expected_type=type_hints["dev_endpoint_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Glue", jsii.invoke(self, "onDevendpoint", [dev_endpoint_name, account, region, partition]))

    @jsii.member(jsii_name="onJob")
    def on_job(
        self,
        job_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Glue":
        '''(experimental) Adds a resource of type job to the statement.

        https://docs.aws.amazon.com/glue/latest/dg/glue-specifying-resource-arns.html

        :param job_name: - Identifier for the jobName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9e9fbad932d8fd7dbdd2d087595ac7c731226e788fdb58b77a1f73ca21905156)
            check_type(argname="argument job_name", value=job_name, expected_type=type_hints["job_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Glue", jsii.invoke(self, "onJob", [job_name, account, region, partition]))

    @jsii.member(jsii_name="onMlTransform")
    def on_ml_transform(
        self,
        transform_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Glue":
        '''(experimental) Adds a resource of type mlTransform to the statement.

        https://docs.aws.amazon.com/glue/latest/dg/glue-specifying-resource-arns.html

        :param transform_id: - Identifier for the transformId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__96ca014a1632f3836294139f16c9fb7236fcef88af8025ae0c0029ced45a660f)
            check_type(argname="argument transform_id", value=transform_id, expected_type=type_hints["transform_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Glue", jsii.invoke(self, "onMlTransform", [transform_id, account, region, partition]))

    @jsii.member(jsii_name="onRegistry")
    def on_registry(
        self,
        registry_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Glue":
        '''(experimental) Adds a resource of type registry to the statement.

        https://docs.aws.amazon.com/glue/latest/dg/glue-specifying-resource-arns.html

        :param registry_name: - Identifier for the registryName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6ec3f41078000585a46b5048d113829c6c753770b832a08abb0e51403a9d8047)
            check_type(argname="argument registry_name", value=registry_name, expected_type=type_hints["registry_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Glue", jsii.invoke(self, "onRegistry", [registry_name, account, region, partition]))

    @jsii.member(jsii_name="onSchema")
    def on_schema(
        self,
        schema_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Glue":
        '''(experimental) Adds a resource of type schema to the statement.

        https://docs.aws.amazon.com/glue/latest/dg/glue-specifying-resource-arns.html

        :param schema_name: - Identifier for the schemaName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bc779a78319f6159f68037c58dffe7302f4c723120563132c78d0b0b78978eda)
            check_type(argname="argument schema_name", value=schema_name, expected_type=type_hints["schema_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Glue", jsii.invoke(self, "onSchema", [schema_name, account, region, partition]))

    @jsii.member(jsii_name="onSession")
    def on_session(
        self,
        session_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Glue":
        '''(experimental) Adds a resource of type session to the statement.

        https://docs.aws.amazon.com/glue/latest/dg/glue-specifying-resource-arns.html

        :param session_id: - Identifier for the sessionId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__54c0c550779644ac1b1bb2056419ecdfbbcfb19a5a9970302001e82a011ee8a7)
            check_type(argname="argument session_id", value=session_id, expected_type=type_hints["session_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Glue", jsii.invoke(self, "onSession", [session_id, account, region, partition]))

    @jsii.member(jsii_name="onTable")
    def on_table(
        self,
        database_name: builtins.str,
        table_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Glue":
        '''(experimental) Adds a resource of type table to the statement.

        https://docs.aws.amazon.com/glue/latest/dg/glue-specifying-resource-arns.html

        :param database_name: - Identifier for the databaseName.
        :param table_name: - Identifier for the tableName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c1ec30a907e1988fff5decbf4e021bd60c230dc19f05b6e3d55f75890d7a2ad1)
            check_type(argname="argument database_name", value=database_name, expected_type=type_hints["database_name"])
            check_type(argname="argument table_name", value=table_name, expected_type=type_hints["table_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Glue", jsii.invoke(self, "onTable", [database_name, table_name, account, region, partition]))

    @jsii.member(jsii_name="onTableversion")
    def on_tableversion(
        self,
        database_name: builtins.str,
        table_name: builtins.str,
        table_version_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Glue":
        '''(experimental) Adds a resource of type tableversion to the statement.

        https://docs.aws.amazon.com/glue/latest/dg/glue-specifying-resource-arns.html

        :param database_name: - Identifier for the databaseName.
        :param table_name: - Identifier for the tableName.
        :param table_version_name: - Identifier for the tableVersionName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ce12a982648c20988fdf806cb8e7c3d5388e56d2acd23de9f19c073966390d16)
            check_type(argname="argument database_name", value=database_name, expected_type=type_hints["database_name"])
            check_type(argname="argument table_name", value=table_name, expected_type=type_hints["table_name"])
            check_type(argname="argument table_version_name", value=table_version_name, expected_type=type_hints["table_version_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Glue", jsii.invoke(self, "onTableversion", [database_name, table_name, table_version_name, account, region, partition]))

    @jsii.member(jsii_name="onTrigger")
    def on_trigger(
        self,
        trigger_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Glue":
        '''(experimental) Adds a resource of type trigger to the statement.

        https://docs.aws.amazon.com/glue/latest/dg/glue-specifying-resource-arns.html

        :param trigger_name: - Identifier for the triggerName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__48c0448abb501d9a37def1fd138bab41e8d03d9803063d651f2be25b310ef962)
            check_type(argname="argument trigger_name", value=trigger_name, expected_type=type_hints["trigger_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Glue", jsii.invoke(self, "onTrigger", [trigger_name, account, region, partition]))

    @jsii.member(jsii_name="onUserdefinedfunction")
    def on_userdefinedfunction(
        self,
        database_name: builtins.str,
        user_defined_function_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Glue":
        '''(experimental) Adds a resource of type userdefinedfunction to the statement.

        https://docs.aws.amazon.com/glue/latest/dg/glue-specifying-resource-arns.html

        :param database_name: - Identifier for the databaseName.
        :param user_defined_function_name: - Identifier for the userDefinedFunctionName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__94057aee04dddea3e576d201934f976f055ae1729097c324a11557f36440b712)
            check_type(argname="argument database_name", value=database_name, expected_type=type_hints["database_name"])
            check_type(argname="argument user_defined_function_name", value=user_defined_function_name, expected_type=type_hints["user_defined_function_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Glue", jsii.invoke(self, "onUserdefinedfunction", [database_name, user_defined_function_name, account, region, partition]))

    @jsii.member(jsii_name="onWorkflow")
    def on_workflow(
        self,
        workflow_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Glue":
        '''(experimental) Adds a resource of type workflow to the statement.

        https://docs.aws.amazon.com/glue/latest/dg/glue-specifying-resource-arns.html

        :param workflow_name: - Identifier for the workflowName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__42c32f6969fc9b42d518a507fccfcafaf4e82fd7c3d8dc151e81150d05b7b08f)
            check_type(argname="argument workflow_name", value=workflow_name, expected_type=type_hints["workflow_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Glue", jsii.invoke(self, "onWorkflow", [workflow_name, account, region, partition]))

    @jsii.member(jsii_name="toBatchCreatePartition")
    def to_batch_create_partition(self) -> "Glue":
        '''(experimental) Grants permission to create one or more partitions.

        Access Level: Write

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-catalog-partitions.html#aws-glue-api-catalog-partitions-BatchCreatePartition

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toBatchCreatePartition", []))

    @jsii.member(jsii_name="toBatchDeleteConnection")
    def to_batch_delete_connection(self) -> "Glue":
        '''(experimental) Grants permission to delete one or more connections.

        Access Level: Write

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-catalog-connections.html#aws-glue-api-catalog-connections-BatchDeleteConnection

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toBatchDeleteConnection", []))

    @jsii.member(jsii_name="toBatchDeletePartition")
    def to_batch_delete_partition(self) -> "Glue":
        '''(experimental) Grants permission to delete one or more partitions.

        Access Level: Write

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-catalog-partitions.html#aws-glue-api-catalog-partitions-BatchDeletePartition

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toBatchDeletePartition", []))

    @jsii.member(jsii_name="toBatchDeleteTable")
    def to_batch_delete_table(self) -> "Glue":
        '''(experimental) Grants permission to delete one or more tables.

        Access Level: Write

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-catalog-tables.html#aws-glue-api-catalog-tables-BatchDeleteTable

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toBatchDeleteTable", []))

    @jsii.member(jsii_name="toBatchDeleteTableVersion")
    def to_batch_delete_table_version(self) -> "Glue":
        '''(experimental) Grants permission to delete one or more versions of a table.

        Access Level: Write

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-catalog-tables.html#aws-glue-api-catalog-tables-DeleteTableVersion

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toBatchDeleteTableVersion", []))

    @jsii.member(jsii_name="toBatchGetBlueprints")
    def to_batch_get_blueprints(self) -> "Glue":
        '''(experimental) Grants permission to retrieve one or more blueprints.

        Access Level: Read

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-workflow.html#aws-glue-api-workflow-BatchGetBlueprints

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toBatchGetBlueprints", []))

    @jsii.member(jsii_name="toBatchGetCrawlers")
    def to_batch_get_crawlers(self) -> "Glue":
        '''(experimental) Grants permission to retrieve one or more crawlers.

        Access Level: Read

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-crawler-crawling.html#aws-glue-api-crawler-crawling-BatchGetCrawlers

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toBatchGetCrawlers", []))

    @jsii.member(jsii_name="toBatchGetCustomEntityTypes")
    def to_batch_get_custom_entity_types(self) -> "Glue":
        '''(experimental) Grants permission to retrieve one or more Custom Entity Types.

        Access Level: Read

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-sensitive-data-api.html#aws-glue-api-sensitive-data-api-BatchGetCustomEntityTypes

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toBatchGetCustomEntityTypes", []))

    @jsii.member(jsii_name="toBatchGetDevEndpoints")
    def to_batch_get_dev_endpoints(self) -> "Glue":
        '''(experimental) Grants permission to retrieve one or more development endpoints.

        Access Level: Read

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-dev-endpoint.html#aws-glue-api-dev-endpoint-BatchGetDevEndpoints

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toBatchGetDevEndpoints", []))

    @jsii.member(jsii_name="toBatchGetJobs")
    def to_batch_get_jobs(self) -> "Glue":
        '''(experimental) Grants permission to retrieve one or more jobs.

        Access Level: Read

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-jobs-job.html#aws-glue-api-jobs-job-BatchGetJobs

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toBatchGetJobs", []))

    @jsii.member(jsii_name="toBatchGetPartition")
    def to_batch_get_partition(self) -> "Glue":
        '''(experimental) Grants permission to retrieve one or more partitions.

        Access Level: Read

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-catalog-partitions.html#aws-glue-api-catalog-partitions-BatchGetPartition

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toBatchGetPartition", []))

    @jsii.member(jsii_name="toBatchGetTriggers")
    def to_batch_get_triggers(self) -> "Glue":
        '''(experimental) Grants permission to retrieve one or more triggers.

        Access Level: Read

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-jobs-trigger.html#aws-glue-api-jobs-trigger-BatchGetTriggers

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toBatchGetTriggers", []))

    @jsii.member(jsii_name="toBatchGetWorkflows")
    def to_batch_get_workflows(self) -> "Glue":
        '''(experimental) Grants permission to retrieve one or more workflows.

        Access Level: Read

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-workflow.html#aws-glue-api-workflow-BatchGetWorkflows

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toBatchGetWorkflows", []))

    @jsii.member(jsii_name="toBatchStopJobRun")
    def to_batch_stop_job_run(self) -> "Glue":
        '''(experimental) Grants permission to stop one or more job runs for a job.

        Access Level: Write

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-jobs-runs.html#aws-glue-api-jobs-runs-BatchStopStartJobRun

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toBatchStopJobRun", []))

    @jsii.member(jsii_name="toBatchUpdatePartition")
    def to_batch_update_partition(self) -> "Glue":
        '''(experimental) Grants permission to update one or more partitions.

        Access Level: Write

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-catalog-partitions.html#aws-glue-api-catalog-partitions-BatchUpdatePartition

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toBatchUpdatePartition", []))

    @jsii.member(jsii_name="toCancelDataQualityRuleRecommendationRun")
    def to_cancel_data_quality_rule_recommendation_run(self) -> "Glue":
        '''(experimental) Grants permission to stop a running Data Quality rule recommendation run.

        Access Level: Write

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-data-quality-api.html#aws-glue-api-data-quality-api-CancelDataQualityRuleRecommendationRun

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toCancelDataQualityRuleRecommendationRun", []))

    @jsii.member(jsii_name="toCancelDataQualityRulesetEvaluationRun")
    def to_cancel_data_quality_ruleset_evaluation_run(self) -> "Glue":
        '''(experimental) Grants permission to stop a running Data Quality ruleset evaluation run.

        Access Level: Write

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-data-quality-api.html#aws-glue-api-data-quality-api-CancelDataQualityRulesetEvaluationRun

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toCancelDataQualityRulesetEvaluationRun", []))

    @jsii.member(jsii_name="toCancelMLTaskRun")
    def to_cancel_ml_task_run(self) -> "Glue":
        '''(experimental) Grants permission to stop a running ML Task Run.

        Access Level: Write

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-machine-learning-api.html#aws-glue-api-machine-learning-api-CancelMLTaskRun

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toCancelMLTaskRun", []))

    @jsii.member(jsii_name="toCancelStatement")
    def to_cancel_statement(self) -> "Glue":
        '''(experimental) Grants permission to cancel a statement in an interactive session.

        Access Level: Write

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-interactive-sessions.html#aws-glue-interactive-sessions-CancelStatement

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toCancelStatement", []))

    @jsii.member(jsii_name="toCheckSchemaVersionValidity")
    def to_check_schema_version_validity(self) -> "Glue":
        '''(experimental) Grants permission to retrieve a check the validity of schema version.

        Access Level: Read

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-schema-registry-api.html#aws-glue-api-schema-registry-api-CheckSchemaVersionValidity

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toCheckSchemaVersionValidity", []))

    @jsii.member(jsii_name="toCreateBlueprint")
    def to_create_blueprint(self) -> "Glue":
        '''(experimental) Grants permission to create a blueprint.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-workflow.html#aws-glue-api-workflow-CreateBlueprint

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toCreateBlueprint", []))

    @jsii.member(jsii_name="toCreateClassifier")
    def to_create_classifier(self) -> "Glue":
        '''(experimental) Grants permission to create a classifier.

        Access Level: Write

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-crawler-classifiers.html#aws-glue-api-crawler-classifiers-CreateClassifier

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toCreateClassifier", []))

    @jsii.member(jsii_name="toCreateConnection")
    def to_create_connection(self) -> "Glue":
        '''(experimental) Grants permission to create a connection.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-catalog-connections.html#aws-glue-api-catalog-connections-CreateConnection

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toCreateConnection", []))

    @jsii.member(jsii_name="toCreateCrawler")
    def to_create_crawler(self) -> "Glue":
        '''(experimental) Grants permission to create a crawler.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-crawler-crawling.html#aws-glue-api-crawler-crawling-CreateCrawler

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toCreateCrawler", []))

    @jsii.member(jsii_name="toCreateCustomEntityType")
    def to_create_custom_entity_type(self) -> "Glue":
        '''(experimental) Grants permission to create a Custom Entity Type.

        Access Level: Write

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-sensitive-data-api.html#aws-glue-api-sensitive-data-api-CreateCustomEntityType

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toCreateCustomEntityType", []))

    @jsii.member(jsii_name="toCreateDatabase")
    def to_create_database(self) -> "Glue":
        '''(experimental) Grants permission to create a database.

        Access Level: Write

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-catalog-databases.html#aws-glue-api-catalog-databases-CreateDatabase

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toCreateDatabase", []))

    @jsii.member(jsii_name="toCreateDataQualityRuleset")
    def to_create_data_quality_ruleset(self) -> "Glue":
        '''(experimental) Grants permission to create a Data Quality ruleset.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-data-quality-api.html#aws-glue-api-data-quality-api-CreateDataQualityRuleset

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toCreateDataQualityRuleset", []))

    @jsii.member(jsii_name="toCreateDevEndpoint")
    def to_create_dev_endpoint(self) -> "Glue":
        '''(experimental) Grants permission to create a development endpoint.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-dev-endpoint.html#aws-glue-api-dev-endpoint-CreateDevEndpoint

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toCreateDevEndpoint", []))

    @jsii.member(jsii_name="toCreateJob")
    def to_create_job(self) -> "Glue":
        '''(experimental) Grants permission to create a job.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifVpcIds()
        - .ifSubnetIds()
        - .ifSecurityGroupIds()

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-jobs-job.html#aws-glue-api-jobs-job-CreateJob

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toCreateJob", []))

    @jsii.member(jsii_name="toCreateMLTransform")
    def to_create_ml_transform(self) -> "Glue":
        '''(experimental) Grants permission to create an ML Transform.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-machine-learning-api.html#aws-glue-api-machine-learning-api-CreateMLTransform

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toCreateMLTransform", []))

    @jsii.member(jsii_name="toCreatePartition")
    def to_create_partition(self) -> "Glue":
        '''(experimental) Grants permission to create a partition.

        Access Level: Write

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-catalog-partitions.html#aws-glue-api-catalog-partitions-CreatePartition

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toCreatePartition", []))

    @jsii.member(jsii_name="toCreatePartitionIndex")
    def to_create_partition_index(self) -> "Glue":
        '''(experimental) Grants permission to create a specified partition index in an existing table.

        Access Level: Write

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-catalog-tables.html#aws-glue-api-catalog-tables-CreatePartitionIndex

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toCreatePartitionIndex", []))

    @jsii.member(jsii_name="toCreateRegistry")
    def to_create_registry(self) -> "Glue":
        '''(experimental) Grants permission to create a new schema registry.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-schema-registry-api.html#aws-glue-api-schema-registry-api-CreateRegistry

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toCreateRegistry", []))

    @jsii.member(jsii_name="toCreateSchema")
    def to_create_schema(self) -> "Glue":
        '''(experimental) Grants permission to create a new schema container.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-schema-registry-api.html#aws-glue-api-schema-registry-api-CreateSchema

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toCreateSchema", []))

    @jsii.member(jsii_name="toCreateScript")
    def to_create_script(self) -> "Glue":
        '''(experimental) Grants permission to create a script.

        Access Level: Write

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-etl-script-generation.html#aws-glue-api-etl-script-generation-CreateScript

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toCreateScript", []))

    @jsii.member(jsii_name="toCreateSecurityConfiguration")
    def to_create_security_configuration(self) -> "Glue":
        '''(experimental) Grants permission to create a security configuration.

        Access Level: Write

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-jobs-security.html#aws-glue-api-jobs-security-CreateSecurityConfiguration

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toCreateSecurityConfiguration", []))

    @jsii.member(jsii_name="toCreateSession")
    def to_create_session(self) -> "Glue":
        '''(experimental) Grants permission to create an interactive session.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-interactive-sessions.html#aws-glue-api-interactive-sessions-CreateSession

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toCreateSession", []))

    @jsii.member(jsii_name="toCreateTable")
    def to_create_table(self) -> "Glue":
        '''(experimental) Grants permission to create a table.

        Access Level: Write

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-catalog-tables.html#aws-glue-api-catalog-tables-CreateTable

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toCreateTable", []))

    @jsii.member(jsii_name="toCreateTrigger")
    def to_create_trigger(self) -> "Glue":
        '''(experimental) Grants permission to create a trigger.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-jobs-trigger.html#aws-glue-api-jobs-trigger-CreateTrigger

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toCreateTrigger", []))

    @jsii.member(jsii_name="toCreateUserDefinedFunction")
    def to_create_user_defined_function(self) -> "Glue":
        '''(experimental) Grants permission to create a function definition.

        Access Level: Write

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-catalog-functions.html#aws-glue-api-catalog-functions-CreateUserDefinedFunction

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toCreateUserDefinedFunction", []))

    @jsii.member(jsii_name="toCreateWorkflow")
    def to_create_workflow(self) -> "Glue":
        '''(experimental) Grants permission to create a workflow.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-workflow.html#aws-glue-api-workflow-CreateWorkflow

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toCreateWorkflow", []))

    @jsii.member(jsii_name="toDeleteBlueprint")
    def to_delete_blueprint(self) -> "Glue":
        '''(experimental) Grants permission to delete a blueprint.

        Access Level: Write

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-workflow.html#aws-glue-api-workflow-DeleteBlueprint

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toDeleteBlueprint", []))

    @jsii.member(jsii_name="toDeleteClassifier")
    def to_delete_classifier(self) -> "Glue":
        '''(experimental) Grants permission to delete a classifier.

        Access Level: Write

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-crawler-classifiers.html#aws-glue-api-crawler-classifiers-DeleteClassifier

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toDeleteClassifier", []))

    @jsii.member(jsii_name="toDeleteColumnStatisticsForPartition")
    def to_delete_column_statistics_for_partition(self) -> "Glue":
        '''(experimental) Grants permission to delete the partition column statistics of a column.

        Access Level: Write

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-catalog-partitions.html#aws-glue-api-catalog-partitions-DeleteColumnStatisticsForPartition

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toDeleteColumnStatisticsForPartition", []))

    @jsii.member(jsii_name="toDeleteColumnStatisticsForTable")
    def to_delete_column_statistics_for_table(self) -> "Glue":
        '''(experimental) Grants permission to delete the table statistics of columns.

        Access Level: Write

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-catalog-tables.html#aws-glue-api-catalog-tables-DeleteColumnStatisticsForTable

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toDeleteColumnStatisticsForTable", []))

    @jsii.member(jsii_name="toDeleteConnection")
    def to_delete_connection(self) -> "Glue":
        '''(experimental) Grants permission to delete a connection.

        Access Level: Write

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-catalog-connections.html#aws-glue-api-catalog-connections-DeleteConnection

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toDeleteConnection", []))

    @jsii.member(jsii_name="toDeleteCrawler")
    def to_delete_crawler(self) -> "Glue":
        '''(experimental) Grants permission to delete a crawler.

        Access Level: Write

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-crawler-crawling.html#aws-glue-api-crawler-crawling-DeleteCrawler

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toDeleteCrawler", []))

    @jsii.member(jsii_name="toDeleteCustomEntityType")
    def to_delete_custom_entity_type(self) -> "Glue":
        '''(experimental) Grants permission to delete a Custom Entity Type.

        Access Level: Write

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-sensitive-data-api.html#aws-glue-api-sensitive-data-api-DeleteCustomEntityType

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toDeleteCustomEntityType", []))

    @jsii.member(jsii_name="toDeleteDatabase")
    def to_delete_database(self) -> "Glue":
        '''(experimental) Grants permission to delete a database.

        Access Level: Write

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-catalog-databases.html#aws-glue-api-catalog-databases-DeleteDatabase

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toDeleteDatabase", []))

    @jsii.member(jsii_name="toDeleteDataQualityRuleset")
    def to_delete_data_quality_ruleset(self) -> "Glue":
        '''(experimental) Grants permission to delete a Data Quality ruleset.

        Access Level: Write

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-data-quality-api.html#aws-glue-api-data-quality-api-DeleteDataQualityRuleset

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toDeleteDataQualityRuleset", []))

    @jsii.member(jsii_name="toDeleteDevEndpoint")
    def to_delete_dev_endpoint(self) -> "Glue":
        '''(experimental) Grants permission to delete a development endpoint.

        Access Level: Write

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-dev-endpoint.html#aws-glue-api-dev-endpoint-DeleteDevEndpoint

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toDeleteDevEndpoint", []))

    @jsii.member(jsii_name="toDeleteJob")
    def to_delete_job(self) -> "Glue":
        '''(experimental) Grants permission to delete a job.

        Access Level: Write

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-jobs-job.html#aws-glue-api-jobs-job-DeleteJob

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toDeleteJob", []))

    @jsii.member(jsii_name="toDeleteMLTransform")
    def to_delete_ml_transform(self) -> "Glue":
        '''(experimental) Grants permission to delete an ML Transform.

        Access Level: Write

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-machine-learning-api.html#aws-glue-api-machine-learning-api-DeleteMLTransform

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toDeleteMLTransform", []))

    @jsii.member(jsii_name="toDeletePartition")
    def to_delete_partition(self) -> "Glue":
        '''(experimental) Grants permission to delete a partition.

        Access Level: Write

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-catalog-partitions.html#aws-glue-api-catalog-partitions-DeletePartition

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toDeletePartition", []))

    @jsii.member(jsii_name="toDeletePartitionIndex")
    def to_delete_partition_index(self) -> "Glue":
        '''(experimental) Grants permission to delete a specified partition index from an existing table.

        Access Level: Write

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-catalog-tables.html#aws-glue-api-catalog-tables-DeletePartitionIndex

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toDeletePartitionIndex", []))

    @jsii.member(jsii_name="toDeleteRegistry")
    def to_delete_registry(self) -> "Glue":
        '''(experimental) Grants permission to delete a schema registry.

        Access Level: Write

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-schema-registry-api.html#aws-glue-api-schema-registry-api-DeleteRegistry

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toDeleteRegistry", []))

    @jsii.member(jsii_name="toDeleteResourcePolicy")
    def to_delete_resource_policy(self) -> "Glue":
        '''(experimental) Grants permission to delete a resource policy.

        Access Level: Permissions management

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-jobs-security.html#aws-glue-api-jobs-security-DeleteResourcePolicy

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toDeleteResourcePolicy", []))

    @jsii.member(jsii_name="toDeleteSchema")
    def to_delete_schema(self) -> "Glue":
        '''(experimental) Grants permission to delete a schema container.

        Access Level: Write

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-schema-registry-api.html#aws-glue-api-schema-registry-api-DeleteSchema

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toDeleteSchema", []))

    @jsii.member(jsii_name="toDeleteSchemaVersions")
    def to_delete_schema_versions(self) -> "Glue":
        '''(experimental) Grants permission to delete a range of schema versions.

        Access Level: Write

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-schema-registry-api.html#aws-glue-api-schema-registry-api-DeleteSchemaVersions

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toDeleteSchemaVersions", []))

    @jsii.member(jsii_name="toDeleteSecurityConfiguration")
    def to_delete_security_configuration(self) -> "Glue":
        '''(experimental) Grants permission to delete a security configuration.

        Access Level: Write

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-jobs-security.html#aws-glue-api-jobs-security-DeleteSecurityConfiguration

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toDeleteSecurityConfiguration", []))

    @jsii.member(jsii_name="toDeleteSession")
    def to_delete_session(self) -> "Glue":
        '''(experimental) Grants permission to delete an interactive session after stopping the session if not already stopped.

        Access Level: Write

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-interactive-sessions.html#aws-glue-interactive-sessions-DeleteSession

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toDeleteSession", []))

    @jsii.member(jsii_name="toDeleteTable")
    def to_delete_table(self) -> "Glue":
        '''(experimental) Grants permission to delete a table.

        Access Level: Write

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-catalog-tables.html#aws-glue-api-catalog-tables-DeleteTable

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toDeleteTable", []))

    @jsii.member(jsii_name="toDeleteTableVersion")
    def to_delete_table_version(self) -> "Glue":
        '''(experimental) Grants permission to delete a version of a table.

        Access Level: Write

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-catalog-tables.html#aws-glue-api-catalog-tables-DeleteTableVersion

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toDeleteTableVersion", []))

    @jsii.member(jsii_name="toDeleteTrigger")
    def to_delete_trigger(self) -> "Glue":
        '''(experimental) Grants permission to delete a trigger.

        Access Level: Write

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-jobs-trigger.html#aws-glue-api-jobs-trigger-DeleteTrigger

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toDeleteTrigger", []))

    @jsii.member(jsii_name="toDeleteUserDefinedFunction")
    def to_delete_user_defined_function(self) -> "Glue":
        '''(experimental) Grants permission to delete a function definition.

        Access Level: Write

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-catalog-functions.html#aws-glue-api-catalog-functions-DeleteUserDefinedFunction

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toDeleteUserDefinedFunction", []))

    @jsii.member(jsii_name="toDeleteWorkflow")
    def to_delete_workflow(self) -> "Glue":
        '''(experimental) Grants permission to delete a workflow.

        Access Level: Write

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-workflow.html#aws-glue-api-workflow-DeleteWorkflow

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toDeleteWorkflow", []))

    @jsii.member(jsii_name="toDeregisterDataPreview")
    def to_deregister_data_preview(self) -> "Glue":
        '''(experimental) Grants permission to terminate Glue Studio Notebook session.

        Access Level: Permissions management

        https://docs.aws.amazon.com/glue/latest/ug/notebook-getting-started.html#create-notebook-permissions-operations

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toDeregisterDataPreview", []))

    @jsii.member(jsii_name="toGetBlueprint")
    def to_get_blueprint(self) -> "Glue":
        '''(experimental) Grants permission to retrieve a blueprint.

        Access Level: Read

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-workflow.html#aws-glue-api-workflow-GetBlueprint

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toGetBlueprint", []))

    @jsii.member(jsii_name="toGetBlueprintRun")
    def to_get_blueprint_run(self) -> "Glue":
        '''(experimental) Grants permission to retrieve a blueprint run.

        Access Level: Read

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-workflow.html#aws-glue-api-workflow-GetBlueprintRun

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toGetBlueprintRun", []))

    @jsii.member(jsii_name="toGetBlueprintRuns")
    def to_get_blueprint_runs(self) -> "Glue":
        '''(experimental) Grants permission to retrieve all runs of a blueprint.

        Access Level: Read

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-workflow.html#aws-glue-api-workflow-GetBlueprintRuns

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toGetBlueprintRuns", []))

    @jsii.member(jsii_name="toGetCatalogImportStatus")
    def to_get_catalog_import_status(self) -> "Glue":
        '''(experimental) Grants permission to retrieve the catalog import status.

        Access Level: Read

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-catalog-migration.html#aws-glue-api-catalog-migration-GetCatalogImportStatus

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toGetCatalogImportStatus", []))

    @jsii.member(jsii_name="toGetClassifier")
    def to_get_classifier(self) -> "Glue":
        '''(experimental) Grants permission to retrieve a classifier.

        Access Level: Read

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-crawler-classifiers.html#aws-glue-api-crawler-classifiers-GetClassifier

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toGetClassifier", []))

    @jsii.member(jsii_name="toGetClassifiers")
    def to_get_classifiers(self) -> "Glue":
        '''(experimental) Grants permission to list all classifiers.

        Access Level: Read

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-crawler-classifiers.html#aws-glue-api-crawler-classifiers-GetClassifiers

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toGetClassifiers", []))

    @jsii.member(jsii_name="toGetColumnStatisticsForPartition")
    def to_get_column_statistics_for_partition(self) -> "Glue":
        '''(experimental) Grants permission to retrieve partition statistics of columns.

        Access Level: Read

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-catalog-partitions.html#aws-glue-api-catalog-partitions-GetColumnStatisticsForPartition

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toGetColumnStatisticsForPartition", []))

    @jsii.member(jsii_name="toGetColumnStatisticsForTable")
    def to_get_column_statistics_for_table(self) -> "Glue":
        '''(experimental) Grants permission to retrieve table statistics of columns.

        Access Level: Read

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-catalog-tables.html#aws-glue-api-catalog-tables-GetColumnStatisticsForTable

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toGetColumnStatisticsForTable", []))

    @jsii.member(jsii_name="toGetConnection")
    def to_get_connection(self) -> "Glue":
        '''(experimental) Grants permission to retrieve a connection.

        Access Level: Read

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-catalog-connections.html#aws-glue-api-catalog-connections-GetConnection

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toGetConnection", []))

    @jsii.member(jsii_name="toGetConnections")
    def to_get_connections(self) -> "Glue":
        '''(experimental) Grants permission to retrieve a list of connections.

        Access Level: Read

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-catalog-connections.html#aws-glue-api-catalog-connections-GetConnections

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toGetConnections", []))

    @jsii.member(jsii_name="toGetCrawler")
    def to_get_crawler(self) -> "Glue":
        '''(experimental) Grants permission to retrieve a crawler.

        Access Level: Read

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-crawler-crawling.html#aws-glue-api-crawler-crawling-GetCrawler

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toGetCrawler", []))

    @jsii.member(jsii_name="toGetCrawlerMetrics")
    def to_get_crawler_metrics(self) -> "Glue":
        '''(experimental) Grants permission to retrieve metrics about crawlers.

        Access Level: Read

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-crawler-crawling.html#aws-glue-api-crawler-crawling-GetCrawlerMetrics

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toGetCrawlerMetrics", []))

    @jsii.member(jsii_name="toGetCrawlers")
    def to_get_crawlers(self) -> "Glue":
        '''(experimental) Grants permission to retrieve all crawlers.

        Access Level: Read

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-crawler-crawling.html#aws-glue-api-crawler-crawling-GetCrawlers

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toGetCrawlers", []))

    @jsii.member(jsii_name="toGetCustomEntityType")
    def to_get_custom_entity_type(self) -> "Glue":
        '''(experimental) Grants permission to read a Custom Entity Type.

        Access Level: Read

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-sensitive-data-api.html#aws-glue-api-sensitive-data-api-GetCustomEntityType

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toGetCustomEntityType", []))

    @jsii.member(jsii_name="toGetDatabase")
    def to_get_database(self) -> "Glue":
        '''(experimental) Grants permission to retrieve a database.

        Access Level: Read

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-catalog-databases.html#aws-glue-api-catalog-databases-GetDatabase

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toGetDatabase", []))

    @jsii.member(jsii_name="toGetDatabases")
    def to_get_databases(self) -> "Glue":
        '''(experimental) Grants permission to retrieve all databases.

        Access Level: Read

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-catalog-databases.html#aws-glue-api-catalog-databases-GetDatabases

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toGetDatabases", []))

    @jsii.member(jsii_name="toGetDataCatalogEncryptionSettings")
    def to_get_data_catalog_encryption_settings(self) -> "Glue":
        '''(experimental) Grants permission to retrieve catalog encryption settings.

        Access Level: Read

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-jobs-security.html#aws-glue-api-jobs-security-GetDataCatalogEncryptionSettings

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toGetDataCatalogEncryptionSettings", []))

    @jsii.member(jsii_name="toGetDataflowGraph")
    def to_get_dataflow_graph(self) -> "Glue":
        '''(experimental) Grants permission to transform a script into a directed acyclic graph (DAG).

        Access Level: Read

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-etl-script-generation.html#aws-glue-api-etl-script-generation-GetDataflowGraph

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toGetDataflowGraph", []))

    @jsii.member(jsii_name="toGetDataQualityResult")
    def to_get_data_quality_result(self) -> "Glue":
        '''(experimental) Grants permission to retrieve a Data Quality result.

        Access Level: Read

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-data-quality-api.html#aws-glue-api-data-quality-api-GetDataQualityResult

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toGetDataQualityResult", []))

    @jsii.member(jsii_name="toGetDataQualityRuleRecommendationRun")
    def to_get_data_quality_rule_recommendation_run(self) -> "Glue":
        '''(experimental) Grants permission to retrieve a Data Quality rule recommendation run.

        Access Level: Read

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-data-quality-api.html#aws-glue-api-data-quality-api-GetDataQualityRuleRecommendationRun

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toGetDataQualityRuleRecommendationRun", []))

    @jsii.member(jsii_name="toGetDataQualityRuleset")
    def to_get_data_quality_ruleset(self) -> "Glue":
        '''(experimental) Grants permission to retrieve a Data Quality ruleset.

        Access Level: Read

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-data-quality-api.html#aws-glue-api-data-quality-api-GetDataQualityRuleset

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toGetDataQualityRuleset", []))

    @jsii.member(jsii_name="toGetDataQualityRulesetEvaluationRun")
    def to_get_data_quality_ruleset_evaluation_run(self) -> "Glue":
        '''(experimental) Grants permission to retrieve a Data Quality rule recommendation run.

        Access Level: Read

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-data-quality-api.html#aws-glue-api-data-quality-api-GetDataQualityRulesetEvaluationRun

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toGetDataQualityRulesetEvaluationRun", []))

    @jsii.member(jsii_name="toGetDevEndpoint")
    def to_get_dev_endpoint(self) -> "Glue":
        '''(experimental) Grants permission to retrieve a development endpoint.

        Access Level: Read

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-dev-endpoint.html#aws-glue-api-dev-endpoint-GetDevEndpoint

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toGetDevEndpoint", []))

    @jsii.member(jsii_name="toGetDevEndpoints")
    def to_get_dev_endpoints(self) -> "Glue":
        '''(experimental) Grants permission to retrieve all development endpoints.

        Access Level: Read

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-dev-endpoint.html#aws-glue-api-dev-endpoint-GetDevEndpoints

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toGetDevEndpoints", []))

    @jsii.member(jsii_name="toGetJob")
    def to_get_job(self) -> "Glue":
        '''(experimental) Grants permission to retrieve a job.

        Access Level: Read

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-jobs-job.html#aws-glue-api-jobs-job-GetJob

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toGetJob", []))

    @jsii.member(jsii_name="toGetJobBookmark")
    def to_get_job_bookmark(self) -> "Glue":
        '''(experimental) Grants permission to retrieve a job bookmark.

        Access Level: Read

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-jobs-runs.html#aws-glue-api-jobs-job-GetJobBookmark

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toGetJobBookmark", []))

    @jsii.member(jsii_name="toGetJobRun")
    def to_get_job_run(self) -> "Glue":
        '''(experimental) Grants permission to retrieve a job run.

        Access Level: Read

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-jobs-runs.html#aws-glue-api-jobs-runs-GetJobRun

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toGetJobRun", []))

    @jsii.member(jsii_name="toGetJobRuns")
    def to_get_job_runs(self) -> "Glue":
        '''(experimental) Grants permission to retrieve all job runs of a job.

        Access Level: Read

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-jobs-runs.html#aws-glue-api-jobs-runs-GetJobRuns

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toGetJobRuns", []))

    @jsii.member(jsii_name="toGetJobs")
    def to_get_jobs(self) -> "Glue":
        '''(experimental) Grants permission to retrieve all current jobs.

        Access Level: Read

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-jobs-job.html#aws-glue-api-jobs-job-GetJobs

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toGetJobs", []))

    @jsii.member(jsii_name="toGetMapping")
    def to_get_mapping(self) -> "Glue":
        '''(experimental) Grants permission to create a mapping.

        Access Level: Read

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-etl-script-generation.html#aws-glue-api-etl-script-generation-GetMapping

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toGetMapping", []))

    @jsii.member(jsii_name="toGetMLTaskRun")
    def to_get_ml_task_run(self) -> "Glue":
        '''(experimental) Grants permission to retrieve an ML Task Run.

        Access Level: Read

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-machine-learning-api.html#aws-glue-api-machine-learning-api-GetMLTaskRun

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toGetMLTaskRun", []))

    @jsii.member(jsii_name="toGetMLTaskRuns")
    def to_get_ml_task_runs(self) -> "Glue":
        '''(experimental) Grants permission to retrieve all ML Task Runs.

        Access Level: List

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-machine-learning-api.html#aws-glue-api-machine-learning-api-GetMLTaskRuns

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toGetMLTaskRuns", []))

    @jsii.member(jsii_name="toGetMLTransform")
    def to_get_ml_transform(self) -> "Glue":
        '''(experimental) Grants permission to retrieve an ML Transform.

        Access Level: Read

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-machine-learning-api.html#aws-glue-api-machine-learning-api-GetMLTransform

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toGetMLTransform", []))

    @jsii.member(jsii_name="toGetMLTransforms")
    def to_get_ml_transforms(self) -> "Glue":
        '''(experimental) Grants permission to retrieve all ML Transforms.

        Access Level: List

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-machine-learning-api.html#aws-glue-api-machine-learning-api-GetMLTransforms

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toGetMLTransforms", []))

    @jsii.member(jsii_name="toGetNotebookInstanceStatus")
    def to_get_notebook_instance_status(self) -> "Glue":
        '''(experimental) Grants permission to retrieve Glue Studio Notebooks session status.

        Access Level: Permissions management

        https://docs.aws.amazon.com/glue/latest/ug/notebook-getting-started.html#create-notebook-permissions-operations

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toGetNotebookInstanceStatus", []))

    @jsii.member(jsii_name="toGetPartition")
    def to_get_partition(self) -> "Glue":
        '''(experimental) Grants permission to retrieve a partition.

        Access Level: Read

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-catalog-partitions.html#aws-glue-api-catalog-partitions-GetPartition

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toGetPartition", []))

    @jsii.member(jsii_name="toGetPartitionIndexes")
    def to_get_partition_indexes(self) -> "Glue":
        '''(experimental) Grants permission to retrieve partition indexes for a table.

        Access Level: Read

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-catalog-tables.html#aws-glue-api-catalog-tables-GetPartitionIndexes

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toGetPartitionIndexes", []))

    @jsii.member(jsii_name="toGetPartitions")
    def to_get_partitions(self) -> "Glue":
        '''(experimental) Grants permission to retrieve the partitions of a table.

        Access Level: Read

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-catalog-partitions.html#aws-glue-api-catalog-partitions-GetPartitions

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toGetPartitions", []))

    @jsii.member(jsii_name="toGetPlan")
    def to_get_plan(self) -> "Glue":
        '''(experimental) Grants permission to retrieve a mapping for a script.

        Access Level: Read

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-etl-script-generation.html#aws-glue-api-etl-script-generation-GetPlan

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toGetPlan", []))

    @jsii.member(jsii_name="toGetRegistry")
    def to_get_registry(self) -> "Glue":
        '''(experimental) Grants permission to retrieve a schema registry.

        Access Level: Read

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-schema-registry-api.html#aws-glue-api-schema-registry-api-GetRegistry

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toGetRegistry", []))

    @jsii.member(jsii_name="toGetResourcePolicies")
    def to_get_resource_policies(self) -> "Glue":
        '''(experimental) Grants permission to retrieve resource policies.

        Access Level: Read

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-jobs-security.html#aws-glue-api-jobs-security-GetResourcePolicies

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toGetResourcePolicies", []))

    @jsii.member(jsii_name="toGetResourcePolicy")
    def to_get_resource_policy(self) -> "Glue":
        '''(experimental) Grants permission to retrieve a resource policy.

        Access Level: Read

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-jobs-security.html#aws-glue-api-jobs-security-GetResourcePolicy

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toGetResourcePolicy", []))

    @jsii.member(jsii_name="toGetSchema")
    def to_get_schema(self) -> "Glue":
        '''(experimental) Grants permission to retrieve a schema container.

        Access Level: Read

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-schema-registry-api.html#aws-glue-api-schema-registry-api-GetSchema

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toGetSchema", []))

    @jsii.member(jsii_name="toGetSchemaByDefinition")
    def to_get_schema_by_definition(self) -> "Glue":
        '''(experimental) Grants permission to retrieve a schema version based on schema definition.

        Access Level: Read

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-schema-registry-api.html#aws-glue-api-schema-registry-api-GetSchemaByDefinition

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toGetSchemaByDefinition", []))

    @jsii.member(jsii_name="toGetSchemaVersion")
    def to_get_schema_version(self) -> "Glue":
        '''(experimental) Grants permission to retrieve a schema version.

        Access Level: Read

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-schema-registry-api.html#aws-glue-api-schema-registry-api-GetSchemaVersion

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toGetSchemaVersion", []))

    @jsii.member(jsii_name="toGetSchemaVersionsDiff")
    def to_get_schema_versions_diff(self) -> "Glue":
        '''(experimental) Grants permission to compare two schema versions in schema registry.

        Access Level: Read

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-schema-registry-api.html#aws-glue-api-schema-registry-api-GetSchemaVersionsDiff

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toGetSchemaVersionsDiff", []))

    @jsii.member(jsii_name="toGetSecurityConfiguration")
    def to_get_security_configuration(self) -> "Glue":
        '''(experimental) Grants permission to retrieve a security configuration.

        Access Level: Read

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-jobs-security.html#aws-glue-api-jobs-security-GetSecurityConfiguration

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toGetSecurityConfiguration", []))

    @jsii.member(jsii_name="toGetSecurityConfigurations")
    def to_get_security_configurations(self) -> "Glue":
        '''(experimental) Grants permission to retrieve one or more security configurations.

        Access Level: Read

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-jobs-security.html#aws-glue-api-jobs-security-GetSecurityConfigurations

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toGetSecurityConfigurations", []))

    @jsii.member(jsii_name="toGetSession")
    def to_get_session(self) -> "Glue":
        '''(experimental) Grants permission to retrieve an interactive session.

        Access Level: Read

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-interactive-sessions.html#aws-glue-interactive-sessions-GetSession

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toGetSession", []))

    @jsii.member(jsii_name="toGetStatement")
    def to_get_statement(self) -> "Glue":
        '''(experimental) Grants permission to retrieve result and information about a statement in an interactive session.

        Access Level: Read

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-interactive-sessions.html#aws-glue-interactive-sessions-GetStatement

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toGetStatement", []))

    @jsii.member(jsii_name="toGetTable")
    def to_get_table(self) -> "Glue":
        '''(experimental) Grants permission to retrieve a table.

        Access Level: Read

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-catalog-tables.html#aws-glue-api-catalog-tables-GetTable

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toGetTable", []))

    @jsii.member(jsii_name="toGetTables")
    def to_get_tables(self) -> "Glue":
        '''(experimental) Grants permission to retrieve the tables in a database.

        Access Level: Read

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-catalog-tables.html#aws-glue-api-catalog-tables-GetTables

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toGetTables", []))

    @jsii.member(jsii_name="toGetTableVersion")
    def to_get_table_version(self) -> "Glue":
        '''(experimental) Grants permission to retrieve a version of a table.

        Access Level: Read

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-catalog-tables.html#aws-glue-api-catalog-tables-GetTableVersion

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toGetTableVersion", []))

    @jsii.member(jsii_name="toGetTableVersions")
    def to_get_table_versions(self) -> "Glue":
        '''(experimental) Grants permission to retrieve a list of versions of a table.

        Access Level: Read

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-catalog-tables.html#aws-glue-api-catalog-tables-GetTableVersions

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toGetTableVersions", []))

    @jsii.member(jsii_name="toGetTags")
    def to_get_tags(self) -> "Glue":
        '''(experimental) Grants permission to retrieve all tags associated with a resource.

        Access Level: Read

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-tags.html#aws-glue-api-tags-UntagResource

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toGetTags", []))

    @jsii.member(jsii_name="toGetTrigger")
    def to_get_trigger(self) -> "Glue":
        '''(experimental) Grants permission to retrieve a trigger.

        Access Level: Read

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-jobs-trigger.html#aws-glue-api-jobs-trigger-GetTrigger

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toGetTrigger", []))

    @jsii.member(jsii_name="toGetTriggers")
    def to_get_triggers(self) -> "Glue":
        '''(experimental) Grants permission to retrieve the triggers associated with a job.

        Access Level: Read

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-jobs-trigger.html#aws-glue-api-jobs-trigger-GetTriggers

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toGetTriggers", []))

    @jsii.member(jsii_name="toGetUserDefinedFunction")
    def to_get_user_defined_function(self) -> "Glue":
        '''(experimental) Grants permission to retrieve a function definition.

        Access Level: Read

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-catalog-functions.html#aws-glue-api-catalog-functions-GetUserDefinedFunction

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toGetUserDefinedFunction", []))

    @jsii.member(jsii_name="toGetUserDefinedFunctions")
    def to_get_user_defined_functions(self) -> "Glue":
        '''(experimental) Grants permission to retrieve multiple function definitions.

        Access Level: Read

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-catalog-functions.html#aws-glue-api-catalog-functions-GetUserDefinedFunctions

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toGetUserDefinedFunctions", []))

    @jsii.member(jsii_name="toGetWorkflow")
    def to_get_workflow(self) -> "Glue":
        '''(experimental) Grants permission to retrieve a workflow.

        Access Level: Read

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-workflow.html#aws-glue-api-workflow-GetWorkflow

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toGetWorkflow", []))

    @jsii.member(jsii_name="toGetWorkflowRun")
    def to_get_workflow_run(self) -> "Glue":
        '''(experimental) Grants permission to retrieve a workflow run.

        Access Level: Read

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-workflow.html#aws-glue-api-workflow-GetWorkflowRun

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toGetWorkflowRun", []))

    @jsii.member(jsii_name="toGetWorkflowRunProperties")
    def to_get_workflow_run_properties(self) -> "Glue":
        '''(experimental) Grants permission to retrieve workflow run properties.

        Access Level: Read

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-workflow.html#aws-glue-api-workflow-GetWorkflowRunProperties

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toGetWorkflowRunProperties", []))

    @jsii.member(jsii_name="toGetWorkflowRuns")
    def to_get_workflow_runs(self) -> "Glue":
        '''(experimental) Grants permission to retrieve all runs of a workflow.

        Access Level: Read

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-workflow.html#aws-glue-api-workflow-GetWorkflowRuns

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toGetWorkflowRuns", []))

    @jsii.member(jsii_name="toGlueNotebookAuthorize")
    def to_glue_notebook_authorize(self) -> "Glue":
        '''(experimental) Grants permission to access Glue Studio Notebooks.

        Access Level: Permissions management

        https://docs.aws.amazon.com/glue/latest/ug/notebook-getting-started.html#create-notebook-permissions-operations

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toGlueNotebookAuthorize", []))

    @jsii.member(jsii_name="toGlueNotebookRefreshCredentials")
    def to_glue_notebook_refresh_credentials(self) -> "Glue":
        '''(experimental) Grants permission to refresh Glue Studio Notebooks credentials.

        Access Level: Permissions management

        https://docs.aws.amazon.com/glue/latest/ug/notebook-getting-started.html#create-notebook-permissions-operations

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toGlueNotebookRefreshCredentials", []))

    @jsii.member(jsii_name="toImportCatalogToGlue")
    def to_import_catalog_to_glue(self) -> "Glue":
        '''(experimental) Grants permission to import an Athena data catalog into AWS Glue.

        Access Level: Write

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-catalog-migration.html#aws-glue-api-catalog-migration-ImportCatalogToGlue

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toImportCatalogToGlue", []))

    @jsii.member(jsii_name="toListBlueprints")
    def to_list_blueprints(self) -> "Glue":
        '''(experimental) Grants permission to retrieve all blueprints.

        Access Level: List

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-workflow.html#aws-glue-api-workflow-ListBlueprints

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toListBlueprints", []))

    @jsii.member(jsii_name="toListCrawlers")
    def to_list_crawlers(self) -> "Glue":
        '''(experimental) Grants permission to retrieve all crawlers.

        Access Level: List

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-crawler-crawling.html#aws-glue-api-crawler-crawling-ListCrawlers

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toListCrawlers", []))

    @jsii.member(jsii_name="toListCrawls")
    def to_list_crawls(self) -> "Glue":
        '''(experimental) Grants permission to retrieve crawl run history for a crawler.

        Access Level: List

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-crawler-crawling.html#aws-glue-api-crawler-crawling-ListCrawls

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toListCrawls", []))

    @jsii.member(jsii_name="toListCustomEntityTypes")
    def to_list_custom_entity_types(self) -> "Glue":
        '''(experimental) Grants permission to retrieve all Custom Entity Types.

        Access Level: List

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-sensitive-data-api.html#aws-glue-api-sensitive-data-api-ListGetCustomEntityTypes

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toListCustomEntityTypes", []))

    @jsii.member(jsii_name="toListDataQualityResults")
    def to_list_data_quality_results(self) -> "Glue":
        '''(experimental) Grants permission to retrieve all Data Quality results.

        Access Level: List

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-data-quality-api.html#aws-glue-api-data-quality-api-ListDataQualityResults

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toListDataQualityResults", []))

    @jsii.member(jsii_name="toListDataQualityRuleRecommendationRuns")
    def to_list_data_quality_rule_recommendation_runs(self) -> "Glue":
        '''(experimental) Grants permission to retrieve all Data Quality rule recommendation runs.

        Access Level: List

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-data-quality-api.html#aws-glue-api-data-quality-api-ListDataQualityRuleRecommendationRuns

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toListDataQualityRuleRecommendationRuns", []))

    @jsii.member(jsii_name="toListDataQualityRulesetEvaluationRuns")
    def to_list_data_quality_ruleset_evaluation_runs(self) -> "Glue":
        '''(experimental) Grants permission to retrieve all Data Quality rule recommendation runs.

        Access Level: List

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-data-quality-api.html#aws-glue-api-data-quality-api-ListDataQualityRulesetEvaluationRuns

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toListDataQualityRulesetEvaluationRuns", []))

    @jsii.member(jsii_name="toListDataQualityRulesets")
    def to_list_data_quality_rulesets(self) -> "Glue":
        '''(experimental) Grants permission to retrieve a list of Data Quality rulesets.

        Access Level: List

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-data-quality-api.html#aws-glue-api-data-quality-api-ListDataQualityRulesets

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toListDataQualityRulesets", []))

    @jsii.member(jsii_name="toListDevEndpoints")
    def to_list_dev_endpoints(self) -> "Glue":
        '''(experimental) Grants permission to retrieve all development endpoints.

        Access Level: List

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-dev-endpoint.html#aws-glue-api-dev-endpoint-ListDevEndpoints

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toListDevEndpoints", []))

    @jsii.member(jsii_name="toListJobs")
    def to_list_jobs(self) -> "Glue":
        '''(experimental) Grants permission to retrieve all current jobs.

        Access Level: List

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-jobs-job.html#aws-glue-api-jobs-job-ListJobs

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toListJobs", []))

    @jsii.member(jsii_name="toListMLTransforms")
    def to_list_ml_transforms(self) -> "Glue":
        '''(experimental) Grants permission to retrieve all ML Transforms.

        Access Level: List

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-machine-learning-api.html#aws-glue-api-machine-learning-api-ListMLTransforms

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toListMLTransforms", []))

    @jsii.member(jsii_name="toListRegistries")
    def to_list_registries(self) -> "Glue":
        '''(experimental) Grants permission to retrieve a list of schema registries.

        Access Level: List

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-schema-registry-api.html#aws-glue-api-schema-registry-api-ListRegistries

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toListRegistries", []))

    @jsii.member(jsii_name="toListSchemas")
    def to_list_schemas(self) -> "Glue":
        '''(experimental) Grants permission to retrieve a list of schema containers.

        Access Level: List

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-schema-registry-api.html#aws-glue-api-schema-registry-api-ListSchemas

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toListSchemas", []))

    @jsii.member(jsii_name="toListSchemaVersions")
    def to_list_schema_versions(self) -> "Glue":
        '''(experimental) Grants permission to retrieve a list of schema versions.

        Access Level: List

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-schema-registry-api.html#aws-glue-api-schema-registry-api-ListSchemaVersions

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toListSchemaVersions", []))

    @jsii.member(jsii_name="toListSessions")
    def to_list_sessions(self) -> "Glue":
        '''(experimental) Grants permission to retrieve a list of interactive session.

        Access Level: List

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-interactive-sessions.html#aws-glue-interactive-sessions-ListSessions

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toListSessions", []))

    @jsii.member(jsii_name="toListStatements")
    def to_list_statements(self) -> "Glue":
        '''(experimental) Grants permission to retrieve a list of statements in an interactive session.

        Access Level: List

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-interactive-sessions.html#aws-glue-interactive-sessions-ListStatements

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toListStatements", []))

    @jsii.member(jsii_name="toListTriggers")
    def to_list_triggers(self) -> "Glue":
        '''(experimental) Grants permission to retrieve all triggers.

        Access Level: List

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-jobs-trigger.html#aws-glue-api-jobs-trigger-ListTriggers

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toListTriggers", []))

    @jsii.member(jsii_name="toListWorkflows")
    def to_list_workflows(self) -> "Glue":
        '''(experimental) Grants permission to retrieve all workflows.

        Access Level: List

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-workflow.html#aws-glue-api-workflow-ListWorkflows

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toListWorkflows", []))

    @jsii.member(jsii_name="toNotifyEvent")
    def to_notify_event(self) -> "Glue":
        '''(experimental) Grants permission to notify an event to the event-driven workflow.

        Access Level: Write

        https://docs.aws.amazon.com/glue/latest/dg/starting-workflow-eventbridge.html

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toNotifyEvent", []))

    @jsii.member(jsii_name="toPublishDataQuality")
    def to_publish_data_quality(self) -> "Glue":
        '''(experimental) Grants permission to publish Data Quality results.

        Access Level: Write

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-data-quality-api.html

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toPublishDataQuality", []))

    @jsii.member(jsii_name="toPutDataCatalogEncryptionSettings")
    def to_put_data_catalog_encryption_settings(self) -> "Glue":
        '''(experimental) Grants permission to update catalog encryption settings.

        Access Level: Write

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-jobs-security.html#aws-glue-api-jobs-security-PutDataCatalogEncryptionSettings

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toPutDataCatalogEncryptionSettings", []))

    @jsii.member(jsii_name="toPutResourcePolicy")
    def to_put_resource_policy(self) -> "Glue":
        '''(experimental) Grants permission to update a resource policy.

        Access Level: Permissions management

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-jobs-security.html#aws-glue-api-jobs-security-PutResourcePolicy

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toPutResourcePolicy", []))

    @jsii.member(jsii_name="toPutSchemaVersionMetadata")
    def to_put_schema_version_metadata(self) -> "Glue":
        '''(experimental) Grants permission to add metadata to schema version.

        Access Level: Write

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-schema-registry-api.html#aws-glue-api-schema-registry-api-PutSchemaVersionMetadata

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toPutSchemaVersionMetadata", []))

    @jsii.member(jsii_name="toPutWorkflowRunProperties")
    def to_put_workflow_run_properties(self) -> "Glue":
        '''(experimental) Grants permission to update workflow run properties.

        Access Level: Write

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-workflow.html#aws-glue-api-workflow-PutWorkflowRunProperties

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toPutWorkflowRunProperties", []))

    @jsii.member(jsii_name="toQuerySchemaVersionMetadata")
    def to_query_schema_version_metadata(self) -> "Glue":
        '''(experimental) Grants permission to fetch metadata for a schema version.

        Access Level: List

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-schema-registry-api.html#aws-glue-api-schema-registry-api-QuerySchemaVersionMetadata

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toQuerySchemaVersionMetadata", []))

    @jsii.member(jsii_name="toRegisterSchemaVersion")
    def to_register_schema_version(self) -> "Glue":
        '''(experimental) Grants permission to create a new schema version.

        Access Level: Write

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-schema-registry-api.html#aws-glue-api-schema-registry-api-RegisterSchemaVersion

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toRegisterSchemaVersion", []))

    @jsii.member(jsii_name="toRemoveSchemaVersionMetadata")
    def to_remove_schema_version_metadata(self) -> "Glue":
        '''(experimental) Grants permission to remove metadata from schema version.

        Access Level: Write

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-schema-registry-api.html#aws-glue-api-schema-registry-api-RemoveSchemaVersionMetadata

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toRemoveSchemaVersionMetadata", []))

    @jsii.member(jsii_name="toResetJobBookmark")
    def to_reset_job_bookmark(self) -> "Glue":
        '''(experimental) Grants permission to reset a job bookmark.

        Access Level: Write

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-jobs-runs.html#aws-glue-api-jobs-runs-ResetJobBookmark

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toResetJobBookmark", []))

    @jsii.member(jsii_name="toResumeWorkflowRun")
    def to_resume_workflow_run(self) -> "Glue":
        '''(experimental) Grants permission to resume a workflow run.

        Access Level: Write

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-workflow.html#aws-glue-api-workflow-ResumeWorkflowRun

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toResumeWorkflowRun", []))

    @jsii.member(jsii_name="toRunStatement")
    def to_run_statement(self) -> "Glue":
        '''(experimental) Grants permission to run a code or statement in an interactive session.

        Access Level: Write

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-interactive-sessions.html#aws-glue-interactive-sessions-RunStatement

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toRunStatement", []))

    @jsii.member(jsii_name="toSearchTables")
    def to_search_tables(self) -> "Glue":
        '''(experimental) Grants permission to retrieve the tables in the catalog.

        Access Level: Read

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-catalog-tables.html#aws-glue-api-catalog-tables-SearchTables

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toSearchTables", []))

    @jsii.member(jsii_name="toStartBlueprintRun")
    def to_start_blueprint_run(self) -> "Glue":
        '''(experimental) Grants permission to start running a blueprint.

        Access Level: Write

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-workflow.html#aws-glue-api-workflow-StartBlueprintRun

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toStartBlueprintRun", []))

    @jsii.member(jsii_name="toStartCrawler")
    def to_start_crawler(self) -> "Glue":
        '''(experimental) Grants permission to start a crawler.

        Access Level: Write

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-crawler-crawling.html#aws-glue-api-crawler-crawling-StartCrawler

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toStartCrawler", []))

    @jsii.member(jsii_name="toStartCrawlerSchedule")
    def to_start_crawler_schedule(self) -> "Glue":
        '''(experimental) Grants permission to change the schedule state of a crawler to SCHEDULED.

        Access Level: Write

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-crawler-scheduler.html#aws-glue-api-crawler-scheduler-StartCrawlerSchedule

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toStartCrawlerSchedule", []))

    @jsii.member(jsii_name="toStartDataQualityRuleRecommendationRun")
    def to_start_data_quality_rule_recommendation_run(self) -> "Glue":
        '''(experimental) Grants permission to start a Data Quality rule recommendation run.

        Access Level: Write

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-data-quality-api.html#aws-glue-api-data-quality-api-StartDataQualityRuleRecommendationRun

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toStartDataQualityRuleRecommendationRun", []))

    @jsii.member(jsii_name="toStartDataQualityRulesetEvaluationRun")
    def to_start_data_quality_ruleset_evaluation_run(self) -> "Glue":
        '''(experimental) Grants permission to start a Data Quality rule recommendation run.

        Access Level: Write

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-data-quality-api.html#aws-glue-api-data-quality-api-StartDataQualityRulesetEvaluationRun

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toStartDataQualityRulesetEvaluationRun", []))

    @jsii.member(jsii_name="toStartExportLabelsTaskRun")
    def to_start_export_labels_task_run(self) -> "Glue":
        '''(experimental) Grants permission to start an Export Labels ML Task Run.

        Access Level: Write

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-machine-learning-api.html#aws-glue-api-machine-learning-api-StartExportLabelsTaskRun

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toStartExportLabelsTaskRun", []))

    @jsii.member(jsii_name="toStartImportLabelsTaskRun")
    def to_start_import_labels_task_run(self) -> "Glue":
        '''(experimental) Grants permission to start an Import Labels ML Task Run.

        Access Level: Write

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-machine-learning-api.html#aws-glue-api-machine-learning-api-StartImportLabelsTaskRun

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toStartImportLabelsTaskRun", []))

    @jsii.member(jsii_name="toStartJobRun")
    def to_start_job_run(self) -> "Glue":
        '''(experimental) Grants permission to start running a job.

        Access Level: Write

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-jobs-runs.html#aws-glue-api-jobs-runs-StartJobRun

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toStartJobRun", []))

    @jsii.member(jsii_name="toStartMLEvaluationTaskRun")
    def to_start_ml_evaluation_task_run(self) -> "Glue":
        '''(experimental) Grants permission to start an Evaluation ML Task Run.

        Access Level: Write

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-machine-learning-api.html#aws-glue-api-machine-learning-api-StartMLEvaluationTaskRun

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toStartMLEvaluationTaskRun", []))

    @jsii.member(jsii_name="toStartMLLabelingSetGenerationTaskRun")
    def to_start_ml_labeling_set_generation_task_run(self) -> "Glue":
        '''(experimental) Grants permission to start a Labeling Set Generation ML Task Run.

        Access Level: Write

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-machine-learning-api.html#aws-glue-api-machine-learning-api-StartMLLabelingSetGenerationTaskRun

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toStartMLLabelingSetGenerationTaskRun", []))

    @jsii.member(jsii_name="toStartNotebook")
    def to_start_notebook(self) -> "Glue":
        '''(experimental) Grants permission to start Glue Studio Notebooks.

        Access Level: Permissions management

        https://docs.aws.amazon.com/glue/latest/ug/notebook-getting-started.html#create-notebook-permissions-operations

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toStartNotebook", []))

    @jsii.member(jsii_name="toStartTrigger")
    def to_start_trigger(self) -> "Glue":
        '''(experimental) Grants permission to start a trigger.

        Access Level: Write

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-jobs-trigger.html#aws-glue-api-jobs-trigger-StartTrigger

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toStartTrigger", []))

    @jsii.member(jsii_name="toStartWorkflowRun")
    def to_start_workflow_run(self) -> "Glue":
        '''(experimental) Grants permission to start running a workflow.

        Access Level: Write

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-workflow.html#aws-glue-api-workflow-StartWorkflowRun

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toStartWorkflowRun", []))

    @jsii.member(jsii_name="toStopCrawler")
    def to_stop_crawler(self) -> "Glue":
        '''(experimental) Grants permission to stop a running crawler.

        Access Level: Write

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-crawler-crawling.html#aws-glue-api-crawler-crawling-StopCrawler

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toStopCrawler", []))

    @jsii.member(jsii_name="toStopCrawlerSchedule")
    def to_stop_crawler_schedule(self) -> "Glue":
        '''(experimental) Grants permission to set the schedule state of a crawler to NOT_SCHEDULED.

        Access Level: Write

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-crawler-scheduler.html#aws-glue-api-crawler-scheduler-StopCrawlerSchedule

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toStopCrawlerSchedule", []))

    @jsii.member(jsii_name="toStopSession")
    def to_stop_session(self) -> "Glue":
        '''(experimental) Grants permission to stop an interactive session.

        Access Level: Write

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-interactive-sessions.html#aws-glue-interactive-sessions-StopSession

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toStopSession", []))

    @jsii.member(jsii_name="toStopTrigger")
    def to_stop_trigger(self) -> "Glue":
        '''(experimental) Grants permission to stop a trigger.

        Access Level: Write

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-jobs-trigger.html#aws-glue-api-jobs-trigger-StopTrigger

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toStopTrigger", []))

    @jsii.member(jsii_name="toStopWorkflowRun")
    def to_stop_workflow_run(self) -> "Glue":
        '''(experimental) Grants permission to stop a workflow run.

        Access Level: Write

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-workflow.html#aws-glue-api-workflow-StopWorkflowRun

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toStopWorkflowRun", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Glue":
        '''(experimental) Grants permission to add tags to a resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-tags.html#aws-glue-api-tags-TagResource

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toTerminateNotebook")
    def to_terminate_notebook(self) -> "Glue":
        '''(experimental) Grants permission to terminate Glue Studio Notebooks.

        Access Level: Permissions management

        https://docs.aws.amazon.com/glue/latest/ug/notebook-getting-started.html#create-notebook-permissions-operations

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toTerminateNotebook", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Glue":
        '''(experimental) Grants permission to remove tags associated with a resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-tags.html#aws-glue-api-tags-UntagResource

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateBlueprint")
    def to_update_blueprint(self) -> "Glue":
        '''(experimental) Grants permission to update a blueprint.

        Access Level: Write

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-workflow.html#aws-glue-api-workflow-UpdateBlueprint

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toUpdateBlueprint", []))

    @jsii.member(jsii_name="toUpdateClassifier")
    def to_update_classifier(self) -> "Glue":
        '''(experimental) Grants permission to update a classifier.

        Access Level: Write

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-crawler-classifiers.html#aws-glue-api-crawler-classifiers-UpdateClassifier

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toUpdateClassifier", []))

    @jsii.member(jsii_name="toUpdateColumnStatisticsForPartition")
    def to_update_column_statistics_for_partition(self) -> "Glue":
        '''(experimental) Grants permission to update partition statistics of columns.

        Access Level: Write

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-catalog-partitions.html#aws-glue-api-catalog-partitions-UpdateColumnStatisticsForPartition

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toUpdateColumnStatisticsForPartition", []))

    @jsii.member(jsii_name="toUpdateColumnStatisticsForTable")
    def to_update_column_statistics_for_table(self) -> "Glue":
        '''(experimental) Grants permission to update table statistics of columns.

        Access Level: Write

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-catalog-tables.html#aws-glue-api-catalog-tables-UpdateColumnStatisticsForTable

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toUpdateColumnStatisticsForTable", []))

    @jsii.member(jsii_name="toUpdateConnection")
    def to_update_connection(self) -> "Glue":
        '''(experimental) Grants permission to update a connection.

        Access Level: Write

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-catalog-connections.html#aws-glue-api-catalog-connections-UpdateConnection

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toUpdateConnection", []))

    @jsii.member(jsii_name="toUpdateCrawler")
    def to_update_crawler(self) -> "Glue":
        '''(experimental) Grants permission to update a crawler.

        Access Level: Write

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-crawler-crawling.html#aws-glue-api-crawler-crawling-UpdateCrawler

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toUpdateCrawler", []))

    @jsii.member(jsii_name="toUpdateCrawlerSchedule")
    def to_update_crawler_schedule(self) -> "Glue":
        '''(experimental) Grants permission to update the schedule of a crawler.

        Access Level: Write

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-crawler-scheduler.html#aws-glue-api-crawler-scheduler-UpdateCrawlerSchedule

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toUpdateCrawlerSchedule", []))

    @jsii.member(jsii_name="toUpdateDatabase")
    def to_update_database(self) -> "Glue":
        '''(experimental) Grants permission to update a database.

        Access Level: Write

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-catalog-databases.html#aws-glue-api-catalog-databases-UpdateDatabase

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toUpdateDatabase", []))

    @jsii.member(jsii_name="toUpdateDataQualityRuleset")
    def to_update_data_quality_ruleset(self) -> "Glue":
        '''(experimental) Grants permission to update a Data Quality ruleset.

        Access Level: Write

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-data-quality-api.html#aws-glue-api-data-quality-api-UpdateDataQualityRuleset

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toUpdateDataQualityRuleset", []))

    @jsii.member(jsii_name="toUpdateDevEndpoint")
    def to_update_dev_endpoint(self) -> "Glue":
        '''(experimental) Grants permission to update a development endpoint.

        Access Level: Write

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-dev-endpoint.html#aws-glue-api-dev-endpoint-UpdateDevEndpoint

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toUpdateDevEndpoint", []))

    @jsii.member(jsii_name="toUpdateJob")
    def to_update_job(self) -> "Glue":
        '''(experimental) Grants permission to update a job.

        Access Level: Write

        Possible conditions:

        - .ifVpcIds()
        - .ifSubnetIds()
        - .ifSecurityGroupIds()

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-jobs-job.html#aws-glue-api-jobs-job-UpdateJob

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toUpdateJob", []))

    @jsii.member(jsii_name="toUpdateMLTransform")
    def to_update_ml_transform(self) -> "Glue":
        '''(experimental) Grants permission to update an ML Transform.

        Access Level: Write

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-machine-learning-api.html#aws-glue-api-machine-learning-api-UpdateMLTransform

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toUpdateMLTransform", []))

    @jsii.member(jsii_name="toUpdatePartition")
    def to_update_partition(self) -> "Glue":
        '''(experimental) Grants permission to update a partition.

        Access Level: Write

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-catalog-partitions.html#aws-glue-api-catalog-partitions-UpdatePartition

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toUpdatePartition", []))

    @jsii.member(jsii_name="toUpdateRegistry")
    def to_update_registry(self) -> "Glue":
        '''(experimental) Grants permission to update a schema registry.

        Access Level: Write

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-schema-registry-api.html#aws-glue-api-schema-registry-api-UpdateRegistry

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toUpdateRegistry", []))

    @jsii.member(jsii_name="toUpdateSchema")
    def to_update_schema(self) -> "Glue":
        '''(experimental) Grants permission to update a schema container.

        Access Level: Write

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-schema-registry-api.html#aws-glue-api-schema-registry-api-UpdateSchema

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toUpdateSchema", []))

    @jsii.member(jsii_name="toUpdateTable")
    def to_update_table(self) -> "Glue":
        '''(experimental) Grants permission to update a table.

        Access Level: Write

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-catalog-tables.html#aws-glue-api-catalog-tables-UpdateTable

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toUpdateTable", []))

    @jsii.member(jsii_name="toUpdateTrigger")
    def to_update_trigger(self) -> "Glue":
        '''(experimental) Grants permission to update a trigger.

        Access Level: Write

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-jobs-trigger.html#aws-glue-api-jobs-trigger-UpdateTrigger

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toUpdateTrigger", []))

    @jsii.member(jsii_name="toUpdateUserDefinedFunction")
    def to_update_user_defined_function(self) -> "Glue":
        '''(experimental) Grants permission to update a function definition.

        Access Level: Write

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-catalog-functions.html#aws-glue-api-catalog-functions-UpdateUserDefinedFunction

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toUpdateUserDefinedFunction", []))

    @jsii.member(jsii_name="toUpdateWorkflow")
    def to_update_workflow(self) -> "Glue":
        '''(experimental) Grants permission to update a workflow.

        Access Level: Write

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-workflow.html#aws-glue-api-workflow-UpdateWorkflow

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toUpdateWorkflow", []))

    @jsii.member(jsii_name="toUseGlueStudio")
    def to_use_glue_studio(self) -> "Glue":
        '''(experimental) Grants permission to use Glue Studio and access its internal APIs.

        Access Level: Permissions management

        https://docs.aws.amazon.com/glue/latest/ug/setting-up.html#getting-started-min-privs

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toUseGlueStudio", []))

    @jsii.member(jsii_name="toUseMLTransforms")
    def to_use_ml_transforms(self) -> "Glue":
        '''(experimental) Grants permission to use an ML Transform from within a Glue ETL Script.

        Access Level: Write

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-machine-learning-api.html

        :stability: experimental
        '''
        return typing.cast("Glue", jsii.invoke(self, "toUseMLTransforms", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__71b36c44d259763bd51bd5ab0610898b6bbcbfe958a9f8f9f836321be841f5f4)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c0d69e162087cbdb0cd97ee85cca3e4be82a3cc3cc4cadf11c21da0e923e2259)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Grafana(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Grafana",
):
    '''(experimental) Statement provider for service `grafana <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonmanagedgrafana.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `grafana <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonmanagedgrafana.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onWorkspace")
    def on_workspace(
        self,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Grafana":
        '''(experimental) Adds a resource of type workspace to the statement.

        https://docs.aws.amazon.com/grafana/latest/userguide/security-iam.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__28c13f99b5a8cc5cdf0e0a1381bd527ea05af7cbbaad53ca00f05723e20d15fe)
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Grafana", jsii.invoke(self, "onWorkspace", [resource_id, account, region, partition]))

    @jsii.member(jsii_name="toAssociateLicense")
    def to_associate_license(self) -> "Grafana":
        '''(experimental) Grants permission to upgrade a workspace with a license.

        Access Level: Write

        Dependent actions:

        - aws-marketplace:ViewSubscriptions

        https://docs.aws.amazon.com/grafana/latest/userguide/AMG-and-IAM.html

        :stability: experimental
        '''
        return typing.cast("Grafana", jsii.invoke(self, "toAssociateLicense", []))

    @jsii.member(jsii_name="toCreateWorkspace")
    def to_create_workspace(self) -> "Grafana":
        '''(experimental) Grants permission to create a workspace.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        Dependent actions:

        - ec2:DescribeSecurityGroups
        - ec2:DescribeSubnets
        - iam:CreateServiceLinkedRole
        - organizations:DescribeOrganization
        - sso:CreateManagedApplicationInstance
        - sso:DescribeRegisteredRegions
        - sso:GetSharedSsoConfiguration

        https://docs.aws.amazon.com/grafana/latest/userguide/AMG-and-IAM.html

        :stability: experimental
        '''
        return typing.cast("Grafana", jsii.invoke(self, "toCreateWorkspace", []))

    @jsii.member(jsii_name="toCreateWorkspaceApiKey")
    def to_create_workspace_api_key(self) -> "Grafana":
        '''(experimental) Grants permission to create API keys for a workspace.

        Access Level: Write

        https://docs.aws.amazon.com/grafana/latest/userguide/AMG-and-IAM.html

        :stability: experimental
        '''
        return typing.cast("Grafana", jsii.invoke(self, "toCreateWorkspaceApiKey", []))

    @jsii.member(jsii_name="toDeleteWorkspace")
    def to_delete_workspace(self) -> "Grafana":
        '''(experimental) Grants permission to delete a workspace.

        Access Level: Write

        Dependent actions:

        - sso:DeleteManagedApplicationInstance

        https://docs.aws.amazon.com/grafana/latest/userguide/AMG-and-IAM.html

        :stability: experimental
        '''
        return typing.cast("Grafana", jsii.invoke(self, "toDeleteWorkspace", []))

    @jsii.member(jsii_name="toDeleteWorkspaceApiKey")
    def to_delete_workspace_api_key(self) -> "Grafana":
        '''(experimental) Grants permission to delete API keys from a workspace.

        Access Level: Write

        https://docs.aws.amazon.com/grafana/latest/userguide/AMG-and-IAM.html

        :stability: experimental
        '''
        return typing.cast("Grafana", jsii.invoke(self, "toDeleteWorkspaceApiKey", []))

    @jsii.member(jsii_name="toDescribeWorkspace")
    def to_describe_workspace(self) -> "Grafana":
        '''(experimental) Grants permission to describe a workspace.

        Access Level: Read

        https://docs.aws.amazon.com/grafana/latest/userguide/AMG-and-IAM.html

        :stability: experimental
        '''
        return typing.cast("Grafana", jsii.invoke(self, "toDescribeWorkspace", []))

    @jsii.member(jsii_name="toDescribeWorkspaceAuthentication")
    def to_describe_workspace_authentication(self) -> "Grafana":
        '''(experimental) Grants permission to describe authentication providers on a workspace.

        Access Level: Read

        https://docs.aws.amazon.com/grafana/latest/userguide/AMG-and-IAM.html

        :stability: experimental
        '''
        return typing.cast("Grafana", jsii.invoke(self, "toDescribeWorkspaceAuthentication", []))

    @jsii.member(jsii_name="toDisassociateLicense")
    def to_disassociate_license(self) -> "Grafana":
        '''(experimental) Grants permission to remove a license from a workspace.

        Access Level: Write

        https://docs.aws.amazon.com/grafana/latest/userguide/AMG-and-IAM.html

        :stability: experimental
        '''
        return typing.cast("Grafana", jsii.invoke(self, "toDisassociateLicense", []))

    @jsii.member(jsii_name="toListPermissions")
    def to_list_permissions(self) -> "Grafana":
        '''(experimental) Grants permission to list the permissions on a wokspace.

        Access Level: List

        https://docs.aws.amazon.com/grafana/latest/userguide/AMG-and-IAM.html

        :stability: experimental
        '''
        return typing.cast("Grafana", jsii.invoke(self, "toListPermissions", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Grafana":
        '''(experimental) Grants permission to list tags associated with a workspace.

        Access Level: Read

        https://docs.aws.amazon.com/grafana/latest/APIReference/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("Grafana", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toListWorkspaces")
    def to_list_workspaces(self) -> "Grafana":
        '''(experimental) Grants permission to list workspaces.

        Access Level: Read

        https://docs.aws.amazon.com/grafana/latest/userguide/AMG-and-IAM.html

        :stability: experimental
        '''
        return typing.cast("Grafana", jsii.invoke(self, "toListWorkspaces", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Grafana":
        '''(experimental) Grants permission to add tags to, or update tag values of, a workspace.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/grafana/latest/APIReference/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("Grafana", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Grafana":
        '''(experimental) Grants permission to remove tags from a workspace.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/grafana/latest/APIReference/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("Grafana", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdatePermissions")
    def to_update_permissions(self) -> "Grafana":
        '''(experimental) Grants permission to modify the permissions on a workspace.

        Access Level: Permissions management

        https://docs.aws.amazon.com/grafana/latest/userguide/AMG-and-IAM.html

        :stability: experimental
        '''
        return typing.cast("Grafana", jsii.invoke(self, "toUpdatePermissions", []))

    @jsii.member(jsii_name="toUpdateWorkspace")
    def to_update_workspace(self) -> "Grafana":
        '''(experimental) Grants permission to modify a workspace.

        Access Level: Write

        Dependent actions:

        - ec2:DescribeSecurityGroups
        - ec2:DescribeSubnets
        - iam:CreateServiceLinkedRole

        https://docs.aws.amazon.com/grafana/latest/userguide/AMG-and-IAM.html

        :stability: experimental
        '''
        return typing.cast("Grafana", jsii.invoke(self, "toUpdateWorkspace", []))

    @jsii.member(jsii_name="toUpdateWorkspaceAuthentication")
    def to_update_workspace_authentication(self) -> "Grafana":
        '''(experimental) Grants permission to modify authentication providers on a workspace.

        Access Level: Write

        https://docs.aws.amazon.com/grafana/latest/userguide/AMG-and-IAM.html

        :stability: experimental
        '''
        return typing.cast("Grafana", jsii.invoke(self, "toUpdateWorkspaceAuthentication", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__92e4ca72b77dcdcd4d7d2be023278985a148df8b62387694891a2f5b25c809e9)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c67dd6684581e17f7c4b5ec4de32dc6f4799098042b28c48e41dae1551f588b7)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Greengrass(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Greengrass",
):
    '''(experimental) Statement provider for service `greengrass <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiotgreengrass.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `greengrass <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiotgreengrass.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onBulkDeployment")
    def on_bulk_deployment(
        self,
        bulk_deployment_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Greengrass":
        '''(experimental) Adds a resource of type bulkDeployment to the statement.

        https://docs.aws.amazon.com/greengrass/latest/developerguide/bulk-deploy-cli.html

        :param bulk_deployment_id: - Identifier for the bulkDeploymentId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__12afa0afbf9c76e91fc9a7118b95a89f354aefdb3645caef745ea272f314b38f)
            check_type(argname="argument bulk_deployment_id", value=bulk_deployment_id, expected_type=type_hints["bulk_deployment_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Greengrass", jsii.invoke(self, "onBulkDeployment", [bulk_deployment_id, account, region, partition]))

    @jsii.member(jsii_name="onCertificateAuthority")
    def on_certificate_authority(
        self,
        group_id: builtins.str,
        certificate_authority_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Greengrass":
        '''(experimental) Adds a resource of type certificateAuthority to the statement.

        https://docs.aws.amazon.com/greengrass/latest/developerguide/gg-sec.html

        :param group_id: - Identifier for the groupId.
        :param certificate_authority_id: - Identifier for the certificateAuthorityId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c768cf9f733731bd1fca8599d602dc826b401a39abdd595f3ffcaa2a41a5dfb5)
            check_type(argname="argument group_id", value=group_id, expected_type=type_hints["group_id"])
            check_type(argname="argument certificate_authority_id", value=certificate_authority_id, expected_type=type_hints["certificate_authority_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Greengrass", jsii.invoke(self, "onCertificateAuthority", [group_id, certificate_authority_id, account, region, partition]))

    @jsii.member(jsii_name="onConnectivityInfo")
    def on_connectivity_info(
        self,
        thing_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Greengrass":
        '''(experimental) Adds a resource of type connectivityInfo to the statement.

        https://docs.aws.amazon.com/greengrass/latest/apireference/definitions-connectivityinfo.html

        :param thing_name: - Identifier for the thingName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__901edd8cb8f2020bba2e3b9c01a555523c2568c2665f36b50778bcd681cce7c6)
            check_type(argname="argument thing_name", value=thing_name, expected_type=type_hints["thing_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Greengrass", jsii.invoke(self, "onConnectivityInfo", [thing_name, account, region, partition]))

    @jsii.member(jsii_name="onConnectorDefinition")
    def on_connector_definition(
        self,
        connector_definition_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Greengrass":
        '''(experimental) Adds a resource of type connectorDefinition to the statement.

        https://docs.aws.amazon.com/greengrass/latest/apireference/definitions-connector.html

        :param connector_definition_id: - Identifier for the connectorDefinitionId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5fd074d70b114abbaeea4bb9cb2f1d249e3a5df393559e331453352b6e7dd5f3)
            check_type(argname="argument connector_definition_id", value=connector_definition_id, expected_type=type_hints["connector_definition_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Greengrass", jsii.invoke(self, "onConnectorDefinition", [connector_definition_id, account, region, partition]))

    @jsii.member(jsii_name="onConnectorDefinitionVersion")
    def on_connector_definition_version(
        self,
        connector_definition_id: builtins.str,
        version_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Greengrass":
        '''(experimental) Adds a resource of type connectorDefinitionVersion to the statement.

        https://docs.aws.amazon.com/greengrass/latest/apireference/definitions-connectordefinitionversion.html

        :param connector_definition_id: - Identifier for the connectorDefinitionId.
        :param version_id: - Identifier for the versionId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7a132b47b48c4bdca7a9c224fc0ec5ba450282b53e40c9e2746dc28d5b667a14)
            check_type(argname="argument connector_definition_id", value=connector_definition_id, expected_type=type_hints["connector_definition_id"])
            check_type(argname="argument version_id", value=version_id, expected_type=type_hints["version_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Greengrass", jsii.invoke(self, "onConnectorDefinitionVersion", [connector_definition_id, version_id, account, region, partition]))

    @jsii.member(jsii_name="onCoreDefinition")
    def on_core_definition(
        self,
        core_definition_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Greengrass":
        '''(experimental) Adds a resource of type coreDefinition to the statement.

        https://docs.aws.amazon.com/greengrass/latest/apireference/definitions-core.html

        :param core_definition_id: - Identifier for the coreDefinitionId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4a500d1d6093e9c3ab9517e5c67f018117572a9e6d9b573c55a8c3467441f358)
            check_type(argname="argument core_definition_id", value=core_definition_id, expected_type=type_hints["core_definition_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Greengrass", jsii.invoke(self, "onCoreDefinition", [core_definition_id, account, region, partition]))

    @jsii.member(jsii_name="onCoreDefinitionVersion")
    def on_core_definition_version(
        self,
        core_definition_id: builtins.str,
        version_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Greengrass":
        '''(experimental) Adds a resource of type coreDefinitionVersion to the statement.

        https://docs.aws.amazon.com/greengrass/latest/apireference/definitions-coredefinitionversion.html

        :param core_definition_id: - Identifier for the coreDefinitionId.
        :param version_id: - Identifier for the versionId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0481831d3ede6b739deef95fbb451662f03f842f449fd213b934535b24ced152)
            check_type(argname="argument core_definition_id", value=core_definition_id, expected_type=type_hints["core_definition_id"])
            check_type(argname="argument version_id", value=version_id, expected_type=type_hints["version_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Greengrass", jsii.invoke(self, "onCoreDefinitionVersion", [core_definition_id, version_id, account, region, partition]))

    @jsii.member(jsii_name="onDeployment")
    def on_deployment(
        self,
        group_id: builtins.str,
        deployment_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Greengrass":
        '''(experimental) Adds a resource of type deployment to the statement.

        https://docs.aws.amazon.com/greengrass/latest/apireference/definitions-createdeploymentrequest.html

        :param group_id: - Identifier for the groupId.
        :param deployment_id: - Identifier for the deploymentId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__294b73d1aa15ee0dbf213d60e28889c0b01d749b58efd1cfb237e476c0bf9741)
            check_type(argname="argument group_id", value=group_id, expected_type=type_hints["group_id"])
            check_type(argname="argument deployment_id", value=deployment_id, expected_type=type_hints["deployment_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Greengrass", jsii.invoke(self, "onDeployment", [group_id, deployment_id, account, region, partition]))

    @jsii.member(jsii_name="onDeviceDefinition")
    def on_device_definition(
        self,
        device_definition_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Greengrass":
        '''(experimental) Adds a resource of type deviceDefinition to the statement.

        https://docs.aws.amazon.com/greengrass/latest/apireference/definitions-device.html

        :param device_definition_id: - Identifier for the deviceDefinitionId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ae92cbc469a6d7034595efc2c22212f7a5f4d69f8ae75e5380c5fe69c43f6ca0)
            check_type(argname="argument device_definition_id", value=device_definition_id, expected_type=type_hints["device_definition_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Greengrass", jsii.invoke(self, "onDeviceDefinition", [device_definition_id, account, region, partition]))

    @jsii.member(jsii_name="onDeviceDefinitionVersion")
    def on_device_definition_version(
        self,
        device_definition_id: builtins.str,
        version_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Greengrass":
        '''(experimental) Adds a resource of type deviceDefinitionVersion to the statement.

        https://docs.aws.amazon.com/greengrass/latest/apireference/definitions-devicedefinitionversion.html

        :param device_definition_id: - Identifier for the deviceDefinitionId.
        :param version_id: - Identifier for the versionId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1ed5d0d9b8ea84a5da1dde288fed180e307c50ab0cae19a21260c9bc1453f7d3)
            check_type(argname="argument device_definition_id", value=device_definition_id, expected_type=type_hints["device_definition_id"])
            check_type(argname="argument version_id", value=version_id, expected_type=type_hints["version_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Greengrass", jsii.invoke(self, "onDeviceDefinitionVersion", [device_definition_id, version_id, account, region, partition]))

    @jsii.member(jsii_name="onFunctionDefinition")
    def on_function_definition(
        self,
        function_definition_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Greengrass":
        '''(experimental) Adds a resource of type functionDefinition to the statement.

        https://docs.aws.amazon.com/greengrass/latest/apireference/definitions-function.html

        :param function_definition_id: - Identifier for the functionDefinitionId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__48b1e4090d70d753241e7127ed2eb9b9ede14ab9b3f48710de169636bdbb4489)
            check_type(argname="argument function_definition_id", value=function_definition_id, expected_type=type_hints["function_definition_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Greengrass", jsii.invoke(self, "onFunctionDefinition", [function_definition_id, account, region, partition]))

    @jsii.member(jsii_name="onFunctionDefinitionVersion")
    def on_function_definition_version(
        self,
        function_definition_id: builtins.str,
        version_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Greengrass":
        '''(experimental) Adds a resource of type functionDefinitionVersion to the statement.

        https://docs.aws.amazon.com/greengrass/latest/apireference/definitions-functiondefinitionversion.html

        :param function_definition_id: - Identifier for the functionDefinitionId.
        :param version_id: - Identifier for the versionId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8947a2ca38435ac5830cc4a751e6100915d813f7b0a4052cf8480cd89fd7f2a1)
            check_type(argname="argument function_definition_id", value=function_definition_id, expected_type=type_hints["function_definition_id"])
            check_type(argname="argument version_id", value=version_id, expected_type=type_hints["version_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Greengrass", jsii.invoke(self, "onFunctionDefinitionVersion", [function_definition_id, version_id, account, region, partition]))

    @jsii.member(jsii_name="onGroup")
    def on_group(
        self,
        group_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Greengrass":
        '''(experimental) Adds a resource of type group to the statement.

        https://docs.aws.amazon.com/greengrass/latest/apireference/definitions-groupinformation.html

        :param group_id: - Identifier for the groupId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d58b9374b01f08bd9a9321e8af2956818fe4bb2d7a446917a7fc0e5ec18ae481)
            check_type(argname="argument group_id", value=group_id, expected_type=type_hints["group_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Greengrass", jsii.invoke(self, "onGroup", [group_id, account, region, partition]))

    @jsii.member(jsii_name="onGroupVersion")
    def on_group_version(
        self,
        group_id: builtins.str,
        version_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Greengrass":
        '''(experimental) Adds a resource of type groupVersion to the statement.

        https://docs.aws.amazon.com/greengrass/latest/apireference/definitions-groupversion.html

        :param group_id: - Identifier for the groupId.
        :param version_id: - Identifier for the versionId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__19d63a4d18ac101242a0403b540b37399fe273ababe2ffb634aac5a1ddc255f3)
            check_type(argname="argument group_id", value=group_id, expected_type=type_hints["group_id"])
            check_type(argname="argument version_id", value=version_id, expected_type=type_hints["version_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Greengrass", jsii.invoke(self, "onGroupVersion", [group_id, version_id, account, region, partition]))

    @jsii.member(jsii_name="onLoggerDefinition")
    def on_logger_definition(
        self,
        logger_definition_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Greengrass":
        '''(experimental) Adds a resource of type loggerDefinition to the statement.

        https://docs.aws.amazon.com/greengrass/latest/apireference/definitions-logger.html

        :param logger_definition_id: - Identifier for the loggerDefinitionId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0bb74cdfc337fc3b536a7a2b7056b3d2a7cdea0d93858307153ba1f9d71e218e)
            check_type(argname="argument logger_definition_id", value=logger_definition_id, expected_type=type_hints["logger_definition_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Greengrass", jsii.invoke(self, "onLoggerDefinition", [logger_definition_id, account, region, partition]))

    @jsii.member(jsii_name="onLoggerDefinitionVersion")
    def on_logger_definition_version(
        self,
        logger_definition_id: builtins.str,
        version_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Greengrass":
        '''(experimental) Adds a resource of type loggerDefinitionVersion to the statement.

        https://docs.aws.amazon.com/greengrass/latest/apireference/definitions-loggerdefinitionversion.html

        :param logger_definition_id: - Identifier for the loggerDefinitionId.
        :param version_id: - Identifier for the versionId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bcbf6de500691d506ad4d20dd88d13cde40ba5590709a8baa16c7b4108c0b588)
            check_type(argname="argument logger_definition_id", value=logger_definition_id, expected_type=type_hints["logger_definition_id"])
            check_type(argname="argument version_id", value=version_id, expected_type=type_hints["version_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Greengrass", jsii.invoke(self, "onLoggerDefinitionVersion", [logger_definition_id, version_id, account, region, partition]))

    @jsii.member(jsii_name="onResourceDefinition")
    def on_resource_definition(
        self,
        resource_definition_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Greengrass":
        '''(experimental) Adds a resource of type resourceDefinition to the statement.

        https://docs.aws.amazon.com/greengrass/latest/apireference/definitions-resource.html

        :param resource_definition_id: - Identifier for the resourceDefinitionId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__be0a202fe121bbc7f3c9efea5765393e4b6c034ca0974713f9b3aeb454200f67)
            check_type(argname="argument resource_definition_id", value=resource_definition_id, expected_type=type_hints["resource_definition_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Greengrass", jsii.invoke(self, "onResourceDefinition", [resource_definition_id, account, region, partition]))

    @jsii.member(jsii_name="onResourceDefinitionVersion")
    def on_resource_definition_version(
        self,
        resource_definition_id: builtins.str,
        version_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Greengrass":
        '''(experimental) Adds a resource of type resourceDefinitionVersion to the statement.

        https://docs.aws.amazon.com/greengrass/latest/apireference/definitions-resourcedefinitionversion.html

        :param resource_definition_id: - Identifier for the resourceDefinitionId.
        :param version_id: - Identifier for the versionId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__da6da26cfcffdcdfd1466b98c7124f0a94ffc6bcc0a8d70152e61edbc9fa8166)
            check_type(argname="argument resource_definition_id", value=resource_definition_id, expected_type=type_hints["resource_definition_id"])
            check_type(argname="argument version_id", value=version_id, expected_type=type_hints["version_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Greengrass", jsii.invoke(self, "onResourceDefinitionVersion", [resource_definition_id, version_id, account, region, partition]))

    @jsii.member(jsii_name="onSubscriptionDefinition")
    def on_subscription_definition(
        self,
        subscription_definition_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Greengrass":
        '''(experimental) Adds a resource of type subscriptionDefinition to the statement.

        https://docs.aws.amazon.com/greengrass/latest/apireference/definitions-subscription.html

        :param subscription_definition_id: - Identifier for the subscriptionDefinitionId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__401afc84b94f9d31b20a3592e725b4dcded8d0e1638eda0dc2bc23b483c9392f)
            check_type(argname="argument subscription_definition_id", value=subscription_definition_id, expected_type=type_hints["subscription_definition_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Greengrass", jsii.invoke(self, "onSubscriptionDefinition", [subscription_definition_id, account, region, partition]))

    @jsii.member(jsii_name="onSubscriptionDefinitionVersion")
    def on_subscription_definition_version(
        self,
        subscription_definition_id: builtins.str,
        version_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Greengrass":
        '''(experimental) Adds a resource of type subscriptionDefinitionVersion to the statement.

        https://docs.aws.amazon.com/greengrass/latest/apireference/definitions-subscriptiondefinitionversion.html

        :param subscription_definition_id: - Identifier for the subscriptionDefinitionId.
        :param version_id: - Identifier for the versionId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__09c0a1c4565f843089dd0abb0d4415eb3b3ab0b8d77057f480a4ae9f8086abb7)
            check_type(argname="argument subscription_definition_id", value=subscription_definition_id, expected_type=type_hints["subscription_definition_id"])
            check_type(argname="argument version_id", value=version_id, expected_type=type_hints["version_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Greengrass", jsii.invoke(self, "onSubscriptionDefinitionVersion", [subscription_definition_id, version_id, account, region, partition]))

    @jsii.member(jsii_name="onThing")
    def on_thing(
        self,
        thing_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Greengrass":
        '''(experimental) Adds a resource of type thing to the statement.

        https://docs.aws.amazon.com/iot/latest/developerguide/thing-registry.html

        :param thing_name: - Identifier for the thingName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__20af4c7e7afc59c436610edcc1f56ce05aebce0b698730b23ee9fad6f870d482)
            check_type(argname="argument thing_name", value=thing_name, expected_type=type_hints["thing_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Greengrass", jsii.invoke(self, "onThing", [thing_name, account, region, partition]))

    @jsii.member(jsii_name="onThingRuntimeConfig")
    def on_thing_runtime_config(
        self,
        thing_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Greengrass":
        '''(experimental) Adds a resource of type thingRuntimeConfig to the statement.

        https://docs.aws.amazon.com/iot/latest/developerguide/thing-registry.html

        :param thing_name: - Identifier for the thingName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b81488801f146991ae8ee67bc46c2fb4ff8824aa227fe8e9166ab0c87f7cd850)
            check_type(argname="argument thing_name", value=thing_name, expected_type=type_hints["thing_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Greengrass", jsii.invoke(self, "onThingRuntimeConfig", [thing_name, account, region, partition]))

    @jsii.member(jsii_name="toAssociateRoleToGroup")
    def to_associate_role_to_group(self) -> "Greengrass":
        '''(experimental) Grants permission to associate a role with a group.

        The role's permissions must allow Greengrass core Lambda functions and connectors to perform actions in other AWS services

        Access Level: Write

        https://docs.aws.amazon.com/greengrass/latest/apireference/associateroletogroup-put.html

        :stability: experimental
        '''
        return typing.cast("Greengrass", jsii.invoke(self, "toAssociateRoleToGroup", []))

    @jsii.member(jsii_name="toAssociateServiceRoleToAccount")
    def to_associate_service_role_to_account(self) -> "Greengrass":
        '''(experimental) Grants permission to associate a role with your account.

        AWS IoT Greengrass uses this role to access your Lambda functions and AWS IoT resources

        Access Level: Permissions management

        https://docs.aws.amazon.com/greengrass/latest/apireference/associateserviceroletoaccount-put.html

        :stability: experimental
        '''
        return typing.cast("Greengrass", jsii.invoke(self, "toAssociateServiceRoleToAccount", []))

    @jsii.member(jsii_name="toCreateConnectorDefinition")
    def to_create_connector_definition(self) -> "Greengrass":
        '''(experimental) Grants permission to create a connector definition.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/greengrass/latest/apireference/createconnectordefinition-post.html

        :stability: experimental
        '''
        return typing.cast("Greengrass", jsii.invoke(self, "toCreateConnectorDefinition", []))

    @jsii.member(jsii_name="toCreateConnectorDefinitionVersion")
    def to_create_connector_definition_version(self) -> "Greengrass":
        '''(experimental) Grants permission to create a version of an existing connector definition.

        Access Level: Write

        https://docs.aws.amazon.com/greengrass/latest/apireference/createconnectordefinitionversion-post.html

        :stability: experimental
        '''
        return typing.cast("Greengrass", jsii.invoke(self, "toCreateConnectorDefinitionVersion", []))

    @jsii.member(jsii_name="toCreateCoreDefinition")
    def to_create_core_definition(self) -> "Greengrass":
        '''(experimental) Grants permission to create a core definition.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/greengrass/latest/apireference/createcoredefinition-post.html

        :stability: experimental
        '''
        return typing.cast("Greengrass", jsii.invoke(self, "toCreateCoreDefinition", []))

    @jsii.member(jsii_name="toCreateCoreDefinitionVersion")
    def to_create_core_definition_version(self) -> "Greengrass":
        '''(experimental) Grants permission to create a version of an existing core definition.

        Greengrass groups must each contain exactly one Greengrass core

        Access Level: Write

        https://docs.aws.amazon.com/greengrass/latest/apireference/createcoredefinitionversion-post.html

        :stability: experimental
        '''
        return typing.cast("Greengrass", jsii.invoke(self, "toCreateCoreDefinitionVersion", []))

    @jsii.member(jsii_name="toCreateDeployment")
    def to_create_deployment(self) -> "Greengrass":
        '''(experimental) Grants permission to create a deployment.

        Access Level: Write

        https://docs.aws.amazon.com/greengrass/latest/apireference/createdeployment-post.html

        :stability: experimental
        '''
        return typing.cast("Greengrass", jsii.invoke(self, "toCreateDeployment", []))

    @jsii.member(jsii_name="toCreateDeviceDefinition")
    def to_create_device_definition(self) -> "Greengrass":
        '''(experimental) Grants permission to create a device definition.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/greengrass/latest/apireference/createdevicedefinition-post.html

        :stability: experimental
        '''
        return typing.cast("Greengrass", jsii.invoke(self, "toCreateDeviceDefinition", []))

    @jsii.member(jsii_name="toCreateDeviceDefinitionVersion")
    def to_create_device_definition_version(self) -> "Greengrass":
        '''(experimental) Grants permission to create a version of an existing device definition.

        Access Level: Write

        https://docs.aws.amazon.com/greengrass/latest/apireference/createdevicedefinitionversion-post.html

        :stability: experimental
        '''
        return typing.cast("Greengrass", jsii.invoke(self, "toCreateDeviceDefinitionVersion", []))

    @jsii.member(jsii_name="toCreateFunctionDefinition")
    def to_create_function_definition(self) -> "Greengrass":
        '''(experimental) Grants permission to create a Lambda function definition to be used in a group that contains a list of Lambda functions and their configurations.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/greengrass/latest/apireference/createfunctiondefinition-post.html

        :stability: experimental
        '''
        return typing.cast("Greengrass", jsii.invoke(self, "toCreateFunctionDefinition", []))

    @jsii.member(jsii_name="toCreateFunctionDefinitionVersion")
    def to_create_function_definition_version(self) -> "Greengrass":
        '''(experimental) Grants permission to create a version of an existing Lambda function definition.

        Access Level: Write

        https://docs.aws.amazon.com/greengrass/latest/apireference/createfunctiondefinitionversion-post.html

        :stability: experimental
        '''
        return typing.cast("Greengrass", jsii.invoke(self, "toCreateFunctionDefinitionVersion", []))

    @jsii.member(jsii_name="toCreateGroup")
    def to_create_group(self) -> "Greengrass":
        '''(experimental) Grants permission to create a group.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/greengrass/latest/apireference/creategroup-post.html

        :stability: experimental
        '''
        return typing.cast("Greengrass", jsii.invoke(self, "toCreateGroup", []))

    @jsii.member(jsii_name="toCreateGroupCertificateAuthority")
    def to_create_group_certificate_authority(self) -> "Greengrass":
        '''(experimental) Grants permission to create a CA for the group, or rotate the existing CA.

        Access Level: Write

        https://docs.aws.amazon.com/greengrass/latest/apireference/creategroupcertificateauthority-post.html

        :stability: experimental
        '''
        return typing.cast("Greengrass", jsii.invoke(self, "toCreateGroupCertificateAuthority", []))

    @jsii.member(jsii_name="toCreateGroupVersion")
    def to_create_group_version(self) -> "Greengrass":
        '''(experimental) Grants permission to create a version of a group that has already been defined.

        Access Level: Write

        https://docs.aws.amazon.com/greengrass/latest/apireference/creategroupversion-post.html

        :stability: experimental
        '''
        return typing.cast("Greengrass", jsii.invoke(self, "toCreateGroupVersion", []))

    @jsii.member(jsii_name="toCreateLoggerDefinition")
    def to_create_logger_definition(self) -> "Greengrass":
        '''(experimental) Grants permission to create a logger definition.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/greengrass/latest/apireference/createloggerdefinition-post.html

        :stability: experimental
        '''
        return typing.cast("Greengrass", jsii.invoke(self, "toCreateLoggerDefinition", []))

    @jsii.member(jsii_name="toCreateLoggerDefinitionVersion")
    def to_create_logger_definition_version(self) -> "Greengrass":
        '''(experimental) Grants permission to create a version of an existing logger definition.

        Access Level: Write

        https://docs.aws.amazon.com/greengrass/latest/apireference/createloggerdefinitionversion-post.html

        :stability: experimental
        '''
        return typing.cast("Greengrass", jsii.invoke(self, "toCreateLoggerDefinitionVersion", []))

    @jsii.member(jsii_name="toCreateResourceDefinition")
    def to_create_resource_definition(self) -> "Greengrass":
        '''(experimental) Grants permission to create a resource definition that contains a list of resources to be used in a group.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/greengrass/latest/apireference/createresourcedefinition-post.html

        :stability: experimental
        '''
        return typing.cast("Greengrass", jsii.invoke(self, "toCreateResourceDefinition", []))

    @jsii.member(jsii_name="toCreateResourceDefinitionVersion")
    def to_create_resource_definition_version(self) -> "Greengrass":
        '''(experimental) Grants permission to create a version of an existing resource definition.

        Access Level: Write

        https://docs.aws.amazon.com/greengrass/latest/apireference/createresourcedefinitionversion-post.html

        :stability: experimental
        '''
        return typing.cast("Greengrass", jsii.invoke(self, "toCreateResourceDefinitionVersion", []))

    @jsii.member(jsii_name="toCreateSoftwareUpdateJob")
    def to_create_software_update_job(self) -> "Greengrass":
        '''(experimental) Grants permission to create an AWS IoT job that will trigger your Greengrass cores to update the software they are running.

        Access Level: Write

        https://docs.aws.amazon.com/greengrass/latest/apireference/createsoftwareupdatejob-post.html

        :stability: experimental
        '''
        return typing.cast("Greengrass", jsii.invoke(self, "toCreateSoftwareUpdateJob", []))

    @jsii.member(jsii_name="toCreateSubscriptionDefinition")
    def to_create_subscription_definition(self) -> "Greengrass":
        '''(experimental) Grants permission to create a subscription definition.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/greengrass/latest/apireference/createsubscriptiondefinition-post.html

        :stability: experimental
        '''
        return typing.cast("Greengrass", jsii.invoke(self, "toCreateSubscriptionDefinition", []))

    @jsii.member(jsii_name="toCreateSubscriptionDefinitionVersion")
    def to_create_subscription_definition_version(self) -> "Greengrass":
        '''(experimental) Grants permission to create a version of an existing subscription definition.

        Access Level: Write

        https://docs.aws.amazon.com/greengrass/latest/apireference/createsubscriptiondefinitionversion-post.html

        :stability: experimental
        '''
        return typing.cast("Greengrass", jsii.invoke(self, "toCreateSubscriptionDefinitionVersion", []))

    @jsii.member(jsii_name="toDeleteConnectorDefinition")
    def to_delete_connector_definition(self) -> "Greengrass":
        '''(experimental) Grants permission to delete a connector definition.

        Access Level: Write

        https://docs.aws.amazon.com/greengrass/latest/apireference/deleteconnectordefinition-delete.html

        :stability: experimental
        '''
        return typing.cast("Greengrass", jsii.invoke(self, "toDeleteConnectorDefinition", []))

    @jsii.member(jsii_name="toDeleteCoreDefinition")
    def to_delete_core_definition(self) -> "Greengrass":
        '''(experimental) Grants permission to delete a core definition.

        Deleting a definition that is currently in use in a deployment affects future deployments

        Access Level: Write

        https://docs.aws.amazon.com/greengrass/latest/apireference/deletecoredefinition-delete.html

        :stability: experimental
        '''
        return typing.cast("Greengrass", jsii.invoke(self, "toDeleteCoreDefinition", []))

    @jsii.member(jsii_name="toDeleteDeviceDefinition")
    def to_delete_device_definition(self) -> "Greengrass":
        '''(experimental) Grants permission to delete a device definition.

        Deleting a definition that is currently in use in a deployment affects future deployments

        Access Level: Write

        https://docs.aws.amazon.com/greengrass/latest/apireference/deletedevicedefinition-delete.html

        :stability: experimental
        '''
        return typing.cast("Greengrass", jsii.invoke(self, "toDeleteDeviceDefinition", []))

    @jsii.member(jsii_name="toDeleteFunctionDefinition")
    def to_delete_function_definition(self) -> "Greengrass":
        '''(experimental) Grants permission to delete a Lambda function definition.

        Deleting a definition that is currently in use in a deployment affects future deployments

        Access Level: Write

        https://docs.aws.amazon.com/greengrass/latest/apireference/deletefunctiondefinition-delete.html

        :stability: experimental
        '''
        return typing.cast("Greengrass", jsii.invoke(self, "toDeleteFunctionDefinition", []))

    @jsii.member(jsii_name="toDeleteGroup")
    def to_delete_group(self) -> "Greengrass":
        '''(experimental) Grants permission to delete a group that is not currently in use in a deployment.

        Access Level: Write

        https://docs.aws.amazon.com/greengrass/latest/apireference/deletegroup-delete.html

        :stability: experimental
        '''
        return typing.cast("Greengrass", jsii.invoke(self, "toDeleteGroup", []))

    @jsii.member(jsii_name="toDeleteLoggerDefinition")
    def to_delete_logger_definition(self) -> "Greengrass":
        '''(experimental) Grants permission to delete a logger definition.

        Deleting a definition that is currently in use in a deployment affects future deployments

        Access Level: Write

        https://docs.aws.amazon.com/greengrass/latest/apireference/deleteloggerdefinition-delete.html

        :stability: experimental
        '''
        return typing.cast("Greengrass", jsii.invoke(self, "toDeleteLoggerDefinition", []))

    @jsii.member(jsii_name="toDeleteResourceDefinition")
    def to_delete_resource_definition(self) -> "Greengrass":
        '''(experimental) Grants permission to delete a resource definition.

        Access Level: Write

        https://docs.aws.amazon.com/greengrass/latest/apireference/deleteresourcedefinition-delete.html

        :stability: experimental
        '''
        return typing.cast("Greengrass", jsii.invoke(self, "toDeleteResourceDefinition", []))

    @jsii.member(jsii_name="toDeleteSubscriptionDefinition")
    def to_delete_subscription_definition(self) -> "Greengrass":
        '''(experimental) Grants permission to delete a subscription definition.

        Deleting a definition that is currently in use in a deployment affects future deployments

        Access Level: Write

        https://docs.aws.amazon.com/greengrass/latest/apireference/deletesubscriptiondefinition-delete.html

        :stability: experimental
        '''
        return typing.cast("Greengrass", jsii.invoke(self, "toDeleteSubscriptionDefinition", []))

    @jsii.member(jsii_name="toDisassociateRoleFromGroup")
    def to_disassociate_role_from_group(self) -> "Greengrass":
        '''(experimental) Grants permission to disassociate the role from a group.

        Access Level: Write

        https://docs.aws.amazon.com/greengrass/latest/apireference/disassociaterolefromgroup-delete.html

        :stability: experimental
        '''
        return typing.cast("Greengrass", jsii.invoke(self, "toDisassociateRoleFromGroup", []))

    @jsii.member(jsii_name="toDisassociateServiceRoleFromAccount")
    def to_disassociate_service_role_from_account(self) -> "Greengrass":
        '''(experimental) Grants permission to disassociate the service role from an account. Without a service role, deployments will not work.

        Access Level: Write

        https://docs.aws.amazon.com/greengrass/latest/apireference/disassociateservicerolefromaccount-delete.html

        :stability: experimental
        '''
        return typing.cast("Greengrass", jsii.invoke(self, "toDisassociateServiceRoleFromAccount", []))

    @jsii.member(jsii_name="toDiscover")
    def to_discover(self) -> "Greengrass":
        '''(experimental) Grants permission to retrieve information required to connect to a Greengrass core.

        Access Level: Read

        https://docs.aws.amazon.com/greengrass/latest/developerguide/gg-discover-api.html

        :stability: experimental
        '''
        return typing.cast("Greengrass", jsii.invoke(self, "toDiscover", []))

    @jsii.member(jsii_name="toGetAssociatedRole")
    def to_get_associated_role(self) -> "Greengrass":
        '''(experimental) Grants permission to retrieve the role associated with a group.

        Access Level: Read

        https://docs.aws.amazon.com/greengrass/latest/apireference/getassociatedrole-get.html

        :stability: experimental
        '''
        return typing.cast("Greengrass", jsii.invoke(self, "toGetAssociatedRole", []))

    @jsii.member(jsii_name="toGetBulkDeploymentStatus")
    def to_get_bulk_deployment_status(self) -> "Greengrass":
        '''(experimental) Grants permission to return the status of a bulk deployment.

        Access Level: Read

        https://docs.aws.amazon.com/greengrass/latest/apireference/getbulkdeploymentstatus-get.html

        :stability: experimental
        '''
        return typing.cast("Greengrass", jsii.invoke(self, "toGetBulkDeploymentStatus", []))

    @jsii.member(jsii_name="toGetConnectivityInfo")
    def to_get_connectivity_info(self) -> "Greengrass":
        '''(experimental) Grants permission to retrieve the connectivity information for a core.

        Access Level: Read

        https://docs.aws.amazon.com/greengrass/latest/apireference/getconnectivityinfo-get.html

        :stability: experimental
        '''
        return typing.cast("Greengrass", jsii.invoke(self, "toGetConnectivityInfo", []))

    @jsii.member(jsii_name="toGetConnectorDefinition")
    def to_get_connector_definition(self) -> "Greengrass":
        '''(experimental) Grants permission to retrieve information about a connector definition.

        Access Level: Read

        https://docs.aws.amazon.com/greengrass/latest/apireference/getconnectordefinition-get.html

        :stability: experimental
        '''
        return typing.cast("Greengrass", jsii.invoke(self, "toGetConnectorDefinition", []))

    @jsii.member(jsii_name="toGetConnectorDefinitionVersion")
    def to_get_connector_definition_version(self) -> "Greengrass":
        '''(experimental) Grants permission to retrieve information about a connector definition version.

        Access Level: Read

        https://docs.aws.amazon.com/greengrass/latest/apireference/getconnectordefinitionversion-get.html

        :stability: experimental
        '''
        return typing.cast("Greengrass", jsii.invoke(self, "toGetConnectorDefinitionVersion", []))

    @jsii.member(jsii_name="toGetCoreDefinition")
    def to_get_core_definition(self) -> "Greengrass":
        '''(experimental) Grants permission to retrieve information about a core definition.

        Access Level: Read

        https://docs.aws.amazon.com/greengrass/latest/apireference/getcoredefinition-get.html

        :stability: experimental
        '''
        return typing.cast("Greengrass", jsii.invoke(self, "toGetCoreDefinition", []))

    @jsii.member(jsii_name="toGetCoreDefinitionVersion")
    def to_get_core_definition_version(self) -> "Greengrass":
        '''(experimental) Grants permission to retrieve information about a core definition version.

        Access Level: Read

        https://docs.aws.amazon.com/greengrass/latest/apireference/getcoredefinitionversion-get.html

        :stability: experimental
        '''
        return typing.cast("Greengrass", jsii.invoke(self, "toGetCoreDefinitionVersion", []))

    @jsii.member(jsii_name="toGetDeploymentStatus")
    def to_get_deployment_status(self) -> "Greengrass":
        '''(experimental) Grants permission to return the status of a deployment.

        Access Level: Read

        https://docs.aws.amazon.com/greengrass/latest/apireference/getdeploymentstatus-get.html

        :stability: experimental
        '''
        return typing.cast("Greengrass", jsii.invoke(self, "toGetDeploymentStatus", []))

    @jsii.member(jsii_name="toGetDeviceDefinition")
    def to_get_device_definition(self) -> "Greengrass":
        '''(experimental) Grants permission to retrieve information about a device definition.

        Access Level: Read

        https://docs.aws.amazon.com/greengrass/latest/apireference/getdevicedefinition-get.html

        :stability: experimental
        '''
        return typing.cast("Greengrass", jsii.invoke(self, "toGetDeviceDefinition", []))

    @jsii.member(jsii_name="toGetDeviceDefinitionVersion")
    def to_get_device_definition_version(self) -> "Greengrass":
        '''(experimental) Grants permission to retrieve information about a device definition version.

        Access Level: Read

        https://docs.aws.amazon.com/greengrass/latest/apireference/getdevicedefinitionversion-get.html

        :stability: experimental
        '''
        return typing.cast("Greengrass", jsii.invoke(self, "toGetDeviceDefinitionVersion", []))

    @jsii.member(jsii_name="toGetFunctionDefinition")
    def to_get_function_definition(self) -> "Greengrass":
        '''(experimental) Grants permission to retrieve information about a Lambda function definition, such as its creation time and latest version.

        Access Level: Read

        https://docs.aws.amazon.com/greengrass/latest/apireference/getfunctiondefinition-get.html

        :stability: experimental
        '''
        return typing.cast("Greengrass", jsii.invoke(self, "toGetFunctionDefinition", []))

    @jsii.member(jsii_name="toGetFunctionDefinitionVersion")
    def to_get_function_definition_version(self) -> "Greengrass":
        '''(experimental) Grants permission to retrieve information about a Lambda function definition version, such as which Lambda functions are included in the version and their configurations.

        Access Level: Read

        https://docs.aws.amazon.com/greengrass/latest/apireference/getfunctiondefinitionversion-get.html

        :stability: experimental
        '''
        return typing.cast("Greengrass", jsii.invoke(self, "toGetFunctionDefinitionVersion", []))

    @jsii.member(jsii_name="toGetGroup")
    def to_get_group(self) -> "Greengrass":
        '''(experimental) Grants permission to retrieve information about a group.

        Access Level: Read

        https://docs.aws.amazon.com/greengrass/latest/apireference/getgroup-get.html

        :stability: experimental
        '''
        return typing.cast("Greengrass", jsii.invoke(self, "toGetGroup", []))

    @jsii.member(jsii_name="toGetGroupCertificateAuthority")
    def to_get_group_certificate_authority(self) -> "Greengrass":
        '''(experimental) Grants permission to return the public key of the CA associated with a group.

        Access Level: Read

        https://docs.aws.amazon.com/greengrass/latest/apireference/getgroupcertificateauthority-get.html

        :stability: experimental
        '''
        return typing.cast("Greengrass", jsii.invoke(self, "toGetGroupCertificateAuthority", []))

    @jsii.member(jsii_name="toGetGroupCertificateConfiguration")
    def to_get_group_certificate_configuration(self) -> "Greengrass":
        '''(experimental) Grants permission to retrieve the current configuration for the CA used by a group.

        Access Level: Read

        https://docs.aws.amazon.com/greengrass/latest/apireference/getgroupcertificateconfiguration-get.html

        :stability: experimental
        '''
        return typing.cast("Greengrass", jsii.invoke(self, "toGetGroupCertificateConfiguration", []))

    @jsii.member(jsii_name="toGetGroupVersion")
    def to_get_group_version(self) -> "Greengrass":
        '''(experimental) Grants permission to retrieve information about a group version.

        Access Level: Read

        https://docs.aws.amazon.com/greengrass/latest/apireference/getgroupversion-get.html

        :stability: experimental
        '''
        return typing.cast("Greengrass", jsii.invoke(self, "toGetGroupVersion", []))

    @jsii.member(jsii_name="toGetLoggerDefinition")
    def to_get_logger_definition(self) -> "Greengrass":
        '''(experimental) Grants permission to retrieve information about a logger definition.

        Access Level: Read

        https://docs.aws.amazon.com/greengrass/latest/apireference/getloggerdefinition-get.html

        :stability: experimental
        '''
        return typing.cast("Greengrass", jsii.invoke(self, "toGetLoggerDefinition", []))

    @jsii.member(jsii_name="toGetLoggerDefinitionVersion")
    def to_get_logger_definition_version(self) -> "Greengrass":
        '''(experimental) Grants permission to retrieve information about a logger definition version.

        Access Level: Read

        https://docs.aws.amazon.com/greengrass/latest/apireference/getloggerdefinitionversion-get.html

        :stability: experimental
        '''
        return typing.cast("Greengrass", jsii.invoke(self, "toGetLoggerDefinitionVersion", []))

    @jsii.member(jsii_name="toGetResourceDefinition")
    def to_get_resource_definition(self) -> "Greengrass":
        '''(experimental) Grants permission to retrieve information about a resource definition, such as its creation time and latest version.

        Access Level: Read

        https://docs.aws.amazon.com/greengrass/latest/apireference/getresourcedefinition-get.html

        :stability: experimental
        '''
        return typing.cast("Greengrass", jsii.invoke(self, "toGetResourceDefinition", []))

    @jsii.member(jsii_name="toGetResourceDefinitionVersion")
    def to_get_resource_definition_version(self) -> "Greengrass":
        '''(experimental) Grants permission to retrieve information about a resource definition version, such as which resources are included in the version.

        Access Level: Read

        https://docs.aws.amazon.com/greengrass/latest/apireference/getresourcedefinitionversion-get.html

        :stability: experimental
        '''
        return typing.cast("Greengrass", jsii.invoke(self, "toGetResourceDefinitionVersion", []))

    @jsii.member(jsii_name="toGetServiceRoleForAccount")
    def to_get_service_role_for_account(self) -> "Greengrass":
        '''(experimental) Grants permission to retrieve the service role that is attached to an account.

        Access Level: Read

        https://docs.aws.amazon.com/greengrass/latest/apireference/getserviceroleforaccount-get.html

        :stability: experimental
        '''
        return typing.cast("Greengrass", jsii.invoke(self, "toGetServiceRoleForAccount", []))

    @jsii.member(jsii_name="toGetSubscriptionDefinition")
    def to_get_subscription_definition(self) -> "Greengrass":
        '''(experimental) Grants permission to retrieve information about a subscription definition.

        Access Level: Read

        https://docs.aws.amazon.com/greengrass/latest/apireference/getsubscriptiondefinition-get.html

        :stability: experimental
        '''
        return typing.cast("Greengrass", jsii.invoke(self, "toGetSubscriptionDefinition", []))

    @jsii.member(jsii_name="toGetSubscriptionDefinitionVersion")
    def to_get_subscription_definition_version(self) -> "Greengrass":
        '''(experimental) Grants permission to retrieve information about a subscription definition version.

        Access Level: Read

        https://docs.aws.amazon.com/greengrass/latest/apireference/getsubscriptiondefinitionversion-get.html

        :stability: experimental
        '''
        return typing.cast("Greengrass", jsii.invoke(self, "toGetSubscriptionDefinitionVersion", []))

    @jsii.member(jsii_name="toGetThingRuntimeConfiguration")
    def to_get_thing_runtime_configuration(self) -> "Greengrass":
        '''(experimental) Grants permission to retrieve runtime configuration of a thing.

        Access Level: Read

        https://docs.aws.amazon.com/greengrass/latest/apireference/getthingruntimeconfiguration-get.html

        :stability: experimental
        '''
        return typing.cast("Greengrass", jsii.invoke(self, "toGetThingRuntimeConfiguration", []))

    @jsii.member(jsii_name="toListBulkDeploymentDetailedReports")
    def to_list_bulk_deployment_detailed_reports(self) -> "Greengrass":
        '''(experimental) Grants permission to retrieve a paginated list of the deployments that have been started in a bulk deployment operation and their current deployment status.

        Access Level: Read

        https://docs.aws.amazon.com/greengrass/latest/apireference/listbulkdeploymentdetailedreports-get.html

        :stability: experimental
        '''
        return typing.cast("Greengrass", jsii.invoke(self, "toListBulkDeploymentDetailedReports", []))

    @jsii.member(jsii_name="toListBulkDeployments")
    def to_list_bulk_deployments(self) -> "Greengrass":
        '''(experimental) Grants permission to retrieve a list of bulk deployments.

        Access Level: List

        https://docs.aws.amazon.com/greengrass/latest/apireference/listbulkdeployments-get.html

        :stability: experimental
        '''
        return typing.cast("Greengrass", jsii.invoke(self, "toListBulkDeployments", []))

    @jsii.member(jsii_name="toListConnectorDefinitions")
    def to_list_connector_definitions(self) -> "Greengrass":
        '''(experimental) Grants permission to retrieve a list of connector definitions.

        Access Level: List

        https://docs.aws.amazon.com/greengrass/latest/apireference/listconnectordefinitions-get.html

        :stability: experimental
        '''
        return typing.cast("Greengrass", jsii.invoke(self, "toListConnectorDefinitions", []))

    @jsii.member(jsii_name="toListConnectorDefinitionVersions")
    def to_list_connector_definition_versions(self) -> "Greengrass":
        '''(experimental) Grants permission to list the versions of a connector definition.

        Access Level: List

        https://docs.aws.amazon.com/greengrass/latest/apireference/listconnectordefinitionversions-get.html

        :stability: experimental
        '''
        return typing.cast("Greengrass", jsii.invoke(self, "toListConnectorDefinitionVersions", []))

    @jsii.member(jsii_name="toListCoreDefinitions")
    def to_list_core_definitions(self) -> "Greengrass":
        '''(experimental) Grants permission to retrieve a list of core definitions.

        Access Level: List

        https://docs.aws.amazon.com/greengrass/latest/apireference/listcoredefinitions-get.html

        :stability: experimental
        '''
        return typing.cast("Greengrass", jsii.invoke(self, "toListCoreDefinitions", []))

    @jsii.member(jsii_name="toListCoreDefinitionVersions")
    def to_list_core_definition_versions(self) -> "Greengrass":
        '''(experimental) Grants permission to list the versions of a core definition.

        Access Level: List

        https://docs.aws.amazon.com/greengrass/latest/apireference/listcoredefinitionversions-get.html

        :stability: experimental
        '''
        return typing.cast("Greengrass", jsii.invoke(self, "toListCoreDefinitionVersions", []))

    @jsii.member(jsii_name="toListDeployments")
    def to_list_deployments(self) -> "Greengrass":
        '''(experimental) Grants permission to retrieve a list of all deployments for a group.

        Access Level: List

        https://docs.aws.amazon.com/greengrass/latest/apireference/listdeployments-get.html

        :stability: experimental
        '''
        return typing.cast("Greengrass", jsii.invoke(self, "toListDeployments", []))

    @jsii.member(jsii_name="toListDeviceDefinitions")
    def to_list_device_definitions(self) -> "Greengrass":
        '''(experimental) Grants permission to retrieve a list of device definitions.

        Access Level: List

        https://docs.aws.amazon.com/greengrass/latest/apireference/listdevicedefinitions-get.html

        :stability: experimental
        '''
        return typing.cast("Greengrass", jsii.invoke(self, "toListDeviceDefinitions", []))

    @jsii.member(jsii_name="toListDeviceDefinitionVersions")
    def to_list_device_definition_versions(self) -> "Greengrass":
        '''(experimental) Grants permission to list the versions of a device definition.

        Access Level: List

        https://docs.aws.amazon.com/greengrass/latest/apireference/listdevicedefinitionversions-get.html

        :stability: experimental
        '''
        return typing.cast("Greengrass", jsii.invoke(self, "toListDeviceDefinitionVersions", []))

    @jsii.member(jsii_name="toListFunctionDefinitions")
    def to_list_function_definitions(self) -> "Greengrass":
        '''(experimental) Grants permission to retrieve a list of Lambda function definitions.

        Access Level: List

        https://docs.aws.amazon.com/greengrass/latest/apireference/listfunctiondefinitions-get.html

        :stability: experimental
        '''
        return typing.cast("Greengrass", jsii.invoke(self, "toListFunctionDefinitions", []))

    @jsii.member(jsii_name="toListFunctionDefinitionVersions")
    def to_list_function_definition_versions(self) -> "Greengrass":
        '''(experimental) Grants permission to list the versions of a Lambda function definition.

        Access Level: List

        https://docs.aws.amazon.com/greengrass/latest/apireference/listfunctiondefinitionversions-get.html

        :stability: experimental
        '''
        return typing.cast("Greengrass", jsii.invoke(self, "toListFunctionDefinitionVersions", []))

    @jsii.member(jsii_name="toListGroupCertificateAuthorities")
    def to_list_group_certificate_authorities(self) -> "Greengrass":
        '''(experimental) Grants permission to retrieve a list of current CAs for a group.

        Access Level: List

        https://docs.aws.amazon.com/greengrass/latest/apireference/listgroupcertificateauthorities-get.html

        :stability: experimental
        '''
        return typing.cast("Greengrass", jsii.invoke(self, "toListGroupCertificateAuthorities", []))

    @jsii.member(jsii_name="toListGroups")
    def to_list_groups(self) -> "Greengrass":
        '''(experimental) Grants permission to retrieve a list of groups.

        Access Level: List

        https://docs.aws.amazon.com/greengrass/latest/apireference/listgroups-get.html

        :stability: experimental
        '''
        return typing.cast("Greengrass", jsii.invoke(self, "toListGroups", []))

    @jsii.member(jsii_name="toListGroupVersions")
    def to_list_group_versions(self) -> "Greengrass":
        '''(experimental) Grants permission to list the versions of a group.

        Access Level: List

        https://docs.aws.amazon.com/greengrass/latest/apireference/listgroupversions-get.html

        :stability: experimental
        '''
        return typing.cast("Greengrass", jsii.invoke(self, "toListGroupVersions", []))

    @jsii.member(jsii_name="toListLoggerDefinitions")
    def to_list_logger_definitions(self) -> "Greengrass":
        '''(experimental) Grants permission to retrieve a list of logger definitions.

        Access Level: List

        https://docs.aws.amazon.com/greengrass/latest/apireference/listloggerdefinitions-get.html

        :stability: experimental
        '''
        return typing.cast("Greengrass", jsii.invoke(self, "toListLoggerDefinitions", []))

    @jsii.member(jsii_name="toListLoggerDefinitionVersions")
    def to_list_logger_definition_versions(self) -> "Greengrass":
        '''(experimental) Grants permission to list the versions of a logger definition.

        Access Level: List

        https://docs.aws.amazon.com/greengrass/latest/apireference/listloggerdefinitionversions-get.html

        :stability: experimental
        '''
        return typing.cast("Greengrass", jsii.invoke(self, "toListLoggerDefinitionVersions", []))

    @jsii.member(jsii_name="toListResourceDefinitions")
    def to_list_resource_definitions(self) -> "Greengrass":
        '''(experimental) Grants permission to retrieve a list of resource definitions.

        Access Level: List

        https://docs.aws.amazon.com/greengrass/latest/apireference/listresourcedefinitions-get.html

        :stability: experimental
        '''
        return typing.cast("Greengrass", jsii.invoke(self, "toListResourceDefinitions", []))

    @jsii.member(jsii_name="toListResourceDefinitionVersions")
    def to_list_resource_definition_versions(self) -> "Greengrass":
        '''(experimental) Grants permission to list the versions of a resource definition.

        Access Level: List

        https://docs.aws.amazon.com/greengrass/latest/apireference/listresourcedefinitionversions-get.html

        :stability: experimental
        '''
        return typing.cast("Greengrass", jsii.invoke(self, "toListResourceDefinitionVersions", []))

    @jsii.member(jsii_name="toListSubscriptionDefinitions")
    def to_list_subscription_definitions(self) -> "Greengrass":
        '''(experimental) Grants permission to retrieve a list of subscription definitions.

        Access Level: List

        https://docs.aws.amazon.com/greengrass/latest/apireference/listsubscriptiondefinitions-get.html

        :stability: experimental
        '''
        return typing.cast("Greengrass", jsii.invoke(self, "toListSubscriptionDefinitions", []))

    @jsii.member(jsii_name="toListSubscriptionDefinitionVersions")
    def to_list_subscription_definition_versions(self) -> "Greengrass":
        '''(experimental) Grants permission to list the versions of a subscription definition.

        Access Level: List

        https://docs.aws.amazon.com/greengrass/latest/apireference/listsubscriptiondefinitionversions-get.html

        :stability: experimental
        '''
        return typing.cast("Greengrass", jsii.invoke(self, "toListSubscriptionDefinitionVersions", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Greengrass":
        '''(experimental) Grants permission to list the tags for a resource.

        Access Level: Read

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/greengrass/latest/apireference/listtagsforresource-get.html

        :stability: experimental
        '''
        return typing.cast("Greengrass", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toResetDeployments")
    def to_reset_deployments(self) -> "Greengrass":
        '''(experimental) Grants permission to reset a group's deployments.

        Access Level: Write

        https://docs.aws.amazon.com/greengrass/latest/apireference/resetdeployments-post.html

        :stability: experimental
        '''
        return typing.cast("Greengrass", jsii.invoke(self, "toResetDeployments", []))

    @jsii.member(jsii_name="toStartBulkDeployment")
    def to_start_bulk_deployment(self) -> "Greengrass":
        '''(experimental) Grants permission to deploy multiple groups in one operation.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/greengrass/latest/apireference/startbulkdeployment-post.html

        :stability: experimental
        '''
        return typing.cast("Greengrass", jsii.invoke(self, "toStartBulkDeployment", []))

    @jsii.member(jsii_name="toStopBulkDeployment")
    def to_stop_bulk_deployment(self) -> "Greengrass":
        '''(experimental) Grants permission to stop the execution of a bulk deployment.

        Access Level: Write

        https://docs.aws.amazon.com/greengrass/latest/apireference/stopbulkdeployment-put.html

        :stability: experimental
        '''
        return typing.cast("Greengrass", jsii.invoke(self, "toStopBulkDeployment", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Greengrass":
        '''(experimental) Grants permission to add tags to a resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/greengrass/latest/apireference/tagresource-post.html

        :stability: experimental
        '''
        return typing.cast("Greengrass", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Greengrass":
        '''(experimental) Grants permission to remove tags from a resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/greengrass/latest/apireference/untagresource-delete.html

        :stability: experimental
        '''
        return typing.cast("Greengrass", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateConnectivityInfo")
    def to_update_connectivity_info(self) -> "Greengrass":
        '''(experimental) Grants permission to update the connectivity information for a Greengrass core.

        Any devices that belong to the group that has this core will receive this information in order to find the location of the core and connect to it

        Access Level: Write

        https://docs.aws.amazon.com/greengrass/latest/apireference/updateconnectivityinfo-put.html

        :stability: experimental
        '''
        return typing.cast("Greengrass", jsii.invoke(self, "toUpdateConnectivityInfo", []))

    @jsii.member(jsii_name="toUpdateConnectorDefinition")
    def to_update_connector_definition(self) -> "Greengrass":
        '''(experimental) Grants permission to update a connector definition.

        Access Level: Write

        https://docs.aws.amazon.com/greengrass/latest/apireference/updateconnectordefinition-put.html

        :stability: experimental
        '''
        return typing.cast("Greengrass", jsii.invoke(self, "toUpdateConnectorDefinition", []))

    @jsii.member(jsii_name="toUpdateCoreDefinition")
    def to_update_core_definition(self) -> "Greengrass":
        '''(experimental) Grants permission to update a core definition.

        Access Level: Write

        https://docs.aws.amazon.com/greengrass/latest/apireference/updatecoredefinition-put.html

        :stability: experimental
        '''
        return typing.cast("Greengrass", jsii.invoke(self, "toUpdateCoreDefinition", []))

    @jsii.member(jsii_name="toUpdateDeviceDefinition")
    def to_update_device_definition(self) -> "Greengrass":
        '''(experimental) Grants permission to update a device definition.

        Access Level: Write

        https://docs.aws.amazon.com/greengrass/latest/apireference/updatedevicedefinition-put.html

        :stability: experimental
        '''
        return typing.cast("Greengrass", jsii.invoke(self, "toUpdateDeviceDefinition", []))

    @jsii.member(jsii_name="toUpdateFunctionDefinition")
    def to_update_function_definition(self) -> "Greengrass":
        '''(experimental) Grants permission to update a Lambda function definition.

        Access Level: Write

        https://docs.aws.amazon.com/greengrass/latest/apireference/updatefunctiondefinition-put.html

        :stability: experimental
        '''
        return typing.cast("Greengrass", jsii.invoke(self, "toUpdateFunctionDefinition", []))

    @jsii.member(jsii_name="toUpdateGroup")
    def to_update_group(self) -> "Greengrass":
        '''(experimental) Grants permission to update a group.

        Access Level: Write

        https://docs.aws.amazon.com/greengrass/latest/apireference/updategroup-put.html

        :stability: experimental
        '''
        return typing.cast("Greengrass", jsii.invoke(self, "toUpdateGroup", []))

    @jsii.member(jsii_name="toUpdateGroupCertificateConfiguration")
    def to_update_group_certificate_configuration(self) -> "Greengrass":
        '''(experimental) Grants permission to update the certificate expiry time for a group.

        Access Level: Write

        https://docs.aws.amazon.com/greengrass/latest/apireference/updategroupcertificateconfiguration-put.html

        :stability: experimental
        '''
        return typing.cast("Greengrass", jsii.invoke(self, "toUpdateGroupCertificateConfiguration", []))

    @jsii.member(jsii_name="toUpdateLoggerDefinition")
    def to_update_logger_definition(self) -> "Greengrass":
        '''(experimental) Grants permission to update a logger definition.

        Access Level: Write

        https://docs.aws.amazon.com/greengrass/latest/apireference/updateloggerdefinition-put.html

        :stability: experimental
        '''
        return typing.cast("Greengrass", jsii.invoke(self, "toUpdateLoggerDefinition", []))

    @jsii.member(jsii_name="toUpdateResourceDefinition")
    def to_update_resource_definition(self) -> "Greengrass":
        '''(experimental) Grants permission to update a resource definition.

        Access Level: Write

        https://docs.aws.amazon.com/greengrass/latest/apireference/updateresourcedefinition-put.html

        :stability: experimental
        '''
        return typing.cast("Greengrass", jsii.invoke(self, "toUpdateResourceDefinition", []))

    @jsii.member(jsii_name="toUpdateSubscriptionDefinition")
    def to_update_subscription_definition(self) -> "Greengrass":
        '''(experimental) Grants permission to update a subscription definition.

        Access Level: Write

        https://docs.aws.amazon.com/greengrass/latest/apireference/updatesubscriptiondefinition-put.html

        :stability: experimental
        '''
        return typing.cast("Greengrass", jsii.invoke(self, "toUpdateSubscriptionDefinition", []))

    @jsii.member(jsii_name="toUpdateThingRuntimeConfiguration")
    def to_update_thing_runtime_configuration(self) -> "Greengrass":
        '''(experimental) Grants permission to update runtime configuration of a thing.

        Access Level: Write

        https://docs.aws.amazon.com/greengrass/latest/apireference/updatethingruntimeconfiguration-put.html

        :stability: experimental
        '''
        return typing.cast("Greengrass", jsii.invoke(self, "toUpdateThingRuntimeConfiguration", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ab24f0cdcda6dad9685a30056f3e80c2b8558d7451e0f2172bf1a9757a95631a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__951c8f8a36e765a2658f3a736a68be6f6c17e61f0e560383e94b3f69afa0fb7b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class GreengrassV2(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.GreengrassV2",
):
    '''(experimental) Statement provider for service `greengrass-v2 <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiotgreengrassv2.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `greengrass-v2 <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiotgreengrassv2.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onComponent")
    def on_component(
        self,
        component_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "GreengrassV2":
        '''(experimental) Adds a resource of type component to the statement.

        https://docs.aws.amazon.com/greengrass/v2/APIReference/API_Component.html

        :param component_name: - Identifier for the componentName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7492ceb6efd68e34bb36b1779e2e2cb9df1832b43a14dec6372671c8a1b00b33)
            check_type(argname="argument component_name", value=component_name, expected_type=type_hints["component_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("GreengrassV2", jsii.invoke(self, "onComponent", [component_name, account, region, partition]))

    @jsii.member(jsii_name="onComponentVersion")
    def on_component_version(
        self,
        component_name: builtins.str,
        component_version: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "GreengrassV2":
        '''(experimental) Adds a resource of type componentVersion to the statement.

        https://docs.aws.amazon.com/greengrass/v2/APIReference/API_Component.html

        :param component_name: - Identifier for the componentName.
        :param component_version: - Identifier for the componentVersion.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__52a1250e1fa52cf2c69a5259d25e9bf8275ae2ccc5fb8557ae578284e87da440)
            check_type(argname="argument component_name", value=component_name, expected_type=type_hints["component_name"])
            check_type(argname="argument component_version", value=component_version, expected_type=type_hints["component_version"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("GreengrassV2", jsii.invoke(self, "onComponentVersion", [component_name, component_version, account, region, partition]))

    @jsii.member(jsii_name="onConnectivityInfo")
    def on_connectivity_info(
        self,
        thing_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "GreengrassV2":
        '''(experimental) Adds a resource of type connectivityInfo to the statement.

        https://docs.aws.amazon.com/greengrass/v2/APIReference/API_ConnectivityInfo.html

        :param thing_name: - Identifier for the thingName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__91e7213ffa0c857ccc2a2f855e8e9f284588df5976a762d5a4af54f967937a76)
            check_type(argname="argument thing_name", value=thing_name, expected_type=type_hints["thing_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("GreengrassV2", jsii.invoke(self, "onConnectivityInfo", [thing_name, account, region, partition]))

    @jsii.member(jsii_name="onCoreDevice")
    def on_core_device(
        self,
        core_device_thing_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "GreengrassV2":
        '''(experimental) Adds a resource of type coreDevice to the statement.

        https://docs.aws.amazon.com/greengrass/v2/APIReference/API_CoreDevice.html

        :param core_device_thing_name: - Identifier for the coreDeviceThingName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b75da0151276e074ecbb716c3d03e5850980ba992aa82cc2626933c3cd18a2f9)
            check_type(argname="argument core_device_thing_name", value=core_device_thing_name, expected_type=type_hints["core_device_thing_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("GreengrassV2", jsii.invoke(self, "onCoreDevice", [core_device_thing_name, account, region, partition]))

    @jsii.member(jsii_name="onDeployment")
    def on_deployment(
        self,
        deployment_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "GreengrassV2":
        '''(experimental) Adds a resource of type deployment to the statement.

        https://docs.aws.amazon.com/greengrass/v2/APIReference/API_Deployment.html

        :param deployment_id: - Identifier for the deploymentId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__cf140bce90752de9ee4e58607ac80865aeb1647d7f2efa8b26231867aa52d572)
            check_type(argname="argument deployment_id", value=deployment_id, expected_type=type_hints["deployment_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("GreengrassV2", jsii.invoke(self, "onDeployment", [deployment_id, account, region, partition]))

    @jsii.member(jsii_name="toAssociateServiceRoleToAccount")
    def to_associate_service_role_to_account(self) -> "GreengrassV2":
        '''(experimental) Grants permission to associate a role with your account.

        AWS IoT Greengrass uses this role to access your Lambda functions and AWS IoT resources

        Access Level: Permissions management

        Dependent actions:

        - iam:PassRole

        https://docs.aws.amazon.com/greengrass/v2/APIReference/API_AssociateServiceRoleToAccount.html

        :stability: experimental
        '''
        return typing.cast("GreengrassV2", jsii.invoke(self, "toAssociateServiceRoleToAccount", []))

    @jsii.member(jsii_name="toBatchAssociateClientDeviceWithCoreDevice")
    def to_batch_associate_client_device_with_core_device(self) -> "GreengrassV2":
        '''(experimental) Grants permission to associate a list of client devices with a core device.

        Access Level: Write

        https://docs.aws.amazon.com/greengrass/v2/APIReference/API_BatchAssociateClientDeviceWithCoreDevice.html

        :stability: experimental
        '''
        return typing.cast("GreengrassV2", jsii.invoke(self, "toBatchAssociateClientDeviceWithCoreDevice", []))

    @jsii.member(jsii_name="toBatchDisassociateClientDeviceFromCoreDevice")
    def to_batch_disassociate_client_device_from_core_device(self) -> "GreengrassV2":
        '''(experimental) Grants permission to disassociate a list of client devices from a core device.

        Access Level: Write

        https://docs.aws.amazon.com/greengrass/v2/APIReference/API_BatchDisassociateClientDeviceFromCoreDevice.html

        :stability: experimental
        '''
        return typing.cast("GreengrassV2", jsii.invoke(self, "toBatchDisassociateClientDeviceFromCoreDevice", []))

    @jsii.member(jsii_name="toCancelDeployment")
    def to_cancel_deployment(self) -> "GreengrassV2":
        '''(experimental) Grants permission to cancel a deployment.

        Access Level: Write

        Dependent actions:

        - iot:CancelJob
        - iot:DeleteThingShadow
        - iot:DescribeJob
        - iot:DescribeThing
        - iot:DescribeThingGroup
        - iot:GetThingShadow
        - iot:UpdateJob
        - iot:UpdateThingShadow

        https://docs.aws.amazon.com/greengrass/v2/APIReference/API_CancelDeployment.html

        :stability: experimental
        '''
        return typing.cast("GreengrassV2", jsii.invoke(self, "toCancelDeployment", []))

    @jsii.member(jsii_name="toCreateComponentVersion")
    def to_create_component_version(self) -> "GreengrassV2":
        '''(experimental) Grants permission to create a component.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/greengrass/v2/APIReference/API_CreateComponentVersion.html

        :stability: experimental
        '''
        return typing.cast("GreengrassV2", jsii.invoke(self, "toCreateComponentVersion", []))

    @jsii.member(jsii_name="toCreateDeployment")
    def to_create_deployment(self) -> "GreengrassV2":
        '''(experimental) Grants permission to create a deployment.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - iot:CancelJob
        - iot:CreateJob
        - iot:DeleteThingShadow
        - iot:DescribeJob
        - iot:DescribeThing
        - iot:DescribeThingGroup
        - iot:GetThingShadow
        - iot:UpdateJob
        - iot:UpdateThingShadow

        https://docs.aws.amazon.com/greengrass/v2/APIReference/API_CreateDeployment.html

        :stability: experimental
        '''
        return typing.cast("GreengrassV2", jsii.invoke(self, "toCreateDeployment", []))

    @jsii.member(jsii_name="toDeleteComponent")
    def to_delete_component(self) -> "GreengrassV2":
        '''(experimental) Grants permission to delete a component.

        Access Level: Write

        https://docs.aws.amazon.com/greengrass/v2/APIReference/API_DeleteComponent.html

        :stability: experimental
        '''
        return typing.cast("GreengrassV2", jsii.invoke(self, "toDeleteComponent", []))

    @jsii.member(jsii_name="toDeleteCoreDevice")
    def to_delete_core_device(self) -> "GreengrassV2":
        '''(experimental) Grants permission to delete a AWS IoT Greengrass core device, which is an AWS IoT thing.

        This operation removes the core device from the list of core devices. This operation doesn't delete the AWS IoT thing

        Access Level: Write

        Dependent actions:

        - iot:DescribeJobExecution

        https://docs.aws.amazon.com/greengrass/v2/APIReference/API_DeleteCoreDevice.html

        :stability: experimental
        '''
        return typing.cast("GreengrassV2", jsii.invoke(self, "toDeleteCoreDevice", []))

    @jsii.member(jsii_name="toDeleteDeployment")
    def to_delete_deployment(self) -> "GreengrassV2":
        '''(experimental) Grants permission to delete a deployment. To delete an active deployment, it needs to be cancelled first.

        Access Level: Write

        Dependent actions:

        - iot:DeleteJob

        https://docs.aws.amazon.com/greengrass/v2/APIReference/API_DeleteDeployment.html

        :stability: experimental
        '''
        return typing.cast("GreengrassV2", jsii.invoke(self, "toDeleteDeployment", []))

    @jsii.member(jsii_name="toDescribeComponent")
    def to_describe_component(self) -> "GreengrassV2":
        '''(experimental) Grants permission to retrieve metadata for a version of a component.

        Access Level: Read

        https://docs.aws.amazon.com/greengrass/v2/APIReference/API_DescribeComponent.html

        :stability: experimental
        '''
        return typing.cast("GreengrassV2", jsii.invoke(self, "toDescribeComponent", []))

    @jsii.member(jsii_name="toDisassociateServiceRoleFromAccount")
    def to_disassociate_service_role_from_account(self) -> "GreengrassV2":
        '''(experimental) Grants permission to disassociate the service role from an account. Without a service role, deployments will not work.

        Access Level: Write

        https://docs.aws.amazon.com/greengrass/v2/APIReference/API_DisassociateServiceRoleFromAccount.html

        :stability: experimental
        '''
        return typing.cast("GreengrassV2", jsii.invoke(self, "toDisassociateServiceRoleFromAccount", []))

    @jsii.member(jsii_name="toGetComponent")
    def to_get_component(self) -> "GreengrassV2":
        '''(experimental) Grants permission to get the recipe for a version of a component.

        Access Level: Read

        https://docs.aws.amazon.com/greengrass/v2/APIReference/API_GetComponent.html

        :stability: experimental
        '''
        return typing.cast("GreengrassV2", jsii.invoke(self, "toGetComponent", []))

    @jsii.member(jsii_name="toGetComponentVersionArtifact")
    def to_get_component_version_artifact(self) -> "GreengrassV2":
        '''(experimental) Grants permission to get the pre-signed URL to download a public component artifact.

        Access Level: Read

        https://docs.aws.amazon.com/greengrass/v2/APIReference/API_GetComponentVersionArtifact.html

        :stability: experimental
        '''
        return typing.cast("GreengrassV2", jsii.invoke(self, "toGetComponentVersionArtifact", []))

    @jsii.member(jsii_name="toGetConnectivityInfo")
    def to_get_connectivity_info(self) -> "GreengrassV2":
        '''(experimental) Grants permission to retrieve the connectivity information for a Greengrass core device.

        Access Level: Read

        Dependent actions:

        - iot:GetThingShadow

        https://docs.aws.amazon.com/greengrass/v2/APIReference/API_GetConnectivityInfo.html

        :stability: experimental
        '''
        return typing.cast("GreengrassV2", jsii.invoke(self, "toGetConnectivityInfo", []))

    @jsii.member(jsii_name="toGetCoreDevice")
    def to_get_core_device(self) -> "GreengrassV2":
        '''(experimental) Grants permission to retrieves metadata for a AWS IoT Greengrass core device.

        Access Level: Read

        https://docs.aws.amazon.com/greengrass/v2/APIReference/API_GetCoreDevice.html

        :stability: experimental
        '''
        return typing.cast("GreengrassV2", jsii.invoke(self, "toGetCoreDevice", []))

    @jsii.member(jsii_name="toGetDeployment")
    def to_get_deployment(self) -> "GreengrassV2":
        '''(experimental) Grants permission to get a deployment.

        Access Level: Read

        Dependent actions:

        - iot:DescribeJob
        - iot:DescribeThing
        - iot:DescribeThingGroup
        - iot:GetThingShadow

        https://docs.aws.amazon.com/greengrass/v2/APIReference/API_GetDeployment.html

        :stability: experimental
        '''
        return typing.cast("GreengrassV2", jsii.invoke(self, "toGetDeployment", []))

    @jsii.member(jsii_name="toGetServiceRoleForAccount")
    def to_get_service_role_for_account(self) -> "GreengrassV2":
        '''(experimental) Grants permission to retrieve the service role that is attached to an account.

        Access Level: Read

        https://docs.aws.amazon.com/greengrass/v2/APIReference/API_GetServiceRoleForAccount.html

        :stability: experimental
        '''
        return typing.cast("GreengrassV2", jsii.invoke(self, "toGetServiceRoleForAccount", []))

    @jsii.member(jsii_name="toListClientDevicesAssociatedWithCoreDevice")
    def to_list_client_devices_associated_with_core_device(self) -> "GreengrassV2":
        '''(experimental) Grants permission to retrieve a paginated list of client devices associated to a AWS IoT Greengrass core device.

        Access Level: List

        https://docs.aws.amazon.com/greengrass/v2/APIReference/API_ListClientDevicesAssociatedWithCoreDevice.html

        :stability: experimental
        '''
        return typing.cast("GreengrassV2", jsii.invoke(self, "toListClientDevicesAssociatedWithCoreDevice", []))

    @jsii.member(jsii_name="toListComponents")
    def to_list_components(self) -> "GreengrassV2":
        '''(experimental) Grants permission to retrieve a paginated list of component summaries.

        Access Level: List

        https://docs.aws.amazon.com/greengrass/v2/APIReference/API_ListComponents.html

        :stability: experimental
        '''
        return typing.cast("GreengrassV2", jsii.invoke(self, "toListComponents", []))

    @jsii.member(jsii_name="toListComponentVersions")
    def to_list_component_versions(self) -> "GreengrassV2":
        '''(experimental) Grants permission to retrieve a paginated list of all versions for a component.

        Access Level: List

        https://docs.aws.amazon.com/greengrass/v2/APIReference/API_ListComponentVersions.html

        :stability: experimental
        '''
        return typing.cast("GreengrassV2", jsii.invoke(self, "toListComponentVersions", []))

    @jsii.member(jsii_name="toListCoreDevices")
    def to_list_core_devices(self) -> "GreengrassV2":
        '''(experimental) Grants permission to retrieve a paginated list of AWS IoT Greengrass core devices.

        Access Level: List

        https://docs.aws.amazon.com/greengrass/v2/APIReference/API_ListCoreDevices.html

        :stability: experimental
        '''
        return typing.cast("GreengrassV2", jsii.invoke(self, "toListCoreDevices", []))

    @jsii.member(jsii_name="toListDeployments")
    def to_list_deployments(self) -> "GreengrassV2":
        '''(experimental) Grants permission to retrieves a paginated list of deployments.

        Access Level: List

        Dependent actions:

        - iot:DescribeJob
        - iot:DescribeThing
        - iot:DescribeThingGroup
        - iot:GetThingShadow

        https://docs.aws.amazon.com/greengrass/v2/APIReference/API_ListDeployments.html

        :stability: experimental
        '''
        return typing.cast("GreengrassV2", jsii.invoke(self, "toListDeployments", []))

    @jsii.member(jsii_name="toListEffectiveDeployments")
    def to_list_effective_deployments(self) -> "GreengrassV2":
        '''(experimental) Grants permission to retrieves a paginated list of deployment jobs that AWS IoT Greengrass sends to AWS IoT Greengrass core devices.

        Access Level: List

        Dependent actions:

        - iot:DescribeJob
        - iot:DescribeJobExecution
        - iot:DescribeThing
        - iot:DescribeThingGroup
        - iot:GetThingShadow

        https://docs.aws.amazon.com/greengrass/v2/APIReference/API_ListEffectiveDeployments.html

        :stability: experimental
        '''
        return typing.cast("GreengrassV2", jsii.invoke(self, "toListEffectiveDeployments", []))

    @jsii.member(jsii_name="toListInstalledComponents")
    def to_list_installed_components(self) -> "GreengrassV2":
        '''(experimental) Grants permission to retrieve a paginated list of the components that a AWS IoT Greengrass core device runs.

        Access Level: List

        https://docs.aws.amazon.com/greengrass/v2/APIReference/API_ListInstalledComponents.html

        :stability: experimental
        '''
        return typing.cast("GreengrassV2", jsii.invoke(self, "toListInstalledComponents", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "GreengrassV2":
        '''(experimental) Grants permission to list the tags for a resource.

        Access Level: Read

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/greengrass/v2/APIReference/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("GreengrassV2", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toResolveComponentCandidates")
    def to_resolve_component_candidates(self) -> "GreengrassV2":
        '''(experimental) Grants permission to list components that meet the component, version, and platform requirements of a deployment.

        Access Level: List

        https://docs.aws.amazon.com/greengrass/v2/APIReference/API_ResolveComponentCandidates.html

        :stability: experimental
        '''
        return typing.cast("GreengrassV2", jsii.invoke(self, "toResolveComponentCandidates", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "GreengrassV2":
        '''(experimental) Grants permission to add tags to a resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/greengrass/v2/APIReference/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("GreengrassV2", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "GreengrassV2":
        '''(experimental) Grants permission to remove tags from a resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/greengrass/v2/APIReference/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("GreengrassV2", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateConnectivityInfo")
    def to_update_connectivity_info(self) -> "GreengrassV2":
        '''(experimental) Grants permission to update the connectivity information for a Greengrass core.

        Any devices that belong to the group that has this core will receive this information in order to find the location of the core and connect to it

        Access Level: Write

        Dependent actions:

        - iot:GetThingShadow
        - iot:UpdateThingShadow

        https://docs.aws.amazon.com/greengrass/v2/APIReference/API_UpdateConnectivityInfo.html

        :stability: experimental
        '''
        return typing.cast("GreengrassV2", jsii.invoke(self, "toUpdateConnectivityInfo", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4c0f3c405c5dceca4771cafda0a7e178b3d0f85cbf631491a983111cb0e55eda)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ebb70652d0bc19763bcd0bb347655c98564d08fc19bf9357e9a5cd06169a431e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Groundstation(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Groundstation",
):
    '''(experimental) Statement provider for service `groundstation <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsgroundstation.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `groundstation <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsgroundstation.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="ifConfigId")
    def if_config_id(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Groundstation":
        '''(experimental) Filters access by the ID of a config.

        https://docs.aws.amazon.com/ground-station/latest/APIReference/API_CreateConfig.html#groundstation-CreateConfig-response-configId

        Applies to resource types:

        - Config

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5ecc52419c4e0e32080614e488984183ecbe363409785b7ef81e4b5d74339270)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Groundstation", jsii.invoke(self, "ifConfigId", [value, operator]))

    @jsii.member(jsii_name="ifConfigType")
    def if_config_type(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Groundstation":
        '''(experimental) Filters access by the type of a config.

        https://docs.aws.amazon.com/ground-station/latest/APIReference/API_CreateConfig.html#groundstation-CreateConfig-response-configType

        Applies to resource types:

        - Config

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__aa16de2fe94279756fdec80634470eebe2782f8733c9d9e1180d6db2e0024810)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Groundstation", jsii.invoke(self, "ifConfigType", [value, operator]))

    @jsii.member(jsii_name="ifContactId")
    def if_contact_id(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Groundstation":
        '''(experimental) Filters access by the ID of a contact.

        https://docs.aws.amazon.com/ground-station/latest/APIReference/API_ReserveContact.html#groundstation-ReserveContact-response-contactId

        Applies to resource types:

        - Contact

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c276ab5b9af52df248bd0223449799f9341fce56614f698073a6f28b63eec9fa)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Groundstation", jsii.invoke(self, "ifContactId", [value, operator]))

    @jsii.member(jsii_name="ifDataflowEndpointGroupId")
    def if_dataflow_endpoint_group_id(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Groundstation":
        '''(experimental) Filters access by the ID of a dataflow endpoint group.

        https://docs.aws.amazon.com/ground-station/latest/APIReference/API_CreateDataflowEndpointGroup.html#groundstation-CreateDataflowEndpointGroup-response-dataflowEndpointGroupId

        Applies to resource types:

        - DataflowEndpointGroup

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__54f61a0d767d6c87ea41209131afd282c06fec0e2091ae663b2fb9e8e0ee691e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Groundstation", jsii.invoke(self, "ifDataflowEndpointGroupId", [value, operator]))

    @jsii.member(jsii_name="ifGroundStationId")
    def if_ground_station_id(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Groundstation":
        '''(experimental) Filters access by the ID of a ground station.

        https://docs.aws.amazon.com/ground-station/latest/APIReference/API_GroundStationData.html#groundstation-Type-GroundStationData-groundStationId

        Applies to resource types:

        - GroundStationResource

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8be15834a248ad26d046d838bb5ad038474a083f39595893e6d82dc74eb1a04c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Groundstation", jsii.invoke(self, "ifGroundStationId", [value, operator]))

    @jsii.member(jsii_name="ifMissionProfileId")
    def if_mission_profile_id(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Groundstation":
        '''(experimental) Filters access by the ID of a mission profile.

        https://docs.aws.amazon.com/ground-station/latest/APIReference/API_CreateMissionProfile.html#groundstation-CreateMissionProfile-response-missionProfileId

        Applies to resource types:

        - MissionProfile

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__dd3a2688bd00e5b4145e14fa3e9c9b5bb44f55b539cf4e350c05960701f14c0d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Groundstation", jsii.invoke(self, "ifMissionProfileId", [value, operator]))

    @jsii.member(jsii_name="ifSatelliteId")
    def if_satellite_id(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Groundstation":
        '''(experimental) Filters access by the ID of a satellite.

        https://docs.aws.amazon.com/ground-station/latest/APIReference/API_SatelliteListItem.html#groundstation-Type-SatelliteListItem-satelliteId

        Applies to resource types:

        - Satellite

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2c69e9c8648b8dbf33f7a60834b410972beb744193a6783382e8efec6fa96187)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Groundstation", jsii.invoke(self, "ifSatelliteId", [value, operator]))

    @jsii.member(jsii_name="onConfig")
    def on_config(
        self,
        config_type: builtins.str,
        config_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Groundstation":
        '''(experimental) Adds a resource of type Config to the statement.

        https://docs.aws.amazon.com/ground-station/latest/APIReference/API_ConfigListItem.html

        :param config_type: - Identifier for the configType.
        :param config_id: - Identifier for the configId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag() - .ifConfigId() - .ifConfigType()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0d50340f48d773cabe2f5f4ef0c0317ce945c0138a129183751d479432ccdbc4)
            check_type(argname="argument config_type", value=config_type, expected_type=type_hints["config_type"])
            check_type(argname="argument config_id", value=config_id, expected_type=type_hints["config_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Groundstation", jsii.invoke(self, "onConfig", [config_type, config_id, account, region, partition]))

    @jsii.member(jsii_name="onContact")
    def on_contact(
        self,
        contact_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Groundstation":
        '''(experimental) Adds a resource of type Contact to the statement.

        https://docs.aws.amazon.com/ground-station/latest/APIReference/API_ContactData.html

        :param contact_id: - Identifier for the contactId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag() - .ifContactId()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ff0837f771bec3d920613dfe21834cd4265d7c5813014b21d02a889aff982922)
            check_type(argname="argument contact_id", value=contact_id, expected_type=type_hints["contact_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Groundstation", jsii.invoke(self, "onContact", [contact_id, account, region, partition]))

    @jsii.member(jsii_name="onDataflowEndpointGroup")
    def on_dataflow_endpoint_group(
        self,
        dataflow_endpoint_group_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Groundstation":
        '''(experimental) Adds a resource of type DataflowEndpointGroup to the statement.

        https://docs.aws.amazon.com/ground-station/latest/APIReference/API_DataflowEndpoint.html

        :param dataflow_endpoint_group_id: - Identifier for the dataflowEndpointGroupId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag() - .ifDataflowEndpointGroupId()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bd1da9220d4ae8eac4d555c9cdaa00cfa2dcd33de155798f2746204bc90cf0ab)
            check_type(argname="argument dataflow_endpoint_group_id", value=dataflow_endpoint_group_id, expected_type=type_hints["dataflow_endpoint_group_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Groundstation", jsii.invoke(self, "onDataflowEndpointGroup", [dataflow_endpoint_group_id, account, region, partition]))

    @jsii.member(jsii_name="onGroundStationResource")
    def on_ground_station_resource(
        self,
        ground_station_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Groundstation":
        '''(experimental) Adds a resource of type GroundStationResource to the statement.

        https://docs.aws.amazon.com/ground-station/latest/APIReference/API_GroundStationData.html

        :param ground_station_id: - Identifier for the groundStationId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifGroundStationId()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__274b99d114d58b1450baed068b71d041e91473d4478cc02877f9460985c7b2f4)
            check_type(argname="argument ground_station_id", value=ground_station_id, expected_type=type_hints["ground_station_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Groundstation", jsii.invoke(self, "onGroundStationResource", [ground_station_id, account, region, partition]))

    @jsii.member(jsii_name="onMissionProfile")
    def on_mission_profile(
        self,
        mission_profile_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Groundstation":
        '''(experimental) Adds a resource of type MissionProfile to the statement.

        https://docs.aws.amazon.com/ground-station/latest/APIReference/API_MissionProfileListItem.html

        :param mission_profile_id: - Identifier for the missionProfileId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag() - .ifMissionProfileId()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__df1baf626cad71cd92aff8d24a3858ee192a2b2cd654ceebe451675c486f269c)
            check_type(argname="argument mission_profile_id", value=mission_profile_id, expected_type=type_hints["mission_profile_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Groundstation", jsii.invoke(self, "onMissionProfile", [mission_profile_id, account, region, partition]))

    @jsii.member(jsii_name="onSatellite")
    def on_satellite(
        self,
        satellite_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Groundstation":
        '''(experimental) Adds a resource of type Satellite to the statement.

        https://docs.aws.amazon.com/ground-station/latest/APIReference/API_SatelliteListItem.html

        :param satellite_id: - Identifier for the satelliteId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifSatelliteId()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__42e38978678c1fd62b224c673b192fd6843281c79b41c3a081de570784bb7863)
            check_type(argname="argument satellite_id", value=satellite_id, expected_type=type_hints["satellite_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Groundstation", jsii.invoke(self, "onSatellite", [satellite_id, account, region, partition]))

    @jsii.member(jsii_name="toCancelContact")
    def to_cancel_contact(self) -> "Groundstation":
        '''(experimental) Grants permission to cancel a contact.

        Access Level: Write

        https://docs.aws.amazon.com/ground-station/latest/APIReference/API_CancelContact.html

        :stability: experimental
        '''
        return typing.cast("Groundstation", jsii.invoke(self, "toCancelContact", []))

    @jsii.member(jsii_name="toCreateConfig")
    def to_create_config(self) -> "Groundstation":
        '''(experimental) Grants permission to create a configuration.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/ground-station/latest/APIReference/API_CreateConfig.html

        :stability: experimental
        '''
        return typing.cast("Groundstation", jsii.invoke(self, "toCreateConfig", []))

    @jsii.member(jsii_name="toCreateDataflowEndpointGroup")
    def to_create_dataflow_endpoint_group(self) -> "Groundstation":
        '''(experimental) Grants permission to create a data flow endpoint group.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/ground-station/latest/APIReference/API_CreateDataflowEndpointGroup.html

        :stability: experimental
        '''
        return typing.cast("Groundstation", jsii.invoke(self, "toCreateDataflowEndpointGroup", []))

    @jsii.member(jsii_name="toCreateMissionProfile")
    def to_create_mission_profile(self) -> "Groundstation":
        '''(experimental) Grants permission to create a mission profile.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/ground-station/latest/APIReference/API_CreateMissionProfile.html

        :stability: experimental
        '''
        return typing.cast("Groundstation", jsii.invoke(self, "toCreateMissionProfile", []))

    @jsii.member(jsii_name="toDeleteConfig")
    def to_delete_config(self) -> "Groundstation":
        '''(experimental) Grants permission to delete a config.

        Access Level: Write

        https://docs.aws.amazon.com/ground-station/latest/APIReference/API_DeleteConfig.html

        :stability: experimental
        '''
        return typing.cast("Groundstation", jsii.invoke(self, "toDeleteConfig", []))

    @jsii.member(jsii_name="toDeleteDataflowEndpointGroup")
    def to_delete_dataflow_endpoint_group(self) -> "Groundstation":
        '''(experimental) Grants permission to delete a data flow endpoint group.

        Access Level: Write

        https://docs.aws.amazon.com/ground-station/latest/APIReference/API_DeleteDataflowEndpointGroup.html

        :stability: experimental
        '''
        return typing.cast("Groundstation", jsii.invoke(self, "toDeleteDataflowEndpointGroup", []))

    @jsii.member(jsii_name="toDeleteMissionProfile")
    def to_delete_mission_profile(self) -> "Groundstation":
        '''(experimental) Grants permission to delete a mission profile.

        Access Level: Write

        https://docs.aws.amazon.com/ground-station/latest/APIReference/API_DeleteMissionProfile.html

        :stability: experimental
        '''
        return typing.cast("Groundstation", jsii.invoke(self, "toDeleteMissionProfile", []))

    @jsii.member(jsii_name="toDescribeContact")
    def to_describe_contact(self) -> "Groundstation":
        '''(experimental) Grants permission to describe a contact.

        Access Level: Read

        https://docs.aws.amazon.com/ground-station/latest/APIReference/API_DescribeContact.html

        :stability: experimental
        '''
        return typing.cast("Groundstation", jsii.invoke(self, "toDescribeContact", []))

    @jsii.member(jsii_name="toGetConfig")
    def to_get_config(self) -> "Groundstation":
        '''(experimental) Grants permission to return a configuration.

        Access Level: Read

        https://docs.aws.amazon.com/ground-station/latest/APIReference/API_GetConfig.html

        :stability: experimental
        '''
        return typing.cast("Groundstation", jsii.invoke(self, "toGetConfig", []))

    @jsii.member(jsii_name="toGetDataflowEndpointGroup")
    def to_get_dataflow_endpoint_group(self) -> "Groundstation":
        '''(experimental) Grants permission to return a data flow endpoint group.

        Access Level: Read

        https://docs.aws.amazon.com/ground-station/latest/APIReference/API_GetDataflowEndpointGroup.html

        :stability: experimental
        '''
        return typing.cast("Groundstation", jsii.invoke(self, "toGetDataflowEndpointGroup", []))

    @jsii.member(jsii_name="toGetMinuteUsage")
    def to_get_minute_usage(self) -> "Groundstation":
        '''(experimental) Grants permission to return minutes usage.

        Access Level: Read

        https://docs.aws.amazon.com/ground-station/latest/APIReference/API_GetMinuteUsage.html

        :stability: experimental
        '''
        return typing.cast("Groundstation", jsii.invoke(self, "toGetMinuteUsage", []))

    @jsii.member(jsii_name="toGetMissionProfile")
    def to_get_mission_profile(self) -> "Groundstation":
        '''(experimental) Grants permission to retrieve a mission profile.

        Access Level: Read

        https://docs.aws.amazon.com/ground-station/latest/APIReference/API_GetMissionProfile.html

        :stability: experimental
        '''
        return typing.cast("Groundstation", jsii.invoke(self, "toGetMissionProfile", []))

    @jsii.member(jsii_name="toGetSatellite")
    def to_get_satellite(self) -> "Groundstation":
        '''(experimental) Grants permission to return information about a satellite.

        Access Level: Read

        https://docs.aws.amazon.com/ground-station/latest/APIReference/API_GetSatellite.html

        :stability: experimental
        '''
        return typing.cast("Groundstation", jsii.invoke(self, "toGetSatellite", []))

    @jsii.member(jsii_name="toListConfigs")
    def to_list_configs(self) -> "Groundstation":
        '''(experimental) Grants permission to return a list of past configurations.

        Access Level: List

        https://docs.aws.amazon.com/ground-station/latest/APIReference/API_ListConfigs.html

        :stability: experimental
        '''
        return typing.cast("Groundstation", jsii.invoke(self, "toListConfigs", []))

    @jsii.member(jsii_name="toListContacts")
    def to_list_contacts(self) -> "Groundstation":
        '''(experimental) Grants permission to return a list of contacts.

        Access Level: List

        https://docs.aws.amazon.com/ground-station/latest/APIReference/API_ListContacts.html

        :stability: experimental
        '''
        return typing.cast("Groundstation", jsii.invoke(self, "toListContacts", []))

    @jsii.member(jsii_name="toListDataflowEndpointGroups")
    def to_list_dataflow_endpoint_groups(self) -> "Groundstation":
        '''(experimental) Grants permission to list data flow endpoint groups.

        Access Level: List

        https://docs.aws.amazon.com/ground-station/latest/APIReference/API_ListDataflowEndpointGroups.html

        :stability: experimental
        '''
        return typing.cast("Groundstation", jsii.invoke(self, "toListDataflowEndpointGroups", []))

    @jsii.member(jsii_name="toListGroundStations")
    def to_list_ground_stations(self) -> "Groundstation":
        '''(experimental) Grants permission to list ground stations.

        Access Level: List

        https://docs.aws.amazon.com/ground-station/latest/APIReference/API_ListGroundStations.html

        :stability: experimental
        '''
        return typing.cast("Groundstation", jsii.invoke(self, "toListGroundStations", []))

    @jsii.member(jsii_name="toListMissionProfiles")
    def to_list_mission_profiles(self) -> "Groundstation":
        '''(experimental) Grants permission to return a list of mission profiles.

        Access Level: List

        https://docs.aws.amazon.com/ground-station/latest/APIReference/API_ListMissionProfiles.html

        :stability: experimental
        '''
        return typing.cast("Groundstation", jsii.invoke(self, "toListMissionProfiles", []))

    @jsii.member(jsii_name="toListSatellites")
    def to_list_satellites(self) -> "Groundstation":
        '''(experimental) Grants permission to list satellites.

        Access Level: List

        https://docs.aws.amazon.com/ground-station/latest/APIReference/API_ListSatellites.html

        :stability: experimental
        '''
        return typing.cast("Groundstation", jsii.invoke(self, "toListSatellites", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Groundstation":
        '''(experimental) Grants permission to list tags for a resource.

        Access Level: Read

        https://docs.aws.amazon.com/ground-station/latest/APIReference/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("Groundstation", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toReserveContact")
    def to_reserve_contact(self) -> "Groundstation":
        '''(experimental) Grants permission to reserve a contact.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/ground-station/latest/APIReference/API_ReserveContact.html

        :stability: experimental
        '''
        return typing.cast("Groundstation", jsii.invoke(self, "toReserveContact", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Groundstation":
        '''(experimental) Grants permission to assign a resource tag.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/ground-station/latest/APIReference/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("Groundstation", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Groundstation":
        '''(experimental) Grants permission to deassign a resource tag.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/ground-station/latest/APIReference/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("Groundstation", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateConfig")
    def to_update_config(self) -> "Groundstation":
        '''(experimental) Grants permission to update a configuration.

        Access Level: Write

        https://docs.aws.amazon.com/ground-station/latest/APIReference/API_UpdateConfig.html

        :stability: experimental
        '''
        return typing.cast("Groundstation", jsii.invoke(self, "toUpdateConfig", []))

    @jsii.member(jsii_name="toUpdateMissionProfile")
    def to_update_mission_profile(self) -> "Groundstation":
        '''(experimental) Grants permission to update a mission profile.

        Access Level: Write

        https://docs.aws.amazon.com/ground-station/latest/APIReference/API_UpdateMissionProfile.html

        :stability: experimental
        '''
        return typing.cast("Groundstation", jsii.invoke(self, "toUpdateMissionProfile", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ca17e5cfcd355a07b28ff1f725c1ee1bebd71e2e87e8bd2a70e839d68b597ee8)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b48613eaee2fd6d9d66fc5ed75dd3138be7f7311eb18719847ed79b2dcd571e9)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Groundtruthlabeling(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Groundtruthlabeling",
):
    '''(experimental) Statement provider for service `groundtruthlabeling <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazongroundtruthlabeling.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `groundtruthlabeling <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazongroundtruthlabeling.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="toAssociatePatchToManifestJob")
    def to_associate_patch_to_manifest_job(self) -> "Groundtruthlabeling":
        '''(experimental) Grants permission to associate a patch file with the manifest file to update the manifest file.

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/dg/sms-data-input.html#sms-console-create-manifest-file

        :stability: experimental
        '''
        return typing.cast("Groundtruthlabeling", jsii.invoke(self, "toAssociatePatchToManifestJob", []))

    @jsii.member(jsii_name="toDescribeConsoleJob")
    def to_describe_console_job(self) -> "Groundtruthlabeling":
        '''(experimental) Grants permission to get status of GroundTruthLabeling Jobs.

        Access Level: Read

        https://docs.aws.amazon.com/sagemaker/latest/dg/sms-data-input.html#sms-console-create-manifest-file

        :stability: experimental
        '''
        return typing.cast("Groundtruthlabeling", jsii.invoke(self, "toDescribeConsoleJob", []))

    @jsii.member(jsii_name="toListDatasetObjects")
    def to_list_dataset_objects(self) -> "Groundtruthlabeling":
        '''(experimental) Grants permission to list dataset objects in a manifest file.

        Access Level: Read

        https://docs.aws.amazon.com/sagemaker/latest/dg/sms-data-input.html#sms-console-create-manifest-file

        :stability: experimental
        '''
        return typing.cast("Groundtruthlabeling", jsii.invoke(self, "toListDatasetObjects", []))

    @jsii.member(jsii_name="toRunFilterOrSampleDatasetJob")
    def to_run_filter_or_sample_dataset_job(self) -> "Groundtruthlabeling":
        '''(experimental) Grants permission to filter records from a manifest file using S3 select. Get sample entries based on random sampling.

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/dg/sms-data-input.html#sms-data-filtering

        :stability: experimental
        '''
        return typing.cast("Groundtruthlabeling", jsii.invoke(self, "toRunFilterOrSampleDatasetJob", []))

    @jsii.member(jsii_name="toRunGenerateManifestByCrawlingJob")
    def to_run_generate_manifest_by_crawling_job(self) -> "Groundtruthlabeling":
        '''(experimental) Grants permission to list a S3 prefix and create manifest files from objects in that location.

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/dg/sms-data-input.html#sms-console-create-manifest-file

        :stability: experimental
        '''
        return typing.cast("Groundtruthlabeling", jsii.invoke(self, "toRunGenerateManifestByCrawlingJob", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ad2096ec42d0cac6f047797ba51946b00fe6e2f5b8422f96df0089da4b1d408f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__91d4b6a70693726320325a877e4400d3963d8ada7263986890daf8421b5b8f19)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Guardduty(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Guardduty",
):
    '''(experimental) Statement provider for service `guardduty <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonguardduty.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `guardduty <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonguardduty.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onDetector")
    def on_detector(
        self,
        detector_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Guardduty":
        '''(experimental) Adds a resource of type detector to the statement.

        https://docs.aws.amazon.com/guardduty/latest/ug/guardduty_managing_access.html#guardduty-resources

        :param detector_id: - Identifier for the detectorId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__cea7df3a9955fe5ee0e9955e1c50f525aebc8a62c3f2d3fe6821b7b0727d3e28)
            check_type(argname="argument detector_id", value=detector_id, expected_type=type_hints["detector_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Guardduty", jsii.invoke(self, "onDetector", [detector_id, account, region, partition]))

    @jsii.member(jsii_name="onFilter")
    def on_filter(
        self,
        detector_id: builtins.str,
        filter_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Guardduty":
        '''(experimental) Adds a resource of type filter to the statement.

        https://docs.aws.amazon.com/guardduty/latest/ug/guardduty_managing_access.html#guardduty-resources

        :param detector_id: - Identifier for the detectorId.
        :param filter_name: - Identifier for the filterName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ad1d5f712064010f8743e32126c9d8a2ffa7efb2ea14e762edcbb2bb41ccbec0)
            check_type(argname="argument detector_id", value=detector_id, expected_type=type_hints["detector_id"])
            check_type(argname="argument filter_name", value=filter_name, expected_type=type_hints["filter_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Guardduty", jsii.invoke(self, "onFilter", [detector_id, filter_name, account, region, partition]))

    @jsii.member(jsii_name="onIpset")
    def on_ipset(
        self,
        detector_id: builtins.str,
        i_p_set_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Guardduty":
        '''(experimental) Adds a resource of type ipset to the statement.

        https://docs.aws.amazon.com/guardduty/latest/ug/guardduty_managing_access.html#guardduty-resources

        :param detector_id: - Identifier for the detectorId.
        :param i_p_set_id: - Identifier for the iPSetId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e86ec17e7ea8bf805b5873c87938d8772a58f9551aadc86c1814646a1364f00a)
            check_type(argname="argument detector_id", value=detector_id, expected_type=type_hints["detector_id"])
            check_type(argname="argument i_p_set_id", value=i_p_set_id, expected_type=type_hints["i_p_set_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Guardduty", jsii.invoke(self, "onIpset", [detector_id, i_p_set_id, account, region, partition]))

    @jsii.member(jsii_name="onPublishingDestination")
    def on_publishing_destination(
        self,
        detector_id: builtins.str,
        publishing_destination_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Guardduty":
        '''(experimental) Adds a resource of type publishingDestination to the statement.

        https://docs.aws.amazon.com/guardduty/latest/ug/guardduty_managing_access.html#guardduty-resources

        :param detector_id: - Identifier for the detectorId.
        :param publishing_destination_id: - Identifier for the publishingDestinationId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__241896856ec8e8c1302db39f1e7243d8fd8edb66749c390d136f502faaec8055)
            check_type(argname="argument detector_id", value=detector_id, expected_type=type_hints["detector_id"])
            check_type(argname="argument publishing_destination_id", value=publishing_destination_id, expected_type=type_hints["publishing_destination_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Guardduty", jsii.invoke(self, "onPublishingDestination", [detector_id, publishing_destination_id, account, region, partition]))

    @jsii.member(jsii_name="onThreatintelset")
    def on_threatintelset(
        self,
        detector_id: builtins.str,
        threat_intel_set_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Guardduty":
        '''(experimental) Adds a resource of type threatintelset to the statement.

        https://docs.aws.amazon.com/guardduty/latest/ug/guardduty_managing_access.html#guardduty-resources

        :param detector_id: - Identifier for the detectorId.
        :param threat_intel_set_id: - Identifier for the threatIntelSetId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b022d497353262a2a3eea251c14c61c1520e94121492ba7fce2f150f3eef4574)
            check_type(argname="argument detector_id", value=detector_id, expected_type=type_hints["detector_id"])
            check_type(argname="argument threat_intel_set_id", value=threat_intel_set_id, expected_type=type_hints["threat_intel_set_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Guardduty", jsii.invoke(self, "onThreatintelset", [detector_id, threat_intel_set_id, account, region, partition]))

    @jsii.member(jsii_name="toAcceptInvitation")
    def to_accept_invitation(self) -> "Guardduty":
        '''(experimental) Grants permission to accept invitations to become a GuardDuty member account.

        Access Level: Write

        https://docs.aws.amazon.com/guardduty/latest/APIReference/API_AcceptInvitation.html

        :stability: experimental
        '''
        return typing.cast("Guardduty", jsii.invoke(self, "toAcceptInvitation", []))

    @jsii.member(jsii_name="toArchiveFindings")
    def to_archive_findings(self) -> "Guardduty":
        '''(experimental) Grants permission to archive GuardDuty findings.

        Access Level: Write

        https://docs.aws.amazon.com/guardduty/latest/APIReference/API_ArchiveFindings.html

        :stability: experimental
        '''
        return typing.cast("Guardduty", jsii.invoke(self, "toArchiveFindings", []))

    @jsii.member(jsii_name="toCreateDetector")
    def to_create_detector(self) -> "Guardduty":
        '''(experimental) Grants permission to create a detector.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/guardduty/latest/APIReference/API_CreateDetector.html

        :stability: experimental
        '''
        return typing.cast("Guardduty", jsii.invoke(self, "toCreateDetector", []))

    @jsii.member(jsii_name="toCreateFilter")
    def to_create_filter(self) -> "Guardduty":
        '''(experimental) Grants permission to create GuardDuty filters. A filters defines finding attributes and conditions used to filter findings.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/guardduty/latest/APIReference/API_CreateFilter.html

        :stability: experimental
        '''
        return typing.cast("Guardduty", jsii.invoke(self, "toCreateFilter", []))

    @jsii.member(jsii_name="toCreateIPSet")
    def to_create_ip_set(self) -> "Guardduty":
        '''(experimental) Grants permission to create an IPSet.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - iam:DeleteRolePolicy
        - iam:PutRolePolicy

        https://docs.aws.amazon.com/guardduty/latest/APIReference/API_CreateIPSet.html

        :stability: experimental
        '''
        return typing.cast("Guardduty", jsii.invoke(self, "toCreateIPSet", []))

    @jsii.member(jsii_name="toCreateMembers")
    def to_create_members(self) -> "Guardduty":
        '''(experimental) Grants permission to create GuardDuty member accounts, where the account used to create a member becomes the GuardDuty administrator account.

        Access Level: Write

        https://docs.aws.amazon.com/guardduty/latest/APIReference/API_CreateMembers.html

        :stability: experimental
        '''
        return typing.cast("Guardduty", jsii.invoke(self, "toCreateMembers", []))

    @jsii.member(jsii_name="toCreatePublishingDestination")
    def to_create_publishing_destination(self) -> "Guardduty":
        '''(experimental) Grants permission to create a publishing destination.

        Access Level: Write

        Dependent actions:

        - s3:GetObject
        - s3:ListBucket

        https://docs.aws.amazon.com/guardduty/latest/APIReference/API_CreatePublishingDestination.html

        :stability: experimental
        '''
        return typing.cast("Guardduty", jsii.invoke(self, "toCreatePublishingDestination", []))

    @jsii.member(jsii_name="toCreateSampleFindings")
    def to_create_sample_findings(self) -> "Guardduty":
        '''(experimental) Grants permission to create sample findings.

        Access Level: Write

        https://docs.aws.amazon.com/guardduty/latest/APIReference/API_CreateSampleFindings.html

        :stability: experimental
        '''
        return typing.cast("Guardduty", jsii.invoke(self, "toCreateSampleFindings", []))

    @jsii.member(jsii_name="toCreateThreatIntelSet")
    def to_create_threat_intel_set(self) -> "Guardduty":
        '''(experimental) Grants permission to create GuardDuty ThreatIntelSets, where a ThreatIntelSet consists of known malicious IP addresses used by GuardDuty to generate findings.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/guardduty/latest/APIReference/API_CreateThreatIntelSet.html

        :stability: experimental
        '''
        return typing.cast("Guardduty", jsii.invoke(self, "toCreateThreatIntelSet", []))

    @jsii.member(jsii_name="toDeclineInvitations")
    def to_decline_invitations(self) -> "Guardduty":
        '''(experimental) Grants permission to decline invitations to become a GuardDuty member account.

        Access Level: Write

        https://docs.aws.amazon.com/guardduty/latest/APIReference/API_DeclineInvitations.html

        :stability: experimental
        '''
        return typing.cast("Guardduty", jsii.invoke(self, "toDeclineInvitations", []))

    @jsii.member(jsii_name="toDeleteDetector")
    def to_delete_detector(self) -> "Guardduty":
        '''(experimental) Grants permission to delete GuardDuty detectors.

        Access Level: Write

        https://docs.aws.amazon.com/guardduty/latest/APIReference/API_DeleteDetector.html

        :stability: experimental
        '''
        return typing.cast("Guardduty", jsii.invoke(self, "toDeleteDetector", []))

    @jsii.member(jsii_name="toDeleteFilter")
    def to_delete_filter(self) -> "Guardduty":
        '''(experimental) Grants permission to delete GuardDuty filters.

        Access Level: Write

        https://docs.aws.amazon.com/guardduty/latest/APIReference/API_DeleteFilter.html

        :stability: experimental
        '''
        return typing.cast("Guardduty", jsii.invoke(self, "toDeleteFilter", []))

    @jsii.member(jsii_name="toDeleteInvitations")
    def to_delete_invitations(self) -> "Guardduty":
        '''(experimental) Grants permission to delete invitations to become a GuardDuty member account.

        Access Level: Write

        https://docs.aws.amazon.com/guardduty/latest/APIReference/API_DeleteInvitations.html

        :stability: experimental
        '''
        return typing.cast("Guardduty", jsii.invoke(self, "toDeleteInvitations", []))

    @jsii.member(jsii_name="toDeleteIPSet")
    def to_delete_ip_set(self) -> "Guardduty":
        '''(experimental) Grants permission to delete GuardDuty IPSets.

        Access Level: Write

        https://docs.aws.amazon.com/guardduty/latest/APIReference/API_DeleteIPSet.html

        :stability: experimental
        '''
        return typing.cast("Guardduty", jsii.invoke(self, "toDeleteIPSet", []))

    @jsii.member(jsii_name="toDeleteMembers")
    def to_delete_members(self) -> "Guardduty":
        '''(experimental) Grants permission to delete GuardDuty member accounts.

        Access Level: Write

        https://docs.aws.amazon.com/guardduty/latest/APIReference/API_DeleteMembers.html

        :stability: experimental
        '''
        return typing.cast("Guardduty", jsii.invoke(self, "toDeleteMembers", []))

    @jsii.member(jsii_name="toDeletePublishingDestination")
    def to_delete_publishing_destination(self) -> "Guardduty":
        '''(experimental) Grants permission to delete a publishing destination.

        Access Level: Write

        https://docs.aws.amazon.com/guardduty/latest/APIReference/API_DeletePublishingDestination.html

        :stability: experimental
        '''
        return typing.cast("Guardduty", jsii.invoke(self, "toDeletePublishingDestination", []))

    @jsii.member(jsii_name="toDeleteThreatIntelSet")
    def to_delete_threat_intel_set(self) -> "Guardduty":
        '''(experimental) Grants permission to delete GuardDuty ThreatIntelSets.

        Access Level: Write

        https://docs.aws.amazon.com/guardduty/latest/APIReference/API_DeleteThreatIntelSet.html

        :stability: experimental
        '''
        return typing.cast("Guardduty", jsii.invoke(self, "toDeleteThreatIntelSet", []))

    @jsii.member(jsii_name="toDescribeMalwareScans")
    def to_describe_malware_scans(self) -> "Guardduty":
        '''(experimental) Grants permission to retrieve details about malware scans.

        Access Level: Read

        https://docs.aws.amazon.com/guardduty/latest/APIReference/API_DescribeMalwareScans.html

        :stability: experimental
        '''
        return typing.cast("Guardduty", jsii.invoke(self, "toDescribeMalwareScans", []))

    @jsii.member(jsii_name="toDescribeOrganizationConfiguration")
    def to_describe_organization_configuration(self) -> "Guardduty":
        '''(experimental) Grants permission to retrieve details about the delegated administrator associated with a GuardDuty detector.

        Access Level: Read

        https://docs.aws.amazon.com/guardduty/latest/APIReference/API_DescribeOrganizationConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Guardduty", jsii.invoke(self, "toDescribeOrganizationConfiguration", []))

    @jsii.member(jsii_name="toDescribePublishingDestination")
    def to_describe_publishing_destination(self) -> "Guardduty":
        '''(experimental) Grants permission to retrieve details about a publishing destination.

        Access Level: Read

        https://docs.aws.amazon.com/guardduty/latest/APIReference/API_DescribePublishingDestination.html

        :stability: experimental
        '''
        return typing.cast("Guardduty", jsii.invoke(self, "toDescribePublishingDestination", []))

    @jsii.member(jsii_name="toDisableOrganizationAdminAccount")
    def to_disable_organization_admin_account(self) -> "Guardduty":
        '''(experimental) Grants permission to disable the organization delegated administrator for GuardDuty.

        Access Level: Write

        https://docs.aws.amazon.com/guardduty/latest/APIReference/API_DisableOrganizationAdminAccount.html

        :stability: experimental
        '''
        return typing.cast("Guardduty", jsii.invoke(self, "toDisableOrganizationAdminAccount", []))

    @jsii.member(jsii_name="toDisassociateFromMasterAccount")
    def to_disassociate_from_master_account(self) -> "Guardduty":
        '''(experimental) Grants permission to disassociate a GuardDuty member account from its GuardDuty administrator account.

        Access Level: Write

        https://docs.aws.amazon.com/guardduty/latest/APIReference/API_DisassociateFromMasterAccount.html

        :stability: experimental
        '''
        return typing.cast("Guardduty", jsii.invoke(self, "toDisassociateFromMasterAccount", []))

    @jsii.member(jsii_name="toDisassociateMembers")
    def to_disassociate_members(self) -> "Guardduty":
        '''(experimental) Grants permission to disassociate GuardDuty member accounts from their administrator GuardDuty account.

        Access Level: Write

        https://docs.aws.amazon.com/guardduty/latest/APIReference/API_DisassociateMembers.html

        :stability: experimental
        '''
        return typing.cast("Guardduty", jsii.invoke(self, "toDisassociateMembers", []))

    @jsii.member(jsii_name="toEnableOrganizationAdminAccount")
    def to_enable_organization_admin_account(self) -> "Guardduty":
        '''(experimental) Grants permission to enable an organization delegated administrator for GuardDuty.

        Access Level: Write

        https://docs.aws.amazon.com/guardduty/latest/APIReference/API_EnableOrganizationAdminAccount.html

        :stability: experimental
        '''
        return typing.cast("Guardduty", jsii.invoke(self, "toEnableOrganizationAdminAccount", []))

    @jsii.member(jsii_name="toGetDetector")
    def to_get_detector(self) -> "Guardduty":
        '''(experimental) Grants permission to retrieve GuardDuty detectors.

        Access Level: Read

        https://docs.aws.amazon.com/guardduty/latest/APIReference/API_GetDetector.html

        :stability: experimental
        '''
        return typing.cast("Guardduty", jsii.invoke(self, "toGetDetector", []))

    @jsii.member(jsii_name="toGetFilter")
    def to_get_filter(self) -> "Guardduty":
        '''(experimental) Grants permission to retrieve GuardDuty filters.

        Access Level: Read

        https://docs.aws.amazon.com/guardduty/latest/APIReference/API_GetFilter.html

        :stability: experimental
        '''
        return typing.cast("Guardduty", jsii.invoke(self, "toGetFilter", []))

    @jsii.member(jsii_name="toGetFindings")
    def to_get_findings(self) -> "Guardduty":
        '''(experimental) Grants permission to retrieve GuardDuty findings.

        Access Level: Read

        https://docs.aws.amazon.com/guardduty/latest/APIReference/API_GetFindings.html

        :stability: experimental
        '''
        return typing.cast("Guardduty", jsii.invoke(self, "toGetFindings", []))

    @jsii.member(jsii_name="toGetFindingsStatistics")
    def to_get_findings_statistics(self) -> "Guardduty":
        '''(experimental) Grants permission to retrieve a list of GuardDuty finding statistics.

        Access Level: Read

        https://docs.aws.amazon.com/guardduty/latest/APIReference/API_GetFindingsStatistics.html

        :stability: experimental
        '''
        return typing.cast("Guardduty", jsii.invoke(self, "toGetFindingsStatistics", []))

    @jsii.member(jsii_name="toGetInvitationsCount")
    def to_get_invitations_count(self) -> "Guardduty":
        '''(experimental) Grants permission to retrieve the count of all GuardDuty invitations sent to a specified account, which does not include the accepted invitation.

        Access Level: Read

        https://docs.aws.amazon.com/guardduty/latest/APIReference/API_GetInvitationsCount.html

        :stability: experimental
        '''
        return typing.cast("Guardduty", jsii.invoke(self, "toGetInvitationsCount", []))

    @jsii.member(jsii_name="toGetIPSet")
    def to_get_ip_set(self) -> "Guardduty":
        '''(experimental) Grants permission to retrieve GuardDuty IPSets.

        Access Level: Read

        https://docs.aws.amazon.com/guardduty/latest/APIReference/API_GetIPSet.html

        :stability: experimental
        '''
        return typing.cast("Guardduty", jsii.invoke(self, "toGetIPSet", []))

    @jsii.member(jsii_name="toGetMalwareScanSettings")
    def to_get_malware_scan_settings(self) -> "Guardduty":
        '''(experimental) Grants permission to retrieve the malware scan settings.

        Access Level: Read

        https://docs.aws.amazon.com/guardduty/latest/APIReference/API_GetMalwareScanSettings.html

        :stability: experimental
        '''
        return typing.cast("Guardduty", jsii.invoke(self, "toGetMalwareScanSettings", []))

    @jsii.member(jsii_name="toGetMasterAccount")
    def to_get_master_account(self) -> "Guardduty":
        '''(experimental) Grants permission to retrieve details of the GuardDuty administrator account associated with a member account.

        Access Level: Read

        https://docs.aws.amazon.com/guardduty/latest/APIReference/API_GetMasterAccount.html

        :stability: experimental
        '''
        return typing.cast("Guardduty", jsii.invoke(self, "toGetMasterAccount", []))

    @jsii.member(jsii_name="toGetMemberDetectors")
    def to_get_member_detectors(self) -> "Guardduty":
        '''(experimental) Grants permission to describe which data sources are enabled for member accounts detectors.

        Access Level: Read

        https://docs.aws.amazon.com/guardduty/latest/APIReference/API_GetMemberDetectors.html

        :stability: experimental
        '''
        return typing.cast("Guardduty", jsii.invoke(self, "toGetMemberDetectors", []))

    @jsii.member(jsii_name="toGetMembers")
    def to_get_members(self) -> "Guardduty":
        '''(experimental) Grants permission to retrieve the member accounts associated with an administrator account.

        Access Level: Read

        https://docs.aws.amazon.com/guardduty/latest/APIReference/API_GetMembers.html

        :stability: experimental
        '''
        return typing.cast("Guardduty", jsii.invoke(self, "toGetMembers", []))

    @jsii.member(jsii_name="toGetThreatIntelSet")
    def to_get_threat_intel_set(self) -> "Guardduty":
        '''(experimental) Grants permission to retrieve GuardDuty ThreatIntelSets.

        Access Level: Read

        https://docs.aws.amazon.com/guardduty/latest/APIReference/API_GetThreatIntelSet.html

        :stability: experimental
        '''
        return typing.cast("Guardduty", jsii.invoke(self, "toGetThreatIntelSet", []))

    @jsii.member(jsii_name="toGetUsageStatistics")
    def to_get_usage_statistics(self) -> "Guardduty":
        '''(experimental) Grants permission to list Amazon GuardDuty usage statistics over the last 30 days for the specified detector ID.

        Access Level: Read

        https://docs.aws.amazon.com/guardduty/latest/APIReference/API_GetUsageStatistics.html

        :stability: experimental
        '''
        return typing.cast("Guardduty", jsii.invoke(self, "toGetUsageStatistics", []))

    @jsii.member(jsii_name="toInviteMembers")
    def to_invite_members(self) -> "Guardduty":
        '''(experimental) Grants permission to invite other AWS accounts to enable GuardDuty and become GuardDuty member accounts.

        Access Level: Write

        https://docs.aws.amazon.com/guardduty/latest/APIReference/API_InviteMembers.html

        :stability: experimental
        '''
        return typing.cast("Guardduty", jsii.invoke(self, "toInviteMembers", []))

    @jsii.member(jsii_name="toListDetectors")
    def to_list_detectors(self) -> "Guardduty":
        '''(experimental) Grants permission to retrieve a list of GuardDuty detectors.

        Access Level: List

        https://docs.aws.amazon.com/guardduty/latest/APIReference/API_ListDetectors.html

        :stability: experimental
        '''
        return typing.cast("Guardduty", jsii.invoke(self, "toListDetectors", []))

    @jsii.member(jsii_name="toListFilters")
    def to_list_filters(self) -> "Guardduty":
        '''(experimental) Grants permission to retrieve a list of GuardDuty filters.

        Access Level: List

        https://docs.aws.amazon.com/guardduty/latest/APIReference/API_ListFilters.html

        :stability: experimental
        '''
        return typing.cast("Guardduty", jsii.invoke(self, "toListFilters", []))

    @jsii.member(jsii_name="toListFindings")
    def to_list_findings(self) -> "Guardduty":
        '''(experimental) Grants permission to retrieve a list of GuardDuty findings.

        Access Level: List

        https://docs.aws.amazon.com/guardduty/latest/APIReference/API_ListFindings.html

        :stability: experimental
        '''
        return typing.cast("Guardduty", jsii.invoke(self, "toListFindings", []))

    @jsii.member(jsii_name="toListInvitations")
    def to_list_invitations(self) -> "Guardduty":
        '''(experimental) Grants permission to retrieve a list of all of the GuardDuty membership invitations that were sent to an AWS account.

        Access Level: List

        https://docs.aws.amazon.com/guardduty/latest/APIReference/API_ListInvitations.html

        :stability: experimental
        '''
        return typing.cast("Guardduty", jsii.invoke(self, "toListInvitations", []))

    @jsii.member(jsii_name="toListIPSets")
    def to_list_ip_sets(self) -> "Guardduty":
        '''(experimental) Grants permission to retrieve a list of GuardDuty IPSets.

        Access Level: List

        https://docs.aws.amazon.com/guardduty/latest/APIReference/API_ListIPSets.html

        :stability: experimental
        '''
        return typing.cast("Guardduty", jsii.invoke(self, "toListIPSets", []))

    @jsii.member(jsii_name="toListMembers")
    def to_list_members(self) -> "Guardduty":
        '''(experimental) Grants permission to retrieve a list of GuardDuty member accounts associated with an administrator account.

        Access Level: List

        https://docs.aws.amazon.com/guardduty/latest/APIReference/API_ListMembers.html

        :stability: experimental
        '''
        return typing.cast("Guardduty", jsii.invoke(self, "toListMembers", []))

    @jsii.member(jsii_name="toListOrganizationAdminAccounts")
    def to_list_organization_admin_accounts(self) -> "Guardduty":
        '''(experimental) Grants permission to list details about the organization delegated administrator for GuardDuty.

        Access Level: List

        https://docs.aws.amazon.com/guardduty/latest/APIReference/API_ListOrganizationAdminAccounts.html

        :stability: experimental
        '''
        return typing.cast("Guardduty", jsii.invoke(self, "toListOrganizationAdminAccounts", []))

    @jsii.member(jsii_name="toListPublishingDestinations")
    def to_list_publishing_destinations(self) -> "Guardduty":
        '''(experimental) Grants permission to retrieve a list of publishing destinations.

        Access Level: List

        https://docs.aws.amazon.com/guardduty/latest/APIReference/API_ListPublishingDestinations.html

        :stability: experimental
        '''
        return typing.cast("Guardduty", jsii.invoke(self, "toListPublishingDestinations", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Guardduty":
        '''(experimental) Grants permission to retrieve a list of tags associated with a GuardDuty resource.

        Access Level: Read

        https://docs.aws.amazon.com/guardduty/latest/APIReference/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("Guardduty", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toListThreatIntelSets")
    def to_list_threat_intel_sets(self) -> "Guardduty":
        '''(experimental) Grants permission to retrieve a list of GuardDuty ThreatIntelSets.

        Access Level: List

        https://docs.aws.amazon.com/guardduty/latest/APIReference/API_ListThreatIntelSets.html

        :stability: experimental
        '''
        return typing.cast("Guardduty", jsii.invoke(self, "toListThreatIntelSets", []))

    @jsii.member(jsii_name="toStartMonitoringMembers")
    def to_start_monitoring_members(self) -> "Guardduty":
        '''(experimental) Grants permission to a GuardDuty administrator account to monitor findings from GuardDuty member accounts.

        Access Level: Write

        https://docs.aws.amazon.com/guardduty/latest/APIReference/API_StartMonitoringMembers.html

        :stability: experimental
        '''
        return typing.cast("Guardduty", jsii.invoke(self, "toStartMonitoringMembers", []))

    @jsii.member(jsii_name="toStopMonitoringMembers")
    def to_stop_monitoring_members(self) -> "Guardduty":
        '''(experimental) Grants permission to disable monitoring findings from member accounts.

        Access Level: Write

        https://docs.aws.amazon.com/guardduty/latest/APIReference/API_StopMonitoringMembers.html

        :stability: experimental
        '''
        return typing.cast("Guardduty", jsii.invoke(self, "toStopMonitoringMembers", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Guardduty":
        '''(experimental) Grants permission to add tags to a GuardDuty resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/guardduty/latest/APIReference/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("Guardduty", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUnarchiveFindings")
    def to_unarchive_findings(self) -> "Guardduty":
        '''(experimental) Grants permission to unarchive GuardDuty findings.

        Access Level: Write

        https://docs.aws.amazon.com/guardduty/latest/APIReference/API_UnarchiveFindings.html

        :stability: experimental
        '''
        return typing.cast("Guardduty", jsii.invoke(self, "toUnarchiveFindings", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Guardduty":
        '''(experimental) Grants permission to remove tags from a GuardDuty resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/guardduty/latest/APIReference/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("Guardduty", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateDetector")
    def to_update_detector(self) -> "Guardduty":
        '''(experimental) Grants permission to update GuardDuty detectors.

        Access Level: Write

        https://docs.aws.amazon.com/guardduty/latest/APIReference/API_UpdateDetector.html

        :stability: experimental
        '''
        return typing.cast("Guardduty", jsii.invoke(self, "toUpdateDetector", []))

    @jsii.member(jsii_name="toUpdateFilter")
    def to_update_filter(self) -> "Guardduty":
        '''(experimental) Grants permission to updates GuardDuty filters.

        Access Level: Write

        https://docs.aws.amazon.com/guardduty/latest/APIReference/API_UpdateFilter.html

        :stability: experimental
        '''
        return typing.cast("Guardduty", jsii.invoke(self, "toUpdateFilter", []))

    @jsii.member(jsii_name="toUpdateFindingsFeedback")
    def to_update_findings_feedback(self) -> "Guardduty":
        '''(experimental) Grants permission to update findings feedback to mark GuardDuty findings as useful or not useful.

        Access Level: Write

        https://docs.aws.amazon.com/guardduty/latest/APIReference/API_UpdateFindingsFeedback.html

        :stability: experimental
        '''
        return typing.cast("Guardduty", jsii.invoke(self, "toUpdateFindingsFeedback", []))

    @jsii.member(jsii_name="toUpdateIPSet")
    def to_update_ip_set(self) -> "Guardduty":
        '''(experimental) Grants permission to update GuardDuty IPSets.

        Access Level: Write

        Dependent actions:

        - iam:DeleteRolePolicy
        - iam:PutRolePolicy

        https://docs.aws.amazon.com/guardduty/latest/APIReference/API_UpdateIPSet.html

        :stability: experimental
        '''
        return typing.cast("Guardduty", jsii.invoke(self, "toUpdateIPSet", []))

    @jsii.member(jsii_name="toUpdateMalwareScanSettings")
    def to_update_malware_scan_settings(self) -> "Guardduty":
        '''(experimental) Grants permission to update the malware scan settings.

        Access Level: Write

        https://docs.aws.amazon.com/guardduty/latest/APIReference/API_UpdateMalwareScanSettings.html

        :stability: experimental
        '''
        return typing.cast("Guardduty", jsii.invoke(self, "toUpdateMalwareScanSettings", []))

    @jsii.member(jsii_name="toUpdateMemberDetectors")
    def to_update_member_detectors(self) -> "Guardduty":
        '''(experimental) Grants permission to update which data sources are enabled for member accounts detectors.

        Access Level: Write

        https://docs.aws.amazon.com/guardduty/latest/APIReference/API_UpdateMemberDetectors.html

        :stability: experimental
        '''
        return typing.cast("Guardduty", jsii.invoke(self, "toUpdateMemberDetectors", []))

    @jsii.member(jsii_name="toUpdateOrganizationConfiguration")
    def to_update_organization_configuration(self) -> "Guardduty":
        '''(experimental) Grants permission to update the delegated administrator configuration associated with a GuardDuty detector.

        Access Level: Write

        https://docs.aws.amazon.com/guardduty/latest/APIReference/API_UpdateOrganizationConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Guardduty", jsii.invoke(self, "toUpdateOrganizationConfiguration", []))

    @jsii.member(jsii_name="toUpdatePublishingDestination")
    def to_update_publishing_destination(self) -> "Guardduty":
        '''(experimental) Grants permission to update a publishing destination.

        Access Level: Write

        Dependent actions:

        - s3:GetObject
        - s3:ListBucket

        https://docs.aws.amazon.com/guardduty/latest/APIReference/API_UpdatePublishingDestination.html

        :stability: experimental
        '''
        return typing.cast("Guardduty", jsii.invoke(self, "toUpdatePublishingDestination", []))

    @jsii.member(jsii_name="toUpdateThreatIntelSet")
    def to_update_threat_intel_set(self) -> "Guardduty":
        '''(experimental) Grants permission to updates the GuardDuty ThreatIntelSets.

        Access Level: Write

        Dependent actions:

        - iam:DeleteRolePolicy
        - iam:PutRolePolicy

        https://docs.aws.amazon.com/guardduty/latest/APIReference/API_UpdateThreatIntelSet.html

        :stability: experimental
        '''
        return typing.cast("Guardduty", jsii.invoke(self, "toUpdateThreatIntelSet", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b59cc1ee56f62e2297187a34c05880638ad8c7efed70a3913ac80c53001800d1)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__db3c3faa002a37d3c6c64cf99ed84cf177097a7fcc86c15d709b7f3297f23403)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Health(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Health",
):
    '''(experimental) Statement provider for service `health <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awshealthapisandnotifications.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `health <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awshealthapisandnotifications.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="ifEventTypeCode")
    def if_event_type_code(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Health":
        '''(experimental) Filters access by event type.

        https://docs.aws.amazon.com/health/latest/ug/controlling-access.html

        Applies to actions:

        - .toDescribeAffectedEntities()
        - .toDescribeEventDetails()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ed2b9e6fe81e77bc3a334b82977ca12e9c116b1211ad3cebf403493a505fa538)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Health", jsii.invoke(self, "ifEventTypeCode", [value, operator]))

    @jsii.member(jsii_name="ifService")
    def if_service(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Health":
        '''(experimental) Filters access by impacted service.

        https://docs.aws.amazon.com/health/latest/ug/controlling-access.html

        Applies to actions:

        - .toDescribeAffectedEntities()
        - .toDescribeEventDetails()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__90e8f091eb959c13ac07e8c56ff964578ece8d96e40ebe594406126681f54f68)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Health", jsii.invoke(self, "ifService", [value, operator]))

    @jsii.member(jsii_name="onEvent")
    def on_event(
        self,
        service: builtins.str,
        event_type_code: builtins.str,
        event_type_plus_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Health":
        '''(experimental) Adds a resource of type event to the statement.

        https://docs.aws.amazon.com/health/latest/ug/supported-operations.html

        :param service: - Identifier for the service.
        :param event_type_code: - Identifier for the eventTypeCode.
        :param event_type_plus_id: - Identifier for the eventTypePlusId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3e38addd14f6f1a732bab1ef75e148ea5f95df77cf348cc99ff9955156b7110d)
            check_type(argname="argument service", value=service, expected_type=type_hints["service"])
            check_type(argname="argument event_type_code", value=event_type_code, expected_type=type_hints["event_type_code"])
            check_type(argname="argument event_type_plus_id", value=event_type_plus_id, expected_type=type_hints["event_type_plus_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Health", jsii.invoke(self, "onEvent", [service, event_type_code, event_type_plus_id, account, region, partition]))

    @jsii.member(jsii_name="toDescribeAffectedAccountsForOrganization")
    def to_describe_affected_accounts_for_organization(self) -> "Health":
        '''(experimental) Grants permission to retrieve a list of accounts that have been affected by the specified events in organization.

        Access Level: Read

        Dependent actions:

        - organizations:ListAccounts

        https://docs.aws.amazon.com/health/latest/APIReference/API_DescribeAffectedAccountsForOrganization.html

        :stability: experimental
        '''
        return typing.cast("Health", jsii.invoke(self, "toDescribeAffectedAccountsForOrganization", []))

    @jsii.member(jsii_name="toDescribeAffectedEntities")
    def to_describe_affected_entities(self) -> "Health":
        '''(experimental) Grants permission to retrieve a list of entities that have been affected by the specified events.

        Access Level: Read

        Possible conditions:

        - .ifEventTypeCode()
        - .ifService()

        https://docs.aws.amazon.com/health/latest/APIReference/API_DescribeAffectedEntities.html

        :stability: experimental
        '''
        return typing.cast("Health", jsii.invoke(self, "toDescribeAffectedEntities", []))

    @jsii.member(jsii_name="toDescribeAffectedEntitiesForOrganization")
    def to_describe_affected_entities_for_organization(self) -> "Health":
        '''(experimental) Grants permission to retrieve a list of entities that have been affected by the specified events and accounts in organization.

        Access Level: Read

        Dependent actions:

        - organizations:ListAccounts

        https://docs.aws.amazon.com/health/latest/APIReference/API_DescribeAffectedEntitiesForOrganization.html

        :stability: experimental
        '''
        return typing.cast("Health", jsii.invoke(self, "toDescribeAffectedEntitiesForOrganization", []))

    @jsii.member(jsii_name="toDescribeEntityAggregates")
    def to_describe_entity_aggregates(self) -> "Health":
        '''(experimental) Grants permission to retrieve the number of entities that are affected by each of the specified events.

        Access Level: Read

        https://docs.aws.amazon.com/health/latest/APIReference/API_DescribeEntityAggregates.html

        :stability: experimental
        '''
        return typing.cast("Health", jsii.invoke(self, "toDescribeEntityAggregates", []))

    @jsii.member(jsii_name="toDescribeEventAggregates")
    def to_describe_event_aggregates(self) -> "Health":
        '''(experimental) Grants permission to retrieve the number of events of each event type (issue, scheduled change, and account notification).

        Access Level: Read

        https://docs.aws.amazon.com/health/latest/APIReference/API_DescribeEventAggregates.html

        :stability: experimental
        '''
        return typing.cast("Health", jsii.invoke(self, "toDescribeEventAggregates", []))

    @jsii.member(jsii_name="toDescribeEventDetails")
    def to_describe_event_details(self) -> "Health":
        '''(experimental) Grants permission to retrieve detailed information about one or more specified events.

        Access Level: Read

        Possible conditions:

        - .ifEventTypeCode()
        - .ifService()

        https://docs.aws.amazon.com/health/latest/APIReference/API_DescribeEventDetails.html

        :stability: experimental
        '''
        return typing.cast("Health", jsii.invoke(self, "toDescribeEventDetails", []))

    @jsii.member(jsii_name="toDescribeEventDetailsForOrganization")
    def to_describe_event_details_for_organization(self) -> "Health":
        '''(experimental) Grants permission to retrieve detailed information about one or more specified events for provided accounts in organization.

        Access Level: Read

        Dependent actions:

        - organizations:ListAccounts

        https://docs.aws.amazon.com/health/latest/APIReference/API_DescribeEventDetailsForOrganization.html

        :stability: experimental
        '''
        return typing.cast("Health", jsii.invoke(self, "toDescribeEventDetailsForOrganization", []))

    @jsii.member(jsii_name="toDescribeEvents")
    def to_describe_events(self) -> "Health":
        '''(experimental) Grants permission to retrieve information about events that meet the specified filter criteria.

        Access Level: Read

        https://docs.aws.amazon.com/health/latest/APIReference/API_DescribeEvents.html

        :stability: experimental
        '''
        return typing.cast("Health", jsii.invoke(self, "toDescribeEvents", []))

    @jsii.member(jsii_name="toDescribeEventsForOrganization")
    def to_describe_events_for_organization(self) -> "Health":
        '''(experimental) Grants permission to retrieve information about events that meet the specified filter criteria in organization.

        Access Level: Read

        Dependent actions:

        - organizations:ListAccounts

        https://docs.aws.amazon.com/health/latest/APIReference/API_DescribeEventsForOrganization.html

        :stability: experimental
        '''
        return typing.cast("Health", jsii.invoke(self, "toDescribeEventsForOrganization", []))

    @jsii.member(jsii_name="toDescribeEventTypes")
    def to_describe_event_types(self) -> "Health":
        '''(experimental) Grants permission to retrieve the event types that meet the specified filter criteria.

        Access Level: Read

        https://docs.aws.amazon.com/health/latest/APIReference/API_DescribeEventTypes.html

        :stability: experimental
        '''
        return typing.cast("Health", jsii.invoke(self, "toDescribeEventTypes", []))

    @jsii.member(jsii_name="toDescribeHealthServiceStatusForOrganization")
    def to_describe_health_service_status_for_organization(self) -> "Health":
        '''(experimental) Grants permission to retrieve the status of enabling or disabling the Organizational View feature.

        Access Level: Read

        Dependent actions:

        - organizations:ListAccounts

        https://docs.aws.amazon.com/health/latest/APIReference/API_DescribeHealthServiceStatusForOrganization.html

        :stability: experimental
        '''
        return typing.cast("Health", jsii.invoke(self, "toDescribeHealthServiceStatusForOrganization", []))

    @jsii.member(jsii_name="toDisableHealthServiceAccessForOrganization")
    def to_disable_health_service_access_for_organization(self) -> "Health":
        '''(experimental) Grants permission to disable the Organizational View feature.

        Access Level: Permissions management

        Dependent actions:

        - organizations:DisableAWSServiceAccess
        - organizations:ListAccounts

        https://docs.aws.amazon.com/health/latest/APIReference/API_DisableHealthServiceAccessForOrganization.html

        :stability: experimental
        '''
        return typing.cast("Health", jsii.invoke(self, "toDisableHealthServiceAccessForOrganization", []))

    @jsii.member(jsii_name="toEnableHealthServiceAccessForOrganization")
    def to_enable_health_service_access_for_organization(self) -> "Health":
        '''(experimental) Grants permission to enable the Organizational View feature.

        Access Level: Permissions management

        Dependent actions:

        - iam:CreateServiceLinkedRole
        - organizations:EnableAWSServiceAccess
        - organizations:ListAccounts

        https://docs.aws.amazon.com/health/latest/APIReference/API_EnableHealthServiceAccessForOrganization.html

        :stability: experimental
        '''
        return typing.cast("Health", jsii.invoke(self, "toEnableHealthServiceAccessForOrganization", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__814141424fba7e509c5f1bc263258f2c15cc65311b313d7019039f421f4ab7a5)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d2294861476b93993fd10109e41c2790fd0bc956656a8b0a6d90816818663010)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Healthlake(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Healthlake",
):
    '''(experimental) Statement provider for service `healthlake <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonhealthlake.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `healthlake <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonhealthlake.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onDatastore")
    def on_datastore(
        self,
        datastore_id: builtins.str,
        account_id: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Healthlake":
        '''(experimental) Adds a resource of type datastore to the statement.

        https://docs.aws.amazon.com/healthlake/latest/APIReference/API_DatastoreProperties.html

        :param datastore_id: - Identifier for the datastoreId.
        :param account_id: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e280f3904761000c5913190a8d8646994b943e6ce0b1d78e3e3a923d4170b91e)
            check_type(argname="argument datastore_id", value=datastore_id, expected_type=type_hints["datastore_id"])
            check_type(argname="argument account_id", value=account_id, expected_type=type_hints["account_id"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Healthlake", jsii.invoke(self, "onDatastore", [datastore_id, account_id, region, partition]))

    @jsii.member(jsii_name="toCreateFHIRDatastore")
    def to_create_fhir_datastore(self) -> "Healthlake":
        '''(experimental) Grants permission to create a datastore that can ingest and export FHIR data.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/healthlake/latest/APIReference/API_CreateFHIRDatastore.html

        :stability: experimental
        '''
        return typing.cast("Healthlake", jsii.invoke(self, "toCreateFHIRDatastore", []))

    @jsii.member(jsii_name="toCreateResource")
    def to_create_resource(self) -> "Healthlake":
        '''(experimental) Grants permission to create resource.

        Access Level: Write

        https://docs.aws.amazon.com/healthlake/latest/devguide/crud-healthlake.html

        :stability: experimental
        '''
        return typing.cast("Healthlake", jsii.invoke(self, "toCreateResource", []))

    @jsii.member(jsii_name="toDeleteFHIRDatastore")
    def to_delete_fhir_datastore(self) -> "Healthlake":
        '''(experimental) Grants permission to delete a datastore.

        Access Level: Write

        https://docs.aws.amazon.com/healthlake/latest/APIReference/API_DeleteFHIRDatastore.html

        :stability: experimental
        '''
        return typing.cast("Healthlake", jsii.invoke(self, "toDeleteFHIRDatastore", []))

    @jsii.member(jsii_name="toDeleteResource")
    def to_delete_resource(self) -> "Healthlake":
        '''(experimental) Grants permission to delete resource.

        Access Level: Write

        https://docs.aws.amazon.com/healthlake/latest/devguide/crud-healthlake.html

        :stability: experimental
        '''
        return typing.cast("Healthlake", jsii.invoke(self, "toDeleteResource", []))

    @jsii.member(jsii_name="toDescribeFHIRDatastore")
    def to_describe_fhir_datastore(self) -> "Healthlake":
        '''(experimental) Grants permission to get the properties associated with the FHIR datastore, including the datastore ID, datastore ARN, datastore name, datastore status, created at, datastore type version, and datastore endpoint.

        Access Level: Read

        https://docs.aws.amazon.com/healthlake/latest/APIReference/API_DescribeFHIRDatastore.html

        :stability: experimental
        '''
        return typing.cast("Healthlake", jsii.invoke(self, "toDescribeFHIRDatastore", []))

    @jsii.member(jsii_name="toDescribeFHIRExportJob")
    def to_describe_fhir_export_job(self) -> "Healthlake":
        '''(experimental) Grants permission to display the properties of a FHIR export job, including the ID, ARN, name, and the status of the datastore.

        Access Level: Read

        https://docs.aws.amazon.com/healthlake/latest/APIReference/API_DescribeFHIRExportJob.html

        :stability: experimental
        '''
        return typing.cast("Healthlake", jsii.invoke(self, "toDescribeFHIRExportJob", []))

    @jsii.member(jsii_name="toDescribeFHIRImportJob")
    def to_describe_fhir_import_job(self) -> "Healthlake":
        '''(experimental) Grants permission to display the properties of a FHIR import job, including the ID, ARN, name, and the status of the datastore.

        Access Level: Read

        https://docs.aws.amazon.com/healthlake/latest/APIReference/API_DescribeFHIRImportJob.html

        :stability: experimental
        '''
        return typing.cast("Healthlake", jsii.invoke(self, "toDescribeFHIRImportJob", []))

    @jsii.member(jsii_name="toGetCapabilities")
    def to_get_capabilities(self) -> "Healthlake":
        '''(experimental) Grants permission to get the capabilities of a FHIR datastore.

        Access Level: Read

        https://docs.aws.amazon.com/healthlake/latest/devguide/crud-healthlake.html

        :stability: experimental
        '''
        return typing.cast("Healthlake", jsii.invoke(self, "toGetCapabilities", []))

    @jsii.member(jsii_name="toListFHIRDatastores")
    def to_list_fhir_datastores(self) -> "Healthlake":
        '''(experimental) Grants permission to list all FHIR datastores that are in the user’s account, regardless of datastore status.

        Access Level: List

        https://docs.aws.amazon.com/healthlake/latest/APIReference/API_ListFHIRDatastores.html

        :stability: experimental
        '''
        return typing.cast("Healthlake", jsii.invoke(self, "toListFHIRDatastores", []))

    @jsii.member(jsii_name="toListFHIRExportJobs")
    def to_list_fhir_export_jobs(self) -> "Healthlake":
        '''(experimental) Grants permission to get a list of export jobs for the specified datastore.

        Access Level: List

        https://docs.aws.amazon.com/healthlake/latest/APIReference/API_ListFHIRExportJobs.html

        :stability: experimental
        '''
        return typing.cast("Healthlake", jsii.invoke(self, "toListFHIRExportJobs", []))

    @jsii.member(jsii_name="toListFHIRImportJobs")
    def to_list_fhir_import_jobs(self) -> "Healthlake":
        '''(experimental) Grants permission to get a list of import jobs for the specified datastore.

        Access Level: List

        https://docs.aws.amazon.com/healthlake/latest/APIReference/API_ListFHIRImportJobs.html

        :stability: experimental
        '''
        return typing.cast("Healthlake", jsii.invoke(self, "toListFHIRImportJobs", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Healthlake":
        '''(experimental) Grants permission to get a list of tags for the specified datastore.

        Access Level: Read

        https://docs.aws.amazon.com/healthlake/latest/APIReference/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("Healthlake", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toReadResource")
    def to_read_resource(self) -> "Healthlake":
        '''(experimental) Grants permission to read resource.

        Access Level: Read

        https://docs.aws.amazon.com/healthlake/latest/devguide/crud-healthlake.html

        :stability: experimental
        '''
        return typing.cast("Healthlake", jsii.invoke(self, "toReadResource", []))

    @jsii.member(jsii_name="toSearchWithGet")
    def to_search_with_get(self) -> "Healthlake":
        '''(experimental) Grants permission to search resources with GET method.

        Access Level: Read

        https://docs.aws.amazon.com/healthlake/latest/devguide/search-healthlake.html

        :stability: experimental
        '''
        return typing.cast("Healthlake", jsii.invoke(self, "toSearchWithGet", []))

    @jsii.member(jsii_name="toSearchWithPost")
    def to_search_with_post(self) -> "Healthlake":
        '''(experimental) Grants permission to search resources with POST method.

        Access Level: Read

        https://docs.aws.amazon.com/healthlake/latest/devguide/search-healthlake.html

        :stability: experimental
        '''
        return typing.cast("Healthlake", jsii.invoke(self, "toSearchWithPost", []))

    @jsii.member(jsii_name="toStartFHIRExportJob")
    def to_start_fhir_export_job(self) -> "Healthlake":
        '''(experimental) Grants permission to begin a FHIR Export job.

        Access Level: Write

        https://docs.aws.amazon.com/healthlake/latest/APIReference/API_StartFHIRExportJob.html

        :stability: experimental
        '''
        return typing.cast("Healthlake", jsii.invoke(self, "toStartFHIRExportJob", []))

    @jsii.member(jsii_name="toStartFHIRImportJob")
    def to_start_fhir_import_job(self) -> "Healthlake":
        '''(experimental) Grants permission to begin a FHIR Import job.

        Access Level: Write

        https://docs.aws.amazon.com/healthlake/latest/APIReference/API_StartFHIRImportJob.html

        :stability: experimental
        '''
        return typing.cast("Healthlake", jsii.invoke(self, "toStartFHIRImportJob", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Healthlake":
        '''(experimental) Grants permission to add tags to a datastore.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()
        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/healthlake/latest/APIReference/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("Healthlake", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Healthlake":
        '''(experimental) Grants permission to remove tags associated with a datastore.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/healthlake/latest/APIReference/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("Healthlake", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateResource")
    def to_update_resource(self) -> "Healthlake":
        '''(experimental) Grants permission to update resource.

        Access Level: Write

        https://docs.aws.amazon.com/healthlake/latest/devguide/crud-healthlake.html

        :stability: experimental
        '''
        return typing.cast("Healthlake", jsii.invoke(self, "toUpdateResource", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__785651f980e7dcdc78cd68e3d0bd9746a4f4b0e140ecb7e1749abdd7db37b5e5)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__630625f0bd01709f34c439e1b3214a0a44df209fdf92511431562e67ab331153)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Honeycode(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Honeycode",
):
    '''(experimental) Statement provider for service `honeycode <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonhoneycode.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `honeycode <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonhoneycode.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onScreen")
    def on_screen(
        self,
        workbook_id: builtins.str,
        app_id: builtins.str,
        screen_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Honeycode":
        '''(experimental) Adds a resource of type screen to the statement.

        https://docs.aws.amazon.com/honeycode/latest/UserGuide/resource-screen.html

        :param workbook_id: - Identifier for the workbookId.
        :param app_id: - Identifier for the appId.
        :param screen_id: - Identifier for the screenId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__29ae07ad81c31fc614607dc7a6fa710bee52886e283f51680028c43b1b22f560)
            check_type(argname="argument workbook_id", value=workbook_id, expected_type=type_hints["workbook_id"])
            check_type(argname="argument app_id", value=app_id, expected_type=type_hints["app_id"])
            check_type(argname="argument screen_id", value=screen_id, expected_type=type_hints["screen_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Honeycode", jsii.invoke(self, "onScreen", [workbook_id, app_id, screen_id, account, region, partition]))

    @jsii.member(jsii_name="onScreenAutomation")
    def on_screen_automation(
        self,
        workbook_id: builtins.str,
        app_id: builtins.str,
        screen_id: builtins.str,
        automation_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Honeycode":
        '''(experimental) Adds a resource of type screen-automation to the statement.

        https://docs.aws.amazon.com/honeycode/latest/UserGuide/resource-screen-automation.html

        :param workbook_id: - Identifier for the workbookId.
        :param app_id: - Identifier for the appId.
        :param screen_id: - Identifier for the screenId.
        :param automation_id: - Identifier for the automationId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__55da74dffe8799e6d14428dd81477c38830b3436294b679c0d330b1508fa4192)
            check_type(argname="argument workbook_id", value=workbook_id, expected_type=type_hints["workbook_id"])
            check_type(argname="argument app_id", value=app_id, expected_type=type_hints["app_id"])
            check_type(argname="argument screen_id", value=screen_id, expected_type=type_hints["screen_id"])
            check_type(argname="argument automation_id", value=automation_id, expected_type=type_hints["automation_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Honeycode", jsii.invoke(self, "onScreenAutomation", [workbook_id, app_id, screen_id, automation_id, account, region, partition]))

    @jsii.member(jsii_name="onTable")
    def on_table(
        self,
        workbook_id: builtins.str,
        table_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Honeycode":
        '''(experimental) Adds a resource of type table to the statement.

        https://docs.aws.amazon.com/honeycode/latest/UserGuide/resource-table.html

        :param workbook_id: - Identifier for the workbookId.
        :param table_id: - Identifier for the tableId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f5aa918baa2e694a70e1c712d5e870f45e9c5db1a4141976700839cfc9ff370f)
            check_type(argname="argument workbook_id", value=workbook_id, expected_type=type_hints["workbook_id"])
            check_type(argname="argument table_id", value=table_id, expected_type=type_hints["table_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Honeycode", jsii.invoke(self, "onTable", [workbook_id, table_id, account, region, partition]))

    @jsii.member(jsii_name="onWorkbook")
    def on_workbook(
        self,
        workbook_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Honeycode":
        '''(experimental) Adds a resource of type workbook to the statement.

        https://docs.aws.amazon.com/honeycode/latest/UserGuide/resource-workbook.html

        :param workbook_id: - Identifier for the workbookId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__54529182e221efadd7f646fc909769128113d65edc8e2851ddbe5565be07bb9b)
            check_type(argname="argument workbook_id", value=workbook_id, expected_type=type_hints["workbook_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Honeycode", jsii.invoke(self, "onWorkbook", [workbook_id, account, region, partition]))

    @jsii.member(jsii_name="toApproveTeamAssociation")
    def to_approve_team_association(self) -> "Honeycode":
        '''(experimental) Grants permission to approve a team association request for your AWS Account.

        Access Level: Write

        https://docs.aws.amazon.com/honeycode/latest/UserGuide/team-association.html#approve-team-association

        :stability: experimental
        '''
        return typing.cast("Honeycode", jsii.invoke(self, "toApproveTeamAssociation", []))

    @jsii.member(jsii_name="toBatchCreateTableRows")
    def to_batch_create_table_rows(self) -> "Honeycode":
        '''(experimental) Grants permission to create new rows in a table.

        Access Level: Write

        https://docs.aws.amazon.com/honeycode/latest/UserGuide/API_BatchCreateTableRows.html

        :stability: experimental
        '''
        return typing.cast("Honeycode", jsii.invoke(self, "toBatchCreateTableRows", []))

    @jsii.member(jsii_name="toBatchDeleteTableRows")
    def to_batch_delete_table_rows(self) -> "Honeycode":
        '''(experimental) Grants permission to delete rows from a table.

        Access Level: Write

        https://docs.aws.amazon.com/honeycode/latest/UserGuide/API_BatchDeleteTableRows.html

        :stability: experimental
        '''
        return typing.cast("Honeycode", jsii.invoke(self, "toBatchDeleteTableRows", []))

    @jsii.member(jsii_name="toBatchUpdateTableRows")
    def to_batch_update_table_rows(self) -> "Honeycode":
        '''(experimental) Grants permission to update rows in a table.

        Access Level: Write

        https://docs.aws.amazon.com/honeycode/latest/UserGuide/API_BatchUpdateTableRows.html

        :stability: experimental
        '''
        return typing.cast("Honeycode", jsii.invoke(self, "toBatchUpdateTableRows", []))

    @jsii.member(jsii_name="toBatchUpsertTableRows")
    def to_batch_upsert_table_rows(self) -> "Honeycode":
        '''(experimental) Grants permission to upsert rows in a table.

        Access Level: Write

        https://docs.aws.amazon.com/honeycode/latest/UserGuide/API_BatchUpsertTableRows.html

        :stability: experimental
        '''
        return typing.cast("Honeycode", jsii.invoke(self, "toBatchUpsertTableRows", []))

    @jsii.member(jsii_name="toCreateTeam")
    def to_create_team(self) -> "Honeycode":
        '''(experimental) Grants permission to create a new Amazon Honeycode team for your AWS Account.

        Access Level: Write

        https://docs.aws.amazon.com/honeycode/latest/UserGuide/team.html#create-team

        :stability: experimental
        '''
        return typing.cast("Honeycode", jsii.invoke(self, "toCreateTeam", []))

    @jsii.member(jsii_name="toCreateTenant")
    def to_create_tenant(self) -> "Honeycode":
        '''(experimental) Grants permission to create a new tenant within Amazon Honeycode for your AWS Account.

        Access Level: Write

        https://docs.aws.amazon.com/honeycode/latest/UserGuide/tenant.html#create-tenant

        :stability: experimental
        '''
        return typing.cast("Honeycode", jsii.invoke(self, "toCreateTenant", []))

    @jsii.member(jsii_name="toDeleteDomains")
    def to_delete_domains(self) -> "Honeycode":
        '''(experimental) Grants permission to delete Amazon Honeycode domains for your AWS Account.

        Access Level: Write

        https://docs.aws.amazon.com/honeycode/latest/UserGuide/domain.html#delete-domains

        :stability: experimental
        '''
        return typing.cast("Honeycode", jsii.invoke(self, "toDeleteDomains", []))

    @jsii.member(jsii_name="toDeregisterGroups")
    def to_deregister_groups(self) -> "Honeycode":
        '''(experimental) Grants permission to remove groups from an Amazon Honeycode team for your AWS Account.

        Access Level: Write

        https://docs.aws.amazon.com/honeycode/latest/UserGuide/group.html#deregister-groups

        :stability: experimental
        '''
        return typing.cast("Honeycode", jsii.invoke(self, "toDeregisterGroups", []))

    @jsii.member(jsii_name="toDescribeTableDataImportJob")
    def to_describe_table_data_import_job(self) -> "Honeycode":
        '''(experimental) Grants permission to get details about a table data import job.

        Access Level: Read

        https://docs.aws.amazon.com/honeycode/latest/UserGuide/API_DescribeTableDataImportJob.html

        :stability: experimental
        '''
        return typing.cast("Honeycode", jsii.invoke(self, "toDescribeTableDataImportJob", []))

    @jsii.member(jsii_name="toDescribeTeam")
    def to_describe_team(self) -> "Honeycode":
        '''(experimental) Grants permission to get details about Amazon Honeycode teams for your AWS Account.

        Access Level: Read

        https://docs.aws.amazon.com/honeycode/latest/UserGuide/team.html#describe-team

        :stability: experimental
        '''
        return typing.cast("Honeycode", jsii.invoke(self, "toDescribeTeam", []))

    @jsii.member(jsii_name="toGetScreenData")
    def to_get_screen_data(self) -> "Honeycode":
        '''(experimental) Grants permission to load the data from a screen.

        Access Level: Read

        https://docs.aws.amazon.com/honeycode/latest/UserGuide/API_GetScreenData.html

        :stability: experimental
        '''
        return typing.cast("Honeycode", jsii.invoke(self, "toGetScreenData", []))

    @jsii.member(jsii_name="toInvokeScreenAutomation")
    def to_invoke_screen_automation(self) -> "Honeycode":
        '''(experimental) Grants permission to invoke a screen automation.

        Access Level: Write

        https://docs.aws.amazon.com/honeycode/latest/UserGuide/API_InvokeScreenAutomation.html

        :stability: experimental
        '''
        return typing.cast("Honeycode", jsii.invoke(self, "toInvokeScreenAutomation", []))

    @jsii.member(jsii_name="toListDomains")
    def to_list_domains(self) -> "Honeycode":
        '''(experimental) Grants permission to list all Amazon Honeycode domains and their verification status for your AWS Account.

        Access Level: List

        https://docs.aws.amazon.com/honeycode/latest/UserGuide/domain.html#list-domains

        :stability: experimental
        '''
        return typing.cast("Honeycode", jsii.invoke(self, "toListDomains", []))

    @jsii.member(jsii_name="toListGroups")
    def to_list_groups(self) -> "Honeycode":
        '''(experimental) Grants permission to list all groups in an Amazon Honeycode team for your AWS Account.

        Access Level: List

        https://docs.aws.amazon.com/honeycode/latest/UserGuide/group.html#list-groups

        :stability: experimental
        '''
        return typing.cast("Honeycode", jsii.invoke(self, "toListGroups", []))

    @jsii.member(jsii_name="toListTableColumns")
    def to_list_table_columns(self) -> "Honeycode":
        '''(experimental) Grants permission to list the columns in a table.

        Access Level: List

        https://docs.aws.amazon.com/honeycode/latest/UserGuide/API_ListTableColumns.html

        :stability: experimental
        '''
        return typing.cast("Honeycode", jsii.invoke(self, "toListTableColumns", []))

    @jsii.member(jsii_name="toListTableRows")
    def to_list_table_rows(self) -> "Honeycode":
        '''(experimental) Grants permission to list the rows in a table.

        Access Level: List

        https://docs.aws.amazon.com/honeycode/latest/UserGuide/API_ListTableRows.html

        :stability: experimental
        '''
        return typing.cast("Honeycode", jsii.invoke(self, "toListTableRows", []))

    @jsii.member(jsii_name="toListTables")
    def to_list_tables(self) -> "Honeycode":
        '''(experimental) Grants permission to list the tables in a workbook.

        Access Level: List

        https://docs.aws.amazon.com/honeycode/latest/UserGuide/API_ListTables.html

        :stability: experimental
        '''
        return typing.cast("Honeycode", jsii.invoke(self, "toListTables", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Honeycode":
        '''(experimental) Grants permission to list all tags for a resource.

        Access Level: Tagging

        https://docs.aws.amazon.com/honeycode/latest/UserGuide/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("Honeycode", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toListTeamAssociations")
    def to_list_team_associations(self) -> "Honeycode":
        '''(experimental) Grants permission to list all pending and approved team associations with your AWS Account.

        Access Level: List

        https://docs.aws.amazon.com/honeycode/latest/UserGuide/team-association.html#list-team-associations

        :stability: experimental
        '''
        return typing.cast("Honeycode", jsii.invoke(self, "toListTeamAssociations", []))

    @jsii.member(jsii_name="toListTenants")
    def to_list_tenants(self) -> "Honeycode":
        '''(experimental) Grants permission to list all tenants of Amazon Honeycode for your AWS Account.

        Access Level: List

        https://docs.aws.amazon.com/honeycode/latest/UserGuide/tenant.html#list-tenants

        :stability: experimental
        '''
        return typing.cast("Honeycode", jsii.invoke(self, "toListTenants", []))

    @jsii.member(jsii_name="toQueryTableRows")
    def to_query_table_rows(self) -> "Honeycode":
        '''(experimental) Grants permission to query the rows of a table using a filter.

        Access Level: Read

        https://docs.aws.amazon.com/honeycode/latest/UserGuide/API_QueryTableRows.html

        :stability: experimental
        '''
        return typing.cast("Honeycode", jsii.invoke(self, "toQueryTableRows", []))

    @jsii.member(jsii_name="toRegisterDomainForVerification")
    def to_register_domain_for_verification(self) -> "Honeycode":
        '''(experimental) Grants permission to request verification of the Amazon Honeycode domains for your AWS Account.

        Access Level: Write

        https://docs.aws.amazon.com/honeycode/latest/UserGuide/domain.html#register-domain-for-verification

        :stability: experimental
        '''
        return typing.cast("Honeycode", jsii.invoke(self, "toRegisterDomainForVerification", []))

    @jsii.member(jsii_name="toRegisterGroups")
    def to_register_groups(self) -> "Honeycode":
        '''(experimental) Grants permission to add groups to an Amazon Honeycode team for your AWS Account.

        Access Level: Write

        https://docs.aws.amazon.com/honeycode/latest/UserGuide/group.html#register-groups

        :stability: experimental
        '''
        return typing.cast("Honeycode", jsii.invoke(self, "toRegisterGroups", []))

    @jsii.member(jsii_name="toRejectTeamAssociation")
    def to_reject_team_association(self) -> "Honeycode":
        '''(experimental) Grants permission to reject a team association request for your AWS Account.

        Access Level: Write

        https://docs.aws.amazon.com/honeycode/latest/UserGuide/team-association.html#reject-team-association

        :stability: experimental
        '''
        return typing.cast("Honeycode", jsii.invoke(self, "toRejectTeamAssociation", []))

    @jsii.member(jsii_name="toRestartDomainVerification")
    def to_restart_domain_verification(self) -> "Honeycode":
        '''(experimental) Grants permission to restart verification of the Amazon Honeycode domains for your AWS Account.

        Access Level: Write

        https://docs.aws.amazon.com/honeycode/latest/UserGuide/domain.html#restart-domain-verification

        :stability: experimental
        '''
        return typing.cast("Honeycode", jsii.invoke(self, "toRestartDomainVerification", []))

    @jsii.member(jsii_name="toStartTableDataImportJob")
    def to_start_table_data_import_job(self) -> "Honeycode":
        '''(experimental) Grants permission to start a table data import job.

        Access Level: Write

        https://docs.aws.amazon.com/honeycode/latest/UserGuide/API_StartTableDataImportJob.html

        :stability: experimental
        '''
        return typing.cast("Honeycode", jsii.invoke(self, "toStartTableDataImportJob", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Honeycode":
        '''(experimental) Grants permission to tag a resource.

        Access Level: Tagging

        https://docs.aws.amazon.com/honeycode/latest/UserGuide/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("Honeycode", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Honeycode":
        '''(experimental) Grants permission to untag a resource.

        Access Level: Tagging

        https://docs.aws.amazon.com/honeycode/latest/UserGuide/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("Honeycode", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateTeam")
    def to_update_team(self) -> "Honeycode":
        '''(experimental) Grants permission to update an Amazon Honeycode team for your AWS Account.

        Access Level: Write

        https://docs.aws.amazon.com/honeycode/latest/UserGuide/team.html#update-team

        :stability: experimental
        '''
        return typing.cast("Honeycode", jsii.invoke(self, "toUpdateTeam", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__22fbb6eba27728e9e94b9690c613d7e4f26de23deb8b00cf34bbf43d0ede1ef8)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2565d5a59189267f4c803679ca6940b3da85059775f45f56a8ff006a113b82dc)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Iam(PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Iam"):
    '''(experimental) Statement provider for service `iam <https://docs.aws.amazon.com/service-authorization/latest/reference/list_identityandaccessmanagement.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `iam <https://docs.aws.amazon.com/service-authorization/latest/reference/list_identityandaccessmanagement.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="ifAssociatedResourceArn")
    def if_associated_resource_arn(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Iam":
        '''(experimental) Filters by the resource that the role will be used on behalf of.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_iam-condition-keys.html#ck_AssociatedResourceArn

        Applies to actions:

        - .toPassRole()

        :param value: The value(s) to check.
        :param operator: Works with `arn operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_ARN>`_. **Default:** ``ArnLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__51e01b91ede806824f359c55c3986afb8a8b3bb03714ec4127cfb4f4113faa53)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Iam", jsii.invoke(self, "ifAssociatedResourceArn", [value, operator]))

    @jsii.member(jsii_name="ifAWSServiceName")
    def if_aws_service_name(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Iam":
        '''(experimental) Filters access by the AWS service to which this role is attached.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_iam-condition-keys.html#ck_AWSServiceName

        Applies to actions:

        - .toCreateServiceLinkedRole()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__24ad06f0753e2dcedf79c30a4cea688e01f0844aa55c9f006ec46c4567293ff8)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Iam", jsii.invoke(self, "ifAWSServiceName", [value, operator]))

    @jsii.member(jsii_name="ifOrganizationsPolicyId")
    def if_organizations_policy_id(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Iam":
        '''(experimental) Filters access by the ID of an AWS Organizations policy.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_iam-condition-keys.html#ck_OrganizationsPolicyId

        Applies to actions:

        - .toGenerateOrganizationsAccessReport()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ebce342636fc71b0039cd86d5ad3caa74b9151aa8685e9a19d57d62c1e86c1dc)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Iam", jsii.invoke(self, "ifOrganizationsPolicyId", [value, operator]))

    @jsii.member(jsii_name="ifPassedToService")
    def if_passed_to_service(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Iam":
        '''(experimental) Filters access by the AWS service to which this role is passed.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_iam-condition-keys.html#ck_PassedToService

        Applies to actions:

        - .toPassRole()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__371b943df67bd0b89d1a67f7cd2842abde2a09124adbd92dc94d2f5d821bd02a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Iam", jsii.invoke(self, "ifPassedToService", [value, operator]))

    @jsii.member(jsii_name="ifPermissionsBoundary")
    def if_permissions_boundary(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Iam":
        '''(experimental) Filters access if the specified policy is set as the permissions boundary on the IAM entity (user or role).

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_iam-condition-keys.html#ck_PermissionsBoundary

        Applies to actions:

        - .toAttachRolePolicy()
        - .toAttachUserPolicy()
        - .toCreateRole()
        - .toCreateUser()
        - .toDeleteRolePermissionsBoundary()
        - .toDeleteRolePolicy()
        - .toDeleteUserPermissionsBoundary()
        - .toDeleteUserPolicy()
        - .toDetachRolePolicy()
        - .toDetachUserPolicy()
        - .toPutRolePermissionsBoundary()
        - .toPutRolePolicy()
        - .toPutUserPermissionsBoundary()
        - .toPutUserPolicy()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3b2ff01862ce573e05c55d351c7341885252782818a7ca90788bd7c4ff3fa4f0)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Iam", jsii.invoke(self, "ifPermissionsBoundary", [value, operator]))

    @jsii.member(jsii_name="ifPolicyARN")
    def if_policy_arn(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Iam":
        '''(experimental) Filters access by the ARN of an IAM policy.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_iam-condition-keys.html#ck_PolicyARN

        Applies to actions:

        - .toAttachGroupPolicy()
        - .toAttachRolePolicy()
        - .toAttachUserPolicy()
        - .toDetachGroupPolicy()
        - .toDetachRolePolicy()
        - .toDetachUserPolicy()

        :param value: The value(s) to check.
        :param operator: Works with `arn operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_ARN>`_. **Default:** ``ArnLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b86aa61a6706e1c6d3a0562158cf95e9cf0127d6e1c71dd6c88affde1a63c3ea)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Iam", jsii.invoke(self, "ifPolicyARN", [value, operator]))

    @jsii.member(jsii_name="ifResourceTag")
    def if_resource_tag(
        self,
        tag_key: builtins.str,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Iam":
        '''(experimental) Filters access by the tags attached to an IAM entity (user or role).

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_iam-condition-keys.html#ck_ResourceTag

        Applies to resource types:

        - role
        - user

        :param tag_key: The tag key to check.
        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c4a968fca0c559b4f4822b0c0dd9dced8db39c16ce64b13a7ac6dbc61f4624af)
            check_type(argname="argument tag_key", value=tag_key, expected_type=type_hints["tag_key"])
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Iam", jsii.invoke(self, "ifResourceTag", [tag_key, value, operator]))

    @jsii.member(jsii_name="onAccessReport")
    def on_access_report(
        self,
        entity_path: builtins.str,
        account: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Iam":
        '''(experimental) Adds a resource of type access-report to the statement.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/access_policies_access-advisor-view-data-orgs.html

        :param entity_path: - Identifier for the entityPath.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9cef621b4babd9880979ff2b2f0da6776154d404c4cbefd50de7339d2f3d8d3e)
            check_type(argname="argument entity_path", value=entity_path, expected_type=type_hints["entity_path"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Iam", jsii.invoke(self, "onAccessReport", [entity_path, account, partition]))

    @jsii.member(jsii_name="onAssumedRole")
    def on_assumed_role(
        self,
        role_name: builtins.str,
        role_session_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Iam":
        '''(experimental) Adds a resource of type assumed-role to the statement.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/id_credentials_temp_use-resources.html

        :param role_name: - Identifier for the roleName.
        :param role_session_name: - Identifier for the roleSessionName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__36efb7f4fc7145a93262fb97ba537d40991061b00059b10f032baed7d593dfaf)
            check_type(argname="argument role_name", value=role_name, expected_type=type_hints["role_name"])
            check_type(argname="argument role_session_name", value=role_session_name, expected_type=type_hints["role_session_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Iam", jsii.invoke(self, "onAssumedRole", [role_name, role_session_name, account, partition]))

    @jsii.member(jsii_name="onFederatedUser")
    def on_federated_user(
        self,
        user_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Iam":
        '''(experimental) Adds a resource of type federated-user to the statement.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/id_roles_providers_saml.html

        :param user_name: - Identifier for the userName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__72face6d5d5f6d899d1e7612634824cf8a13c7ee8d94855df9e1c9f5379760bd)
            check_type(argname="argument user_name", value=user_name, expected_type=type_hints["user_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Iam", jsii.invoke(self, "onFederatedUser", [user_name, account, partition]))

    @jsii.member(jsii_name="onGroup")
    def on_group(
        self,
        group_name_with_path: builtins.str,
        account: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Iam":
        '''(experimental) Adds a resource of type group to the statement.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/id_groups.html

        :param group_name_with_path: - Identifier for the groupNameWithPath.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f976829733e677182b2c843cb77d21525cb8923a3eb4be394e8c25467462df46)
            check_type(argname="argument group_name_with_path", value=group_name_with_path, expected_type=type_hints["group_name_with_path"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Iam", jsii.invoke(self, "onGroup", [group_name_with_path, account, partition]))

    @jsii.member(jsii_name="onInstanceProfile")
    def on_instance_profile(
        self,
        instance_profile_name_with_path: builtins.str,
        account: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Iam":
        '''(experimental) Adds a resource of type instance-profile to the statement.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/id_roles_use_switch-role-ec2_instance-profiles.html

        :param instance_profile_name_with_path: - Identifier for the instanceProfileNameWithPath.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__23e8c92178ca78781348df3b98e580f3c7cee919987904054e32fadf54ea6093)
            check_type(argname="argument instance_profile_name_with_path", value=instance_profile_name_with_path, expected_type=type_hints["instance_profile_name_with_path"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Iam", jsii.invoke(self, "onInstanceProfile", [instance_profile_name_with_path, account, partition]))

    @jsii.member(jsii_name="onMfa")
    def on_mfa(
        self,
        mfa_token_id_with_path: builtins.str,
        account: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Iam":
        '''(experimental) Adds a resource of type mfa to the statement.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/id_credentials_mfa.html

        :param mfa_token_id_with_path: - Identifier for the mfaTokenIdWithPath.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__818c067fb16fbf6833b8c31310d23be617ac89e852c4e8168848f4e51ba04609)
            check_type(argname="argument mfa_token_id_with_path", value=mfa_token_id_with_path, expected_type=type_hints["mfa_token_id_with_path"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Iam", jsii.invoke(self, "onMfa", [mfa_token_id_with_path, account, partition]))

    @jsii.member(jsii_name="onOidcProvider")
    def on_oidc_provider(
        self,
        oidc_provider_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Iam":
        '''(experimental) Adds a resource of type oidc-provider to the statement.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/id_roles_providers_create_oidc.html

        :param oidc_provider_name: - Identifier for the oidcProviderName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6a32b7ba0b0a7d515d160ccd1ac451a13362276a709e2e33433b1784b9ff005f)
            check_type(argname="argument oidc_provider_name", value=oidc_provider_name, expected_type=type_hints["oidc_provider_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Iam", jsii.invoke(self, "onOidcProvider", [oidc_provider_name, account, partition]))

    @jsii.member(jsii_name="onPolicy")
    def on_policy(
        self,
        policy_name_with_path: builtins.str,
        account: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Iam":
        '''(experimental) Adds a resource of type policy to the statement.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/access_policies_managed-vs-inline.html

        :param policy_name_with_path: - Identifier for the policyNameWithPath.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e5ab53fc1f061c825741fc6963a4fa031c652e758d73c05558e2960db7e0fdfb)
            check_type(argname="argument policy_name_with_path", value=policy_name_with_path, expected_type=type_hints["policy_name_with_path"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Iam", jsii.invoke(self, "onPolicy", [policy_name_with_path, account, partition]))

    @jsii.member(jsii_name="onRole")
    def on_role(
        self,
        role_name_with_path: builtins.str,
        account: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Iam":
        '''(experimental) Adds a resource of type role to the statement.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/id_roles.html

        :param role_name_with_path: - Identifier for the roleNameWithPath.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag() - .ifResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__767105fd34e8827cb3f620a3c67cbbab6f50a64e828cf7aba74662123f4cd57c)
            check_type(argname="argument role_name_with_path", value=role_name_with_path, expected_type=type_hints["role_name_with_path"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Iam", jsii.invoke(self, "onRole", [role_name_with_path, account, partition]))

    @jsii.member(jsii_name="onSamlProvider")
    def on_saml_provider(
        self,
        saml_provider_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Iam":
        '''(experimental) Adds a resource of type saml-provider to the statement.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/id_roles_providers_saml.html

        :param saml_provider_name: - Identifier for the samlProviderName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2579af43a304503e0c46a59394073bd9f48ba6c4578237022bf19b7df6e3945d)
            check_type(argname="argument saml_provider_name", value=saml_provider_name, expected_type=type_hints["saml_provider_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Iam", jsii.invoke(self, "onSamlProvider", [saml_provider_name, account, partition]))

    @jsii.member(jsii_name="onServerCertificate")
    def on_server_certificate(
        self,
        certificate_name_with_path: builtins.str,
        account: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Iam":
        '''(experimental) Adds a resource of type server-certificate to the statement.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/id_credentials_server-certs.html

        :param certificate_name_with_path: - Identifier for the certificateNameWithPath.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1f95d7c6ce27bfc3cdc177609bdb83845c8a330bf393ea5b12b3e19256e7e662)
            check_type(argname="argument certificate_name_with_path", value=certificate_name_with_path, expected_type=type_hints["certificate_name_with_path"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Iam", jsii.invoke(self, "onServerCertificate", [certificate_name_with_path, account, partition]))

    @jsii.member(jsii_name="onSmsMfa")
    def on_sms_mfa(
        self,
        mfa_token_id_with_path: builtins.str,
        account: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Iam":
        '''(experimental) Adds a resource of type sms-mfa to the statement.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/id_credentials_mfa_enable_sms.html

        :param mfa_token_id_with_path: - Identifier for the mfaTokenIdWithPath.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__85d366a8ba3636b9091fc068129fda47ae616cbbecf81f6bffd3b72cad634383)
            check_type(argname="argument mfa_token_id_with_path", value=mfa_token_id_with_path, expected_type=type_hints["mfa_token_id_with_path"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Iam", jsii.invoke(self, "onSmsMfa", [mfa_token_id_with_path, account, partition]))

    @jsii.member(jsii_name="onUser")
    def on_user(
        self,
        user_name_with_path: builtins.str,
        account: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Iam":
        '''(experimental) Adds a resource of type user to the statement.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/id_users.html

        :param user_name_with_path: - Identifier for the userNameWithPath.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag() - .ifResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b8eb83663b02be981cd113d543100a718dc49594ef80fa943a1b65aa82e489d7)
            check_type(argname="argument user_name_with_path", value=user_name_with_path, expected_type=type_hints["user_name_with_path"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Iam", jsii.invoke(self, "onUser", [user_name_with_path, account, partition]))

    @jsii.member(jsii_name="toAddClientIDToOpenIDConnectProvider")
    def to_add_client_id_to_open_id_connect_provider(self) -> "Iam":
        '''(experimental) Grants permission to add a new client ID (audience) to the list of registered IDs for the specified IAM OpenID Connect (OIDC) provider resource.

        Access Level: Write

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_AddClientIDToOpenIDConnectProvider.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toAddClientIDToOpenIDConnectProvider", []))

    @jsii.member(jsii_name="toAddRoleToInstanceProfile")
    def to_add_role_to_instance_profile(self) -> "Iam":
        '''(experimental) Grants permission to add an IAM role to the specified instance profile.

        Access Level: Write

        Dependent actions:

        - iam:PassRole

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_AddRoleToInstanceProfile.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toAddRoleToInstanceProfile", []))

    @jsii.member(jsii_name="toAddUserToGroup")
    def to_add_user_to_group(self) -> "Iam":
        '''(experimental) Grants permission to add an IAM user to the specified IAM group.

        Access Level: Write

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_AddUserToGroup.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toAddUserToGroup", []))

    @jsii.member(jsii_name="toAttachGroupPolicy")
    def to_attach_group_policy(self) -> "Iam":
        '''(experimental) Grants permission to attach a managed policy to the specified IAM group.

        Access Level: Permissions management

        Possible conditions:

        - .ifPolicyARN()

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_AttachGroupPolicy.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toAttachGroupPolicy", []))

    @jsii.member(jsii_name="toAttachRolePolicy")
    def to_attach_role_policy(self) -> "Iam":
        '''(experimental) Grants permission to attach a managed policy to the specified IAM role.

        Access Level: Permissions management

        Possible conditions:

        - .ifPolicyARN()
        - .ifPermissionsBoundary()

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_AttachRolePolicy.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toAttachRolePolicy", []))

    @jsii.member(jsii_name="toAttachUserPolicy")
    def to_attach_user_policy(self) -> "Iam":
        '''(experimental) Grants permission to attach a managed policy to the specified IAM user.

        Access Level: Permissions management

        Possible conditions:

        - .ifPolicyARN()
        - .ifPermissionsBoundary()

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_AttachUserPolicy.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toAttachUserPolicy", []))

    @jsii.member(jsii_name="toChangePassword")
    def to_change_password(self) -> "Iam":
        '''(experimental) Grants permission for an IAM user to to change their own password.

        Access Level: Write

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_ChangePassword.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toChangePassword", []))

    @jsii.member(jsii_name="toCreateAccessKey")
    def to_create_access_key(self) -> "Iam":
        '''(experimental) Grants permission to create access key and secret access key for the specified IAM user.

        Access Level: Write

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_CreateAccessKey.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toCreateAccessKey", []))

    @jsii.member(jsii_name="toCreateAccountAlias")
    def to_create_account_alias(self) -> "Iam":
        '''(experimental) Grants permission to create an alias for your AWS account.

        Access Level: Write

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_CreateAccountAlias.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toCreateAccountAlias", []))

    @jsii.member(jsii_name="toCreateGroup")
    def to_create_group(self) -> "Iam":
        '''(experimental) Grants permission to create a new group.

        Access Level: Write

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_CreateGroup.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toCreateGroup", []))

    @jsii.member(jsii_name="toCreateInstanceProfile")
    def to_create_instance_profile(self) -> "Iam":
        '''(experimental) Grants permission to create a new instance profile.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_CreateInstanceProfile.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toCreateInstanceProfile", []))

    @jsii.member(jsii_name="toCreateLoginProfile")
    def to_create_login_profile(self) -> "Iam":
        '''(experimental) Grants permission to create a password for the specified IAM user.

        Access Level: Write

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_CreateLoginProfile.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toCreateLoginProfile", []))

    @jsii.member(jsii_name="toCreateOpenIDConnectProvider")
    def to_create_open_id_connect_provider(self) -> "Iam":
        '''(experimental) Grants permission to create an IAM resource that describes an identity provider (IdP) that supports OpenID Connect (OIDC).

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_CreateOpenIDConnectProvider.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toCreateOpenIDConnectProvider", []))

    @jsii.member(jsii_name="toCreatePolicy")
    def to_create_policy(self) -> "Iam":
        '''(experimental) Grants permission to create a new managed policy.

        Access Level: Permissions management

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_CreatePolicy.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toCreatePolicy", []))

    @jsii.member(jsii_name="toCreatePolicyVersion")
    def to_create_policy_version(self) -> "Iam":
        '''(experimental) Grants permission to create a new version of the specified managed policy.

        Access Level: Permissions management

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_CreatePolicyVersion.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toCreatePolicyVersion", []))

    @jsii.member(jsii_name="toCreateRole")
    def to_create_role(self) -> "Iam":
        '''(experimental) Grants permission to create a new role.

        Access Level: Write

        Possible conditions:

        - .ifPermissionsBoundary()
        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_CreateRole.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toCreateRole", []))

    @jsii.member(jsii_name="toCreateSAMLProvider")
    def to_create_saml_provider(self) -> "Iam":
        '''(experimental) Grants permission to create an IAM resource that describes an identity provider (IdP) that supports SAML 2.0.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_CreateSAMLProvider.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toCreateSAMLProvider", []))

    @jsii.member(jsii_name="toCreateServiceLinkedRole")
    def to_create_service_linked_role(self) -> "Iam":
        '''(experimental) Grants permission to create an IAM role that allows an AWS service to perform actions on your behalf.

        Access Level: Write

        Possible conditions:

        - .ifAWSServiceName()

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_CreateServiceLinkedRole.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toCreateServiceLinkedRole", []))

    @jsii.member(jsii_name="toCreateServiceSpecificCredential")
    def to_create_service_specific_credential(self) -> "Iam":
        '''(experimental) Grants permission to create a new service-specific credential for an IAM user.

        Access Level: Write

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_CreateServiceSpecificCredential.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toCreateServiceSpecificCredential", []))

    @jsii.member(jsii_name="toCreateUser")
    def to_create_user(self) -> "Iam":
        '''(experimental) Grants permission to create a new IAM user.

        Access Level: Write

        Possible conditions:

        - .ifPermissionsBoundary()
        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_CreateUser.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toCreateUser", []))

    @jsii.member(jsii_name="toCreateVirtualMFADevice")
    def to_create_virtual_mfa_device(self) -> "Iam":
        '''(experimental) Grants permission to create a new virtual MFA device.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_CreateVirtualMFADevice.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toCreateVirtualMFADevice", []))

    @jsii.member(jsii_name="toDeactivateMFADevice")
    def to_deactivate_mfa_device(self) -> "Iam":
        '''(experimental) Grants permission to deactivate the specified MFA device and remove its association with the IAM user for which it was originally enabled.

        Access Level: Write

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_DeactivateMFADevice.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toDeactivateMFADevice", []))

    @jsii.member(jsii_name="toDeleteAccessKey")
    def to_delete_access_key(self) -> "Iam":
        '''(experimental) Grants permission to delete the access key pair that is associated with the specified IAM user.

        Access Level: Write

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_DeleteAccessKey.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toDeleteAccessKey", []))

    @jsii.member(jsii_name="toDeleteAccountAlias")
    def to_delete_account_alias(self) -> "Iam":
        '''(experimental) Grants permission to delete the specified AWS account alias.

        Access Level: Write

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_DeleteAccountAlias.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toDeleteAccountAlias", []))

    @jsii.member(jsii_name="toDeleteAccountPasswordPolicy")
    def to_delete_account_password_policy(self) -> "Iam":
        '''(experimental) Grants permission to delete the password policy for the AWS account.

        Access Level: Permissions management

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_DeleteAccountPasswordPolicy.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toDeleteAccountPasswordPolicy", []))

    @jsii.member(jsii_name="toDeleteGroup")
    def to_delete_group(self) -> "Iam":
        '''(experimental) Grants permission to delete the specified IAM group.

        Access Level: Write

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_DeleteGroup.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toDeleteGroup", []))

    @jsii.member(jsii_name="toDeleteGroupPolicy")
    def to_delete_group_policy(self) -> "Iam":
        '''(experimental) Grants permission to delete the specified inline policy from its group.

        Access Level: Permissions management

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_DeleteGroupPolicy.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toDeleteGroupPolicy", []))

    @jsii.member(jsii_name="toDeleteInstanceProfile")
    def to_delete_instance_profile(self) -> "Iam":
        '''(experimental) Grants permission to delete the specified instance profile.

        Access Level: Write

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_DeleteInstanceProfile.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toDeleteInstanceProfile", []))

    @jsii.member(jsii_name="toDeleteLoginProfile")
    def to_delete_login_profile(self) -> "Iam":
        '''(experimental) Grants permission to delete the password for the specified IAM user.

        Access Level: Write

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_DeleteLoginProfile.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toDeleteLoginProfile", []))

    @jsii.member(jsii_name="toDeleteOpenIDConnectProvider")
    def to_delete_open_id_connect_provider(self) -> "Iam":
        '''(experimental) Grants permission to delete an OpenID Connect identity provider (IdP) resource object in IAM.

        Access Level: Write

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_DeleteOpenIDConnectProvider.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toDeleteOpenIDConnectProvider", []))

    @jsii.member(jsii_name="toDeletePolicy")
    def to_delete_policy(self) -> "Iam":
        '''(experimental) Grants permission to delete the specified managed policy and remove it from any IAM entities (users, groups, or roles) to which it is attached.

        Access Level: Permissions management

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_DeletePolicy.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toDeletePolicy", []))

    @jsii.member(jsii_name="toDeletePolicyVersion")
    def to_delete_policy_version(self) -> "Iam":
        '''(experimental) Grants permission to delete a version from the specified managed policy.

        Access Level: Permissions management

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_DeletePolicyVersion.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toDeletePolicyVersion", []))

    @jsii.member(jsii_name="toDeleteRole")
    def to_delete_role(self) -> "Iam":
        '''(experimental) Grants permission to delete the specified role.

        Access Level: Write

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_DeleteRole.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toDeleteRole", []))

    @jsii.member(jsii_name="toDeleteRolePermissionsBoundary")
    def to_delete_role_permissions_boundary(self) -> "Iam":
        '''(experimental) Grants permission to remove the permissions boundary from a role.

        Access Level: Permissions management

        Possible conditions:

        - .ifPermissionsBoundary()

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_DeleteRolePermissionsBoundary.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toDeleteRolePermissionsBoundary", []))

    @jsii.member(jsii_name="toDeleteRolePolicy")
    def to_delete_role_policy(self) -> "Iam":
        '''(experimental) Grants permission to delete the specified inline policy from the specified role.

        Access Level: Permissions management

        Possible conditions:

        - .ifPermissionsBoundary()

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_DeleteRolePolicy.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toDeleteRolePolicy", []))

    @jsii.member(jsii_name="toDeleteSAMLProvider")
    def to_delete_saml_provider(self) -> "Iam":
        '''(experimental) Grants permission to delete a SAML provider resource in IAM.

        Access Level: Write

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_DeleteSAMLProvider.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toDeleteSAMLProvider", []))

    @jsii.member(jsii_name="toDeleteServerCertificate")
    def to_delete_server_certificate(self) -> "Iam":
        '''(experimental) Grants permission to delete the specified server certificate.

        Access Level: Write

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_DeleteServerCertificate.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toDeleteServerCertificate", []))

    @jsii.member(jsii_name="toDeleteServiceLinkedRole")
    def to_delete_service_linked_role(self) -> "Iam":
        '''(experimental) Grants permission to delete an IAM role that is linked to a specific AWS service, if the service is no longer using it.

        Access Level: Write

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_DeleteServiceLinkedRole.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toDeleteServiceLinkedRole", []))

    @jsii.member(jsii_name="toDeleteServiceSpecificCredential")
    def to_delete_service_specific_credential(self) -> "Iam":
        '''(experimental) Grants permission to delete the specified service-specific credential for an IAM user.

        Access Level: Write

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_DeleteServiceSpecificCredential.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toDeleteServiceSpecificCredential", []))

    @jsii.member(jsii_name="toDeleteSigningCertificate")
    def to_delete_signing_certificate(self) -> "Iam":
        '''(experimental) Grants permission to delete a signing certificate that is associated with the specified IAM user.

        Access Level: Write

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_DeleteSigningCertificate.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toDeleteSigningCertificate", []))

    @jsii.member(jsii_name="toDeleteSSHPublicKey")
    def to_delete_ssh_public_key(self) -> "Iam":
        '''(experimental) Grants permission to delete the specified SSH public key.

        Access Level: Write

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_DeleteSSHPublicKey.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toDeleteSSHPublicKey", []))

    @jsii.member(jsii_name="toDeleteUser")
    def to_delete_user(self) -> "Iam":
        '''(experimental) Grants permission to delete the specified IAM user.

        Access Level: Write

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_DeleteUser.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toDeleteUser", []))

    @jsii.member(jsii_name="toDeleteUserPermissionsBoundary")
    def to_delete_user_permissions_boundary(self) -> "Iam":
        '''(experimental) Grants permission to remove the permissions boundary from the specified IAM user.

        Access Level: Permissions management

        Possible conditions:

        - .ifPermissionsBoundary()

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_DeleteUserPermissionsBoundary.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toDeleteUserPermissionsBoundary", []))

    @jsii.member(jsii_name="toDeleteUserPolicy")
    def to_delete_user_policy(self) -> "Iam":
        '''(experimental) Grants permission to delete the specified inline policy from an IAM user.

        Access Level: Permissions management

        Possible conditions:

        - .ifPermissionsBoundary()

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_DeleteUserPolicy.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toDeleteUserPolicy", []))

    @jsii.member(jsii_name="toDeleteVirtualMFADevice")
    def to_delete_virtual_mfa_device(self) -> "Iam":
        '''(experimental) Grants permission to delete a virtual MFA device.

        Access Level: Write

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_DeleteVirtualMFADevice.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toDeleteVirtualMFADevice", []))

    @jsii.member(jsii_name="toDetachGroupPolicy")
    def to_detach_group_policy(self) -> "Iam":
        '''(experimental) Grants permission to detach a managed policy from the specified IAM group.

        Access Level: Permissions management

        Possible conditions:

        - .ifPolicyARN()

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_DetachGroupPolicy.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toDetachGroupPolicy", []))

    @jsii.member(jsii_name="toDetachRolePolicy")
    def to_detach_role_policy(self) -> "Iam":
        '''(experimental) Grants permission to detach a managed policy from the specified role.

        Access Level: Permissions management

        Possible conditions:

        - .ifPolicyARN()
        - .ifPermissionsBoundary()

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_DetachRolePolicy.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toDetachRolePolicy", []))

    @jsii.member(jsii_name="toDetachUserPolicy")
    def to_detach_user_policy(self) -> "Iam":
        '''(experimental) Grants permission to detach a managed policy from the specified IAM user.

        Access Level: Permissions management

        Possible conditions:

        - .ifPolicyARN()
        - .ifPermissionsBoundary()

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_DetachUserPolicy.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toDetachUserPolicy", []))

    @jsii.member(jsii_name="toEnableMFADevice")
    def to_enable_mfa_device(self) -> "Iam":
        '''(experimental) Grants permission to enable an MFA device and associate it with the specified IAM user.

        Access Level: Write

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_EnableMFADevice.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toEnableMFADevice", []))

    @jsii.member(jsii_name="toGenerateCredentialReport")
    def to_generate_credential_report(self) -> "Iam":
        '''(experimental) Grants permission to generate a credential report for the AWS account.

        Access Level: Read

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_GenerateCredentialReport.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toGenerateCredentialReport", []))

    @jsii.member(jsii_name="toGenerateOrganizationsAccessReport")
    def to_generate_organizations_access_report(self) -> "Iam":
        '''(experimental) Grants permission to generate an access report for an AWS Organizations entity.

        Access Level: Read

        Possible conditions:

        - .ifOrganizationsPolicyId()

        Dependent actions:

        - organizations:DescribePolicy
        - organizations:ListChildren
        - organizations:ListParents
        - organizations:ListPoliciesForTarget
        - organizations:ListRoots
        - organizations:ListTargetsForPolicy

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_GenerateOrganizationsAccessReport.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toGenerateOrganizationsAccessReport", []))

    @jsii.member(jsii_name="toGenerateServiceLastAccessedDetails")
    def to_generate_service_last_accessed_details(self) -> "Iam":
        '''(experimental) Grants permission to generate a service last accessed data report for an IAM resource.

        Access Level: Read

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_GenerateServiceLastAccessedDetails.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toGenerateServiceLastAccessedDetails", []))

    @jsii.member(jsii_name="toGetAccessKeyLastUsed")
    def to_get_access_key_last_used(self) -> "Iam":
        '''(experimental) Grants permission to retrieve information about when the specified access key was last used.

        Access Level: Read

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_GetAccessKeyLastUsed.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toGetAccessKeyLastUsed", []))

    @jsii.member(jsii_name="toGetAccountAuthorizationDetails")
    def to_get_account_authorization_details(self) -> "Iam":
        '''(experimental) Grants permission to retrieve information about all IAM users, groups, roles, and policies in your AWS account, including their relationships to one another.

        Access Level: Read

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_GetAccountAuthorizationDetails.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toGetAccountAuthorizationDetails", []))

    @jsii.member(jsii_name="toGetAccountPasswordPolicy")
    def to_get_account_password_policy(self) -> "Iam":
        '''(experimental) Grants permission to retrieve the password policy for the AWS account.

        Access Level: Read

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_GetAccountPasswordPolicy.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toGetAccountPasswordPolicy", []))

    @jsii.member(jsii_name="toGetAccountSummary")
    def to_get_account_summary(self) -> "Iam":
        '''(experimental) Grants permission to retrieve information about IAM entity usage and IAM quotas in the AWS account.

        Access Level: List

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_GetAccountSummary.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toGetAccountSummary", []))

    @jsii.member(jsii_name="toGetContextKeysForCustomPolicy")
    def to_get_context_keys_for_custom_policy(self) -> "Iam":
        '''(experimental) Grants permission to retrieve a list of all of the context keys that are referenced in the specified policy.

        Access Level: Read

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_GetContextKeysForCustomPolicy.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toGetContextKeysForCustomPolicy", []))

    @jsii.member(jsii_name="toGetContextKeysForPrincipalPolicy")
    def to_get_context_keys_for_principal_policy(self) -> "Iam":
        '''(experimental) Grants permission to retrieve a list of all context keys that are referenced in all IAM policies that are attached to the specified IAM identity (user, group, or role).

        Access Level: Read

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_GetContextKeysForPrincipalPolicy.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toGetContextKeysForPrincipalPolicy", []))

    @jsii.member(jsii_name="toGetCredentialReport")
    def to_get_credential_report(self) -> "Iam":
        '''(experimental) Grants permission to retrieve a credential report for the AWS account.

        Access Level: Read

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_GetCredentialReport.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toGetCredentialReport", []))

    @jsii.member(jsii_name="toGetGroup")
    def to_get_group(self) -> "Iam":
        '''(experimental) Grants permission to retrieve a list of IAM users in the specified IAM group.

        Access Level: Read

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_GetGroup.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toGetGroup", []))

    @jsii.member(jsii_name="toGetGroupPolicy")
    def to_get_group_policy(self) -> "Iam":
        '''(experimental) Grants permission to retrieve an inline policy document that is embedded in the specified IAM group.

        Access Level: Read

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_GetGroupPolicy.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toGetGroupPolicy", []))

    @jsii.member(jsii_name="toGetInstanceProfile")
    def to_get_instance_profile(self) -> "Iam":
        '''(experimental) Grants permission to retrieve information about the specified instance profile, including the instance profile's path, GUID, ARN, and role.

        Access Level: Read

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_GetInstanceProfile.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toGetInstanceProfile", []))

    @jsii.member(jsii_name="toGetLoginProfile")
    def to_get_login_profile(self) -> "Iam":
        '''(experimental) Grants permission to retrieve the user name and password creation date for the specified IAM user.

        Access Level: List

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_GetLoginProfile.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toGetLoginProfile", []))

    @jsii.member(jsii_name="toGetOpenIDConnectProvider")
    def to_get_open_id_connect_provider(self) -> "Iam":
        '''(experimental) Grants permission to retrieve information about the specified OpenID Connect (OIDC) provider resource in IAM.

        Access Level: Read

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_GetOpenIDConnectProvider.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toGetOpenIDConnectProvider", []))

    @jsii.member(jsii_name="toGetOrganizationsAccessReport")
    def to_get_organizations_access_report(self) -> "Iam":
        '''(experimental) Grants permission to retrieve an AWS Organizations access report.

        Access Level: Read

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_GetOrganizationsAccessReport.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toGetOrganizationsAccessReport", []))

    @jsii.member(jsii_name="toGetPolicy")
    def to_get_policy(self) -> "Iam":
        '''(experimental) Grants permission to retrieve information about the specified managed policy, including the policy's default version and the total number of identities to which the policy is attached.

        Access Level: Read

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_GetPolicy.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toGetPolicy", []))

    @jsii.member(jsii_name="toGetPolicyVersion")
    def to_get_policy_version(self) -> "Iam":
        '''(experimental) Grants permission to retrieve information about a version of the specified managed policy, including the policy document.

        Access Level: Read

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_GetPolicyVersion.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toGetPolicyVersion", []))

    @jsii.member(jsii_name="toGetRole")
    def to_get_role(self) -> "Iam":
        '''(experimental) Grants permission to retrieve information about the specified role, including the role's path, GUID, ARN, and the role's trust policy.

        Access Level: Read

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_GetRole.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toGetRole", []))

    @jsii.member(jsii_name="toGetRolePolicy")
    def to_get_role_policy(self) -> "Iam":
        '''(experimental) Grants permission to retrieve an inline policy document that is embedded with the specified IAM role.

        Access Level: Read

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_GetRolePolicy.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toGetRolePolicy", []))

    @jsii.member(jsii_name="toGetSAMLProvider")
    def to_get_saml_provider(self) -> "Iam":
        '''(experimental) Grants permission to retrieve the SAML provider metadocument that was uploaded when the IAM SAML provider resource was created or updated.

        Access Level: Read

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_GetSAMLProvider.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toGetSAMLProvider", []))

    @jsii.member(jsii_name="toGetServerCertificate")
    def to_get_server_certificate(self) -> "Iam":
        '''(experimental) Grants permission to retrieve information about the specified server certificate stored in IAM.

        Access Level: Read

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_GetServerCertificate.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toGetServerCertificate", []))

    @jsii.member(jsii_name="toGetServiceLastAccessedDetails")
    def to_get_service_last_accessed_details(self) -> "Iam":
        '''(experimental) Grants permission to retrieve information about the service last accessed data report.

        Access Level: Read

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_GetServiceLastAccessedDetails.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toGetServiceLastAccessedDetails", []))

    @jsii.member(jsii_name="toGetServiceLastAccessedDetailsWithEntities")
    def to_get_service_last_accessed_details_with_entities(self) -> "Iam":
        '''(experimental) Grants permission to retrieve information about the entities from the service last accessed data report.

        Access Level: Read

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_GetServiceLastAccessedDetailsWithEntities.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toGetServiceLastAccessedDetailsWithEntities", []))

    @jsii.member(jsii_name="toGetServiceLinkedRoleDeletionStatus")
    def to_get_service_linked_role_deletion_status(self) -> "Iam":
        '''(experimental) Grants permission to retrieve an IAM service-linked role deletion status.

        Access Level: Read

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_GetServiceLinkedRoleDeletionStatus.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toGetServiceLinkedRoleDeletionStatus", []))

    @jsii.member(jsii_name="toGetSSHPublicKey")
    def to_get_ssh_public_key(self) -> "Iam":
        '''(experimental) Grants permission to retrieve the specified SSH public key, including metadata about the key.

        Access Level: Read

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_GetSSHPublicKey.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toGetSSHPublicKey", []))

    @jsii.member(jsii_name="toGetUser")
    def to_get_user(self) -> "Iam":
        '''(experimental) Grants permission to retrieve information about the specified IAM user, including the user's creation date, path, unique ID, and ARN.

        Access Level: Read

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_GetUser.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toGetUser", []))

    @jsii.member(jsii_name="toGetUserPolicy")
    def to_get_user_policy(self) -> "Iam":
        '''(experimental) Grants permission to retrieve an inline policy document that is embedded in the specified IAM user.

        Access Level: Read

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_GetUserPolicy.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toGetUserPolicy", []))

    @jsii.member(jsii_name="toListAccessKeys")
    def to_list_access_keys(self) -> "Iam":
        '''(experimental) Grants permission to list information about the access key IDs that are associated with the specified IAM user.

        Access Level: List

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_ListAccessKeys.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toListAccessKeys", []))

    @jsii.member(jsii_name="toListAccountAliases")
    def to_list_account_aliases(self) -> "Iam":
        '''(experimental) Grants permission to list the account alias that is associated with the AWS account.

        Access Level: List

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_ListAccountAliases.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toListAccountAliases", []))

    @jsii.member(jsii_name="toListAttachedGroupPolicies")
    def to_list_attached_group_policies(self) -> "Iam":
        '''(experimental) Grants permission to list all managed policies that are attached to the specified IAM group.

        Access Level: List

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_ListAttachedGroupPolicies.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toListAttachedGroupPolicies", []))

    @jsii.member(jsii_name="toListAttachedRolePolicies")
    def to_list_attached_role_policies(self) -> "Iam":
        '''(experimental) Grants permission to list all managed policies that are attached to the specified IAM role.

        Access Level: List

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_ListAttachedRolePolicies.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toListAttachedRolePolicies", []))

    @jsii.member(jsii_name="toListAttachedUserPolicies")
    def to_list_attached_user_policies(self) -> "Iam":
        '''(experimental) Grants permission to list all managed policies that are attached to the specified IAM user.

        Access Level: List

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_ListAttachedUserPolicies.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toListAttachedUserPolicies", []))

    @jsii.member(jsii_name="toListEntitiesForPolicy")
    def to_list_entities_for_policy(self) -> "Iam":
        '''(experimental) Grants permission to list all IAM identities to which the specified managed policy is attached.

        Access Level: List

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_ListEntitiesForPolicy.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toListEntitiesForPolicy", []))

    @jsii.member(jsii_name="toListGroupPolicies")
    def to_list_group_policies(self) -> "Iam":
        '''(experimental) Grants permission to list the names of the inline policies that are embedded in the specified IAM group.

        Access Level: List

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_ListGroupPolicies.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toListGroupPolicies", []))

    @jsii.member(jsii_name="toListGroups")
    def to_list_groups(self) -> "Iam":
        '''(experimental) Grants permission to list the IAM groups that have the specified path prefix.

        Access Level: List

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_ListGroups.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toListGroups", []))

    @jsii.member(jsii_name="toListGroupsForUser")
    def to_list_groups_for_user(self) -> "Iam":
        '''(experimental) Grants permission to list the IAM groups that the specified IAM user belongs to.

        Access Level: List

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_ListGroupsForUser.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toListGroupsForUser", []))

    @jsii.member(jsii_name="toListInstanceProfiles")
    def to_list_instance_profiles(self) -> "Iam":
        '''(experimental) Grants permission to list the instance profiles that have the specified path prefix.

        Access Level: List

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_ListInstanceProfiles.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toListInstanceProfiles", []))

    @jsii.member(jsii_name="toListInstanceProfilesForRole")
    def to_list_instance_profiles_for_role(self) -> "Iam":
        '''(experimental) Grants permission to list the instance profiles that have the specified associated IAM role.

        Access Level: List

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_ListInstanceProfilesForRole.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toListInstanceProfilesForRole", []))

    @jsii.member(jsii_name="toListInstanceProfileTags")
    def to_list_instance_profile_tags(self) -> "Iam":
        '''(experimental) Grants permission to list the tags that are attached to the specified instance profile.

        Access Level: List

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_ListInstanceProfileTags.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toListInstanceProfileTags", []))

    @jsii.member(jsii_name="toListMFADevices")
    def to_list_mfa_devices(self) -> "Iam":
        '''(experimental) Grants permission to list the MFA devices for an IAM user.

        Access Level: List

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_ListMFADevices.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toListMFADevices", []))

    @jsii.member(jsii_name="toListMFADeviceTags")
    def to_list_mfa_device_tags(self) -> "Iam":
        '''(experimental) Grants permission to list the tags that are attached to the specified virtual mfa device.

        Access Level: List

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_ListMFADeviceTags.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toListMFADeviceTags", []))

    @jsii.member(jsii_name="toListOpenIDConnectProviders")
    def to_list_open_id_connect_providers(self) -> "Iam":
        '''(experimental) Grants permission to list information about the IAM OpenID Connect (OIDC) provider resource objects that are defined in the AWS account.

        Access Level: List

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_ListOpenIDConnectProviders.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toListOpenIDConnectProviders", []))

    @jsii.member(jsii_name="toListOpenIDConnectProviderTags")
    def to_list_open_id_connect_provider_tags(self) -> "Iam":
        '''(experimental) Grants permission to list the tags that are attached to the specified OpenID Connect provider.

        Access Level: List

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_ListOpenIDConnectProviderTags.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toListOpenIDConnectProviderTags", []))

    @jsii.member(jsii_name="toListPolicies")
    def to_list_policies(self) -> "Iam":
        '''(experimental) Grants permission to list all managed policies.

        Access Level: List

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_ListPolicies.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toListPolicies", []))

    @jsii.member(jsii_name="toListPoliciesGrantingServiceAccess")
    def to_list_policies_granting_service_access(self) -> "Iam":
        '''(experimental) Grants permission to list information about the policies that grant an entity access to a specific service.

        Access Level: List

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_ListPoliciesGrantingServiceAccess.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toListPoliciesGrantingServiceAccess", []))

    @jsii.member(jsii_name="toListPolicyTags")
    def to_list_policy_tags(self) -> "Iam":
        '''(experimental) Grants permission to list the tags that are attached to the specified managed policy.

        Access Level: List

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_ListPolicyTags.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toListPolicyTags", []))

    @jsii.member(jsii_name="toListPolicyVersions")
    def to_list_policy_versions(self) -> "Iam":
        '''(experimental) Grants permission to list information about the versions of the specified managed policy, including the version that is currently set as the policy's default version.

        Access Level: List

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_ListPolicyVersions.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toListPolicyVersions", []))

    @jsii.member(jsii_name="toListRolePolicies")
    def to_list_role_policies(self) -> "Iam":
        '''(experimental) Grants permission to list the names of the inline policies that are embedded in the specified IAM role.

        Access Level: List

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_ListRolePolicies.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toListRolePolicies", []))

    @jsii.member(jsii_name="toListRoles")
    def to_list_roles(self) -> "Iam":
        '''(experimental) Grants permission to list the IAM roles that have the specified path prefix.

        Access Level: List

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_ListRoles.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toListRoles", []))

    @jsii.member(jsii_name="toListRoleTags")
    def to_list_role_tags(self) -> "Iam":
        '''(experimental) Grants permission to list the tags that are attached to the specified IAM role.

        Access Level: List

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_ListRoleTags.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toListRoleTags", []))

    @jsii.member(jsii_name="toListSAMLProviders")
    def to_list_saml_providers(self) -> "Iam":
        '''(experimental) Grants permission to list the SAML provider resources in IAM.

        Access Level: List

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_ListSAMLProviders.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toListSAMLProviders", []))

    @jsii.member(jsii_name="toListSAMLProviderTags")
    def to_list_saml_provider_tags(self) -> "Iam":
        '''(experimental) Grants permission to list the tags that are attached to the specified SAML provider.

        Access Level: List

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_ListSAMLProviderTags.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toListSAMLProviderTags", []))

    @jsii.member(jsii_name="toListServerCertificates")
    def to_list_server_certificates(self) -> "Iam":
        '''(experimental) Grants permission to list the server certificates that have the specified path prefix.

        Access Level: List

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_ListServerCertificates.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toListServerCertificates", []))

    @jsii.member(jsii_name="toListServerCertificateTags")
    def to_list_server_certificate_tags(self) -> "Iam":
        '''(experimental) Grants permission to list the tags that are attached to the specified server certificate.

        Access Level: List

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_ListServerCertificateTags.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toListServerCertificateTags", []))

    @jsii.member(jsii_name="toListServiceSpecificCredentials")
    def to_list_service_specific_credentials(self) -> "Iam":
        '''(experimental) Grants permission to list the service-specific credentials that are associated with the specified IAM user.

        Access Level: List

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_ListServiceSpecificCredentials.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toListServiceSpecificCredentials", []))

    @jsii.member(jsii_name="toListSigningCertificates")
    def to_list_signing_certificates(self) -> "Iam":
        '''(experimental) Grants permission to list information about the signing certificates that are associated with the specified IAM user.

        Access Level: List

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_ListSigningCertificates.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toListSigningCertificates", []))

    @jsii.member(jsii_name="toListSSHPublicKeys")
    def to_list_ssh_public_keys(self) -> "Iam":
        '''(experimental) Grants permission to list information about the SSH public keys that are associated with the specified IAM user.

        Access Level: List

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_ListSSHPublicKeys.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toListSSHPublicKeys", []))

    @jsii.member(jsii_name="toListUserPolicies")
    def to_list_user_policies(self) -> "Iam":
        '''(experimental) Grants permission to list the names of the inline policies that are embedded in the specified IAM user.

        Access Level: List

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_ListUserPolicies.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toListUserPolicies", []))

    @jsii.member(jsii_name="toListUsers")
    def to_list_users(self) -> "Iam":
        '''(experimental) Grants permission to list the IAM users that have the specified path prefix.

        Access Level: List

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_ListUsers.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toListUsers", []))

    @jsii.member(jsii_name="toListUserTags")
    def to_list_user_tags(self) -> "Iam":
        '''(experimental) Grants permission to list the tags that are attached to the specified IAM user.

        Access Level: List

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_ListUserTags.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toListUserTags", []))

    @jsii.member(jsii_name="toListVirtualMFADevices")
    def to_list_virtual_mfa_devices(self) -> "Iam":
        '''(experimental) Grants permission to list virtual MFA devices by assignment status.

        Access Level: List

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_ListVirtualMFADevices.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toListVirtualMFADevices", []))

    @jsii.member(jsii_name="toPassRole")
    def to_pass_role(self) -> "Iam":
        '''(experimental) Grants permission to pass a role to a service.

        Access Level: Write

        Possible conditions:

        - .ifAssociatedResourceArn()
        - .ifPassedToService()

        https://docs.aws.amazon.com/IAM/latest/UserGuide/id_roles_use_passrole.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toPassRole", []))

    @jsii.member(jsii_name="toPutGroupPolicy")
    def to_put_group_policy(self) -> "Iam":
        '''(experimental) Grants permission to create or update an inline policy document that is embedded in the specified IAM group.

        Access Level: Permissions management

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_PutGroupPolicy.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toPutGroupPolicy", []))

    @jsii.member(jsii_name="toPutRolePermissionsBoundary")
    def to_put_role_permissions_boundary(self) -> "Iam":
        '''(experimental) Grants permission to set a managed policy as a permissions boundary for a role.

        Access Level: Permissions management

        Possible conditions:

        - .ifPermissionsBoundary()

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_PutRolePermissionsBoundary.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toPutRolePermissionsBoundary", []))

    @jsii.member(jsii_name="toPutRolePolicy")
    def to_put_role_policy(self) -> "Iam":
        '''(experimental) Grants permission to create or update an inline policy document that is embedded in the specified IAM role.

        Access Level: Permissions management

        Possible conditions:

        - .ifPermissionsBoundary()

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_PutRolePolicy.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toPutRolePolicy", []))

    @jsii.member(jsii_name="toPutUserPermissionsBoundary")
    def to_put_user_permissions_boundary(self) -> "Iam":
        '''(experimental) Grants permission to set a managed policy as a permissions boundary for an IAM user.

        Access Level: Permissions management

        Possible conditions:

        - .ifPermissionsBoundary()

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_PutUserPermissionsBoundary.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toPutUserPermissionsBoundary", []))

    @jsii.member(jsii_name="toPutUserPolicy")
    def to_put_user_policy(self) -> "Iam":
        '''(experimental) Grants permission to create or update an inline policy document that is embedded in the specified IAM user.

        Access Level: Permissions management

        Possible conditions:

        - .ifPermissionsBoundary()

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_PutUserPolicy.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toPutUserPolicy", []))

    @jsii.member(jsii_name="toRemoveClientIDFromOpenIDConnectProvider")
    def to_remove_client_id_from_open_id_connect_provider(self) -> "Iam":
        '''(experimental) Grants permission to remove the client ID (audience) from the list of client IDs in the specified IAM OpenID Connect (OIDC) provider resource.

        Access Level: Write

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_RemoveClientIDFromOpenIDConnectProvider.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toRemoveClientIDFromOpenIDConnectProvider", []))

    @jsii.member(jsii_name="toRemoveRoleFromInstanceProfile")
    def to_remove_role_from_instance_profile(self) -> "Iam":
        '''(experimental) Grants permission to remove an IAM role from the specified EC2 instance profile.

        Access Level: Write

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_RemoveRoleFromInstanceProfile.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toRemoveRoleFromInstanceProfile", []))

    @jsii.member(jsii_name="toRemoveUserFromGroup")
    def to_remove_user_from_group(self) -> "Iam":
        '''(experimental) Grants permission to remove an IAM user from the specified group.

        Access Level: Write

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_RemoveUserFromGroup.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toRemoveUserFromGroup", []))

    @jsii.member(jsii_name="toResetServiceSpecificCredential")
    def to_reset_service_specific_credential(self) -> "Iam":
        '''(experimental) Grants permission to reset the password for an existing service-specific credential for an IAM user.

        Access Level: Write

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_ResetServiceSpecificCredential.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toResetServiceSpecificCredential", []))

    @jsii.member(jsii_name="toResyncMFADevice")
    def to_resync_mfa_device(self) -> "Iam":
        '''(experimental) Grants permission to synchronize the specified MFA device with its IAM entity (user or role).

        Access Level: Write

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_ResyncMFADevice.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toResyncMFADevice", []))

    @jsii.member(jsii_name="toSetDefaultPolicyVersion")
    def to_set_default_policy_version(self) -> "Iam":
        '''(experimental) Grants permission to set the version of the specified policy as the policy's default version.

        Access Level: Permissions management

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_SetDefaultPolicyVersion.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toSetDefaultPolicyVersion", []))

    @jsii.member(jsii_name="toSetSecurityTokenServicePreferences")
    def to_set_security_token_service_preferences(self) -> "Iam":
        '''(experimental) Grants permission to set the STS global endpoint token version.

        Access Level: Write

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_SetSecurityTokenServicePreferences.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toSetSecurityTokenServicePreferences", []))

    @jsii.member(jsii_name="toSimulateCustomPolicy")
    def to_simulate_custom_policy(self) -> "Iam":
        '''(experimental) Grants permission to simulate whether an identity-based policy or resource-based policy provides permissions for specific API operations and resources.

        Access Level: Read

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_SimulateCustomPolicy.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toSimulateCustomPolicy", []))

    @jsii.member(jsii_name="toSimulatePrincipalPolicy")
    def to_simulate_principal_policy(self) -> "Iam":
        '''(experimental) Grants permission to simulate whether an identity-based policy that is attached to a specified IAM entity (user or role) provides permissions for specific API operations and resources.

        Access Level: Read

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_SimulatePrincipalPolicy.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toSimulatePrincipalPolicy", []))

    @jsii.member(jsii_name="toTagInstanceProfile")
    def to_tag_instance_profile(self) -> "Iam":
        '''(experimental) Grants permission to add tags to an instance profile.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_TagInstanceProfile.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toTagInstanceProfile", []))

    @jsii.member(jsii_name="toTagMFADevice")
    def to_tag_mfa_device(self) -> "Iam":
        '''(experimental) Grants permission to add tags to a virtual mfa device.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_TagMFADevice.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toTagMFADevice", []))

    @jsii.member(jsii_name="toTagOpenIDConnectProvider")
    def to_tag_open_id_connect_provider(self) -> "Iam":
        '''(experimental) Grants permission to add tags to an OpenID Connect provider.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_TagOpenIDConnectProvider.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toTagOpenIDConnectProvider", []))

    @jsii.member(jsii_name="toTagPolicy")
    def to_tag_policy(self) -> "Iam":
        '''(experimental) Grants permission to add tags to a managed policy.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_TagPolicy.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toTagPolicy", []))

    @jsii.member(jsii_name="toTagRole")
    def to_tag_role(self) -> "Iam":
        '''(experimental) Grants permission to add tags to an IAM role.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_TagRole.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toTagRole", []))

    @jsii.member(jsii_name="toTagSAMLProvider")
    def to_tag_saml_provider(self) -> "Iam":
        '''(experimental) Grants permission to add tags to a SAML Provider.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_TagSAMLProvider.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toTagSAMLProvider", []))

    @jsii.member(jsii_name="toTagServerCertificate")
    def to_tag_server_certificate(self) -> "Iam":
        '''(experimental) Grants permission to add tags to a server certificate.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_TagServerCertificate.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toTagServerCertificate", []))

    @jsii.member(jsii_name="toTagUser")
    def to_tag_user(self) -> "Iam":
        '''(experimental) Grants permission to add tags to an IAM user.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_TagUser.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toTagUser", []))

    @jsii.member(jsii_name="toUntagInstanceProfile")
    def to_untag_instance_profile(self) -> "Iam":
        '''(experimental) Grants permission to remove the specified tags from the instance profile.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_UntagInstanceProfile.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toUntagInstanceProfile", []))

    @jsii.member(jsii_name="toUntagMFADevice")
    def to_untag_mfa_device(self) -> "Iam":
        '''(experimental) Grants permission to remove the specified tags from the virtual mfa device.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_UntagMFADevice.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toUntagMFADevice", []))

    @jsii.member(jsii_name="toUntagOpenIDConnectProvider")
    def to_untag_open_id_connect_provider(self) -> "Iam":
        '''(experimental) Grants permission to remove the specified tags from the OpenID Connect provider.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_UntagOpenIDConnectProvider.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toUntagOpenIDConnectProvider", []))

    @jsii.member(jsii_name="toUntagPolicy")
    def to_untag_policy(self) -> "Iam":
        '''(experimental) Grants permission to remove the specified tags from the managed policy.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_UntagPolicy.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toUntagPolicy", []))

    @jsii.member(jsii_name="toUntagRole")
    def to_untag_role(self) -> "Iam":
        '''(experimental) Grants permission to remove the specified tags from the role.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_UntagRole.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toUntagRole", []))

    @jsii.member(jsii_name="toUntagSAMLProvider")
    def to_untag_saml_provider(self) -> "Iam":
        '''(experimental) Grants permission to remove the specified tags from the SAML Provider.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_UntagSAMLProvider.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toUntagSAMLProvider", []))

    @jsii.member(jsii_name="toUntagServerCertificate")
    def to_untag_server_certificate(self) -> "Iam":
        '''(experimental) Grants permission to remove the specified tags from the server certificate.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_UntagServerCertificate.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toUntagServerCertificate", []))

    @jsii.member(jsii_name="toUntagUser")
    def to_untag_user(self) -> "Iam":
        '''(experimental) Grants permission to remove the specified tags from the user.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_UntagUser.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toUntagUser", []))

    @jsii.member(jsii_name="toUpdateAccessKey")
    def to_update_access_key(self) -> "Iam":
        '''(experimental) Grants permission to update the status of the specified access key as Active or Inactive.

        Access Level: Write

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_UpdateAccessKey.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toUpdateAccessKey", []))

    @jsii.member(jsii_name="toUpdateAccountPasswordPolicy")
    def to_update_account_password_policy(self) -> "Iam":
        '''(experimental) Grants permission to update the password policy settings for the AWS account.

        Access Level: Write

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_UpdateAccountPasswordPolicy.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toUpdateAccountPasswordPolicy", []))

    @jsii.member(jsii_name="toUpdateAssumeRolePolicy")
    def to_update_assume_role_policy(self) -> "Iam":
        '''(experimental) Grants permission to update the policy that grants an IAM entity permission to assume a role.

        Access Level: Permissions management

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_UpdateAssumeRolePolicy.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toUpdateAssumeRolePolicy", []))

    @jsii.member(jsii_name="toUpdateGroup")
    def to_update_group(self) -> "Iam":
        '''(experimental) Grants permission to update the name or path of the specified IAM group.

        Access Level: Write

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_UpdateGroup.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toUpdateGroup", []))

    @jsii.member(jsii_name="toUpdateLoginProfile")
    def to_update_login_profile(self) -> "Iam":
        '''(experimental) Grants permission to change the password for the specified IAM user.

        Access Level: Write

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_UpdateLoginProfile.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toUpdateLoginProfile", []))

    @jsii.member(jsii_name="toUpdateOpenIDConnectProviderThumbprint")
    def to_update_open_id_connect_provider_thumbprint(self) -> "Iam":
        '''(experimental) Grants permission to update the entire list of server certificate thumbprints that are associated with an OpenID Connect (OIDC) provider resource.

        Access Level: Write

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_UpdateOpenIDConnectProviderThumbprint.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toUpdateOpenIDConnectProviderThumbprint", []))

    @jsii.member(jsii_name="toUpdateRole")
    def to_update_role(self) -> "Iam":
        '''(experimental) Grants permission to update the description or maximum session duration setting of a role.

        Access Level: Write

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_UpdateRole.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toUpdateRole", []))

    @jsii.member(jsii_name="toUpdateRoleDescription")
    def to_update_role_description(self) -> "Iam":
        '''(experimental) Grants permission to update only the description of a role.

        Access Level: Write

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_UpdateRoleDescription.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toUpdateRoleDescription", []))

    @jsii.member(jsii_name="toUpdateSAMLProvider")
    def to_update_saml_provider(self) -> "Iam":
        '''(experimental) Grants permission to update the metadata document for an existing SAML provider resource.

        Access Level: Write

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_UpdateSAMLProvider.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toUpdateSAMLProvider", []))

    @jsii.member(jsii_name="toUpdateServerCertificate")
    def to_update_server_certificate(self) -> "Iam":
        '''(experimental) Grants permission to update the name or the path of the specified server certificate stored in IAM.

        Access Level: Write

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_UpdateServerCertificate.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toUpdateServerCertificate", []))

    @jsii.member(jsii_name="toUpdateServiceSpecificCredential")
    def to_update_service_specific_credential(self) -> "Iam":
        '''(experimental) Grants permission to update the status of a service-specific credential to active or inactive for an IAM user.

        Access Level: Write

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_UpdateServiceSpecificCredential.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toUpdateServiceSpecificCredential", []))

    @jsii.member(jsii_name="toUpdateSigningCertificate")
    def to_update_signing_certificate(self) -> "Iam":
        '''(experimental) Grants permission to update the status of the specified user signing certificate to active or disabled.

        Access Level: Write

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_UpdateSigningCertificate.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toUpdateSigningCertificate", []))

    @jsii.member(jsii_name="toUpdateSSHPublicKey")
    def to_update_ssh_public_key(self) -> "Iam":
        '''(experimental) Grants permission to update the status of an IAM user's SSH public key to active or inactive.

        Access Level: Write

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_UpdateSSHPublicKey.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toUpdateSSHPublicKey", []))

    @jsii.member(jsii_name="toUpdateUser")
    def to_update_user(self) -> "Iam":
        '''(experimental) Grants permission to update the name or the path of the specified IAM user.

        Access Level: Write

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_UpdateUser.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toUpdateUser", []))

    @jsii.member(jsii_name="toUploadServerCertificate")
    def to_upload_server_certificate(self) -> "Iam":
        '''(experimental) Grants permission to upload a server certificate entity for the AWS account.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_UploadServerCertificate.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toUploadServerCertificate", []))

    @jsii.member(jsii_name="toUploadSigningCertificate")
    def to_upload_signing_certificate(self) -> "Iam":
        '''(experimental) Grants permission to upload an X.509 signing certificate and associate it with the specified IAM user.

        Access Level: Write

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_UploadSigningCertificate.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toUploadSigningCertificate", []))

    @jsii.member(jsii_name="toUploadSSHPublicKey")
    def to_upload_ssh_public_key(self) -> "Iam":
        '''(experimental) Grants permission to upload an SSH public key and associate it with the specified IAM user.

        Access Level: Write

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_UploadSSHPublicKey.html

        :stability: experimental
        '''
        return typing.cast("Iam", jsii.invoke(self, "toUploadSSHPublicKey", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c270c965af986565ecd35d4500f767ea910599fc83a2d171f1d78764c9f7dad7)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__29cc7835040fa92b08dc30e091e5b97f845228809637ad377cdf40da2414232c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class IdentitySync(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.IdentitySync",
):
    '''(experimental) Statement provider for service `identity-sync <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsidentitysync.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `identity-sync <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsidentitysync.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onSyncProfileResource")
    def on_sync_profile_resource(
        self,
        sync_profile_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "IdentitySync":
        '''(experimental) Adds a resource of type SyncProfileResource to the statement.

        https://docs.aws.amazon.com/singlesignon/latest/userguide/security-iam-awsmanpol.html

        :param sync_profile_name: - Identifier for the syncProfileName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__25f375fd47557b0fa07ec1293b88234f5a9ad9f55e422a954ff4150d0e62de2d)
            check_type(argname="argument sync_profile_name", value=sync_profile_name, expected_type=type_hints["sync_profile_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("IdentitySync", jsii.invoke(self, "onSyncProfileResource", [sync_profile_name, account, region, partition]))

    @jsii.member(jsii_name="onSyncTargetResource")
    def on_sync_target_resource(
        self,
        sync_profile_name: builtins.str,
        sync_target_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "IdentitySync":
        '''(experimental) Adds a resource of type SyncTargetResource to the statement.

        https://docs.aws.amazon.com/singlesignon/latest/userguide/security-iam-awsmanpol.html

        :param sync_profile_name: - Identifier for the syncProfileName.
        :param sync_target_name: - Identifier for the syncTargetName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__df8da733d03dae714bfbb4d0a6694231ad627c77fed324f45a098ff419887232)
            check_type(argname="argument sync_profile_name", value=sync_profile_name, expected_type=type_hints["sync_profile_name"])
            check_type(argname="argument sync_target_name", value=sync_target_name, expected_type=type_hints["sync_target_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("IdentitySync", jsii.invoke(self, "onSyncTargetResource", [sync_profile_name, sync_target_name, account, region, partition]))

    @jsii.member(jsii_name="toCreateSyncFilter")
    def to_create_sync_filter(self) -> "IdentitySync":
        '''(experimental) Grants permission to create a sync filter on the sync profile.

        Access Level: Write

        https://docs.aws.amazon.com/singlesignon/latest/userguide/security-iam-awsmanpol.html

        :stability: experimental
        '''
        return typing.cast("IdentitySync", jsii.invoke(self, "toCreateSyncFilter", []))

    @jsii.member(jsii_name="toCreateSyncProfile")
    def to_create_sync_profile(self) -> "IdentitySync":
        '''(experimental) Grants permission to create a sync profile for the identity source.

        Access Level: Write

        Dependent actions:

        - ds:AuthorizeApplication

        https://docs.aws.amazon.com/singlesignon/latest/userguide/security-iam-awsmanpol.html

        :stability: experimental
        '''
        return typing.cast("IdentitySync", jsii.invoke(self, "toCreateSyncProfile", []))

    @jsii.member(jsii_name="toCreateSyncTarget")
    def to_create_sync_target(self) -> "IdentitySync":
        '''(experimental) Grants permission to create a sync target for the identity source.

        Access Level: Write

        https://docs.aws.amazon.com/singlesignon/latest/userguide/security-iam-awsmanpol.html

        :stability: experimental
        '''
        return typing.cast("IdentitySync", jsii.invoke(self, "toCreateSyncTarget", []))

    @jsii.member(jsii_name="toDeleteSyncFilter")
    def to_delete_sync_filter(self) -> "IdentitySync":
        '''(experimental) Grants permission to delete a sync filter from the sync profile.

        Access Level: Write

        https://docs.aws.amazon.com/singlesignon/latest/userguide/security-iam-awsmanpol.html

        :stability: experimental
        '''
        return typing.cast("IdentitySync", jsii.invoke(self, "toDeleteSyncFilter", []))

    @jsii.member(jsii_name="toDeleteSyncProfile")
    def to_delete_sync_profile(self) -> "IdentitySync":
        '''(experimental) Grants permission to delete a sync profile from the source.

        Access Level: Write

        Dependent actions:

        - ds:UnauthorizeApplication

        https://docs.aws.amazon.com/singlesignon/latest/userguide/security-iam-awsmanpol.html

        :stability: experimental
        '''
        return typing.cast("IdentitySync", jsii.invoke(self, "toDeleteSyncProfile", []))

    @jsii.member(jsii_name="toDeleteSyncTarget")
    def to_delete_sync_target(self) -> "IdentitySync":
        '''(experimental) Grants permission to delete a sync target from the source.

        Access Level: Write

        https://docs.aws.amazon.com/singlesignon/latest/userguide/security-iam-awsmanpol.html

        :stability: experimental
        '''
        return typing.cast("IdentitySync", jsii.invoke(self, "toDeleteSyncTarget", []))

    @jsii.member(jsii_name="toGetSyncProfile")
    def to_get_sync_profile(self) -> "IdentitySync":
        '''(experimental) Grants permission to retrieve a sync profile by using a sync profile name.

        Access Level: Read

        https://docs.aws.amazon.com/singlesignon/latest/userguide/security-iam-awsmanpol.html

        :stability: experimental
        '''
        return typing.cast("IdentitySync", jsii.invoke(self, "toGetSyncProfile", []))

    @jsii.member(jsii_name="toGetSyncTarget")
    def to_get_sync_target(self) -> "IdentitySync":
        '''(experimental) Grants permission to retrieve a sync target from the sync profile.

        Access Level: Read

        https://docs.aws.amazon.com/singlesignon/latest/userguide/security-iam-awsmanpol.html

        :stability: experimental
        '''
        return typing.cast("IdentitySync", jsii.invoke(self, "toGetSyncTarget", []))

    @jsii.member(jsii_name="toListSyncFilters")
    def to_list_sync_filters(self) -> "IdentitySync":
        '''(experimental) Grants permission to list the sync filters from the sync profile.

        Access Level: List

        https://docs.aws.amazon.com/singlesignon/latest/userguide/security-iam-awsmanpol.html

        :stability: experimental
        '''
        return typing.cast("IdentitySync", jsii.invoke(self, "toListSyncFilters", []))

    @jsii.member(jsii_name="toStartSync")
    def to_start_sync(self) -> "IdentitySync":
        '''(experimental) Grants permission to start a sync process or to resume a sync process that was previously paused.

        Access Level: Write

        https://docs.aws.amazon.com/singlesignon/latest/userguide/security-iam-awsmanpol.html

        :stability: experimental
        '''
        return typing.cast("IdentitySync", jsii.invoke(self, "toStartSync", []))

    @jsii.member(jsii_name="toStopSync")
    def to_stop_sync(self) -> "IdentitySync":
        '''(experimental) Grants permission to stop any planned sync process in the sync schedule from starting.

        Access Level: Write

        https://docs.aws.amazon.com/singlesignon/latest/userguide/security-iam-awsmanpol.html

        :stability: experimental
        '''
        return typing.cast("IdentitySync", jsii.invoke(self, "toStopSync", []))

    @jsii.member(jsii_name="toUpdateSyncTarget")
    def to_update_sync_target(self) -> "IdentitySync":
        '''(experimental) Grants permission to update a sync target on the sync profile.

        Access Level: Write

        https://docs.aws.amazon.com/singlesignon/latest/userguide/security-iam-awsmanpol.html

        :stability: experimental
        '''
        return typing.cast("IdentitySync", jsii.invoke(self, "toUpdateSyncTarget", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2d23f22ef8fff5c9e0ca75ec85342f483f15b7e43187f66e75a2777f5c7b6aab)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__953d28cb15042c3eb3519acb2b6025e1ec30f763079b98a3319138b1a6a45990)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Identitystore(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Identitystore",
):
    '''(experimental) Statement provider for service `identitystore <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsidentitystore.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `identitystore <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsidentitystore.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onAllGroupMemberships")
    def on_all_group_memberships(
        self,
        resource_name: builtins.str,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Identitystore":
        '''(experimental) Adds a resource of type AllGroupMemberships to the statement.

        https://docs.aws.amazon.com/singlesignon/latest/

        :param resource_name: - Identifier for the resourceName.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6bbb46a3fcc95159a4ba2216eb37f0cd4863efeba7fc5b46ddc4f9cb0ae88d40)
            check_type(argname="argument resource_name", value=resource_name, expected_type=type_hints["resource_name"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Identitystore", jsii.invoke(self, "onAllGroupMemberships", [resource_name, partition]))

    @jsii.member(jsii_name="onAllGroups")
    def on_all_groups(
        self,
        resource_name: builtins.str,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Identitystore":
        '''(experimental) Adds a resource of type AllGroups to the statement.

        https://docs.aws.amazon.com/singlesignon/latest/

        :param resource_name: - Identifier for the resourceName.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__70335b8e53f2de7f5266a5fa3d7a52991648ca3423ea5cc3f05ab45d4df5fa23)
            check_type(argname="argument resource_name", value=resource_name, expected_type=type_hints["resource_name"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Identitystore", jsii.invoke(self, "onAllGroups", [resource_name, partition]))

    @jsii.member(jsii_name="onAllUsers")
    def on_all_users(
        self,
        resource_name: builtins.str,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Identitystore":
        '''(experimental) Adds a resource of type AllUsers to the statement.

        https://docs.aws.amazon.com/singlesignon/latest/

        :param resource_name: - Identifier for the resourceName.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7019cfd465a7f9f30c6b995b3eedff47e1657cc7c2b579bdc5602ab3cc54657c)
            check_type(argname="argument resource_name", value=resource_name, expected_type=type_hints["resource_name"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Identitystore", jsii.invoke(self, "onAllUsers", [resource_name, partition]))

    @jsii.member(jsii_name="onGroup")
    def on_group(
        self,
        group_id: builtins.str,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Identitystore":
        '''(experimental) Adds a resource of type Group to the statement.

        https://docs.aws.amazon.com/singlesignon/latest/

        :param group_id: - Identifier for the groupId.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5417b9654823a3b52c4663f8fa37058ce2d93040e16aa9b2e2d941b7e65a7334)
            check_type(argname="argument group_id", value=group_id, expected_type=type_hints["group_id"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Identitystore", jsii.invoke(self, "onGroup", [group_id, partition]))

    @jsii.member(jsii_name="onGroupMembership")
    def on_group_membership(
        self,
        membership_id: builtins.str,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Identitystore":
        '''(experimental) Adds a resource of type GroupMembership to the statement.

        https://docs.aws.amazon.com/singlesignon/latest/

        :param membership_id: - Identifier for the membershipId.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f3f7d17f6a07a2a3d4db5aa9759e5167414bf08ba680170d0d2d9fa2f01c99f1)
            check_type(argname="argument membership_id", value=membership_id, expected_type=type_hints["membership_id"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Identitystore", jsii.invoke(self, "onGroupMembership", [membership_id, partition]))

    @jsii.member(jsii_name="onIdentitystore")
    def on_identitystore(
        self,
        identity_store_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Identitystore":
        '''(experimental) Adds a resource of type Identitystore to the statement.

        https://docs.aws.amazon.com/singlesignon/latest/

        :param identity_store_id: - Identifier for the identityStoreId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c4f1073908ab6d91e0b2462519175a6cf32dbbda8acc71b63520014924a272b4)
            check_type(argname="argument identity_store_id", value=identity_store_id, expected_type=type_hints["identity_store_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Identitystore", jsii.invoke(self, "onIdentitystore", [identity_store_id, account, partition]))

    @jsii.member(jsii_name="onUser")
    def on_user(
        self,
        user_id: builtins.str,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Identitystore":
        '''(experimental) Adds a resource of type User to the statement.

        https://docs.aws.amazon.com/singlesignon/latest/

        :param user_id: - Identifier for the userId.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__15e5131a0408e4c821beb578e55688970dd6aadc8debaf2a2bd6c7dc526140ff)
            check_type(argname="argument user_id", value=user_id, expected_type=type_hints["user_id"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Identitystore", jsii.invoke(self, "onUser", [user_id, partition]))

    @jsii.member(jsii_name="toCreateGroup")
    def to_create_group(self) -> "Identitystore":
        '''(experimental) Grants permission to create a group in the specified IdentityStore.

        Access Level: Write

        https://docs.aws.amazon.com/singlesignon/latest/IdentityStoreAPIReference/API_CreateGroup.html

        :stability: experimental
        '''
        return typing.cast("Identitystore", jsii.invoke(self, "toCreateGroup", []))

    @jsii.member(jsii_name="toCreateGroupMembership")
    def to_create_group_membership(self) -> "Identitystore":
        '''(experimental) Grants permission to create a member to a group in the specified IdentityStore.

        Access Level: Write

        https://docs.aws.amazon.com/singlesignon/latest/IdentityStoreAPIReference/API_CreateGroupMembership.html

        :stability: experimental
        '''
        return typing.cast("Identitystore", jsii.invoke(self, "toCreateGroupMembership", []))

    @jsii.member(jsii_name="toCreateUser")
    def to_create_user(self) -> "Identitystore":
        '''(experimental) Grants permission to create a user in the specified IdentityStore.

        Access Level: Write

        https://docs.aws.amazon.com/singlesignon/latest/IdentityStoreAPIReference/API_CreateUser.html

        :stability: experimental
        '''
        return typing.cast("Identitystore", jsii.invoke(self, "toCreateUser", []))

    @jsii.member(jsii_name="toDeleteGroup")
    def to_delete_group(self) -> "Identitystore":
        '''(experimental) Grants permission to delete a group in the specified IdentityStore.

        Access Level: Write

        https://docs.aws.amazon.com/singlesignon/latest/IdentityStoreAPIReference/API_DeleteGroup.html

        :stability: experimental
        '''
        return typing.cast("Identitystore", jsii.invoke(self, "toDeleteGroup", []))

    @jsii.member(jsii_name="toDeleteGroupMembership")
    def to_delete_group_membership(self) -> "Identitystore":
        '''(experimental) Grants permission to remove a member that is part of a group in the specified IdentityStore.

        Access Level: Write

        https://docs.aws.amazon.com/singlesignon/latest/IdentityStoreAPIReference/API_DeleteGroupMembership.html

        :stability: experimental
        '''
        return typing.cast("Identitystore", jsii.invoke(self, "toDeleteGroupMembership", []))

    @jsii.member(jsii_name="toDeleteUser")
    def to_delete_user(self) -> "Identitystore":
        '''(experimental) Grants permission to delete a user in the specified IdentityStore.

        Access Level: Write

        https://docs.aws.amazon.com/singlesignon/latest/IdentityStoreAPIReference/API_DeleteUser.html

        :stability: experimental
        '''
        return typing.cast("Identitystore", jsii.invoke(self, "toDeleteUser", []))

    @jsii.member(jsii_name="toDescribeGroup")
    def to_describe_group(self) -> "Identitystore":
        '''(experimental) Grants permission to retrieve information about a group in the specified IdentityStore.

        Access Level: Read

        https://docs.aws.amazon.com/singlesignon/latest/IdentityStoreAPIReference/API_DescribeGroup.html

        :stability: experimental
        '''
        return typing.cast("Identitystore", jsii.invoke(self, "toDescribeGroup", []))

    @jsii.member(jsii_name="toDescribeGroupMembership")
    def to_describe_group_membership(self) -> "Identitystore":
        '''(experimental) Grants permission to retrieve information about a member that is part of a group in the specified IdentityStore.

        Access Level: Read

        https://docs.aws.amazon.com/singlesignon/latest/IdentityStoreAPIReference/API_DescribeGroupMembership.html

        :stability: experimental
        '''
        return typing.cast("Identitystore", jsii.invoke(self, "toDescribeGroupMembership", []))

    @jsii.member(jsii_name="toDescribeUser")
    def to_describe_user(self) -> "Identitystore":
        '''(experimental) Grants permission to retrieve information about user in the specified IdentityStore.

        Access Level: Read

        https://docs.aws.amazon.com/singlesignon/latest/IdentityStoreAPIReference/API_DescribeUser.html

        :stability: experimental
        '''
        return typing.cast("Identitystore", jsii.invoke(self, "toDescribeUser", []))

    @jsii.member(jsii_name="toGetGroupId")
    def to_get_group_id(self) -> "Identitystore":
        '''(experimental) Grants permission to retrieve ID information about group in the specified IdentityStore.

        Access Level: Read

        https://docs.aws.amazon.com/singlesignon/latest/IdentityStoreAPIReference/API_GetGroupId.html

        :stability: experimental
        '''
        return typing.cast("Identitystore", jsii.invoke(self, "toGetGroupId", []))

    @jsii.member(jsii_name="toGetGroupMembershipId")
    def to_get_group_membership_id(self) -> "Identitystore":
        '''(experimental) Grants permission to retrieve ID information of a member which is part of a group in the specified IdentityStore.

        Access Level: Read

        https://docs.aws.amazon.com/singlesignon/latest/IdentityStoreAPIReference/API_GetGroupMembershipId.html

        :stability: experimental
        '''
        return typing.cast("Identitystore", jsii.invoke(self, "toGetGroupMembershipId", []))

    @jsii.member(jsii_name="toGetUserId")
    def to_get_user_id(self) -> "Identitystore":
        '''(experimental) Grants permission to retrieves ID information about user in the specified IdentityStore.

        Access Level: Read

        https://docs.aws.amazon.com/singlesignon/latest/IdentityStoreAPIReference/API_GetUserId.html

        :stability: experimental
        '''
        return typing.cast("Identitystore", jsii.invoke(self, "toGetUserId", []))

    @jsii.member(jsii_name="toIsMemberInGroups")
    def to_is_member_in_groups(self) -> "Identitystore":
        '''(experimental) Grants permission to check if a member is a part of groups in the specified IdentityStore.

        Access Level: Read

        https://docs.aws.amazon.com/singlesignon/latest/IdentityStoreAPIReference/API_IsMemberInGroups.html

        :stability: experimental
        '''
        return typing.cast("Identitystore", jsii.invoke(self, "toIsMemberInGroups", []))

    @jsii.member(jsii_name="toListGroupMemberships")
    def to_list_group_memberships(self) -> "Identitystore":
        '''(experimental) Grants permission to retrieve all members that are part of a group in the specified IdentityStore.

        Access Level: List

        https://docs.aws.amazon.com/singlesignon/latest/IdentityStoreAPIReference/API_ListGroupMemberships.html

        :stability: experimental
        '''
        return typing.cast("Identitystore", jsii.invoke(self, "toListGroupMemberships", []))

    @jsii.member(jsii_name="toListGroupMembershipsForMember")
    def to_list_group_memberships_for_member(self) -> "Identitystore":
        '''(experimental) Grants permission to list groups of the target member in the specified IdentityStore.

        Access Level: List

        https://docs.aws.amazon.com/singlesignon/latest/IdentityStoreAPIReference/API_ListGroupMembershipsForMember.html

        :stability: experimental
        '''
        return typing.cast("Identitystore", jsii.invoke(self, "toListGroupMembershipsForMember", []))

    @jsii.member(jsii_name="toListGroups")
    def to_list_groups(self) -> "Identitystore":
        '''(experimental) Grants permission to search for groups within the specified IdentityStore.

        Access Level: List

        https://docs.aws.amazon.com/singlesignon/latest/IdentityStoreAPIReference/API_ListGroups.html

        :stability: experimental
        '''
        return typing.cast("Identitystore", jsii.invoke(self, "toListGroups", []))

    @jsii.member(jsii_name="toListUsers")
    def to_list_users(self) -> "Identitystore":
        '''(experimental) Grants permission to search for users in the specified IdentityStore.

        Access Level: List

        https://docs.aws.amazon.com/singlesignon/latest/IdentityStoreAPIReference/API_ListUsers.html

        :stability: experimental
        '''
        return typing.cast("Identitystore", jsii.invoke(self, "toListUsers", []))

    @jsii.member(jsii_name="toUpdateGroup")
    def to_update_group(self) -> "Identitystore":
        '''(experimental) Grants permission to update information about a group in the specified IdentityStore.

        Access Level: Write

        https://docs.aws.amazon.com/singlesignon/latest/IdentityStoreAPIReference/API_UpdateGroup.html

        :stability: experimental
        '''
        return typing.cast("Identitystore", jsii.invoke(self, "toUpdateGroup", []))

    @jsii.member(jsii_name="toUpdateUser")
    def to_update_user(self) -> "Identitystore":
        '''(experimental) Grants permission to update user information in the specified IdentityStore.

        Access Level: Write

        https://docs.aws.amazon.com/singlesignon/latest/IdentityStoreAPIReference/API_UpdateUser.html

        :stability: experimental
        '''
        return typing.cast("Identitystore", jsii.invoke(self, "toUpdateUser", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8e7f8db8b9ee8f0c6060cfaee47820b2b8d94f32715583cd13f8e771a8a5b967)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ce1f63b4785f2db14686d8990bf549b94411b1c6c7f3b89a24ce7f049b2643a3)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class IdentitystoreAuth(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.IdentitystoreAuth",
):
    '''(experimental) Statement provider for service `identitystore-auth <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsidentitystoreauth.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `identitystore-auth <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsidentitystoreauth.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="toBatchDeleteSession")
    def to_batch_delete_session(self) -> "IdentitystoreAuth":
        '''(experimental) Grants permission to delete a batch of specified sessions.

        Access Level: Write

        https://docs.aws.amazon.com/singlesignon/latest/userguide/manage-app-session.html

        :stability: experimental
        '''
        return typing.cast("IdentitystoreAuth", jsii.invoke(self, "toBatchDeleteSession", []))

    @jsii.member(jsii_name="toBatchGetSession")
    def to_batch_get_session(self) -> "IdentitystoreAuth":
        '''(experimental) Grants permission to return session attributes for a batch of specified sessions.

        Access Level: Read

        https://docs.aws.amazon.com/singlesignon/latest/userguide/manage-app-session.html

        :stability: experimental
        '''
        return typing.cast("IdentitystoreAuth", jsii.invoke(self, "toBatchGetSession", []))

    @jsii.member(jsii_name="toListSessions")
    def to_list_sessions(self) -> "IdentitystoreAuth":
        '''(experimental) Grants permission to retrieve a list of active sessions for the specified user.

        Access Level: List

        https://docs.aws.amazon.com/singlesignon/latest/userguide/manage-app-session.html

        :stability: experimental
        '''
        return typing.cast("IdentitystoreAuth", jsii.invoke(self, "toListSessions", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c22ba346b5ce9e41789e4a045267db59a8345d3b44f35e63be1f13dd50792878)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5d1654ab1bbad6de8e6fc66142ba70a803a4e931594eb707e2a006e24657910b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Imagebuilder(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Imagebuilder",
):
    '''(experimental) Statement provider for service `imagebuilder <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonec2imagebuilder.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `imagebuilder <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonec2imagebuilder.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="ifCreatedResourceTag")
    def if_created_resource_tag(
        self,
        key: builtins.str,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Imagebuilder":
        '''(experimental) Filters access by the tag key-value pairs attached to the resource created by Image Builder.

        https://docs.aws.amazon.com/imagebuilder/latest/userguide/security_iam_service-with-iam.html#image-builder-security-createdresourcetag

        Applies to actions:

        - .toCreateInfrastructureConfiguration()
        - .toUpdateInfrastructureConfiguration()

        :param key: The tag key to check.
        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d4b99ec0f7a38e90dc79de0b078d62a35906e3f7ad7716fc8ac0a9f99f2823d0)
            check_type(argname="argument key", value=key, expected_type=type_hints["key"])
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Imagebuilder", jsii.invoke(self, "ifCreatedResourceTag", [key, value, operator]))

    @jsii.member(jsii_name="ifCreatedResourceTagKeys")
    def if_created_resource_tag_keys(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Imagebuilder":
        '''(experimental) Filters access by the presence of tag keys in the request.

        https://docs.aws.amazon.com/imagebuilder/latest/userguide/security_iam_service-with-iam.html#image-builder-security-createdresourcetagkeys

        Applies to actions:

        - .toCreateInfrastructureConfiguration()
        - .toUpdateInfrastructureConfiguration()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__70fdea28e97fffbde9d0f9659ea44ed6135edadb80d825f1ea34f34852690ab8)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Imagebuilder", jsii.invoke(self, "ifCreatedResourceTagKeys", [value, operator]))

    @jsii.member(jsii_name="ifEc2MetadataHttpTokens")
    def if_ec2_metadata_http_tokens(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Imagebuilder":
        '''(experimental) Filters access by the EC2 Instance Metadata HTTP Token Requirement specified in the request.

        https://docs.aws.amazon.com/imagebuilder/latest/userguide/security_iam_service-with-iam.html#image-builder-security-ec2metadatahttptokens

        Applies to actions:

        - .toCreateInfrastructureConfiguration()
        - .toUpdateInfrastructureConfiguration()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3656da77f76423b6dc7b057fcdd1aaa240b419b200ad90e383c04350a31a7672)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Imagebuilder", jsii.invoke(self, "ifEc2MetadataHttpTokens", [value, operator]))

    @jsii.member(jsii_name="ifStatusTopicArn")
    def if_status_topic_arn(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Imagebuilder":
        '''(experimental) Filters access by the SNS Topic Arn in the request to which terminal state notifications will be published.

        https://docs.aws.amazon.com/imagebuilder/latest/userguide/security_iam_service-with-iam.html#image-builder-security-statustopicarn

        Applies to actions:

        - .toCreateInfrastructureConfiguration()
        - .toUpdateInfrastructureConfiguration()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__035a6bbb49aee966e25aebc06096509aaa549bef6c708485ef3f006cc9e94408)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Imagebuilder", jsii.invoke(self, "ifStatusTopicArn", [value, operator]))

    @jsii.member(jsii_name="onComponent")
    def on_component(
        self,
        component_name: builtins.str,
        component_version: builtins.str,
        component_build_version: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Imagebuilder":
        '''(experimental) Adds a resource of type component to the statement.

        https://docs.aws.amazon.com/imagebuilder/latest/APIReference/API_Component.html

        :param component_name: - Identifier for the componentName.
        :param component_version: - Identifier for the componentVersion.
        :param component_build_version: - Identifier for the componentBuildVersion.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ad04b7944d04f00090732ce5958c5458392c7b43ef0061fb411c3f0b9d7e65e9)
            check_type(argname="argument component_name", value=component_name, expected_type=type_hints["component_name"])
            check_type(argname="argument component_version", value=component_version, expected_type=type_hints["component_version"])
            check_type(argname="argument component_build_version", value=component_build_version, expected_type=type_hints["component_build_version"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Imagebuilder", jsii.invoke(self, "onComponent", [component_name, component_version, component_build_version, account, region, partition]))

    @jsii.member(jsii_name="onComponentVersion")
    def on_component_version(
        self,
        component_name: builtins.str,
        component_version: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Imagebuilder":
        '''(experimental) Adds a resource of type componentVersion to the statement.

        https://docs.aws.amazon.com/imagebuilder/latest/APIReference/API_ComponentVersion

        :param component_name: - Identifier for the componentName.
        :param component_version: - Identifier for the componentVersion.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5b1fb701911dbde185c9fa58400bb5a0c8a99281a023990c01a2b9c6705cce8e)
            check_type(argname="argument component_name", value=component_name, expected_type=type_hints["component_name"])
            check_type(argname="argument component_version", value=component_version, expected_type=type_hints["component_version"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Imagebuilder", jsii.invoke(self, "onComponentVersion", [component_name, component_version, account, region, partition]))

    @jsii.member(jsii_name="onContainerRecipe")
    def on_container_recipe(
        self,
        container_recipe_name: builtins.str,
        container_recipe_version: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Imagebuilder":
        '''(experimental) Adds a resource of type containerRecipe to the statement.

        https://docs.aws.amazon.com/imagebuilder/latest/APIReference/API_ContainerRecipe.html

        :param container_recipe_name: - Identifier for the containerRecipeName.
        :param container_recipe_version: - Identifier for the containerRecipeVersion.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__669ad431acdf803e07c5d3b93a1bfdab4b32a5fe0ffc19dc9a7eb105c1349502)
            check_type(argname="argument container_recipe_name", value=container_recipe_name, expected_type=type_hints["container_recipe_name"])
            check_type(argname="argument container_recipe_version", value=container_recipe_version, expected_type=type_hints["container_recipe_version"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Imagebuilder", jsii.invoke(self, "onContainerRecipe", [container_recipe_name, container_recipe_version, account, region, partition]))

    @jsii.member(jsii_name="onDistributionConfiguration")
    def on_distribution_configuration(
        self,
        distribution_configuration_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Imagebuilder":
        '''(experimental) Adds a resource of type distributionConfiguration to the statement.

        https://docs.aws.amazon.com/imagebuilder/latest/APIReference/API_DistributionConfiguration.html

        :param distribution_configuration_name: - Identifier for the distributionConfigurationName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2df50790657388520b29a11089692a3c2a2b77a221f5231949a8eeae5cb4c68d)
            check_type(argname="argument distribution_configuration_name", value=distribution_configuration_name, expected_type=type_hints["distribution_configuration_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Imagebuilder", jsii.invoke(self, "onDistributionConfiguration", [distribution_configuration_name, account, region, partition]))

    @jsii.member(jsii_name="onImage")
    def on_image(
        self,
        image_name: builtins.str,
        image_version: builtins.str,
        image_build_version: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Imagebuilder":
        '''(experimental) Adds a resource of type image to the statement.

        https://docs.aws.amazon.com/imagebuilder/latest/APIReference/API_Image.html

        :param image_name: - Identifier for the imageName.
        :param image_version: - Identifier for the imageVersion.
        :param image_build_version: - Identifier for the imageBuildVersion.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__38381d3fbd5ddbb532d5548a5e887803d9fcf1ae7df5c58f37f429109871f0a0)
            check_type(argname="argument image_name", value=image_name, expected_type=type_hints["image_name"])
            check_type(argname="argument image_version", value=image_version, expected_type=type_hints["image_version"])
            check_type(argname="argument image_build_version", value=image_build_version, expected_type=type_hints["image_build_version"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Imagebuilder", jsii.invoke(self, "onImage", [image_name, image_version, image_build_version, account, region, partition]))

    @jsii.member(jsii_name="onImagePipeline")
    def on_image_pipeline(
        self,
        image_pipeline_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Imagebuilder":
        '''(experimental) Adds a resource of type imagePipeline to the statement.

        https://docs.aws.amazon.com/imagebuilder/latest/APIReference/API_ImagePipeline.html

        :param image_pipeline_name: - Identifier for the imagePipelineName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0794fbee8dd0815650fdc9367f4db890d9b5674572c20a1e3f41e1b707f0ec05)
            check_type(argname="argument image_pipeline_name", value=image_pipeline_name, expected_type=type_hints["image_pipeline_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Imagebuilder", jsii.invoke(self, "onImagePipeline", [image_pipeline_name, account, region, partition]))

    @jsii.member(jsii_name="onImageRecipe")
    def on_image_recipe(
        self,
        image_recipe_name: builtins.str,
        image_recipe_version: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Imagebuilder":
        '''(experimental) Adds a resource of type imageRecipe to the statement.

        https://docs.aws.amazon.com/imagebuilder/latest/APIReference/API_ImageRecipe.html

        :param image_recipe_name: - Identifier for the imageRecipeName.
        :param image_recipe_version: - Identifier for the imageRecipeVersion.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a42d74c9638776833370907637c2381c7c83cb38404c66052d2a89661ba5d76b)
            check_type(argname="argument image_recipe_name", value=image_recipe_name, expected_type=type_hints["image_recipe_name"])
            check_type(argname="argument image_recipe_version", value=image_recipe_version, expected_type=type_hints["image_recipe_version"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Imagebuilder", jsii.invoke(self, "onImageRecipe", [image_recipe_name, image_recipe_version, account, region, partition]))

    @jsii.member(jsii_name="onImageVersion")
    def on_image_version(
        self,
        image_name: builtins.str,
        image_version: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Imagebuilder":
        '''(experimental) Adds a resource of type imageVersion to the statement.

        https://docs.aws.amazon.com/imagebuilder/latest/APIReference/API_ImageVersion.html

        :param image_name: - Identifier for the imageName.
        :param image_version: - Identifier for the imageVersion.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c716688ce5746348a93d00db1ab0e2045938afa7ec61fac9807b1880ba72d97b)
            check_type(argname="argument image_name", value=image_name, expected_type=type_hints["image_name"])
            check_type(argname="argument image_version", value=image_version, expected_type=type_hints["image_version"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Imagebuilder", jsii.invoke(self, "onImageVersion", [image_name, image_version, account, region, partition]))

    @jsii.member(jsii_name="onInfrastructureConfiguration")
    def on_infrastructure_configuration(
        self,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Imagebuilder":
        '''(experimental) Adds a resource of type infrastructureConfiguration to the statement.

        https://docs.aws.amazon.com/imagebuilder/latest/APIReference/API_InfrastructureConfiguration.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__222fc29bdfff9a4864b79bcb68b3b51fd18997ca433c9f56235742cd837c3e74)
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Imagebuilder", jsii.invoke(self, "onInfrastructureConfiguration", [resource_id, account, region, partition]))

    @jsii.member(jsii_name="onKmsKey")
    def on_kms_key(
        self,
        key_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Imagebuilder":
        '''(experimental) Adds a resource of type kmsKey to the statement.

        https://docs.aws.amazon.com/kms/latest/developerguide/concepts.html#master_keys

        :param key_id: - Identifier for the keyId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__20b3eb10d7858eb003f981aa373e49f58c2d79d63f66da48ba1360a9c8a86491)
            check_type(argname="argument key_id", value=key_id, expected_type=type_hints["key_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Imagebuilder", jsii.invoke(self, "onKmsKey", [key_id, account, region, partition]))

    @jsii.member(jsii_name="toCancelImageCreation")
    def to_cancel_image_creation(self) -> "Imagebuilder":
        '''(experimental) Grants permission to cancel an image creation.

        Access Level: Write

        https://docs.aws.amazon.com/imagebuilder/latest/APIReference/API_CancelImageCreation.html

        :stability: experimental
        '''
        return typing.cast("Imagebuilder", jsii.invoke(self, "toCancelImageCreation", []))

    @jsii.member(jsii_name="toCreateComponent")
    def to_create_component(self) -> "Imagebuilder":
        '''(experimental) Grants permission to create a new component.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - iam:CreateServiceLinkedRole
        - imagebuilder:TagResource
        - kms:Encrypt
        - kms:GenerateDataKey
        - kms:GenerateDataKeyWithoutPlaintext

        https://docs.aws.amazon.com/imagebuilder/latest/APIReference/API_CreateComponent.html

        :stability: experimental
        '''
        return typing.cast("Imagebuilder", jsii.invoke(self, "toCreateComponent", []))

    @jsii.member(jsii_name="toCreateContainerRecipe")
    def to_create_container_recipe(self) -> "Imagebuilder":
        '''(experimental) Grants permission to create a new Container Recipe.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - ecr:DescribeImages
        - ecr:DescribeRepositories
        - iam:CreateServiceLinkedRole
        - imagebuilder:GetComponent
        - imagebuilder:GetImage
        - imagebuilder:TagResource
        - kms:Encrypt
        - kms:GenerateDataKey
        - kms:GenerateDataKeyWithoutPlaintext

        https://docs.aws.amazon.com/imagebuilder/latest/APIReference/API_CreateContainerRecipe.html

        :stability: experimental
        '''
        return typing.cast("Imagebuilder", jsii.invoke(self, "toCreateContainerRecipe", []))

    @jsii.member(jsii_name="toCreateDistributionConfiguration")
    def to_create_distribution_configuration(self) -> "Imagebuilder":
        '''(experimental) Grants permission to create a new distribution configuration.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - iam:CreateServiceLinkedRole
        - imagebuilder:TagResource

        https://docs.aws.amazon.com/imagebuilder/latest/APIReference/API_CreateDistributionConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Imagebuilder", jsii.invoke(self, "toCreateDistributionConfiguration", []))

    @jsii.member(jsii_name="toCreateImage")
    def to_create_image(self) -> "Imagebuilder":
        '''(experimental) Grants permission to create a new image.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - iam:CreateServiceLinkedRole
        - imagebuilder:GetContainerRecipe
        - imagebuilder:GetDistributionConfiguration
        - imagebuilder:GetImageRecipe
        - imagebuilder:GetInfrastructureConfiguration
        - imagebuilder:TagResource

        https://docs.aws.amazon.com/imagebuilder/latest/APIReference/API_CreateImage.html

        :stability: experimental
        '''
        return typing.cast("Imagebuilder", jsii.invoke(self, "toCreateImage", []))

    @jsii.member(jsii_name="toCreateImagePipeline")
    def to_create_image_pipeline(self) -> "Imagebuilder":
        '''(experimental) Grants permission to create a new image pipeline.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - iam:CreateServiceLinkedRole
        - imagebuilder:GetContainerRecipe
        - imagebuilder:GetImageRecipe
        - imagebuilder:TagResource

        https://docs.aws.amazon.com/imagebuilder/latest/APIReference/API_CreateImagePipeline.html

        :stability: experimental
        '''
        return typing.cast("Imagebuilder", jsii.invoke(self, "toCreateImagePipeline", []))

    @jsii.member(jsii_name="toCreateImageRecipe")
    def to_create_image_recipe(self) -> "Imagebuilder":
        '''(experimental) Grants permission to create a new Image Recipe.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - ec2:DescribeImages
        - iam:CreateServiceLinkedRole
        - imagebuilder:GetComponent
        - imagebuilder:GetImage
        - imagebuilder:TagResource

        https://docs.aws.amazon.com/imagebuilder/latest/APIReference/API_CreateImageRecipe.html

        :stability: experimental
        '''
        return typing.cast("Imagebuilder", jsii.invoke(self, "toCreateImageRecipe", []))

    @jsii.member(jsii_name="toCreateInfrastructureConfiguration")
    def to_create_infrastructure_configuration(self) -> "Imagebuilder":
        '''(experimental) Grants permission to create a new infrastructure configuration.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifCreatedResourceTagKeys()
        - .ifCreatedResourceTag()
        - .ifEc2MetadataHttpTokens()
        - .ifStatusTopicArn()

        Dependent actions:

        - iam:CreateServiceLinkedRole
        - iam:PassRole
        - imagebuilder:TagResource
        - sns:Publish

        https://docs.aws.amazon.com/imagebuilder/latest/APIReference/API_CreateInfrastructureConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Imagebuilder", jsii.invoke(self, "toCreateInfrastructureConfiguration", []))

    @jsii.member(jsii_name="toDeleteComponent")
    def to_delete_component(self) -> "Imagebuilder":
        '''(experimental) Grants permission to delete a component.

        Access Level: Write

        https://docs.aws.amazon.com/imagebuilder/latest/APIReference/API_DeleteComponent.html

        :stability: experimental
        '''
        return typing.cast("Imagebuilder", jsii.invoke(self, "toDeleteComponent", []))

    @jsii.member(jsii_name="toDeleteContainerRecipe")
    def to_delete_container_recipe(self) -> "Imagebuilder":
        '''(experimental) Grants permission to delete a container recipe.

        Access Level: Write

        https://docs.aws.amazon.com/imagebuilder/latest/APIReference/API_DeleteContainerRecipe.html

        :stability: experimental
        '''
        return typing.cast("Imagebuilder", jsii.invoke(self, "toDeleteContainerRecipe", []))

    @jsii.member(jsii_name="toDeleteDistributionConfiguration")
    def to_delete_distribution_configuration(self) -> "Imagebuilder":
        '''(experimental) Grants permission to delete a distribution configuration.

        Access Level: Write

        https://docs.aws.amazon.com/imagebuilder/latest/APIReference/API_DeleteDistributionConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Imagebuilder", jsii.invoke(self, "toDeleteDistributionConfiguration", []))

    @jsii.member(jsii_name="toDeleteImage")
    def to_delete_image(self) -> "Imagebuilder":
        '''(experimental) Grants permission to delete an image.

        Access Level: Write

        https://docs.aws.amazon.com/imagebuilder/latest/APIReference/API_DeleteImage.html

        :stability: experimental
        '''
        return typing.cast("Imagebuilder", jsii.invoke(self, "toDeleteImage", []))

    @jsii.member(jsii_name="toDeleteImagePipeline")
    def to_delete_image_pipeline(self) -> "Imagebuilder":
        '''(experimental) Grants permission to delete an image pipeline.

        Access Level: Write

        https://docs.aws.amazon.com/imagebuilder/latest/APIReference/API_DeleteImagePipeline.html

        :stability: experimental
        '''
        return typing.cast("Imagebuilder", jsii.invoke(self, "toDeleteImagePipeline", []))

    @jsii.member(jsii_name="toDeleteImageRecipe")
    def to_delete_image_recipe(self) -> "Imagebuilder":
        '''(experimental) Grants permission to delete an image recipe.

        Access Level: Write

        https://docs.aws.amazon.com/imagebuilder/latest/APIReference/API_DeleteImageRecipe.html

        :stability: experimental
        '''
        return typing.cast("Imagebuilder", jsii.invoke(self, "toDeleteImageRecipe", []))

    @jsii.member(jsii_name="toDeleteInfrastructureConfiguration")
    def to_delete_infrastructure_configuration(self) -> "Imagebuilder":
        '''(experimental) Grants permission to delete an infrastructure configuration.

        Access Level: Write

        https://docs.aws.amazon.com/imagebuilder/latest/APIReference/API_DeleteInfrastructureConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Imagebuilder", jsii.invoke(self, "toDeleteInfrastructureConfiguration", []))

    @jsii.member(jsii_name="toGetComponent")
    def to_get_component(self) -> "Imagebuilder":
        '''(experimental) Grants permission to view details about a component.

        Access Level: Read

        Dependent actions:

        - kms:Decrypt

        https://docs.aws.amazon.com/imagebuilder/latest/APIReference/API_GetComponent.html

        :stability: experimental
        '''
        return typing.cast("Imagebuilder", jsii.invoke(self, "toGetComponent", []))

    @jsii.member(jsii_name="toGetComponentPolicy")
    def to_get_component_policy(self) -> "Imagebuilder":
        '''(experimental) Grants permission to view the resource policy associated with a component.

        Access Level: Read

        https://docs.aws.amazon.com/imagebuilder/latest/APIReference/API_GetComponentPolicy.html

        :stability: experimental
        '''
        return typing.cast("Imagebuilder", jsii.invoke(self, "toGetComponentPolicy", []))

    @jsii.member(jsii_name="toGetContainerRecipe")
    def to_get_container_recipe(self) -> "Imagebuilder":
        '''(experimental) Grants permission to view details about a container recipe.

        Access Level: Read

        https://docs.aws.amazon.com/imagebuilder/latest/APIReference/API_GetContainerRecipe.html

        :stability: experimental
        '''
        return typing.cast("Imagebuilder", jsii.invoke(self, "toGetContainerRecipe", []))

    @jsii.member(jsii_name="toGetContainerRecipePolicy")
    def to_get_container_recipe_policy(self) -> "Imagebuilder":
        '''(experimental) Grants permission to view the resource policy associated with a container recipe.

        Access Level: Read

        https://docs.aws.amazon.com/imagebuilder/latest/APIReference/API_GetContainerRecipePolicy.html

        :stability: experimental
        '''
        return typing.cast("Imagebuilder", jsii.invoke(self, "toGetContainerRecipePolicy", []))

    @jsii.member(jsii_name="toGetDistributionConfiguration")
    def to_get_distribution_configuration(self) -> "Imagebuilder":
        '''(experimental) Grants permission to view details about a distribution configuration.

        Access Level: Read

        https://docs.aws.amazon.com/imagebuilder/latest/APIReference/API_GetDistributionConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Imagebuilder", jsii.invoke(self, "toGetDistributionConfiguration", []))

    @jsii.member(jsii_name="toGetImage")
    def to_get_image(self) -> "Imagebuilder":
        '''(experimental) Grants permission to view details about an image.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/imagebuilder/latest/APIReference/API_GetImage.html

        :stability: experimental
        '''
        return typing.cast("Imagebuilder", jsii.invoke(self, "toGetImage", []))

    @jsii.member(jsii_name="toGetImagePipeline")
    def to_get_image_pipeline(self) -> "Imagebuilder":
        '''(experimental) Grants permission to view details about an image pipeline.

        Access Level: Read

        https://docs.aws.amazon.com/imagebuilder/latest/APIReference/API_GetImagePipeline.html

        :stability: experimental
        '''
        return typing.cast("Imagebuilder", jsii.invoke(self, "toGetImagePipeline", []))

    @jsii.member(jsii_name="toGetImagePolicy")
    def to_get_image_policy(self) -> "Imagebuilder":
        '''(experimental) Grants permission to view the resource policy associated with an image.

        Access Level: Read

        https://docs.aws.amazon.com/imagebuilder/latest/APIReference/API_GetImagePolicy.html

        :stability: experimental
        '''
        return typing.cast("Imagebuilder", jsii.invoke(self, "toGetImagePolicy", []))

    @jsii.member(jsii_name="toGetImageRecipe")
    def to_get_image_recipe(self) -> "Imagebuilder":
        '''(experimental) Grants permission to view details about an image recipe.

        Access Level: Read

        https://docs.aws.amazon.com/imagebuilder/latest/APIReference/API_GetImageRecipe.html

        :stability: experimental
        '''
        return typing.cast("Imagebuilder", jsii.invoke(self, "toGetImageRecipe", []))

    @jsii.member(jsii_name="toGetImageRecipePolicy")
    def to_get_image_recipe_policy(self) -> "Imagebuilder":
        '''(experimental) Grants permission to view the resource policy associated with an image recipe.

        Access Level: Read

        https://docs.aws.amazon.com/imagebuilder/latest/APIReference/API_GetImageRecipePolicy.html

        :stability: experimental
        '''
        return typing.cast("Imagebuilder", jsii.invoke(self, "toGetImageRecipePolicy", []))

    @jsii.member(jsii_name="toGetInfrastructureConfiguration")
    def to_get_infrastructure_configuration(self) -> "Imagebuilder":
        '''(experimental) Grants permission to view details about an infrastructure configuration.

        Access Level: Read

        https://docs.aws.amazon.com/imagebuilder/latest/APIReference/API_GetInfrastructureConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Imagebuilder", jsii.invoke(self, "toGetInfrastructureConfiguration", []))

    @jsii.member(jsii_name="toImportComponent")
    def to_import_component(self) -> "Imagebuilder":
        '''(experimental) Grants permission to import a new component.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - iam:CreateServiceLinkedRole
        - imagebuilder:TagResource
        - kms:Encrypt
        - kms:GenerateDataKey
        - kms:GenerateDataKeyWithoutPlaintext

        https://docs.aws.amazon.com/imagebuilder/latest/APIReference/API_ImportComponent.html

        :stability: experimental
        '''
        return typing.cast("Imagebuilder", jsii.invoke(self, "toImportComponent", []))

    @jsii.member(jsii_name="toImportVmImage")
    def to_import_vm_image(self) -> "Imagebuilder":
        '''(experimental) Grants permission to import an image.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - ec2:DescribeImportImageTasks
        - iam:CreateServiceLinkedRole

        https://docs.aws.amazon.com/imagebuilder/latest/APIReference/API_ImportVmImage.html

        :stability: experimental
        '''
        return typing.cast("Imagebuilder", jsii.invoke(self, "toImportVmImage", []))

    @jsii.member(jsii_name="toListComponentBuildVersions")
    def to_list_component_build_versions(self) -> "Imagebuilder":
        '''(experimental) Grants permission to list the component build versions in your account.

        Access Level: List

        https://docs.aws.amazon.com/imagebuilder/latest/APIReference/API_ListComponentBuildVersions.html

        :stability: experimental
        '''
        return typing.cast("Imagebuilder", jsii.invoke(self, "toListComponentBuildVersions", []))

    @jsii.member(jsii_name="toListComponents")
    def to_list_components(self) -> "Imagebuilder":
        '''(experimental) Grants permission to list the component versions owned by or shared with your account.

        Access Level: List

        https://docs.aws.amazon.com/imagebuilder/latest/APIReference/API_ListComponents.html

        :stability: experimental
        '''
        return typing.cast("Imagebuilder", jsii.invoke(self, "toListComponents", []))

    @jsii.member(jsii_name="toListContainerRecipes")
    def to_list_container_recipes(self) -> "Imagebuilder":
        '''(experimental) Grants permission to list the container recipes owned by or shared with your account.

        Access Level: List

        https://docs.aws.amazon.com/imagebuilder/latest/APIReference/API_ListContainerRecipes.html

        :stability: experimental
        '''
        return typing.cast("Imagebuilder", jsii.invoke(self, "toListContainerRecipes", []))

    @jsii.member(jsii_name="toListDistributionConfigurations")
    def to_list_distribution_configurations(self) -> "Imagebuilder":
        '''(experimental) Grants permission to list the distribution configurations in your account.

        Access Level: List

        https://docs.aws.amazon.com/imagebuilder/latest/APIReference/API_ListDistributionConfigurations.html

        :stability: experimental
        '''
        return typing.cast("Imagebuilder", jsii.invoke(self, "toListDistributionConfigurations", []))

    @jsii.member(jsii_name="toListImageBuildVersions")
    def to_list_image_build_versions(self) -> "Imagebuilder":
        '''(experimental) Grants permission to list the image build versions in your account.

        Access Level: List

        https://docs.aws.amazon.com/imagebuilder/latest/APIReference/API_ListImageBuildVersions.html

        :stability: experimental
        '''
        return typing.cast("Imagebuilder", jsii.invoke(self, "toListImageBuildVersions", []))

    @jsii.member(jsii_name="toListImagePackages")
    def to_list_image_packages(self) -> "Imagebuilder":
        '''(experimental) Grants permission to returns a list of packages installed on the specified image.

        Access Level: List

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/imagebuilder/latest/APIReference/API_ListImagePackages.html

        :stability: experimental
        '''
        return typing.cast("Imagebuilder", jsii.invoke(self, "toListImagePackages", []))

    @jsii.member(jsii_name="toListImagePipelineImages")
    def to_list_image_pipeline_images(self) -> "Imagebuilder":
        '''(experimental) Grants permission to returns a list of images created by the specified pipeline.

        Access Level: List

        https://docs.aws.amazon.com/imagebuilder/latest/APIReference/API_ListImagePipelineImages.html

        :stability: experimental
        '''
        return typing.cast("Imagebuilder", jsii.invoke(self, "toListImagePipelineImages", []))

    @jsii.member(jsii_name="toListImagePipelines")
    def to_list_image_pipelines(self) -> "Imagebuilder":
        '''(experimental) Grants permission to list the image pipelines in your account.

        Access Level: List

        https://docs.aws.amazon.com/imagebuilder/latest/APIReference/API_ListImagePipelines.html

        :stability: experimental
        '''
        return typing.cast("Imagebuilder", jsii.invoke(self, "toListImagePipelines", []))

    @jsii.member(jsii_name="toListImageRecipes")
    def to_list_image_recipes(self) -> "Imagebuilder":
        '''(experimental) Grants permission to list the image recipes owned by or shared with your account.

        Access Level: List

        https://docs.aws.amazon.com/imagebuilder/latest/APIReference/API_ListImageRecipes.html

        :stability: experimental
        '''
        return typing.cast("Imagebuilder", jsii.invoke(self, "toListImageRecipes", []))

    @jsii.member(jsii_name="toListImages")
    def to_list_images(self) -> "Imagebuilder":
        '''(experimental) Grants permission to list the image versions owned by or shared with your account.

        Access Level: List

        https://docs.aws.amazon.com/imagebuilder/latest/APIReference/API_ListImages.html

        :stability: experimental
        '''
        return typing.cast("Imagebuilder", jsii.invoke(self, "toListImages", []))

    @jsii.member(jsii_name="toListInfrastructureConfigurations")
    def to_list_infrastructure_configurations(self) -> "Imagebuilder":
        '''(experimental) Grants permission to list the infrastructure configurations in your account.

        Access Level: List

        https://docs.aws.amazon.com/imagebuilder/latest/APIReference/API_ListInfrastructureConfigurations.html

        :stability: experimental
        '''
        return typing.cast("Imagebuilder", jsii.invoke(self, "toListInfrastructureConfigurations", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Imagebuilder":
        '''(experimental) Grants permission to list tag for an Image Builder resource.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/imagebuilder/latest/APIReference/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("Imagebuilder", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toPutComponentPolicy")
    def to_put_component_policy(self) -> "Imagebuilder":
        '''(experimental) Grants permission to set the resource policy associated with a component.

        Access Level: Permissions management

        https://docs.aws.amazon.com/imagebuilder/latest/APIReference/API_PutComponentPolicy.html

        :stability: experimental
        '''
        return typing.cast("Imagebuilder", jsii.invoke(self, "toPutComponentPolicy", []))

    @jsii.member(jsii_name="toPutContainerRecipePolicy")
    def to_put_container_recipe_policy(self) -> "Imagebuilder":
        '''(experimental) Grants permission to set the resource policy associated with a container recipe.

        Access Level: Permissions management

        https://docs.aws.amazon.com/imagebuilder/latest/APIReference/API_PutContainerRecipePolicy.html

        :stability: experimental
        '''
        return typing.cast("Imagebuilder", jsii.invoke(self, "toPutContainerRecipePolicy", []))

    @jsii.member(jsii_name="toPutImagePolicy")
    def to_put_image_policy(self) -> "Imagebuilder":
        '''(experimental) Grants permission to set the resource policy associated with an image.

        Access Level: Permissions management

        https://docs.aws.amazon.com/imagebuilder/latest/APIReference/API_PutImagePolicy.html

        :stability: experimental
        '''
        return typing.cast("Imagebuilder", jsii.invoke(self, "toPutImagePolicy", []))

    @jsii.member(jsii_name="toPutImageRecipePolicy")
    def to_put_image_recipe_policy(self) -> "Imagebuilder":
        '''(experimental) Grants permission to set the resource policy associated with an image recipe.

        Access Level: Permissions management

        https://docs.aws.amazon.com/imagebuilder/latest/APIReference/API_PutImageRecipePolicy.html

        :stability: experimental
        '''
        return typing.cast("Imagebuilder", jsii.invoke(self, "toPutImageRecipePolicy", []))

    @jsii.member(jsii_name="toStartImagePipelineExecution")
    def to_start_image_pipeline_execution(self) -> "Imagebuilder":
        '''(experimental) Grants permission to create a new image from a pipeline.

        Access Level: Write

        Dependent actions:

        - iam:CreateServiceLinkedRole
        - imagebuilder:GetImagePipeline

        https://docs.aws.amazon.com/imagebuilder/latest/APIReference/API_StartImagePipelineExecution.html

        :stability: experimental
        '''
        return typing.cast("Imagebuilder", jsii.invoke(self, "toStartImagePipelineExecution", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Imagebuilder":
        '''(experimental) Grants permission to tag an Image Builder resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()
        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/imagebuilder/latest/APIReference/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("Imagebuilder", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Imagebuilder":
        '''(experimental) Grants permission to untag an Image Builder resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsResourceTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/imagebuilder/latest/APIReference/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("Imagebuilder", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateDistributionConfiguration")
    def to_update_distribution_configuration(self) -> "Imagebuilder":
        '''(experimental) Grants permission to update an existing distribution configuration.

        Access Level: Write

        https://docs.aws.amazon.com/imagebuilder/latest/APIReference/API_UpdateDistributionConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Imagebuilder", jsii.invoke(self, "toUpdateDistributionConfiguration", []))

    @jsii.member(jsii_name="toUpdateImagePipeline")
    def to_update_image_pipeline(self) -> "Imagebuilder":
        '''(experimental) Grants permission to update an existing image pipeline.

        Access Level: Write

        https://docs.aws.amazon.com/imagebuilder/latest/APIReference/API_UpdateImagePipeline.html

        :stability: experimental
        '''
        return typing.cast("Imagebuilder", jsii.invoke(self, "toUpdateImagePipeline", []))

    @jsii.member(jsii_name="toUpdateInfrastructureConfiguration")
    def to_update_infrastructure_configuration(self) -> "Imagebuilder":
        '''(experimental) Grants permission to update an existing infrastructure configuration.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()
        - .ifCreatedResourceTagKeys()
        - .ifCreatedResourceTag()
        - .ifEc2MetadataHttpTokens()
        - .ifStatusTopicArn()

        Dependent actions:

        - iam:PassRole
        - sns:Publish

        https://docs.aws.amazon.com/imagebuilder/latest/APIReference/API_UpdateInfrastructureConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Imagebuilder", jsii.invoke(self, "toUpdateInfrastructureConfiguration", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e970c10f6e79d1dc90dea95cc3df8e1b85668d916130f993cb0d76789d15d8dd)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4beb41163296e4ce1c193bfd0bdbbcddcf2be67c5d07e656ecc3ff942fc8dbf2)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Importexport(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Importexport",
):
    '''(experimental) Statement provider for service `importexport <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsimportexportdiskservice.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `importexport <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsimportexportdiskservice.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="toCancelJob")
    def to_cancel_job(self) -> "Importexport":
        '''(experimental) This action cancels a specified job.

        Only the job owner can cancel it. The action fails if the job has already started or is complete.

        Access Level: Write

        https://docs.aws.amazon.com/AWSImportExport/latest/DG/WebCancelJob.html

        :stability: experimental
        '''
        return typing.cast("Importexport", jsii.invoke(self, "toCancelJob", []))

    @jsii.member(jsii_name="toCreateJob")
    def to_create_job(self) -> "Importexport":
        '''(experimental) This action initiates the process of scheduling an upload or download of your data.

        Access Level: Write

        https://docs.aws.amazon.com/AWSImportExport/latest/DG/WebCreateJob.html

        :stability: experimental
        '''
        return typing.cast("Importexport", jsii.invoke(self, "toCreateJob", []))

    @jsii.member(jsii_name="toGetShippingLabel")
    def to_get_shipping_label(self) -> "Importexport":
        '''(experimental) This action generates a pre-paid shipping label that you will use to ship your device to AWS for processing.

        Access Level: Read

        https://docs.aws.amazon.com/AWSImportExport/latest/DG/WebGetShippingLabel.html

        :stability: experimental
        '''
        return typing.cast("Importexport", jsii.invoke(self, "toGetShippingLabel", []))

    @jsii.member(jsii_name="toGetStatus")
    def to_get_status(self) -> "Importexport":
        '''(experimental) This action returns information about a job, including where the job is in the processing pipeline, the status of the results, and the signature value associated with the job.

        Access Level: Read

        https://docs.aws.amazon.com/AWSImportExport/latest/DG/WebGetStatus.html

        :stability: experimental
        '''
        return typing.cast("Importexport", jsii.invoke(self, "toGetStatus", []))

    @jsii.member(jsii_name="toListJobs")
    def to_list_jobs(self) -> "Importexport":
        '''(experimental) This action returns the jobs associated with the requester.

        Access Level: List

        https://docs.aws.amazon.com/AWSImportExport/latest/DG/WebListJobs.html

        :stability: experimental
        '''
        return typing.cast("Importexport", jsii.invoke(self, "toListJobs", []))

    @jsii.member(jsii_name="toUpdateJob")
    def to_update_job(self) -> "Importexport":
        '''(experimental) You use this action to change the parameters specified in the original manifest file by supplying a new manifest file.

        Access Level: Write

        https://docs.aws.amazon.com/AWSImportExport/latest/DG/WebUpdateJob.html

        :stability: experimental
        '''
        return typing.cast("Importexport", jsii.invoke(self, "toUpdateJob", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6be903d13071598c2e0ec526efeb600c1963d6216d4cf965b952c59735b916ca)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c2bd4b8895ae02366fea0121d676c8ef556bc45fa3b2d818b41b216d25b3e364)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Inspector(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Inspector",
):
    '''(experimental) Statement provider for service `inspector <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazoninspector.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `inspector <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazoninspector.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="toAddAttributesToFindings")
    def to_add_attributes_to_findings(self) -> "Inspector":
        '''(experimental) Grants permission to assign attributes (key and value pairs) to the findings that are specified by the ARNs of the findings.

        Access Level: Write

        https://docs.aws.amazon.com/inspector/latest/APIReference/API_AddAttributesToFindings.html

        :stability: experimental
        '''
        return typing.cast("Inspector", jsii.invoke(self, "toAddAttributesToFindings", []))

    @jsii.member(jsii_name="toCreateAssessmentTarget")
    def to_create_assessment_target(self) -> "Inspector":
        '''(experimental) Grants permission to create a new assessment target using the ARN of the resource group that is generated by CreateResourceGroup.

        Access Level: Write

        https://docs.aws.amazon.com/inspector/latest/APIReference/API_CreateAssessmentTarget.html

        :stability: experimental
        '''
        return typing.cast("Inspector", jsii.invoke(self, "toCreateAssessmentTarget", []))

    @jsii.member(jsii_name="toCreateAssessmentTemplate")
    def to_create_assessment_template(self) -> "Inspector":
        '''(experimental) Grants permission to create an assessment template for the assessment target that is specified by the ARN of the assessment target.

        Access Level: Write

        https://docs.aws.amazon.com/inspector/latest/APIReference/API_CreateAssessmentTemplate.html

        :stability: experimental
        '''
        return typing.cast("Inspector", jsii.invoke(self, "toCreateAssessmentTemplate", []))

    @jsii.member(jsii_name="toCreateExclusionsPreview")
    def to_create_exclusions_preview(self) -> "Inspector":
        '''(experimental) Grants permission to start the generation of an exclusions preview for the specified assessment template.

        Access Level: Write

        https://docs.aws.amazon.com/inspector/latest/APIReference/API_CreateExclusionsPreview.html

        :stability: experimental
        '''
        return typing.cast("Inspector", jsii.invoke(self, "toCreateExclusionsPreview", []))

    @jsii.member(jsii_name="toCreateResourceGroup")
    def to_create_resource_group(self) -> "Inspector":
        '''(experimental) Grants permission to create a resource group using the specified set of tags (key and value pairs) that are used to select the EC2 instances to be included in an Amazon Inspector assessment target.

        Access Level: Write

        https://docs.aws.amazon.com/inspector/latest/APIReference/API_CreateResourceGroup.html

        :stability: experimental
        '''
        return typing.cast("Inspector", jsii.invoke(self, "toCreateResourceGroup", []))

    @jsii.member(jsii_name="toDeleteAssessmentRun")
    def to_delete_assessment_run(self) -> "Inspector":
        '''(experimental) Grants permission to delete the assessment run that is specified by the ARN of the assessment run.

        Access Level: Write

        https://docs.aws.amazon.com/inspector/latest/APIReference/API_DeleteAssessmentRun.html

        :stability: experimental
        '''
        return typing.cast("Inspector", jsii.invoke(self, "toDeleteAssessmentRun", []))

    @jsii.member(jsii_name="toDeleteAssessmentTarget")
    def to_delete_assessment_target(self) -> "Inspector":
        '''(experimental) Grants permission to delete the assessment target that is specified by the ARN of the assessment target.

        Access Level: Write

        https://docs.aws.amazon.com/inspector/latest/APIReference/API_DeleteAssessmentTarget.html

        :stability: experimental
        '''
        return typing.cast("Inspector", jsii.invoke(self, "toDeleteAssessmentTarget", []))

    @jsii.member(jsii_name="toDeleteAssessmentTemplate")
    def to_delete_assessment_template(self) -> "Inspector":
        '''(experimental) Grants permission to delete the assessment template that is specified by the ARN of the assessment template.

        Access Level: Write

        https://docs.aws.amazon.com/inspector/latest/APIReference/API_DeleteAssessmentTemplate.html

        :stability: experimental
        '''
        return typing.cast("Inspector", jsii.invoke(self, "toDeleteAssessmentTemplate", []))

    @jsii.member(jsii_name="toDescribeAssessmentRuns")
    def to_describe_assessment_runs(self) -> "Inspector":
        '''(experimental) Grants permission to describe the assessment runs that are specified by the ARNs of the assessment runs.

        Access Level: Read

        https://docs.aws.amazon.com/inspector/latest/APIReference/API_DescribeAssessmentRuns.html

        :stability: experimental
        '''
        return typing.cast("Inspector", jsii.invoke(self, "toDescribeAssessmentRuns", []))

    @jsii.member(jsii_name="toDescribeAssessmentTargets")
    def to_describe_assessment_targets(self) -> "Inspector":
        '''(experimental) Grants permission to describe the assessment targets that are specified by the ARNs of the assessment targets.

        Access Level: Read

        https://docs.aws.amazon.com/inspector/latest/APIReference/API_DescribeAssessmentTargets.html

        :stability: experimental
        '''
        return typing.cast("Inspector", jsii.invoke(self, "toDescribeAssessmentTargets", []))

    @jsii.member(jsii_name="toDescribeAssessmentTemplates")
    def to_describe_assessment_templates(self) -> "Inspector":
        '''(experimental) Grants permission to describe the assessment templates that are specified by the ARNs of the assessment templates.

        Access Level: Read

        https://docs.aws.amazon.com/inspector/latest/APIReference/API_DescribeAssessmentTemplates.html

        :stability: experimental
        '''
        return typing.cast("Inspector", jsii.invoke(self, "toDescribeAssessmentTemplates", []))

    @jsii.member(jsii_name="toDescribeCrossAccountAccessRole")
    def to_describe_cross_account_access_role(self) -> "Inspector":
        '''(experimental) Grants permission to describe the IAM role that enables Amazon Inspector to access your AWS account.

        Access Level: Read

        https://docs.aws.amazon.com/inspector/latest/APIReference/API_DescribeCrossAccountAccessRole.html

        :stability: experimental
        '''
        return typing.cast("Inspector", jsii.invoke(self, "toDescribeCrossAccountAccessRole", []))

    @jsii.member(jsii_name="toDescribeExclusions")
    def to_describe_exclusions(self) -> "Inspector":
        '''(experimental) Grants permission to describe the exclusions that are specified by the exclusions' ARNs.

        Access Level: Read

        https://docs.aws.amazon.com/inspector/latest/APIReference/API_DescribeExclusions.html

        :stability: experimental
        '''
        return typing.cast("Inspector", jsii.invoke(self, "toDescribeExclusions", []))

    @jsii.member(jsii_name="toDescribeFindings")
    def to_describe_findings(self) -> "Inspector":
        '''(experimental) Grants permission to describe the findings that are specified by the ARNs of the findings.

        Access Level: Read

        https://docs.aws.amazon.com/inspector/latest/APIReference/API_DescribeFindings.html

        :stability: experimental
        '''
        return typing.cast("Inspector", jsii.invoke(self, "toDescribeFindings", []))

    @jsii.member(jsii_name="toDescribeResourceGroups")
    def to_describe_resource_groups(self) -> "Inspector":
        '''(experimental) Grants permission to describe the resource groups that are specified by the ARNs of the resource groups.

        Access Level: Read

        https://docs.aws.amazon.com/inspector/latest/APIReference/API_DescribeResourceGroups.html

        :stability: experimental
        '''
        return typing.cast("Inspector", jsii.invoke(self, "toDescribeResourceGroups", []))

    @jsii.member(jsii_name="toDescribeRulesPackages")
    def to_describe_rules_packages(self) -> "Inspector":
        '''(experimental) Grants permission to describe the rules packages that are specified by the ARNs of the rules packages.

        Access Level: Read

        https://docs.aws.amazon.com/inspector/latest/APIReference/API_DescribeRulesPackages.html

        :stability: experimental
        '''
        return typing.cast("Inspector", jsii.invoke(self, "toDescribeRulesPackages", []))

    @jsii.member(jsii_name="toGetAssessmentReport")
    def to_get_assessment_report(self) -> "Inspector":
        '''(experimental) Grants permission to produce an assessment report that includes detailed and comprehensive results of a specified assessment run.

        Access Level: Read

        https://docs.aws.amazon.com/inspector/latest/APIReference/API_GetAssessmentReport.html

        :stability: experimental
        '''
        return typing.cast("Inspector", jsii.invoke(self, "toGetAssessmentReport", []))

    @jsii.member(jsii_name="toGetExclusionsPreview")
    def to_get_exclusions_preview(self) -> "Inspector":
        '''(experimental) Grants permission to retrieve the exclusions preview (a list of ExclusionPreview objects) specified by the preview token.

        Access Level: Read

        https://docs.aws.amazon.com/inspector/latest/APIReference/API_GetExclusionsPreview.html

        :stability: experimental
        '''
        return typing.cast("Inspector", jsii.invoke(self, "toGetExclusionsPreview", []))

    @jsii.member(jsii_name="toGetTelemetryMetadata")
    def to_get_telemetry_metadata(self) -> "Inspector":
        '''(experimental) Grants permission to get information about the data that is collected for the specified assessment run.

        Access Level: Read

        https://docs.aws.amazon.com/inspector/latest/APIReference/API_GetTelemetryMetadata.html

        :stability: experimental
        '''
        return typing.cast("Inspector", jsii.invoke(self, "toGetTelemetryMetadata", []))

    @jsii.member(jsii_name="toListAssessmentRunAgents")
    def to_list_assessment_run_agents(self) -> "Inspector":
        '''(experimental) Grants permission to list the agents of the assessment runs that are specified by the ARNs of the assessment runs.

        Access Level: List

        https://docs.aws.amazon.com/inspector/latest/APIReference/API_ListAssessmentRunAgents.html

        :stability: experimental
        '''
        return typing.cast("Inspector", jsii.invoke(self, "toListAssessmentRunAgents", []))

    @jsii.member(jsii_name="toListAssessmentRuns")
    def to_list_assessment_runs(self) -> "Inspector":
        '''(experimental) Grants permission to list the assessment runs that correspond to the assessment templates that are specified by the ARNs of the assessment templates.

        Access Level: List

        https://docs.aws.amazon.com/inspector/latest/APIReference/API_ListAssessmentRuns.html

        :stability: experimental
        '''
        return typing.cast("Inspector", jsii.invoke(self, "toListAssessmentRuns", []))

    @jsii.member(jsii_name="toListAssessmentTargets")
    def to_list_assessment_targets(self) -> "Inspector":
        '''(experimental) Grants permission to list the ARNs of the assessment targets within this AWS account.

        Access Level: List

        https://docs.aws.amazon.com/inspector/latest/APIReference/API_ListAssessmentTargets.html

        :stability: experimental
        '''
        return typing.cast("Inspector", jsii.invoke(self, "toListAssessmentTargets", []))

    @jsii.member(jsii_name="toListAssessmentTemplates")
    def to_list_assessment_templates(self) -> "Inspector":
        '''(experimental) Grants permission to list the assessment templates that correspond to the assessment targets that are specified by the ARNs of the assessment targets.

        Access Level: List

        https://docs.aws.amazon.com/inspector/latest/APIReference/API_ListAssessmentTemplates.html

        :stability: experimental
        '''
        return typing.cast("Inspector", jsii.invoke(self, "toListAssessmentTemplates", []))

    @jsii.member(jsii_name="toListEventSubscriptions")
    def to_list_event_subscriptions(self) -> "Inspector":
        '''(experimental) Grants permission to list all the event subscriptions for the assessment template that is specified by the ARN of the assessment template.

        Access Level: List

        https://docs.aws.amazon.com/inspector/latest/APIReference/API_ListEventSubscriptions.html

        :stability: experimental
        '''
        return typing.cast("Inspector", jsii.invoke(self, "toListEventSubscriptions", []))

    @jsii.member(jsii_name="toListExclusions")
    def to_list_exclusions(self) -> "Inspector":
        '''(experimental) Grants permission to list exclusions that are generated by the assessment run.

        Access Level: List

        https://docs.aws.amazon.com/inspector/latest/APIReference/API_ListExclusions.html

        :stability: experimental
        '''
        return typing.cast("Inspector", jsii.invoke(self, "toListExclusions", []))

    @jsii.member(jsii_name="toListFindings")
    def to_list_findings(self) -> "Inspector":
        '''(experimental) Grants permission to list findings that are generated by the assessment runs that are specified by the ARNs of the assessment runs.

        Access Level: List

        https://docs.aws.amazon.com/inspector/latest/APIReference/API_ListFindings.html

        :stability: experimental
        '''
        return typing.cast("Inspector", jsii.invoke(self, "toListFindings", []))

    @jsii.member(jsii_name="toListRulesPackages")
    def to_list_rules_packages(self) -> "Inspector":
        '''(experimental) Grants permission to list all available Amazon Inspector rules packages.

        Access Level: List

        https://docs.aws.amazon.com/inspector/latest/APIReference/API_ListRulesPackages.html

        :stability: experimental
        '''
        return typing.cast("Inspector", jsii.invoke(self, "toListRulesPackages", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Inspector":
        '''(experimental) Grants permission to list all tags associated with an assessment template.

        Access Level: Read

        https://docs.aws.amazon.com/inspector/latest/APIReference/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("Inspector", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toPreviewAgents")
    def to_preview_agents(self) -> "Inspector":
        '''(experimental) Grants permission to preview the agents installed on the EC2 instances that are part of the specified assessment target.

        Access Level: Read

        https://docs.aws.amazon.com/inspector/latest/APIReference/API_PreviewAgents.html

        :stability: experimental
        '''
        return typing.cast("Inspector", jsii.invoke(self, "toPreviewAgents", []))

    @jsii.member(jsii_name="toRegisterCrossAccountAccessRole")
    def to_register_cross_account_access_role(self) -> "Inspector":
        '''(experimental) Grants permission to register the IAM role that Amazon Inspector uses to list your EC2 instances at the start of the assessment run or when you call the PreviewAgents action.

        Access Level: Write

        https://docs.aws.amazon.com/inspector/latest/APIReference/API_RegisterCrossAccountAccessRole.html

        :stability: experimental
        '''
        return typing.cast("Inspector", jsii.invoke(self, "toRegisterCrossAccountAccessRole", []))

    @jsii.member(jsii_name="toRemoveAttributesFromFindings")
    def to_remove_attributes_from_findings(self) -> "Inspector":
        '''(experimental) Grants permission to remove entire attributes (key and value pairs) from the findings that are specified by the ARNs of the findings where an attribute with the specified key exists.

        Access Level: Write

        https://docs.aws.amazon.com/inspector/latest/APIReference/API_RemoveAttributesFromFindings.html

        :stability: experimental
        '''
        return typing.cast("Inspector", jsii.invoke(self, "toRemoveAttributesFromFindings", []))

    @jsii.member(jsii_name="toSetTagsForResource")
    def to_set_tags_for_resource(self) -> "Inspector":
        '''(experimental) Grants permission to set tags (key and value pairs) to the assessment template that is specified by the ARN of the assessment template.

        Access Level: Tagging

        https://docs.aws.amazon.com/inspector/latest/APIReference/API_SetTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("Inspector", jsii.invoke(self, "toSetTagsForResource", []))

    @jsii.member(jsii_name="toStartAssessmentRun")
    def to_start_assessment_run(self) -> "Inspector":
        '''(experimental) Grants permission to start the assessment run specified by the ARN of the assessment template.

        Access Level: Write

        https://docs.aws.amazon.com/inspector/latest/APIReference/API_StartAssessmentRun.html

        :stability: experimental
        '''
        return typing.cast("Inspector", jsii.invoke(self, "toStartAssessmentRun", []))

    @jsii.member(jsii_name="toStopAssessmentRun")
    def to_stop_assessment_run(self) -> "Inspector":
        '''(experimental) Grants permission to stop the assessment run that is specified by the ARN of the assessment run.

        Access Level: Write

        https://docs.aws.amazon.com/inspector/latest/APIReference/API_StopAssessmentRun.html

        :stability: experimental
        '''
        return typing.cast("Inspector", jsii.invoke(self, "toStopAssessmentRun", []))

    @jsii.member(jsii_name="toSubscribeToEvent")
    def to_subscribe_to_event(self) -> "Inspector":
        '''(experimental) Grants permission to enable the process of sending Amazon Simple Notification Service (SNS) notifications about a specified event to a specified SNS topic.

        Access Level: Write

        https://docs.aws.amazon.com/inspector/latest/APIReference/API_SubscribeToEvent.html

        :stability: experimental
        '''
        return typing.cast("Inspector", jsii.invoke(self, "toSubscribeToEvent", []))

    @jsii.member(jsii_name="toUnsubscribeFromEvent")
    def to_unsubscribe_from_event(self) -> "Inspector":
        '''(experimental) Grants permission to disable the process of sending Amazon Simple Notification Service (SNS) notifications about a specified event to a specified SNS topic.

        Access Level: Write

        https://docs.aws.amazon.com/inspector/latest/APIReference/API_UnsubscribeFromEvent.html

        :stability: experimental
        '''
        return typing.cast("Inspector", jsii.invoke(self, "toUnsubscribeFromEvent", []))

    @jsii.member(jsii_name="toUpdateAssessmentTarget")
    def to_update_assessment_target(self) -> "Inspector":
        '''(experimental) Grants permission to update the assessment target that is specified by the ARN of the assessment target.

        Access Level: Write

        https://docs.aws.amazon.com/inspector/latest/APIReference/API_UpdateAssessmentTarget.html

        :stability: experimental
        '''
        return typing.cast("Inspector", jsii.invoke(self, "toUpdateAssessmentTarget", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__52e8f4cd6fb98ebeaf9c24175268bba828a5b9a73cd38a1e96e1806891a94bd1)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bdb469de99614a888d061e0a804cf319b24e84b054675b1f811fad06edbcc74e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Inspector2(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Inspector2",
):
    '''(experimental) Statement provider for service `inspector2 <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazoninspector2.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `inspector2 <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazoninspector2.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onFilter")
    def on_filter(
        self,
        owner_id: builtins.str,
        filter_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Inspector2":
        '''(experimental) Adds a resource of type Filter to the statement.

        https://docs.aws.amazon.com/inspector/latest/user/what-is-inspector.html

        :param owner_id: - Identifier for the ownerId.
        :param filter_id: - Identifier for the filterId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6b7000ccdd077dd557b49732d6439877394aa88cd7922ca7f6ad0180ebd04750)
            check_type(argname="argument owner_id", value=owner_id, expected_type=type_hints["owner_id"])
            check_type(argname="argument filter_id", value=filter_id, expected_type=type_hints["filter_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Inspector2", jsii.invoke(self, "onFilter", [owner_id, filter_id, account, region, partition]))

    @jsii.member(jsii_name="onFinding")
    def on_finding(
        self,
        finding_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Inspector2":
        '''(experimental) Adds a resource of type Finding to the statement.

        https://docs.aws.amazon.com/inspector/latest/user/what-is-inspector.html

        :param finding_id: - Identifier for the findingId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fa66cb6fe5ddc51f27006ea238aefedbe5115bb0b242881410e105892c72e72d)
            check_type(argname="argument finding_id", value=finding_id, expected_type=type_hints["finding_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Inspector2", jsii.invoke(self, "onFinding", [finding_id, account, region, partition]))

    @jsii.member(jsii_name="toAssociateMember")
    def to_associate_member(self) -> "Inspector2":
        '''(experimental) Grants permission to associate an account with an Amazon Inspector administrator account.

        Access Level: Write

        https://docs.aws.amazon.com/inspector/v2/APIReference/API_AssociateMember.html

        :stability: experimental
        '''
        return typing.cast("Inspector2", jsii.invoke(self, "toAssociateMember", []))

    @jsii.member(jsii_name="toBatchGetAccountStatus")
    def to_batch_get_account_status(self) -> "Inspector2":
        '''(experimental) Grants permission to retrieve information about Amazon Inspector accounts for an account.

        Access Level: Read

        https://docs.aws.amazon.com/inspector/v2/APIReference/API_BatchGetAccountStatus.html

        :stability: experimental
        '''
        return typing.cast("Inspector2", jsii.invoke(self, "toBatchGetAccountStatus", []))

    @jsii.member(jsii_name="toBatchGetFreeTrialInfo")
    def to_batch_get_free_trial_info(self) -> "Inspector2":
        '''(experimental) Grants permission to retrieve free trial period eligibility about Amazon Inspector accounts for an account.

        Access Level: Read

        https://docs.aws.amazon.com/inspector/v2/APIReference/API_BatchGetFreeTrialInfo.html

        :stability: experimental
        '''
        return typing.cast("Inspector2", jsii.invoke(self, "toBatchGetFreeTrialInfo", []))

    @jsii.member(jsii_name="toCancelFindingsReport")
    def to_cancel_findings_report(self) -> "Inspector2":
        '''(experimental) Grants permission to cancel the generation of a findings report.

        Access Level: Write

        https://docs.aws.amazon.com/inspector/v2/APIReference/API_CancelFindingsReport.html

        :stability: experimental
        '''
        return typing.cast("Inspector2", jsii.invoke(self, "toCancelFindingsReport", []))

    @jsii.member(jsii_name="toCreateFilter")
    def to_create_filter(self) -> "Inspector2":
        '''(experimental) Grants permission to create and define the settings for a findings filter.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/inspector/v2/APIReference/API_CreateFilter.html

        :stability: experimental
        '''
        return typing.cast("Inspector2", jsii.invoke(self, "toCreateFilter", []))

    @jsii.member(jsii_name="toCreateFindingsReport")
    def to_create_findings_report(self) -> "Inspector2":
        '''(experimental) Grants permission to request the generation of a findings report.

        Access Level: Write

        https://docs.aws.amazon.com/inspector/v2/APIReference/API_CreateFindingsReport.html

        :stability: experimental
        '''
        return typing.cast("Inspector2", jsii.invoke(self, "toCreateFindingsReport", []))

    @jsii.member(jsii_name="toDeleteFilter")
    def to_delete_filter(self) -> "Inspector2":
        '''(experimental) Grants permission to delete a findings filter.

        Access Level: Write

        https://docs.aws.amazon.com/inspector/v2/APIReference/API_DeleteFilter.html

        :stability: experimental
        '''
        return typing.cast("Inspector2", jsii.invoke(self, "toDeleteFilter", []))

    @jsii.member(jsii_name="toDescribeOrganizationConfiguration")
    def to_describe_organization_configuration(self) -> "Inspector2":
        '''(experimental) Grants permission to retrieve information about the Amazon Inspector configuration settings for an AWS organization.

        Access Level: Read

        https://docs.aws.amazon.com/inspector/v2/APIReference/API_DescribeOrganizationConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Inspector2", jsii.invoke(self, "toDescribeOrganizationConfiguration", []))

    @jsii.member(jsii_name="toDisable")
    def to_disable(self) -> "Inspector2":
        '''(experimental) Grants permission to disable an Amazon Inspector account.

        Access Level: Write

        https://docs.aws.amazon.com/inspector/v2/APIReference/API_Disable.html

        :stability: experimental
        '''
        return typing.cast("Inspector2", jsii.invoke(self, "toDisable", []))

    @jsii.member(jsii_name="toDisableDelegatedAdminAccount")
    def to_disable_delegated_admin_account(self) -> "Inspector2":
        '''(experimental) Grants permission to disable an account as the delegated Amazon Inspector administrator account for an AWS organization.

        Access Level: Write

        https://docs.aws.amazon.com/inspector/v2/APIReference/API_DisableDelegatedAdminAccount.html

        :stability: experimental
        '''
        return typing.cast("Inspector2", jsii.invoke(self, "toDisableDelegatedAdminAccount", []))

    @jsii.member(jsii_name="toDisassociateMember")
    def to_disassociate_member(self) -> "Inspector2":
        '''(experimental) Grants permission to an Amazon Inspector administrator account to disassociate from an Inspector member account.

        Access Level: Write

        https://docs.aws.amazon.com/inspector/v2/APIReference/API_DisassociateMember.html

        :stability: experimental
        '''
        return typing.cast("Inspector2", jsii.invoke(self, "toDisassociateMember", []))

    @jsii.member(jsii_name="toEnable")
    def to_enable(self) -> "Inspector2":
        '''(experimental) Grants permission to enable and specify the configuration settings for a new Amazon Inspector account.

        Access Level: Write

        https://docs.aws.amazon.com/inspector/v2/APIReference/API_Enable.html

        :stability: experimental
        '''
        return typing.cast("Inspector2", jsii.invoke(self, "toEnable", []))

    @jsii.member(jsii_name="toEnableDelegatedAdminAccount")
    def to_enable_delegated_admin_account(self) -> "Inspector2":
        '''(experimental) Grants permission to enable an account as the delegated Amazon Inspector administrator account for an AWS organization.

        Access Level: Write

        https://docs.aws.amazon.com/inspector/v2/APIReference/API_EnableDelegatedAdminAccount.html

        :stability: experimental
        '''
        return typing.cast("Inspector2", jsii.invoke(self, "toEnableDelegatedAdminAccount", []))

    @jsii.member(jsii_name="toGetConfiguration")
    def to_get_configuration(self) -> "Inspector2":
        '''(experimental) Grants permission to retrieve information about the Amazon Inspector configuration settings for an AWS account.

        Access Level: Read

        https://docs.aws.amazon.com/inspector/v2/APIReference/API_GetConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Inspector2", jsii.invoke(self, "toGetConfiguration", []))

    @jsii.member(jsii_name="toGetDelegatedAdminAccount")
    def to_get_delegated_admin_account(self) -> "Inspector2":
        '''(experimental) Grants permission to retrieve information about the Amazon Inspector administrator account for an account.

        Access Level: Read

        https://docs.aws.amazon.com/inspector/v2/APIReference/API_GetDelegatedAdminAccount.html

        :stability: experimental
        '''
        return typing.cast("Inspector2", jsii.invoke(self, "toGetDelegatedAdminAccount", []))

    @jsii.member(jsii_name="toGetFindingsReportStatus")
    def to_get_findings_report_status(self) -> "Inspector2":
        '''(experimental) Grants permission to retrieve status for a requested findings report.

        Access Level: Read

        https://docs.aws.amazon.com/inspector/v2/APIReference/API_GetFindingsReportStatus.html

        :stability: experimental
        '''
        return typing.cast("Inspector2", jsii.invoke(self, "toGetFindingsReportStatus", []))

    @jsii.member(jsii_name="toGetMember")
    def to_get_member(self) -> "Inspector2":
        '''(experimental) Grants permission to retrieve information about an account that's associated with an Amazon Inspector administrator account.

        Access Level: Read

        https://docs.aws.amazon.com/inspector/v2/APIReference/API_GetMember.html

        :stability: experimental
        '''
        return typing.cast("Inspector2", jsii.invoke(self, "toGetMember", []))

    @jsii.member(jsii_name="toListAccountPermissions")
    def to_list_account_permissions(self) -> "Inspector2":
        '''(experimental) Grants permission to retrieve feature configuration permissions associated with an Amazon Inspector account within an organization.

        Access Level: List

        https://docs.aws.amazon.com/inspector/v2/APIReference/API_ListAccountPermissions.html

        :stability: experimental
        '''
        return typing.cast("Inspector2", jsii.invoke(self, "toListAccountPermissions", []))

    @jsii.member(jsii_name="toListCoverage")
    def to_list_coverage(self) -> "Inspector2":
        '''(experimental) Grants permission to retrieve the types of statistics Amazon Inspector can generate for resources Inspector monitors.

        Access Level: List

        https://docs.aws.amazon.com/inspector/v2/APIReference/API_ListCoverage.html

        :stability: experimental
        '''
        return typing.cast("Inspector2", jsii.invoke(self, "toListCoverage", []))

    @jsii.member(jsii_name="toListCoverageStatistics")
    def to_list_coverage_statistics(self) -> "Inspector2":
        '''(experimental) Grants permission to retrieve statistical data and other information about the resources Amazon Inspector monitors.

        Access Level: List

        https://docs.aws.amazon.com/inspector/v2/APIReference/API_ListCoverageStatistics.html

        :stability: experimental
        '''
        return typing.cast("Inspector2", jsii.invoke(self, "toListCoverageStatistics", []))

    @jsii.member(jsii_name="toListDelegatedAdminAccounts")
    def to_list_delegated_admin_accounts(self) -> "Inspector2":
        '''(experimental) Grants permission to retrieve information about the delegated Amazon Inspector administrator account for an AWS organization.

        Access Level: List

        https://docs.aws.amazon.com/inspector/v2/APIReference/API_ListDelegatedAdminAccounts.html

        :stability: experimental
        '''
        return typing.cast("Inspector2", jsii.invoke(self, "toListDelegatedAdminAccounts", []))

    @jsii.member(jsii_name="toListFilters")
    def to_list_filters(self) -> "Inspector2":
        '''(experimental) Grants permission to retrieve information about all findings filters.

        Access Level: List

        https://docs.aws.amazon.com/inspector/v2/APIReference/API_ListFilters.html

        :stability: experimental
        '''
        return typing.cast("Inspector2", jsii.invoke(self, "toListFilters", []))

    @jsii.member(jsii_name="toListFindingAggregations")
    def to_list_finding_aggregations(self) -> "Inspector2":
        '''(experimental) Grants permission to retrieve statistical data and other information about Amazon Inspector findings.

        Access Level: List

        https://docs.aws.amazon.com/inspector/v2/APIReference/API_ListFindingAggregations.html

        :stability: experimental
        '''
        return typing.cast("Inspector2", jsii.invoke(self, "toListFindingAggregations", []))

    @jsii.member(jsii_name="toListFindings")
    def to_list_findings(self) -> "Inspector2":
        '''(experimental) Grants permission to retrieve a subset of information about one or more findings.

        Access Level: List

        https://docs.aws.amazon.com/inspector/v2/APIReference/API_ListFindings.html

        :stability: experimental
        '''
        return typing.cast("Inspector2", jsii.invoke(self, "toListFindings", []))

    @jsii.member(jsii_name="toListMembers")
    def to_list_members(self) -> "Inspector2":
        '''(experimental) Grants permission to retrieve information about the Amazon Inspector member accounts that are associated with an Inspector administrator account.

        Access Level: List

        https://docs.aws.amazon.com/inspector/v2/APIReference/API_ListMembers.html

        :stability: experimental
        '''
        return typing.cast("Inspector2", jsii.invoke(self, "toListMembers", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Inspector2":
        '''(experimental) Grants permission to retrieve the tags for an Amazon Inspector resource.

        Access Level: Read

        https://docs.aws.amazon.com/inspector/v2/APIReference/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("Inspector2", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toListUsageTotals")
    def to_list_usage_totals(self) -> "Inspector2":
        '''(experimental) Grants permission to retrieve aggregated usage data for an account.

        Access Level: List

        https://docs.aws.amazon.com/inspector/v2/APIReference/API_ListUsageTotals.html

        :stability: experimental
        '''
        return typing.cast("Inspector2", jsii.invoke(self, "toListUsageTotals", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Inspector2":
        '''(experimental) Grants permission to add or update the tags for an Amazon Inspector resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/inspector/v2/APIReference/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("Inspector2", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Inspector2":
        '''(experimental) Grants permission to remove tags from an Amazon Inspector resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/inspector/v2/APIReference/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("Inspector2", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateConfiguration")
    def to_update_configuration(self) -> "Inspector2":
        '''(experimental) Grants permission to update information about the Amazon Inspector configuration settings for an AWS account.

        Access Level: Write

        https://docs.aws.amazon.com/inspector/v2/APIReference/API_UpdateConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Inspector2", jsii.invoke(self, "toUpdateConfiguration", []))

    @jsii.member(jsii_name="toUpdateFilter")
    def to_update_filter(self) -> "Inspector2":
        '''(experimental) Grants permission to update the settings for a findings filter.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/inspector/v2/APIReference/API_UpdateFilter.html

        :stability: experimental
        '''
        return typing.cast("Inspector2", jsii.invoke(self, "toUpdateFilter", []))

    @jsii.member(jsii_name="toUpdateOrganizationConfiguration")
    def to_update_organization_configuration(self) -> "Inspector2":
        '''(experimental) Grants permission to update Amazon Inspector configuration settings for an AWS organization.

        Access Level: Write

        https://docs.aws.amazon.com/inspector/v2/APIReference/API_UpdateOrganizationConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Inspector2", jsii.invoke(self, "toUpdateOrganizationConfiguration", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e0f53ceeb84c12c72187f071deadffa8e0ecd57549d2c74bdbc5e320054ede49)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__817d81e8f4b787b445f3eb89ed3fa04a7bb5099d3f9b45df9fc1cb6f61733fb8)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Internetmonitor(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Internetmonitor",
):
    '''(experimental) Statement provider for service `internetmonitor <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazoncloudwatchinternetmonitor.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `internetmonitor <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazoncloudwatchinternetmonitor.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onHealthEvents")
    def on_health_events(
        self,
        monitor_name: builtins.str,
        event_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Internetmonitor":
        '''(experimental) Adds a resource of type HealthEvents to the statement.

        :param monitor_name: - Identifier for the monitorName.
        :param event_id: - Identifier for the eventId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1b115bd7dff4f5a6789e5247c226ec3ec0a770c9b4deddb99d67574fd4b23eb0)
            check_type(argname="argument monitor_name", value=monitor_name, expected_type=type_hints["monitor_name"])
            check_type(argname="argument event_id", value=event_id, expected_type=type_hints["event_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Internetmonitor", jsii.invoke(self, "onHealthEvents", [monitor_name, event_id, account, region, partition]))

    @jsii.member(jsii_name="onMonitor")
    def on_monitor(
        self,
        monitor_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Internetmonitor":
        '''(experimental) Adds a resource of type Monitor to the statement.

        :param monitor_name: - Identifier for the monitorName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__681d01e0d32cd3a839b2741f5409475bb12206bb3ccfaab86c5a23203fbd5cf0)
            check_type(argname="argument monitor_name", value=monitor_name, expected_type=type_hints["monitor_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Internetmonitor", jsii.invoke(self, "onMonitor", [monitor_name, account, region, partition]))

    @jsii.member(jsii_name="toCreateMonitor")
    def to_create_monitor(self) -> "Internetmonitor":
        '''(experimental) Creates a monitor.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        :stability: experimental
        '''
        return typing.cast("Internetmonitor", jsii.invoke(self, "toCreateMonitor", []))

    @jsii.member(jsii_name="toDeleteMonitor")
    def to_delete_monitor(self) -> "Internetmonitor":
        '''(experimental) Deletes a monitor.

        Access Level: Write

        :stability: experimental
        '''
        return typing.cast("Internetmonitor", jsii.invoke(self, "toDeleteMonitor", []))

    @jsii.member(jsii_name="toGetHealthEvent")
    def to_get_health_event(self) -> "Internetmonitor":
        '''(experimental) Gets information about a health event for a specified monitor.

        Access Level: Read

        :stability: experimental
        '''
        return typing.cast("Internetmonitor", jsii.invoke(self, "toGetHealthEvent", []))

    @jsii.member(jsii_name="toGetMonitor")
    def to_get_monitor(self) -> "Internetmonitor":
        '''(experimental) Gets information about a monitor.

        Access Level: Read

        :stability: experimental
        '''
        return typing.cast("Internetmonitor", jsii.invoke(self, "toGetMonitor", []))

    @jsii.member(jsii_name="toListHealthEvents")
    def to_list_health_events(self) -> "Internetmonitor":
        '''(experimental) Lists all health events for a monitor.

        Access Level: List

        :stability: experimental
        '''
        return typing.cast("Internetmonitor", jsii.invoke(self, "toListHealthEvents", []))

    @jsii.member(jsii_name="toListMonitors")
    def to_list_monitors(self) -> "Internetmonitor":
        '''(experimental) Lists all monitors in an account and their statuses.

        Access Level: List

        :stability: experimental
        '''
        return typing.cast("Internetmonitor", jsii.invoke(self, "toListMonitors", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Internetmonitor":
        '''(experimental) Lists the tags for a resource.

        Access Level: Read

        :stability: experimental
        '''
        return typing.cast("Internetmonitor", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Internetmonitor":
        '''(experimental) Adds a tag to a resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        :stability: experimental
        '''
        return typing.cast("Internetmonitor", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Internetmonitor":
        '''(experimental) Removes a tag from a resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        :stability: experimental
        '''
        return typing.cast("Internetmonitor", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateMonitor")
    def to_update_monitor(self) -> "Internetmonitor":
        '''(experimental) Updates a monitor.

        Access Level: Write

        :stability: experimental
        '''
        return typing.cast("Internetmonitor", jsii.invoke(self, "toUpdateMonitor", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__91c15c399c4d8f48bfbd83fb312a8e7da3993b2d0dcc735871d2a7946c3935f9)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a7c5e8b98312a59f28b0d8e4de5715766904a061979fb42a0dbabe66a084475b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Iot(PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Iot"):
    '''(experimental) Statement provider for service `iot <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `iot <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="ifClientMode")
    def if_client_mode(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Iot":
        '''(experimental) Filters access by the mode of the client for IoT Tunnel.

        https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html

        Applies to actions:

        - .toRotateTunnelAccessToken()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2a678deeb7c6ef286cfaef54b9eee189146be9341876cc9a50bd6bc34cae497b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Iot", jsii.invoke(self, "ifClientMode", [value, operator]))

    @jsii.member(jsii_name="ifDelete")
    def if_delete(self, value: typing.Optional[builtins.bool] = None) -> "Iot":
        '''(experimental) Filters access by a flag indicating whether or not to also delete an IoT Tunnel immediately when making iot:CloseTunnel request.

        https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html

        Applies to actions:

        - .toCloseTunnel()

        :param value: ``true`` or ``false``. **Default:** ``true``

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__73d0d7d3c3a0cd05e71cb2cf597d0275b18564c1c75d51bb09baaab0ffb5e856)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast("Iot", jsii.invoke(self, "ifDelete", [value]))

    @jsii.member(jsii_name="ifDomainName")
    def if_domain_name(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Iot":
        '''(experimental) Filters access by based on the domain name of an IoT DomainConfiguration.

        https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html

        Applies to actions:

        - .toCreateDomainConfiguration()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bdf519f6ba12122a251cf3bc7d8b45292c55a8dae7677c83e4bfc6011898b548)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Iot", jsii.invoke(self, "ifDomainName", [value, operator]))

    @jsii.member(jsii_name="ifThingGroupArn")
    def if_thing_group_arn(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Iot":
        '''(experimental) Filters access by a list of IoT Thing Group ARNs that the destination IoT Thing belongs to for an IoT Tunnel.

        https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html

        Applies to actions:

        - .toOpenTunnel()
        - .toRotateTunnelAccessToken()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c35841a9bf114c6f082cd63e6358c4ab148a34d078b51966a65997ff6bfd9d04)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Iot", jsii.invoke(self, "ifThingGroupArn", [value, operator]))

    @jsii.member(jsii_name="ifTunnelDestinationService")
    def if_tunnel_destination_service(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Iot":
        '''(experimental) Filters access by a list of destination services for an IoT Tunnel.

        https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html

        Applies to actions:

        - .toOpenTunnel()
        - .toRotateTunnelAccessToken()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9dd84ad6218151d20b15443bce782aff508f06205616f8302f11ba656b63656a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Iot", jsii.invoke(self, "ifTunnelDestinationService", [value, operator]))

    @jsii.member(jsii_name="onAuthorizer")
    def on_authorizer(
        self,
        authorizer_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Iot":
        '''(experimental) Adds a resource of type authorizer to the statement.

        https://docs.aws.amazon.com/iot/latest/developerguide/custom-authorizer.html

        :param authorizer_name: - Identifier for the authorizerName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ca60255f270bfd87fdcdb7038513ee1ab2f88a08f53224c1e6f878ca2d7e6275)
            check_type(argname="argument authorizer_name", value=authorizer_name, expected_type=type_hints["authorizer_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Iot", jsii.invoke(self, "onAuthorizer", [authorizer_name, account, region, partition]))

    @jsii.member(jsii_name="onBillinggroup")
    def on_billinggroup(
        self,
        billing_group_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Iot":
        '''(experimental) Adds a resource of type billinggroup to the statement.

        https://docs.aws.amazon.com/iot/latest/developerguide/billing-groups.html

        :param billing_group_name: - Identifier for the billingGroupName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7da516d998962c94089ac0f51af40cebba36743c60eed17c116b2fe91ef68198)
            check_type(argname="argument billing_group_name", value=billing_group_name, expected_type=type_hints["billing_group_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Iot", jsii.invoke(self, "onBillinggroup", [billing_group_name, account, region, partition]))

    @jsii.member(jsii_name="onCacert")
    def on_cacert(
        self,
        c_a_certificate: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Iot":
        '''(experimental) Adds a resource of type cacert to the statement.

        https://docs.aws.amazon.com/iot/latest/developerguide/x509-certs.html

        :param c_a_certificate: - Identifier for the cACertificate.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__37cba9ebf0ed6af20bc96379a315231c6fc74f484009d59406672f8429d9f63f)
            check_type(argname="argument c_a_certificate", value=c_a_certificate, expected_type=type_hints["c_a_certificate"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Iot", jsii.invoke(self, "onCacert", [c_a_certificate, account, region, partition]))

    @jsii.member(jsii_name="onCert")
    def on_cert(
        self,
        certificate: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Iot":
        '''(experimental) Adds a resource of type cert to the statement.

        https://docs.aws.amazon.com/iot/latest/developerguide/x509-certs.html

        :param certificate: - Identifier for the certificate.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__eb00be10d9b699780d4ec12fe6957b29c67d2fa6f6e9127d9e042139ac95d5ac)
            check_type(argname="argument certificate", value=certificate, expected_type=type_hints["certificate"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Iot", jsii.invoke(self, "onCert", [certificate, account, region, partition]))

    @jsii.member(jsii_name="onClient")
    def on_client(
        self,
        client_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Iot":
        '''(experimental) Adds a resource of type client to the statement.

        https://docs.aws.amazon.com/iot/latest/developerguide/iot-message-broker.html

        :param client_id: - Identifier for the clientId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4db9b012e05495416af3535b8b518a7523ce35289a856d0a7df929ed286d162d)
            check_type(argname="argument client_id", value=client_id, expected_type=type_hints["client_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Iot", jsii.invoke(self, "onClient", [client_id, account, region, partition]))

    @jsii.member(jsii_name="onCustommetric")
    def on_custommetric(
        self,
        metric_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Iot":
        '''(experimental) Adds a resource of type custommetric to the statement.

        https://docs.aws.amazon.com/iot/latest/developerguide/device-defender-detect.html

        :param metric_name: - Identifier for the metricName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4410d3000ba1807ef6d99ddf96658bf54a951b02fc11f3de99322380e1a99e53)
            check_type(argname="argument metric_name", value=metric_name, expected_type=type_hints["metric_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Iot", jsii.invoke(self, "onCustommetric", [metric_name, account, region, partition]))

    @jsii.member(jsii_name="onDestination")
    def on_destination(
        self,
        destination_type: builtins.str,
        uuid: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Iot":
        '''(experimental) Adds a resource of type destination to the statement.

        https://docs.aws.amazon.com/iot/latest/developerguide/rule-destination.html

        :param destination_type: - Identifier for the destinationType.
        :param uuid: - Identifier for the uuid.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__38fddfd3cc2ce3c82061daaa9df89bea6c739a1d7d68802863455b2cf9d52ab3)
            check_type(argname="argument destination_type", value=destination_type, expected_type=type_hints["destination_type"])
            check_type(argname="argument uuid", value=uuid, expected_type=type_hints["uuid"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Iot", jsii.invoke(self, "onDestination", [destination_type, uuid, account, region, partition]))

    @jsii.member(jsii_name="onDimension")
    def on_dimension(
        self,
        dimension_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Iot":
        '''(experimental) Adds a resource of type dimension to the statement.

        https://docs.aws.amazon.com/iot/latest/developerguide/device-defender-detect.html

        :param dimension_name: - Identifier for the dimensionName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8fe7c4ccdb5d857f3e4f9e3f1e61c13e3b6fca65d7ff5ce52ce67661468414c1)
            check_type(argname="argument dimension_name", value=dimension_name, expected_type=type_hints["dimension_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Iot", jsii.invoke(self, "onDimension", [dimension_name, account, region, partition]))

    @jsii.member(jsii_name="onDomainconfiguration")
    def on_domainconfiguration(
        self,
        domain_configuration_name: builtins.str,
        id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Iot":
        '''(experimental) Adds a resource of type domainconfiguration to the statement.

        https://docs.aws.amazon.com/iot/latest/developerguide/domain-configuration.html

        :param domain_configuration_name: - Identifier for the domainConfigurationName.
        :param id: - Identifier for the id.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__43c10fad0723de9336ed527ad5879aff7d6bf4de83f73b66673c2c18ec1c5a89)
            check_type(argname="argument domain_configuration_name", value=domain_configuration_name, expected_type=type_hints["domain_configuration_name"])
            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Iot", jsii.invoke(self, "onDomainconfiguration", [domain_configuration_name, id, account, region, partition]))

    @jsii.member(jsii_name="onDynamicthinggroup")
    def on_dynamicthinggroup(
        self,
        thing_group_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Iot":
        '''(experimental) Adds a resource of type dynamicthinggroup to the statement.

        https://docs.aws.amazon.com/iot/latest/developerguide/dynamic-thing-groups.html

        :param thing_group_name: - Identifier for the thingGroupName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4415ca7570c0174ef263cb35e474936c5bffe4b74bcb478fea201be13a1a25d2)
            check_type(argname="argument thing_group_name", value=thing_group_name, expected_type=type_hints["thing_group_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Iot", jsii.invoke(self, "onDynamicthinggroup", [thing_group_name, account, region, partition]))

    @jsii.member(jsii_name="onFleetmetric")
    def on_fleetmetric(
        self,
        fleet_metric_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Iot":
        '''(experimental) Adds a resource of type fleetmetric to the statement.

        https://docs.aws.amazon.com/iot/latest/developerguide/iot-indexing.html

        :param fleet_metric_name: - Identifier for the fleetMetricName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__860388947b420377e26aa59edf0db6bff26d13c534d72a60205377c121a64070)
            check_type(argname="argument fleet_metric_name", value=fleet_metric_name, expected_type=type_hints["fleet_metric_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Iot", jsii.invoke(self, "onFleetmetric", [fleet_metric_name, account, region, partition]))

    @jsii.member(jsii_name="onIndex")
    def on_index(
        self,
        index_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Iot":
        '''(experimental) Adds a resource of type index to the statement.

        https://docs.aws.amazon.com/iot/latest/developerguide/iot-indexing.html

        :param index_name: - Identifier for the indexName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a6900ee00f159019fda7f27229a8c047ef83fefbf9e8ee9285d3a31807c42f1e)
            check_type(argname="argument index_name", value=index_name, expected_type=type_hints["index_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Iot", jsii.invoke(self, "onIndex", [index_name, account, region, partition]))

    @jsii.member(jsii_name="onJob")
    def on_job(
        self,
        job_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Iot":
        '''(experimental) Adds a resource of type job to the statement.

        https://docs.aws.amazon.com/iot/latest/developerguide/iot-jobs.html

        :param job_id: - Identifier for the jobId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bad5b3c2166893c0c89ff2f97bf41d7929a0d195a47bf3d552e9a0f02bd0488d)
            check_type(argname="argument job_id", value=job_id, expected_type=type_hints["job_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Iot", jsii.invoke(self, "onJob", [job_id, account, region, partition]))

    @jsii.member(jsii_name="onJobtemplate")
    def on_jobtemplate(
        self,
        job_template_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Iot":
        '''(experimental) Adds a resource of type jobtemplate to the statement.

        https://docs.aws.amazon.com/iot/latest/developerguide/iot-job-templates.html

        :param job_template_id: - Identifier for the jobTemplateId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2cabf1463a818eceaa00dfd99e2e93957ba0baf236b2d4c2e149815ea4c83b1c)
            check_type(argname="argument job_template_id", value=job_template_id, expected_type=type_hints["job_template_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Iot", jsii.invoke(self, "onJobtemplate", [job_template_id, account, region, partition]))

    @jsii.member(jsii_name="onMitigationaction")
    def on_mitigationaction(
        self,
        mitigation_action_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Iot":
        '''(experimental) Adds a resource of type mitigationaction to the statement.

        https://docs.aws.amazon.com/iot/latest/developerguide/device-defender-mitigation-actions.html

        :param mitigation_action_name: - Identifier for the mitigationActionName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__31a2ac4ca88d1afd5b1a9046e21fb4ba0a373629496ba2451d816e7f4d39a895)
            check_type(argname="argument mitigation_action_name", value=mitigation_action_name, expected_type=type_hints["mitigation_action_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Iot", jsii.invoke(self, "onMitigationaction", [mitigation_action_name, account, region, partition]))

    @jsii.member(jsii_name="onOtaupdate")
    def on_otaupdate(
        self,
        ota_update_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Iot":
        '''(experimental) Adds a resource of type otaupdate to the statement.

        https://docs.aws.amazon.com/freertos/latest/userguide/freertos-ota-dev.html

        :param ota_update_id: - Identifier for the otaUpdateId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e2cc07f44fc1c35aa2c5e7b53d66dd8e7be63278485f6f6daefcb8777dbf4480)
            check_type(argname="argument ota_update_id", value=ota_update_id, expected_type=type_hints["ota_update_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Iot", jsii.invoke(self, "onOtaupdate", [ota_update_id, account, region, partition]))

    @jsii.member(jsii_name="onPolicy")
    def on_policy(
        self,
        policy_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Iot":
        '''(experimental) Adds a resource of type policy to the statement.

        https://docs.aws.amazon.com/iot/latest/developerguide/iot-policies.html

        :param policy_name: - Identifier for the policyName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__02a8c051eba42be9a8e2c8c2658c581027f757909241804a78e1ca825b6654f8)
            check_type(argname="argument policy_name", value=policy_name, expected_type=type_hints["policy_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Iot", jsii.invoke(self, "onPolicy", [policy_name, account, region, partition]))

    @jsii.member(jsii_name="onProvisioningtemplate")
    def on_provisioningtemplate(
        self,
        provisioning_template: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Iot":
        '''(experimental) Adds a resource of type provisioningtemplate to the statement.

        https://docs.aws.amazon.com/iot/latest/developerguide/provision-template.html

        :param provisioning_template: - Identifier for the provisioningTemplate.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6715ba4c2c7427f4f582864db5bba16902250c28efe91bcf071a7e72d87509fc)
            check_type(argname="argument provisioning_template", value=provisioning_template, expected_type=type_hints["provisioning_template"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Iot", jsii.invoke(self, "onProvisioningtemplate", [provisioning_template, account, region, partition]))

    @jsii.member(jsii_name="onRolealias")
    def on_rolealias(
        self,
        role_alias: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Iot":
        '''(experimental) Adds a resource of type rolealias to the statement.

        https://docs.aws.amazon.com/iot/latest/developerguide/authorizing-direct-aws.html

        :param role_alias: - Identifier for the roleAlias.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__030dca3f2e808c7390a0205174e8a8b4839bd2c7bda1ac6dbfe7dd4815087b91)
            check_type(argname="argument role_alias", value=role_alias, expected_type=type_hints["role_alias"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Iot", jsii.invoke(self, "onRolealias", [role_alias, account, region, partition]))

    @jsii.member(jsii_name="onRule")
    def on_rule(
        self,
        rule_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Iot":
        '''(experimental) Adds a resource of type rule to the statement.

        https://docs.aws.amazon.com/iot/latest/developerguide/iot-rules.html

        :param rule_name: - Identifier for the ruleName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1b184cdbc6d6abce3163edcb3138f23074377c1fd326980bdbb736b65adc3eef)
            check_type(argname="argument rule_name", value=rule_name, expected_type=type_hints["rule_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Iot", jsii.invoke(self, "onRule", [rule_name, account, region, partition]))

    @jsii.member(jsii_name="onScheduledaudit")
    def on_scheduledaudit(
        self,
        schedule_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Iot":
        '''(experimental) Adds a resource of type scheduledaudit to the statement.

        https://docs.aws.amazon.com/iot/latest/developerguide/device-defender-audit.html

        :param schedule_name: - Identifier for the scheduleName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__283d9872f8ec28426dea3b9a5932505eb0d0b72867233d580e77fd6cfa1c766b)
            check_type(argname="argument schedule_name", value=schedule_name, expected_type=type_hints["schedule_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Iot", jsii.invoke(self, "onScheduledaudit", [schedule_name, account, region, partition]))

    @jsii.member(jsii_name="onSecurityprofile")
    def on_securityprofile(
        self,
        security_profile_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Iot":
        '''(experimental) Adds a resource of type securityprofile to the statement.

        https://docs.aws.amazon.com/iot/latest/developerguide/device-defender-detect.html

        :param security_profile_name: - Identifier for the securityProfileName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__999ac758bfe37a00e2899d6a12ac9df3a453323db1649f6b03543f68c50198a9)
            check_type(argname="argument security_profile_name", value=security_profile_name, expected_type=type_hints["security_profile_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Iot", jsii.invoke(self, "onSecurityprofile", [security_profile_name, account, region, partition]))

    @jsii.member(jsii_name="onStream")
    def on_stream(
        self,
        stream_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Iot":
        '''(experimental) Adds a resource of type stream to the statement.

        https://docs.aws.amazon.com/freertos/latest/userguide/freertos-ota-dev.html

        :param stream_id: - Identifier for the streamId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ba063d0eb76965c5a5d62f4d930604f1731d36bea0c18de855e3e060af874b8f)
            check_type(argname="argument stream_id", value=stream_id, expected_type=type_hints["stream_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Iot", jsii.invoke(self, "onStream", [stream_id, account, region, partition]))

    @jsii.member(jsii_name="onThing")
    def on_thing(
        self,
        thing_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Iot":
        '''(experimental) Adds a resource of type thing to the statement.

        https://docs.aws.amazon.com/iot/latest/developerguide/thing-registry.html

        :param thing_name: - Identifier for the thingName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c1064b2e6da4d185dedfd67822efb09baca3764f615f6fd57c0c91cb7ddf5c01)
            check_type(argname="argument thing_name", value=thing_name, expected_type=type_hints["thing_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Iot", jsii.invoke(self, "onThing", [thing_name, account, region, partition]))

    @jsii.member(jsii_name="onThinggroup")
    def on_thinggroup(
        self,
        thing_group_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Iot":
        '''(experimental) Adds a resource of type thinggroup to the statement.

        https://docs.aws.amazon.com/iot/latest/developerguide/thing-groups.html

        :param thing_group_name: - Identifier for the thingGroupName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__28347f799e70c93c4299d9f1a5b10dd65d973818fe864be08cbb806cd96bfff2)
            check_type(argname="argument thing_group_name", value=thing_group_name, expected_type=type_hints["thing_group_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Iot", jsii.invoke(self, "onThinggroup", [thing_group_name, account, region, partition]))

    @jsii.member(jsii_name="onThingtype")
    def on_thingtype(
        self,
        thing_type_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Iot":
        '''(experimental) Adds a resource of type thingtype to the statement.

        https://docs.aws.amazon.com/iot/latest/developerguide/thing-types.html

        :param thing_type_name: - Identifier for the thingTypeName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b9f2e5bdde0d3354c68466b91fdbd7740bc80955951ef4aa82612d2cb296a0b8)
            check_type(argname="argument thing_type_name", value=thing_type_name, expected_type=type_hints["thing_type_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Iot", jsii.invoke(self, "onThingtype", [thing_type_name, account, region, partition]))

    @jsii.member(jsii_name="onTopic")
    def on_topic(
        self,
        topic_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Iot":
        '''(experimental) Adds a resource of type topic to the statement.

        https://docs.aws.amazon.com/iot/latest/developerguide/iot-message-broker.html

        :param topic_name: - Identifier for the topicName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fbe29c7b31d800925ec5e01643540bb36064cdc2819c4de019714654b6c11685)
            check_type(argname="argument topic_name", value=topic_name, expected_type=type_hints["topic_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Iot", jsii.invoke(self, "onTopic", [topic_name, account, region, partition]))

    @jsii.member(jsii_name="onTopicfilter")
    def on_topicfilter(
        self,
        topic_filter: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Iot":
        '''(experimental) Adds a resource of type topicfilter to the statement.

        https://docs.aws.amazon.com/iot/latest/developerguide/topics.html

        :param topic_filter: - Identifier for the topicFilter.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ce97f087f536b10d1e1179fb112435eafebb53a1e92dcef936ba0300d4195690)
            check_type(argname="argument topic_filter", value=topic_filter, expected_type=type_hints["topic_filter"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Iot", jsii.invoke(self, "onTopicfilter", [topic_filter, account, region, partition]))

    @jsii.member(jsii_name="onTunnel")
    def on_tunnel(
        self,
        tunnel_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Iot":
        '''(experimental) Adds a resource of type tunnel to the statement.

        https://docs.aws.amazon.com/iot/latest/developerguide/iot-tunnels.html

        :param tunnel_id: - Identifier for the tunnelId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3fb4b588335c66d5ce0b1bb62bedfabbb71e6276ced69128f9edff200083bad2)
            check_type(argname="argument tunnel_id", value=tunnel_id, expected_type=type_hints["tunnel_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Iot", jsii.invoke(self, "onTunnel", [tunnel_id, account, region, partition]))

    @jsii.member(jsii_name="toAcceptCertificateTransfer")
    def to_accept_certificate_transfer(self) -> "Iot":
        '''(experimental) Grants permission to accept a pending certificate transfer.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_AcceptCertificateTransfer.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toAcceptCertificateTransfer", []))

    @jsii.member(jsii_name="toAddThingToBillingGroup")
    def to_add_thing_to_billing_group(self) -> "Iot":
        '''(experimental) Grants permission to add a thing to the specified billing group.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_AddThingToBillingGroup.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toAddThingToBillingGroup", []))

    @jsii.member(jsii_name="toAddThingToThingGroup")
    def to_add_thing_to_thing_group(self) -> "Iot":
        '''(experimental) Grants permission to add a thing to the specified thing group.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_AddThingToThingGroup.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toAddThingToThingGroup", []))

    @jsii.member(jsii_name="toAssociateTargetsWithJob")
    def to_associate_targets_with_job(self) -> "Iot":
        '''(experimental) Grants permission to associate a group with a continuous job.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_AssociateTargetsWithJob.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toAssociateTargetsWithJob", []))

    @jsii.member(jsii_name="toAttachPolicy")
    def to_attach_policy(self) -> "Iot":
        '''(experimental) Grants permission to attach a policy to the specified target.

        Access Level: Permissions management

        https://docs.aws.amazon.com/iot/latest/apireference/API_AttachPolicy.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toAttachPolicy", []))

    @jsii.member(jsii_name="toAttachPrincipalPolicy")
    def to_attach_principal_policy(self) -> "Iot":
        '''(experimental) Grants permission to attach the specified policy to the specified principal (certificate or other credential).

        Access Level: Permissions management

        https://docs.aws.amazon.com/iot/latest/apireference/API_AttachPrincipalPolicy.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toAttachPrincipalPolicy", []))

    @jsii.member(jsii_name="toAttachSecurityProfile")
    def to_attach_security_profile(self) -> "Iot":
        '''(experimental) Grants permission to associate a Device Defender security profile with a thing group or with this account.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_AttachSecurityProfile.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toAttachSecurityProfile", []))

    @jsii.member(jsii_name="toAttachThingPrincipal")
    def to_attach_thing_principal(self) -> "Iot":
        '''(experimental) Grants permission to attach the specified principal to the specified thing.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_AttachThingPrincipal.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toAttachThingPrincipal", []))

    @jsii.member(jsii_name="toCancelAuditMitigationActionsTask")
    def to_cancel_audit_mitigation_actions_task(self) -> "Iot":
        '''(experimental) Grants permission to cancel a mitigation action task that is in progress.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_CancelAuditMitigationActionsTask.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toCancelAuditMitigationActionsTask", []))

    @jsii.member(jsii_name="toCancelAuditTask")
    def to_cancel_audit_task(self) -> "Iot":
        '''(experimental) Grants permission to cancel an audit that is in progress. The audit can be either scheduled or on-demand.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_CancelAuditTask.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toCancelAuditTask", []))

    @jsii.member(jsii_name="toCancelCertificateTransfer")
    def to_cancel_certificate_transfer(self) -> "Iot":
        '''(experimental) Grants permission to cancel a pending transfer for the specified certificate.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_CancelCertificateTransfer.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toCancelCertificateTransfer", []))

    @jsii.member(jsii_name="toCancelDetectMitigationActionsTask")
    def to_cancel_detect_mitigation_actions_task(self) -> "Iot":
        '''(experimental) Grants permission to cancel a Device Defender ML Detect mitigation action.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_CancelDetectMitigationActionsTask.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toCancelDetectMitigationActionsTask", []))

    @jsii.member(jsii_name="toCancelJob")
    def to_cancel_job(self) -> "Iot":
        '''(experimental) Grants permission to cancel a job.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_CancelJob.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toCancelJob", []))

    @jsii.member(jsii_name="toCancelJobExecution")
    def to_cancel_job_execution(self) -> "Iot":
        '''(experimental) Grants permission to cancel a job execution on a particular device.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_CancelJobExecution.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toCancelJobExecution", []))

    @jsii.member(jsii_name="toClearDefaultAuthorizer")
    def to_clear_default_authorizer(self) -> "Iot":
        '''(experimental) Grants permission to clear the default authorizer.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_ClearDefaultAuthorizer.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toClearDefaultAuthorizer", []))

    @jsii.member(jsii_name="toCloseTunnel")
    def to_close_tunnel(self) -> "Iot":
        '''(experimental) Grants permission to close a tunnel.

        Access Level: Write

        Possible conditions:

        - .ifDelete()

        https://docs.aws.amazon.com/iot/latest/apireference/API_iot-secure-tunneling_CloseTunnel.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toCloseTunnel", []))

    @jsii.member(jsii_name="toConfirmTopicRuleDestination")
    def to_confirm_topic_rule_destination(self) -> "Iot":
        '''(experimental) Grants permission to confirm a http url TopicRuleDestinationDestination.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_ConfirmTopicRuleDestination.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toConfirmTopicRuleDestination", []))

    @jsii.member(jsii_name="toConnect")
    def to_connect(self) -> "Iot":
        '''(experimental) Grants permission to connect as the specified client.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/developerguide/policy-actions.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toConnect", []))

    @jsii.member(jsii_name="toCreateAuditSuppression")
    def to_create_audit_suppression(self) -> "Iot":
        '''(experimental) Grants permission to create a Device Defender audit suppression.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_CreateAuditSuppression.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toCreateAuditSuppression", []))

    @jsii.member(jsii_name="toCreateAuthorizer")
    def to_create_authorizer(self) -> "Iot":
        '''(experimental) Grants permission to create an authorizer.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/iot/latest/apireference/API_CreateAuthorizer.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toCreateAuthorizer", []))

    @jsii.member(jsii_name="toCreateBillingGroup")
    def to_create_billing_group(self) -> "Iot":
        '''(experimental) Grants permission to create a billing group.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/iot/latest/apireference/API_CreateBillingGroup.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toCreateBillingGroup", []))

    @jsii.member(jsii_name="toCreateCertificateFromCsr")
    def to_create_certificate_from_csr(self) -> "Iot":
        '''(experimental) Grants permission to create an X.509 certificate using the specified certificate signing request.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_CreateCertificateFromCsr.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toCreateCertificateFromCsr", []))

    @jsii.member(jsii_name="toCreateCustomMetric")
    def to_create_custom_metric(self) -> "Iot":
        '''(experimental) Grants permission to create a custom metric for device side metric reporting and monitoring.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/iot/latest/apireference/API_CreateCustomMetric.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toCreateCustomMetric", []))

    @jsii.member(jsii_name="toCreateDimension")
    def to_create_dimension(self) -> "Iot":
        '''(experimental) Grants permission to define a dimension that can be used to to limit the scope of a metric used in a security profile.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/iot/latest/apireference/API_CreateDimension.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toCreateDimension", []))

    @jsii.member(jsii_name="toCreateDomainConfiguration")
    def to_create_domain_configuration(self) -> "Iot":
        '''(experimental) Grants permission to create a domain configuration.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifDomainName()

        https://docs.aws.amazon.com/iot/latest/apireference/API_CreateDomainConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toCreateDomainConfiguration", []))

    @jsii.member(jsii_name="toCreateDynamicThingGroup")
    def to_create_dynamic_thing_group(self) -> "Iot":
        '''(experimental) Grants permission to create a Dynamic Thing Group.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/iot/latest/apireference/API_CreateDynamicThingGroup.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toCreateDynamicThingGroup", []))

    @jsii.member(jsii_name="toCreateFleetMetric")
    def to_create_fleet_metric(self) -> "Iot":
        '''(experimental) Grants permission to create a fleet metric.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/iot/latest/apireference/iot-indexing.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toCreateFleetMetric", []))

    @jsii.member(jsii_name="toCreateJob")
    def to_create_job(self) -> "Iot":
        '''(experimental) Grants permission to create a job.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/iot/latest/apireference/API_CreateJob.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toCreateJob", []))

    @jsii.member(jsii_name="toCreateJobTemplate")
    def to_create_job_template(self) -> "Iot":
        '''(experimental) Grants permission to create a job template.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/iot/latest/apireference/API_CreateJobTemplate.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toCreateJobTemplate", []))

    @jsii.member(jsii_name="toCreateKeysAndCertificate")
    def to_create_keys_and_certificate(self) -> "Iot":
        '''(experimental) Grants permission to create a 2048 bit RSA key pair and issues an X.509 certificate using the issued public key.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_CreateKeysAndCertificate.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toCreateKeysAndCertificate", []))

    @jsii.member(jsii_name="toCreateMitigationAction")
    def to_create_mitigation_action(self) -> "Iot":
        '''(experimental) Grants permission to define an action that can be applied to audit findings by using StartAuditMitigationActionsTask.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/iot/latest/apireference/API_CreateMitigationAction.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toCreateMitigationAction", []))

    @jsii.member(jsii_name="toCreateOTAUpdate")
    def to_create_ota_update(self) -> "Iot":
        '''(experimental) Grants permission to create an OTA update job.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/iot/latest/apireference/API_CreateOTAUpdate.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toCreateOTAUpdate", []))

    @jsii.member(jsii_name="toCreatePolicy")
    def to_create_policy(self) -> "Iot":
        '''(experimental) Grants permission to create an AWS IoT policy.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/iot/latest/apireference/API_CreatePolicy.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toCreatePolicy", []))

    @jsii.member(jsii_name="toCreatePolicyVersion")
    def to_create_policy_version(self) -> "Iot":
        '''(experimental) Grants permission to create a new version of the specified AWS IoT policy.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_CreatePolicyVersion.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toCreatePolicyVersion", []))

    @jsii.member(jsii_name="toCreateProvisioningClaim")
    def to_create_provisioning_claim(self) -> "Iot":
        '''(experimental) Grants permission to create a provisioning claim.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_CreateProvisioningClaim.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toCreateProvisioningClaim", []))

    @jsii.member(jsii_name="toCreateProvisioningTemplate")
    def to_create_provisioning_template(self) -> "Iot":
        '''(experimental) Grants permission to create a fleet provisioning template.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - iam:PassRole

        https://docs.aws.amazon.com/iot/latest/apireference/API_CreateProvisioningTemplate.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toCreateProvisioningTemplate", []))

    @jsii.member(jsii_name="toCreateProvisioningTemplateVersion")
    def to_create_provisioning_template_version(self) -> "Iot":
        '''(experimental) Grants permission to create a new version of a fleet provisioning template.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_CreateProvisioningTemplateVersion.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toCreateProvisioningTemplateVersion", []))

    @jsii.member(jsii_name="toCreateRoleAlias")
    def to_create_role_alias(self) -> "Iot":
        '''(experimental) Grants permission to create a role alias.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - iam:PassRole

        https://docs.aws.amazon.com/iot/latest/apireference/API_CreateRoleAlias.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toCreateRoleAlias", []))

    @jsii.member(jsii_name="toCreateScheduledAudit")
    def to_create_scheduled_audit(self) -> "Iot":
        '''(experimental) Grants permission to create a scheduled audit that is run at a specified time interval.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/iot/latest/apireference/API_CreateScheduledAudit.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toCreateScheduledAudit", []))

    @jsii.member(jsii_name="toCreateSecurityProfile")
    def to_create_security_profile(self) -> "Iot":
        '''(experimental) Grants permission to create a Device Defender security profile.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/iot/latest/apireference/API_CreateSecurityProfile.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toCreateSecurityProfile", []))

    @jsii.member(jsii_name="toCreateStream")
    def to_create_stream(self) -> "Iot":
        '''(experimental) Grants permission to create a new AWS IoT stream.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/iot/latest/apireference/API_CreateStream.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toCreateStream", []))

    @jsii.member(jsii_name="toCreateThing")
    def to_create_thing(self) -> "Iot":
        '''(experimental) Grants permission to create a thing in the thing registry.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_CreateThing.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toCreateThing", []))

    @jsii.member(jsii_name="toCreateThingGroup")
    def to_create_thing_group(self) -> "Iot":
        '''(experimental) Grants permission to create a thing group.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/iot/latest/apireference/API_CreateThingGroup.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toCreateThingGroup", []))

    @jsii.member(jsii_name="toCreateThingType")
    def to_create_thing_type(self) -> "Iot":
        '''(experimental) Grants permission to create a new thing type.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/iot/latest/apireference/API_CreateThingType.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toCreateThingType", []))

    @jsii.member(jsii_name="toCreateTopicRule")
    def to_create_topic_rule(self) -> "Iot":
        '''(experimental) Grants permission to create a rule.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/iot/latest/apireference/API_CreateTopicRule.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toCreateTopicRule", []))

    @jsii.member(jsii_name="toCreateTopicRuleDestination")
    def to_create_topic_rule_destination(self) -> "Iot":
        '''(experimental) Grants permission to create a TopicRuleDestination.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_CreateTopicRuleDestination.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toCreateTopicRuleDestination", []))

    @jsii.member(jsii_name="toDeleteAccountAuditConfiguration")
    def to_delete_account_audit_configuration(self) -> "Iot":
        '''(experimental) Grants permission to delete the audit configuration associated with the account.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_DeleteAccountAuditConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toDeleteAccountAuditConfiguration", []))

    @jsii.member(jsii_name="toDeleteAuditSuppression")
    def to_delete_audit_suppression(self) -> "Iot":
        '''(experimental) Grants permission to delete a Device Defender audit suppression.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_DeleteAuditSuppression.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toDeleteAuditSuppression", []))

    @jsii.member(jsii_name="toDeleteAuthorizer")
    def to_delete_authorizer(self) -> "Iot":
        '''(experimental) Grants permission to delete the specified authorizer.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_DeleteAuthorizer.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toDeleteAuthorizer", []))

    @jsii.member(jsii_name="toDeleteBillingGroup")
    def to_delete_billing_group(self) -> "Iot":
        '''(experimental) Grants permission to delete the specified billing group.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_DeleteBillingGroup.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toDeleteBillingGroup", []))

    @jsii.member(jsii_name="toDeleteCACertificate")
    def to_delete_ca_certificate(self) -> "Iot":
        '''(experimental) Grants permission to delete a registered CA certificate.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_DeleteCACertificate.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toDeleteCACertificate", []))

    @jsii.member(jsii_name="toDeleteCertificate")
    def to_delete_certificate(self) -> "Iot":
        '''(experimental) Grants permission to delete the specified certificate.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_DeleteCertificate.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toDeleteCertificate", []))

    @jsii.member(jsii_name="toDeleteCustomMetric")
    def to_delete_custom_metric(self) -> "Iot":
        '''(experimental) Grants permission to deletes the specified custom metric from your AWS account.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_DeleteCustomMetric.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toDeleteCustomMetric", []))

    @jsii.member(jsii_name="toDeleteDimension")
    def to_delete_dimension(self) -> "Iot":
        '''(experimental) Grants permission to remove the specified dimension from your AWS account.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_DeleteDimension.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toDeleteDimension", []))

    @jsii.member(jsii_name="toDeleteDomainConfiguration")
    def to_delete_domain_configuration(self) -> "Iot":
        '''(experimental) Grants permission to delete a domain configuration.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_DeleteDomainConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toDeleteDomainConfiguration", []))

    @jsii.member(jsii_name="toDeleteDynamicThingGroup")
    def to_delete_dynamic_thing_group(self) -> "Iot":
        '''(experimental) Grants permission to delete the specified Dynamic Thing Group.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_DeleteDynamicThingGroup.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toDeleteDynamicThingGroup", []))

    @jsii.member(jsii_name="toDeleteFleetMetric")
    def to_delete_fleet_metric(self) -> "Iot":
        '''(experimental) Grants permission to delete the specified fleet metric.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/iot-indexing.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toDeleteFleetMetric", []))

    @jsii.member(jsii_name="toDeleteJob")
    def to_delete_job(self) -> "Iot":
        '''(experimental) Grants permission to delete a job and its related job executions.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_DeleteJob.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toDeleteJob", []))

    @jsii.member(jsii_name="toDeleteJobExecution")
    def to_delete_job_execution(self) -> "Iot":
        '''(experimental) Grants permission to delete a job execution.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_DeleteJobExecution.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toDeleteJobExecution", []))

    @jsii.member(jsii_name="toDeleteJobTemplate")
    def to_delete_job_template(self) -> "Iot":
        '''(experimental) Grants permission to delete a job template.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_DeleteJobTemplate.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toDeleteJobTemplate", []))

    @jsii.member(jsii_name="toDeleteMitigationAction")
    def to_delete_mitigation_action(self) -> "Iot":
        '''(experimental) Grants permission to delete a defined mitigation action from your AWS account.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_DeleteMitigationAction.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toDeleteMitigationAction", []))

    @jsii.member(jsii_name="toDeleteOTAUpdate")
    def to_delete_ota_update(self) -> "Iot":
        '''(experimental) Grants permission to delete an OTA update job.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_DeleteOTAUpdate.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toDeleteOTAUpdate", []))

    @jsii.member(jsii_name="toDeletePolicy")
    def to_delete_policy(self) -> "Iot":
        '''(experimental) Grants permission to delete the specified policy.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_DeletePolicy.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toDeletePolicy", []))

    @jsii.member(jsii_name="toDeletePolicyVersion")
    def to_delete_policy_version(self) -> "Iot":
        '''(experimental) Grants permission to Delete the specified version of the specified policy.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_DeletePolicyVersion.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toDeletePolicyVersion", []))

    @jsii.member(jsii_name="toDeleteProvisioningTemplate")
    def to_delete_provisioning_template(self) -> "Iot":
        '''(experimental) Grants permission to delete a fleet provisioning template.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_DeleteProvisioningTemplate.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toDeleteProvisioningTemplate", []))

    @jsii.member(jsii_name="toDeleteProvisioningTemplateVersion")
    def to_delete_provisioning_template_version(self) -> "Iot":
        '''(experimental) Grants permission to delete a fleet provisioning template version.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_DeleteProvisioningTemplateVersion.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toDeleteProvisioningTemplateVersion", []))

    @jsii.member(jsii_name="toDeleteRegistrationCode")
    def to_delete_registration_code(self) -> "Iot":
        '''(experimental) Grants permission to delete a CA certificate registration code.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_DeleteRegistrationCode.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toDeleteRegistrationCode", []))

    @jsii.member(jsii_name="toDeleteRoleAlias")
    def to_delete_role_alias(self) -> "Iot":
        '''(experimental) Grants permission to delete the specified role alias.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_DeleteRoleAlias.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toDeleteRoleAlias", []))

    @jsii.member(jsii_name="toDeleteScheduledAudit")
    def to_delete_scheduled_audit(self) -> "Iot":
        '''(experimental) Grants permission to delete a scheduled audit.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_DeleteScheduledAudit.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toDeleteScheduledAudit", []))

    @jsii.member(jsii_name="toDeleteSecurityProfile")
    def to_delete_security_profile(self) -> "Iot":
        '''(experimental) Grants permission to delete a Device Defender security profile.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_DeleteSecurityProfile.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toDeleteSecurityProfile", []))

    @jsii.member(jsii_name="toDeleteStream")
    def to_delete_stream(self) -> "Iot":
        '''(experimental) Grants permission to delete a specified stream.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_DeleteStream.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toDeleteStream", []))

    @jsii.member(jsii_name="toDeleteThing")
    def to_delete_thing(self) -> "Iot":
        '''(experimental) Grants permission to delete the specified thing.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_DeleteThing.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toDeleteThing", []))

    @jsii.member(jsii_name="toDeleteThingGroup")
    def to_delete_thing_group(self) -> "Iot":
        '''(experimental) Grants permission to delete the specified thing group.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_DeleteThingGroup.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toDeleteThingGroup", []))

    @jsii.member(jsii_name="toDeleteThingShadow")
    def to_delete_thing_shadow(self) -> "Iot":
        '''(experimental) Grants permission to delete the specified thing shadow.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/developerguide/policy-actions.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toDeleteThingShadow", []))

    @jsii.member(jsii_name="toDeleteThingType")
    def to_delete_thing_type(self) -> "Iot":
        '''(experimental) Grants permission to delete the specified thing type.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_DeleteThingType.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toDeleteThingType", []))

    @jsii.member(jsii_name="toDeleteTopicRule")
    def to_delete_topic_rule(self) -> "Iot":
        '''(experimental) Grants permission to delete the specified rule.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_DeleteTopicRule.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toDeleteTopicRule", []))

    @jsii.member(jsii_name="toDeleteTopicRuleDestination")
    def to_delete_topic_rule_destination(self) -> "Iot":
        '''(experimental) Grants permission to delete a TopicRuleDestination.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_DeleteTopicRuleDestination.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toDeleteTopicRuleDestination", []))

    @jsii.member(jsii_name="toDeleteV2LoggingLevel")
    def to_delete_v2_logging_level(self) -> "Iot":
        '''(experimental) Grants permission to delete the specified v2 logging level.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_DeleteV2LoggingLevel.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toDeleteV2LoggingLevel", []))

    @jsii.member(jsii_name="toDeprecateThingType")
    def to_deprecate_thing_type(self) -> "Iot":
        '''(experimental) Grants permission to deprecate the specified thing type.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_DeprecateThingType.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toDeprecateThingType", []))

    @jsii.member(jsii_name="toDescribeAccountAuditConfiguration")
    def to_describe_account_audit_configuration(self) -> "Iot":
        '''(experimental) Grants permission to get information about audit configurations for the account.

        Access Level: Read

        https://docs.aws.amazon.com/iot/latest/apireference/API_DescribeAccountAuditConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toDescribeAccountAuditConfiguration", []))

    @jsii.member(jsii_name="toDescribeAuditFinding")
    def to_describe_audit_finding(self) -> "Iot":
        '''(experimental) Grants permission to get information about a single audit finding.

        Properties include the reason for noncompliance, the severity of the issue, and when the audit that returned the finding was started

        Access Level: Read

        https://docs.aws.amazon.com/iot/latest/apireference/API_DescribeAuditFinding.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toDescribeAuditFinding", []))

    @jsii.member(jsii_name="toDescribeAuditMitigationActionsTask")
    def to_describe_audit_mitigation_actions_task(self) -> "Iot":
        '''(experimental) Grants permission to get information about an audit mitigation task that is used to apply mitigation actions to a set of audit findings.

        Access Level: Read

        https://docs.aws.amazon.com/iot/latest/apireference/API_DescribeAuditMitigationActionsTask.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toDescribeAuditMitigationActionsTask", []))

    @jsii.member(jsii_name="toDescribeAuditSuppression")
    def to_describe_audit_suppression(self) -> "Iot":
        '''(experimental) Grants permission to get information about a Device Defender audit suppression.

        Access Level: Read

        https://docs.aws.amazon.com/iot/latest/apireference/API_DescribeAuditSuppression.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toDescribeAuditSuppression", []))

    @jsii.member(jsii_name="toDescribeAuditTask")
    def to_describe_audit_task(self) -> "Iot":
        '''(experimental) Grants permission to get information about a Device Defender audit.

        Access Level: Read

        https://docs.aws.amazon.com/iot/latest/apireference/API_DescribeAuditTask.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toDescribeAuditTask", []))

    @jsii.member(jsii_name="toDescribeAuthorizer")
    def to_describe_authorizer(self) -> "Iot":
        '''(experimental) Grants permission to describe an authorizer.

        Access Level: Read

        https://docs.aws.amazon.com/iot/latest/apireference/API_DescribeAuthorizer.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toDescribeAuthorizer", []))

    @jsii.member(jsii_name="toDescribeBillingGroup")
    def to_describe_billing_group(self) -> "Iot":
        '''(experimental) Grants permission to get information about the specified billing group.

        Access Level: Read

        https://docs.aws.amazon.com/iot/latest/apireference/API_DescribeBillingGroup.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toDescribeBillingGroup", []))

    @jsii.member(jsii_name="toDescribeCACertificate")
    def to_describe_ca_certificate(self) -> "Iot":
        '''(experimental) Grants permission to describe a registered CA certificate.

        Access Level: Read

        https://docs.aws.amazon.com/iot/latest/apireference/API_DescribeCACertificate.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toDescribeCACertificate", []))

    @jsii.member(jsii_name="toDescribeCertificate")
    def to_describe_certificate(self) -> "Iot":
        '''(experimental) Grants permission to get information about the specified certificate.

        Access Level: Read

        https://docs.aws.amazon.com/iot/latest/apireference/API_DescribeCertificate.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toDescribeCertificate", []))

    @jsii.member(jsii_name="toDescribeCustomMetric")
    def to_describe_custom_metric(self) -> "Iot":
        '''(experimental) Grants permission to describe a custom metric that is defined in your AWS account.

        Access Level: Read

        https://docs.aws.amazon.com/iot/latest/apireference/API_DescribeCustomMetric.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toDescribeCustomMetric", []))

    @jsii.member(jsii_name="toDescribeDefaultAuthorizer")
    def to_describe_default_authorizer(self) -> "Iot":
        '''(experimental) Grants permission to describe the default authorizer.

        Access Level: Read

        https://docs.aws.amazon.com/iot/latest/apireference/API_DescribeDefaultAuthorizer.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toDescribeDefaultAuthorizer", []))

    @jsii.member(jsii_name="toDescribeDetectMitigationActionsTask")
    def to_describe_detect_mitigation_actions_task(self) -> "Iot":
        '''(experimental) Grants permission to describe a Device Defender ML Detect mitigation action.

        Access Level: Read

        https://docs.aws.amazon.com/iot/latest/apireference/API_DescribeDetectMitigationActionsTask.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toDescribeDetectMitigationActionsTask", []))

    @jsii.member(jsii_name="toDescribeDimension")
    def to_describe_dimension(self) -> "Iot":
        '''(experimental) Grants permission to get details about a dimension that is defined in your AWS account.

        Access Level: Read

        https://docs.aws.amazon.com/iot/latest/apireference/API_DescribeDimension.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toDescribeDimension", []))

    @jsii.member(jsii_name="toDescribeDomainConfiguration")
    def to_describe_domain_configuration(self) -> "Iot":
        '''(experimental) Grants permission to get information about the domain configuration.

        Access Level: Read

        https://docs.aws.amazon.com/iot/latest/apireference/API_DescribeDomainConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toDescribeDomainConfiguration", []))

    @jsii.member(jsii_name="toDescribeEndpoint")
    def to_describe_endpoint(self) -> "Iot":
        '''(experimental) Grants permission to get a unique endpoint specific to the AWS account making the call.

        Access Level: Read

        https://docs.aws.amazon.com/iot/latest/apireference/API_DescribeEndpoint.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toDescribeEndpoint", []))

    @jsii.member(jsii_name="toDescribeEventConfigurations")
    def to_describe_event_configurations(self) -> "Iot":
        '''(experimental) Grants permission to get account event configurations.

        Access Level: Read

        https://docs.aws.amazon.com/iot/latest/apireference/API_DescribeEventConfigurations.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toDescribeEventConfigurations", []))

    @jsii.member(jsii_name="toDescribeFleetMetric")
    def to_describe_fleet_metric(self) -> "Iot":
        '''(experimental) Grants permission to get information about the specified fleet metric.

        Access Level: Read

        https://docs.aws.amazon.com/iot/latest/apireference/iot-indexing.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toDescribeFleetMetric", []))

    @jsii.member(jsii_name="toDescribeIndex")
    def to_describe_index(self) -> "Iot":
        '''(experimental) Grants permission to get information about the specified index.

        Access Level: Read

        https://docs.aws.amazon.com/iot/latest/apireference/API_DescribeIndex.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toDescribeIndex", []))

    @jsii.member(jsii_name="toDescribeJob")
    def to_describe_job(self) -> "Iot":
        '''(experimental) Grants permission to describe a job.

        Access Level: Read

        https://docs.aws.amazon.com/iot/latest/apireference/API_DescribeJob.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toDescribeJob", []))

    @jsii.member(jsii_name="toDescribeJobExecution")
    def to_describe_job_execution(self) -> "Iot":
        '''(experimental) Grants permission to describe a job execution.

        Access Level: Read

        https://docs.aws.amazon.com/iot/latest/apireference/API_DescribeJobExecution.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toDescribeJobExecution", []))

    @jsii.member(jsii_name="toDescribeJobTemplate")
    def to_describe_job_template(self) -> "Iot":
        '''(experimental) Grants permission to describe a job template.

        Access Level: Read

        https://docs.aws.amazon.com/iot/latest/apireference/API_DescribeJobTemplate.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toDescribeJobTemplate", []))

    @jsii.member(jsii_name="toDescribeManagedJobTemplate")
    def to_describe_managed_job_template(self) -> "Iot":
        '''(experimental) Grants permission to describe a managed job template.

        Access Level: Read

        https://docs.aws.amazon.com/iot/latest/apireference/API_DescribeManagedJobTemplate.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toDescribeManagedJobTemplate", []))

    @jsii.member(jsii_name="toDescribeMitigationAction")
    def to_describe_mitigation_action(self) -> "Iot":
        '''(experimental) Grants permission to get information about a mitigation action.

        Access Level: Read

        https://docs.aws.amazon.com/iot/latest/apireference/API_DescribeMitigationAction.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toDescribeMitigationAction", []))

    @jsii.member(jsii_name="toDescribeProvisioningTemplate")
    def to_describe_provisioning_template(self) -> "Iot":
        '''(experimental) Grants permission to get information about a fleet provisioning template.

        Access Level: Read

        https://docs.aws.amazon.com/iot/latest/apireference/API_DescribeProvisioningTemplate.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toDescribeProvisioningTemplate", []))

    @jsii.member(jsii_name="toDescribeProvisioningTemplateVersion")
    def to_describe_provisioning_template_version(self) -> "Iot":
        '''(experimental) Grants permission to get information about a fleet provisioning template version.

        Access Level: Read

        https://docs.aws.amazon.com/iot/latest/apireference/API_DescribeProvisioningTemplateVersion.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toDescribeProvisioningTemplateVersion", []))

    @jsii.member(jsii_name="toDescribeRoleAlias")
    def to_describe_role_alias(self) -> "Iot":
        '''(experimental) Grants permission to describe a role alias.

        Access Level: Read

        https://docs.aws.amazon.com/iot/latest/apireference/API_DescribeRoleAlias.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toDescribeRoleAlias", []))

    @jsii.member(jsii_name="toDescribeScheduledAudit")
    def to_describe_scheduled_audit(self) -> "Iot":
        '''(experimental) Grants permission to get information about a scheduled audit.

        Access Level: Read

        https://docs.aws.amazon.com/iot/latest/apireference/API_DescribeScheduledAudit.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toDescribeScheduledAudit", []))

    @jsii.member(jsii_name="toDescribeSecurityProfile")
    def to_describe_security_profile(self) -> "Iot":
        '''(experimental) Grants permission to get information about a Device Defender security profile.

        Access Level: Read

        https://docs.aws.amazon.com/iot/latest/apireference/API_DescribeSecurityProfile.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toDescribeSecurityProfile", []))

    @jsii.member(jsii_name="toDescribeStream")
    def to_describe_stream(self) -> "Iot":
        '''(experimental) Grants permission to get information about the specified stream.

        Access Level: Read

        https://docs.aws.amazon.com/iot/latest/apireference/API_DescribeStream.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toDescribeStream", []))

    @jsii.member(jsii_name="toDescribeThing")
    def to_describe_thing(self) -> "Iot":
        '''(experimental) Grants permission to get information about the specified thing.

        Access Level: Read

        https://docs.aws.amazon.com/iot/latest/apireference/API_DescribeThing.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toDescribeThing", []))

    @jsii.member(jsii_name="toDescribeThingGroup")
    def to_describe_thing_group(self) -> "Iot":
        '''(experimental) Grants permission to get information about the specified thing group.

        Access Level: Read

        https://docs.aws.amazon.com/iot/latest/apireference/API_DescribeThingGroup.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toDescribeThingGroup", []))

    @jsii.member(jsii_name="toDescribeThingRegistrationTask")
    def to_describe_thing_registration_task(self) -> "Iot":
        '''(experimental) Grants permission to get information about the bulk thing registration task.

        Access Level: Read

        https://docs.aws.amazon.com/iot/latest/apireference/API_DescribeThingRegistrationTask.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toDescribeThingRegistrationTask", []))

    @jsii.member(jsii_name="toDescribeThingType")
    def to_describe_thing_type(self) -> "Iot":
        '''(experimental) Grants permission to get information about the specified thing type.

        Access Level: Read

        https://docs.aws.amazon.com/iot/latest/apireference/API_DescribeThingType.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toDescribeThingType", []))

    @jsii.member(jsii_name="toDescribeTunnel")
    def to_describe_tunnel(self) -> "Iot":
        '''(experimental) Grants permission to describe a tunnel.

        Access Level: Read

        https://docs.aws.amazon.com/iot/latest/apireference/API_iot-secure-tunneling_DescribeTunnel.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toDescribeTunnel", []))

    @jsii.member(jsii_name="toDetachPolicy")
    def to_detach_policy(self) -> "Iot":
        '''(experimental) Grants permission to detach a policy from the specified target.

        Access Level: Permissions management

        https://docs.aws.amazon.com/iot/latest/apireference/API_DetachPolicy.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toDetachPolicy", []))

    @jsii.member(jsii_name="toDetachPrincipalPolicy")
    def to_detach_principal_policy(self) -> "Iot":
        '''(experimental) Grants permission to remove the specified policy from the specified certificate.

        Access Level: Permissions management

        https://docs.aws.amazon.com/iot/latest/apireference/API_DetachPrincipalPolicy.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toDetachPrincipalPolicy", []))

    @jsii.member(jsii_name="toDetachSecurityProfile")
    def to_detach_security_profile(self) -> "Iot":
        '''(experimental) Grants permission to disassociate a Device Defender security profile from a thing group or from this account.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_DetachSecurityProfile.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toDetachSecurityProfile", []))

    @jsii.member(jsii_name="toDetachThingPrincipal")
    def to_detach_thing_principal(self) -> "Iot":
        '''(experimental) Grants permission to detach the specified principal from the specified thing.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_DetachThingPrincipal.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toDetachThingPrincipal", []))

    @jsii.member(jsii_name="toDisableTopicRule")
    def to_disable_topic_rule(self) -> "Iot":
        '''(experimental) Grants permission to disable the specified rule.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_DisableTopicRule.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toDisableTopicRule", []))

    @jsii.member(jsii_name="toEnableTopicRule")
    def to_enable_topic_rule(self) -> "Iot":
        '''(experimental) Grants permission to enable the specified rule.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_EnableTopicRule.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toEnableTopicRule", []))

    @jsii.member(jsii_name="toGetBehaviorModelTrainingSummaries")
    def to_get_behavior_model_training_summaries(self) -> "Iot":
        '''(experimental) Grants permission to fetch a Device Defender's ML Detect Security Profile training model's status.

        Access Level: List

        https://docs.aws.amazon.com/iot/latest/apireference/API_GetBehaviorModelTrainingSummaries.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toGetBehaviorModelTrainingSummaries", []))

    @jsii.member(jsii_name="toGetBucketsAggregation")
    def to_get_buckets_aggregation(self) -> "Iot":
        '''(experimental) Grants permission to get buckets aggregation for IoT fleet index.

        Access Level: Read

        https://docs.aws.amazon.com/iot/latest/apireference/iot-indexing.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toGetBucketsAggregation", []))

    @jsii.member(jsii_name="toGetCardinality")
    def to_get_cardinality(self) -> "Iot":
        '''(experimental) Grants permission to get cardinality for IoT fleet index.

        Access Level: Read

        https://docs.aws.amazon.com/iot/latest/apireference/API_GetCardinality.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toGetCardinality", []))

    @jsii.member(jsii_name="toGetEffectivePolicies")
    def to_get_effective_policies(self) -> "Iot":
        '''(experimental) Grants permission to get effective policies.

        Access Level: Read

        https://docs.aws.amazon.com/iot/latest/apireference/API_GetEffectivePolicies.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toGetEffectivePolicies", []))

    @jsii.member(jsii_name="toGetIndexingConfiguration")
    def to_get_indexing_configuration(self) -> "Iot":
        '''(experimental) Grants permission to get current fleet indexing configuration.

        Access Level: Read

        https://docs.aws.amazon.com/iot/latest/apireference/API_GetIndexingConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toGetIndexingConfiguration", []))

    @jsii.member(jsii_name="toGetJobDocument")
    def to_get_job_document(self) -> "Iot":
        '''(experimental) Grants permission to get a job document.

        Access Level: Read

        https://docs.aws.amazon.com/iot/latest/apireference/API_GetJobDocument.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toGetJobDocument", []))

    @jsii.member(jsii_name="toGetLoggingOptions")
    def to_get_logging_options(self) -> "Iot":
        '''(experimental) Grants permission to get the logging options.

        Access Level: Read

        https://docs.aws.amazon.com/iot/latest/apireference/API_GetLoggingOptions.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toGetLoggingOptions", []))

    @jsii.member(jsii_name="toGetOTAUpdate")
    def to_get_ota_update(self) -> "Iot":
        '''(experimental) Grants permission to get the information about the OTA update job.

        Access Level: Read

        https://docs.aws.amazon.com/iot/latest/apireference/API_GetOTAUpdate.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toGetOTAUpdate", []))

    @jsii.member(jsii_name="toGetPercentiles")
    def to_get_percentiles(self) -> "Iot":
        '''(experimental) Grants permission to get percentiles for IoT fleet index.

        Access Level: Read

        https://docs.aws.amazon.com/iot/latest/apireference/API_GetPercentiles.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toGetPercentiles", []))

    @jsii.member(jsii_name="toGetPolicy")
    def to_get_policy(self) -> "Iot":
        '''(experimental) Grants permission to get information about the specified policy with the policy document of the default version.

        Access Level: Read

        https://docs.aws.amazon.com/iot/latest/apireference/API_GetPolicy.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toGetPolicy", []))

    @jsii.member(jsii_name="toGetPolicyVersion")
    def to_get_policy_version(self) -> "Iot":
        '''(experimental) Grants permission to get information about the specified policy version.

        Access Level: Read

        https://docs.aws.amazon.com/iot/latest/apireference/API_GetPolicyVersion.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toGetPolicyVersion", []))

    @jsii.member(jsii_name="toGetRegistrationCode")
    def to_get_registration_code(self) -> "Iot":
        '''(experimental) Grants permission to get a registration code used to register a CA certificate with AWS IoT.

        Access Level: Read

        https://docs.aws.amazon.com/iot/latest/apireference/API_GetRegistrationCode.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toGetRegistrationCode", []))

    @jsii.member(jsii_name="toGetRetainedMessage")
    def to_get_retained_message(self) -> "Iot":
        '''(experimental) Grants permission to get the retained message on the specified topic.

        Access Level: Read

        https://docs.aws.amazon.com/iot/latest/developerguide/policy-actions.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toGetRetainedMessage", []))

    @jsii.member(jsii_name="toGetStatistics")
    def to_get_statistics(self) -> "Iot":
        '''(experimental) Grants permission to get statistics for IoT fleet index.

        Access Level: Read

        https://docs.aws.amazon.com/iot/latest/apireference/API_GetStatistics.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toGetStatistics", []))

    @jsii.member(jsii_name="toGetThingShadow")
    def to_get_thing_shadow(self) -> "Iot":
        '''(experimental) Grants permission to get the thing shadow.

        Access Level: Read

        https://docs.aws.amazon.com/iot/latest/developerguide/policy-actions.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toGetThingShadow", []))

    @jsii.member(jsii_name="toGetTopicRule")
    def to_get_topic_rule(self) -> "Iot":
        '''(experimental) Grants permission to get information about the specified rule.

        Access Level: Read

        https://docs.aws.amazon.com/iot/latest/apireference/API_GetTopicRule.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toGetTopicRule", []))

    @jsii.member(jsii_name="toGetTopicRuleDestination")
    def to_get_topic_rule_destination(self) -> "Iot":
        '''(experimental) Grants permission to get a TopicRuleDestination.

        Access Level: Read

        https://docs.aws.amazon.com/iot/latest/apireference/API_GetTopicRuleDestination.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toGetTopicRuleDestination", []))

    @jsii.member(jsii_name="toGetV2LoggingOptions")
    def to_get_v2_logging_options(self) -> "Iot":
        '''(experimental) Grants permission to get v2 logging options.

        Access Level: Read

        https://docs.aws.amazon.com/iot/latest/apireference/API_GetV2LoggingOptions.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toGetV2LoggingOptions", []))

    @jsii.member(jsii_name="toListActiveViolations")
    def to_list_active_violations(self) -> "Iot":
        '''(experimental) Grants permission to list the active violations for a given Device Defender security profile or Thing.

        Access Level: List

        https://docs.aws.amazon.com/iot/latest/apireference/API_ListActiveViolations.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toListActiveViolations", []))

    @jsii.member(jsii_name="toListAttachedPolicies")
    def to_list_attached_policies(self) -> "Iot":
        '''(experimental) Grants permission to list the policies attached to the specified thing group.

        Access Level: List

        https://docs.aws.amazon.com/iot/latest/apireference/API_ListAttachedPolicies.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toListAttachedPolicies", []))

    @jsii.member(jsii_name="toListAuditFindings")
    def to_list_audit_findings(self) -> "Iot":
        '''(experimental) Grants permission to list the findings (results) of a Device Defender audit or of the audits performed during a specified time period.

        Access Level: List

        https://docs.aws.amazon.com/iot/latest/apireference/API_ListAuditFindings.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toListAuditFindings", []))

    @jsii.member(jsii_name="toListAuditMitigationActionsExecutions")
    def to_list_audit_mitigation_actions_executions(self) -> "Iot":
        '''(experimental) Grants permission to get the status of audit mitigation action tasks that were executed.

        Access Level: List

        https://docs.aws.amazon.com/iot/latest/apireference/API_ListAuditMitigationActionsExecutions.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toListAuditMitigationActionsExecutions", []))

    @jsii.member(jsii_name="toListAuditMitigationActionsTasks")
    def to_list_audit_mitigation_actions_tasks(self) -> "Iot":
        '''(experimental) Grants permission to get a list of audit mitigation action tasks that match the specified filters.

        Access Level: List

        https://docs.aws.amazon.com/iot/latest/apireference/API_ListAuditMitigationActionsTasks.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toListAuditMitigationActionsTasks", []))

    @jsii.member(jsii_name="toListAuditSuppressions")
    def to_list_audit_suppressions(self) -> "Iot":
        '''(experimental) Grants permission to list your Device Defender audit suppressions.

        Access Level: List

        https://docs.aws.amazon.com/iot/latest/apireference/API_ListAuditSuppressions.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toListAuditSuppressions", []))

    @jsii.member(jsii_name="toListAuditTasks")
    def to_list_audit_tasks(self) -> "Iot":
        '''(experimental) Grants permission to list the Device Defender audits that have been performed during a given time period.

        Access Level: List

        https://docs.aws.amazon.com/iot/latest/apireference/API_ListAuditTasks.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toListAuditTasks", []))

    @jsii.member(jsii_name="toListAuthorizers")
    def to_list_authorizers(self) -> "Iot":
        '''(experimental) Grants permission to list the authorizers registered in your account.

        Access Level: List

        https://docs.aws.amazon.com/iot/latest/apireference/API_ListAuthorizers.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toListAuthorizers", []))

    @jsii.member(jsii_name="toListBillingGroups")
    def to_list_billing_groups(self) -> "Iot":
        '''(experimental) Grants permission to list all billing groups.

        Access Level: List

        https://docs.aws.amazon.com/iot/latest/apireference/API_ListBillingGroups.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toListBillingGroups", []))

    @jsii.member(jsii_name="toListCACertificates")
    def to_list_ca_certificates(self) -> "Iot":
        '''(experimental) Grants permission to list the CA certificates registered for your AWS account.

        Access Level: List

        https://docs.aws.amazon.com/iot/latest/apireference/API_ListCACertificates.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toListCACertificates", []))

    @jsii.member(jsii_name="toListCertificates")
    def to_list_certificates(self) -> "Iot":
        '''(experimental) Grants permission to list your certificates.

        Access Level: List

        https://docs.aws.amazon.com/iot/latest/apireference/API_ListCertificates.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toListCertificates", []))

    @jsii.member(jsii_name="toListCertificatesByCA")
    def to_list_certificates_by_ca(self) -> "Iot":
        '''(experimental) Grants permission to list the device certificates signed by the specified CA certificate.

        Access Level: List

        https://docs.aws.amazon.com/iot/latest/apireference/API_ListCertificatesByCA.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toListCertificatesByCA", []))

    @jsii.member(jsii_name="toListCustomMetrics")
    def to_list_custom_metrics(self) -> "Iot":
        '''(experimental) Grants permission to list the custom metrics in your AWS account.

        Access Level: List

        https://docs.aws.amazon.com/iot/latest/apireference/API_ListCustomMetrics.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toListCustomMetrics", []))

    @jsii.member(jsii_name="toListDetectMitigationActionsExecutions")
    def to_list_detect_mitigation_actions_executions(self) -> "Iot":
        '''(experimental) Grants permission to lists mitigation actions executions for a Device Defender ML Detect Security Profile.

        Access Level: List

        https://docs.aws.amazon.com/iot/latest/apireference/API_ListDetectMitigationActionsExecutions.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toListDetectMitigationActionsExecutions", []))

    @jsii.member(jsii_name="toListDetectMitigationActionsTasks")
    def to_list_detect_mitigation_actions_tasks(self) -> "Iot":
        '''(experimental) Grants permission to list Device Defender ML Detect mitigation actions tasks.

        Access Level: List

        https://docs.aws.amazon.com/iot/latest/apireference/API_ListDetectMitigationActionsTasks.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toListDetectMitigationActionsTasks", []))

    @jsii.member(jsii_name="toListDimensions")
    def to_list_dimensions(self) -> "Iot":
        '''(experimental) Grants permission to list the dimensions that are defined for your AWS account.

        Access Level: List

        https://docs.aws.amazon.com/iot/latest/apireference/API_ListDimensions.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toListDimensions", []))

    @jsii.member(jsii_name="toListDomainConfigurations")
    def to_list_domain_configurations(self) -> "Iot":
        '''(experimental) Grants permission to list the domain configuration created by your AWS account.

        Access Level: List

        https://docs.aws.amazon.com/iot/latest/apireference/API_ListDomainConfigurations.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toListDomainConfigurations", []))

    @jsii.member(jsii_name="toListFleetMetrics")
    def to_list_fleet_metrics(self) -> "Iot":
        '''(experimental) Grants permission to list the fleet metrics in your account.

        Access Level: List

        https://docs.aws.amazon.com/iot/latest/apireference/iot-indexing.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toListFleetMetrics", []))

    @jsii.member(jsii_name="toListIndices")
    def to_list_indices(self) -> "Iot":
        '''(experimental) Grants permission to list all indices for fleet index.

        Access Level: List

        https://docs.aws.amazon.com/iot/latest/apireference/API_ListIndices.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toListIndices", []))

    @jsii.member(jsii_name="toListJobExecutionsForJob")
    def to_list_job_executions_for_job(self) -> "Iot":
        '''(experimental) Grants permission to list the job executions for a job.

        Access Level: List

        https://docs.aws.amazon.com/iot/latest/apireference/API_ListJobExecutionsForJob.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toListJobExecutionsForJob", []))

    @jsii.member(jsii_name="toListJobExecutionsForThing")
    def to_list_job_executions_for_thing(self) -> "Iot":
        '''(experimental) Grants permission to list the job executions for the specified thing.

        Access Level: List

        https://docs.aws.amazon.com/iot/latest/apireference/API_ListJobExecutionsForThing.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toListJobExecutionsForThing", []))

    @jsii.member(jsii_name="toListJobs")
    def to_list_jobs(self) -> "Iot":
        '''(experimental) Grants permission to list jobs.

        Access Level: List

        https://docs.aws.amazon.com/iot/latest/apireference/API_ListJobs.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toListJobs", []))

    @jsii.member(jsii_name="toListJobTemplates")
    def to_list_job_templates(self) -> "Iot":
        '''(experimental) Grants permission to list job templates.

        Access Level: List

        https://docs.aws.amazon.com/iot/latest/apireference/API_ListJobTemplates.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toListJobTemplates", []))

    @jsii.member(jsii_name="toListManagedJobTemplates")
    def to_list_managed_job_templates(self) -> "Iot":
        '''(experimental) Grants permission to list managed job templates.

        Access Level: List

        https://docs.aws.amazon.com/iot/latest/apireference/API_ListManagedJobTemplates.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toListManagedJobTemplates", []))

    @jsii.member(jsii_name="toListMetricValues")
    def to_list_metric_values(self) -> "Iot":
        '''(experimental) Adds support to list metric datapoints collected for IoT devices.

        Access Level: List

        https://docs.aws.amazon.com/iot/latest/apireference/API_ListMetricValues.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toListMetricValues", []))

    @jsii.member(jsii_name="toListMitigationActions")
    def to_list_mitigation_actions(self) -> "Iot":
        '''(experimental) Grants permission to get a list of all mitigation actions that match the specified filter criteria.

        Access Level: List

        https://docs.aws.amazon.com/iot/latest/apireference/API_ListMitigationActions.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toListMitigationActions", []))

    @jsii.member(jsii_name="toListNamedShadowsForThing")
    def to_list_named_shadows_for_thing(self) -> "Iot":
        '''(experimental) Grants permission to list all named shadows for a given thing.

        Access Level: List

        https://docs.aws.amazon.com/iot/latest/apireference/API_ListNamedShadowsForThing.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toListNamedShadowsForThing", []))

    @jsii.member(jsii_name="toListOTAUpdates")
    def to_list_ota_updates(self) -> "Iot":
        '''(experimental) Grants permission to list OTA update jobs in the account.

        Access Level: List

        https://docs.aws.amazon.com/iot/latest/apireference/API_ListOTAUpdates.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toListOTAUpdates", []))

    @jsii.member(jsii_name="toListOutgoingCertificates")
    def to_list_outgoing_certificates(self) -> "Iot":
        '''(experimental) Grants permission to list certificates that are being transfered but not yet accepted.

        Access Level: List

        https://docs.aws.amazon.com/iot/latest/apireference/API_ListOutgoingCertificates.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toListOutgoingCertificates", []))

    @jsii.member(jsii_name="toListPolicies")
    def to_list_policies(self) -> "Iot":
        '''(experimental) Grants permission to list your policies.

        Access Level: List

        https://docs.aws.amazon.com/iot/latest/apireference/API_ListPolicies.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toListPolicies", []))

    @jsii.member(jsii_name="toListPolicyPrincipals")
    def to_list_policy_principals(self) -> "Iot":
        '''(experimental) Grants permission to list the principals associated with the specified policy.

        Access Level: List

        https://docs.aws.amazon.com/iot/latest/apireference/API_ListPolicyPrincipals.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toListPolicyPrincipals", []))

    @jsii.member(jsii_name="toListPolicyVersions")
    def to_list_policy_versions(self) -> "Iot":
        '''(experimental) Grants permission to list the versions of the specified policy, and identifies the default version.

        Access Level: List

        https://docs.aws.amazon.com/iot/latest/apireference/API_ListPolicyVersions.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toListPolicyVersions", []))

    @jsii.member(jsii_name="toListPrincipalPolicies")
    def to_list_principal_policies(self) -> "Iot":
        '''(experimental) Grants permission to list the policies attached to the specified principal.

        If you use an Amazon Cognito identity, the ID needs to be in Amazon Cognito Identity format

        Access Level: List

        https://docs.aws.amazon.com/iot/latest/apireference/API_ListPrincipalPolicies.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toListPrincipalPolicies", []))

    @jsii.member(jsii_name="toListPrincipalThings")
    def to_list_principal_things(self) -> "Iot":
        '''(experimental) Grants permission to list the things associated with the specified principal.

        Access Level: List

        https://docs.aws.amazon.com/iot/latest/apireference/API_ListPrincipalThings.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toListPrincipalThings", []))

    @jsii.member(jsii_name="toListProvisioningTemplates")
    def to_list_provisioning_templates(self) -> "Iot":
        '''(experimental) Grants permission to list the fleet provisioning templates in your AWS account.

        Access Level: List

        https://docs.aws.amazon.com/iot/latest/apireference/API_ListProvisioningTemplates.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toListProvisioningTemplates", []))

    @jsii.member(jsii_name="toListProvisioningTemplateVersions")
    def to_list_provisioning_template_versions(self) -> "Iot":
        '''(experimental) Grants permission to get a list of fleet provisioning template versions.

        Access Level: List

        https://docs.aws.amazon.com/iot/latest/apireference/API_ListProvisioningTemplateVersions.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toListProvisioningTemplateVersions", []))

    @jsii.member(jsii_name="toListRetainedMessages")
    def to_list_retained_messages(self) -> "Iot":
        '''(experimental) Grants permission to list the retained messages for your account.

        Access Level: List

        https://docs.aws.amazon.com/iot/latest/developerguide/policy-actions.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toListRetainedMessages", []))

    @jsii.member(jsii_name="toListRoleAliases")
    def to_list_role_aliases(self) -> "Iot":
        '''(experimental) Grants permission to list role aliases.

        Access Level: List

        https://docs.aws.amazon.com/iot/latest/apireference/API_ListRoleAliases.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toListRoleAliases", []))

    @jsii.member(jsii_name="toListScheduledAudits")
    def to_list_scheduled_audits(self) -> "Iot":
        '''(experimental) Grants permission to list all of your scheduled audits.

        Access Level: List

        https://docs.aws.amazon.com/iot/latest/apireference/API_ListScheduledAudits.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toListScheduledAudits", []))

    @jsii.member(jsii_name="toListSecurityProfiles")
    def to_list_security_profiles(self) -> "Iot":
        '''(experimental) Grants permission to list the Device Defender security profiles you have created.

        Access Level: List

        https://docs.aws.amazon.com/iot/latest/apireference/API_ListSecurityProfiles.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toListSecurityProfiles", []))

    @jsii.member(jsii_name="toListSecurityProfilesForTarget")
    def to_list_security_profiles_for_target(self) -> "Iot":
        '''(experimental) Grants permission to list the Device Defender security profiles attached to a target.

        Access Level: List

        https://docs.aws.amazon.com/iot/latest/apireference/API_ListSecurityProfilesForTarget.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toListSecurityProfilesForTarget", []))

    @jsii.member(jsii_name="toListStreams")
    def to_list_streams(self) -> "Iot":
        '''(experimental) Grants permission to list the streams in your account.

        Access Level: List

        https://docs.aws.amazon.com/iot/latest/apireference/API_ListStreams.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toListStreams", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Iot":
        '''(experimental) Grants permission to list all tags for a given resource.

        Access Level: Read

        https://docs.aws.amazon.com/iot/latest/apireference/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toListTargetsForPolicy")
    def to_list_targets_for_policy(self) -> "Iot":
        '''(experimental) Grants permission to list targets for the specified policy.

        Access Level: List

        https://docs.aws.amazon.com/iot/latest/apireference/API_ListTargetsForPolicy.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toListTargetsForPolicy", []))

    @jsii.member(jsii_name="toListTargetsForSecurityProfile")
    def to_list_targets_for_security_profile(self) -> "Iot":
        '''(experimental) Grants permission to list the targets associated with a given Device Defender security profile.

        Access Level: List

        https://docs.aws.amazon.com/iot/latest/apireference/API_ListTargetsForSecurityProfile.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toListTargetsForSecurityProfile", []))

    @jsii.member(jsii_name="toListThingGroups")
    def to_list_thing_groups(self) -> "Iot":
        '''(experimental) Grants permission to list all thing groups.

        Access Level: List

        https://docs.aws.amazon.com/iot/latest/apireference/API_ListThingGroups.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toListThingGroups", []))

    @jsii.member(jsii_name="toListThingGroupsForThing")
    def to_list_thing_groups_for_thing(self) -> "Iot":
        '''(experimental) Grants permission to list thing groups to which the specified thing belongs.

        Access Level: List

        https://docs.aws.amazon.com/iot/latest/apireference/API_ListThingGroupsForThing.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toListThingGroupsForThing", []))

    @jsii.member(jsii_name="toListThingPrincipals")
    def to_list_thing_principals(self) -> "Iot":
        '''(experimental) Grants permission to list the principals associated with the specified thing.

        Access Level: List

        https://docs.aws.amazon.com/iot/latest/apireference/API_ListThingPrincipals.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toListThingPrincipals", []))

    @jsii.member(jsii_name="toListThingRegistrationTaskReports")
    def to_list_thing_registration_task_reports(self) -> "Iot":
        '''(experimental) Grants permission to list information about bulk thing registration tasks.

        Access Level: List

        https://docs.aws.amazon.com/iot/latest/apireference/API_ListThingRegistrationTaskReports.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toListThingRegistrationTaskReports", []))

    @jsii.member(jsii_name="toListThingRegistrationTasks")
    def to_list_thing_registration_tasks(self) -> "Iot":
        '''(experimental) Grants permission to list bulk thing registration tasks.

        Access Level: List

        https://docs.aws.amazon.com/iot/latest/apireference/API_ListThingRegistrationTasks.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toListThingRegistrationTasks", []))

    @jsii.member(jsii_name="toListThings")
    def to_list_things(self) -> "Iot":
        '''(experimental) Grants permission to list all things.

        Access Level: List

        https://docs.aws.amazon.com/iot/latest/apireference/API_ListThings.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toListThings", []))

    @jsii.member(jsii_name="toListThingsInBillingGroup")
    def to_list_things_in_billing_group(self) -> "Iot":
        '''(experimental) Grants permission to list all things in the specified billing group.

        Access Level: List

        https://docs.aws.amazon.com/iot/latest/apireference/API_ListThingsInBillingGroup.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toListThingsInBillingGroup", []))

    @jsii.member(jsii_name="toListThingsInThingGroup")
    def to_list_things_in_thing_group(self) -> "Iot":
        '''(experimental) Grants permission to list all things in the specified thing group.

        Access Level: List

        https://docs.aws.amazon.com/iot/latest/apireference/API_ListThingsInThingGroup.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toListThingsInThingGroup", []))

    @jsii.member(jsii_name="toListThingTypes")
    def to_list_thing_types(self) -> "Iot":
        '''(experimental) Grants permission to list all thing types.

        Access Level: List

        https://docs.aws.amazon.com/iot/latest/apireference/API_ListThingTypes.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toListThingTypes", []))

    @jsii.member(jsii_name="toListTopicRuleDestinations")
    def to_list_topic_rule_destinations(self) -> "Iot":
        '''(experimental) Grants permission to list all TopicRuleDestinations.

        Access Level: List

        https://docs.aws.amazon.com/iot/latest/apireference/API_ListTopicRuleDestinations.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toListTopicRuleDestinations", []))

    @jsii.member(jsii_name="toListTopicRules")
    def to_list_topic_rules(self) -> "Iot":
        '''(experimental) Grants permission to list the rules for the specific topic.

        Access Level: List

        https://docs.aws.amazon.com/iot/latest/apireference/API_ListTopicRules.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toListTopicRules", []))

    @jsii.member(jsii_name="toListTunnels")
    def to_list_tunnels(self) -> "Iot":
        '''(experimental) Grants permission to list tunnels.

        Access Level: List

        https://docs.aws.amazon.com/iot/latest/apireference/API_iot-secure-tunneling_ListTunnels.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toListTunnels", []))

    @jsii.member(jsii_name="toListV2LoggingLevels")
    def to_list_v2_logging_levels(self) -> "Iot":
        '''(experimental) Grants permission to list the v2 logging levels.

        Access Level: List

        https://docs.aws.amazon.com/iot/latest/apireference/API_ListV2LoggingLevels.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toListV2LoggingLevels", []))

    @jsii.member(jsii_name="toListViolationEvents")
    def to_list_violation_events(self) -> "Iot":
        '''(experimental) Grants permission to list the Device Defender security profile violations discovered during the given time period.

        Access Level: List

        https://docs.aws.amazon.com/iot/latest/apireference/API_ListViolationEvents.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toListViolationEvents", []))

    @jsii.member(jsii_name="toOpenTunnel")
    def to_open_tunnel(self) -> "Iot":
        '''(experimental) Grants permission to open a tunnel.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifThingGroupArn()
        - .ifTunnelDestinationService()

        https://docs.aws.amazon.com/iot/latest/apireference/API_iot-secure-tunneling_OpenTunnel.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toOpenTunnel", []))

    @jsii.member(jsii_name="toPublish")
    def to_publish(self) -> "Iot":
        '''(experimental) Grants permission to publish to the specified topic.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/developerguide/policy-actions.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toPublish", []))

    @jsii.member(jsii_name="toPutVerificationStateOnViolation")
    def to_put_verification_state_on_violation(self) -> "Iot":
        '''(experimental) Grants permission to put verification state on a violation.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_PutVerificationStateOnViolation.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toPutVerificationStateOnViolation", []))

    @jsii.member(jsii_name="toReceive")
    def to_receive(self) -> "Iot":
        '''(experimental) Grants permission to receive from the specified topic.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/developerguide/policy-actions.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toReceive", []))

    @jsii.member(jsii_name="toRegisterCACertificate")
    def to_register_ca_certificate(self) -> "Iot":
        '''(experimental) Grants permission to register a CA certificate with AWS IoT.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - iam:PassRole

        https://docs.aws.amazon.com/iot/latest/apireference/API_RegisterCACertificate.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toRegisterCACertificate", []))

    @jsii.member(jsii_name="toRegisterCertificate")
    def to_register_certificate(self) -> "Iot":
        '''(experimental) Grants permission to register a device certificate with AWS IoT.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_RegisterCertificate.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toRegisterCertificate", []))

    @jsii.member(jsii_name="toRegisterCertificateWithoutCA")
    def to_register_certificate_without_ca(self) -> "Iot":
        '''(experimental) Grants permission to register a device certificate with AWS IoT without a registered CA (certificate authority).

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_RegisterCertificateWithoutCA.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toRegisterCertificateWithoutCA", []))

    @jsii.member(jsii_name="toRegisterThing")
    def to_register_thing(self) -> "Iot":
        '''(experimental) Grants permission to register your thing.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_RegisterThing.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toRegisterThing", []))

    @jsii.member(jsii_name="toRejectCertificateTransfer")
    def to_reject_certificate_transfer(self) -> "Iot":
        '''(experimental) Grants permission to reject a pending certificate transfer.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_RejectCertificateTransfer.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toRejectCertificateTransfer", []))

    @jsii.member(jsii_name="toRemoveThingFromBillingGroup")
    def to_remove_thing_from_billing_group(self) -> "Iot":
        '''(experimental) Grants permission to remove thing from the specified billing group.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_RemoveThingFromBillingGroup.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toRemoveThingFromBillingGroup", []))

    @jsii.member(jsii_name="toRemoveThingFromThingGroup")
    def to_remove_thing_from_thing_group(self) -> "Iot":
        '''(experimental) Grants permission to remove thing from the specified thing group.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_RemoveThingFromThingGroup.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toRemoveThingFromThingGroup", []))

    @jsii.member(jsii_name="toReplaceTopicRule")
    def to_replace_topic_rule(self) -> "Iot":
        '''(experimental) Grants permission to replace the specified rule.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_ReplaceTopicRule.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toReplaceTopicRule", []))

    @jsii.member(jsii_name="toRetainPublish")
    def to_retain_publish(self) -> "Iot":
        '''(experimental) Grants permission to publish a retained message to the specified topic.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/developerguide/policy-actions.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toRetainPublish", []))

    @jsii.member(jsii_name="toRotateTunnelAccessToken")
    def to_rotate_tunnel_access_token(self) -> "Iot":
        '''(experimental) Grants permission to rotate the access token of a tunnel.

        Access Level: Write

        Possible conditions:

        - .ifThingGroupArn()
        - .ifTunnelDestinationService()
        - .ifClientMode()

        https://docs.aws.amazon.com/iot/latest/apireference/API_iot-secure-tunneling_RotateTunnelAccessToken.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toRotateTunnelAccessToken", []))

    @jsii.member(jsii_name="toSearchIndex")
    def to_search_index(self) -> "Iot":
        '''(experimental) Grants permission to search IoT fleet index.

        Access Level: Read

        https://docs.aws.amazon.com/iot/latest/apireference/API_SearchIndex.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toSearchIndex", []))

    @jsii.member(jsii_name="toSetDefaultAuthorizer")
    def to_set_default_authorizer(self) -> "Iot":
        '''(experimental) Grants permission to set the default authorizer.

        This will be used if a websocket connection is made without specifying an authorizer

        Access Level: Permissions management

        https://docs.aws.amazon.com/iot/latest/apireference/API_SetDefaultAuthorizer.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toSetDefaultAuthorizer", []))

    @jsii.member(jsii_name="toSetDefaultPolicyVersion")
    def to_set_default_policy_version(self) -> "Iot":
        '''(experimental) Grants permission to set the specified version of the specified policy as the policy's default (operative) version.

        Access Level: Permissions management

        https://docs.aws.amazon.com/iot/latest/apireference/API_SetDefaultPolicyVersion.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toSetDefaultPolicyVersion", []))

    @jsii.member(jsii_name="toSetLoggingOptions")
    def to_set_logging_options(self) -> "Iot":
        '''(experimental) Grants permission to set the logging options.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_SetLoggingOptions.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toSetLoggingOptions", []))

    @jsii.member(jsii_name="toSetV2LoggingLevel")
    def to_set_v2_logging_level(self) -> "Iot":
        '''(experimental) Grants permission to set the v2 logging level.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_SetV2LoggingLevel.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toSetV2LoggingLevel", []))

    @jsii.member(jsii_name="toSetV2LoggingOptions")
    def to_set_v2_logging_options(self) -> "Iot":
        '''(experimental) Grants permission to set the v2 logging options.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_SetV2LoggingOptions.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toSetV2LoggingOptions", []))

    @jsii.member(jsii_name="toStartAuditMitigationActionsTask")
    def to_start_audit_mitigation_actions_task(self) -> "Iot":
        '''(experimental) Grants permission to start a task that applies a set of mitigation actions to the specified target.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_StartAuditMitigationActionsTask.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toStartAuditMitigationActionsTask", []))

    @jsii.member(jsii_name="toStartDetectMitigationActionsTask")
    def to_start_detect_mitigation_actions_task(self) -> "Iot":
        '''(experimental) Grants permission to start a Device Defender ML Detect mitigation actions task.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_StartDetectMitigationActionsTask.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toStartDetectMitigationActionsTask", []))

    @jsii.member(jsii_name="toStartOnDemandAuditTask")
    def to_start_on_demand_audit_task(self) -> "Iot":
        '''(experimental) Grants permission to start an on-demand Device Defender audit.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_StartOnDemandAuditTask.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toStartOnDemandAuditTask", []))

    @jsii.member(jsii_name="toStartThingRegistrationTask")
    def to_start_thing_registration_task(self) -> "Iot":
        '''(experimental) Grants permission to start a bulk thing registration task.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_StartThingRegistrationTask.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toStartThingRegistrationTask", []))

    @jsii.member(jsii_name="toStopThingRegistrationTask")
    def to_stop_thing_registration_task(self) -> "Iot":
        '''(experimental) Grants permission to stop a bulk thing registration task.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_StopThingRegistrationTask.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toStopThingRegistrationTask", []))

    @jsii.member(jsii_name="toSubscribe")
    def to_subscribe(self) -> "Iot":
        '''(experimental) Grants permission to subscribe to the specified TopicFilter.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/developerguide/policy-actions.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toSubscribe", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Iot":
        '''(experimental) Grants permission to tag a specified resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/iot/latest/apireference/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toTestAuthorization")
    def to_test_authorization(self) -> "Iot":
        '''(experimental) Grants permission to test the policies evaluation for group policies.

        Access Level: Read

        https://docs.aws.amazon.com/iot/latest/apireference/API_TestAuthorization.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toTestAuthorization", []))

    @jsii.member(jsii_name="toTestInvokeAuthorizer")
    def to_test_invoke_authorizer(self) -> "Iot":
        '''(experimental) Grants permission to test invoke the specified custom authorizer for testing purposes.

        Access Level: Read

        https://docs.aws.amazon.com/iot/latest/apireference/API_TestInvokeAuthorizer.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toTestInvokeAuthorizer", []))

    @jsii.member(jsii_name="toTransferCertificate")
    def to_transfer_certificate(self) -> "Iot":
        '''(experimental) Grants permission to transfer the specified certificate to the specified AWS account.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_TransferCertificate.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toTransferCertificate", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Iot":
        '''(experimental) Grants permission to untag a specified resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/iot/latest/apireference/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateAccountAuditConfiguration")
    def to_update_account_audit_configuration(self) -> "Iot":
        '''(experimental) Grants permission to configure or reconfigure the Device Defender audit settings for this account.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_UpdateAccountAuditConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toUpdateAccountAuditConfiguration", []))

    @jsii.member(jsii_name="toUpdateAuditSuppression")
    def to_update_audit_suppression(self) -> "Iot":
        '''(experimental) Grants permission to update a Device Defender audit suppression.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_UpdateAuditSuppression.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toUpdateAuditSuppression", []))

    @jsii.member(jsii_name="toUpdateAuthorizer")
    def to_update_authorizer(self) -> "Iot":
        '''(experimental) Grants permission to update an authorizer.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_UpdateAuthorizer.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toUpdateAuthorizer", []))

    @jsii.member(jsii_name="toUpdateBillingGroup")
    def to_update_billing_group(self) -> "Iot":
        '''(experimental) Grants permission to update information associated with the specified billing group.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_UpdateBillingGroup.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toUpdateBillingGroup", []))

    @jsii.member(jsii_name="toUpdateCACertificate")
    def to_update_ca_certificate(self) -> "Iot":
        '''(experimental) Grants permission to update a registered CA certificate.

        Access Level: Write

        Dependent actions:

        - iam:PassRole

        https://docs.aws.amazon.com/iot/latest/apireference/API_UpdateCACertificate.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toUpdateCACertificate", []))

    @jsii.member(jsii_name="toUpdateCertificate")
    def to_update_certificate(self) -> "Iot":
        '''(experimental) Grants permission to update the status of the specified certificate. This operation is idempotent.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_UpdateCertificate.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toUpdateCertificate", []))

    @jsii.member(jsii_name="toUpdateCustomMetric")
    def to_update_custom_metric(self) -> "Iot":
        '''(experimental) Grants permission to update the specified custom metric.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_UpdateCustomMetric.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toUpdateCustomMetric", []))

    @jsii.member(jsii_name="toUpdateDimension")
    def to_update_dimension(self) -> "Iot":
        '''(experimental) Grants permission to update the definition for a dimension.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_UpdateDimension.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toUpdateDimension", []))

    @jsii.member(jsii_name="toUpdateDomainConfiguration")
    def to_update_domain_configuration(self) -> "Iot":
        '''(experimental) Grants permission to update a domain configuration.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_UpdateDomainConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toUpdateDomainConfiguration", []))

    @jsii.member(jsii_name="toUpdateDynamicThingGroup")
    def to_update_dynamic_thing_group(self) -> "Iot":
        '''(experimental) Grants permission to update a Dynamic Thing Group.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_UpdateDynamicThingGroup.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toUpdateDynamicThingGroup", []))

    @jsii.member(jsii_name="toUpdateEventConfigurations")
    def to_update_event_configurations(self) -> "Iot":
        '''(experimental) Grants permission to update event configurations.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_UpdateEventConfigurations.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toUpdateEventConfigurations", []))

    @jsii.member(jsii_name="toUpdateFleetMetric")
    def to_update_fleet_metric(self) -> "Iot":
        '''(experimental) Grants permission to update a fleet metric.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/iot-indexing.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toUpdateFleetMetric", []))

    @jsii.member(jsii_name="toUpdateIndexingConfiguration")
    def to_update_indexing_configuration(self) -> "Iot":
        '''(experimental) Grants permission to update fleet indexing configuration.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_UpdateIndexingConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toUpdateIndexingConfiguration", []))

    @jsii.member(jsii_name="toUpdateJob")
    def to_update_job(self) -> "Iot":
        '''(experimental) Grants permission to update a job.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_UpdateJob.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toUpdateJob", []))

    @jsii.member(jsii_name="toUpdateMitigationAction")
    def to_update_mitigation_action(self) -> "Iot":
        '''(experimental) Grants permission to update the definition for the specified mitigation action.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_UpdateMitigationAction.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toUpdateMitigationAction", []))

    @jsii.member(jsii_name="toUpdateProvisioningTemplate")
    def to_update_provisioning_template(self) -> "Iot":
        '''(experimental) Grants permission to update a fleet provisioning template.

        Access Level: Write

        Dependent actions:

        - iam:PassRole

        https://docs.aws.amazon.com/iot/latest/apireference/API_UpdateProvisioningTemplate.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toUpdateProvisioningTemplate", []))

    @jsii.member(jsii_name="toUpdateRoleAlias")
    def to_update_role_alias(self) -> "Iot":
        '''(experimental) Grants permission to update the role alias.

        Access Level: Write

        Dependent actions:

        - iam:PassRole

        https://docs.aws.amazon.com/iot/latest/apireference/API_UpdateRoleAlias.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toUpdateRoleAlias", []))

    @jsii.member(jsii_name="toUpdateScheduledAudit")
    def to_update_scheduled_audit(self) -> "Iot":
        '''(experimental) Grants permission to update a scheduled audit, including what checks are performed and how often the audit takes place.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_UpdateScheduledAudit.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toUpdateScheduledAudit", []))

    @jsii.member(jsii_name="toUpdateSecurityProfile")
    def to_update_security_profile(self) -> "Iot":
        '''(experimental) Grants permission to update a Device Defender security profile.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_UpdateSecurityProfile.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toUpdateSecurityProfile", []))

    @jsii.member(jsii_name="toUpdateStream")
    def to_update_stream(self) -> "Iot":
        '''(experimental) Grants permission to update the data for a stream.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_UpdateStream.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toUpdateStream", []))

    @jsii.member(jsii_name="toUpdateThing")
    def to_update_thing(self) -> "Iot":
        '''(experimental) Grants permission to update information associated with the specified thing.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_UpdateThing.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toUpdateThing", []))

    @jsii.member(jsii_name="toUpdateThingGroup")
    def to_update_thing_group(self) -> "Iot":
        '''(experimental) Grants permission to update information associated with the specified thing group.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_UpdateThingGroup.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toUpdateThingGroup", []))

    @jsii.member(jsii_name="toUpdateThingGroupsForThing")
    def to_update_thing_groups_for_thing(self) -> "Iot":
        '''(experimental) Grants permission to update the thing groups to which the thing belongs.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_UpdateThingGroupsForThing.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toUpdateThingGroupsForThing", []))

    @jsii.member(jsii_name="toUpdateThingShadow")
    def to_update_thing_shadow(self) -> "Iot":
        '''(experimental) Grants permission to update the thing shadow.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/developerguide/policy-actions.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toUpdateThingShadow", []))

    @jsii.member(jsii_name="toUpdateTopicRuleDestination")
    def to_update_topic_rule_destination(self) -> "Iot":
        '''(experimental) Grants permission to update a TopicRuleDestination.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_UpdateTopicRuleDestination.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toUpdateTopicRuleDestination", []))

    @jsii.member(jsii_name="toValidateSecurityProfileBehaviors")
    def to_validate_security_profile_behaviors(self) -> "Iot":
        '''(experimental) Grants permission to validate a Device Defender security profile behaviors specification.

        Access Level: Read

        https://docs.aws.amazon.com/iot/latest/apireference/API_ValidateSecurityProfileBehaviors.html

        :stability: experimental
        '''
        return typing.cast("Iot", jsii.invoke(self, "toValidateSecurityProfileBehaviors", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c63140d528698e0571d7ca60155c036136be15000f668548ce4b9bccbf819cad)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__144f0312868ff065a1c99ef045fc2863732e327cf4dafc6131312d7f11439397)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Iot1click(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Iot1click",
):
    '''(experimental) Statement provider for service `iot1click <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot1-click.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `iot1click <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot1-click.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onDevice")
    def on_device(
        self,
        device_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Iot1click":
        '''(experimental) Adds a resource of type device to the statement.

        https://docs.aws.amazon.com/iot-1-click/1.0/devices-apireference/resources.html

        :param device_id: - Identifier for the deviceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c278466e0f1a624d01926a3ad1949067795ef21171e8d16ece084a1934f20e5f)
            check_type(argname="argument device_id", value=device_id, expected_type=type_hints["device_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Iot1click", jsii.invoke(self, "onDevice", [device_id, account, region, partition]))

    @jsii.member(jsii_name="onProject")
    def on_project(
        self,
        project_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Iot1click":
        '''(experimental) Adds a resource of type project to the statement.

        https://docs.aws.amazon.com/iot-1-click/latest/projects-apireference/API_Operations.html

        :param project_name: - Identifier for the projectName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__80d2eae19ba42a76673f5192bfd67b45f63812e565f0c806bc121a50cae58973)
            check_type(argname="argument project_name", value=project_name, expected_type=type_hints["project_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Iot1click", jsii.invoke(self, "onProject", [project_name, account, region, partition]))

    @jsii.member(jsii_name="toAssociateDeviceWithPlacement")
    def to_associate_device_with_placement(self) -> "Iot1click":
        '''(experimental) Grants permission to associate a device to a placement.

        Access Level: Write

        https://docs.aws.amazon.com/iot-1-click/latest/projects-apireference/API_AssociateDeviceWithPlacement.html

        :stability: experimental
        '''
        return typing.cast("Iot1click", jsii.invoke(self, "toAssociateDeviceWithPlacement", []))

    @jsii.member(jsii_name="toClaimDevicesByClaimCode")
    def to_claim_devices_by_claim_code(self) -> "Iot1click":
        '''(experimental) Grants permission to claim a batch of devices with a claim code.

        Access Level: Read

        https://docs.aws.amazon.com/iot-1-click/1.0/devices-apireference/claims-claimcode.html

        :stability: experimental
        '''
        return typing.cast("Iot1click", jsii.invoke(self, "toClaimDevicesByClaimCode", []))

    @jsii.member(jsii_name="toCreatePlacement")
    def to_create_placement(self) -> "Iot1click":
        '''(experimental) Grants permission to create a new placement in a project.

        Access Level: Write

        https://docs.aws.amazon.com/iot-1-click/latest/projects-apireference/API_CreatePlacement.html

        :stability: experimental
        '''
        return typing.cast("Iot1click", jsii.invoke(self, "toCreatePlacement", []))

    @jsii.member(jsii_name="toCreateProject")
    def to_create_project(self) -> "Iot1click":
        '''(experimental) Grants permission to create a new project.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/iot-1-click/latest/projects-apireference/API_CreateProject.html

        :stability: experimental
        '''
        return typing.cast("Iot1click", jsii.invoke(self, "toCreateProject", []))

    @jsii.member(jsii_name="toDeletePlacement")
    def to_delete_placement(self) -> "Iot1click":
        '''(experimental) Grants permission to delete a placement from a project.

        Access Level: Write

        https://docs.aws.amazon.com/iot-1-click/latest/projects-apireference/API_DeletePlacement.html

        :stability: experimental
        '''
        return typing.cast("Iot1click", jsii.invoke(self, "toDeletePlacement", []))

    @jsii.member(jsii_name="toDeleteProject")
    def to_delete_project(self) -> "Iot1click":
        '''(experimental) Grants permission to delete a project.

        Access Level: Write

        https://docs.aws.amazon.com/iot-1-click/latest/projects-apireference/API_DeleteProject.html

        :stability: experimental
        '''
        return typing.cast("Iot1click", jsii.invoke(self, "toDeleteProject", []))

    @jsii.member(jsii_name="toDescribeDevice")
    def to_describe_device(self) -> "Iot1click":
        '''(experimental) Grants permission to describe a device.

        Access Level: Read

        https://docs.aws.amazon.com/iot-1-click/1.0/devices-apireference/devices-deviceid.html

        :stability: experimental
        '''
        return typing.cast("Iot1click", jsii.invoke(self, "toDescribeDevice", []))

    @jsii.member(jsii_name="toDescribePlacement")
    def to_describe_placement(self) -> "Iot1click":
        '''(experimental) Grants permission to describe a placement.

        Access Level: Read

        https://docs.aws.amazon.com/iot-1-click/latest/projects-apireference/API_DescribePlacement.html

        :stability: experimental
        '''
        return typing.cast("Iot1click", jsii.invoke(self, "toDescribePlacement", []))

    @jsii.member(jsii_name="toDescribeProject")
    def to_describe_project(self) -> "Iot1click":
        '''(experimental) Grants permission to describe a project.

        Access Level: Read

        https://docs.aws.amazon.com/iot-1-click/latest/projects-apireference/API_DescribeProject.html

        :stability: experimental
        '''
        return typing.cast("Iot1click", jsii.invoke(self, "toDescribeProject", []))

    @jsii.member(jsii_name="toDisassociateDeviceFromPlacement")
    def to_disassociate_device_from_placement(self) -> "Iot1click":
        '''(experimental) Grants permission to disassociate a device from a placement.

        Access Level: Write

        https://docs.aws.amazon.com/iot-1-click/latest/projects-apireference/API_DisassociateDeviceFromPlacement.html

        :stability: experimental
        '''
        return typing.cast("Iot1click", jsii.invoke(self, "toDisassociateDeviceFromPlacement", []))

    @jsii.member(jsii_name="toFinalizeDeviceClaim")
    def to_finalize_device_claim(self) -> "Iot1click":
        '''(experimental) Grants permission to finalize a device claim.

        Access Level: Read

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/iot-1-click/1.0/devices-apireference/devices-deviceid-finalize-claim.html

        :stability: experimental
        '''
        return typing.cast("Iot1click", jsii.invoke(self, "toFinalizeDeviceClaim", []))

    @jsii.member(jsii_name="toGetDeviceMethods")
    def to_get_device_methods(self) -> "Iot1click":
        '''(experimental) Grants permission to get available methods of a device.

        Access Level: Read

        https://docs.aws.amazon.com/iot-1-click/1.0/devices-apireference/devices-deviceid-methods.html

        :stability: experimental
        '''
        return typing.cast("Iot1click", jsii.invoke(self, "toGetDeviceMethods", []))

    @jsii.member(jsii_name="toGetDevicesInPlacement")
    def to_get_devices_in_placement(self) -> "Iot1click":
        '''(experimental) Grants permission to get devices associated to a placement.

        Access Level: Read

        https://docs.aws.amazon.com/iot-1-click/latest/projects-apireference/API_GetDevicesInPlacement.html

        :stability: experimental
        '''
        return typing.cast("Iot1click", jsii.invoke(self, "toGetDevicesInPlacement", []))

    @jsii.member(jsii_name="toInitiateDeviceClaim")
    def to_initiate_device_claim(self) -> "Iot1click":
        '''(experimental) Grants permission to initialize a device claim.

        Access Level: Read

        https://docs.aws.amazon.com/iot-1-click/1.0/devices-apireference/devices-deviceid-initiate-claim.html

        :stability: experimental
        '''
        return typing.cast("Iot1click", jsii.invoke(self, "toInitiateDeviceClaim", []))

    @jsii.member(jsii_name="toInvokeDeviceMethod")
    def to_invoke_device_method(self) -> "Iot1click":
        '''(experimental) Grants permission to invoke a device method.

        Access Level: Write

        https://docs.aws.amazon.com/iot-1-click/1.0/devices-apireference/devices-deviceid-methods.html

        :stability: experimental
        '''
        return typing.cast("Iot1click", jsii.invoke(self, "toInvokeDeviceMethod", []))

    @jsii.member(jsii_name="toListDeviceEvents")
    def to_list_device_events(self) -> "Iot1click":
        '''(experimental) Grants permission to list past events published by a device.

        Access Level: Read

        https://docs.aws.amazon.com/iot-1-click/1.0/devices-apireference/devices-deviceid-events.html

        :stability: experimental
        '''
        return typing.cast("Iot1click", jsii.invoke(self, "toListDeviceEvents", []))

    @jsii.member(jsii_name="toListDevices")
    def to_list_devices(self) -> "Iot1click":
        '''(experimental) Grants permission to list all devices.

        Access Level: List

        https://docs.aws.amazon.com/iot-1-click/1.0/devices-apireference/devices.html

        :stability: experimental
        '''
        return typing.cast("Iot1click", jsii.invoke(self, "toListDevices", []))

    @jsii.member(jsii_name="toListPlacements")
    def to_list_placements(self) -> "Iot1click":
        '''(experimental) Grants permission to list placements in a project.

        Access Level: Read

        https://docs.aws.amazon.com/iot-1-click/latest/projects-apireference/API_ListPlacements.html

        :stability: experimental
        '''
        return typing.cast("Iot1click", jsii.invoke(self, "toListPlacements", []))

    @jsii.member(jsii_name="toListProjects")
    def to_list_projects(self) -> "Iot1click":
        '''(experimental) Grants permission to list all projects.

        Access Level: List

        https://docs.aws.amazon.com/iot-1-click/latest/projects-apireference/API_ListProjects.html

        :stability: experimental
        '''
        return typing.cast("Iot1click", jsii.invoke(self, "toListProjects", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Iot1click":
        '''(experimental) Grants permission to lists the tags for a resource.

        Access Level: Read

        https://docs.aws.amazon.com/iot-1-click/latest/projects-apireference/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("Iot1click", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Iot1click":
        '''(experimental) Grants permission to add or modify the tags of a resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/iot-1-click/latest/projects-apireference/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("Iot1click", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUnclaimDevice")
    def to_unclaim_device(self) -> "Iot1click":
        '''(experimental) Grants permission to unclaim a device.

        Access Level: Read

        https://docs.aws.amazon.com/iot-1-click/1.0/devices-apireference/devices-deviceid-unclaim.html

        :stability: experimental
        '''
        return typing.cast("Iot1click", jsii.invoke(self, "toUnclaimDevice", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Iot1click":
        '''(experimental) Grants permission to remove the given tags (metadata) from a resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/iot-1-click/latest/projects-apireference/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("Iot1click", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateDeviceState")
    def to_update_device_state(self) -> "Iot1click":
        '''(experimental) Grants permission to update device state.

        Access Level: Write

        https://docs.aws.amazon.com/iot-1-click/1.0/devices-apireference/devices-deviceid-state.html

        :stability: experimental
        '''
        return typing.cast("Iot1click", jsii.invoke(self, "toUpdateDeviceState", []))

    @jsii.member(jsii_name="toUpdatePlacement")
    def to_update_placement(self) -> "Iot1click":
        '''(experimental) Grants permission to update a placement.

        Access Level: Write

        https://docs.aws.amazon.com/iot-1-click/latest/projects-apireference/API_UpdatePlacement.html

        :stability: experimental
        '''
        return typing.cast("Iot1click", jsii.invoke(self, "toUpdatePlacement", []))

    @jsii.member(jsii_name="toUpdateProject")
    def to_update_project(self) -> "Iot1click":
        '''(experimental) Update a project.

        Access Level: Write

        https://docs.aws.amazon.com/iot-1-click/latest/projects-apireference/API_UpdateProject.html

        :stability: experimental
        '''
        return typing.cast("Iot1click", jsii.invoke(self, "toUpdateProject", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__559b4a751c02c9a7189a423dade1f57f60dbe17ead270133dec0571e55783cb7)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__40c5a38bbfbc6e13e9351797c718faa7aeb2dec75b944101fcc922120232b54f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class IotDeviceTester(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.IotDeviceTester",
):
    '''(experimental) Statement provider for service `iot-device-tester <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiotdevicetester.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `iot-device-tester <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiotdevicetester.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="toCheckVersion")
    def to_check_version(self) -> "IotDeviceTester":
        '''(experimental) Grants permission to IoT Device Tester to check if a given set of product, test suite and device tester version are compatible.

        Access Level: Read

        https://docs.aws.amazon.com/freertos/latest/userguide/dev-tester-prereqs.html

        :stability: experimental
        '''
        return typing.cast("IotDeviceTester", jsii.invoke(self, "toCheckVersion", []))

    @jsii.member(jsii_name="toDownloadTestSuite")
    def to_download_test_suite(self) -> "IotDeviceTester":
        '''(experimental) Grants permission to IoT Device Tester to download compatible test suite versions.

        Access Level: Read

        https://docs.aws.amazon.com/freertos/latest/userguide/dev-tester-prereqs.html

        :stability: experimental
        '''
        return typing.cast("IotDeviceTester", jsii.invoke(self, "toDownloadTestSuite", []))

    @jsii.member(jsii_name="toLatestIdt")
    def to_latest_idt(self) -> "IotDeviceTester":
        '''(experimental) Grants permission to IoT Device Tester to get information on latest version of device tester available.

        Access Level: Read

        https://docs.aws.amazon.com/freertos/latest/userguide/dev-tester-prereqs.html

        :stability: experimental
        '''
        return typing.cast("IotDeviceTester", jsii.invoke(self, "toLatestIdt", []))

    @jsii.member(jsii_name="toSendMetrics")
    def to_send_metrics(self) -> "IotDeviceTester":
        '''(experimental) Grants permission to IoT Device Tester to send usage metrics on your behalf.

        Access Level: Write

        https://docs.aws.amazon.com/freertos/latest/userguide/dev-tester-prereqs.html

        :stability: experimental
        '''
        return typing.cast("IotDeviceTester", jsii.invoke(self, "toSendMetrics", []))

    @jsii.member(jsii_name="toSupportedVersion")
    def to_supported_version(self) -> "IotDeviceTester":
        '''(experimental) Grants permission to IoT Device Tester to get list of supported products and test suite versions.

        Access Level: Read

        https://docs.aws.amazon.com/freertos/latest/userguide/dev-tester-prereqs.html

        :stability: experimental
        '''
        return typing.cast("IotDeviceTester", jsii.invoke(self, "toSupportedVersion", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__639d4ec4a259e3e8f828a2c0a906b57ef48cf64b4c056c3ff30d97d104df0b6a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c9c4186dbb89989b6dc8cdadc65a77dee695544b92d066063f4035ea84158fb7)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Iotanalytics(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Iotanalytics",
):
    '''(experimental) Statement provider for service `iotanalytics <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiotanalytics.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `iotanalytics <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiotanalytics.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="ifResourceTag")
    def if_resource_tag(
        self,
        tag_key: builtins.str,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Iotanalytics":
        '''(experimental) Filters access by the tag key-value pairs attached to the resource.

        https://docs.aws.amazon.com/iotanalytics/latest/userguide/tagging.html#tagging-iam

        Applies to resource types:

        - channel
        - dataset
        - datastore
        - pipeline

        :param tag_key: The tag key to check.
        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9ce96b57783cbf03457f051479b29768b211c9d912a1bd14acae24bb77805e62)
            check_type(argname="argument tag_key", value=tag_key, expected_type=type_hints["tag_key"])
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Iotanalytics", jsii.invoke(self, "ifResourceTag", [tag_key, value, operator]))

    @jsii.member(jsii_name="onChannel")
    def on_channel(
        self,
        channel_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Iotanalytics":
        '''(experimental) Adds a resource of type channel to the statement.

        https://docs.aws.amazon.com/iotanalytics/latest/userguide/welcome.html#aws-iot-analytics-how

        :param channel_name: - Identifier for the channelName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsRequestTag() - .ifAwsTagKeys() - .ifResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__35786c03b88d61b92d8b0056d6d3e640fc5e7c519802e3fad5479c2f4fce2847)
            check_type(argname="argument channel_name", value=channel_name, expected_type=type_hints["channel_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Iotanalytics", jsii.invoke(self, "onChannel", [channel_name, account, region, partition]))

    @jsii.member(jsii_name="onDataset")
    def on_dataset(
        self,
        dataset_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Iotanalytics":
        '''(experimental) Adds a resource of type dataset to the statement.

        https://docs.aws.amazon.com/iotanalytics/latest/userguide/welcome.html#aws-iot-analytics-how

        :param dataset_name: - Identifier for the datasetName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsRequestTag() - .ifAwsTagKeys() - .ifResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__843ec61daf24d604d52c2d8f8a4fb2015601322794d2e7a11e5a5b213c24e188)
            check_type(argname="argument dataset_name", value=dataset_name, expected_type=type_hints["dataset_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Iotanalytics", jsii.invoke(self, "onDataset", [dataset_name, account, region, partition]))

    @jsii.member(jsii_name="onDatastore")
    def on_datastore(
        self,
        datastore_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Iotanalytics":
        '''(experimental) Adds a resource of type datastore to the statement.

        https://docs.aws.amazon.com/iotanalytics/latest/userguide/welcome.html#aws-iot-analytics-how

        :param datastore_name: - Identifier for the datastoreName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsRequestTag() - .ifAwsTagKeys() - .ifResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f7c1ffc39df3f8b9d5842fda71b1ee05c5242ca48079159a2a52c4a69beaeba4)
            check_type(argname="argument datastore_name", value=datastore_name, expected_type=type_hints["datastore_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Iotanalytics", jsii.invoke(self, "onDatastore", [datastore_name, account, region, partition]))

    @jsii.member(jsii_name="onPipeline")
    def on_pipeline(
        self,
        pipeline_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Iotanalytics":
        '''(experimental) Adds a resource of type pipeline to the statement.

        https://docs.aws.amazon.com/iotanalytics/latest/userguide/welcome.html#aws-iot-analytics-how

        :param pipeline_name: - Identifier for the pipelineName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsRequestTag() - .ifAwsTagKeys() - .ifResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b545b4e3ace20d9671a009c8acad80799ffaea797d55b0be463d566c532115d7)
            check_type(argname="argument pipeline_name", value=pipeline_name, expected_type=type_hints["pipeline_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Iotanalytics", jsii.invoke(self, "onPipeline", [pipeline_name, account, region, partition]))

    @jsii.member(jsii_name="toBatchPutMessage")
    def to_batch_put_message(self) -> "Iotanalytics":
        '''(experimental) Puts a batch of messages into the specified channel.

        Access Level: Write

        https://docs.aws.amazon.com/iotanalytics/latest/APIReference/API_BatchPutMessage.html

        :stability: experimental
        '''
        return typing.cast("Iotanalytics", jsii.invoke(self, "toBatchPutMessage", []))

    @jsii.member(jsii_name="toCancelPipelineReprocessing")
    def to_cancel_pipeline_reprocessing(self) -> "Iotanalytics":
        '''(experimental) Cancels reprocessing for the specified pipeline.

        Access Level: Write

        https://docs.aws.amazon.com/iotanalytics/latest/APIReference/API_CancelPipelineReprocessing.html

        :stability: experimental
        '''
        return typing.cast("Iotanalytics", jsii.invoke(self, "toCancelPipelineReprocessing", []))

    @jsii.member(jsii_name="toCreateChannel")
    def to_create_channel(self) -> "Iotanalytics":
        '''(experimental) Creates a channel.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/iotanalytics/latest/APIReference/API_CreateChannel.html

        :stability: experimental
        '''
        return typing.cast("Iotanalytics", jsii.invoke(self, "toCreateChannel", []))

    @jsii.member(jsii_name="toCreateDataset")
    def to_create_dataset(self) -> "Iotanalytics":
        '''(experimental) Creates a dataset.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/iotanalytics/latest/APIReference/API_CreateDataset.html

        :stability: experimental
        '''
        return typing.cast("Iotanalytics", jsii.invoke(self, "toCreateDataset", []))

    @jsii.member(jsii_name="toCreateDatasetContent")
    def to_create_dataset_content(self) -> "Iotanalytics":
        '''(experimental) Generates content from the specified dataset (by executing the dataset actions).

        Access Level: Write

        https://docs.aws.amazon.com/iotanalytics/latest/APIReference/API_CreateDatasetContent.html

        :stability: experimental
        '''
        return typing.cast("Iotanalytics", jsii.invoke(self, "toCreateDatasetContent", []))

    @jsii.member(jsii_name="toCreateDatastore")
    def to_create_datastore(self) -> "Iotanalytics":
        '''(experimental) Creates a datastore.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/iotanalytics/latest/APIReference/API_CreateDatastore.html

        :stability: experimental
        '''
        return typing.cast("Iotanalytics", jsii.invoke(self, "toCreateDatastore", []))

    @jsii.member(jsii_name="toCreatePipeline")
    def to_create_pipeline(self) -> "Iotanalytics":
        '''(experimental) Creates a pipeline.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/iotanalytics/latest/APIReference/API_CreatePipeline.html

        :stability: experimental
        '''
        return typing.cast("Iotanalytics", jsii.invoke(self, "toCreatePipeline", []))

    @jsii.member(jsii_name="toDeleteChannel")
    def to_delete_channel(self) -> "Iotanalytics":
        '''(experimental) Deletes the specified channel.

        Access Level: Write

        https://docs.aws.amazon.com/iotanalytics/latest/APIReference/API_DeleteChannel.html

        :stability: experimental
        '''
        return typing.cast("Iotanalytics", jsii.invoke(self, "toDeleteChannel", []))

    @jsii.member(jsii_name="toDeleteDataset")
    def to_delete_dataset(self) -> "Iotanalytics":
        '''(experimental) Deletes the specified dataset.

        Access Level: Write

        https://docs.aws.amazon.com/iotanalytics/latest/APIReference/API_DeleteDataset.html

        :stability: experimental
        '''
        return typing.cast("Iotanalytics", jsii.invoke(self, "toDeleteDataset", []))

    @jsii.member(jsii_name="toDeleteDatasetContent")
    def to_delete_dataset_content(self) -> "Iotanalytics":
        '''(experimental) Deletes the content of the specified dataset.

        Access Level: Write

        https://docs.aws.amazon.com/iotanalytics/latest/APIReference/API_DeleteDatasetContent.html

        :stability: experimental
        '''
        return typing.cast("Iotanalytics", jsii.invoke(self, "toDeleteDatasetContent", []))

    @jsii.member(jsii_name="toDeleteDatastore")
    def to_delete_datastore(self) -> "Iotanalytics":
        '''(experimental) Deletes the specified datastore.

        Access Level: Write

        https://docs.aws.amazon.com/iotanalytics/latest/APIReference/API_DeleteDatastore.html

        :stability: experimental
        '''
        return typing.cast("Iotanalytics", jsii.invoke(self, "toDeleteDatastore", []))

    @jsii.member(jsii_name="toDeletePipeline")
    def to_delete_pipeline(self) -> "Iotanalytics":
        '''(experimental) Deletes the specified pipeline.

        Access Level: Write

        https://docs.aws.amazon.com/iotanalytics/latest/APIReference/API_DeletePipeline.html

        :stability: experimental
        '''
        return typing.cast("Iotanalytics", jsii.invoke(self, "toDeletePipeline", []))

    @jsii.member(jsii_name="toDescribeChannel")
    def to_describe_channel(self) -> "Iotanalytics":
        '''(experimental) Describes the specified channel.

        Access Level: Read

        https://docs.aws.amazon.com/iotanalytics/latest/APIReference/API_DescribeChannel.html

        :stability: experimental
        '''
        return typing.cast("Iotanalytics", jsii.invoke(self, "toDescribeChannel", []))

    @jsii.member(jsii_name="toDescribeDataset")
    def to_describe_dataset(self) -> "Iotanalytics":
        '''(experimental) Describes the specified dataset.

        Access Level: Read

        https://docs.aws.amazon.com/iotanalytics/latest/APIReference/API_DescribeDataset.html

        :stability: experimental
        '''
        return typing.cast("Iotanalytics", jsii.invoke(self, "toDescribeDataset", []))

    @jsii.member(jsii_name="toDescribeDatastore")
    def to_describe_datastore(self) -> "Iotanalytics":
        '''(experimental) Describes the specified datastore.

        Access Level: Read

        https://docs.aws.amazon.com/iotanalytics/latest/APIReference/API_DescribeDatastore.html

        :stability: experimental
        '''
        return typing.cast("Iotanalytics", jsii.invoke(self, "toDescribeDatastore", []))

    @jsii.member(jsii_name="toDescribeLoggingOptions")
    def to_describe_logging_options(self) -> "Iotanalytics":
        '''(experimental) Describes logging options for the the account.

        Access Level: Read

        https://docs.aws.amazon.com/iotanalytics/latest/APIReference/API_DescribeLoggingOptions.html

        :stability: experimental
        '''
        return typing.cast("Iotanalytics", jsii.invoke(self, "toDescribeLoggingOptions", []))

    @jsii.member(jsii_name="toDescribePipeline")
    def to_describe_pipeline(self) -> "Iotanalytics":
        '''(experimental) Describes the specified pipeline.

        Access Level: Read

        https://docs.aws.amazon.com/iotanalytics/latest/APIReference/API_DescribePipeline.html

        :stability: experimental
        '''
        return typing.cast("Iotanalytics", jsii.invoke(self, "toDescribePipeline", []))

    @jsii.member(jsii_name="toGetDatasetContent")
    def to_get_dataset_content(self) -> "Iotanalytics":
        '''(experimental) Gets the content of the specified dataset.

        Access Level: Read

        https://docs.aws.amazon.com/iotanalytics/latest/APIReference/API_GetDatasetContent.html

        :stability: experimental
        '''
        return typing.cast("Iotanalytics", jsii.invoke(self, "toGetDatasetContent", []))

    @jsii.member(jsii_name="toListChannels")
    def to_list_channels(self) -> "Iotanalytics":
        '''(experimental) Lists the channels for the account.

        Access Level: List

        https://docs.aws.amazon.com/iotanalytics/latest/APIReference/API_ListChannels.html

        :stability: experimental
        '''
        return typing.cast("Iotanalytics", jsii.invoke(self, "toListChannels", []))

    @jsii.member(jsii_name="toListDatasetContents")
    def to_list_dataset_contents(self) -> "Iotanalytics":
        '''(experimental) Lists information about dataset contents that have been created.

        Access Level: List

        https://docs.aws.amazon.com/iotanalytics/latest/APIReference/API_ListDatasetContents.html

        :stability: experimental
        '''
        return typing.cast("Iotanalytics", jsii.invoke(self, "toListDatasetContents", []))

    @jsii.member(jsii_name="toListDatasets")
    def to_list_datasets(self) -> "Iotanalytics":
        '''(experimental) Lists the datasets for the account.

        Access Level: List

        https://docs.aws.amazon.com/iotanalytics/latest/APIReference/API_ListDatasets.html

        :stability: experimental
        '''
        return typing.cast("Iotanalytics", jsii.invoke(self, "toListDatasets", []))

    @jsii.member(jsii_name="toListDatastores")
    def to_list_datastores(self) -> "Iotanalytics":
        '''(experimental) Lists the datastores for the account.

        Access Level: List

        https://docs.aws.amazon.com/iotanalytics/latest/APIReference/API_ListDatastores.html

        :stability: experimental
        '''
        return typing.cast("Iotanalytics", jsii.invoke(self, "toListDatastores", []))

    @jsii.member(jsii_name="toListPipelines")
    def to_list_pipelines(self) -> "Iotanalytics":
        '''(experimental) Lists the pipelines for the account.

        Access Level: List

        https://docs.aws.amazon.com/iotanalytics/latest/APIReference/API_ListPipelines.html

        :stability: experimental
        '''
        return typing.cast("Iotanalytics", jsii.invoke(self, "toListPipelines", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Iotanalytics":
        '''(experimental) Lists the tags (metadata) which you have assigned to the resource.

        Access Level: Read

        https://docs.aws.amazon.com/iotanalytics/latest/APIReference/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("Iotanalytics", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toPutLoggingOptions")
    def to_put_logging_options(self) -> "Iotanalytics":
        '''(experimental) Puts logging options for the the account.

        Access Level: Write

        https://docs.aws.amazon.com/iotanalytics/latest/APIReference/API_PutLoggingOptions.html

        :stability: experimental
        '''
        return typing.cast("Iotanalytics", jsii.invoke(self, "toPutLoggingOptions", []))

    @jsii.member(jsii_name="toRunPipelineActivity")
    def to_run_pipeline_activity(self) -> "Iotanalytics":
        '''(experimental) Runs the specified pipeline activity.

        Access Level: Read

        https://docs.aws.amazon.com/iotanalytics/latest/APIReference/API_RunPipelineActivity.html

        :stability: experimental
        '''
        return typing.cast("Iotanalytics", jsii.invoke(self, "toRunPipelineActivity", []))

    @jsii.member(jsii_name="toSampleChannelData")
    def to_sample_channel_data(self) -> "Iotanalytics":
        '''(experimental) Samples the specified channel's data.

        Access Level: Read

        https://docs.aws.amazon.com/iotanalytics/latest/APIReference/API_SampleChannelData.html

        :stability: experimental
        '''
        return typing.cast("Iotanalytics", jsii.invoke(self, "toSampleChannelData", []))

    @jsii.member(jsii_name="toStartPipelineReprocessing")
    def to_start_pipeline_reprocessing(self) -> "Iotanalytics":
        '''(experimental) Starts reprocessing for the specified pipeline.

        Access Level: Write

        https://docs.aws.amazon.com/iotanalytics/latest/APIReference/API_StartPipelineReprocessing.html

        :stability: experimental
        '''
        return typing.cast("Iotanalytics", jsii.invoke(self, "toStartPipelineReprocessing", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Iotanalytics":
        '''(experimental) Adds to or modifies the tags of the given resource.

        Tags are metadata which can be used to manage a resource

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/iotanalytics/latest/APIReference/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("Iotanalytics", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Iotanalytics":
        '''(experimental) Removes the given tags (metadata) from the resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/iotanalytics/latest/APIReference/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("Iotanalytics", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateChannel")
    def to_update_channel(self) -> "Iotanalytics":
        '''(experimental) Updates the specified channel.

        Access Level: Write

        https://docs.aws.amazon.com/iotanalytics/latest/APIReference/API_UpdateChannel.html

        :stability: experimental
        '''
        return typing.cast("Iotanalytics", jsii.invoke(self, "toUpdateChannel", []))

    @jsii.member(jsii_name="toUpdateDataset")
    def to_update_dataset(self) -> "Iotanalytics":
        '''(experimental) Updates the specified dataset.

        Access Level: Write

        https://docs.aws.amazon.com/iotanalytics/latest/APIReference/API_UpdateDataset.html

        :stability: experimental
        '''
        return typing.cast("Iotanalytics", jsii.invoke(self, "toUpdateDataset", []))

    @jsii.member(jsii_name="toUpdateDatastore")
    def to_update_datastore(self) -> "Iotanalytics":
        '''(experimental) Updates the specified datastore.

        Access Level: Write

        https://docs.aws.amazon.com/iotanalytics/latest/APIReference/API_UpdateDatastore.html

        :stability: experimental
        '''
        return typing.cast("Iotanalytics", jsii.invoke(self, "toUpdateDatastore", []))

    @jsii.member(jsii_name="toUpdatePipeline")
    def to_update_pipeline(self) -> "Iotanalytics":
        '''(experimental) Updates the specified pipeline.

        Access Level: Write

        https://docs.aws.amazon.com/iotanalytics/latest/APIReference/API_UpdatePipeline.html

        :stability: experimental
        '''
        return typing.cast("Iotanalytics", jsii.invoke(self, "toUpdatePipeline", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0cbc35f845f9a2392fe6b00a304b1966f32a9396554fceef79cb669bfc7352e6)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a7fa2411144c92c4364a7bc032231ced70bffc224d35c91caa6011d694b9d7fa)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Iotdeviceadvisor(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Iotdeviceadvisor",
):
    '''(experimental) Statement provider for service `iotdeviceadvisor <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiotcoredeviceadvisor.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `iotdeviceadvisor <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiotcoredeviceadvisor.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onSuitedefinition")
    def on_suitedefinition(
        self,
        suite_definition_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Iotdeviceadvisor":
        '''(experimental) Adds a resource of type Suitedefinition to the statement.

        https://docs.aws.amazon.com/iot/latest/developerguide/device-advisor-workflow.html#device-advisor-workflow-create-suite-definition

        :param suite_definition_id: - Identifier for the suiteDefinitionId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__26498995465f382ca81c9fbbc83c61cbc259dc41ae024b8b8d104cc3f48954e3)
            check_type(argname="argument suite_definition_id", value=suite_definition_id, expected_type=type_hints["suite_definition_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Iotdeviceadvisor", jsii.invoke(self, "onSuitedefinition", [suite_definition_id, account, region, partition]))

    @jsii.member(jsii_name="onSuiterun")
    def on_suiterun(
        self,
        suite_definition_id: builtins.str,
        suite_run_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Iotdeviceadvisor":
        '''(experimental) Adds a resource of type Suiterun to the statement.

        https://docs.aws.amazon.com/iot/latest/developerguide/device-advisor-workflow.html#device-advisor-workflow-start-suite-run

        :param suite_definition_id: - Identifier for the suiteDefinitionId.
        :param suite_run_id: - Identifier for the suiteRunId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__dba29940ec294714c32e0ec84a2a35fdaabeae3d4bc0e45780e95bfaf4e6e989)
            check_type(argname="argument suite_definition_id", value=suite_definition_id, expected_type=type_hints["suite_definition_id"])
            check_type(argname="argument suite_run_id", value=suite_run_id, expected_type=type_hints["suite_run_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Iotdeviceadvisor", jsii.invoke(self, "onSuiterun", [suite_definition_id, suite_run_id, account, region, partition]))

    @jsii.member(jsii_name="toCreateSuiteDefinition")
    def to_create_suite_definition(self) -> "Iotdeviceadvisor":
        '''(experimental) Grants permission to create a suite definition.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/iot/latest/apireference/API_iotdeviceadvisor_CreateSuiteDefinition.html

        :stability: experimental
        '''
        return typing.cast("Iotdeviceadvisor", jsii.invoke(self, "toCreateSuiteDefinition", []))

    @jsii.member(jsii_name="toDeleteSuiteDefinition")
    def to_delete_suite_definition(self) -> "Iotdeviceadvisor":
        '''(experimental) Grants permission to delete a suite definition.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_iotdeviceadvisor_DeleteSuiteDefinition.html

        :stability: experimental
        '''
        return typing.cast("Iotdeviceadvisor", jsii.invoke(self, "toDeleteSuiteDefinition", []))

    @jsii.member(jsii_name="toGetEndpoint")
    def to_get_endpoint(self) -> "Iotdeviceadvisor":
        '''(experimental) Grants permission to get a Device Advisor endpoint.

        Access Level: Read

        https://docs.aws.amazon.com/iot/latest/apireference/API_iotdeviceadvisor_GetEndpoint.html

        :stability: experimental
        '''
        return typing.cast("Iotdeviceadvisor", jsii.invoke(self, "toGetEndpoint", []))

    @jsii.member(jsii_name="toGetSuiteDefinition")
    def to_get_suite_definition(self) -> "Iotdeviceadvisor":
        '''(experimental) Grants permission to get a suite definition.

        Access Level: Read

        https://docs.aws.amazon.com/iot/latest/apireference/API_iotdeviceadvisor_GetSuiteDefinition.html

        :stability: experimental
        '''
        return typing.cast("Iotdeviceadvisor", jsii.invoke(self, "toGetSuiteDefinition", []))

    @jsii.member(jsii_name="toGetSuiteRun")
    def to_get_suite_run(self) -> "Iotdeviceadvisor":
        '''(experimental) Grants permission to get a suite run.

        Access Level: Read

        https://docs.aws.amazon.com/iot/latest/apireference/API_iotdeviceadvisor_GetSuiteRun.html

        :stability: experimental
        '''
        return typing.cast("Iotdeviceadvisor", jsii.invoke(self, "toGetSuiteRun", []))

    @jsii.member(jsii_name="toGetSuiteRunReport")
    def to_get_suite_run_report(self) -> "Iotdeviceadvisor":
        '''(experimental) Grants permission to get the qualification report for a suite run.

        Access Level: Read

        https://docs.aws.amazon.com/iot/latest/apireference/API_iotdeviceadvisor_GetSuiteRunReport.html

        :stability: experimental
        '''
        return typing.cast("Iotdeviceadvisor", jsii.invoke(self, "toGetSuiteRunReport", []))

    @jsii.member(jsii_name="toListSuiteDefinitions")
    def to_list_suite_definitions(self) -> "Iotdeviceadvisor":
        '''(experimental) Grants permission to list suite definitions.

        Access Level: List

        https://docs.aws.amazon.com/iot/latest/apireference/API_iotdeviceadvisor_ListSuiteDefinitions.html

        :stability: experimental
        '''
        return typing.cast("Iotdeviceadvisor", jsii.invoke(self, "toListSuiteDefinitions", []))

    @jsii.member(jsii_name="toListSuiteRuns")
    def to_list_suite_runs(self) -> "Iotdeviceadvisor":
        '''(experimental) Grants permission to list suite runs.

        Access Level: List

        https://docs.aws.amazon.com/iot/latest/apireference/API_iotdeviceadvisor_ListSuiteRuns.html

        :stability: experimental
        '''
        return typing.cast("Iotdeviceadvisor", jsii.invoke(self, "toListSuiteRuns", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Iotdeviceadvisor":
        '''(experimental) Grants permission to list the tags (metadata) assigned to a resource.

        Access Level: Read

        https://docs.aws.amazon.com/iot/latest/apireference/API_iotdeviceadvisor_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("Iotdeviceadvisor", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toStartSuiteRun")
    def to_start_suite_run(self) -> "Iotdeviceadvisor":
        '''(experimental) Grants permission to start a suite run.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/iot/latest/apireference/API_iotdeviceadvisor_StartSuiteRun.html

        :stability: experimental
        '''
        return typing.cast("Iotdeviceadvisor", jsii.invoke(self, "toStartSuiteRun", []))

    @jsii.member(jsii_name="toStopSuiteRun")
    def to_stop_suite_run(self) -> "Iotdeviceadvisor":
        '''(experimental) Grants permission to stop a suite run.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_iotdeviceadvisor_StopSuiteRun.html

        :stability: experimental
        '''
        return typing.cast("Iotdeviceadvisor", jsii.invoke(self, "toStopSuiteRun", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Iotdeviceadvisor":
        '''(experimental) Grants permission to add to or modify the tags of the given resource.

        Tags are metadata which can be used to manage a resource

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/iot/latest/apireference/API_iotdeviceadvisor_TagResource.html

        :stability: experimental
        '''
        return typing.cast("Iotdeviceadvisor", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Iotdeviceadvisor":
        '''(experimental) Grants permission to remove the given tags (metadata) from a resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/iot/latest/apireference/API_iotdeviceadvisor_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("Iotdeviceadvisor", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateSuiteDefinition")
    def to_update_suite_definition(self) -> "Iotdeviceadvisor":
        '''(experimental) Grants permission to update a suite definition.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_iotdeviceadvisor_UpdateSuiteDefinition.html

        :stability: experimental
        '''
        return typing.cast("Iotdeviceadvisor", jsii.invoke(self, "toUpdateSuiteDefinition", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fe2faea11b37c67490547642c17f755c25f372007e13b7e7a4bf3f2b726044bf)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a9e1d04413c70dd8f5e7eeb178bba4582ab1b06d24c1a14466ea878b4ed74c9d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Iotevents(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Iotevents",
):
    '''(experimental) Statement provider for service `iotevents <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiotevents.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `iotevents <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiotevents.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="ifKeyValue")
    def if_key_value(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Iotevents":
        '''(experimental) Filters access by the instanceId (key-value) of the message.

        https://docs.aws.amazon.com/iotevents/latest/developerguide/security_iam_id-based-policy-examples.htmlsecurity_iam_service-with-iam-id-based-policies-conditionkeys

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5c2d117d63c1c8981fbf1fb5e3ebe5011e910ab0ebabb2870f000b7bc2742efd)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Iotevents", jsii.invoke(self, "ifKeyValue", [value, operator]))

    @jsii.member(jsii_name="onAlarmModel")
    def on_alarm_model(
        self,
        alarm_model_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Iotevents":
        '''(experimental) Adds a resource of type alarmModel to the statement.

        https://docs.aws.amazon.com/iotevents/latest/developerguide/iotevents-getting-started.html

        :param alarm_model_name: - Identifier for the alarmModelName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__40f00f543088f7d046fbd66211ba68a6c5f67fc7bbcc4250693afdb78f9fa027)
            check_type(argname="argument alarm_model_name", value=alarm_model_name, expected_type=type_hints["alarm_model_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Iotevents", jsii.invoke(self, "onAlarmModel", [alarm_model_name, account, region, partition]))

    @jsii.member(jsii_name="onDetectorModel")
    def on_detector_model(
        self,
        detector_model_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Iotevents":
        '''(experimental) Adds a resource of type detectorModel to the statement.

        https://docs.aws.amazon.com/iotevents/latest/developerguide/iotevents-getting-started.html

        :param detector_model_name: - Identifier for the detectorModelName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bd81e60c67a1879cb56fa949f631838ae5b366f6f8cbace7b496faec84d65f6b)
            check_type(argname="argument detector_model_name", value=detector_model_name, expected_type=type_hints["detector_model_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Iotevents", jsii.invoke(self, "onDetectorModel", [detector_model_name, account, region, partition]))

    @jsii.member(jsii_name="onInput")
    def on_input(
        self,
        input_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Iotevents":
        '''(experimental) Adds a resource of type input to the statement.

        https://docs.aws.amazon.com/iotevents/latest/developerguide/iotevents-getting-started.html

        :param input_name: - Identifier for the inputName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8651265098a6231873ee04ef71db43a2fadc1248d2650a87d0012a493c272d2b)
            check_type(argname="argument input_name", value=input_name, expected_type=type_hints["input_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Iotevents", jsii.invoke(self, "onInput", [input_name, account, region, partition]))

    @jsii.member(jsii_name="toBatchAcknowledgeAlarm")
    def to_batch_acknowledge_alarm(self) -> "Iotevents":
        '''(experimental) Grants permission to send one or more acknowledge action requests to AWS IoT Events.

        Access Level: Write

        https://docs.aws.amazon.com/iotevents/latest/apireference/API_iotevents-data_BatchAcknowledgeAlarm.html

        :stability: experimental
        '''
        return typing.cast("Iotevents", jsii.invoke(self, "toBatchAcknowledgeAlarm", []))

    @jsii.member(jsii_name="toBatchDeleteDetector")
    def to_batch_delete_detector(self) -> "Iotevents":
        '''(experimental) Grants permission to delete a detector instance within the AWS IoT Events system.

        Access Level: Write

        https://docs.aws.amazon.com/iotevents/latest/apireference/API_iotevents-data_BatchDeleteDetector.html

        :stability: experimental
        '''
        return typing.cast("Iotevents", jsii.invoke(self, "toBatchDeleteDetector", []))

    @jsii.member(jsii_name="toBatchDisableAlarm")
    def to_batch_disable_alarm(self) -> "Iotevents":
        '''(experimental) Grants permission to disable one or more alarm instances.

        Access Level: Write

        https://docs.aws.amazon.com/iotevents/latest/apireference/API_iotevents-data_BatchDisableAlarm.html

        :stability: experimental
        '''
        return typing.cast("Iotevents", jsii.invoke(self, "toBatchDisableAlarm", []))

    @jsii.member(jsii_name="toBatchEnableAlarm")
    def to_batch_enable_alarm(self) -> "Iotevents":
        '''(experimental) Grants permission to enable one or more alarm instances.

        Access Level: Write

        https://docs.aws.amazon.com/iotevents/latest/apireference/API_iotevents-data_BatchEnableAlarm.html

        :stability: experimental
        '''
        return typing.cast("Iotevents", jsii.invoke(self, "toBatchEnableAlarm", []))

    @jsii.member(jsii_name="toBatchPutMessage")
    def to_batch_put_message(self) -> "Iotevents":
        '''(experimental) Grants permission to send a set of messages to the AWS IoT Events system.

        Access Level: Write

        https://docs.aws.amazon.com/iotevents/latest/apireference/API_iotevents-data_BatchPutMessage.html

        :stability: experimental
        '''
        return typing.cast("Iotevents", jsii.invoke(self, "toBatchPutMessage", []))

    @jsii.member(jsii_name="toBatchResetAlarm")
    def to_batch_reset_alarm(self) -> "Iotevents":
        '''(experimental) Grants permission to reset one or more alarm instances.

        Access Level: Write

        https://docs.aws.amazon.com/iotevents/latest/apireference/API_iotevents-data_BatchResetAlarm.html

        :stability: experimental
        '''
        return typing.cast("Iotevents", jsii.invoke(self, "toBatchResetAlarm", []))

    @jsii.member(jsii_name="toBatchSnoozeAlarm")
    def to_batch_snooze_alarm(self) -> "Iotevents":
        '''(experimental) Grants permission to change one or more alarm instances to the snooze mode.

        Access Level: Write

        https://docs.aws.amazon.com/iotevents/latest/apireference/API_iotevents-data_BatchSnoozeAlarm.html

        :stability: experimental
        '''
        return typing.cast("Iotevents", jsii.invoke(self, "toBatchSnoozeAlarm", []))

    @jsii.member(jsii_name="toBatchUpdateDetector")
    def to_batch_update_detector(self) -> "Iotevents":
        '''(experimental) Grants permission to update a detector instance within the AWS IoT Events system.

        Access Level: Write

        https://docs.aws.amazon.com/iotevents/latest/apireference/API_iotevents-data_BatchUpdateDetector.html

        :stability: experimental
        '''
        return typing.cast("Iotevents", jsii.invoke(self, "toBatchUpdateDetector", []))

    @jsii.member(jsii_name="toCreateAlarmModel")
    def to_create_alarm_model(self) -> "Iotevents":
        '''(experimental) Grants permission to create an alarm model to monitor an AWS IoT Events input attribute or an AWS IoT SiteWise asset property.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/iotevents/latest/apireference/API_CreateAlarmModel.html

        :stability: experimental
        '''
        return typing.cast("Iotevents", jsii.invoke(self, "toCreateAlarmModel", []))

    @jsii.member(jsii_name="toCreateDetectorModel")
    def to_create_detector_model(self) -> "Iotevents":
        '''(experimental) Grants permission to create a detector model to monitor an AWS IoT Events input attribute.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/iotevents/latest/apireference/API_CreateDetectorModel.html

        :stability: experimental
        '''
        return typing.cast("Iotevents", jsii.invoke(self, "toCreateDetectorModel", []))

    @jsii.member(jsii_name="toCreateInput")
    def to_create_input(self) -> "Iotevents":
        '''(experimental) Grants permission to create an Input in IotEvents.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/iotevents/latest/apireference/API_CreateInput.html

        :stability: experimental
        '''
        return typing.cast("Iotevents", jsii.invoke(self, "toCreateInput", []))

    @jsii.member(jsii_name="toDeleteAlarmModel")
    def to_delete_alarm_model(self) -> "Iotevents":
        '''(experimental) Grants permission to delete an alarm model.

        Access Level: Write

        https://docs.aws.amazon.com/iotevents/latest/apireference/API_DeleteAlarmModel.html

        :stability: experimental
        '''
        return typing.cast("Iotevents", jsii.invoke(self, "toDeleteAlarmModel", []))

    @jsii.member(jsii_name="toDeleteDetectorModel")
    def to_delete_detector_model(self) -> "Iotevents":
        '''(experimental) Grants permission to delete a detector model.

        Access Level: Write

        https://docs.aws.amazon.com/iotevents/latest/apireference/API_DeleteDetectorModel.html

        :stability: experimental
        '''
        return typing.cast("Iotevents", jsii.invoke(self, "toDeleteDetectorModel", []))

    @jsii.member(jsii_name="toDeleteInput")
    def to_delete_input(self) -> "Iotevents":
        '''(experimental) Grants permission to delete an input.

        Access Level: Write

        https://docs.aws.amazon.com/iotevents/latest/apireference/API_DeleteInput.html

        :stability: experimental
        '''
        return typing.cast("Iotevents", jsii.invoke(self, "toDeleteInput", []))

    @jsii.member(jsii_name="toDescribeAlarm")
    def to_describe_alarm(self) -> "Iotevents":
        '''(experimental) Grants permission to retrieve information about an alarm instance.

        Access Level: Read

        https://docs.aws.amazon.com/iotevents/latest/apireference/API_iotevents-data_DescribeAlarm.html

        :stability: experimental
        '''
        return typing.cast("Iotevents", jsii.invoke(self, "toDescribeAlarm", []))

    @jsii.member(jsii_name="toDescribeAlarmModel")
    def to_describe_alarm_model(self) -> "Iotevents":
        '''(experimental) Grants permission to retrieve information about an alarm model.

        Access Level: Read

        https://docs.aws.amazon.com/iotevents/latest/apireference/API_DescribeAlarmModel.html

        :stability: experimental
        '''
        return typing.cast("Iotevents", jsii.invoke(self, "toDescribeAlarmModel", []))

    @jsii.member(jsii_name="toDescribeDetector")
    def to_describe_detector(self) -> "Iotevents":
        '''(experimental) Grants permission to retriev information about a detector instance.

        Access Level: Read

        https://docs.aws.amazon.com/iotevents/latest/apireference/API_iotevents-data_DescribeDetector.html

        :stability: experimental
        '''
        return typing.cast("Iotevents", jsii.invoke(self, "toDescribeDetector", []))

    @jsii.member(jsii_name="toDescribeDetectorModel")
    def to_describe_detector_model(self) -> "Iotevents":
        '''(experimental) Grants permission to retrieve information about a detector model.

        Access Level: Read

        https://docs.aws.amazon.com/iotevents/latest/apireference/API_DescribeDetectorModel.html

        :stability: experimental
        '''
        return typing.cast("Iotevents", jsii.invoke(self, "toDescribeDetectorModel", []))

    @jsii.member(jsii_name="toDescribeDetectorModelAnalysis")
    def to_describe_detector_model_analysis(self) -> "Iotevents":
        '''(experimental) Grants permission to retrieve the detector model analysis information.

        Access Level: Read

        https://docs.aws.amazon.com/iotevents/latest/apireference/API_DescribeDetectorModelAnalysis.html

        :stability: experimental
        '''
        return typing.cast("Iotevents", jsii.invoke(self, "toDescribeDetectorModelAnalysis", []))

    @jsii.member(jsii_name="toDescribeInput")
    def to_describe_input(self) -> "Iotevents":
        '''(experimental) Grants permission to retrieve an information about Input.

        Access Level: Read

        https://docs.aws.amazon.com/iotevents/latest/apireference/API_DescribeInput.html

        :stability: experimental
        '''
        return typing.cast("Iotevents", jsii.invoke(self, "toDescribeInput", []))

    @jsii.member(jsii_name="toDescribeLoggingOptions")
    def to_describe_logging_options(self) -> "Iotevents":
        '''(experimental) Grants permission to retrieve the current settings of the AWS IoT Events logging options.

        Access Level: Read

        https://docs.aws.amazon.com/iotevents/latest/apireference/API_DescribeLoggingOptions.html

        :stability: experimental
        '''
        return typing.cast("Iotevents", jsii.invoke(self, "toDescribeLoggingOptions", []))

    @jsii.member(jsii_name="toGetDetectorModelAnalysisResults")
    def to_get_detector_model_analysis_results(self) -> "Iotevents":
        '''(experimental) Grants permission to retrieve the detector model analysis results.

        Access Level: Read

        https://docs.aws.amazon.com/iotevents/latest/apireference/API_GetDetectorModelAnalysisResults.html

        :stability: experimental
        '''
        return typing.cast("Iotevents", jsii.invoke(self, "toGetDetectorModelAnalysisResults", []))

    @jsii.member(jsii_name="toListAlarmModels")
    def to_list_alarm_models(self) -> "Iotevents":
        '''(experimental) Grants permission to list the alarm models that you created.

        Access Level: List

        https://docs.aws.amazon.com/iotevents/latest/apireference/API_ListAlarmModels.html

        :stability: experimental
        '''
        return typing.cast("Iotevents", jsii.invoke(self, "toListAlarmModels", []))

    @jsii.member(jsii_name="toListAlarmModelVersions")
    def to_list_alarm_model_versions(self) -> "Iotevents":
        '''(experimental) Grants permission to list all the versions of an alarm model.

        Access Level: List

        https://docs.aws.amazon.com/iotevents/latest/apireference/API_ListAlarmModelVersions.html

        :stability: experimental
        '''
        return typing.cast("Iotevents", jsii.invoke(self, "toListAlarmModelVersions", []))

    @jsii.member(jsii_name="toListAlarms")
    def to_list_alarms(self) -> "Iotevents":
        '''(experimental) Grants permission to retrieve information about all alarm instances per alarmModel.

        Access Level: List

        https://docs.aws.amazon.com/iotevents/latest/apireference/API_iotevents-data_ListAlarms.html

        :stability: experimental
        '''
        return typing.cast("Iotevents", jsii.invoke(self, "toListAlarms", []))

    @jsii.member(jsii_name="toListDetectorModels")
    def to_list_detector_models(self) -> "Iotevents":
        '''(experimental) Grants permission to list the detector models that you created.

        Access Level: List

        https://docs.aws.amazon.com/iotevents/latest/apireference/API_ListDetectorModels.html

        :stability: experimental
        '''
        return typing.cast("Iotevents", jsii.invoke(self, "toListDetectorModels", []))

    @jsii.member(jsii_name="toListDetectorModelVersions")
    def to_list_detector_model_versions(self) -> "Iotevents":
        '''(experimental) Grants permission to list all the versions of a detector model.

        Access Level: List

        https://docs.aws.amazon.com/iotevents/latest/apireference/API_ListDetectorModelVersions.html

        :stability: experimental
        '''
        return typing.cast("Iotevents", jsii.invoke(self, "toListDetectorModelVersions", []))

    @jsii.member(jsii_name="toListDetectors")
    def to_list_detectors(self) -> "Iotevents":
        '''(experimental) Grants permission to retrieve information about all detector instances per detectormodel.

        Access Level: List

        https://docs.aws.amazon.com/iotevents/latest/apireference/API_iotevents-data_ListDetectors.html

        :stability: experimental
        '''
        return typing.cast("Iotevents", jsii.invoke(self, "toListDetectors", []))

    @jsii.member(jsii_name="toListInputRoutings")
    def to_list_input_routings(self) -> "Iotevents":
        '''(experimental) Grants permission to list one or more input routings.

        Access Level: List

        https://docs.aws.amazon.com/iotevents/latest/apireference/API_ListInputRoutings.html

        :stability: experimental
        '''
        return typing.cast("Iotevents", jsii.invoke(self, "toListInputRoutings", []))

    @jsii.member(jsii_name="toListInputs")
    def to_list_inputs(self) -> "Iotevents":
        '''(experimental) Grants permission to lists the inputs you have created.

        Access Level: List

        https://docs.aws.amazon.com/iotevents/latest/apireference/API_ListInputs.html

        :stability: experimental
        '''
        return typing.cast("Iotevents", jsii.invoke(self, "toListInputs", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Iotevents":
        '''(experimental) Grants permission to list the tags (metadata) which you have assigned to the resource.

        Access Level: Read

        https://docs.aws.amazon.com/iotevents/latest/apireference/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("Iotevents", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toPutLoggingOptions")
    def to_put_logging_options(self) -> "Iotevents":
        '''(experimental) Grants permission to set or update the AWS IoT Events logging options.

        Access Level: Write

        https://docs.aws.amazon.com/iotevents/latest/apireference/API_PutLoggingOptions.html

        :stability: experimental
        '''
        return typing.cast("Iotevents", jsii.invoke(self, "toPutLoggingOptions", []))

    @jsii.member(jsii_name="toStartDetectorModelAnalysis")
    def to_start_detector_model_analysis(self) -> "Iotevents":
        '''(experimental) Grants permission to start the detector model analysis.

        Access Level: Write

        https://docs.aws.amazon.com/iotevents/latest/apireference/API_StartDetectorModelAnalysis.html

        :stability: experimental
        '''
        return typing.cast("Iotevents", jsii.invoke(self, "toStartDetectorModelAnalysis", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Iotevents":
        '''(experimental) Grants permission to adds to or modifies the tags of the given resource.Tags are metadata which can be used to manage a resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/iotevents/latest/apireference/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("Iotevents", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Iotevents":
        '''(experimental) Grants permission to remove the given tags (metadata) from the resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/iotevents/latest/apireference/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("Iotevents", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateAlarmModel")
    def to_update_alarm_model(self) -> "Iotevents":
        '''(experimental) Grants permission to update an alarm model.

        Access Level: Write

        https://docs.aws.amazon.com/iotevents/latest/apireference/API_UpdateAlarmModel.html

        :stability: experimental
        '''
        return typing.cast("Iotevents", jsii.invoke(self, "toUpdateAlarmModel", []))

    @jsii.member(jsii_name="toUpdateDetectorModel")
    def to_update_detector_model(self) -> "Iotevents":
        '''(experimental) Grants permission to update a detector model.

        Access Level: Write

        https://docs.aws.amazon.com/iotevents/latest/apireference/API_UpdateDetectorModel.html

        :stability: experimental
        '''
        return typing.cast("Iotevents", jsii.invoke(self, "toUpdateDetectorModel", []))

    @jsii.member(jsii_name="toUpdateInput")
    def to_update_input(self) -> "Iotevents":
        '''(experimental) Grants permission to update an input.

        Access Level: Write

        https://docs.aws.amazon.com/iotevents/latest/apireference/API_UpdateInput.html

        :stability: experimental
        '''
        return typing.cast("Iotevents", jsii.invoke(self, "toUpdateInput", []))

    @jsii.member(jsii_name="toUpdateInputRouting")
    def to_update_input_routing(self) -> "Iotevents":
        '''(experimental) Grants permission to update input routing.

        Access Level: Write

        https://docs.aws.amazon.com/iotevents/latest/apireference/API_UpdateInputRouting.html

        :stability: experimental
        '''
        return typing.cast("Iotevents", jsii.invoke(self, "toUpdateInputRouting", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8d953be9257b4c2113792e76f965715d068d20ec1056f1898bacf6e9bb39f935)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9ddd589fece652954a841f1829fc7836d11f8ce848b75fa5efcd67ac5f416876)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Iotfleethub(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Iotfleethub",
):
    '''(experimental) Statement provider for service `iotfleethub <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiotfleethubfordevicemanagement.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `iotfleethub <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiotfleethubfordevicemanagement.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onApplication")
    def on_application(
        self,
        application_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Iotfleethub":
        '''(experimental) Adds a resource of type application to the statement.

        https://docs.aws.amazon.com/iot/latest/apireference/API_iotfleethub_ApplicationSummary.html

        :param application_id: - Identifier for the applicationId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__266d3d8bdd15f87c2ac7758b5fdd21ee347127b81ca61cd41ba7db01d360a671)
            check_type(argname="argument application_id", value=application_id, expected_type=type_hints["application_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Iotfleethub", jsii.invoke(self, "onApplication", [application_id, account, region, partition]))

    @jsii.member(jsii_name="toCreateApplication")
    def to_create_application(self) -> "Iotfleethub":
        '''(experimental) Grants permission to create an application.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - sso:CreateManagedApplicationInstance
        - sso:DescribeRegisteredRegions

        https://docs.aws.amazon.com/iot/latest/apireference/API_iotfleethub_CreateApplication.html

        :stability: experimental
        '''
        return typing.cast("Iotfleethub", jsii.invoke(self, "toCreateApplication", []))

    @jsii.member(jsii_name="toDeleteApplication")
    def to_delete_application(self) -> "Iotfleethub":
        '''(experimental) Grants permission to delete an application.

        Access Level: Write

        Dependent actions:

        - sso:DeleteManagedApplicationInstance

        https://docs.aws.amazon.com/iot/latest/apireference/API_iotfleethub_DeleteApplication.html

        :stability: experimental
        '''
        return typing.cast("Iotfleethub", jsii.invoke(self, "toDeleteApplication", []))

    @jsii.member(jsii_name="toDescribeApplication")
    def to_describe_application(self) -> "Iotfleethub":
        '''(experimental) Grants permission to describe an application.

        Access Level: Read

        https://docs.aws.amazon.com/iot/latest/apireference/API_iotfleethub_DescribeApplication.html

        :stability: experimental
        '''
        return typing.cast("Iotfleethub", jsii.invoke(self, "toDescribeApplication", []))

    @jsii.member(jsii_name="toListApplications")
    def to_list_applications(self) -> "Iotfleethub":
        '''(experimental) Grants permission to list all applications.

        Access Level: List

        https://docs.aws.amazon.com/iot/latest/apireference/API_iotfleethub_ListApplications.html

        :stability: experimental
        '''
        return typing.cast("Iotfleethub", jsii.invoke(self, "toListApplications", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Iotfleethub":
        '''(experimental) Grants permission to list all tags for a resource.

        Access Level: Read

        https://docs.aws.amazon.com/iot/latest/apireference/API_iotfleethub_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("Iotfleethub", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Iotfleethub":
        '''(experimental) Grants permission to tag a resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/iot/latest/apireference/API_iotfleethub_TagResource.html

        :stability: experimental
        '''
        return typing.cast("Iotfleethub", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Iotfleethub":
        '''(experimental) Grants permission to untag a resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/iot/latest/apireference/API_iotfleethub_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("Iotfleethub", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateApplication")
    def to_update_application(self) -> "Iotfleethub":
        '''(experimental) Grants permission to update an application.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_iotfleethub_UpdateApplication.html

        :stability: experimental
        '''
        return typing.cast("Iotfleethub", jsii.invoke(self, "toUpdateApplication", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b6d7ebbd23c61f714e212cf9c410cd863973c2122b225dba8353533c6e7a1b50)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1d4eb8c3b58062d80bf2924b7121d887d95a46d4ce1b2d03922d340cf0a2d47c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Iotfleetwise(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Iotfleetwise",
):
    '''(experimental) Statement provider for service `iotfleetwise <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiotfleetwise.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `iotfleetwise <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiotfleetwise.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="ifUpdateToDecoderManifestArn")
    def if_update_to_decoder_manifest_arn(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Iotfleetwise":
        '''(experimental) Filters access by a list of IoT FleetWise Decoder Manifest ARNs.

        https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiotfleetwise.html

        Applies to actions:

        - .toUpdateVehicle()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9ca388bb6e4a425713de2539ea17ae0af8d44659800ff560ef3ef7048d3f9a0a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Iotfleetwise", jsii.invoke(self, "ifUpdateToDecoderManifestArn", [value, operator]))

    @jsii.member(jsii_name="ifUpdateToModelManifestArn")
    def if_update_to_model_manifest_arn(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Iotfleetwise":
        '''(experimental) Filters access by a list of IoT FleetWise Model Manifest ARNs.

        https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiotfleetwise.html

        Applies to actions:

        - .toUpdateVehicle()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e74b42aff11fc894b29f92bcca8481cfb6eca97e8562aab3845c2528f03e3f5d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Iotfleetwise", jsii.invoke(self, "ifUpdateToModelManifestArn", [value, operator]))

    @jsii.member(jsii_name="onCampaign")
    def on_campaign(
        self,
        campaign_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Iotfleetwise":
        '''(experimental) Adds a resource of type campaign to the statement.

        https://docs.aws.amazon.com/iot-fleetwise/latest/developerguide/campaigns.html

        :param campaign_name: - Identifier for the campaignName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c232dfea50a092e8a1d21151ff3910fba324004212ea65bfd7f92c66931c2c66)
            check_type(argname="argument campaign_name", value=campaign_name, expected_type=type_hints["campaign_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Iotfleetwise", jsii.invoke(self, "onCampaign", [campaign_name, account, region, partition]))

    @jsii.member(jsii_name="onDecodermanifest")
    def on_decodermanifest(
        self,
        name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Iotfleetwise":
        '''(experimental) Adds a resource of type decodermanifest to the statement.

        https://docs.aws.amazon.com/iot-fleetwise/latest/developerguide/decoder-manifests.html

        :param name: - Identifier for the name.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__da36a3330ed4cbabc404dc451cc4e96c0aa41daa567cbaddc80b1fa46673fb18)
            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Iotfleetwise", jsii.invoke(self, "onDecodermanifest", [name, account, region, partition]))

    @jsii.member(jsii_name="onFleet")
    def on_fleet(
        self,
        fleet_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Iotfleetwise":
        '''(experimental) Adds a resource of type fleet to the statement.

        https://docs.aws.amazon.com/iot-fleetwise/latest/developerguide/fleets.html

        :param fleet_id: - Identifier for the fleetId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__36531c889c04afbde1311ab455f4315c3a39ec60cebef2f03951d04660854fe0)
            check_type(argname="argument fleet_id", value=fleet_id, expected_type=type_hints["fleet_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Iotfleetwise", jsii.invoke(self, "onFleet", [fleet_id, account, region, partition]))

    @jsii.member(jsii_name="onModelmanifest")
    def on_modelmanifest(
        self,
        name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Iotfleetwise":
        '''(experimental) Adds a resource of type modelmanifest to the statement.

        https://docs.aws.amazon.com/iot-fleetwise/latest/developerguide/vehicle-models.html

        :param name: - Identifier for the name.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2f82986e9d49ff84ab4679eba9c8c9351ebb459ac49034e892e988dc8d9da7a3)
            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Iotfleetwise", jsii.invoke(self, "onModelmanifest", [name, account, region, partition]))

    @jsii.member(jsii_name="onSignalcatalog")
    def on_signalcatalog(
        self,
        name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Iotfleetwise":
        '''(experimental) Adds a resource of type signalcatalog to the statement.

        https://docs.aws.amazon.com/iot-fleetwise/latest/developerguide/signal-catalogs.html

        :param name: - Identifier for the name.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__574ffbcb6206e50a14e993fcae5e97579b60386d776d3f698f757cdb8da7fbfd)
            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Iotfleetwise", jsii.invoke(self, "onSignalcatalog", [name, account, region, partition]))

    @jsii.member(jsii_name="onVehicle")
    def on_vehicle(
        self,
        vehicle_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Iotfleetwise":
        '''(experimental) Adds a resource of type vehicle to the statement.

        https://docs.aws.amazon.com/iot-fleetwise/latest/developerguide/vehicles.html

        :param vehicle_id: - Identifier for the vehicleId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c8dda316b862089163b773db7cd134a3f6b3041a8896af459514e0dda22e409c)
            check_type(argname="argument vehicle_id", value=vehicle_id, expected_type=type_hints["vehicle_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Iotfleetwise", jsii.invoke(self, "onVehicle", [vehicle_id, account, region, partition]))

    @jsii.member(jsii_name="toAssociateVehicleFleet")
    def to_associate_vehicle_fleet(self) -> "Iotfleetwise":
        '''(experimental) Grants permission to associate the given vehicle to a fleet.

        Access Level: Write

        https://docs.aws.amazon.com/iot-fleetwise/latest/APIReference/API_AssociateVehicleFleet.html

        :stability: experimental
        '''
        return typing.cast("Iotfleetwise", jsii.invoke(self, "toAssociateVehicleFleet", []))

    @jsii.member(jsii_name="toCreateCampaign")
    def to_create_campaign(self) -> "Iotfleetwise":
        '''(experimental) Grants permission to create a campaign.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/iot-fleetwise/latest/APIReference/API_CreateCampaign.html

        :stability: experimental
        '''
        return typing.cast("Iotfleetwise", jsii.invoke(self, "toCreateCampaign", []))

    @jsii.member(jsii_name="toCreateDecoderManifest")
    def to_create_decoder_manifest(self) -> "Iotfleetwise":
        '''(experimental) Grants permission to create a decoder manifest for an existing model.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/iot-fleetwise/latest/APIReference/API_CreateDecoderManifest.html

        :stability: experimental
        '''
        return typing.cast("Iotfleetwise", jsii.invoke(self, "toCreateDecoderManifest", []))

    @jsii.member(jsii_name="toCreateFleet")
    def to_create_fleet(self) -> "Iotfleetwise":
        '''(experimental) Grants permission to create a fleet.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/iot-fleetwise/latest/APIReference/API_CreateFleet.html

        :stability: experimental
        '''
        return typing.cast("Iotfleetwise", jsii.invoke(self, "toCreateFleet", []))

    @jsii.member(jsii_name="toCreateModelManifest")
    def to_create_model_manifest(self) -> "Iotfleetwise":
        '''(experimental) Grants permission to create a model manifest definition.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/iot-fleetwise/latest/APIReference/API_CreateModelManifest.html

        :stability: experimental
        '''
        return typing.cast("Iotfleetwise", jsii.invoke(self, "toCreateModelManifest", []))

    @jsii.member(jsii_name="toCreateSignalCatalog")
    def to_create_signal_catalog(self) -> "Iotfleetwise":
        '''(experimental) Grants permission to create a signal catalog.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/iot-fleetwise/latest/APIReference/API_CreateSignalCatalog.html

        :stability: experimental
        '''
        return typing.cast("Iotfleetwise", jsii.invoke(self, "toCreateSignalCatalog", []))

    @jsii.member(jsii_name="toCreateVehicle")
    def to_create_vehicle(self) -> "Iotfleetwise":
        '''(experimental) Grants permission to create a vehicle.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - iot:CreateThing
        - iot:DescribeThing

        https://docs.aws.amazon.com/iot-fleetwise/latest/APIReference/API_CreateVehicle.html

        :stability: experimental
        '''
        return typing.cast("Iotfleetwise", jsii.invoke(self, "toCreateVehicle", []))

    @jsii.member(jsii_name="toDeleteCampaign")
    def to_delete_campaign(self) -> "Iotfleetwise":
        '''(experimental) Grants permission to delete a campaign.

        Access Level: Write

        https://docs.aws.amazon.com/iot-fleetwise/latest/APIReference/API_DeleteCampaign.html

        :stability: experimental
        '''
        return typing.cast("Iotfleetwise", jsii.invoke(self, "toDeleteCampaign", []))

    @jsii.member(jsii_name="toDeleteDecoderManifest")
    def to_delete_decoder_manifest(self) -> "Iotfleetwise":
        '''(experimental) Grants permission to delete the given decoder manifest.

        Access Level: Write

        https://docs.aws.amazon.com/iot-fleetwise/latest/APIReference/API_DeleteDecoderManifest.html

        :stability: experimental
        '''
        return typing.cast("Iotfleetwise", jsii.invoke(self, "toDeleteDecoderManifest", []))

    @jsii.member(jsii_name="toDeleteFleet")
    def to_delete_fleet(self) -> "Iotfleetwise":
        '''(experimental) Grants permission to delete a fleet.

        Access Level: Write

        https://docs.aws.amazon.com/iot-fleetwise/latest/APIReference/API_DeleteFleet.html

        :stability: experimental
        '''
        return typing.cast("Iotfleetwise", jsii.invoke(self, "toDeleteFleet", []))

    @jsii.member(jsii_name="toDeleteModelManifest")
    def to_delete_model_manifest(self) -> "Iotfleetwise":
        '''(experimental) Grants permission to delete the given model manifest.

        Access Level: Write

        https://docs.aws.amazon.com/iot-fleetwise/latest/APIReference/API_DeleteModelManifest.html

        :stability: experimental
        '''
        return typing.cast("Iotfleetwise", jsii.invoke(self, "toDeleteModelManifest", []))

    @jsii.member(jsii_name="toDeleteSignalCatalog")
    def to_delete_signal_catalog(self) -> "Iotfleetwise":
        '''(experimental) Grants permission to delete a specific signal catalog.

        Access Level: Write

        https://docs.aws.amazon.com/iot-fleetwise/latest/APIReference/API_DeleteSignalCatalog.html

        :stability: experimental
        '''
        return typing.cast("Iotfleetwise", jsii.invoke(self, "toDeleteSignalCatalog", []))

    @jsii.member(jsii_name="toDeleteVehicle")
    def to_delete_vehicle(self) -> "Iotfleetwise":
        '''(experimental) Grants permission to delete a vehicle.

        Access Level: Write

        https://docs.aws.amazon.com/iot-fleetwise/latest/APIReference/API_DeleteVehicle.html

        :stability: experimental
        '''
        return typing.cast("Iotfleetwise", jsii.invoke(self, "toDeleteVehicle", []))

    @jsii.member(jsii_name="toDisassociateVehicleFleet")
    def to_disassociate_vehicle_fleet(self) -> "Iotfleetwise":
        '''(experimental) Grants permission to disassociate a vehicle from an existing fleet.

        Access Level: Write

        https://docs.aws.amazon.com/iot-fleetwise/latest/APIReference/API_DisassociateVehicleFleet.html

        :stability: experimental
        '''
        return typing.cast("Iotfleetwise", jsii.invoke(self, "toDisassociateVehicleFleet", []))

    @jsii.member(jsii_name="toGetCampaign")
    def to_get_campaign(self) -> "Iotfleetwise":
        '''(experimental) Grants permission to get summary information for a given campaign.

        Access Level: Read

        https://docs.aws.amazon.com/iot-fleetwise/latest/APIReference/API_GetCampaign.html

        :stability: experimental
        '''
        return typing.cast("Iotfleetwise", jsii.invoke(self, "toGetCampaign", []))

    @jsii.member(jsii_name="toGetDecoderManifest")
    def to_get_decoder_manifest(self) -> "Iotfleetwise":
        '''(experimental) Grants permission to get summary information for a given decoder manifest definition.

        Access Level: Read

        https://docs.aws.amazon.com/iot-fleetwise/latest/APIReference/API_GetDecoderManifest.html

        :stability: experimental
        '''
        return typing.cast("Iotfleetwise", jsii.invoke(self, "toGetDecoderManifest", []))

    @jsii.member(jsii_name="toGetFleet")
    def to_get_fleet(self) -> "Iotfleetwise":
        '''(experimental) Grants permission to get summary information for a fleet.

        Access Level: Read

        https://docs.aws.amazon.com/iot-fleetwise/latest/APIReference/API_GetFleet.html

        :stability: experimental
        '''
        return typing.cast("Iotfleetwise", jsii.invoke(self, "toGetFleet", []))

    @jsii.member(jsii_name="toGetLoggingOptions")
    def to_get_logging_options(self) -> "Iotfleetwise":
        '''(experimental) Grants permission to get the logging options for the AWS account.

        Access Level: Read

        https://docs.aws.amazon.com/iot-fleetwise/latest/APIReference/API_GetLoggingOptions.html

        :stability: experimental
        '''
        return typing.cast("Iotfleetwise", jsii.invoke(self, "toGetLoggingOptions", []))

    @jsii.member(jsii_name="toGetModelManifest")
    def to_get_model_manifest(self) -> "Iotfleetwise":
        '''(experimental) Grants permission to get summary information for a given model manifest definition.

        Access Level: Read

        https://docs.aws.amazon.com/iot-fleetwise/latest/APIReference/API_GetModelManifest.html

        :stability: experimental
        '''
        return typing.cast("Iotfleetwise", jsii.invoke(self, "toGetModelManifest", []))

    @jsii.member(jsii_name="toGetRegisterAccountStatus")
    def to_get_register_account_status(self) -> "Iotfleetwise":
        '''(experimental) Grants permission to get the account registration status with IoT FleetWise.

        Access Level: Read

        https://docs.aws.amazon.com/iot-fleetwise/latest/APIReference/API_GetRegisterAccountStatus.html

        :stability: experimental
        '''
        return typing.cast("Iotfleetwise", jsii.invoke(self, "toGetRegisterAccountStatus", []))

    @jsii.member(jsii_name="toGetSignalCatalog")
    def to_get_signal_catalog(self) -> "Iotfleetwise":
        '''(experimental) Grants permission to get summary information for a specific signal catalog.

        Access Level: Read

        https://docs.aws.amazon.com/iot-fleetwise/latest/APIReference/API_GetSignalCatalog.html

        :stability: experimental
        '''
        return typing.cast("Iotfleetwise", jsii.invoke(self, "toGetSignalCatalog", []))

    @jsii.member(jsii_name="toGetVehicle")
    def to_get_vehicle(self) -> "Iotfleetwise":
        '''(experimental) Grants permission to get summary information for a vehicle.

        Access Level: Read

        https://docs.aws.amazon.com/iot-fleetwise/latest/APIReference/API_GetVehicle.html

        :stability: experimental
        '''
        return typing.cast("Iotfleetwise", jsii.invoke(self, "toGetVehicle", []))

    @jsii.member(jsii_name="toGetVehicleStatus")
    def to_get_vehicle_status(self) -> "Iotfleetwise":
        '''(experimental) Grants permission to get the status of the campaigns running on a specific vehicle.

        Access Level: Read

        https://docs.aws.amazon.com/iot-fleetwise/latest/APIReference/API_GetVehicleStatus.html

        :stability: experimental
        '''
        return typing.cast("Iotfleetwise", jsii.invoke(self, "toGetVehicleStatus", []))

    @jsii.member(jsii_name="toImportDecoderManifest")
    def to_import_decoder_manifest(self) -> "Iotfleetwise":
        '''(experimental) Grants permission to import an existing decoder manifest.

        Access Level: Write

        https://docs.aws.amazon.com/iot-fleetwise/latest/APIReference/API_ImportDecoderManifest.html

        :stability: experimental
        '''
        return typing.cast("Iotfleetwise", jsii.invoke(self, "toImportDecoderManifest", []))

    @jsii.member(jsii_name="toImportSignalCatalog")
    def to_import_signal_catalog(self) -> "Iotfleetwise":
        '''(experimental) Grants permission to create a signal catalog by importing existing definitions.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/iot-fleetwise/latest/APIReference/API_ImportSignalCatalog.html

        :stability: experimental
        '''
        return typing.cast("Iotfleetwise", jsii.invoke(self, "toImportSignalCatalog", []))

    @jsii.member(jsii_name="toListCampaigns")
    def to_list_campaigns(self) -> "Iotfleetwise":
        '''(experimental) Grants permission to list campaigns.

        Access Level: Read

        https://docs.aws.amazon.com/iot-fleetwise/latest/APIReference/API_ListCampaigns.html

        :stability: experimental
        '''
        return typing.cast("Iotfleetwise", jsii.invoke(self, "toListCampaigns", []))

    @jsii.member(jsii_name="toListDecoderManifestNetworkInterfaces")
    def to_list_decoder_manifest_network_interfaces(self) -> "Iotfleetwise":
        '''(experimental) Grants permission to list network interfaces associated to the existing decoder manifest.

        Access Level: List

        https://docs.aws.amazon.com/iot-fleetwise/latest/APIReference/API_ListDecoderManifestNetworkInterfaces.html

        :stability: experimental
        '''
        return typing.cast("Iotfleetwise", jsii.invoke(self, "toListDecoderManifestNetworkInterfaces", []))

    @jsii.member(jsii_name="toListDecoderManifests")
    def to_list_decoder_manifests(self) -> "Iotfleetwise":
        '''(experimental) Grants permission to list all decoder manifests, with an optional filter on model manifest.

        Access Level: Read

        https://docs.aws.amazon.com/iot-fleetwise/latest/APIReference/API_ListDecoderManifests.html

        :stability: experimental
        '''
        return typing.cast("Iotfleetwise", jsii.invoke(self, "toListDecoderManifests", []))

    @jsii.member(jsii_name="toListDecoderManifestSignals")
    def to_list_decoder_manifest_signals(self) -> "Iotfleetwise":
        '''(experimental) Grants permission to list decoder manifest signals.

        Access Level: List

        https://docs.aws.amazon.com/iot-fleetwise/latest/APIReference/API_ListDecoderManifestSignals.html

        :stability: experimental
        '''
        return typing.cast("Iotfleetwise", jsii.invoke(self, "toListDecoderManifestSignals", []))

    @jsii.member(jsii_name="toListFleets")
    def to_list_fleets(self) -> "Iotfleetwise":
        '''(experimental) Grants permission to list all fleets.

        Access Level: Read

        https://docs.aws.amazon.com/iot-fleetwise/latest/APIReference/API_ListFleets.html

        :stability: experimental
        '''
        return typing.cast("Iotfleetwise", jsii.invoke(self, "toListFleets", []))

    @jsii.member(jsii_name="toListFleetsForVehicle")
    def to_list_fleets_for_vehicle(self) -> "Iotfleetwise":
        '''(experimental) Grants permission to list all the fleets that the given vehicle is associated with.

        Access Level: Read

        https://docs.aws.amazon.com/iot-fleetwise/latest/APIReference/API_ListFleetsForVehicle.html

        :stability: experimental
        '''
        return typing.cast("Iotfleetwise", jsii.invoke(self, "toListFleetsForVehicle", []))

    @jsii.member(jsii_name="toListModelManifestNodes")
    def to_list_model_manifest_nodes(self) -> "Iotfleetwise":
        '''(experimental) Grants permission to list all nodes for the given model manifest.

        Access Level: List

        https://docs.aws.amazon.com/iot-fleetwise/latest/APIReference/API_ListModelManifestNodes.html

        :stability: experimental
        '''
        return typing.cast("Iotfleetwise", jsii.invoke(self, "toListModelManifestNodes", []))

    @jsii.member(jsii_name="toListModelManifests")
    def to_list_model_manifests(self) -> "Iotfleetwise":
        '''(experimental) Grants permission to list all model manifests, with an optional filter on signal catalog.

        Access Level: Read

        https://docs.aws.amazon.com/iot-fleetwise/latest/APIReference/API_ListModelManifests.html

        :stability: experimental
        '''
        return typing.cast("Iotfleetwise", jsii.invoke(self, "toListModelManifests", []))

    @jsii.member(jsii_name="toListSignalCatalogNodes")
    def to_list_signal_catalog_nodes(self) -> "Iotfleetwise":
        '''(experimental) Grants permission to list all nodes for a given signal catalog.

        Access Level: Read

        https://docs.aws.amazon.com/iot-fleetwise/latest/APIReference/API_ListSignalCatalogNodes.html

        :stability: experimental
        '''
        return typing.cast("Iotfleetwise", jsii.invoke(self, "toListSignalCatalogNodes", []))

    @jsii.member(jsii_name="toListSignalCatalogs")
    def to_list_signal_catalogs(self) -> "Iotfleetwise":
        '''(experimental) Grants permission to list all signal catalogs.

        Access Level: Read

        https://docs.aws.amazon.com/iot-fleetwise/latest/APIReference/API_ListSignalCatalogs.html

        :stability: experimental
        '''
        return typing.cast("Iotfleetwise", jsii.invoke(self, "toListSignalCatalogs", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Iotfleetwise":
        '''(experimental) Grants permission to list tags for a resource.

        Access Level: Read

        https://docs.aws.amazon.com/iot-fleetwise/latest/APIReference/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("Iotfleetwise", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toListVehicles")
    def to_list_vehicles(self) -> "Iotfleetwise":
        '''(experimental) Grants permission to list all vehicles, with an optional filter on model manifest.

        Access Level: Read

        https://docs.aws.amazon.com/iot-fleetwise/latest/APIReference/API_ListVehicles.html

        :stability: experimental
        '''
        return typing.cast("Iotfleetwise", jsii.invoke(self, "toListVehicles", []))

    @jsii.member(jsii_name="toListVehiclesInFleet")
    def to_list_vehicles_in_fleet(self) -> "Iotfleetwise":
        '''(experimental) Grants permission to list vehicles in the given fleet.

        Access Level: Read

        https://docs.aws.amazon.com/iot-fleetwise/latest/APIReference/API_ListVehiclesInFleet.html

        :stability: experimental
        '''
        return typing.cast("Iotfleetwise", jsii.invoke(self, "toListVehiclesInFleet", []))

    @jsii.member(jsii_name="toPutLoggingOptions")
    def to_put_logging_options(self) -> "Iotfleetwise":
        '''(experimental) Grants permission to put the logging options for the AWS account.

        Access Level: Write

        https://docs.aws.amazon.com/iot-fleetwise/latest/APIReference/API_PutLoggingOptions.html

        :stability: experimental
        '''
        return typing.cast("Iotfleetwise", jsii.invoke(self, "toPutLoggingOptions", []))

    @jsii.member(jsii_name="toRegisterAccount")
    def to_register_account(self) -> "Iotfleetwise":
        '''(experimental) Grants permission to register an AWS account to IoT FleetWise.

        Access Level: Write

        Dependent actions:

        - iam:PassRole

        https://docs.aws.amazon.com/iot-fleetwise/latest/APIReference/API_RegisterAccount.html

        :stability: experimental
        '''
        return typing.cast("Iotfleetwise", jsii.invoke(self, "toRegisterAccount", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Iotfleetwise":
        '''(experimental) Grants permission to add tags to a resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/iot-fleetwise/latest/APIReference/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("Iotfleetwise", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Iotfleetwise":
        '''(experimental) Grants permission to remove tags from a resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/iot-fleetwise/latest/APIReference/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("Iotfleetwise", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateCampaign")
    def to_update_campaign(self) -> "Iotfleetwise":
        '''(experimental) Grants permission to update the given campaign.

        Access Level: Write

        https://docs.aws.amazon.com/iot-fleetwise/latest/APIReference/API_UpdateCampaign.html

        :stability: experimental
        '''
        return typing.cast("Iotfleetwise", jsii.invoke(self, "toUpdateCampaign", []))

    @jsii.member(jsii_name="toUpdateDecoderManifest")
    def to_update_decoder_manifest(self) -> "Iotfleetwise":
        '''(experimental) Grants permission to update a decoder manifest defnition.

        Access Level: Write

        https://docs.aws.amazon.com/iot-fleetwise/latest/APIReference/API_UpdateDecoderManifest.html

        :stability: experimental
        '''
        return typing.cast("Iotfleetwise", jsii.invoke(self, "toUpdateDecoderManifest", []))

    @jsii.member(jsii_name="toUpdateFleet")
    def to_update_fleet(self) -> "Iotfleetwise":
        '''(experimental) Grants permission to update the fleet.

        Access Level: Write

        https://docs.aws.amazon.com/iot-fleetwise/latest/APIReference/API_UpdateFleet.html

        :stability: experimental
        '''
        return typing.cast("Iotfleetwise", jsii.invoke(self, "toUpdateFleet", []))

    @jsii.member(jsii_name="toUpdateModelManifest")
    def to_update_model_manifest(self) -> "Iotfleetwise":
        '''(experimental) Grants permission to update the given model manifest definition.

        Access Level: Write

        https://docs.aws.amazon.com/iot-fleetwise/latest/APIReference/API_UpdateModelManifest.html

        :stability: experimental
        '''
        return typing.cast("Iotfleetwise", jsii.invoke(self, "toUpdateModelManifest", []))

    @jsii.member(jsii_name="toUpdateSignalCatalog")
    def to_update_signal_catalog(self) -> "Iotfleetwise":
        '''(experimental) Grants permission to update a specific signal catalog definition.

        Access Level: Write

        https://docs.aws.amazon.com/iot-fleetwise/latest/APIReference/API_UpdateSignalCatalog.html

        :stability: experimental
        '''
        return typing.cast("Iotfleetwise", jsii.invoke(self, "toUpdateSignalCatalog", []))

    @jsii.member(jsii_name="toUpdateVehicle")
    def to_update_vehicle(self) -> "Iotfleetwise":
        '''(experimental) Grants permission to update the vehicle.

        Access Level: Write

        Possible conditions:

        - .ifUpdateToModelManifestArn()
        - .ifUpdateToDecoderManifestArn()

        https://docs.aws.amazon.com/iot-fleetwise/latest/APIReference/API_UpdateVehicle.html

        :stability: experimental
        '''
        return typing.cast("Iotfleetwise", jsii.invoke(self, "toUpdateVehicle", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b2ef629aad768fb5cffbc06e198b09ddb3db5a3d53302a58f2de40249a6ba413)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f0212ba34e1b01a60d1baec3e1fc9d05593758ed40f102c9a27f7968f01d6f26)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Iotjobsdata(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Iotjobsdata",
):
    '''(experimental) Statement provider for service `iotjobsdata <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiotjobsdataplane.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `iotjobsdata <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiotjobsdataplane.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="ifIotJobId")
    def if_iot_job_id(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Iotjobsdata":
        '''(experimental) Filters access by jobId for iotjobsdata:DescribeJobExecution and iotjobsdata:UpdateJobExecution APIs.

        https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html

        Applies to actions:

        - .toDescribeJobExecution()
        - .toUpdateJobExecution()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__cfc8fc8bacd0274fdb93dc33fbc9bc7d9731fe77df7fc2fe921bdbc42de75aa5)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Iotjobsdata", jsii.invoke(self, "ifIotJobId", [value, operator]))

    @jsii.member(jsii_name="onThing")
    def on_thing(
        self,
        thing_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Iotjobsdata":
        '''(experimental) Adds a resource of type thing to the statement.

        https://docs.aws.amazon.com/iot/latest/developerguide/thing-registry.html

        :param thing_name: - Identifier for the thingName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3f15929c5aee86772654f6ef2e1673469aaa811f5cd69e9de59c9d594606de41)
            check_type(argname="argument thing_name", value=thing_name, expected_type=type_hints["thing_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Iotjobsdata", jsii.invoke(self, "onThing", [thing_name, account, region, partition]))

    @jsii.member(jsii_name="toDescribeJobExecution")
    def to_describe_job_execution(self) -> "Iotjobsdata":
        '''(experimental) Grants permission to describe a job execution.

        Access Level: Read

        Possible conditions:

        - .ifIotJobId()

        https://docs.aws.amazon.com/iot/latest/apireference/API_iot-jobs-data_DescribeJobExecution.html

        :stability: experimental
        '''
        return typing.cast("Iotjobsdata", jsii.invoke(self, "toDescribeJobExecution", []))

    @jsii.member(jsii_name="toGetPendingJobExecutions")
    def to_get_pending_job_executions(self) -> "Iotjobsdata":
        '''(experimental) Grants permission to get the list of all jobs for a thing that are not in a terminal state.

        Access Level: Read

        https://docs.aws.amazon.com/iot/latest/apireference/API_iot-jobs-data_GetPendingJobExecutions.html

        :stability: experimental
        '''
        return typing.cast("Iotjobsdata", jsii.invoke(self, "toGetPendingJobExecutions", []))

    @jsii.member(jsii_name="toStartNextPendingJobExecution")
    def to_start_next_pending_job_execution(self) -> "Iotjobsdata":
        '''(experimental) Grants permission to get and start the next pending job execution for a thing.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_iot-jobs-data_StartNextPendingJobExecution.html

        :stability: experimental
        '''
        return typing.cast("Iotjobsdata", jsii.invoke(self, "toStartNextPendingJobExecution", []))

    @jsii.member(jsii_name="toUpdateJobExecution")
    def to_update_job_execution(self) -> "Iotjobsdata":
        '''(experimental) Grants permission to update a job execution.

        Access Level: Write

        Possible conditions:

        - .ifIotJobId()

        https://docs.aws.amazon.com/iot/latest/apireference/API_iot-jobs-data_UpdateJobExecution.html

        :stability: experimental
        '''
        return typing.cast("Iotjobsdata", jsii.invoke(self, "toUpdateJobExecution", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__cfaac904cd8b8fbde1c0455c4befb3fc9a15617a24a5984fd7bf7a814b086363)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__679ee6d31580092c8808f9f7fbb66866b6877da85a56e78a8bb115f04b9048e4)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Iotroborunner(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Iotroborunner",
):
    '''(experimental) Statement provider for service `iotroborunner <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiotroborunner.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `iotroborunner <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiotroborunner.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="ifActionResourceId")
    def if_action_resource_id(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Iotroborunner":
        '''(experimental) Filters access by the action's identifier.

        https://docs.aws.amazon.com/iotroborunner/latest/dev/#Action

        Applies to resource types:

        - ActionResource

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b0dfd15bd37fd9f88b6a7cc5e810d0fc7baf321f9268208f76d1cd56a63402ed)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Iotroborunner", jsii.invoke(self, "ifActionResourceId", [value, operator]))

    @jsii.member(jsii_name="ifActionTemplateResourceId")
    def if_action_template_resource_id(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Iotroborunner":
        '''(experimental) Filters access by the action template's identifier.

        https://docs.aws.amazon.com/iotroborunner/latest/dev/#ActionTemplate

        Applies to resource types:

        - ActionTemplateResource

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d6a5a3de1ae3e3c354a04e3b425335efb7624d7091b862ad696603f58cda83e8)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Iotroborunner", jsii.invoke(self, "ifActionTemplateResourceId", [value, operator]))

    @jsii.member(jsii_name="ifActivityResourceId")
    def if_activity_resource_id(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Iotroborunner":
        '''(experimental) Filters access by the activity's identifier.

        https://docs.aws.amazon.com/iotroborunner/latest/dev/#Activity

        Applies to resource types:

        - ActivityResource

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__448316af219e9e041066eb77969d2763c9ce5bbd18a9469b73530cef4a77f79b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Iotroborunner", jsii.invoke(self, "ifActivityResourceId", [value, operator]))

    @jsii.member(jsii_name="ifDestinationRelationshipResourceId")
    def if_destination_relationship_resource_id(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Iotroborunner":
        '''(experimental) Filters access by the destination relationship's identifier.

        https://docs.aws.amazon.com/iotroborunner/latest/dev/#DestinationRelationship

        Applies to resource types:

        - DestinationRelationshipResource

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0817e75503ad7b1fd4a6993ee4f038de5aa053c8e802086a7008cfe6eaf8d0d2)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Iotroborunner", jsii.invoke(self, "ifDestinationRelationshipResourceId", [value, operator]))

    @jsii.member(jsii_name="ifDestinationResourceId")
    def if_destination_resource_id(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Iotroborunner":
        '''(experimental) Filters access by the destination's identifier.

        https://docs.aws.amazon.com/iotroborunner/latest/dev/#Destination

        Applies to resource types:

        - DestinationResource

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a32a2619b2df0a02a247f6c8d3428e91d6dd08d0f16bcdc65d771486b6d3a64f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Iotroborunner", jsii.invoke(self, "ifDestinationResourceId", [value, operator]))

    @jsii.member(jsii_name="ifSiteResourceId")
    def if_site_resource_id(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Iotroborunner":
        '''(experimental) Filters access by the site's identifier.

        https://docs.aws.amazon.com/iotroborunner/latest/dev/#Site

        Applies to resource types:

        - SiteResource

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__53ab49f7f85fd9a3394067f35850c5bd58811289ad3c4824dbc74127088cd0a8)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Iotroborunner", jsii.invoke(self, "ifSiteResourceId", [value, operator]))

    @jsii.member(jsii_name="ifTaggingResourceTagKey")
    def if_tagging_resource_tag_key(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Iotroborunner":
        '''(experimental) Filters access by the metadata tag name.

        https://docs.aws.amazon.com/iotroborunner/latest/dev/#Tagging

        Applies to resource types:

        - TaggingResource

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f8553a396ca28a57ecce47ba50edf434fc25eae15c09744e640578ebf7946ab2)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Iotroborunner", jsii.invoke(self, "ifTaggingResourceTagKey", [value, operator]))

    @jsii.member(jsii_name="ifTaskResourceId")
    def if_task_resource_id(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Iotroborunner":
        '''(experimental) Filters access by the task's identifer.

        https://docs.aws.amazon.com/iotroborunner/latest/dev/#Task

        Applies to resource types:

        - TaskResource

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8160a6762bd857b869640764b4d84a203cd77e7e0490aedffcb766f9c8c42127)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Iotroborunner", jsii.invoke(self, "ifTaskResourceId", [value, operator]))

    @jsii.member(jsii_name="ifWorkerFleetResourceId")
    def if_worker_fleet_resource_id(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Iotroborunner":
        '''(experimental) Filters access by the worker fleet's identifier.

        https://docs.aws.amazon.com/iotroborunner/latest/dev/#WorkerFleet

        Applies to resource types:

        - WorkerFleetResource

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__74e5d285e0c1f7cf81be349ceda4c7141a21096ee0b3c8063c91d4550212d7ad)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Iotroborunner", jsii.invoke(self, "ifWorkerFleetResourceId", [value, operator]))

    @jsii.member(jsii_name="ifWorkerResourceId")
    def if_worker_resource_id(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Iotroborunner":
        '''(experimental) Filters access by the workers identifier.

        https://docs.aws.amazon.com/iotroborunner/latest/dev/#Worker

        Applies to resource types:

        - WorkerResource

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6c09794caad7940d938221e15f9b4b047703a7589494d8e2e83eb7f38c973c8f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Iotroborunner", jsii.invoke(self, "ifWorkerResourceId", [value, operator]))

    @jsii.member(jsii_name="onActionResource")
    def on_action_resource(
        self,
        action_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Iotroborunner":
        '''(experimental) Adds a resource of type ActionResource to the statement.

        https://docs.aws.amazon.com/iotroborunner/latest/api/

        :param action_id: - Identifier for the actionId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifActionResourceId()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__76461ac7a643525e88e79006f5f12cdbcf1d4e58a60f6a1e5a399dd6280402f9)
            check_type(argname="argument action_id", value=action_id, expected_type=type_hints["action_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Iotroborunner", jsii.invoke(self, "onActionResource", [action_id, account, region, partition]))

    @jsii.member(jsii_name="onActionTemplateResource")
    def on_action_template_resource(
        self,
        action_template_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Iotroborunner":
        '''(experimental) Adds a resource of type ActionTemplateResource to the statement.

        https://docs.aws.amazon.com/iotroborunner/latest/api/

        :param action_template_id: - Identifier for the actionTemplateId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifActionTemplateResourceId()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c9961e787367c376dc00b1d4a2556f642632185217c03848507d6b64a5af2eff)
            check_type(argname="argument action_template_id", value=action_template_id, expected_type=type_hints["action_template_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Iotroborunner", jsii.invoke(self, "onActionTemplateResource", [action_template_id, account, region, partition]))

    @jsii.member(jsii_name="onActivityResource")
    def on_activity_resource(
        self,
        activity_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Iotroborunner":
        '''(experimental) Adds a resource of type ActivityResource to the statement.

        https://docs.aws.amazon.com/iotroborunner/latest/api/

        :param activity_id: - Identifier for the activityId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifActivityResourceId()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ff875a6304984f6a201e402b1c5d97ec461e3c1531415d34f26a766508a32d79)
            check_type(argname="argument activity_id", value=activity_id, expected_type=type_hints["activity_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Iotroborunner", jsii.invoke(self, "onActivityResource", [activity_id, account, region, partition]))

    @jsii.member(jsii_name="onDestinationRelationshipResource")
    def on_destination_relationship_resource(
        self,
        destination_relationship_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Iotroborunner":
        '''(experimental) Adds a resource of type DestinationRelationshipResource to the statement.

        https://docs.aws.amazon.com/iotroborunner/latest/api/

        :param destination_relationship_id: - Identifier for the destinationRelationshipId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifDestinationRelationshipResourceId()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b1d2e7de629b2749144da1aef39595cca4322a3246948f58a622fa21fb6ad5a9)
            check_type(argname="argument destination_relationship_id", value=destination_relationship_id, expected_type=type_hints["destination_relationship_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Iotroborunner", jsii.invoke(self, "onDestinationRelationshipResource", [destination_relationship_id, account, region, partition]))

    @jsii.member(jsii_name="onDestinationResource")
    def on_destination_resource(
        self,
        site_id: builtins.str,
        destination_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Iotroborunner":
        '''(experimental) Adds a resource of type DestinationResource to the statement.

        https://docs.aws.amazon.com/iotroborunner/latest/api/

        :param site_id: - Identifier for the siteId.
        :param destination_id: - Identifier for the destinationId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifDestinationResourceId()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__335b43db6ee09cf4e415e0e131ad9a400825b37a3249c6d98fa9c2511148b29d)
            check_type(argname="argument site_id", value=site_id, expected_type=type_hints["site_id"])
            check_type(argname="argument destination_id", value=destination_id, expected_type=type_hints["destination_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Iotroborunner", jsii.invoke(self, "onDestinationResource", [site_id, destination_id, account, region, partition]))

    @jsii.member(jsii_name="onSiteResource")
    def on_site_resource(
        self,
        site_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Iotroborunner":
        '''(experimental) Adds a resource of type SiteResource to the statement.

        https://docs.aws.amazon.com/iotroborunner/latest/api/

        :param site_id: - Identifier for the siteId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifSiteResourceId()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e516db3eda110deaa8e9d8b8bbaf185fa37387760b89db5bf56d13af10f7f205)
            check_type(argname="argument site_id", value=site_id, expected_type=type_hints["site_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Iotroborunner", jsii.invoke(self, "onSiteResource", [site_id, account, region, partition]))

    @jsii.member(jsii_name="onTaggingResource")
    def on_tagging_resource(
        self,
        tag_key: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Iotroborunner":
        '''(experimental) Adds a resource of type TaggingResource to the statement.

        https://docs.aws.amazon.com/iotroborunner/latest/api/

        :param tag_key: - Identifier for the tagKey.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifTaggingResourceTagKey()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__67aa020c9c8c53be0f226f20bc55ef99d08b35f50f0b8cd3fcc82d59f7c656a6)
            check_type(argname="argument tag_key", value=tag_key, expected_type=type_hints["tag_key"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Iotroborunner", jsii.invoke(self, "onTaggingResource", [tag_key, account, region, partition]))

    @jsii.member(jsii_name="onTaskResource")
    def on_task_resource(
        self,
        task_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Iotroborunner":
        '''(experimental) Adds a resource of type TaskResource to the statement.

        https://docs.aws.amazon.com/iotroborunner/latest/api/

        :param task_id: - Identifier for the taskId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifTaskResourceId()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a85247d8e0847ea69ed06332fb94a0be4dd80d9144fec4c3bbf1bd6927addffd)
            check_type(argname="argument task_id", value=task_id, expected_type=type_hints["task_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Iotroborunner", jsii.invoke(self, "onTaskResource", [task_id, account, region, partition]))

    @jsii.member(jsii_name="onWorkerFleetResource")
    def on_worker_fleet_resource(
        self,
        site_id: builtins.str,
        worker_fleet_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Iotroborunner":
        '''(experimental) Adds a resource of type WorkerFleetResource to the statement.

        https://docs.aws.amazon.com/iotroborunner/latest/api/

        :param site_id: - Identifier for the siteId.
        :param worker_fleet_id: - Identifier for the workerFleetId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifWorkerFleetResourceId()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7839c3ac016f4f08400b041c929208025f8a25bf0b7532be3d869043b9d83930)
            check_type(argname="argument site_id", value=site_id, expected_type=type_hints["site_id"])
            check_type(argname="argument worker_fleet_id", value=worker_fleet_id, expected_type=type_hints["worker_fleet_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Iotroborunner", jsii.invoke(self, "onWorkerFleetResource", [site_id, worker_fleet_id, account, region, partition]))

    @jsii.member(jsii_name="onWorkerResource")
    def on_worker_resource(
        self,
        site_id: builtins.str,
        worker_fleet_id: builtins.str,
        worker_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Iotroborunner":
        '''(experimental) Adds a resource of type WorkerResource to the statement.

        https://docs.aws.amazon.com/iotroborunner/latest/api/

        :param site_id: - Identifier for the siteId.
        :param worker_fleet_id: - Identifier for the workerFleetId.
        :param worker_id: - Identifier for the workerId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifWorkerResourceId()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3e0c81ad7c938d4b6eb1c3e3318e7d69265f0d4fecfe86ef3349e9590240908d)
            check_type(argname="argument site_id", value=site_id, expected_type=type_hints["site_id"])
            check_type(argname="argument worker_fleet_id", value=worker_fleet_id, expected_type=type_hints["worker_fleet_id"])
            check_type(argname="argument worker_id", value=worker_id, expected_type=type_hints["worker_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Iotroborunner", jsii.invoke(self, "onWorkerResource", [site_id, worker_fleet_id, worker_id, account, region, partition]))

    @jsii.member(jsii_name="toCreateAction")
    def to_create_action(self) -> "Iotroborunner":
        '''(experimental) Grants permission to create an action.

        Access Level: Write

        https://docs.aws.amazon.com/iotroborunner/latest/api/API_CreateAction.html

        :stability: experimental
        '''
        return typing.cast("Iotroborunner", jsii.invoke(self, "toCreateAction", []))

    @jsii.member(jsii_name="toCreateActionTemplate")
    def to_create_action_template(self) -> "Iotroborunner":
        '''(experimental) Grants permission to create an action template.

        Access Level: Write

        https://docs.aws.amazon.com/iotroborunner/latest/api/API_CreateActionTemplate.html

        :stability: experimental
        '''
        return typing.cast("Iotroborunner", jsii.invoke(self, "toCreateActionTemplate", []))

    @jsii.member(jsii_name="toCreateActionTemplateDependency")
    def to_create_action_template_dependency(self) -> "Iotroborunner":
        '''(experimental) Grants permission to create an action template dependency.

        Access Level: Write

        https://docs.aws.amazon.com/iotroborunner/latest/api/API_CreateActionTemplateDependency.html

        :stability: experimental
        '''
        return typing.cast("Iotroborunner", jsii.invoke(self, "toCreateActionTemplateDependency", []))

    @jsii.member(jsii_name="toCreateActivity")
    def to_create_activity(self) -> "Iotroborunner":
        '''(experimental) Grants permission to create an activity.

        Access Level: Write

        https://docs.aws.amazon.com/iotroborunner/latest/api/API_CreateActivity.html

        :stability: experimental
        '''
        return typing.cast("Iotroborunner", jsii.invoke(self, "toCreateActivity", []))

    @jsii.member(jsii_name="toCreateActivityDependency")
    def to_create_activity_dependency(self) -> "Iotroborunner":
        '''(experimental) Grants permission to create an activity dependency.

        Access Level: Write

        https://docs.aws.amazon.com/iotroborunner/latest/api/API_CreateActivityDependency.html

        :stability: experimental
        '''
        return typing.cast("Iotroborunner", jsii.invoke(self, "toCreateActivityDependency", []))

    @jsii.member(jsii_name="toCreateDestination")
    def to_create_destination(self) -> "Iotroborunner":
        '''(experimental) Grants permission to create a destination.

        Access Level: Write

        https://docs.aws.amazon.com/iotroborunner/latest/api/API_CreateDestination.html

        :stability: experimental
        '''
        return typing.cast("Iotroborunner", jsii.invoke(self, "toCreateDestination", []))

    @jsii.member(jsii_name="toCreateDestinationRelationship")
    def to_create_destination_relationship(self) -> "Iotroborunner":
        '''(experimental) Grants permission to create a destination relationship.

        Access Level: Write

        https://docs.aws.amazon.com/iotroborunner/latest/api/API_CreateDestinationRelationship.html

        :stability: experimental
        '''
        return typing.cast("Iotroborunner", jsii.invoke(self, "toCreateDestinationRelationship", []))

    @jsii.member(jsii_name="toCreateSite")
    def to_create_site(self) -> "Iotroborunner":
        '''(experimental) Grants permission to create a site.

        Access Level: Write

        https://docs.aws.amazon.com/iotroborunner/latest/api/API_CreateSite.html

        :stability: experimental
        '''
        return typing.cast("Iotroborunner", jsii.invoke(self, "toCreateSite", []))

    @jsii.member(jsii_name="toCreateTask")
    def to_create_task(self) -> "Iotroborunner":
        '''(experimental) Grants permission to create a task.

        Access Level: Write

        https://docs.aws.amazon.com/iotroborunner/latest/api/API_CreateTask.html

        :stability: experimental
        '''
        return typing.cast("Iotroborunner", jsii.invoke(self, "toCreateTask", []))

    @jsii.member(jsii_name="toCreateTaskDependency")
    def to_create_task_dependency(self) -> "Iotroborunner":
        '''(experimental) Grants permission to create a task dependency.

        Access Level: Write

        https://docs.aws.amazon.com/iotroborunner/latest/api/API_CreateTaskDependency.html

        :stability: experimental
        '''
        return typing.cast("Iotroborunner", jsii.invoke(self, "toCreateTaskDependency", []))

    @jsii.member(jsii_name="toCreateWorker")
    def to_create_worker(self) -> "Iotroborunner":
        '''(experimental) Grants permission to create a worker.

        Access Level: Write

        https://docs.aws.amazon.com/iotroborunner/latest/api/API_CreateWorker.html

        :stability: experimental
        '''
        return typing.cast("Iotroborunner", jsii.invoke(self, "toCreateWorker", []))

    @jsii.member(jsii_name="toCreateWorkerFleet")
    def to_create_worker_fleet(self) -> "Iotroborunner":
        '''(experimental) Grants permission to create a worker fleet.

        Access Level: Write

        https://docs.aws.amazon.com/iotroborunner/latest/api/API_CreateWorkerFleet.html

        :stability: experimental
        '''
        return typing.cast("Iotroborunner", jsii.invoke(self, "toCreateWorkerFleet", []))

    @jsii.member(jsii_name="toDeleteAction")
    def to_delete_action(self) -> "Iotroborunner":
        '''(experimental) Grants permission to delete an action.

        Access Level: Write

        https://docs.aws.amazon.com/iotroborunner/latest/api/API_DeleteAction.html

        :stability: experimental
        '''
        return typing.cast("Iotroborunner", jsii.invoke(self, "toDeleteAction", []))

    @jsii.member(jsii_name="toDeleteActionTemplate")
    def to_delete_action_template(self) -> "Iotroborunner":
        '''(experimental) Grants permission to delete an action template.

        Access Level: Write

        https://docs.aws.amazon.com/iotroborunner/latest/api/API_DeleteActionTemplate.html

        :stability: experimental
        '''
        return typing.cast("Iotroborunner", jsii.invoke(self, "toDeleteActionTemplate", []))

    @jsii.member(jsii_name="toDeleteActionTemplateDependency")
    def to_delete_action_template_dependency(self) -> "Iotroborunner":
        '''(experimental) Grants permission to delete an action template dependency.

        Access Level: Write

        https://docs.aws.amazon.com/iotroborunner/latest/api/API_DeleteActionTemplateDependency.html

        :stability: experimental
        '''
        return typing.cast("Iotroborunner", jsii.invoke(self, "toDeleteActionTemplateDependency", []))

    @jsii.member(jsii_name="toDeleteActivity")
    def to_delete_activity(self) -> "Iotroborunner":
        '''(experimental) Grants permission to delete an activity.

        Access Level: Write

        https://docs.aws.amazon.com/iotroborunner/latest/api/API_DeleteActivity.html

        :stability: experimental
        '''
        return typing.cast("Iotroborunner", jsii.invoke(self, "toDeleteActivity", []))

    @jsii.member(jsii_name="toDeleteActivityDependency")
    def to_delete_activity_dependency(self) -> "Iotroborunner":
        '''(experimental) Grants permission to delete an activity dependency.

        Access Level: Write

        https://docs.aws.amazon.com/iotroborunner/latest/api/API_DeleteActivityDependency.html

        :stability: experimental
        '''
        return typing.cast("Iotroborunner", jsii.invoke(self, "toDeleteActivityDependency", []))

    @jsii.member(jsii_name="toDeleteDestination")
    def to_delete_destination(self) -> "Iotroborunner":
        '''(experimental) Grants permission to delete a destination.

        Access Level: Write

        https://docs.aws.amazon.com/iotroborunner/latest/api/API_DeleteDestination.html

        :stability: experimental
        '''
        return typing.cast("Iotroborunner", jsii.invoke(self, "toDeleteDestination", []))

    @jsii.member(jsii_name="toDeleteDestinationRelationship")
    def to_delete_destination_relationship(self) -> "Iotroborunner":
        '''(experimental) Grants permission to delete a destination relationship.

        Access Level: Write

        https://docs.aws.amazon.com/iotroborunner/latest/api/API_DeleteDestinationRelationship.html

        :stability: experimental
        '''
        return typing.cast("Iotroborunner", jsii.invoke(self, "toDeleteDestinationRelationship", []))

    @jsii.member(jsii_name="toDeleteSite")
    def to_delete_site(self) -> "Iotroborunner":
        '''(experimental) Grants permission to delete a site.

        Access Level: Write

        https://docs.aws.amazon.com/iotroborunner/latest/api/API_DeleteSite.html

        :stability: experimental
        '''
        return typing.cast("Iotroborunner", jsii.invoke(self, "toDeleteSite", []))

    @jsii.member(jsii_name="toDeleteTask")
    def to_delete_task(self) -> "Iotroborunner":
        '''(experimental) Grants permission to delete a task.

        Access Level: Write

        https://docs.aws.amazon.com/iotroborunner/latest/api/API_DeleteTask.html

        :stability: experimental
        '''
        return typing.cast("Iotroborunner", jsii.invoke(self, "toDeleteTask", []))

    @jsii.member(jsii_name="toDeleteTaskDependency")
    def to_delete_task_dependency(self) -> "Iotroborunner":
        '''(experimental) Grants permission to delete a task dependency.

        Access Level: Write

        https://docs.aws.amazon.com/iotroborunner/latest/api/API_DeleteTaskDependency.html

        :stability: experimental
        '''
        return typing.cast("Iotroborunner", jsii.invoke(self, "toDeleteTaskDependency", []))

    @jsii.member(jsii_name="toDeleteWorker")
    def to_delete_worker(self) -> "Iotroborunner":
        '''(experimental) Grants permission to delete a worker.

        Access Level: Write

        https://docs.aws.amazon.com/iotroborunner/latest/api/API_DeleteWorker.html

        :stability: experimental
        '''
        return typing.cast("Iotroborunner", jsii.invoke(self, "toDeleteWorker", []))

    @jsii.member(jsii_name="toDeleteWorkerFleet")
    def to_delete_worker_fleet(self) -> "Iotroborunner":
        '''(experimental) Grants permission to delete a worker fleet.

        Access Level: Write

        https://docs.aws.amazon.com/iotroborunner/latest/api/API_DeleteWorkerFleet.html

        :stability: experimental
        '''
        return typing.cast("Iotroborunner", jsii.invoke(self, "toDeleteWorkerFleet", []))

    @jsii.member(jsii_name="toGetAction")
    def to_get_action(self) -> "Iotroborunner":
        '''(experimental) Grants permission to get an action.

        Access Level: Read

        https://docs.aws.amazon.com/iotroborunner/latest/api/API_GetAction.html

        :stability: experimental
        '''
        return typing.cast("Iotroborunner", jsii.invoke(self, "toGetAction", []))

    @jsii.member(jsii_name="toGetActionTemplate")
    def to_get_action_template(self) -> "Iotroborunner":
        '''(experimental) Grants permission to get an action template.

        Access Level: Read

        https://docs.aws.amazon.com/iotroborunner/latest/api/API_GetActionTemplate.html

        :stability: experimental
        '''
        return typing.cast("Iotroborunner", jsii.invoke(self, "toGetActionTemplate", []))

    @jsii.member(jsii_name="toGetActivity")
    def to_get_activity(self) -> "Iotroborunner":
        '''(experimental) Grants permission to get an activity.

        Access Level: Read

        https://docs.aws.amazon.com/iotroborunner/latest/api/API_GetActivity.html

        :stability: experimental
        '''
        return typing.cast("Iotroborunner", jsii.invoke(self, "toGetActivity", []))

    @jsii.member(jsii_name="toGetDestination")
    def to_get_destination(self) -> "Iotroborunner":
        '''(experimental) Grants permission to get a destination.

        Access Level: Read

        https://docs.aws.amazon.com/iotroborunner/latest/api/API_GetDestination.html

        :stability: experimental
        '''
        return typing.cast("Iotroborunner", jsii.invoke(self, "toGetDestination", []))

    @jsii.member(jsii_name="toGetDestinationRelationship")
    def to_get_destination_relationship(self) -> "Iotroborunner":
        '''(experimental) Grants permission to get a destination relationship.

        Access Level: Read

        https://docs.aws.amazon.com/iotroborunner/latest/api/API_GetDestinationRelationship.html

        :stability: experimental
        '''
        return typing.cast("Iotroborunner", jsii.invoke(self, "toGetDestinationRelationship", []))

    @jsii.member(jsii_name="toGetSite")
    def to_get_site(self) -> "Iotroborunner":
        '''(experimental) Grants permission to get a site.

        Access Level: Read

        https://docs.aws.amazon.com/iotroborunner/latest/api/API_GetSite.html

        :stability: experimental
        '''
        return typing.cast("Iotroborunner", jsii.invoke(self, "toGetSite", []))

    @jsii.member(jsii_name="toGetTask")
    def to_get_task(self) -> "Iotroborunner":
        '''(experimental) Grants permission to get a task.

        Access Level: Read

        https://docs.aws.amazon.com/iotroborunner/latest/api/API_GetTask.html

        :stability: experimental
        '''
        return typing.cast("Iotroborunner", jsii.invoke(self, "toGetTask", []))

    @jsii.member(jsii_name="toGetWorker")
    def to_get_worker(self) -> "Iotroborunner":
        '''(experimental) Grants permission to get a worker.

        Access Level: Read

        https://docs.aws.amazon.com/iotroborunner/latest/api/API_GetWorker.html

        :stability: experimental
        '''
        return typing.cast("Iotroborunner", jsii.invoke(self, "toGetWorker", []))

    @jsii.member(jsii_name="toGetWorkerFleet")
    def to_get_worker_fleet(self) -> "Iotroborunner":
        '''(experimental) Grants permission to get a worker fleet.

        Access Level: Read

        https://docs.aws.amazon.com/iotroborunner/latest/api/API_GetWorkerFleet.html

        :stability: experimental
        '''
        return typing.cast("Iotroborunner", jsii.invoke(self, "toGetWorkerFleet", []))

    @jsii.member(jsii_name="toListActions")
    def to_list_actions(self) -> "Iotroborunner":
        '''(experimental) Grants permission to list actions.

        Access Level: Read

        https://docs.aws.amazon.com/iotroborunner/latest/api/API_ListActions.html

        :stability: experimental
        '''
        return typing.cast("Iotroborunner", jsii.invoke(self, "toListActions", []))

    @jsii.member(jsii_name="toListActionTemplates")
    def to_list_action_templates(self) -> "Iotroborunner":
        '''(experimental) Grants permission to list action templates.

        Access Level: Read

        https://docs.aws.amazon.com/iotroborunner/latest/api/API_ListActionTemplates.html

        :stability: experimental
        '''
        return typing.cast("Iotroborunner", jsii.invoke(self, "toListActionTemplates", []))

    @jsii.member(jsii_name="toListActivities")
    def to_list_activities(self) -> "Iotroborunner":
        '''(experimental) Grants permission to list activities.

        Access Level: Read

        https://docs.aws.amazon.com/iotroborunner/latest/api/API_ListActivities.html

        :stability: experimental
        '''
        return typing.cast("Iotroborunner", jsii.invoke(self, "toListActivities", []))

    @jsii.member(jsii_name="toListDestinationRelationships")
    def to_list_destination_relationships(self) -> "Iotroborunner":
        '''(experimental) Grants permission to list destination relationships.

        Access Level: Read

        https://docs.aws.amazon.com/iotroborunner/latest/api/API_ListDestinationRelationships.html

        :stability: experimental
        '''
        return typing.cast("Iotroborunner", jsii.invoke(self, "toListDestinationRelationships", []))

    @jsii.member(jsii_name="toListDestinations")
    def to_list_destinations(self) -> "Iotroborunner":
        '''(experimental) Grants permission to list destinations.

        Access Level: Read

        https://docs.aws.amazon.com/iotroborunner/latest/api/API_ListDestinations.html

        :stability: experimental
        '''
        return typing.cast("Iotroborunner", jsii.invoke(self, "toListDestinations", []))

    @jsii.member(jsii_name="toListSites")
    def to_list_sites(self) -> "Iotroborunner":
        '''(experimental) Grants permission to list sites.

        Access Level: Read

        https://docs.aws.amazon.com/iotroborunner/latest/api/API_ListSites.html

        :stability: experimental
        '''
        return typing.cast("Iotroborunner", jsii.invoke(self, "toListSites", []))

    @jsii.member(jsii_name="toListTasks")
    def to_list_tasks(self) -> "Iotroborunner":
        '''(experimental) Grants permission to list tasks.

        Access Level: Read

        https://docs.aws.amazon.com/iotroborunner/latest/api/API_ListTasks.html

        :stability: experimental
        '''
        return typing.cast("Iotroborunner", jsii.invoke(self, "toListTasks", []))

    @jsii.member(jsii_name="toListWorkerFleets")
    def to_list_worker_fleets(self) -> "Iotroborunner":
        '''(experimental) Grants permission to list worker fleets.

        Access Level: Read

        https://docs.aws.amazon.com/iotroborunner/latest/api/API_ListWorkerFleets.html

        :stability: experimental
        '''
        return typing.cast("Iotroborunner", jsii.invoke(self, "toListWorkerFleets", []))

    @jsii.member(jsii_name="toListWorkers")
    def to_list_workers(self) -> "Iotroborunner":
        '''(experimental) Grants permission to list workers.

        Access Level: Read

        https://docs.aws.amazon.com/iotroborunner/latest/api/API_ListWorkers.html

        :stability: experimental
        '''
        return typing.cast("Iotroborunner", jsii.invoke(self, "toListWorkers", []))

    @jsii.member(jsii_name="toUpdateActionState")
    def to_update_action_state(self) -> "Iotroborunner":
        '''(experimental) Grants permission to update an action's state.

        Access Level: Write

        https://docs.aws.amazon.com/iotroborunner/latest/api/API_UpdateActionState.html

        :stability: experimental
        '''
        return typing.cast("Iotroborunner", jsii.invoke(self, "toUpdateActionState", []))

    @jsii.member(jsii_name="toUpdateActivity")
    def to_update_activity(self) -> "Iotroborunner":
        '''(experimental) Grants permission to update an activity.

        Access Level: Write

        https://docs.aws.amazon.com/iotroborunner/latest/api/API_UpdateActivity.html

        :stability: experimental
        '''
        return typing.cast("Iotroborunner", jsii.invoke(self, "toUpdateActivity", []))

    @jsii.member(jsii_name="toUpdateDestination")
    def to_update_destination(self) -> "Iotroborunner":
        '''(experimental) Grants permission to update a destination.

        Access Level: Write

        https://docs.aws.amazon.com/iotroborunner/latest/api/API_UpdateDestination.html

        :stability: experimental
        '''
        return typing.cast("Iotroborunner", jsii.invoke(self, "toUpdateDestination", []))

    @jsii.member(jsii_name="toUpdateSite")
    def to_update_site(self) -> "Iotroborunner":
        '''(experimental) Grants permission to update a site.

        Access Level: Write

        https://docs.aws.amazon.com/iotroborunner/latest/api/API_UpdateSite.html

        :stability: experimental
        '''
        return typing.cast("Iotroborunner", jsii.invoke(self, "toUpdateSite", []))

    @jsii.member(jsii_name="toUpdateTask")
    def to_update_task(self) -> "Iotroborunner":
        '''(experimental) Grants permission to update a task.

        Access Level: Write

        https://docs.aws.amazon.com/iotroborunner/latest/api/API_UpdateTask.html

        :stability: experimental
        '''
        return typing.cast("Iotroborunner", jsii.invoke(self, "toUpdateTask", []))

    @jsii.member(jsii_name="toUpdateWorker")
    def to_update_worker(self) -> "Iotroborunner":
        '''(experimental) Grants permission to update a worker.

        Access Level: Write

        https://docs.aws.amazon.com/iotroborunner/latest/api/API_UpdateWorker.html

        :stability: experimental
        '''
        return typing.cast("Iotroborunner", jsii.invoke(self, "toUpdateWorker", []))

    @jsii.member(jsii_name="toUpdateWorkerFleet")
    def to_update_worker_fleet(self) -> "Iotroborunner":
        '''(experimental) Grants permission to update a worker fleet.

        Access Level: Write

        https://docs.aws.amazon.com/iotroborunner/latest/api/API_UpdateWorkerFleet.html

        :stability: experimental
        '''
        return typing.cast("Iotroborunner", jsii.invoke(self, "toUpdateWorkerFleet", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4284aa283d42ed77c9ee56ed71cd98eb6384e0ecfa698355c1646c605e05201c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__dabbbe93ce9e9cb7e66d42e4eb1bb1babbafc40c9a681972c1836a8296583d07)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Iotsitewise(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Iotsitewise",
):
    '''(experimental) Statement provider for service `iotsitewise <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiotsitewise.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `iotsitewise <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiotsitewise.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="ifAssetHierarchyPath")
    def if_asset_hierarchy_path(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Iotsitewise":
        '''(experimental) Filters access by an asset hierarchy path, which is the string of asset IDs in the asset's hierarchy, each separated by a forward slash.

        https://docs.aws.amazon.com/iot-sitewise/latest/userguide/security_iam_service-with-iam.html#security_iam_service-with-iam-id-based-policies-conditionkeys

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fd03653ae5032a16c43b4aa5cf0a9774e332632bfd32338547201c1c26078d60)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Iotsitewise", jsii.invoke(self, "ifAssetHierarchyPath", [value, operator]))

    @jsii.member(jsii_name="ifChildAssetId")
    def if_child_asset_id(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Iotsitewise":
        '''(experimental) Filters access by the ID of a child asset being associated whith a parent asset.

        https://docs.aws.amazon.com/iot-sitewise/latest/userguide/security_iam_service-with-iam.html#security_iam_service-with-iam-id-based-policies-conditionkeys

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1674f05ab51b9bba4a4e826ced16236354ba9482bdb292d88c9de21947b871dc)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Iotsitewise", jsii.invoke(self, "ifChildAssetId", [value, operator]))

    @jsii.member(jsii_name="ifGroup")
    def if_group(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Iotsitewise":
        '''(experimental) Filters access by the ID of an AWS Single Sign-On group.

        https://docs.aws.amazon.com/iot-sitewise/latest/userguide/security_iam_service-with-iam.html#security_iam_service-with-iam-id-based-policies-conditionkeys

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e536f526919bacc1eec63b6dbfc5951a9663488eb28a78ba0c0fc7b8c2b1b01f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Iotsitewise", jsii.invoke(self, "ifGroup", [value, operator]))

    @jsii.member(jsii_name="ifIam")
    def if_iam(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Iotsitewise":
        '''(experimental) Filters access by the ID of an AWS IAM identity.

        https://docs.aws.amazon.com/iot-sitewise/latest/userguide/security_iam_service-with-iam.html#security_iam_service-with-iam-id-based-policies-conditionkeys

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f4de5e678efb461515fe63bd9dbaa0a1739f59e16e4425fa8b99b85ff1be52a7)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Iotsitewise", jsii.invoke(self, "ifIam", [value, operator]))

    @jsii.member(jsii_name="ifIsAssociatedWithAssetProperty")
    def if_is_associated_with_asset_property(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Iotsitewise":
        '''(experimental) Filters access by data streams associated with or not associated with asset properties.

        https://docs.aws.amazon.com/iot-sitewise/latest/userguide/security_iam_service-with-iam.html#security_iam_service-with-iam-id-based-policies-conditionkeys

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8877ad534b326708930759dc5ba22d425feb3f5412d7d760503abaeeff8cd9bb)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Iotsitewise", jsii.invoke(self, "ifIsAssociatedWithAssetProperty", [value, operator]))

    @jsii.member(jsii_name="ifPortal")
    def if_portal(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Iotsitewise":
        '''(experimental) Filters access by the ID of a portal.

        https://docs.aws.amazon.com/iot-sitewise/latest/userguide/security_iam_service-with-iam.html#security_iam_service-with-iam-id-based-policies-conditionkeys

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b009904e7ffd08d7031cbd7c3a183a00d77a4a2e6ed06fb1db5d381c8b7880c8)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Iotsitewise", jsii.invoke(self, "ifPortal", [value, operator]))

    @jsii.member(jsii_name="ifProject")
    def if_project(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Iotsitewise":
        '''(experimental) Filters access by the ID of a project.

        https://docs.aws.amazon.com/iot-sitewise/latest/userguide/security_iam_service-with-iam.html#security_iam_service-with-iam-id-based-policies-conditionkeys

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e7cfec82d03c1ac8ec9c3bfcd4c2fd323e36927770387729496ba47a0434595c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Iotsitewise", jsii.invoke(self, "ifProject", [value, operator]))

    @jsii.member(jsii_name="ifPropertyAlias")
    def if_property_alias(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Iotsitewise":
        '''(experimental) Filters access by the property alias.

        https://docs.aws.amazon.com/iot-sitewise/latest/userguide/security_iam_service-with-iam.html#security_iam_service-with-iam-id-based-policies-conditionkeys

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ce7aa42c79ea37e2a1a6ff7fe305aa47a7c8cf7c2609b5a29524a05f075128cb)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Iotsitewise", jsii.invoke(self, "ifPropertyAlias", [value, operator]))

    @jsii.member(jsii_name="ifPropertyId")
    def if_property_id(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Iotsitewise":
        '''(experimental) Filters access by the ID of an asset property.

        https://docs.aws.amazon.com/iot-sitewise/latest/userguide/security_iam_service-with-iam.html#security_iam_service-with-iam-id-based-policies-conditionkeys

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__72b28b9b4260ef694ebcc5412a90a68811863d2352585f07fa079265480e2ddf)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Iotsitewise", jsii.invoke(self, "ifPropertyId", [value, operator]))

    @jsii.member(jsii_name="ifUser")
    def if_user(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Iotsitewise":
        '''(experimental) Filters access by the ID of an AWS Single Sign-On user.

        https://docs.aws.amazon.com/iot-sitewise/latest/userguide/security_iam_service-with-iam.html#security_iam_service-with-iam-id-based-policies-conditionkeys

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__df4c5ef2d77df4c242c65ddfe400ae198f7cf3bcf30a364aacde02cf86e88396)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Iotsitewise", jsii.invoke(self, "ifUser", [value, operator]))

    @jsii.member(jsii_name="onAccessPolicy")
    def on_access_policy(
        self,
        access_policy_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Iotsitewise":
        '''(experimental) Adds a resource of type access-policy to the statement.

        https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_CreateAccessPolicy.html

        :param access_policy_id: - Identifier for the accessPolicyId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ca2372f34e51337e8962d2ac60403af4bdbe9139998843edf733cdcbfede807f)
            check_type(argname="argument access_policy_id", value=access_policy_id, expected_type=type_hints["access_policy_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Iotsitewise", jsii.invoke(self, "onAccessPolicy", [access_policy_id, account, region, partition]))

    @jsii.member(jsii_name="onAsset")
    def on_asset(
        self,
        asset_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Iotsitewise":
        '''(experimental) Adds a resource of type asset to the statement.

        https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_CreateAsset.html

        :param asset_id: - Identifier for the assetId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__18bcbafab073af9d988c2782ad9ad5d53b5ebaf43a1aba09a19b1e79dfa74f4b)
            check_type(argname="argument asset_id", value=asset_id, expected_type=type_hints["asset_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Iotsitewise", jsii.invoke(self, "onAsset", [asset_id, account, region, partition]))

    @jsii.member(jsii_name="onAssetModel")
    def on_asset_model(
        self,
        asset_model_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Iotsitewise":
        '''(experimental) Adds a resource of type asset-model to the statement.

        https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_CreateAssetModel.html

        :param asset_model_id: - Identifier for the assetModelId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__900c15ed8785d39259dcab4f6ab4182cb901bb0c5cc2610bde74da2c891e8d91)
            check_type(argname="argument asset_model_id", value=asset_model_id, expected_type=type_hints["asset_model_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Iotsitewise", jsii.invoke(self, "onAssetModel", [asset_model_id, account, region, partition]))

    @jsii.member(jsii_name="onDashboard")
    def on_dashboard(
        self,
        dashboard_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Iotsitewise":
        '''(experimental) Adds a resource of type dashboard to the statement.

        https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_CreateDashboard.html

        :param dashboard_id: - Identifier for the dashboardId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e854a824354f582a2b57aed3fbe7ab8c74a020fdc1b983e079560957eac35323)
            check_type(argname="argument dashboard_id", value=dashboard_id, expected_type=type_hints["dashboard_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Iotsitewise", jsii.invoke(self, "onDashboard", [dashboard_id, account, region, partition]))

    @jsii.member(jsii_name="onGateway")
    def on_gateway(
        self,
        gateway_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Iotsitewise":
        '''(experimental) Adds a resource of type gateway to the statement.

        https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_CreateGateway.html

        :param gateway_id: - Identifier for the gatewayId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6655d6fe3fd71b73bf9c7341e3cc86d548389fe113608b96c3af675d8e63e1de)
            check_type(argname="argument gateway_id", value=gateway_id, expected_type=type_hints["gateway_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Iotsitewise", jsii.invoke(self, "onGateway", [gateway_id, account, region, partition]))

    @jsii.member(jsii_name="onPortal")
    def on_portal(
        self,
        portal_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Iotsitewise":
        '''(experimental) Adds a resource of type portal to the statement.

        https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_CreatePortal.html

        :param portal_id: - Identifier for the portalId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__68a0933478402b818eb8eb95dc70844da834128dd9b1a3f52667c6c8fd67641c)
            check_type(argname="argument portal_id", value=portal_id, expected_type=type_hints["portal_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Iotsitewise", jsii.invoke(self, "onPortal", [portal_id, account, region, partition]))

    @jsii.member(jsii_name="onProject")
    def on_project(
        self,
        project_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Iotsitewise":
        '''(experimental) Adds a resource of type project to the statement.

        https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_CreateProject.html

        :param project_id: - Identifier for the projectId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ca1e915f9c2b541beea931c7b17553a73bc6b8a9f92f5038e1f2f00f3613e189)
            check_type(argname="argument project_id", value=project_id, expected_type=type_hints["project_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Iotsitewise", jsii.invoke(self, "onProject", [project_id, account, region, partition]))

    @jsii.member(jsii_name="onTimeSeries")
    def on_time_series(
        self,
        time_series_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Iotsitewise":
        '''(experimental) Adds a resource of type time-series to the statement.

        https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_DescribeTimeSeries.html

        :param time_series_id: - Identifier for the timeSeriesId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3cafc7498e4509764b2bc43adb07e7e4576715485d2ba0cd42c51a39d68b1822)
            check_type(argname="argument time_series_id", value=time_series_id, expected_type=type_hints["time_series_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Iotsitewise", jsii.invoke(self, "onTimeSeries", [time_series_id, account, region, partition]))

    @jsii.member(jsii_name="toAssociateAssets")
    def to_associate_assets(self) -> "Iotsitewise":
        '''(experimental) Grants permission to associate a child asset with a parent asset through a hierarchy.

        Access Level: Write

        https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_AssociateAssets.html

        :stability: experimental
        '''
        return typing.cast("Iotsitewise", jsii.invoke(self, "toAssociateAssets", []))

    @jsii.member(jsii_name="toAssociateTimeSeriesToAssetProperty")
    def to_associate_time_series_to_asset_property(self) -> "Iotsitewise":
        '''(experimental) Grants permission to associate a time series with an asset property.

        Access Level: Write

        https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_AssociateTimeSeriesToAssetProperty.html

        :stability: experimental
        '''
        return typing.cast("Iotsitewise", jsii.invoke(self, "toAssociateTimeSeriesToAssetProperty", []))

    @jsii.member(jsii_name="toBatchAssociateProjectAssets")
    def to_batch_associate_project_assets(self) -> "Iotsitewise":
        '''(experimental) Grants permission to associate assets to a project.

        Access Level: Write

        https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_BatchAssociateProjectAssets.html

        :stability: experimental
        '''
        return typing.cast("Iotsitewise", jsii.invoke(self, "toBatchAssociateProjectAssets", []))

    @jsii.member(jsii_name="toBatchDisassociateProjectAssets")
    def to_batch_disassociate_project_assets(self) -> "Iotsitewise":
        '''(experimental) Grants permission to disassociate assets from a project.

        Access Level: Write

        https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_BatchDisassociateProjectAssets.html

        :stability: experimental
        '''
        return typing.cast("Iotsitewise", jsii.invoke(self, "toBatchDisassociateProjectAssets", []))

    @jsii.member(jsii_name="toBatchGetAssetPropertyAggregates")
    def to_batch_get_asset_property_aggregates(self) -> "Iotsitewise":
        '''(experimental) Grants permission to retrieve computed aggregates for multiple asset properties.

        Access Level: Read

        https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_BatchGetAssetPropertyAggregates.html

        :stability: experimental
        '''
        return typing.cast("Iotsitewise", jsii.invoke(self, "toBatchGetAssetPropertyAggregates", []))

    @jsii.member(jsii_name="toBatchGetAssetPropertyValue")
    def to_batch_get_asset_property_value(self) -> "Iotsitewise":
        '''(experimental) Grants permission to retrieve the latest value for multiple asset properties.

        Access Level: Read

        https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_BatchGetAssetPropertyValue.html

        :stability: experimental
        '''
        return typing.cast("Iotsitewise", jsii.invoke(self, "toBatchGetAssetPropertyValue", []))

    @jsii.member(jsii_name="toBatchGetAssetPropertyValueHistory")
    def to_batch_get_asset_property_value_history(self) -> "Iotsitewise":
        '''(experimental) Grants permission to retrieve the value history for multiple asset properties.

        Access Level: Read

        https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_BatchGetAssetPropertyValueHistory.html

        :stability: experimental
        '''
        return typing.cast("Iotsitewise", jsii.invoke(self, "toBatchGetAssetPropertyValueHistory", []))

    @jsii.member(jsii_name="toBatchPutAssetPropertyValue")
    def to_batch_put_asset_property_value(self) -> "Iotsitewise":
        '''(experimental) Grants permission to put property values for asset properties.

        Access Level: Write

        https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_BatchPutAssetPropertyValue.html

        :stability: experimental
        '''
        return typing.cast("Iotsitewise", jsii.invoke(self, "toBatchPutAssetPropertyValue", []))

    @jsii.member(jsii_name="toCreateAccessPolicy")
    def to_create_access_policy(self) -> "Iotsitewise":
        '''(experimental) Grants permission to create an access policy for a portal or a project.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_CreateAccessPolicy.html

        :stability: experimental
        '''
        return typing.cast("Iotsitewise", jsii.invoke(self, "toCreateAccessPolicy", []))

    @jsii.member(jsii_name="toCreateAsset")
    def to_create_asset(self) -> "Iotsitewise":
        '''(experimental) Grants permission to create an asset from an asset model.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_CreateAsset.html

        :stability: experimental
        '''
        return typing.cast("Iotsitewise", jsii.invoke(self, "toCreateAsset", []))

    @jsii.member(jsii_name="toCreateAssetModel")
    def to_create_asset_model(self) -> "Iotsitewise":
        '''(experimental) Grants permission to create an asset model.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_CreateAssetModel.html

        :stability: experimental
        '''
        return typing.cast("Iotsitewise", jsii.invoke(self, "toCreateAssetModel", []))

    @jsii.member(jsii_name="toCreateBulkImportJob")
    def to_create_bulk_import_job(self) -> "Iotsitewise":
        '''(experimental) Grants permission to create bulk import job.

        Access Level: Write

        https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_CreateBulkImportJob.html

        :stability: experimental
        '''
        return typing.cast("Iotsitewise", jsii.invoke(self, "toCreateBulkImportJob", []))

    @jsii.member(jsii_name="toCreateDashboard")
    def to_create_dashboard(self) -> "Iotsitewise":
        '''(experimental) Grants permission to create a dashboard in a project.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_CreateDashboard.html

        :stability: experimental
        '''
        return typing.cast("Iotsitewise", jsii.invoke(self, "toCreateDashboard", []))

    @jsii.member(jsii_name="toCreateGateway")
    def to_create_gateway(self) -> "Iotsitewise":
        '''(experimental) Grants permission to create a gateway.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_CreateGateway.html

        :stability: experimental
        '''
        return typing.cast("Iotsitewise", jsii.invoke(self, "toCreateGateway", []))

    @jsii.member(jsii_name="toCreatePortal")
    def to_create_portal(self) -> "Iotsitewise":
        '''(experimental) Grants permission to create a portal.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - sso:CreateManagedApplicationInstance
        - sso:DescribeRegisteredRegions

        https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_CreatePortal.html

        :stability: experimental
        '''
        return typing.cast("Iotsitewise", jsii.invoke(self, "toCreatePortal", []))

    @jsii.member(jsii_name="toCreateProject")
    def to_create_project(self) -> "Iotsitewise":
        '''(experimental) Grants permission to create a project in a portal.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_CreateProject.html

        :stability: experimental
        '''
        return typing.cast("Iotsitewise", jsii.invoke(self, "toCreateProject", []))

    @jsii.member(jsii_name="toDeleteAccessPolicy")
    def to_delete_access_policy(self) -> "Iotsitewise":
        '''(experimental) Grants permission to delete an access policy.

        Access Level: Write

        https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_DeleteAccessPolicy.html

        :stability: experimental
        '''
        return typing.cast("Iotsitewise", jsii.invoke(self, "toDeleteAccessPolicy", []))

    @jsii.member(jsii_name="toDeleteAsset")
    def to_delete_asset(self) -> "Iotsitewise":
        '''(experimental) Grants permission to delete an asset.

        Access Level: Write

        https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_DeleteAsset.html

        :stability: experimental
        '''
        return typing.cast("Iotsitewise", jsii.invoke(self, "toDeleteAsset", []))

    @jsii.member(jsii_name="toDeleteAssetModel")
    def to_delete_asset_model(self) -> "Iotsitewise":
        '''(experimental) Grants permission to delete an asset model.

        Access Level: Write

        https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_DeleteAssetModel.html

        :stability: experimental
        '''
        return typing.cast("Iotsitewise", jsii.invoke(self, "toDeleteAssetModel", []))

    @jsii.member(jsii_name="toDeleteDashboard")
    def to_delete_dashboard(self) -> "Iotsitewise":
        '''(experimental) Grants permission to delete a dashboard.

        Access Level: Write

        https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_DeleteDashboard.html

        :stability: experimental
        '''
        return typing.cast("Iotsitewise", jsii.invoke(self, "toDeleteDashboard", []))

    @jsii.member(jsii_name="toDeleteGateway")
    def to_delete_gateway(self) -> "Iotsitewise":
        '''(experimental) Grants permission to delete a gateway.

        Access Level: Write

        https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_DeleteGateway.html

        :stability: experimental
        '''
        return typing.cast("Iotsitewise", jsii.invoke(self, "toDeleteGateway", []))

    @jsii.member(jsii_name="toDeletePortal")
    def to_delete_portal(self) -> "Iotsitewise":
        '''(experimental) Grants permission to delete a portal.

        Access Level: Write

        Dependent actions:

        - sso:DeleteManagedApplicationInstance

        https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_DeletePortal.html

        :stability: experimental
        '''
        return typing.cast("Iotsitewise", jsii.invoke(self, "toDeletePortal", []))

    @jsii.member(jsii_name="toDeleteProject")
    def to_delete_project(self) -> "Iotsitewise":
        '''(experimental) Grants permission to delete a project.

        Access Level: Write

        https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_DeleteProject.html

        :stability: experimental
        '''
        return typing.cast("Iotsitewise", jsii.invoke(self, "toDeleteProject", []))

    @jsii.member(jsii_name="toDeleteTimeSeries")
    def to_delete_time_series(self) -> "Iotsitewise":
        '''(experimental) Grants permission to delete a time series.

        Access Level: Write

        https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_DeleteTimeSeries.html

        :stability: experimental
        '''
        return typing.cast("Iotsitewise", jsii.invoke(self, "toDeleteTimeSeries", []))

    @jsii.member(jsii_name="toDescribeAccessPolicy")
    def to_describe_access_policy(self) -> "Iotsitewise":
        '''(experimental) Grants permission to describe an access policy.

        Access Level: Read

        https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_DescribeAccessPolicy.html

        :stability: experimental
        '''
        return typing.cast("Iotsitewise", jsii.invoke(self, "toDescribeAccessPolicy", []))

    @jsii.member(jsii_name="toDescribeAsset")
    def to_describe_asset(self) -> "Iotsitewise":
        '''(experimental) Grants permission to describe an asset.

        Access Level: Read

        https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_DescribeAsset.html

        :stability: experimental
        '''
        return typing.cast("Iotsitewise", jsii.invoke(self, "toDescribeAsset", []))

    @jsii.member(jsii_name="toDescribeAssetModel")
    def to_describe_asset_model(self) -> "Iotsitewise":
        '''(experimental) Grants permission to describe an asset model.

        Access Level: Read

        https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_DescribeAssetModel.html

        :stability: experimental
        '''
        return typing.cast("Iotsitewise", jsii.invoke(self, "toDescribeAssetModel", []))

    @jsii.member(jsii_name="toDescribeAssetProperty")
    def to_describe_asset_property(self) -> "Iotsitewise":
        '''(experimental) Grants permission to describe an asset property.

        Access Level: Read

        https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_DescribeAssetProperty.html

        :stability: experimental
        '''
        return typing.cast("Iotsitewise", jsii.invoke(self, "toDescribeAssetProperty", []))

    @jsii.member(jsii_name="toDescribeBulkImportJob")
    def to_describe_bulk_import_job(self) -> "Iotsitewise":
        '''(experimental) Grants permission to describe bulk import job.

        Access Level: Read

        https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_DescribeBulkImportJob.html

        :stability: experimental
        '''
        return typing.cast("Iotsitewise", jsii.invoke(self, "toDescribeBulkImportJob", []))

    @jsii.member(jsii_name="toDescribeDashboard")
    def to_describe_dashboard(self) -> "Iotsitewise":
        '''(experimental) Grants permission to describe a dashboard.

        Access Level: Read

        https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_DescribeDashboard.html

        :stability: experimental
        '''
        return typing.cast("Iotsitewise", jsii.invoke(self, "toDescribeDashboard", []))

    @jsii.member(jsii_name="toDescribeDefaultEncryptionConfiguration")
    def to_describe_default_encryption_configuration(self) -> "Iotsitewise":
        '''(experimental) Grants permission to describe the default encryption configuration for the AWS account.

        Access Level: Read

        https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_DescribeDefaultEncryptionConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Iotsitewise", jsii.invoke(self, "toDescribeDefaultEncryptionConfiguration", []))

    @jsii.member(jsii_name="toDescribeGateway")
    def to_describe_gateway(self) -> "Iotsitewise":
        '''(experimental) Grants permission to describe a gateway.

        Access Level: Read

        https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_DescribeGateway.html

        :stability: experimental
        '''
        return typing.cast("Iotsitewise", jsii.invoke(self, "toDescribeGateway", []))

    @jsii.member(jsii_name="toDescribeGatewayCapabilityConfiguration")
    def to_describe_gateway_capability_configuration(self) -> "Iotsitewise":
        '''(experimental) Grants permission to describe a capability configuration for a gateway.

        Access Level: Read

        https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_DescribeGatewayCapabilityConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Iotsitewise", jsii.invoke(self, "toDescribeGatewayCapabilityConfiguration", []))

    @jsii.member(jsii_name="toDescribeLoggingOptions")
    def to_describe_logging_options(self) -> "Iotsitewise":
        '''(experimental) Grants permission to describe logging options for the AWS account.

        Access Level: Read

        https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_DescribeLoggingOptions.html

        :stability: experimental
        '''
        return typing.cast("Iotsitewise", jsii.invoke(self, "toDescribeLoggingOptions", []))

    @jsii.member(jsii_name="toDescribePortal")
    def to_describe_portal(self) -> "Iotsitewise":
        '''(experimental) Grants permission to describe a portal.

        Access Level: Read

        https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_DescribePortal.html

        :stability: experimental
        '''
        return typing.cast("Iotsitewise", jsii.invoke(self, "toDescribePortal", []))

    @jsii.member(jsii_name="toDescribeProject")
    def to_describe_project(self) -> "Iotsitewise":
        '''(experimental) Grants permission to describe a project.

        Access Level: Read

        https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_DescribeProject.html

        :stability: experimental
        '''
        return typing.cast("Iotsitewise", jsii.invoke(self, "toDescribeProject", []))

    @jsii.member(jsii_name="toDescribeStorageConfiguration")
    def to_describe_storage_configuration(self) -> "Iotsitewise":
        '''(experimental) Grants permission to describe the storage configuration for the AWS account.

        Access Level: Read

        https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_DescribeStorageConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Iotsitewise", jsii.invoke(self, "toDescribeStorageConfiguration", []))

    @jsii.member(jsii_name="toDescribeTimeSeries")
    def to_describe_time_series(self) -> "Iotsitewise":
        '''(experimental) Grants permission to describe a time series.

        Access Level: Read

        https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_DescribeTimeSeries.html

        :stability: experimental
        '''
        return typing.cast("Iotsitewise", jsii.invoke(self, "toDescribeTimeSeries", []))

    @jsii.member(jsii_name="toDisassociateAssets")
    def to_disassociate_assets(self) -> "Iotsitewise":
        '''(experimental) Grants permission to disassociate a child asset from a parent asset by a hierarchy.

        Access Level: Write

        https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_DisassociateAssets.html

        :stability: experimental
        '''
        return typing.cast("Iotsitewise", jsii.invoke(self, "toDisassociateAssets", []))

    @jsii.member(jsii_name="toDisassociateTimeSeriesFromAssetProperty")
    def to_disassociate_time_series_from_asset_property(self) -> "Iotsitewise":
        '''(experimental) Grants permission to disassociate a time series from an asset property.

        Access Level: Write

        https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_DisassociateTimeSeriesFromAssetProperty.html

        :stability: experimental
        '''
        return typing.cast("Iotsitewise", jsii.invoke(self, "toDisassociateTimeSeriesFromAssetProperty", []))

    @jsii.member(jsii_name="toGetAssetPropertyAggregates")
    def to_get_asset_property_aggregates(self) -> "Iotsitewise":
        '''(experimental) Grants permission to retrieve computed aggregates for an asset property.

        Access Level: Read

        https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_GetAssetPropertyAggregates.html

        :stability: experimental
        '''
        return typing.cast("Iotsitewise", jsii.invoke(self, "toGetAssetPropertyAggregates", []))

    @jsii.member(jsii_name="toGetAssetPropertyValue")
    def to_get_asset_property_value(self) -> "Iotsitewise":
        '''(experimental) Grants permission to retrieve the latest value for an asset property.

        Access Level: Read

        https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_GetAssetPropertyValue.html

        :stability: experimental
        '''
        return typing.cast("Iotsitewise", jsii.invoke(self, "toGetAssetPropertyValue", []))

    @jsii.member(jsii_name="toGetAssetPropertyValueHistory")
    def to_get_asset_property_value_history(self) -> "Iotsitewise":
        '''(experimental) Grants permission to retrieve the value history for an asset property.

        Access Level: Read

        https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_GetAssetPropertyValueHistory.html

        :stability: experimental
        '''
        return typing.cast("Iotsitewise", jsii.invoke(self, "toGetAssetPropertyValueHistory", []))

    @jsii.member(jsii_name="toGetInterpolatedAssetPropertyValues")
    def to_get_interpolated_asset_property_values(self) -> "Iotsitewise":
        '''(experimental) Grants permission to retrieve interpolated values for an asset property.

        Access Level: Read

        https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_GetInterpolatedAssetPropertyValues.html

        :stability: experimental
        '''
        return typing.cast("Iotsitewise", jsii.invoke(self, "toGetInterpolatedAssetPropertyValues", []))

    @jsii.member(jsii_name="toListAccessPolicies")
    def to_list_access_policies(self) -> "Iotsitewise":
        '''(experimental) Grants permission to list all access policies for an identity or a resource.

        Access Level: List

        https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_ListAccessPolicies.html

        :stability: experimental
        '''
        return typing.cast("Iotsitewise", jsii.invoke(self, "toListAccessPolicies", []))

    @jsii.member(jsii_name="toListAssetModels")
    def to_list_asset_models(self) -> "Iotsitewise":
        '''(experimental) Grants permission to list all asset models.

        Access Level: List

        https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_ListAssetModels.html

        :stability: experimental
        '''
        return typing.cast("Iotsitewise", jsii.invoke(self, "toListAssetModels", []))

    @jsii.member(jsii_name="toListAssetRelationships")
    def to_list_asset_relationships(self) -> "Iotsitewise":
        '''(experimental) Grants permission to list the asset relationship graph for an asset.

        Access Level: List

        https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_ListAssetRelationships.html

        :stability: experimental
        '''
        return typing.cast("Iotsitewise", jsii.invoke(self, "toListAssetRelationships", []))

    @jsii.member(jsii_name="toListAssets")
    def to_list_assets(self) -> "Iotsitewise":
        '''(experimental) Grants permission to list all assets.

        Access Level: List

        https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_ListAssets.html

        :stability: experimental
        '''
        return typing.cast("Iotsitewise", jsii.invoke(self, "toListAssets", []))

    @jsii.member(jsii_name="toListAssociatedAssets")
    def to_list_associated_assets(self) -> "Iotsitewise":
        '''(experimental) Grants permission to list all assets associated with an asset through a hierarchy.

        Access Level: List

        https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_ListAssociatedAssets.html

        :stability: experimental
        '''
        return typing.cast("Iotsitewise", jsii.invoke(self, "toListAssociatedAssets", []))

    @jsii.member(jsii_name="toListBulkImportJobs")
    def to_list_bulk_import_jobs(self) -> "Iotsitewise":
        '''(experimental) Grants permission to list bulk import jobs.

        Access Level: List

        https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_ListBulkImportJobs.html

        :stability: experimental
        '''
        return typing.cast("Iotsitewise", jsii.invoke(self, "toListBulkImportJobs", []))

    @jsii.member(jsii_name="toListDashboards")
    def to_list_dashboards(self) -> "Iotsitewise":
        '''(experimental) Grants permission to list all dashboards in a project.

        Access Level: List

        https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_ListDashboards.html

        :stability: experimental
        '''
        return typing.cast("Iotsitewise", jsii.invoke(self, "toListDashboards", []))

    @jsii.member(jsii_name="toListGateways")
    def to_list_gateways(self) -> "Iotsitewise":
        '''(experimental) Grants permission to list all gateways.

        Access Level: List

        https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_ListGateways.html

        :stability: experimental
        '''
        return typing.cast("Iotsitewise", jsii.invoke(self, "toListGateways", []))

    @jsii.member(jsii_name="toListPortals")
    def to_list_portals(self) -> "Iotsitewise":
        '''(experimental) Grants permission to list all portals.

        Access Level: List

        https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_ListPortals.html

        :stability: experimental
        '''
        return typing.cast("Iotsitewise", jsii.invoke(self, "toListPortals", []))

    @jsii.member(jsii_name="toListProjectAssets")
    def to_list_project_assets(self) -> "Iotsitewise":
        '''(experimental) Grants permission to list all assets associated with a project.

        Access Level: List

        https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_ListProjectAssets.html

        :stability: experimental
        '''
        return typing.cast("Iotsitewise", jsii.invoke(self, "toListProjectAssets", []))

    @jsii.member(jsii_name="toListProjects")
    def to_list_projects(self) -> "Iotsitewise":
        '''(experimental) Grants permission to list all projects in a portal.

        Access Level: List

        https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_ListProjects.html

        :stability: experimental
        '''
        return typing.cast("Iotsitewise", jsii.invoke(self, "toListProjects", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Iotsitewise":
        '''(experimental) Grants permission to list all tags for a resource.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("Iotsitewise", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toListTimeSeries")
    def to_list_time_series(self) -> "Iotsitewise":
        '''(experimental) Grants permission to list time series.

        Access Level: List

        https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_ListTimeSeries.html

        :stability: experimental
        '''
        return typing.cast("Iotsitewise", jsii.invoke(self, "toListTimeSeries", []))

    @jsii.member(jsii_name="toPutDefaultEncryptionConfiguration")
    def to_put_default_encryption_configuration(self) -> "Iotsitewise":
        '''(experimental) Grants permission to set the default encryption configuration for the AWS account.

        Access Level: Write

        https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_PutDefaultEncryptionConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Iotsitewise", jsii.invoke(self, "toPutDefaultEncryptionConfiguration", []))

    @jsii.member(jsii_name="toPutLoggingOptions")
    def to_put_logging_options(self) -> "Iotsitewise":
        '''(experimental) Grants permission to set logging options for the AWS account.

        Access Level: Write

        https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_PutLoggingOptions.html

        :stability: experimental
        '''
        return typing.cast("Iotsitewise", jsii.invoke(self, "toPutLoggingOptions", []))

    @jsii.member(jsii_name="toPutStorageConfiguration")
    def to_put_storage_configuration(self) -> "Iotsitewise":
        '''(experimental) Grants permission to configure storage settings for the AWS account.

        Access Level: Write

        https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_PutStorageConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Iotsitewise", jsii.invoke(self, "toPutStorageConfiguration", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Iotsitewise":
        '''(experimental) Grants permission to tag a resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("Iotsitewise", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Iotsitewise":
        '''(experimental) Grants permission to untag a resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("Iotsitewise", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateAccessPolicy")
    def to_update_access_policy(self) -> "Iotsitewise":
        '''(experimental) Grants permission to update an access policy.

        Access Level: Write

        https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_UpdateAccessPolicy.html

        :stability: experimental
        '''
        return typing.cast("Iotsitewise", jsii.invoke(self, "toUpdateAccessPolicy", []))

    @jsii.member(jsii_name="toUpdateAsset")
    def to_update_asset(self) -> "Iotsitewise":
        '''(experimental) Grants permission to update an asset.

        Access Level: Write

        https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_UpdateAsset.html

        :stability: experimental
        '''
        return typing.cast("Iotsitewise", jsii.invoke(self, "toUpdateAsset", []))

    @jsii.member(jsii_name="toUpdateAssetModel")
    def to_update_asset_model(self) -> "Iotsitewise":
        '''(experimental) Grants permission to update an asset model.

        Access Level: Write

        https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_UpdateAssetModel.html

        :stability: experimental
        '''
        return typing.cast("Iotsitewise", jsii.invoke(self, "toUpdateAssetModel", []))

    @jsii.member(jsii_name="toUpdateAssetModelPropertyRouting")
    def to_update_asset_model_property_routing(self) -> "Iotsitewise":
        '''(experimental) Grants permission to update an AssetModel property routing.

        Access Level: Write

        :stability: experimental
        '''
        return typing.cast("Iotsitewise", jsii.invoke(self, "toUpdateAssetModelPropertyRouting", []))

    @jsii.member(jsii_name="toUpdateAssetProperty")
    def to_update_asset_property(self) -> "Iotsitewise":
        '''(experimental) Grants permission to update an asset property.

        Access Level: Write

        https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_UpdateAssetProperty.html

        :stability: experimental
        '''
        return typing.cast("Iotsitewise", jsii.invoke(self, "toUpdateAssetProperty", []))

    @jsii.member(jsii_name="toUpdateDashboard")
    def to_update_dashboard(self) -> "Iotsitewise":
        '''(experimental) Grants permission to update a dashboard.

        Access Level: Write

        https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_UpdateDashboard.html

        :stability: experimental
        '''
        return typing.cast("Iotsitewise", jsii.invoke(self, "toUpdateDashboard", []))

    @jsii.member(jsii_name="toUpdateGateway")
    def to_update_gateway(self) -> "Iotsitewise":
        '''(experimental) Grants permission to update a gateway.

        Access Level: Write

        https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_UpdateGateway.html

        :stability: experimental
        '''
        return typing.cast("Iotsitewise", jsii.invoke(self, "toUpdateGateway", []))

    @jsii.member(jsii_name="toUpdateGatewayCapabilityConfiguration")
    def to_update_gateway_capability_configuration(self) -> "Iotsitewise":
        '''(experimental) Grants permission to update a capability configuration for a gateway.

        Access Level: Write

        https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_UpdateGatewayCapabilityConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Iotsitewise", jsii.invoke(self, "toUpdateGatewayCapabilityConfiguration", []))

    @jsii.member(jsii_name="toUpdatePortal")
    def to_update_portal(self) -> "Iotsitewise":
        '''(experimental) Grants permission to update a portal.

        Access Level: Write

        https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_UpdatePortal.html

        :stability: experimental
        '''
        return typing.cast("Iotsitewise", jsii.invoke(self, "toUpdatePortal", []))

    @jsii.member(jsii_name="toUpdateProject")
    def to_update_project(self) -> "Iotsitewise":
        '''(experimental) Grants permission to update a project.

        Access Level: Write

        https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_UpdateProject.html

        :stability: experimental
        '''
        return typing.cast("Iotsitewise", jsii.invoke(self, "toUpdateProject", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e75d29f189776cfb14d0067cb3acb21cb5d3233d4626425e50f8e04eff0d6d2f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a193eeee3605ea4c1742b32ca86fe32983bac3ed1e07a51bcc5911727b91a7b4)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Iottwinmaker(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Iottwinmaker",
):
    '''(experimental) Statement provider for service `iottwinmaker <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiottwinmaker.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `iottwinmaker <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiottwinmaker.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onComponentType")
    def on_component_type(
        self,
        workspace_id: builtins.str,
        component_type_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Iottwinmaker":
        '''(experimental) Adds a resource of type componentType to the statement.

        https://docs.aws.amazon.com/iot-twinmaker/latest/apireference/API_CreateComponentType.html

        :param workspace_id: - Identifier for the workspaceId.
        :param component_type_id: - Identifier for the componentTypeId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7ec9c9c8619cd8c5bb05da8ef4da3768f698ff53fdf7c6046dcc260eac2576bd)
            check_type(argname="argument workspace_id", value=workspace_id, expected_type=type_hints["workspace_id"])
            check_type(argname="argument component_type_id", value=component_type_id, expected_type=type_hints["component_type_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Iottwinmaker", jsii.invoke(self, "onComponentType", [workspace_id, component_type_id, account, region, partition]))

    @jsii.member(jsii_name="onEntity")
    def on_entity(
        self,
        workspace_id: builtins.str,
        entity_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Iottwinmaker":
        '''(experimental) Adds a resource of type entity to the statement.

        https://docs.aws.amazon.com/iot-twinmaker/latest/apireference/API_CreateEntity.html

        :param workspace_id: - Identifier for the workspaceId.
        :param entity_id: - Identifier for the entityId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6f1f71e9761b412c5cfec36cab3175bacb4fa5402576e2b87caa15ba6b5acdb1)
            check_type(argname="argument workspace_id", value=workspace_id, expected_type=type_hints["workspace_id"])
            check_type(argname="argument entity_id", value=entity_id, expected_type=type_hints["entity_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Iottwinmaker", jsii.invoke(self, "onEntity", [workspace_id, entity_id, account, region, partition]))

    @jsii.member(jsii_name="onScene")
    def on_scene(
        self,
        workspace_id: builtins.str,
        scene_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Iottwinmaker":
        '''(experimental) Adds a resource of type scene to the statement.

        https://docs.aws.amazon.com/iot-twinmaker/latest/apireference/API_CreateScene.html

        :param workspace_id: - Identifier for the workspaceId.
        :param scene_id: - Identifier for the sceneId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6ca2bd6194ae29569332580a481def766d93290ec93c792aff632dd2f53ea54a)
            check_type(argname="argument workspace_id", value=workspace_id, expected_type=type_hints["workspace_id"])
            check_type(argname="argument scene_id", value=scene_id, expected_type=type_hints["scene_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Iottwinmaker", jsii.invoke(self, "onScene", [workspace_id, scene_id, account, region, partition]))

    @jsii.member(jsii_name="onSyncJob")
    def on_sync_job(
        self,
        workspace_id: builtins.str,
        sync_job_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Iottwinmaker":
        '''(experimental) Adds a resource of type syncJob to the statement.

        https://docs.aws.amazon.com/iot-twinmaker/latest/apireference/API_CreateSyncJob.html

        :param workspace_id: - Identifier for the workspaceId.
        :param sync_job_id: - Identifier for the syncJobId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__378c9edf5c03461e55598a116d9d12bbd218b1ca77260dfe9fd5e7b65b19fa8e)
            check_type(argname="argument workspace_id", value=workspace_id, expected_type=type_hints["workspace_id"])
            check_type(argname="argument sync_job_id", value=sync_job_id, expected_type=type_hints["sync_job_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Iottwinmaker", jsii.invoke(self, "onSyncJob", [workspace_id, sync_job_id, account, region, partition]))

    @jsii.member(jsii_name="onWorkspace")
    def on_workspace(
        self,
        workspace_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Iottwinmaker":
        '''(experimental) Adds a resource of type workspace to the statement.

        https://docs.aws.amazon.com/iot-twinmaker/latest/apireference/API_CreateWorkspace.html

        :param workspace_id: - Identifier for the workspaceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__574da2497b0f29b452278429a5ad113f8cd5e9f917fe236ebe4e68539c3b226e)
            check_type(argname="argument workspace_id", value=workspace_id, expected_type=type_hints["workspace_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Iottwinmaker", jsii.invoke(self, "onWorkspace", [workspace_id, account, region, partition]))

    @jsii.member(jsii_name="toBatchPutPropertyValues")
    def to_batch_put_property_values(self) -> "Iottwinmaker":
        '''(experimental) Grants permission to set values for multiple time series properties.

        Access Level: Write

        Dependent actions:

        - iottwinmaker:GetComponentType
        - iottwinmaker:GetEntity
        - iottwinmaker:GetWorkspace

        https://docs.aws.amazon.com/iot-twinmaker/latest/apireference/API_BatchPutPropertyValues.html

        :stability: experimental
        '''
        return typing.cast("Iottwinmaker", jsii.invoke(self, "toBatchPutPropertyValues", []))

    @jsii.member(jsii_name="toCreateComponentType")
    def to_create_component_type(self) -> "Iottwinmaker":
        '''(experimental) Grants permission to create a componentType.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/iot-twinmaker/latest/apireference/API_CreateComponentType.html

        :stability: experimental
        '''
        return typing.cast("Iottwinmaker", jsii.invoke(self, "toCreateComponentType", []))

    @jsii.member(jsii_name="toCreateEntity")
    def to_create_entity(self) -> "Iottwinmaker":
        '''(experimental) Grants permission to create an entity.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/iot-twinmaker/latest/apireference/API_CreateEntity.html

        :stability: experimental
        '''
        return typing.cast("Iottwinmaker", jsii.invoke(self, "toCreateEntity", []))

    @jsii.member(jsii_name="toCreateScene")
    def to_create_scene(self) -> "Iottwinmaker":
        '''(experimental) Grants permission to create a scene.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/iot-twinmaker/latest/apireference/API_CreateScene.html

        :stability: experimental
        '''
        return typing.cast("Iottwinmaker", jsii.invoke(self, "toCreateScene", []))

    @jsii.member(jsii_name="toCreateSyncJob")
    def to_create_sync_job(self) -> "Iottwinmaker":
        '''(experimental) Grants permission to create a sync job.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/iot-twinmaker/latest/apireference/API_CreateSyncJob.html

        :stability: experimental
        '''
        return typing.cast("Iottwinmaker", jsii.invoke(self, "toCreateSyncJob", []))

    @jsii.member(jsii_name="toCreateWorkspace")
    def to_create_workspace(self) -> "Iottwinmaker":
        '''(experimental) Grants permission to create a workspace.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/iot-twinmaker/latest/apireference/API_CreateWorkspace.html

        :stability: experimental
        '''
        return typing.cast("Iottwinmaker", jsii.invoke(self, "toCreateWorkspace", []))

    @jsii.member(jsii_name="toDeleteComponentType")
    def to_delete_component_type(self) -> "Iottwinmaker":
        '''(experimental) Grants permission to delete a componentType.

        Access Level: Write

        https://docs.aws.amazon.com/iot-twinmaker/latest/apireference/API_DeleteComponentType.html

        :stability: experimental
        '''
        return typing.cast("Iottwinmaker", jsii.invoke(self, "toDeleteComponentType", []))

    @jsii.member(jsii_name="toDeleteEntity")
    def to_delete_entity(self) -> "Iottwinmaker":
        '''(experimental) Grants permission to delete an entity.

        Access Level: Write

        https://docs.aws.amazon.com/iot-twinmaker/latest/apireference/API_DeleteEntity.html

        :stability: experimental
        '''
        return typing.cast("Iottwinmaker", jsii.invoke(self, "toDeleteEntity", []))

    @jsii.member(jsii_name="toDeleteScene")
    def to_delete_scene(self) -> "Iottwinmaker":
        '''(experimental) Grants permission to delete a scene.

        Access Level: Write

        https://docs.aws.amazon.com/iot-twinmaker/latest/apireference/API_DeleteScene.html

        :stability: experimental
        '''
        return typing.cast("Iottwinmaker", jsii.invoke(self, "toDeleteScene", []))

    @jsii.member(jsii_name="toDeleteSyncJob")
    def to_delete_sync_job(self) -> "Iottwinmaker":
        '''(experimental) Grants permission to delete a sync job.

        Access Level: Write

        https://docs.aws.amazon.com/iot-twinmaker/latest/apireference/API_DeleteSyncJob.html

        :stability: experimental
        '''
        return typing.cast("Iottwinmaker", jsii.invoke(self, "toDeleteSyncJob", []))

    @jsii.member(jsii_name="toDeleteWorkspace")
    def to_delete_workspace(self) -> "Iottwinmaker":
        '''(experimental) Grants permission to delete a workspace.

        Access Level: Write

        https://docs.aws.amazon.com/iot-twinmaker/latest/apireference/API_DeleteWorkspace.html

        :stability: experimental
        '''
        return typing.cast("Iottwinmaker", jsii.invoke(self, "toDeleteWorkspace", []))

    @jsii.member(jsii_name="toExecuteQuery")
    def to_execute_query(self) -> "Iottwinmaker":
        '''(experimental) Grants permission to execute query.

        Access Level: Read

        https://docs.aws.amazon.com/iot-twinmaker/latest/apireference/API_ExecuteQuery.html

        :stability: experimental
        '''
        return typing.cast("Iottwinmaker", jsii.invoke(self, "toExecuteQuery", []))

    @jsii.member(jsii_name="toGetComponentType")
    def to_get_component_type(self) -> "Iottwinmaker":
        '''(experimental) Grants permission to get a componentType.

        Access Level: Read

        https://docs.aws.amazon.com/iot-twinmaker/latest/apireference/API_GetComponentType.html

        :stability: experimental
        '''
        return typing.cast("Iottwinmaker", jsii.invoke(self, "toGetComponentType", []))

    @jsii.member(jsii_name="toGetEntity")
    def to_get_entity(self) -> "Iottwinmaker":
        '''(experimental) Grants permission to get an entity.

        Access Level: Read

        https://docs.aws.amazon.com/iot-twinmaker/latest/apireference/API_GetEntity.html

        :stability: experimental
        '''
        return typing.cast("Iottwinmaker", jsii.invoke(self, "toGetEntity", []))

    @jsii.member(jsii_name="toGetPricingPlan")
    def to_get_pricing_plan(self) -> "Iottwinmaker":
        '''(experimental) Grants permission to get pricing plan.

        Access Level: Read

        https://docs.aws.amazon.com/iot-twinmaker/latest/apireference/API_GetPricingPlan.html

        :stability: experimental
        '''
        return typing.cast("Iottwinmaker", jsii.invoke(self, "toGetPricingPlan", []))

    @jsii.member(jsii_name="toGetPropertyValue")
    def to_get_property_value(self) -> "Iottwinmaker":
        '''(experimental) Grants permission to retrieve the property values.

        Access Level: Read

        Dependent actions:

        - iottwinmaker:GetComponentType
        - iottwinmaker:GetEntity
        - iottwinmaker:GetWorkspace

        https://docs.aws.amazon.com/iot-twinmaker/latest/apireference/API_GetPropertyValue.html

        :stability: experimental
        '''
        return typing.cast("Iottwinmaker", jsii.invoke(self, "toGetPropertyValue", []))

    @jsii.member(jsii_name="toGetPropertyValueHistory")
    def to_get_property_value_history(self) -> "Iottwinmaker":
        '''(experimental) Grants permission to retrieve the time series value history.

        Access Level: Read

        Dependent actions:

        - iottwinmaker:GetComponentType
        - iottwinmaker:GetEntity
        - iottwinmaker:GetWorkspace

        https://docs.aws.amazon.com/iot-twinmaker/latest/apireference/API_GetPropertyValueHistory.html

        :stability: experimental
        '''
        return typing.cast("Iottwinmaker", jsii.invoke(self, "toGetPropertyValueHistory", []))

    @jsii.member(jsii_name="toGetScene")
    def to_get_scene(self) -> "Iottwinmaker":
        '''(experimental) Grants permission to get a scene.

        Access Level: Read

        https://docs.aws.amazon.com/iot-twinmaker/latest/apireference/API_GetScene.html

        :stability: experimental
        '''
        return typing.cast("Iottwinmaker", jsii.invoke(self, "toGetScene", []))

    @jsii.member(jsii_name="toGetSyncJob")
    def to_get_sync_job(self) -> "Iottwinmaker":
        '''(experimental) Grants permission to get a sync job.

        Access Level: Read

        https://docs.aws.amazon.com/iot-twinmaker/latest/apireference/API_GetSyncJob.html

        :stability: experimental
        '''
        return typing.cast("Iottwinmaker", jsii.invoke(self, "toGetSyncJob", []))

    @jsii.member(jsii_name="toGetWorkspace")
    def to_get_workspace(self) -> "Iottwinmaker":
        '''(experimental) Grants permission to get a workspace.

        Access Level: Read

        https://docs.aws.amazon.com/iot-twinmaker/latest/apireference/API_GetWorkspace.html

        :stability: experimental
        '''
        return typing.cast("Iottwinmaker", jsii.invoke(self, "toGetWorkspace", []))

    @jsii.member(jsii_name="toListComponentTypes")
    def to_list_component_types(self) -> "Iottwinmaker":
        '''(experimental) Grants permission to list all componentTypes in a workspace.

        Access Level: List

        https://docs.aws.amazon.com/iot-twinmaker/latest/apireference/API_ListComponentTypes.html

        :stability: experimental
        '''
        return typing.cast("Iottwinmaker", jsii.invoke(self, "toListComponentTypes", []))

    @jsii.member(jsii_name="toListEntities")
    def to_list_entities(self) -> "Iottwinmaker":
        '''(experimental) Grants permission to list all entities in a workspace.

        Access Level: List

        https://docs.aws.amazon.com/iot-twinmaker/latest/apireference/API_ListEntities.html

        :stability: experimental
        '''
        return typing.cast("Iottwinmaker", jsii.invoke(self, "toListEntities", []))

    @jsii.member(jsii_name="toListScenes")
    def to_list_scenes(self) -> "Iottwinmaker":
        '''(experimental) Grants permission to list all scenes in a workspace.

        Access Level: List

        https://docs.aws.amazon.com/iot-twinmaker/latest/apireference/API_ListScenes.html

        :stability: experimental
        '''
        return typing.cast("Iottwinmaker", jsii.invoke(self, "toListScenes", []))

    @jsii.member(jsii_name="toListSyncJobs")
    def to_list_sync_jobs(self) -> "Iottwinmaker":
        '''(experimental) Grants permission to list all sync jobs in a workspace.

        Access Level: List

        https://docs.aws.amazon.com/iot-twinmaker/latest/apireference/API_ListSyncJobs.html

        :stability: experimental
        '''
        return typing.cast("Iottwinmaker", jsii.invoke(self, "toListSyncJobs", []))

    @jsii.member(jsii_name="toListSyncResources")
    def to_list_sync_resources(self) -> "Iottwinmaker":
        '''(experimental) Grants permission to list all sync resources for a sync job.

        Access Level: List

        https://docs.aws.amazon.com/iot-twinmaker/latest/apireference/API_ListSyncResources.html

        :stability: experimental
        '''
        return typing.cast("Iottwinmaker", jsii.invoke(self, "toListSyncResources", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Iottwinmaker":
        '''(experimental) Grants permission to list all tags for a resource.

        Access Level: List

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/iot-twinmaker/latest/apireference/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("Iottwinmaker", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toListWorkspaces")
    def to_list_workspaces(self) -> "Iottwinmaker":
        '''(experimental) Grants permission to list all workspaces.

        Access Level: List

        https://docs.aws.amazon.com/iot-twinmaker/latest/apireference/API_ListWorkspaces.html

        :stability: experimental
        '''
        return typing.cast("Iottwinmaker", jsii.invoke(self, "toListWorkspaces", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Iottwinmaker":
        '''(experimental) Grants permission to tag a resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/iot-twinmaker/latest/apireference/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("Iottwinmaker", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Iottwinmaker":
        '''(experimental) Grants permission to untag a resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/iot-twinmaker/latest/apireference/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("Iottwinmaker", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateComponentType")
    def to_update_component_type(self) -> "Iottwinmaker":
        '''(experimental) Grants permission to update a componentType.

        Access Level: Write

        https://docs.aws.amazon.com/iot-twinmaker/latest/apireference/API_UpdateComponentType.html

        :stability: experimental
        '''
        return typing.cast("Iottwinmaker", jsii.invoke(self, "toUpdateComponentType", []))

    @jsii.member(jsii_name="toUpdateEntity")
    def to_update_entity(self) -> "Iottwinmaker":
        '''(experimental) Grants permission to update an entity.

        Access Level: Write

        https://docs.aws.amazon.com/iot-twinmaker/latest/apireference/API_UpdateEntity.html

        :stability: experimental
        '''
        return typing.cast("Iottwinmaker", jsii.invoke(self, "toUpdateEntity", []))

    @jsii.member(jsii_name="toUpdatePricingPlan")
    def to_update_pricing_plan(self) -> "Iottwinmaker":
        '''(experimental) Grants permission to update pricing plan.

        Access Level: Write

        https://docs.aws.amazon.com/iot-twinmaker/latest/apireference/API_UpdatePricingPlan.html

        :stability: experimental
        '''
        return typing.cast("Iottwinmaker", jsii.invoke(self, "toUpdatePricingPlan", []))

    @jsii.member(jsii_name="toUpdateScene")
    def to_update_scene(self) -> "Iottwinmaker":
        '''(experimental) Grants permission to update a scene.

        Access Level: Write

        https://docs.aws.amazon.com/iot-twinmaker/latest/apireference/API_UpdateScene.html

        :stability: experimental
        '''
        return typing.cast("Iottwinmaker", jsii.invoke(self, "toUpdateScene", []))

    @jsii.member(jsii_name="toUpdateWorkspace")
    def to_update_workspace(self) -> "Iottwinmaker":
        '''(experimental) Grants permission to update a workspace.

        Access Level: Write

        https://docs.aws.amazon.com/iot-twinmaker/latest/apireference/API_UpdateWorkspace.html

        :stability: experimental
        '''
        return typing.cast("Iottwinmaker", jsii.invoke(self, "toUpdateWorkspace", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__94d8bd58b7a2c9840b21b8d5a0486b06a2802cd066ee1a639facc4358f0790e9)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__27f65a700eec0efe01b237f6d082a1fa0125d74ef2c4681e2644fc55e3e9e0c8)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Iotwireless(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Iotwireless",
):
    '''(experimental) Statement provider for service `iotwireless <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiotcoreforlorawan.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `iotwireless <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiotcoreforlorawan.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onCert")
    def on_cert(
        self,
        certificate: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Iotwireless":
        '''(experimental) Adds a resource of type cert to the statement.

        https://docs.aws.amazon.com/iot/latest/developerguide/x509-client-certs.html

        :param certificate: - Identifier for the certificate.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__448e3cd92b4d9adbdb7e1bf087d7005e4a1bb2ae7729496836a1cda3f3a2d928)
            check_type(argname="argument certificate", value=certificate, expected_type=type_hints["certificate"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Iotwireless", jsii.invoke(self, "onCert", [certificate, account, region, partition]))

    @jsii.member(jsii_name="onDestination")
    def on_destination(
        self,
        destination_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Iotwireless":
        '''(experimental) Adds a resource of type Destination to the statement.

        https://docs.aws.amazon.com/iot-wireless/2020-11-22/apireference/API_CreateDestination.html

        :param destination_name: - Identifier for the destinationName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__87d1e0478a387ea81ad3fa2852be3d7233401f9cf888aa387e52db6da4aaeb14)
            check_type(argname="argument destination_name", value=destination_name, expected_type=type_hints["destination_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Iotwireless", jsii.invoke(self, "onDestination", [destination_name, account, region, partition]))

    @jsii.member(jsii_name="onDeviceProfile")
    def on_device_profile(
        self,
        device_profile_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Iotwireless":
        '''(experimental) Adds a resource of type DeviceProfile to the statement.

        https://docs.aws.amazon.com/iot-wireless/2020-11-22/apireference/API_CreateDeviceProfile.html

        :param device_profile_id: - Identifier for the deviceProfileId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2c83e3de0c60d0e238e50e8b186ba3dfd8f2cdb6d3f1aff8cab970d9cbf1d41d)
            check_type(argname="argument device_profile_id", value=device_profile_id, expected_type=type_hints["device_profile_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Iotwireless", jsii.invoke(self, "onDeviceProfile", [device_profile_id, account, region, partition]))

    @jsii.member(jsii_name="onFuotaTask")
    def on_fuota_task(
        self,
        fuota_task_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Iotwireless":
        '''(experimental) Adds a resource of type FuotaTask to the statement.

        https://docs.aws.amazon.com/iot-wireless/2020-11-22/apireference/API_CreateFuotaTask.html

        :param fuota_task_id: - Identifier for the fuotaTaskId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__33e616a4e73e5504dc43845d6f4ce6e96f0334fea13048f4da2b219ddafd4720)
            check_type(argname="argument fuota_task_id", value=fuota_task_id, expected_type=type_hints["fuota_task_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Iotwireless", jsii.invoke(self, "onFuotaTask", [fuota_task_id, account, region, partition]))

    @jsii.member(jsii_name="onMulticastGroup")
    def on_multicast_group(
        self,
        multicast_group_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Iotwireless":
        '''(experimental) Adds a resource of type MulticastGroup to the statement.

        https://docs.aws.amazon.com/iot-wireless/2020-11-22/apireference/API_CreateMulticastGroup.html

        :param multicast_group_id: - Identifier for the multicastGroupId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__835a58e7522806eaeaa4dc1c981ca9e375933c92dc0be857d90119ff7d0e109d)
            check_type(argname="argument multicast_group_id", value=multicast_group_id, expected_type=type_hints["multicast_group_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Iotwireless", jsii.invoke(self, "onMulticastGroup", [multicast_group_id, account, region, partition]))

    @jsii.member(jsii_name="onNetworkAnalyzerConfiguration")
    def on_network_analyzer_configuration(
        self,
        network_analyzer_configuration_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Iotwireless":
        '''(experimental) Adds a resource of type NetworkAnalyzerConfiguration to the statement.

        https://docs.aws.amazon.com/iot-wireless/2020-11-22/apireference/API_CreateNetworkAnalyzerConfiguration.html

        :param network_analyzer_configuration_name: - Identifier for the networkAnalyzerConfigurationName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ee9652b53db5918a20178798768e31cc1fb8493cc0e4271191d4e3f61e153c9f)
            check_type(argname="argument network_analyzer_configuration_name", value=network_analyzer_configuration_name, expected_type=type_hints["network_analyzer_configuration_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Iotwireless", jsii.invoke(self, "onNetworkAnalyzerConfiguration", [network_analyzer_configuration_name, account, region, partition]))

    @jsii.member(jsii_name="onServiceProfile")
    def on_service_profile(
        self,
        service_profile_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Iotwireless":
        '''(experimental) Adds a resource of type ServiceProfile to the statement.

        https://docs.aws.amazon.com/iot-wireless/2020-11-22/apireference/API_CreateServiceProfile.html

        :param service_profile_id: - Identifier for the serviceProfileId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__04d6a8a06f66823ae78b6a86677a42abc4c622b43ff36e099708033ae027c9cf)
            check_type(argname="argument service_profile_id", value=service_profile_id, expected_type=type_hints["service_profile_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Iotwireless", jsii.invoke(self, "onServiceProfile", [service_profile_id, account, region, partition]))

    @jsii.member(jsii_name="onSidewalkAccount")
    def on_sidewalk_account(
        self,
        sidewalk_account_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Iotwireless":
        '''(experimental) Adds a resource of type SidewalkAccount to the statement.

        https://docs.aws.amazon.com/iot-wireless/2020-11-22/apireference/API_AssociateAwsAccountWithPartnerAccount.html

        :param sidewalk_account_id: - Identifier for the sidewalkAccountId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__94b9561c1726640d4b891e434ffa056f22c6669df456d409808f6e8e94c4e21a)
            check_type(argname="argument sidewalk_account_id", value=sidewalk_account_id, expected_type=type_hints["sidewalk_account_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Iotwireless", jsii.invoke(self, "onSidewalkAccount", [sidewalk_account_id, account, region, partition]))

    @jsii.member(jsii_name="onThing")
    def on_thing(
        self,
        thing_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Iotwireless":
        '''(experimental) Adds a resource of type thing to the statement.

        https://docs.aws.amazon.com/iot/latest/developerguide/thing-registry.html

        :param thing_name: - Identifier for the thingName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e3af9a36a61ba15435c484b806c3f3a7abf9e9553a3b94e56b638e278384ed65)
            check_type(argname="argument thing_name", value=thing_name, expected_type=type_hints["thing_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Iotwireless", jsii.invoke(self, "onThing", [thing_name, account, region, partition]))

    @jsii.member(jsii_name="onWirelessDevice")
    def on_wireless_device(
        self,
        wireless_device_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Iotwireless":
        '''(experimental) Adds a resource of type WirelessDevice to the statement.

        https://docs.aws.amazon.com/iot-wireless/2020-11-22/apireference/API_CreateWirelessDevice.html

        :param wireless_device_id: - Identifier for the wirelessDeviceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5bcd9ac0f00a9cf47660943624e3070aef2d98eda2e3168f1083033e2bd44908)
            check_type(argname="argument wireless_device_id", value=wireless_device_id, expected_type=type_hints["wireless_device_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Iotwireless", jsii.invoke(self, "onWirelessDevice", [wireless_device_id, account, region, partition]))

    @jsii.member(jsii_name="onWirelessGateway")
    def on_wireless_gateway(
        self,
        wireless_gateway_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Iotwireless":
        '''(experimental) Adds a resource of type WirelessGateway to the statement.

        https://docs.aws.amazon.com/iot-wireless/2020-11-22/apireference/API_CreateWirelessGateway.html

        :param wireless_gateway_id: - Identifier for the wirelessGatewayId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__06e0c68ddee558260d5786ccea364aa0dae847207b9db9cd297ad29e30b50fbb)
            check_type(argname="argument wireless_gateway_id", value=wireless_gateway_id, expected_type=type_hints["wireless_gateway_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Iotwireless", jsii.invoke(self, "onWirelessGateway", [wireless_gateway_id, account, region, partition]))

    @jsii.member(jsii_name="onWirelessGatewayTaskDefinition")
    def on_wireless_gateway_task_definition(
        self,
        wireless_gateway_task_definition_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Iotwireless":
        '''(experimental) Adds a resource of type WirelessGatewayTaskDefinition to the statement.

        https://docs.aws.amazon.com/iot-wireless/2020-11-22/apireference/API_CreateWirelessGatewayTaskDefinition.html

        :param wireless_gateway_task_definition_id: - Identifier for the wirelessGatewayTaskDefinitionId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__271e527fdde83a730b848ffe7a364ae9092ba349c4ba30cf417ec2400a2ea2b8)
            check_type(argname="argument wireless_gateway_task_definition_id", value=wireless_gateway_task_definition_id, expected_type=type_hints["wireless_gateway_task_definition_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Iotwireless", jsii.invoke(self, "onWirelessGatewayTaskDefinition", [wireless_gateway_task_definition_id, account, region, partition]))

    @jsii.member(jsii_name="toAssociateAwsAccountWithPartnerAccount")
    def to_associate_aws_account_with_partner_account(self) -> "Iotwireless":
        '''(experimental) Grants permission to link partner accounts with AWS account.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/iot-wireless/2020-11-22/apireference/API_AssociateAwsAccountWithPartnerAccount.html

        :stability: experimental
        '''
        return typing.cast("Iotwireless", jsii.invoke(self, "toAssociateAwsAccountWithPartnerAccount", []))

    @jsii.member(jsii_name="toAssociateMulticastGroupWithFuotaTask")
    def to_associate_multicast_group_with_fuota_task(self) -> "Iotwireless":
        '''(experimental) Grants permission to associate the MulticastGroup with FuotaTask.

        Access Level: Write

        https://docs.aws.amazon.com/iot-wireless/2020-11-22/apireference/API_AssociateMulticastGroupWithFuotaTask.html

        :stability: experimental
        '''
        return typing.cast("Iotwireless", jsii.invoke(self, "toAssociateMulticastGroupWithFuotaTask", []))

    @jsii.member(jsii_name="toAssociateWirelessDeviceWithFuotaTask")
    def to_associate_wireless_device_with_fuota_task(self) -> "Iotwireless":
        '''(experimental) Grants permission to associate the wireless device with FuotaTask.

        Access Level: Write

        https://docs.aws.amazon.com/iot-wireless/2020-11-22/apireference/API_AssociateWirelessDeviceWithFuotaTask.html

        :stability: experimental
        '''
        return typing.cast("Iotwireless", jsii.invoke(self, "toAssociateWirelessDeviceWithFuotaTask", []))

    @jsii.member(jsii_name="toAssociateWirelessDeviceWithMulticastGroup")
    def to_associate_wireless_device_with_multicast_group(self) -> "Iotwireless":
        '''(experimental) Grants permission to associate the WirelessDevice with MulticastGroup.

        Access Level: Write

        https://docs.aws.amazon.com/iot-wireless/2020-11-22/apireference/API_AssociateWirelessDeviceWithMulticastGroup.html

        :stability: experimental
        '''
        return typing.cast("Iotwireless", jsii.invoke(self, "toAssociateWirelessDeviceWithMulticastGroup", []))

    @jsii.member(jsii_name="toAssociateWirelessDeviceWithThing")
    def to_associate_wireless_device_with_thing(self) -> "Iotwireless":
        '''(experimental) Grants permission to associate the wireless device with AWS IoT thing for a given wirelessDeviceId.

        Access Level: Write

        Dependent actions:

        - iot:DescribeThing

        https://docs.aws.amazon.com/iot-wireless/2020-11-22/apireference/API_AssociateWirelessDeviceWithThing.html

        :stability: experimental
        '''
        return typing.cast("Iotwireless", jsii.invoke(self, "toAssociateWirelessDeviceWithThing", []))

    @jsii.member(jsii_name="toAssociateWirelessGatewayWithCertificate")
    def to_associate_wireless_gateway_with_certificate(self) -> "Iotwireless":
        '''(experimental) Grants permission to associate a WirelessGateway with the IoT Core Identity certificate.

        Access Level: Write

        https://docs.aws.amazon.com/iot-wireless/2020-11-22/apireference/API_AssociateWirelessGatewayWithCertificate.html

        :stability: experimental
        '''
        return typing.cast("Iotwireless", jsii.invoke(self, "toAssociateWirelessGatewayWithCertificate", []))

    @jsii.member(jsii_name="toAssociateWirelessGatewayWithThing")
    def to_associate_wireless_gateway_with_thing(self) -> "Iotwireless":
        '''(experimental) Grants permission to associate the wireless gateway with AWS IoT thing for a given wirelessGatewayId.

        Access Level: Write

        Dependent actions:

        - iot:DescribeThing

        https://docs.aws.amazon.com/iot-wireless/2020-11-22/apireference/API_AssociateWirelessGatewayWithThing.html

        :stability: experimental
        '''
        return typing.cast("Iotwireless", jsii.invoke(self, "toAssociateWirelessGatewayWithThing", []))

    @jsii.member(jsii_name="toCancelMulticastGroupSession")
    def to_cancel_multicast_group_session(self) -> "Iotwireless":
        '''(experimental) Grants permission to cancel the MulticastGroup session.

        Access Level: Write

        https://docs.aws.amazon.com/iot-wireless/2020-11-22/apireference/API_CancelMulticastGroupSession.html

        :stability: experimental
        '''
        return typing.cast("Iotwireless", jsii.invoke(self, "toCancelMulticastGroupSession", []))

    @jsii.member(jsii_name="toCreateDestination")
    def to_create_destination(self) -> "Iotwireless":
        '''(experimental) Grants permission to create a Destination resource.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/iot-wireless/2020-11-22/apireference/API_CreateDestination.html

        :stability: experimental
        '''
        return typing.cast("Iotwireless", jsii.invoke(self, "toCreateDestination", []))

    @jsii.member(jsii_name="toCreateDeviceProfile")
    def to_create_device_profile(self) -> "Iotwireless":
        '''(experimental) Grants permission to create a DeviceProfile resource.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/iot-wireless/2020-11-22/apireference/API_CreateDeviceProfile.html

        :stability: experimental
        '''
        return typing.cast("Iotwireless", jsii.invoke(self, "toCreateDeviceProfile", []))

    @jsii.member(jsii_name="toCreateFuotaTask")
    def to_create_fuota_task(self) -> "Iotwireless":
        '''(experimental) Grants permission to create a FuotaTask resource.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/iot-wireless/2020-11-22/apireference/API_CreateFuotaTask.html

        :stability: experimental
        '''
        return typing.cast("Iotwireless", jsii.invoke(self, "toCreateFuotaTask", []))

    @jsii.member(jsii_name="toCreateMulticastGroup")
    def to_create_multicast_group(self) -> "Iotwireless":
        '''(experimental) Grants permission to create a MulticastGroup resource.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/iot-wireless/2020-11-22/apireference/API_CreateMulticastGroup.html

        :stability: experimental
        '''
        return typing.cast("Iotwireless", jsii.invoke(self, "toCreateMulticastGroup", []))

    @jsii.member(jsii_name="toCreateNetworkAnalyzerConfiguration")
    def to_create_network_analyzer_configuration(self) -> "Iotwireless":
        '''(experimental) Grants permission to create a NetworkAnalyzerConfiguration resource.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/iot-wireless/2020-11-22/apireference/API_CreateNetworkAnalyzerConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Iotwireless", jsii.invoke(self, "toCreateNetworkAnalyzerConfiguration", []))

    @jsii.member(jsii_name="toCreateServiceProfile")
    def to_create_service_profile(self) -> "Iotwireless":
        '''(experimental) Grants permission to create a ServiceProfile resource.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/iot-wireless/2020-11-22/apireference/API_CreateServiceProfile.html

        :stability: experimental
        '''
        return typing.cast("Iotwireless", jsii.invoke(self, "toCreateServiceProfile", []))

    @jsii.member(jsii_name="toCreateWirelessDevice")
    def to_create_wireless_device(self) -> "Iotwireless":
        '''(experimental) Grants permission to create a WirelessDevice resource with given Destination.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/iot-wireless/2020-11-22/apireference/API_CreateWirelessDevice.html

        :stability: experimental
        '''
        return typing.cast("Iotwireless", jsii.invoke(self, "toCreateWirelessDevice", []))

    @jsii.member(jsii_name="toCreateWirelessGateway")
    def to_create_wireless_gateway(self) -> "Iotwireless":
        '''(experimental) Grants permission to create a WirelessGateway resource.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/iot-wireless/2020-11-22/apireference/API_CreateWirelessGateway.html

        :stability: experimental
        '''
        return typing.cast("Iotwireless", jsii.invoke(self, "toCreateWirelessGateway", []))

    @jsii.member(jsii_name="toCreateWirelessGatewayTask")
    def to_create_wireless_gateway_task(self) -> "Iotwireless":
        '''(experimental) Grants permission to create a task for a given WirelessGateway.

        Access Level: Write

        https://docs.aws.amazon.com/iot-wireless/2020-11-22/apireference/API_CreateWirelessGatewayTask.html

        :stability: experimental
        '''
        return typing.cast("Iotwireless", jsii.invoke(self, "toCreateWirelessGatewayTask", []))

    @jsii.member(jsii_name="toCreateWirelessGatewayTaskDefinition")
    def to_create_wireless_gateway_task_definition(self) -> "Iotwireless":
        '''(experimental) Grants permission to create a WirelessGateway task definition.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/iot-wireless/2020-11-22/apireference/API_CreateWirelessGatewayTaskDefinition.html

        :stability: experimental
        '''
        return typing.cast("Iotwireless", jsii.invoke(self, "toCreateWirelessGatewayTaskDefinition", []))

    @jsii.member(jsii_name="toDeleteDestination")
    def to_delete_destination(self) -> "Iotwireless":
        '''(experimental) Grants permission to delete a Destination.

        Access Level: Write

        https://docs.aws.amazon.com/iot-wireless/2020-11-22/apireference/API_DeleteDestination.html

        :stability: experimental
        '''
        return typing.cast("Iotwireless", jsii.invoke(self, "toDeleteDestination", []))

    @jsii.member(jsii_name="toDeleteDeviceProfile")
    def to_delete_device_profile(self) -> "Iotwireless":
        '''(experimental) Grants permission to delete a DeviceProfile.

        Access Level: Write

        https://docs.aws.amazon.com/iot-wireless/2020-11-22/apireference/API_DeleteDeviceProfile.html

        :stability: experimental
        '''
        return typing.cast("Iotwireless", jsii.invoke(self, "toDeleteDeviceProfile", []))

    @jsii.member(jsii_name="toDeleteFuotaTask")
    def to_delete_fuota_task(self) -> "Iotwireless":
        '''(experimental) Grants permission to delete the FuotaTask.

        Access Level: Write

        https://docs.aws.amazon.com/iot-wireless/2020-11-22/apireference/API_DeleteFuotaTask.html

        :stability: experimental
        '''
        return typing.cast("Iotwireless", jsii.invoke(self, "toDeleteFuotaTask", []))

    @jsii.member(jsii_name="toDeleteMulticastGroup")
    def to_delete_multicast_group(self) -> "Iotwireless":
        '''(experimental) Grants permission to delete the MulticastGroup.

        Access Level: Write

        https://docs.aws.amazon.com/iot-wireless/2020-11-22/apireference/API_DeleteMulticastGroup.html

        :stability: experimental
        '''
        return typing.cast("Iotwireless", jsii.invoke(self, "toDeleteMulticastGroup", []))

    @jsii.member(jsii_name="toDeleteNetworkAnalyzerConfiguration")
    def to_delete_network_analyzer_configuration(self) -> "Iotwireless":
        '''(experimental) Grants permission to delete the NetworkAnalyzerConfiguration.

        Access Level: Write

        https://docs.aws.amazon.com/iot-wireless/2020-11-22/apireference/API_DeleteNetworkAnalyzerConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Iotwireless", jsii.invoke(self, "toDeleteNetworkAnalyzerConfiguration", []))

    @jsii.member(jsii_name="toDeleteQueuedMessages")
    def to_delete_queued_messages(self) -> "Iotwireless":
        '''(experimental) Grants permission to delete QueuedMessages.

        Access Level: Write

        https://docs.aws.amazon.com/iot-wireless/2020-11-22/apireference/API_DeleteQueuedMessages.html

        :stability: experimental
        '''
        return typing.cast("Iotwireless", jsii.invoke(self, "toDeleteQueuedMessages", []))

    @jsii.member(jsii_name="toDeleteServiceProfile")
    def to_delete_service_profile(self) -> "Iotwireless":
        '''(experimental) Grants permission to delete a ServiceProfile.

        Access Level: Write

        https://docs.aws.amazon.com/iot-wireless/2020-11-22/apireference/API_DeleteServiceProfile.html

        :stability: experimental
        '''
        return typing.cast("Iotwireless", jsii.invoke(self, "toDeleteServiceProfile", []))

    @jsii.member(jsii_name="toDeleteWirelessDevice")
    def to_delete_wireless_device(self) -> "Iotwireless":
        '''(experimental) Grants permission to delete a WirelessDevice.

        Access Level: Write

        https://docs.aws.amazon.com/iot-wireless/2020-11-22/apireference/API_DeleteWirelessDevice.html

        :stability: experimental
        '''
        return typing.cast("Iotwireless", jsii.invoke(self, "toDeleteWirelessDevice", []))

    @jsii.member(jsii_name="toDeleteWirelessGateway")
    def to_delete_wireless_gateway(self) -> "Iotwireless":
        '''(experimental) Grants permission to delete a WirelessGateway.

        Access Level: Write

        https://docs.aws.amazon.com/iot-wireless/2020-11-22/apireference/API_DeleteWirelessGateway.html

        :stability: experimental
        '''
        return typing.cast("Iotwireless", jsii.invoke(self, "toDeleteWirelessGateway", []))

    @jsii.member(jsii_name="toDeleteWirelessGatewayTask")
    def to_delete_wireless_gateway_task(self) -> "Iotwireless":
        '''(experimental) Grants permission to delete task for a given WirelessGateway.

        Access Level: Write

        https://docs.aws.amazon.com/iot-wireless/2020-11-22/apireference/API_DeleteWirelessGatewayTask.html

        :stability: experimental
        '''
        return typing.cast("Iotwireless", jsii.invoke(self, "toDeleteWirelessGatewayTask", []))

    @jsii.member(jsii_name="toDeleteWirelessGatewayTaskDefinition")
    def to_delete_wireless_gateway_task_definition(self) -> "Iotwireless":
        '''(experimental) Grants permission to delete a WirelessGateway task definition.

        Access Level: Write

        https://docs.aws.amazon.com/iot-wireless/2020-11-22/apireference/API_DeleteWirelessGatewayTaskDefinition.html

        :stability: experimental
        '''
        return typing.cast("Iotwireless", jsii.invoke(self, "toDeleteWirelessGatewayTaskDefinition", []))

    @jsii.member(jsii_name="toDisassociateAwsAccountFromPartnerAccount")
    def to_disassociate_aws_account_from_partner_account(self) -> "Iotwireless":
        '''(experimental) Grants permission to disassociate an AWS account from a partner account.

        Access Level: Write

        https://docs.aws.amazon.com/iot-wireless/2020-11-22/apireference/API_DisassociateAwsAccountFromPartnerAccount.html

        :stability: experimental
        '''
        return typing.cast("Iotwireless", jsii.invoke(self, "toDisassociateAwsAccountFromPartnerAccount", []))

    @jsii.member(jsii_name="toDisassociateMulticastGroupFromFuotaTask")
    def to_disassociate_multicast_group_from_fuota_task(self) -> "Iotwireless":
        '''(experimental) Grants permission to disassociate the MulticastGroup from FuotaTask.

        Access Level: Write

        https://docs.aws.amazon.com/iot-wireless/2020-11-22/apireference/API_DisassociateMulticastGroupFromFuotaTask.html

        :stability: experimental
        '''
        return typing.cast("Iotwireless", jsii.invoke(self, "toDisassociateMulticastGroupFromFuotaTask", []))

    @jsii.member(jsii_name="toDisassociateWirelessDeviceFromFuotaTask")
    def to_disassociate_wireless_device_from_fuota_task(self) -> "Iotwireless":
        '''(experimental) Grants permission to disassociate the wireless device from FuotaTask.

        Access Level: Write

        https://docs.aws.amazon.com/iot-wireless/2020-11-22/apireference/API_DisassociateWirelessDeviceFromFuotaTask.html

        :stability: experimental
        '''
        return typing.cast("Iotwireless", jsii.invoke(self, "toDisassociateWirelessDeviceFromFuotaTask", []))

    @jsii.member(jsii_name="toDisassociateWirelessDeviceFromMulticastGroup")
    def to_disassociate_wireless_device_from_multicast_group(self) -> "Iotwireless":
        '''(experimental) Grants permission to disassociate the wireless device from MulticastGroup.

        Access Level: Write

        https://docs.aws.amazon.com/iot-wireless/2020-11-22/apireference/API_DisassociateWirelessDeviceFromMulticastGroup.html

        :stability: experimental
        '''
        return typing.cast("Iotwireless", jsii.invoke(self, "toDisassociateWirelessDeviceFromMulticastGroup", []))

    @jsii.member(jsii_name="toDisassociateWirelessDeviceFromThing")
    def to_disassociate_wireless_device_from_thing(self) -> "Iotwireless":
        '''(experimental) Grants permission to disassociate a wireless device from a AWS IoT thing.

        Access Level: Write

        Dependent actions:

        - iot:DescribeThing

        https://docs.aws.amazon.com/iot-wireless/2020-11-22/apireference/API_DisassociateWirelessDeviceFromThing.html

        :stability: experimental
        '''
        return typing.cast("Iotwireless", jsii.invoke(self, "toDisassociateWirelessDeviceFromThing", []))

    @jsii.member(jsii_name="toDisassociateWirelessGatewayFromCertificate")
    def to_disassociate_wireless_gateway_from_certificate(self) -> "Iotwireless":
        '''(experimental) Grants permission to disassociate a WirelessGateway from a IoT Core Identity certificate.

        Access Level: Write

        https://docs.aws.amazon.com/iot-wireless/2020-11-22/apireference/API_DisassociateWirelessGatewayFromCertificate.html

        :stability: experimental
        '''
        return typing.cast("Iotwireless", jsii.invoke(self, "toDisassociateWirelessGatewayFromCertificate", []))

    @jsii.member(jsii_name="toDisassociateWirelessGatewayFromThing")
    def to_disassociate_wireless_gateway_from_thing(self) -> "Iotwireless":
        '''(experimental) Grants permission to disassociate a WirelessGateway from a IoT Core thing.

        Access Level: Write

        Dependent actions:

        - iot:DescribeThing

        https://docs.aws.amazon.com/iot-wireless/2020-11-22/apireference/API_DisassociateWirelessGatewayFromThing.html

        :stability: experimental
        '''
        return typing.cast("Iotwireless", jsii.invoke(self, "toDisassociateWirelessGatewayFromThing", []))

    @jsii.member(jsii_name="toGetDestination")
    def to_get_destination(self) -> "Iotwireless":
        '''(experimental) Grants permission to get the Destination.

        Access Level: Read

        https://docs.aws.amazon.com/iot-wireless/2020-11-22/apireference/API_GetDestination.html

        :stability: experimental
        '''
        return typing.cast("Iotwireless", jsii.invoke(self, "toGetDestination", []))

    @jsii.member(jsii_name="toGetDeviceProfile")
    def to_get_device_profile(self) -> "Iotwireless":
        '''(experimental) Grants permission to get the DeviceProfile.

        Access Level: Read

        https://docs.aws.amazon.com/iot-wireless/2020-11-22/apireference/API_GetDeviceProfile.html

        :stability: experimental
        '''
        return typing.cast("Iotwireless", jsii.invoke(self, "toGetDeviceProfile", []))

    @jsii.member(jsii_name="toGetEventConfigurationByResourceTypes")
    def to_get_event_configuration_by_resource_types(self) -> "Iotwireless":
        '''(experimental) Grants permission to get event configuration by resource types.

        Access Level: Read

        https://docs.aws.amazon.com/iot-wireless/2020-11-22/apireference/API_GetEventConfigurationByResourceTypes.html

        :stability: experimental
        '''
        return typing.cast("Iotwireless", jsii.invoke(self, "toGetEventConfigurationByResourceTypes", []))

    @jsii.member(jsii_name="toGetFuotaTask")
    def to_get_fuota_task(self) -> "Iotwireless":
        '''(experimental) Grants permission to get the FuotaTask.

        Access Level: Read

        https://docs.aws.amazon.com/iot-wireless/2020-11-22/apireference/API_GetFuotaTask.html

        :stability: experimental
        '''
        return typing.cast("Iotwireless", jsii.invoke(self, "toGetFuotaTask", []))

    @jsii.member(jsii_name="toGetLogLevelsByResourceTypes")
    def to_get_log_levels_by_resource_types(self) -> "Iotwireless":
        '''(experimental) Grants permission to get log levels by resource types.

        Access Level: Read

        https://docs.aws.amazon.com/iot-wireless/2020-11-22/apireference/API_GetLogLevelsByResourceTypes.html

        :stability: experimental
        '''
        return typing.cast("Iotwireless", jsii.invoke(self, "toGetLogLevelsByResourceTypes", []))

    @jsii.member(jsii_name="toGetMulticastGroup")
    def to_get_multicast_group(self) -> "Iotwireless":
        '''(experimental) Grants permission to get the MulticastGroup.

        Access Level: Read

        https://docs.aws.amazon.com/iot-wireless/2020-11-22/apireference/API_GetMulticastGroup.html

        :stability: experimental
        '''
        return typing.cast("Iotwireless", jsii.invoke(self, "toGetMulticastGroup", []))

    @jsii.member(jsii_name="toGetMulticastGroupSession")
    def to_get_multicast_group_session(self) -> "Iotwireless":
        '''(experimental) Grants permission to get the MulticastGroup session.

        Access Level: Read

        https://docs.aws.amazon.com/iot-wireless/2020-11-22/apireference/API_GetMulticastGroupSession.html

        :stability: experimental
        '''
        return typing.cast("Iotwireless", jsii.invoke(self, "toGetMulticastGroupSession", []))

    @jsii.member(jsii_name="toGetNetworkAnalyzerConfiguration")
    def to_get_network_analyzer_configuration(self) -> "Iotwireless":
        '''(experimental) Grants permission to get the NetworkAnalyzerConfiguration.

        Access Level: Read

        https://docs.aws.amazon.com/iot-wireless/2020-11-22/apireference/API_GetNetworkAnalyzerConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Iotwireless", jsii.invoke(self, "toGetNetworkAnalyzerConfiguration", []))

    @jsii.member(jsii_name="toGetPartnerAccount")
    def to_get_partner_account(self) -> "Iotwireless":
        '''(experimental) Grants permission to get the associated PartnerAccount.

        Access Level: Read

        https://docs.aws.amazon.com/iot-wireless/2020-11-22/apireference/API_GetPartnerAccount.html

        :stability: experimental
        '''
        return typing.cast("Iotwireless", jsii.invoke(self, "toGetPartnerAccount", []))

    @jsii.member(jsii_name="toGetPosition")
    def to_get_position(self) -> "Iotwireless":
        '''(experimental) Grants permission to get position for a given resource.

        Access Level: Read

        https://docs.aws.amazon.com/iot-wireless/2020-11-22/apireference/API_GetPosition.html

        :stability: experimental
        '''
        return typing.cast("Iotwireless", jsii.invoke(self, "toGetPosition", []))

    @jsii.member(jsii_name="toGetPositionConfiguration")
    def to_get_position_configuration(self) -> "Iotwireless":
        '''(experimental) Grants permission to get position configuration for a given resource.

        Access Level: Read

        https://docs.aws.amazon.com/iot-wireless/2020-11-22/apireference/API_GetPositionConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Iotwireless", jsii.invoke(self, "toGetPositionConfiguration", []))

    @jsii.member(jsii_name="toGetPositionEstimate")
    def to_get_position_estimate(self) -> "Iotwireless":
        '''(experimental) Grants permission to get position estimate.

        Access Level: Read

        https://docs.aws.amazon.com/iot-wireless/2020-11-22/apireference/API_GetPositionEstimate.html

        :stability: experimental
        '''
        return typing.cast("Iotwireless", jsii.invoke(self, "toGetPositionEstimate", []))

    @jsii.member(jsii_name="toGetResourceEventConfiguration")
    def to_get_resource_event_configuration(self) -> "Iotwireless":
        '''(experimental) Grants permission to get an event configuration for an identifier.

        Access Level: Read

        https://docs.aws.amazon.com/iot-wireless/2020-11-22/apireference/API_GetResourceEventConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Iotwireless", jsii.invoke(self, "toGetResourceEventConfiguration", []))

    @jsii.member(jsii_name="toGetResourceLogLevel")
    def to_get_resource_log_level(self) -> "Iotwireless":
        '''(experimental) Grants permission to get resource log level.

        Access Level: Read

        https://docs.aws.amazon.com/iot-wireless/2020-11-22/apireference/API_GetResourceLogLevel.html

        :stability: experimental
        '''
        return typing.cast("Iotwireless", jsii.invoke(self, "toGetResourceLogLevel", []))

    @jsii.member(jsii_name="toGetResourcePosition")
    def to_get_resource_position(self) -> "Iotwireless":
        '''(experimental) Grants permission to get position for a given resource.

        Access Level: Read

        https://docs.aws.amazon.com/iot-wireless/2020-11-22/apireference/API_GetResourcePosition.html

        :stability: experimental
        '''
        return typing.cast("Iotwireless", jsii.invoke(self, "toGetResourcePosition", []))

    @jsii.member(jsii_name="toGetServiceEndpoint")
    def to_get_service_endpoint(self) -> "Iotwireless":
        '''(experimental) Grants permission to retrieve the customer account specific endpoint for CUPS protocol connection or LoRaWAN Network Server (LNS) protocol connection, and optionally server trust certificate in PEM format.

        Access Level: Read

        https://docs.aws.amazon.com/iot-wireless/2020-11-22/apireference/API_GetServiceEndpoint.html

        :stability: experimental
        '''
        return typing.cast("Iotwireless", jsii.invoke(self, "toGetServiceEndpoint", []))

    @jsii.member(jsii_name="toGetServiceProfile")
    def to_get_service_profile(self) -> "Iotwireless":
        '''(experimental) Grants permission to get the ServiceProfile.

        Access Level: Read

        https://docs.aws.amazon.com/iot-wireless/2020-11-22/apireference/API_GetServiceProfile.html

        :stability: experimental
        '''
        return typing.cast("Iotwireless", jsii.invoke(self, "toGetServiceProfile", []))

    @jsii.member(jsii_name="toGetWirelessDevice")
    def to_get_wireless_device(self) -> "Iotwireless":
        '''(experimental) Grants permission to get the WirelessDevice.

        Access Level: Read

        https://docs.aws.amazon.com/iot-wireless/2020-11-22/apireference/API_GetWirelessDevice.html

        :stability: experimental
        '''
        return typing.cast("Iotwireless", jsii.invoke(self, "toGetWirelessDevice", []))

    @jsii.member(jsii_name="toGetWirelessDeviceStatistics")
    def to_get_wireless_device_statistics(self) -> "Iotwireless":
        '''(experimental) Grants permission to get statistics info for a given WirelessDevice.

        Access Level: Read

        https://docs.aws.amazon.com/iot-wireless/2020-11-22/apireference/API_GetWirelessDeviceStatistics.html

        :stability: experimental
        '''
        return typing.cast("Iotwireless", jsii.invoke(self, "toGetWirelessDeviceStatistics", []))

    @jsii.member(jsii_name="toGetWirelessGateway")
    def to_get_wireless_gateway(self) -> "Iotwireless":
        '''(experimental) Grants permission to get the WirelessGateway.

        Access Level: Read

        https://docs.aws.amazon.com/iot-wireless/2020-11-22/apireference/API_GetWirelessGateway.html

        :stability: experimental
        '''
        return typing.cast("Iotwireless", jsii.invoke(self, "toGetWirelessGateway", []))

    @jsii.member(jsii_name="toGetWirelessGatewayCertificate")
    def to_get_wireless_gateway_certificate(self) -> "Iotwireless":
        '''(experimental) Grants permission to get the IoT Core Identity certificate id associated with the WirelessGateway.

        Access Level: Read

        https://docs.aws.amazon.com/iot-wireless/2020-11-22/apireference/API_GetWirelessGatewayCertificate.html

        :stability: experimental
        '''
        return typing.cast("Iotwireless", jsii.invoke(self, "toGetWirelessGatewayCertificate", []))

    @jsii.member(jsii_name="toGetWirelessGatewayFirmwareInformation")
    def to_get_wireless_gateway_firmware_information(self) -> "Iotwireless":
        '''(experimental) Grants permission to get Current firmware version and other information for the WirelessGateway.

        Access Level: Read

        https://docs.aws.amazon.com/iot-wireless/2020-11-22/apireference/API_GetWirelessGatewayFirmwareInformation.html

        :stability: experimental
        '''
        return typing.cast("Iotwireless", jsii.invoke(self, "toGetWirelessGatewayFirmwareInformation", []))

    @jsii.member(jsii_name="toGetWirelessGatewayStatistics")
    def to_get_wireless_gateway_statistics(self) -> "Iotwireless":
        '''(experimental) Grants permission to get statistics info for a given WirelessGateway.

        Access Level: Read

        https://docs.aws.amazon.com/iot-wireless/2020-11-22/apireference/API_GetWirelessGatewayStatistics.html

        :stability: experimental
        '''
        return typing.cast("Iotwireless", jsii.invoke(self, "toGetWirelessGatewayStatistics", []))

    @jsii.member(jsii_name="toGetWirelessGatewayTask")
    def to_get_wireless_gateway_task(self) -> "Iotwireless":
        '''(experimental) Grants permission to get the task for a given WirelessGateway.

        Access Level: Read

        https://docs.aws.amazon.com/iot-wireless/2020-11-22/apireference/API_GetWirelessGatewayTask.html

        :stability: experimental
        '''
        return typing.cast("Iotwireless", jsii.invoke(self, "toGetWirelessGatewayTask", []))

    @jsii.member(jsii_name="toGetWirelessGatewayTaskDefinition")
    def to_get_wireless_gateway_task_definition(self) -> "Iotwireless":
        '''(experimental) Grants permission to get the given WirelessGateway task definition.

        Access Level: Read

        https://docs.aws.amazon.com/iot-wireless/2020-11-22/apireference/API_GetWirelessGatewayTaskDefinition.html

        :stability: experimental
        '''
        return typing.cast("Iotwireless", jsii.invoke(self, "toGetWirelessGatewayTaskDefinition", []))

    @jsii.member(jsii_name="toListDestinations")
    def to_list_destinations(self) -> "Iotwireless":
        '''(experimental) Grants permission to list information of available Destinations based on the AWS account.

        Access Level: Read

        https://docs.aws.amazon.com/iot-wireless/2020-11-22/apireference/API_ListDestinations.html

        :stability: experimental
        '''
        return typing.cast("Iotwireless", jsii.invoke(self, "toListDestinations", []))

    @jsii.member(jsii_name="toListDeviceProfiles")
    def to_list_device_profiles(self) -> "Iotwireless":
        '''(experimental) Grants permission to list information of available DeviceProfiles based on the AWS account.

        Access Level: Read

        https://docs.aws.amazon.com/iot-wireless/2020-11-22/apireference/API_ListDeviceProfiles.html

        :stability: experimental
        '''
        return typing.cast("Iotwireless", jsii.invoke(self, "toListDeviceProfiles", []))

    @jsii.member(jsii_name="toListEventConfigurations")
    def to_list_event_configurations(self) -> "Iotwireless":
        '''(experimental) Grants permission to list information of available event configurations based on the AWS account.

        Access Level: Read

        https://docs.aws.amazon.com/iot-wireless/2020-11-22/apireference/API_ListEventConfigurations.html

        :stability: experimental
        '''
        return typing.cast("Iotwireless", jsii.invoke(self, "toListEventConfigurations", []))

    @jsii.member(jsii_name="toListFuotaTasks")
    def to_list_fuota_tasks(self) -> "Iotwireless":
        '''(experimental) Grants permission to list information of available FuotaTasks based on the AWS account.

        Access Level: Read

        https://docs.aws.amazon.com/iot-wireless/2020-11-22/apireference/API_ListFuotaTasks.html

        :stability: experimental
        '''
        return typing.cast("Iotwireless", jsii.invoke(self, "toListFuotaTasks", []))

    @jsii.member(jsii_name="toListMulticastGroups")
    def to_list_multicast_groups(self) -> "Iotwireless":
        '''(experimental) Grants permission to list information of available MulticastGroups based on the AWS account.

        Access Level: Read

        https://docs.aws.amazon.com/iot-wireless/2020-11-22/apireference/API_ListMulticastGroups.html

        :stability: experimental
        '''
        return typing.cast("Iotwireless", jsii.invoke(self, "toListMulticastGroups", []))

    @jsii.member(jsii_name="toListMulticastGroupsByFuotaTask")
    def to_list_multicast_groups_by_fuota_task(self) -> "Iotwireless":
        '''(experimental) Grants permission to list information of available MulticastGroups by FuotaTask based on the AWS account.

        Access Level: Read

        https://docs.aws.amazon.com/iot-wireless/2020-11-22/apireference/API_ListMulticastGroupsByFuotaTask.html

        :stability: experimental
        '''
        return typing.cast("Iotwireless", jsii.invoke(self, "toListMulticastGroupsByFuotaTask", []))

    @jsii.member(jsii_name="toListNetworkAnalyzerConfigurations")
    def to_list_network_analyzer_configurations(self) -> "Iotwireless":
        '''(experimental) Grants permission to list information of available NetworkAnalyzerConfigurations based on the AWS account.

        Access Level: Read

        https://docs.aws.amazon.com/iot-wireless/2020-11-22/apireference/API_ListNetworkAnalyzerConfigurations.html

        :stability: experimental
        '''
        return typing.cast("Iotwireless", jsii.invoke(self, "toListNetworkAnalyzerConfigurations", []))

    @jsii.member(jsii_name="toListPartnerAccounts")
    def to_list_partner_accounts(self) -> "Iotwireless":
        '''(experimental) Grants permission to list the available partner accounts.

        Access Level: Read

        https://docs.aws.amazon.com/iot-wireless/2020-11-22/apireference/API_ListPartnerAccounts.html

        :stability: experimental
        '''
        return typing.cast("Iotwireless", jsii.invoke(self, "toListPartnerAccounts", []))

    @jsii.member(jsii_name="toListPositionConfigurations")
    def to_list_position_configurations(self) -> "Iotwireless":
        '''(experimental) Grants permission to list information of available position configurations based on the AWS account.

        Access Level: Read

        https://docs.aws.amazon.com/iot-wireless/2020-11-22/apireference/API_ListPositionConfigurations.html

        :stability: experimental
        '''
        return typing.cast("Iotwireless", jsii.invoke(self, "toListPositionConfigurations", []))

    @jsii.member(jsii_name="toListQueuedMessages")
    def to_list_queued_messages(self) -> "Iotwireless":
        '''(experimental) Grants permission to list the Queued Messages.

        Access Level: Read

        https://docs.aws.amazon.com/iot-wireless/2020-11-22/apireference/API_ListQueuedMessages.html

        :stability: experimental
        '''
        return typing.cast("Iotwireless", jsii.invoke(self, "toListQueuedMessages", []))

    @jsii.member(jsii_name="toListServiceProfiles")
    def to_list_service_profiles(self) -> "Iotwireless":
        '''(experimental) Grants permission to list information of available ServiceProfiles based on the AWS account.

        Access Level: Read

        https://docs.aws.amazon.com/iot-wireless/2020-11-22/apireference/API_ListServiceProfiles.html

        :stability: experimental
        '''
        return typing.cast("Iotwireless", jsii.invoke(self, "toListServiceProfiles", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Iotwireless":
        '''(experimental) Grants permission to list all tags for a given resource.

        Access Level: Read

        https://docs.aws.amazon.com/iot-wireless/2020-11-22/apireference/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("Iotwireless", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toListWirelessDevices")
    def to_list_wireless_devices(self) -> "Iotwireless":
        '''(experimental) Grants permission to list information of available WirelessDevices based on the AWS account.

        Access Level: Read

        https://docs.aws.amazon.com/iot-wireless/2020-11-22/apireference/API_ListWirelessDevices.html

        :stability: experimental
        '''
        return typing.cast("Iotwireless", jsii.invoke(self, "toListWirelessDevices", []))

    @jsii.member(jsii_name="toListWirelessGateways")
    def to_list_wireless_gateways(self) -> "Iotwireless":
        '''(experimental) Grants permission to list information of available WirelessGateways based on the AWS account.

        Access Level: Read

        https://docs.aws.amazon.com/iot-wireless/2020-11-22/apireference/API_ListWirelessGateways.html

        :stability: experimental
        '''
        return typing.cast("Iotwireless", jsii.invoke(self, "toListWirelessGateways", []))

    @jsii.member(jsii_name="toListWirelessGatewayTaskDefinitions")
    def to_list_wireless_gateway_task_definitions(self) -> "Iotwireless":
        '''(experimental) Grants permission to list information of available WirelessGateway task definitions based on the AWS account.

        Access Level: Read

        https://docs.aws.amazon.com/iot-wireless/2020-11-22/apireference/API_ListWirelessGatewayTaskDefinitions.html

        :stability: experimental
        '''
        return typing.cast("Iotwireless", jsii.invoke(self, "toListWirelessGatewayTaskDefinitions", []))

    @jsii.member(jsii_name="toPutPositionConfiguration")
    def to_put_position_configuration(self) -> "Iotwireless":
        '''(experimental) Grants permission to put position configuration for a given resource.

        Access Level: Write

        https://docs.aws.amazon.com/iot-wireless/2020-11-22/apireference/API_PutPositionConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Iotwireless", jsii.invoke(self, "toPutPositionConfiguration", []))

    @jsii.member(jsii_name="toPutResourceLogLevel")
    def to_put_resource_log_level(self) -> "Iotwireless":
        '''(experimental) Grants permission to put resource log level.

        Access Level: Write

        https://docs.aws.amazon.com/iot-wireless/2020-11-22/apireference/API_PutResourceLogLevel.html

        :stability: experimental
        '''
        return typing.cast("Iotwireless", jsii.invoke(self, "toPutResourceLogLevel", []))

    @jsii.member(jsii_name="toResetAllResourceLogLevels")
    def to_reset_all_resource_log_levels(self) -> "Iotwireless":
        '''(experimental) Grants permission to reset all resource log levels.

        Access Level: Write

        https://docs.aws.amazon.com/iot-wireless/2020-11-22/apireference/API_ResetAllResourceLogLevels.html

        :stability: experimental
        '''
        return typing.cast("Iotwireless", jsii.invoke(self, "toResetAllResourceLogLevels", []))

    @jsii.member(jsii_name="toResetResourceLogLevel")
    def to_reset_resource_log_level(self) -> "Iotwireless":
        '''(experimental) Grants permission to reset resource log level.

        Access Level: Write

        https://docs.aws.amazon.com/iot-wireless/2020-11-22/apireference/API_ResetResourceLogLevel.html

        :stability: experimental
        '''
        return typing.cast("Iotwireless", jsii.invoke(self, "toResetResourceLogLevel", []))

    @jsii.member(jsii_name="toSendDataToMulticastGroup")
    def to_send_data_to_multicast_group(self) -> "Iotwireless":
        '''(experimental) Grants permission to send data to the MulticastGroup.

        Access Level: Write

        https://docs.aws.amazon.com/iot-wireless/2020-11-22/apireference/API_SendDataToMulticastGroup.html

        :stability: experimental
        '''
        return typing.cast("Iotwireless", jsii.invoke(self, "toSendDataToMulticastGroup", []))

    @jsii.member(jsii_name="toSendDataToWirelessDevice")
    def to_send_data_to_wireless_device(self) -> "Iotwireless":
        '''(experimental) Grants permission to send the decrypted application data frame to the target device.

        Access Level: Write

        https://docs.aws.amazon.com/iot-wireless/2020-11-22/apireference/API_SendDataToWirelessDevice.html

        :stability: experimental
        '''
        return typing.cast("Iotwireless", jsii.invoke(self, "toSendDataToWirelessDevice", []))

    @jsii.member(jsii_name="toStartBulkAssociateWirelessDeviceWithMulticastGroup")
    def to_start_bulk_associate_wireless_device_with_multicast_group(
        self,
    ) -> "Iotwireless":
        '''(experimental) Grants permission to associate the WirelessDevices with MulticastGroup.

        Access Level: Write

        https://docs.aws.amazon.com/iot-wireless/2020-11-22/apireference/API_StartBulkAssociateWirelessDeviceWithMulticastGroup.html

        :stability: experimental
        '''
        return typing.cast("Iotwireless", jsii.invoke(self, "toStartBulkAssociateWirelessDeviceWithMulticastGroup", []))

    @jsii.member(jsii_name="toStartBulkDisassociateWirelessDeviceFromMulticastGroup")
    def to_start_bulk_disassociate_wireless_device_from_multicast_group(
        self,
    ) -> "Iotwireless":
        '''(experimental) Grants permission to bulk disassociate the WirelessDevices from MulticastGroup.

        Access Level: Write

        https://docs.aws.amazon.com/iot-wireless/2020-11-22/apireference/API_StartBulkDisassociateWirelessDeviceFromMulticastGroup.html

        :stability: experimental
        '''
        return typing.cast("Iotwireless", jsii.invoke(self, "toStartBulkDisassociateWirelessDeviceFromMulticastGroup", []))

    @jsii.member(jsii_name="toStartFuotaTask")
    def to_start_fuota_task(self) -> "Iotwireless":
        '''(experimental) Grants permission to start the FuotaTask.

        Access Level: Write

        https://docs.aws.amazon.com/iot-wireless/2020-11-22/apireference/API_StartFuotaTask.html

        :stability: experimental
        '''
        return typing.cast("Iotwireless", jsii.invoke(self, "toStartFuotaTask", []))

    @jsii.member(jsii_name="toStartMulticastGroupSession")
    def to_start_multicast_group_session(self) -> "Iotwireless":
        '''(experimental) Grants permission to start the MulticastGroup session.

        Access Level: Write

        https://docs.aws.amazon.com/iot-wireless/2020-11-22/apireference/API_StartMulticastGroupSession.html

        :stability: experimental
        '''
        return typing.cast("Iotwireless", jsii.invoke(self, "toStartMulticastGroupSession", []))

    @jsii.member(jsii_name="toStartNetworkAnalyzerStream")
    def to_start_network_analyzer_stream(self) -> "Iotwireless":
        '''(experimental) Grants permission to start NetworkAnalyzer stream.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/developerguide/connect-iot-lorawan-network-analyzer-api.html

        :stability: experimental
        '''
        return typing.cast("Iotwireless", jsii.invoke(self, "toStartNetworkAnalyzerStream", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Iotwireless":
        '''(experimental) Grants permission to tag a given resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/iot-wireless/2020-11-22/apireference/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("Iotwireless", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toTestWirelessDevice")
    def to_test_wireless_device(self) -> "Iotwireless":
        '''(experimental) Grants permission to simulate a provisioned device to send an uplink data with payload of 'Hello'.

        Access Level: Write

        https://docs.aws.amazon.com/iot-wireless/2020-11-22/apireference/API_TestWirelessDevice.html

        :stability: experimental
        '''
        return typing.cast("Iotwireless", jsii.invoke(self, "toTestWirelessDevice", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Iotwireless":
        '''(experimental) Grants permission to remove the given tags from the resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/iot-wireless/2020-11-22/apireference/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("Iotwireless", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateDestination")
    def to_update_destination(self) -> "Iotwireless":
        '''(experimental) Grants permission to update a Destination resource.

        Access Level: Write

        https://docs.aws.amazon.com/iot-wireless/2020-11-22/apireference/API_UpdateDestination.html

        :stability: experimental
        '''
        return typing.cast("Iotwireless", jsii.invoke(self, "toUpdateDestination", []))

    @jsii.member(jsii_name="toUpdateEventConfigurationByResourceTypes")
    def to_update_event_configuration_by_resource_types(self) -> "Iotwireless":
        '''(experimental) Grants permission to update event configuration by resource types.

        Access Level: Write

        https://docs.aws.amazon.com/iot-wireless/2020-11-22/apireference/API_UpdateEventConfigurationByResourceTypes.html

        :stability: experimental
        '''
        return typing.cast("Iotwireless", jsii.invoke(self, "toUpdateEventConfigurationByResourceTypes", []))

    @jsii.member(jsii_name="toUpdateFuotaTask")
    def to_update_fuota_task(self) -> "Iotwireless":
        '''(experimental) Grants permission to update the FuotaTask.

        Access Level: Write

        https://docs.aws.amazon.com/iot-wireless/2020-11-22/apireference/API_UpdateFuotaTask.html

        :stability: experimental
        '''
        return typing.cast("Iotwireless", jsii.invoke(self, "toUpdateFuotaTask", []))

    @jsii.member(jsii_name="toUpdateLogLevelsByResourceTypes")
    def to_update_log_levels_by_resource_types(self) -> "Iotwireless":
        '''(experimental) Grants permission to update log levels by resource types.

        Access Level: Write

        https://docs.aws.amazon.com/iot-wireless/2020-11-22/apireference/API_UpdateLogLevelsByResourceTypes.html

        :stability: experimental
        '''
        return typing.cast("Iotwireless", jsii.invoke(self, "toUpdateLogLevelsByResourceTypes", []))

    @jsii.member(jsii_name="toUpdateMulticastGroup")
    def to_update_multicast_group(self) -> "Iotwireless":
        '''(experimental) Grants permission to update the MulticastGroup.

        Access Level: Write

        https://docs.aws.amazon.com/iot-wireless/2020-11-22/apireference/API_UpdateMulticastGroup.html

        :stability: experimental
        '''
        return typing.cast("Iotwireless", jsii.invoke(self, "toUpdateMulticastGroup", []))

    @jsii.member(jsii_name="toUpdateNetworkAnalyzerConfiguration")
    def to_update_network_analyzer_configuration(self) -> "Iotwireless":
        '''(experimental) Grants permission to update the NetworkAnalyzerConfiguration.

        Access Level: Write

        https://docs.aws.amazon.com/iot-wireless/2020-11-22/apireference/API_UpdateNetworkAnalyzerConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Iotwireless", jsii.invoke(self, "toUpdateNetworkAnalyzerConfiguration", []))

    @jsii.member(jsii_name="toUpdatePartnerAccount")
    def to_update_partner_account(self) -> "Iotwireless":
        '''(experimental) Grants permission to update a partner account.

        Access Level: Write

        https://docs.aws.amazon.com/iot-wireless/2020-11-22/apireference/API_UpdatePartnerAccount.html

        :stability: experimental
        '''
        return typing.cast("Iotwireless", jsii.invoke(self, "toUpdatePartnerAccount", []))

    @jsii.member(jsii_name="toUpdatePosition")
    def to_update_position(self) -> "Iotwireless":
        '''(experimental) Grants permission to update position for a given resource.

        Access Level: Write

        https://docs.aws.amazon.com/iot-wireless/2020-11-22/apireference/API_UpdatePosition.html

        :stability: experimental
        '''
        return typing.cast("Iotwireless", jsii.invoke(self, "toUpdatePosition", []))

    @jsii.member(jsii_name="toUpdateResourceEventConfiguration")
    def to_update_resource_event_configuration(self) -> "Iotwireless":
        '''(experimental) Grants permission to update an event configuration for an identifier.

        Access Level: Write

        https://docs.aws.amazon.com/iot-wireless/2020-11-22/apireference/API_UpdateResourceEventConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Iotwireless", jsii.invoke(self, "toUpdateResourceEventConfiguration", []))

    @jsii.member(jsii_name="toUpdateResourcePosition")
    def to_update_resource_position(self) -> "Iotwireless":
        '''(experimental) Grants permission to update position for a given resource.

        Access Level: Write

        https://docs.aws.amazon.com/iot-wireless/2020-11-22/apireference/API_UpdateResourcePosition.html

        :stability: experimental
        '''
        return typing.cast("Iotwireless", jsii.invoke(self, "toUpdateResourcePosition", []))

    @jsii.member(jsii_name="toUpdateWirelessDevice")
    def to_update_wireless_device(self) -> "Iotwireless":
        '''(experimental) Grants permission to update a WirelessDevice resource.

        Access Level: Write

        https://docs.aws.amazon.com/iot-wireless/2020-11-22/apireference/API_UpdateWirelessDevice.html

        :stability: experimental
        '''
        return typing.cast("Iotwireless", jsii.invoke(self, "toUpdateWirelessDevice", []))

    @jsii.member(jsii_name="toUpdateWirelessGateway")
    def to_update_wireless_gateway(self) -> "Iotwireless":
        '''(experimental) Grants permission to update a WirelessGateway resource.

        Access Level: Write

        https://docs.aws.amazon.com/iot-wireless/2020-11-22/apireference/API_UpdateWirelessGateway.html

        :stability: experimental
        '''
        return typing.cast("Iotwireless", jsii.invoke(self, "toUpdateWirelessGateway", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7b100525db1545f30b6c61f88bb452d0ed54e0241e447b437995c9ea4021a1d9)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__df9af84393e1fdfaaf16d8adcf1819675745d40dbaf8568902488f6c919c23fb)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Iq(PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Iq"):
    '''(experimental) Statement provider for service `iq <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiq.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `iq <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiq.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="toCreateProject")
    def to_create_project(self) -> "Iq":
        '''(experimental) Grants permission to submit new project requests.

        Access Level: Write

        https://aws.amazon.com/iq/

        :stability: experimental
        '''
        return typing.cast("Iq", jsii.invoke(self, "toCreateProject", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a75eb8d6499e8b3e111a848ea7d052e4bf98d59b3da87029dfd101b6b4b8eeaf)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5ef485f3d2316180ff0a9941f072f70893107eea5cb00f0378f0b96051695d2e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class IqPermission(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.IqPermission",
):
    '''(experimental) Statement provider for service `iq-permission <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiqpermissions.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `iq-permission <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiqpermissions.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="toApproveAccessGrant")
    def to_approve_access_grant(self) -> "IqPermission":
        '''(experimental) Grants permission to approve an access grant.

        Access Level: Write

        https://aws.amazon.com/iq/

        :stability: experimental
        '''
        return typing.cast("IqPermission", jsii.invoke(self, "toApproveAccessGrant", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8bf7f05b545fec9a82b6c6d5801bd38c8bcbbc3f66e39a2fb6bf71669b33f960)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f81b477404a81c85301ffaffb120b4d6c9c50d2eeda71e2e66691c103160dcab)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Ivs(PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Ivs"):
    '''(experimental) Statement provider for service `ivs <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazoninteractivevideoservice.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `ivs <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazoninteractivevideoservice.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onChannel")
    def on_channel(
        self,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Ivs":
        '''(experimental) Adds a resource of type Channel to the statement.

        https://docs.aws.amazon.com/ivs/latest/APIReference/API_Channel.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__245e87b073e72e4d96fc49c1bedbf9453b761c08305e547cec752a669ad29ce8)
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Ivs", jsii.invoke(self, "onChannel", [resource_id, account, region, partition]))

    @jsii.member(jsii_name="onPlaybackKeyPair")
    def on_playback_key_pair(
        self,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Ivs":
        '''(experimental) Adds a resource of type Playback-Key-Pair to the statement.

        https://docs.aws.amazon.com/ivs/latest/APIReference/API_PlaybackKeyPair.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__647f9fa47147319ab1e1b94a36a62bfc1ccdf0f60b4f977af4531bfdb513a1d9)
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Ivs", jsii.invoke(self, "onPlaybackKeyPair", [resource_id, account, region, partition]))

    @jsii.member(jsii_name="onRecordingConfiguration")
    def on_recording_configuration(
        self,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Ivs":
        '''(experimental) Adds a resource of type Recording-Configuration to the statement.

        https://docs.aws.amazon.com/ivs/latest/APIReference/API_RecordingConfiguration.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2148df429f27d3ccf07cf0197e10db3a0394da5dc7a86ad14fd5f6902de0f468)
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Ivs", jsii.invoke(self, "onRecordingConfiguration", [resource_id, account, region, partition]))

    @jsii.member(jsii_name="onStreamKey")
    def on_stream_key(
        self,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Ivs":
        '''(experimental) Adds a resource of type Stream-Key to the statement.

        https://docs.aws.amazon.com/ivs/latest/APIReference/API_StreamKey.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ad4e6311a182cb29b4459dd3bc8f44faac7557d3067489b10a897939093ec630)
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Ivs", jsii.invoke(self, "onStreamKey", [resource_id, account, region, partition]))

    @jsii.member(jsii_name="toBatchGetChannel")
    def to_batch_get_channel(self) -> "Ivs":
        '''(experimental) Grants permission to get multiple channels simultaneously by channel ARN.

        Access Level: Read

        https://docs.aws.amazon.com/ivs/latest/APIReference/API_BatchGetChannel.html

        :stability: experimental
        '''
        return typing.cast("Ivs", jsii.invoke(self, "toBatchGetChannel", []))

    @jsii.member(jsii_name="toBatchGetStreamKey")
    def to_batch_get_stream_key(self) -> "Ivs":
        '''(experimental) Grants permission to get multiple stream keys simultaneously by stream key ARN.

        Access Level: Read

        https://docs.aws.amazon.com/ivs/latest/APIReference/API_BatchGetStreamKey.html

        :stability: experimental
        '''
        return typing.cast("Ivs", jsii.invoke(self, "toBatchGetStreamKey", []))

    @jsii.member(jsii_name="toCreateChannel")
    def to_create_channel(self) -> "Ivs":
        '''(experimental) Grants permission to create a new channel and an associated stream key.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/ivs/latest/APIReference/API_CreateChannel.html

        :stability: experimental
        '''
        return typing.cast("Ivs", jsii.invoke(self, "toCreateChannel", []))

    @jsii.member(jsii_name="toCreateRecordingConfiguration")
    def to_create_recording_configuration(self) -> "Ivs":
        '''(experimental) Grants permission to create a a new recording configuration.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/ivs/latest/APIReference/API_CreateRecordingConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Ivs", jsii.invoke(self, "toCreateRecordingConfiguration", []))

    @jsii.member(jsii_name="toCreateStreamKey")
    def to_create_stream_key(self) -> "Ivs":
        '''(experimental) Grants permission to create a stream key.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/ivs/latest/APIReference/API_CreateStreamKey.html

        :stability: experimental
        '''
        return typing.cast("Ivs", jsii.invoke(self, "toCreateStreamKey", []))

    @jsii.member(jsii_name="toDeleteChannel")
    def to_delete_channel(self) -> "Ivs":
        '''(experimental) Grants permission to delete a channel and channel's stream keys.

        Access Level: Write

        https://docs.aws.amazon.com/ivs/latest/APIReference/API_DeleteChannel.html

        :stability: experimental
        '''
        return typing.cast("Ivs", jsii.invoke(self, "toDeleteChannel", []))

    @jsii.member(jsii_name="toDeletePlaybackKeyPair")
    def to_delete_playback_key_pair(self) -> "Ivs":
        '''(experimental) Grants permission to delete the playback key pair for a specified ARN.

        Access Level: Write

        https://docs.aws.amazon.com/ivs/latest/APIReference/API_DeletePlaybackKeyPair.html

        :stability: experimental
        '''
        return typing.cast("Ivs", jsii.invoke(self, "toDeletePlaybackKeyPair", []))

    @jsii.member(jsii_name="toDeleteRecordingConfiguration")
    def to_delete_recording_configuration(self) -> "Ivs":
        '''(experimental) Grants permission to delete a recording configuration for the specified ARN.

        Access Level: Write

        https://docs.aws.amazon.com/ivs/latest/APIReference/API_DeleteRecordingConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Ivs", jsii.invoke(self, "toDeleteRecordingConfiguration", []))

    @jsii.member(jsii_name="toDeleteStreamKey")
    def to_delete_stream_key(self) -> "Ivs":
        '''(experimental) Grants permission to delete the stream key for a specified ARN.

        Access Level: Write

        https://docs.aws.amazon.com/ivs/latest/APIReference/API_DeleteStreamKey.html

        :stability: experimental
        '''
        return typing.cast("Ivs", jsii.invoke(self, "toDeleteStreamKey", []))

    @jsii.member(jsii_name="toGetChannel")
    def to_get_channel(self) -> "Ivs":
        '''(experimental) Grants permission to get the channel configuration for a specified channel ARN.

        Access Level: Read

        https://docs.aws.amazon.com/ivs/latest/APIReference/API_GetChannel.html

        :stability: experimental
        '''
        return typing.cast("Ivs", jsii.invoke(self, "toGetChannel", []))

    @jsii.member(jsii_name="toGetPlaybackKeyPair")
    def to_get_playback_key_pair(self) -> "Ivs":
        '''(experimental) Grants permission to get the playback keypair information for a specified ARN.

        Access Level: Read

        https://docs.aws.amazon.com/ivs/latest/APIReference/API_GetPlaybackKeyPair.html

        :stability: experimental
        '''
        return typing.cast("Ivs", jsii.invoke(self, "toGetPlaybackKeyPair", []))

    @jsii.member(jsii_name="toGetRecordingConfiguration")
    def to_get_recording_configuration(self) -> "Ivs":
        '''(experimental) Grants permission to get the recording configuration for the specified ARN.

        Access Level: Read

        https://docs.aws.amazon.com/ivs/latest/APIReference/API_GetRecordingConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Ivs", jsii.invoke(self, "toGetRecordingConfiguration", []))

    @jsii.member(jsii_name="toGetStream")
    def to_get_stream(self) -> "Ivs":
        '''(experimental) Grants permission to get information about the active (live) stream on a specified channel.

        Access Level: Read

        https://docs.aws.amazon.com/ivs/latest/APIReference/API_GetStream.html

        :stability: experimental
        '''
        return typing.cast("Ivs", jsii.invoke(self, "toGetStream", []))

    @jsii.member(jsii_name="toGetStreamKey")
    def to_get_stream_key(self) -> "Ivs":
        '''(experimental) Grants permission to get stream-key information for a specified ARN.

        Access Level: Read

        https://docs.aws.amazon.com/ivs/latest/APIReference/API_GetStreamKey.html

        :stability: experimental
        '''
        return typing.cast("Ivs", jsii.invoke(self, "toGetStreamKey", []))

    @jsii.member(jsii_name="toGetStreamSession")
    def to_get_stream_session(self) -> "Ivs":
        '''(experimental) Grants permission to get information about the stream session on a specified channel.

        Access Level: Read

        https://docs.aws.amazon.com/ivs/latest/APIReference/API_GetStreamSession.html

        :stability: experimental
        '''
        return typing.cast("Ivs", jsii.invoke(self, "toGetStreamSession", []))

    @jsii.member(jsii_name="toImportPlaybackKeyPair")
    def to_import_playback_key_pair(self) -> "Ivs":
        '''(experimental) Grants permission to import the public key.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/ivs/latest/APIReference/API_ImportPlaybackKeyPair.html

        :stability: experimental
        '''
        return typing.cast("Ivs", jsii.invoke(self, "toImportPlaybackKeyPair", []))

    @jsii.member(jsii_name="toListChannels")
    def to_list_channels(self) -> "Ivs":
        '''(experimental) Grants permission to get summary information about channels.

        Access Level: List

        https://docs.aws.amazon.com/ivs/latest/APIReference/API_ListChannels.html

        :stability: experimental
        '''
        return typing.cast("Ivs", jsii.invoke(self, "toListChannels", []))

    @jsii.member(jsii_name="toListPlaybackKeyPairs")
    def to_list_playback_key_pairs(self) -> "Ivs":
        '''(experimental) Grants permission to get summary information about playback key pairs.

        Access Level: List

        https://docs.aws.amazon.com/ivs/latest/APIReference/API_ListPlaybackKeyPairs.html

        :stability: experimental
        '''
        return typing.cast("Ivs", jsii.invoke(self, "toListPlaybackKeyPairs", []))

    @jsii.member(jsii_name="toListRecordingConfigurations")
    def to_list_recording_configurations(self) -> "Ivs":
        '''(experimental) Grants permission to get summary information about recording configurations.

        Access Level: List

        https://docs.aws.amazon.com/ivs/latest/APIReference/API_ListRecordingConfigurations.html

        :stability: experimental
        '''
        return typing.cast("Ivs", jsii.invoke(self, "toListRecordingConfigurations", []))

    @jsii.member(jsii_name="toListStreamKeys")
    def to_list_stream_keys(self) -> "Ivs":
        '''(experimental) Grants permission to get summary information about stream keys.

        Access Level: List

        https://docs.aws.amazon.com/ivs/latest/APIReference/API_ListStreamKeys.html

        :stability: experimental
        '''
        return typing.cast("Ivs", jsii.invoke(self, "toListStreamKeys", []))

    @jsii.member(jsii_name="toListStreams")
    def to_list_streams(self) -> "Ivs":
        '''(experimental) Grants permission to get summary information about live streams.

        Access Level: List

        https://docs.aws.amazon.com/ivs/latest/APIReference/API_ListStreams.html

        :stability: experimental
        '''
        return typing.cast("Ivs", jsii.invoke(self, "toListStreams", []))

    @jsii.member(jsii_name="toListStreamSessions")
    def to_list_stream_sessions(self) -> "Ivs":
        '''(experimental) Grants permission to get summary information about streams sessions on a specified channel.

        Access Level: List

        https://docs.aws.amazon.com/ivs/latest/APIReference/API_ListStreamSessions.html

        :stability: experimental
        '''
        return typing.cast("Ivs", jsii.invoke(self, "toListStreamSessions", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Ivs":
        '''(experimental) Grants permission to get information about the tags for a specified ARN.

        Access Level: Read

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/ivs/latest/APIReference/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("Ivs", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toPutMetadata")
    def to_put_metadata(self) -> "Ivs":
        '''(experimental) Grants permission to insert metadata into an RTMP stream for a specified channel.

        Access Level: Write

        https://docs.aws.amazon.com/ivs/latest/APIReference/API_PutMetadata.html

        :stability: experimental
        '''
        return typing.cast("Ivs", jsii.invoke(self, "toPutMetadata", []))

    @jsii.member(jsii_name="toStopStream")
    def to_stop_stream(self) -> "Ivs":
        '''(experimental) Grants permission to disconnect a streamer on a specified channel.

        Access Level: Write

        https://docs.aws.amazon.com/ivs/latest/APIReference/API_StopStream.html

        :stability: experimental
        '''
        return typing.cast("Ivs", jsii.invoke(self, "toStopStream", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Ivs":
        '''(experimental) Grants permission to add or update tags for a resource with a specified ARN.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/ivs/latest/APIReference/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("Ivs", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Ivs":
        '''(experimental) Grants permission to remove tags for a resource with a specified ARN.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/ivs/latest/APIReference/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("Ivs", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateChannel")
    def to_update_channel(self) -> "Ivs":
        '''(experimental) Grants permission to update a channel's configuration.

        Access Level: Write

        https://docs.aws.amazon.com/ivs/latest/APIReference/API_UpdateChannel.html

        :stability: experimental
        '''
        return typing.cast("Ivs", jsii.invoke(self, "toUpdateChannel", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6c37b6a642a2b5b05ca7d26df269143cb6fa52a5ba91d91f12623f7fc1992980)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__97a1b1ab82bf00abb8028d1e7add1790869090005957685f0f70014f90aaa472)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Ivschat(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Ivschat",
):
    '''(experimental) Statement provider for service `ivschat <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazoninteractivevideoservicechat.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `ivschat <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazoninteractivevideoservicechat.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onLoggingConfiguration")
    def on_logging_configuration(
        self,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Ivschat":
        '''(experimental) Adds a resource of type Logging-Configuration to the statement.

        https://docs.aws.amazon.com/ivs/latest/ChatAPIReference/API_LoggingConfiguration.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ad05c11b46c561ea92a8615a1fac9497952b3390e5d2848f814cc26bf8a1c7c6)
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Ivschat", jsii.invoke(self, "onLoggingConfiguration", [resource_id, account, partition]))

    @jsii.member(jsii_name="onRoom")
    def on_room(
        self,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Ivschat":
        '''(experimental) Adds a resource of type Room to the statement.

        https://docs.aws.amazon.com/ivs/latest/ChatAPIReference/API_Room.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d14540aae4ca5aa1e970affb5f2cca4a077dc0d4ba455908b5a68ee55f707659)
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Ivschat", jsii.invoke(self, "onRoom", [resource_id, account, partition]))

    @jsii.member(jsii_name="toCreateChatToken")
    def to_create_chat_token(self) -> "Ivschat":
        '''(experimental) Grants permission to create an encrypted token that is used to establish an individual WebSocket connection to a room.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/ivs/latest/ChatAPIReference/API_CreateChatToken.html

        :stability: experimental
        '''
        return typing.cast("Ivschat", jsii.invoke(self, "toCreateChatToken", []))

    @jsii.member(jsii_name="toCreateLoggingConfiguration")
    def to_create_logging_configuration(self) -> "Ivschat":
        '''(experimental) Grants permission to create a logging configuration that allows clients to record room messages.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/ivs/latest/ChatAPIReference/API_CreateLoggingConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Ivschat", jsii.invoke(self, "toCreateLoggingConfiguration", []))

    @jsii.member(jsii_name="toCreateRoom")
    def to_create_room(self) -> "Ivschat":
        '''(experimental) Grants permission to create a room that allows clients to connect and pass messages.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/ivs/latest/ChatAPIReference/API_CreateRoom.html

        :stability: experimental
        '''
        return typing.cast("Ivschat", jsii.invoke(self, "toCreateRoom", []))

    @jsii.member(jsii_name="toDeleteLoggingConfiguration")
    def to_delete_logging_configuration(self) -> "Ivschat":
        '''(experimental) Grants permission to delete the logging configuration for a specified logging configuration ARN.

        Access Level: Write

        https://docs.aws.amazon.com/ivs/latest/ChatAPIReference/API_DeleteLoggingConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Ivschat", jsii.invoke(self, "toDeleteLoggingConfiguration", []))

    @jsii.member(jsii_name="toDeleteMessage")
    def to_delete_message(self) -> "Ivschat":
        '''(experimental) Grants permission to send an event to a specific room which directs clients to delete a specific message.

        Access Level: Write

        https://docs.aws.amazon.com/ivs/latest/ChatAPIReference/API_DeleteMessage.html

        :stability: experimental
        '''
        return typing.cast("Ivschat", jsii.invoke(self, "toDeleteMessage", []))

    @jsii.member(jsii_name="toDeleteRoom")
    def to_delete_room(self) -> "Ivschat":
        '''(experimental) Grants permission to delete the room for a specified room ARN.

        Access Level: Write

        https://docs.aws.amazon.com/ivs/latest/ChatAPIReference/API_DeleteRoom.html

        :stability: experimental
        '''
        return typing.cast("Ivschat", jsii.invoke(self, "toDeleteRoom", []))

    @jsii.member(jsii_name="toDisconnectUser")
    def to_disconnect_user(self) -> "Ivschat":
        '''(experimental) Grants permission to disconnect all connections using a specified user ID from a room.

        Access Level: Write

        https://docs.aws.amazon.com/ivs/latest/ChatAPIReference/API_DisconnectUser.html

        :stability: experimental
        '''
        return typing.cast("Ivschat", jsii.invoke(self, "toDisconnectUser", []))

    @jsii.member(jsii_name="toGetLoggingConfiguration")
    def to_get_logging_configuration(self) -> "Ivschat":
        '''(experimental) Grants permission to get the logging configuration for a specified logging configuration ARN.

        Access Level: Read

        https://docs.aws.amazon.com/ivs/latest/ChatAPIReference/API_GetLoggingConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Ivschat", jsii.invoke(self, "toGetLoggingConfiguration", []))

    @jsii.member(jsii_name="toGetRoom")
    def to_get_room(self) -> "Ivschat":
        '''(experimental) Grants permission to get the room configuration for a specified room ARN.

        Access Level: Read

        https://docs.aws.amazon.com/ivs/latest/ChatAPIReference/API_GetRoom.html

        :stability: experimental
        '''
        return typing.cast("Ivschat", jsii.invoke(self, "toGetRoom", []))

    @jsii.member(jsii_name="toListLoggingConfigurations")
    def to_list_logging_configurations(self) -> "Ivschat":
        '''(experimental) Grants permission to get summary information about logging configurations.

        Access Level: List

        https://docs.aws.amazon.com/ivs/latest/ChatAPIReference/API_ListLoggingConfigurations.html

        :stability: experimental
        '''
        return typing.cast("Ivschat", jsii.invoke(self, "toListLoggingConfigurations", []))

    @jsii.member(jsii_name="toListRooms")
    def to_list_rooms(self) -> "Ivschat":
        '''(experimental) Grants permission to get summary information about rooms.

        Access Level: List

        https://docs.aws.amazon.com/ivs/latest/ChatAPIReference/API_ListRooms.html

        :stability: experimental
        '''
        return typing.cast("Ivschat", jsii.invoke(self, "toListRooms", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Ivschat":
        '''(experimental) Grants permission to get information about the tags for a specified ARN.

        Access Level: Read

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/ivs/latest/ChatAPIReference/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("Ivschat", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toSendEvent")
    def to_send_event(self) -> "Ivschat":
        '''(experimental) Grants permission to send an event to a room.

        Access Level: Write

        https://docs.aws.amazon.com/ivs/latest/ChatAPIReference/API_SendEvent.html

        :stability: experimental
        '''
        return typing.cast("Ivschat", jsii.invoke(self, "toSendEvent", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Ivschat":
        '''(experimental) Grants permission to add or update tags for a resource with a specified ARN.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/ivs/latest/ChatAPIReference/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("Ivschat", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Ivschat":
        '''(experimental) Grants permission to remove tags for a resource with a specified ARN.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/ivs/latest/ChatAPIReference/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("Ivschat", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateLoggingConfiguration")
    def to_update_logging_configuration(self) -> "Ivschat":
        '''(experimental) Grants permission to update the logging configuration for a specified logging configuration ARN.

        Access Level: Write

        https://docs.aws.amazon.com/ivs/latest/ChatAPIReference/API_UpdateLoggingConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Ivschat", jsii.invoke(self, "toUpdateLoggingConfiguration", []))

    @jsii.member(jsii_name="toUpdateRoom")
    def to_update_room(self) -> "Ivschat":
        '''(experimental) Grants permission to update the room configuration for a specified room ARN.

        Access Level: Write

        https://docs.aws.amazon.com/ivs/latest/ChatAPIReference/API_UpdateRoom.html

        :stability: experimental
        '''
        return typing.cast("Ivschat", jsii.invoke(self, "toUpdateRoom", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__02522b7755d6c263aff0c1cd680ad7d32e1abd355b04277a7dcadc08d644f5c9)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ad53a875cee0a1918692d2ed212593f95a554a6714b1fae7d2282bc808385a1d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Kafka(PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Kafka"):
    '''(experimental) Statement provider for service `kafka <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonmanagedstreamingforapachekafka.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `kafka <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonmanagedstreamingforapachekafka.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onCluster")
    def on_cluster(
        self,
        cluster_name: builtins.str,
        uuid: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Kafka":
        '''(experimental) Adds a resource of type cluster to the statement.

        https://docs.aws.amazon.com/msk/1.0/apireference/clusters-clusterarn.html

        :param cluster_name: - Identifier for the clusterName.
        :param uuid: - Identifier for the uuid.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__37119204a0c0a46594649b653d6c45cd7fc4b55fe4f6e1758478f472e99b719a)
            check_type(argname="argument cluster_name", value=cluster_name, expected_type=type_hints["cluster_name"])
            check_type(argname="argument uuid", value=uuid, expected_type=type_hints["uuid"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Kafka", jsii.invoke(self, "onCluster", [cluster_name, uuid, account, region, partition]))

    @jsii.member(jsii_name="onConfiguration")
    def on_configuration(
        self,
        configuration_name: builtins.str,
        uuid: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Kafka":
        '''(experimental) Adds a resource of type configuration to the statement.

        https://docs.aws.amazon.com/msk/1.0/apireference/configurations-arn.html

        :param configuration_name: - Identifier for the configurationName.
        :param uuid: - Identifier for the uuid.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2e5eade4f749d4c8d5d9eb033cee0c0c5026cc22b97b90a667c20bedc0051edb)
            check_type(argname="argument configuration_name", value=configuration_name, expected_type=type_hints["configuration_name"])
            check_type(argname="argument uuid", value=uuid, expected_type=type_hints["uuid"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Kafka", jsii.invoke(self, "onConfiguration", [configuration_name, uuid, account, region, partition]))

    @jsii.member(jsii_name="onGroup")
    def on_group(
        self,
        cluster_name: builtins.str,
        cluster_uuid: builtins.str,
        group_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Kafka":
        '''(experimental) Adds a resource of type group to the statement.

        https://docs.aws.amazon.com/msk/latest/developerguide/groups

        :param cluster_name: - Identifier for the clusterName.
        :param cluster_uuid: - Identifier for the clusterUuid.
        :param group_name: - Identifier for the groupName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7fd6dd53cb179eb03c05b3ce1a4b2a48712eda6875f3b31e3bfa6af99a745938)
            check_type(argname="argument cluster_name", value=cluster_name, expected_type=type_hints["cluster_name"])
            check_type(argname="argument cluster_uuid", value=cluster_uuid, expected_type=type_hints["cluster_uuid"])
            check_type(argname="argument group_name", value=group_name, expected_type=type_hints["group_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Kafka", jsii.invoke(self, "onGroup", [cluster_name, cluster_uuid, group_name, account, region, partition]))

    @jsii.member(jsii_name="onTopic")
    def on_topic(
        self,
        cluster_name: builtins.str,
        cluster_uuid: builtins.str,
        topic_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Kafka":
        '''(experimental) Adds a resource of type topic to the statement.

        https://docs.aws.amazon.com/msk/latest/developerguide/topics

        :param cluster_name: - Identifier for the clusterName.
        :param cluster_uuid: - Identifier for the clusterUuid.
        :param topic_name: - Identifier for the topicName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f236eaf563e52cffad2ecdb772d59d959664eecc11564048e6db47cb0a1ec926)
            check_type(argname="argument cluster_name", value=cluster_name, expected_type=type_hints["cluster_name"])
            check_type(argname="argument cluster_uuid", value=cluster_uuid, expected_type=type_hints["cluster_uuid"])
            check_type(argname="argument topic_name", value=topic_name, expected_type=type_hints["topic_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Kafka", jsii.invoke(self, "onTopic", [cluster_name, cluster_uuid, topic_name, account, region, partition]))

    @jsii.member(jsii_name="onTransactionalId")
    def on_transactional_id(
        self,
        cluster_name: builtins.str,
        cluster_uuid: builtins.str,
        transactional_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Kafka":
        '''(experimental) Adds a resource of type transactional-id to the statement.

        https://docs.aws.amazon.com/msk/latest/developerguide/transactional_ids

        :param cluster_name: - Identifier for the clusterName.
        :param cluster_uuid: - Identifier for the clusterUuid.
        :param transactional_id: - Identifier for the transactionalId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b6d433e115cf59a8d4cdf64e5156370501f97648b8fdb6c6507157ce5036d3b9)
            check_type(argname="argument cluster_name", value=cluster_name, expected_type=type_hints["cluster_name"])
            check_type(argname="argument cluster_uuid", value=cluster_uuid, expected_type=type_hints["cluster_uuid"])
            check_type(argname="argument transactional_id", value=transactional_id, expected_type=type_hints["transactional_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Kafka", jsii.invoke(self, "onTransactionalId", [cluster_name, cluster_uuid, transactional_id, account, region, partition]))

    @jsii.member(jsii_name="toBatchAssociateScramSecret")
    def to_batch_associate_scram_secret(self) -> "Kafka":
        '''(experimental) Grants permission to associate one or more Scram Secrets with an Amazon MSK cluster.

        Access Level: Write

        Dependent actions:

        - kms:CreateGrant
        - kms:RetireGrant

        https://docs.aws.amazon.com/msk/1.0/apireference/clusters-clusterarn-scram-secrets.html#BatchAssociateScramSecret

        :stability: experimental
        '''
        return typing.cast("Kafka", jsii.invoke(self, "toBatchAssociateScramSecret", []))

    @jsii.member(jsii_name="toBatchDisassociateScramSecret")
    def to_batch_disassociate_scram_secret(self) -> "Kafka":
        '''(experimental) Grants permission to disassociate one or more Scram Secrets from an Amazon MSK cluster.

        Access Level: Write

        Dependent actions:

        - kms:RetireGrant

        https://docs.aws.amazon.com/msk/1.0/apireference/clusters-clusterarn-scram-secrets.html#BatchDisassociateScramSecret

        :stability: experimental
        '''
        return typing.cast("Kafka", jsii.invoke(self, "toBatchDisassociateScramSecret", []))

    @jsii.member(jsii_name="toCreateCluster")
    def to_create_cluster(self) -> "Kafka":
        '''(experimental) Grants permission to create an MSK cluster.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - ec2:DescribeSecurityGroups
        - ec2:DescribeSubnets
        - ec2:DescribeVpcs
        - iam:AttachRolePolicy
        - iam:CreateServiceLinkedRole
        - iam:PutRolePolicy
        - kms:CreateGrant
        - kms:DescribeKey

        https://docs.aws.amazon.com/msk/1.0/apireference/clusters.html#CreateCluster

        :stability: experimental
        '''
        return typing.cast("Kafka", jsii.invoke(self, "toCreateCluster", []))

    @jsii.member(jsii_name="toCreateClusterV2")
    def to_create_cluster_v2(self) -> "Kafka":
        '''(experimental) Grants permission to create an MSK cluster.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - ec2:CreateTags
        - ec2:CreateVpcEndpoint
        - ec2:DeleteVpcEndpoints
        - ec2:DescribeSecurityGroups
        - ec2:DescribeSubnets
        - ec2:DescribeVpcAttribute
        - ec2:DescribeVpcEndpoints
        - ec2:DescribeVpcs
        - iam:AttachRolePolicy
        - iam:CreateServiceLinkedRole
        - iam:PutRolePolicy
        - kms:CreateGrant
        - kms:DescribeKey

        https://docs.aws.amazon.com/MSK/2.0/APIReference/v2-clusters.html#CreateClusterV2

        :stability: experimental
        '''
        return typing.cast("Kafka", jsii.invoke(self, "toCreateClusterV2", []))

    @jsii.member(jsii_name="toCreateConfiguration")
    def to_create_configuration(self) -> "Kafka":
        '''(experimental) Grants permission to create an MSK configuration.

        Access Level: Write

        https://docs.aws.amazon.com/msk/1.0/apireference/configurations.html#CreateConfiguration

        :stability: experimental
        '''
        return typing.cast("Kafka", jsii.invoke(self, "toCreateConfiguration", []))

    @jsii.member(jsii_name="toDeleteCluster")
    def to_delete_cluster(self) -> "Kafka":
        '''(experimental) Grants permission to delete an MSK cluster.

        Access Level: Write

        Dependent actions:

        - ec2:DeleteVpcEndpoints
        - ec2:DescribeVpcAttribute
        - ec2:DescribeVpcEndpoints

        https://docs.aws.amazon.com/msk/1.0/apireference/clusters-clusterarn.html#DeleteCluster

        :stability: experimental
        '''
        return typing.cast("Kafka", jsii.invoke(self, "toDeleteCluster", []))

    @jsii.member(jsii_name="toDeleteConfiguration")
    def to_delete_configuration(self) -> "Kafka":
        '''(experimental) Grants permission to delete the specified MSK configuration.

        Access Level: Write

        https://docs.aws.amazon.com/msk/1.0/apireference/configurations-arn.html#DeleteConfiguration

        :stability: experimental
        '''
        return typing.cast("Kafka", jsii.invoke(self, "toDeleteConfiguration", []))

    @jsii.member(jsii_name="toDescribeCluster")
    def to_describe_cluster(self) -> "Kafka":
        '''(experimental) Grants permission to describe an MSK cluster.

        Access Level: Read

        https://docs.aws.amazon.com/msk/1.0/apireference/clusters-clusterarn.html#DescribeCluster

        :stability: experimental
        '''
        return typing.cast("Kafka", jsii.invoke(self, "toDescribeCluster", []))

    @jsii.member(jsii_name="toDescribeClusterOperation")
    def to_describe_cluster_operation(self) -> "Kafka":
        '''(experimental) Grants permission to describe the cluster operation that is specified by the given ARN.

        Access Level: Read

        https://docs.aws.amazon.com/msk/1.0/apireference/operations-clusteroperationarn.html#DescribeClusterOperation

        :stability: experimental
        '''
        return typing.cast("Kafka", jsii.invoke(self, "toDescribeClusterOperation", []))

    @jsii.member(jsii_name="toDescribeClusterV2")
    def to_describe_cluster_v2(self) -> "Kafka":
        '''(experimental) Grants permission to describe an MSK cluster.

        Access Level: Read

        https://docs.aws.amazon.com/MSK/2.0/APIReference/v2-clusters-clusterarn.html#DescribeClusterV2

        :stability: experimental
        '''
        return typing.cast("Kafka", jsii.invoke(self, "toDescribeClusterV2", []))

    @jsii.member(jsii_name="toDescribeConfiguration")
    def to_describe_configuration(self) -> "Kafka":
        '''(experimental) Grants permission to describe an MSK configuration.

        Access Level: Read

        https://docs.aws.amazon.com/msk/1.0/apireference/configurations-arn.html#DescribeConfiguration

        :stability: experimental
        '''
        return typing.cast("Kafka", jsii.invoke(self, "toDescribeConfiguration", []))

    @jsii.member(jsii_name="toDescribeConfigurationRevision")
    def to_describe_configuration_revision(self) -> "Kafka":
        '''(experimental) Grants permission to describe an MSK configuration revision.

        Access Level: Read

        https://docs.aws.amazon.com/msk/1.0/apireference/configurations-arn-revisions-revision.html#DescribeConfigurationRevision

        :stability: experimental
        '''
        return typing.cast("Kafka", jsii.invoke(self, "toDescribeConfigurationRevision", []))

    @jsii.member(jsii_name="toGetBootstrapBrokers")
    def to_get_bootstrap_brokers(self) -> "Kafka":
        '''(experimental) Grants permission to get connection details for the brokers in an MSK cluster.

        Access Level: Read

        https://docs.aws.amazon.com/msk/1.0/apireference/clusters-clusterarn-bootstrap-brokers.html#GetBootstrapBrokers

        :stability: experimental
        '''
        return typing.cast("Kafka", jsii.invoke(self, "toGetBootstrapBrokers", []))

    @jsii.member(jsii_name="toGetCompatibleKafkaVersions")
    def to_get_compatible_kafka_versions(self) -> "Kafka":
        '''(experimental) Grants permission to get a list of the Apache Kafka versions to which you can update an MSK cluster.

        Access Level: List

        https://docs.aws.amazon.com/msk/1.0/apireference/compatible-kafka-versions.html#GetCompatibleKafkaVersions

        :stability: experimental
        '''
        return typing.cast("Kafka", jsii.invoke(self, "toGetCompatibleKafkaVersions", []))

    @jsii.member(jsii_name="toListClusterOperations")
    def to_list_cluster_operations(self) -> "Kafka":
        '''(experimental) Grants permission to return a list of all the operations that have been performed on the specified MSK cluster.

        Access Level: List

        https://docs.aws.amazon.com/msk/1.0/apireference/clusters-clusterarn-operations.html#ListClusterOperations

        :stability: experimental
        '''
        return typing.cast("Kafka", jsii.invoke(self, "toListClusterOperations", []))

    @jsii.member(jsii_name="toListClusters")
    def to_list_clusters(self) -> "Kafka":
        '''(experimental) Grants permission to list all MSK clusters in this account.

        Access Level: List

        https://docs.aws.amazon.com/msk/1.0/apireference/clusters.html#ListClusters

        :stability: experimental
        '''
        return typing.cast("Kafka", jsii.invoke(self, "toListClusters", []))

    @jsii.member(jsii_name="toListClustersV2")
    def to_list_clusters_v2(self) -> "Kafka":
        '''(experimental) Grants permission to list all MSK clusters in this account.

        Access Level: List

        https://docs.aws.amazon.com/MSK/2.0/APIReference/v2-clusters.html#ListClustersV2

        :stability: experimental
        '''
        return typing.cast("Kafka", jsii.invoke(self, "toListClustersV2", []))

    @jsii.member(jsii_name="toListConfigurationRevisions")
    def to_list_configuration_revisions(self) -> "Kafka":
        '''(experimental) Grants permission to list all revisions for an MSK configuration in this account.

        Access Level: List

        https://docs.aws.amazon.com/msk/1.0/apireference/configurations-arn-revisions.html#ListConfigurationRevisions

        :stability: experimental
        '''
        return typing.cast("Kafka", jsii.invoke(self, "toListConfigurationRevisions", []))

    @jsii.member(jsii_name="toListConfigurations")
    def to_list_configurations(self) -> "Kafka":
        '''(experimental) Grants permission to list all MSK configurations in this account.

        Access Level: List

        https://docs.aws.amazon.com/msk/1.0/apireference/configurations.html#ListConfigurations

        :stability: experimental
        '''
        return typing.cast("Kafka", jsii.invoke(self, "toListConfigurations", []))

    @jsii.member(jsii_name="toListKafkaVersions")
    def to_list_kafka_versions(self) -> "Kafka":
        '''(experimental) Grants permission to list all Apache Kafka versions supported by Amazon MSK.

        Access Level: List

        https://docs.aws.amazon.com/msk/1.0/apireference/kafka-versions.html#ListKafkaVersions

        :stability: experimental
        '''
        return typing.cast("Kafka", jsii.invoke(self, "toListKafkaVersions", []))

    @jsii.member(jsii_name="toListNodes")
    def to_list_nodes(self) -> "Kafka":
        '''(experimental) Grants permission to list brokers in an MSK cluster.

        Access Level: List

        https://docs.aws.amazon.com/msk/1.0/apireference/clusters-clusterarn-nodes.html#ListNodes

        :stability: experimental
        '''
        return typing.cast("Kafka", jsii.invoke(self, "toListNodes", []))

    @jsii.member(jsii_name="toListScramSecrets")
    def to_list_scram_secrets(self) -> "Kafka":
        '''(experimental) Grants permission to list the Scram Secrets associated with an Amazon MSK cluster.

        Access Level: List

        https://docs.aws.amazon.com/msk/1.0/apireference/clusters-clusterarn-scram-secrets.html#ListScramSecrets

        :stability: experimental
        '''
        return typing.cast("Kafka", jsii.invoke(self, "toListScramSecrets", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Kafka":
        '''(experimental) Grants permission to list tags of an MSK resource.

        Access Level: Read

        https://docs.aws.amazon.com/msk/1.0/apireference/tags-resourcearn.html#ListTagsForResource

        :stability: experimental
        '''
        return typing.cast("Kafka", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toRebootBroker")
    def to_reboot_broker(self) -> "Kafka":
        '''(experimental) Grants permission to reboot broker.

        Access Level: Write

        https://docs.aws.amazon.com/msk/1.0/apireference/clusters-clusterarn-reboot-broker.html#RebootBroker

        :stability: experimental
        '''
        return typing.cast("Kafka", jsii.invoke(self, "toRebootBroker", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Kafka":
        '''(experimental) Grants permission to tag an MSK resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/msk/1.0/apireference/tags-resourcearn.html#TagResource

        :stability: experimental
        '''
        return typing.cast("Kafka", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Kafka":
        '''(experimental) Grants permission to remove tags from an MSK resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/msk/1.0/apireference/tags-resourcearn.html#UntagResource

        :stability: experimental
        '''
        return typing.cast("Kafka", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateBrokerCount")
    def to_update_broker_count(self) -> "Kafka":
        '''(experimental) Grants permission to update the number of brokers of the MSK cluster.

        Access Level: Write

        https://docs.aws.amazon.com/msk/1.0/apireference/clusters-clusterarn-nodes-count.html#UpdateBrokerCount

        :stability: experimental
        '''
        return typing.cast("Kafka", jsii.invoke(self, "toUpdateBrokerCount", []))

    @jsii.member(jsii_name="toUpdateBrokerStorage")
    def to_update_broker_storage(self) -> "Kafka":
        '''(experimental) Grants permission to update the storage size of the brokers of the MSK cluster.

        Access Level: Write

        https://docs.aws.amazon.com/msk/1.0/apireference/clusters-clusterarn-nodes-storage.html#UpdateBrokerStorage

        :stability: experimental
        '''
        return typing.cast("Kafka", jsii.invoke(self, "toUpdateBrokerStorage", []))

    @jsii.member(jsii_name="toUpdateBrokerType")
    def to_update_broker_type(self) -> "Kafka":
        '''(experimental) Grants permission to update the broker type of an Amazon MSK cluster.

        Access Level: Write

        https://docs.aws.amazon.com/msk/1.0/apireference/clusters-clusterarn-nodes-type.html#UpdateBrokerType

        :stability: experimental
        '''
        return typing.cast("Kafka", jsii.invoke(self, "toUpdateBrokerType", []))

    @jsii.member(jsii_name="toUpdateClusterConfiguration")
    def to_update_cluster_configuration(self) -> "Kafka":
        '''(experimental) Grants permission to update the configuration of the MSK cluster.

        Access Level: Write

        https://docs.aws.amazon.com/msk/1.0/apireference/clusters-clusterarn-configuration.html#UpdateClusterConfiguration

        :stability: experimental
        '''
        return typing.cast("Kafka", jsii.invoke(self, "toUpdateClusterConfiguration", []))

    @jsii.member(jsii_name="toUpdateClusterKafkaVersion")
    def to_update_cluster_kafka_version(self) -> "Kafka":
        '''(experimental) Grants permission to update the MSK cluster to the specified Apache Kafka version.

        Access Level: Write

        https://docs.aws.amazon.com/msk/1.0/apireference/clusters-clusterarn-version.html#UpdateClusterKafkaVersion

        :stability: experimental
        '''
        return typing.cast("Kafka", jsii.invoke(self, "toUpdateClusterKafkaVersion", []))

    @jsii.member(jsii_name="toUpdateConfiguration")
    def to_update_configuration(self) -> "Kafka":
        '''(experimental) Grants permission to create a new revision of the MSK configuration.

        Access Level: Write

        https://docs.aws.amazon.com/msk/1.0/apireference/configurations-arn.html#UpdateConfiguration

        :stability: experimental
        '''
        return typing.cast("Kafka", jsii.invoke(self, "toUpdateConfiguration", []))

    @jsii.member(jsii_name="toUpdateConnectivity")
    def to_update_connectivity(self) -> "Kafka":
        '''(experimental) Grants permission to update the connectivity settings for the MSK cluster.

        Access Level: Write

        Dependent actions:

        - ec2:DescribeRouteTables
        - ec2:DescribeSubnets

        https://docs.aws.amazon.com/msk/1.0/apireference/clusters-clusterarn-connectivity.html#UpdateConnectivity

        :stability: experimental
        '''
        return typing.cast("Kafka", jsii.invoke(self, "toUpdateConnectivity", []))

    @jsii.member(jsii_name="toUpdateMonitoring")
    def to_update_monitoring(self) -> "Kafka":
        '''(experimental) Grants permission to update the monitoring settings for the MSK cluster.

        Access Level: Write

        https://docs.aws.amazon.com/msk/1.0/apireference/clusters-clusterarn-monitoring.html#UpdateMonitoring

        :stability: experimental
        '''
        return typing.cast("Kafka", jsii.invoke(self, "toUpdateMonitoring", []))

    @jsii.member(jsii_name="toUpdateSecurity")
    def to_update_security(self) -> "Kafka":
        '''(experimental) Grants permission to update the security settings for the MSK cluster.

        Access Level: Write

        Dependent actions:

        - kms:RetireGrant

        https://docs.aws.amazon.com/msk/1.0/apireference/clusters-clusterarn-security.html#UpdateSecurity

        :stability: experimental
        '''
        return typing.cast("Kafka", jsii.invoke(self, "toUpdateSecurity", []))

    @jsii.member(jsii_name="toUpdateStorage")
    def to_update_storage(self) -> "Kafka":
        '''(experimental) Grants permission to update the EBS storage (size or provisioned throughput) associated with MSK brokers or set cluster storage mode to TIERED.

        Access Level: Write

        https://docs.aws.amazon.com/msk/1.0/apireference/clusters-clusterarn-storage.html#UpdateStorage

        :stability: experimental
        '''
        return typing.cast("Kafka", jsii.invoke(self, "toUpdateStorage", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ad4e45e46f4e4a762f62a853bc6f982a958c47730961067df7763dafbaddb084)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__94a16bfb6bee663b631220c0e793fdfe3ff11cb5d484e75a237761e17ed3bcff)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class KafkaCluster(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.KafkaCluster",
):
    '''(experimental) Statement provider for service `kafka-cluster <https://docs.aws.amazon.com/service-authorization/latest/reference/list_apachekafkaapisforamazonmskclusters.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `kafka-cluster <https://docs.aws.amazon.com/service-authorization/latest/reference/list_apachekafkaapisforamazonmskclusters.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onCluster")
    def on_cluster(
        self,
        cluster_name: builtins.str,
        cluster_uuid: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "KafkaCluster":
        '''(experimental) Adds a resource of type cluster to the statement.

        https://docs.aws.amazon.com/msk/latest/developerguide/iam-access-control.html#msk-iam-resources

        :param cluster_name: - Identifier for the clusterName.
        :param cluster_uuid: - Identifier for the clusterUuid.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2d5a9cfa1c9ce4f273182cf078cddf6d4af0b81e146dec6f07e6e77225253497)
            check_type(argname="argument cluster_name", value=cluster_name, expected_type=type_hints["cluster_name"])
            check_type(argname="argument cluster_uuid", value=cluster_uuid, expected_type=type_hints["cluster_uuid"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("KafkaCluster", jsii.invoke(self, "onCluster", [cluster_name, cluster_uuid, account, region, partition]))

    @jsii.member(jsii_name="onGroup")
    def on_group(
        self,
        cluster_name: builtins.str,
        cluster_uuid: builtins.str,
        group_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "KafkaCluster":
        '''(experimental) Adds a resource of type group to the statement.

        https://docs.aws.amazon.com/msk/latest/developerguide/iam-access-control.html#msk-iam-resources

        :param cluster_name: - Identifier for the clusterName.
        :param cluster_uuid: - Identifier for the clusterUuid.
        :param group_name: - Identifier for the groupName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__93dc711492812324b97f36d6f8461dd4f43a5ed0f6a25e8fe1a78a8a3d51eda1)
            check_type(argname="argument cluster_name", value=cluster_name, expected_type=type_hints["cluster_name"])
            check_type(argname="argument cluster_uuid", value=cluster_uuid, expected_type=type_hints["cluster_uuid"])
            check_type(argname="argument group_name", value=group_name, expected_type=type_hints["group_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("KafkaCluster", jsii.invoke(self, "onGroup", [cluster_name, cluster_uuid, group_name, account, region, partition]))

    @jsii.member(jsii_name="onTopic")
    def on_topic(
        self,
        cluster_name: builtins.str,
        cluster_uuid: builtins.str,
        topic_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "KafkaCluster":
        '''(experimental) Adds a resource of type topic to the statement.

        https://docs.aws.amazon.com/msk/latest/developerguide/iam-access-control.html#msk-iam-resources

        :param cluster_name: - Identifier for the clusterName.
        :param cluster_uuid: - Identifier for the clusterUuid.
        :param topic_name: - Identifier for the topicName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__90e24c2ba708ab746b770c45ed1219308c370f2177a8d2bc166776cb08799720)
            check_type(argname="argument cluster_name", value=cluster_name, expected_type=type_hints["cluster_name"])
            check_type(argname="argument cluster_uuid", value=cluster_uuid, expected_type=type_hints["cluster_uuid"])
            check_type(argname="argument topic_name", value=topic_name, expected_type=type_hints["topic_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("KafkaCluster", jsii.invoke(self, "onTopic", [cluster_name, cluster_uuid, topic_name, account, region, partition]))

    @jsii.member(jsii_name="onTransactionalId")
    def on_transactional_id(
        self,
        cluster_name: builtins.str,
        cluster_uuid: builtins.str,
        transactional_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "KafkaCluster":
        '''(experimental) Adds a resource of type transactional-id to the statement.

        https://docs.aws.amazon.com/msk/latest/developerguide/iam-access-control.html#msk-iam-resources

        :param cluster_name: - Identifier for the clusterName.
        :param cluster_uuid: - Identifier for the clusterUuid.
        :param transactional_id: - Identifier for the transactionalId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__87a4edbf07e1c853c38ab08946120cba128e9abba90914a93d301ef0e4f45571)
            check_type(argname="argument cluster_name", value=cluster_name, expected_type=type_hints["cluster_name"])
            check_type(argname="argument cluster_uuid", value=cluster_uuid, expected_type=type_hints["cluster_uuid"])
            check_type(argname="argument transactional_id", value=transactional_id, expected_type=type_hints["transactional_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("KafkaCluster", jsii.invoke(self, "onTransactionalId", [cluster_name, cluster_uuid, transactional_id, account, region, partition]))

    @jsii.member(jsii_name="toAlterCluster")
    def to_alter_cluster(self) -> "KafkaCluster":
        '''(experimental) Grants permission to alter various aspects of the cluster, equivalent to Apache Kafka's ALTER CLUSTER ACL.

        Access Level: Write

        Dependent actions:

        - kafka-cluster:Connect
        - kafka-cluster:DescribeCluster

        https://docs.aws.amazon.com/msk/latest/developerguide/iam-access-control.html#actions

        :stability: experimental
        '''
        return typing.cast("KafkaCluster", jsii.invoke(self, "toAlterCluster", []))

    @jsii.member(jsii_name="toAlterClusterDynamicConfiguration")
    def to_alter_cluster_dynamic_configuration(self) -> "KafkaCluster":
        '''(experimental) Grants permission to alter the dynamic configuration of a cluster, equivalent to Apache Kafka's ALTER_CONFIGS CLUSTER ACL.

        Access Level: Write

        Dependent actions:

        - kafka-cluster:Connect
        - kafka-cluster:DescribeClusterDynamicConfiguration

        https://docs.aws.amazon.com/msk/latest/developerguide/iam-access-control.html#actions

        :stability: experimental
        '''
        return typing.cast("KafkaCluster", jsii.invoke(self, "toAlterClusterDynamicConfiguration", []))

    @jsii.member(jsii_name="toAlterGroup")
    def to_alter_group(self) -> "KafkaCluster":
        '''(experimental) Grants permission to join groups on a cluster, equivalent to Apache Kafka's READ GROUP ACL.

        Access Level: Write

        Dependent actions:

        - kafka-cluster:Connect
        - kafka-cluster:DescribeGroup

        https://docs.aws.amazon.com/msk/latest/developerguide/iam-access-control.html#actions

        :stability: experimental
        '''
        return typing.cast("KafkaCluster", jsii.invoke(self, "toAlterGroup", []))

    @jsii.member(jsii_name="toAlterTopic")
    def to_alter_topic(self) -> "KafkaCluster":
        '''(experimental) Grants permission to alter topics on a cluster, equivalent to Apache Kafka's ALTER TOPIC ACL.

        Access Level: Write

        Dependent actions:

        - kafka-cluster:Connect
        - kafka-cluster:DescribeTopic

        https://docs.aws.amazon.com/msk/latest/developerguide/iam-access-control.html#actions

        :stability: experimental
        '''
        return typing.cast("KafkaCluster", jsii.invoke(self, "toAlterTopic", []))

    @jsii.member(jsii_name="toAlterTopicDynamicConfiguration")
    def to_alter_topic_dynamic_configuration(self) -> "KafkaCluster":
        '''(experimental) Grants permission to alter the dynamic configuration of topics on a cluster, equivalent to Apache Kafka's ALTER_CONFIGS TOPIC ACL.

        Access Level: Write

        Dependent actions:

        - kafka-cluster:Connect
        - kafka-cluster:DescribeTopicDynamicConfiguration

        https://docs.aws.amazon.com/msk/latest/developerguide/iam-access-control.html#actions

        :stability: experimental
        '''
        return typing.cast("KafkaCluster", jsii.invoke(self, "toAlterTopicDynamicConfiguration", []))

    @jsii.member(jsii_name="toAlterTransactionalId")
    def to_alter_transactional_id(self) -> "KafkaCluster":
        '''(experimental) Grants permission to alter transactional IDs on a cluster, equivalent to Apache Kafka's WRITE TRANSACTIONAL_ID ACL.

        Access Level: Write

        Dependent actions:

        - kafka-cluster:Connect
        - kafka-cluster:DescribeTransactionalId
        - kafka-cluster:WriteData

        https://docs.aws.amazon.com/msk/latest/developerguide/iam-access-control.html#actions

        :stability: experimental
        '''
        return typing.cast("KafkaCluster", jsii.invoke(self, "toAlterTransactionalId", []))

    @jsii.member(jsii_name="toConnect")
    def to_connect(self) -> "KafkaCluster":
        '''(experimental) Grants permission to connect and authenticate to the cluster.

        Access Level: Write

        https://docs.aws.amazon.com/msk/latest/developerguide/iam-access-control.html#actions

        :stability: experimental
        '''
        return typing.cast("KafkaCluster", jsii.invoke(self, "toConnect", []))

    @jsii.member(jsii_name="toCreateTopic")
    def to_create_topic(self) -> "KafkaCluster":
        '''(experimental) Grants permission to create topics on a cluster, equivalent to Apache Kafka's CREATE CLUSTER/TOPIC ACL.

        Access Level: Write

        Dependent actions:

        - kafka-cluster:Connect

        https://docs.aws.amazon.com/msk/latest/developerguide/iam-access-control.html#actions

        :stability: experimental
        '''
        return typing.cast("KafkaCluster", jsii.invoke(self, "toCreateTopic", []))

    @jsii.member(jsii_name="toDeleteGroup")
    def to_delete_group(self) -> "KafkaCluster":
        '''(experimental) Grants permission to delete groups on a cluster, equivalent to Apache Kafka's DELETE GROUP ACL.

        Access Level: Write

        Dependent actions:

        - kafka-cluster:Connect
        - kafka-cluster:DescribeGroup

        https://docs.aws.amazon.com/msk/latest/developerguide/iam-access-control.html#actions

        :stability: experimental
        '''
        return typing.cast("KafkaCluster", jsii.invoke(self, "toDeleteGroup", []))

    @jsii.member(jsii_name="toDeleteTopic")
    def to_delete_topic(self) -> "KafkaCluster":
        '''(experimental) Grants permission to delete topics on a cluster, equivalent to Apache Kafka's DELETE TOPIC ACL.

        Access Level: Write

        Dependent actions:

        - kafka-cluster:Connect
        - kafka-cluster:DescribeTopic

        https://docs.aws.amazon.com/msk/latest/developerguide/iam-access-control.html#actions

        :stability: experimental
        '''
        return typing.cast("KafkaCluster", jsii.invoke(self, "toDeleteTopic", []))

    @jsii.member(jsii_name="toDescribeCluster")
    def to_describe_cluster(self) -> "KafkaCluster":
        '''(experimental) Grants permission to describe various aspects of the cluster, equivalent to Apache Kafka's DESCRIBE CLUSTER ACL.

        Access Level: List

        Dependent actions:

        - kafka-cluster:Connect

        https://docs.aws.amazon.com/msk/latest/developerguide/iam-access-control.html#actions

        :stability: experimental
        '''
        return typing.cast("KafkaCluster", jsii.invoke(self, "toDescribeCluster", []))

    @jsii.member(jsii_name="toDescribeClusterDynamicConfiguration")
    def to_describe_cluster_dynamic_configuration(self) -> "KafkaCluster":
        '''(experimental) Grants permission to describe the dynamic configuration of a cluster, equivalent to Apache Kafka's DESCRIBE_CONFIGS CLUSTER ACL.

        Access Level: List

        Dependent actions:

        - kafka-cluster:Connect

        https://docs.aws.amazon.com/msk/latest/developerguide/iam-access-control.html#actions

        :stability: experimental
        '''
        return typing.cast("KafkaCluster", jsii.invoke(self, "toDescribeClusterDynamicConfiguration", []))

    @jsii.member(jsii_name="toDescribeGroup")
    def to_describe_group(self) -> "KafkaCluster":
        '''(experimental) Grants permission to describe groups on a cluster, equivalent to Apache Kafka's DESCRIBE GROUP ACL.

        Access Level: List

        Dependent actions:

        - kafka-cluster:Connect

        https://docs.aws.amazon.com/msk/latest/developerguide/iam-access-control.html#actions

        :stability: experimental
        '''
        return typing.cast("KafkaCluster", jsii.invoke(self, "toDescribeGroup", []))

    @jsii.member(jsii_name="toDescribeTopic")
    def to_describe_topic(self) -> "KafkaCluster":
        '''(experimental) Grants permission to describe topics on a cluster, equivalent to Apache Kafka's DESCRIBE TOPIC ACL.

        Access Level: List

        Dependent actions:

        - kafka-cluster:Connect

        https://docs.aws.amazon.com/msk/latest/developerguide/iam-access-control.html#actions

        :stability: experimental
        '''
        return typing.cast("KafkaCluster", jsii.invoke(self, "toDescribeTopic", []))

    @jsii.member(jsii_name="toDescribeTopicDynamicConfiguration")
    def to_describe_topic_dynamic_configuration(self) -> "KafkaCluster":
        '''(experimental) Grants permission to describe the dynamic configuration of topics on a cluster, equivalent to Apache Kafka's DESCRIBE_CONFIGS TOPIC ACL.

        Access Level: List

        Dependent actions:

        - kafka-cluster:Connect

        https://docs.aws.amazon.com/msk/latest/developerguide/iam-access-control.html#actions

        :stability: experimental
        '''
        return typing.cast("KafkaCluster", jsii.invoke(self, "toDescribeTopicDynamicConfiguration", []))

    @jsii.member(jsii_name="toDescribeTransactionalId")
    def to_describe_transactional_id(self) -> "KafkaCluster":
        '''(experimental) Grants permission to describe transactional IDs on a cluster, equivalent to Apache Kafka's DESCRIBE TRANSACTIONAL_ID ACL.

        Access Level: List

        Dependent actions:

        - kafka-cluster:Connect

        https://docs.aws.amazon.com/msk/latest/developerguide/iam-access-control.html#actions

        :stability: experimental
        '''
        return typing.cast("KafkaCluster", jsii.invoke(self, "toDescribeTransactionalId", []))

    @jsii.member(jsii_name="toReadData")
    def to_read_data(self) -> "KafkaCluster":
        '''(experimental) Grants permission to read data from topics on a cluster, equivalent to Apache Kafka's READ TOPIC ACL.

        Access Level: Read

        Dependent actions:

        - kafka-cluster:AlterGroup
        - kafka-cluster:Connect
        - kafka-cluster:DescribeTopic

        https://docs.aws.amazon.com/msk/latest/developerguide/iam-access-control.html#actions

        :stability: experimental
        '''
        return typing.cast("KafkaCluster", jsii.invoke(self, "toReadData", []))

    @jsii.member(jsii_name="toWriteData")
    def to_write_data(self) -> "KafkaCluster":
        '''(experimental) Grants permission to write data to topics on a cluster, equivalent to Apache Kafka's WRITE TOPIC ACL.

        Access Level: Write

        Dependent actions:

        - kafka-cluster:Connect
        - kafka-cluster:DescribeTopic

        https://docs.aws.amazon.com/msk/latest/developerguide/iam-access-control.html#actions

        :stability: experimental
        '''
        return typing.cast("KafkaCluster", jsii.invoke(self, "toWriteData", []))

    @jsii.member(jsii_name="toWriteDataIdempotently")
    def to_write_data_idempotently(self) -> "KafkaCluster":
        '''(experimental) Grants permission to write data idempotently on a cluster, equivalent to Apache Kafka's IDEMPOTENT_WRITE CLUSTER ACL.

        Access Level: Write

        Dependent actions:

        - kafka-cluster:Connect
        - kafka-cluster:WriteData

        https://docs.aws.amazon.com/msk/latest/developerguide/iam-access-control.html#actions

        :stability: experimental
        '''
        return typing.cast("KafkaCluster", jsii.invoke(self, "toWriteDataIdempotently", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c5abf54761fd4bfb068617a7f3c91af5bff9bf509bd8d587f980198f85669904)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__538baa165e4cd015bb64c35f243884b0d7615e7c95098f326d94119200d2fc52)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Kafkaconnect(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Kafkaconnect",
):
    '''(experimental) Statement provider for service `kafkaconnect <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonmanagedstreamingforkafkaconnect.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `kafkaconnect <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonmanagedstreamingforkafkaconnect.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onConnector")
    def on_connector(
        self,
        connector_name: builtins.str,
        u_uid: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Kafkaconnect":
        '''(experimental) Adds a resource of type connector to the statement.

        https://docs.aws.amazon.com/MSKC/latest/mskc/API_ConnectorSummary.html

        :param connector_name: - Identifier for the connectorName.
        :param u_uid: - Identifier for the uUID.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f090b968493bd396995e0967de945c904aebb63c55a769a908cada067a325f07)
            check_type(argname="argument connector_name", value=connector_name, expected_type=type_hints["connector_name"])
            check_type(argname="argument u_uid", value=u_uid, expected_type=type_hints["u_uid"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Kafkaconnect", jsii.invoke(self, "onConnector", [connector_name, u_uid, account, region, partition]))

    @jsii.member(jsii_name="onCustomPlugin")
    def on_custom_plugin(
        self,
        custom_plugin_name: builtins.str,
        u_uid: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Kafkaconnect":
        '''(experimental) Adds a resource of type custom plugin to the statement.

        https://docs.aws.amazon.com/MSKC/latest/mskc/API_CustomPlugin.html

        :param custom_plugin_name: - Identifier for the customPluginName.
        :param u_uid: - Identifier for the uUID.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__142ddd34b1249e564178e848f3e93c8afebf54fe9637fe173e2c75ad84b2aad4)
            check_type(argname="argument custom_plugin_name", value=custom_plugin_name, expected_type=type_hints["custom_plugin_name"])
            check_type(argname="argument u_uid", value=u_uid, expected_type=type_hints["u_uid"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Kafkaconnect", jsii.invoke(self, "onCustomPlugin", [custom_plugin_name, u_uid, account, region, partition]))

    @jsii.member(jsii_name="onWorkerConfiguration")
    def on_worker_configuration(
        self,
        worker_configuration_name: builtins.str,
        u_uid: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Kafkaconnect":
        '''(experimental) Adds a resource of type worker configuration to the statement.

        https://docs.aws.amazon.com/MSKC/latest/mskc/API_WorkerConfiguration.html

        :param worker_configuration_name: - Identifier for the workerConfigurationName.
        :param u_uid: - Identifier for the uUID.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7121def064542a5fe3f8985dcb6ef101fa3d8098f8e49bf8ad85dc930e22d717)
            check_type(argname="argument worker_configuration_name", value=worker_configuration_name, expected_type=type_hints["worker_configuration_name"])
            check_type(argname="argument u_uid", value=u_uid, expected_type=type_hints["u_uid"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Kafkaconnect", jsii.invoke(self, "onWorkerConfiguration", [worker_configuration_name, u_uid, account, region, partition]))

    @jsii.member(jsii_name="toCreateConnector")
    def to_create_connector(self) -> "Kafkaconnect":
        '''(experimental) Grants permission to create an MSK Connect connector.

        Access Level: Write

        Dependent actions:

        - ec2:CreateNetworkInterface
        - ec2:DescribeSecurityGroups
        - ec2:DescribeSubnets
        - ec2:DescribeVpcs
        - firehose:TagDeliveryStream
        - iam:AttachRolePolicy
        - iam:CreateServiceLinkedRole
        - iam:PassRole
        - iam:PutRolePolicy
        - logs:CreateLogDelivery
        - logs:DescribeLogGroups
        - logs:DescribeResourcePolicies
        - logs:GetLogDelivery
        - logs:ListLogDeliveries
        - logs:PutResourcePolicy
        - s3:GetBucketPolicy
        - s3:PutBucketPolicy

        https://docs.aws.amazon.com/MSKC/latest/mskc/API_CreateConnector.html

        :stability: experimental
        '''
        return typing.cast("Kafkaconnect", jsii.invoke(self, "toCreateConnector", []))

    @jsii.member(jsii_name="toCreateCustomPlugin")
    def to_create_custom_plugin(self) -> "Kafkaconnect":
        '''(experimental) Grants permission to create an MSK Connect custom plugin.

        Access Level: Write

        Dependent actions:

        - s3:GetObject

        https://docs.aws.amazon.com/MSKC/latest/mskc/API_CreateCustomPlugin.html

        :stability: experimental
        '''
        return typing.cast("Kafkaconnect", jsii.invoke(self, "toCreateCustomPlugin", []))

    @jsii.member(jsii_name="toCreateWorkerConfiguration")
    def to_create_worker_configuration(self) -> "Kafkaconnect":
        '''(experimental) Grants permission to create an MSK Connect worker configuration.

        Access Level: Write

        https://docs.aws.amazon.com/MSKC/latest/mskc/API_CreateWorkerConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Kafkaconnect", jsii.invoke(self, "toCreateWorkerConfiguration", []))

    @jsii.member(jsii_name="toDeleteConnector")
    def to_delete_connector(self) -> "Kafkaconnect":
        '''(experimental) Grants permission to delete an MSK Connect connector.

        Access Level: Write

        Dependent actions:

        - logs:DeleteLogDelivery
        - logs:ListLogDeliveries

        https://docs.aws.amazon.com/MSKC/latest/mskc/API_DeleteConnector.html

        :stability: experimental
        '''
        return typing.cast("Kafkaconnect", jsii.invoke(self, "toDeleteConnector", []))

    @jsii.member(jsii_name="toDeleteCustomPlugin")
    def to_delete_custom_plugin(self) -> "Kafkaconnect":
        '''(experimental) Grants permission to delete an MSK Connect custom plugin.

        Access Level: Write

        https://docs.aws.amazon.com/MSKC/latest/mskc/API_DeleteCustomPlugin.html

        :stability: experimental
        '''
        return typing.cast("Kafkaconnect", jsii.invoke(self, "toDeleteCustomPlugin", []))

    @jsii.member(jsii_name="toDescribeConnector")
    def to_describe_connector(self) -> "Kafkaconnect":
        '''(experimental) Grants permission to describe an MSK Connect connector.

        Access Level: Read

        https://docs.aws.amazon.com/MSKC/latest/mskc/API_DescribeConnector.html

        :stability: experimental
        '''
        return typing.cast("Kafkaconnect", jsii.invoke(self, "toDescribeConnector", []))

    @jsii.member(jsii_name="toDescribeCustomPlugin")
    def to_describe_custom_plugin(self) -> "Kafkaconnect":
        '''(experimental) Grants permission to describe an MSK Connect custom plugin.

        Access Level: Read

        https://docs.aws.amazon.com/MSKC/latest/mskc/API_DescribeCustomPlugin.html

        :stability: experimental
        '''
        return typing.cast("Kafkaconnect", jsii.invoke(self, "toDescribeCustomPlugin", []))

    @jsii.member(jsii_name="toDescribeWorkerConfiguration")
    def to_describe_worker_configuration(self) -> "Kafkaconnect":
        '''(experimental) Grants permission to describe an MSK Connect worker configuration.

        Access Level: Read

        https://docs.aws.amazon.com/MSKC/latest/mskc/API_DescribeWorkerConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Kafkaconnect", jsii.invoke(self, "toDescribeWorkerConfiguration", []))

    @jsii.member(jsii_name="toListConnectors")
    def to_list_connectors(self) -> "Kafkaconnect":
        '''(experimental) Grants permission to list all MSK Connect connectors in this account.

        Access Level: Read

        https://docs.aws.amazon.com/MSKC/latest/mskc/API_ListConnectors.html

        :stability: experimental
        '''
        return typing.cast("Kafkaconnect", jsii.invoke(self, "toListConnectors", []))

    @jsii.member(jsii_name="toListCustomPlugins")
    def to_list_custom_plugins(self) -> "Kafkaconnect":
        '''(experimental) Grants permission to list all MSK Connect custom plugins in this account.

        Access Level: Read

        https://docs.aws.amazon.com/MSKC/latest/mskc/API_ListCustomPlugins.html

        :stability: experimental
        '''
        return typing.cast("Kafkaconnect", jsii.invoke(self, "toListCustomPlugins", []))

    @jsii.member(jsii_name="toListWorkerConfigurations")
    def to_list_worker_configurations(self) -> "Kafkaconnect":
        '''(experimental) Grants permission to list all MSK Connect worker configurations in this account.

        Access Level: Read

        https://docs.aws.amazon.com/MSKC/latest/mskc/API_ListWorkerConfigurations.html

        :stability: experimental
        '''
        return typing.cast("Kafkaconnect", jsii.invoke(self, "toListWorkerConfigurations", []))

    @jsii.member(jsii_name="toUpdateConnector")
    def to_update_connector(self) -> "Kafkaconnect":
        '''(experimental) Grants permission to update an MSK Connect connector.

        Access Level: Write

        https://docs.aws.amazon.com/MSKC/latest/mskc/API_UpdateConnector.html

        :stability: experimental
        '''
        return typing.cast("Kafkaconnect", jsii.invoke(self, "toUpdateConnector", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0bfe6417f8fd7be4637ed3c86dd59cb86ac9e6e15f613f4cf7ef88672a304eac)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__984426b036ee9c205002bb77256ccee799dbeab5a852772257c6e0d7d1f1ea09)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Kendra(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Kendra",
):
    '''(experimental) Statement provider for service `kendra <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonkendra.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `kendra <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonkendra.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onDataSource")
    def on_data_source(
        self,
        index_id: builtins.str,
        data_source_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Kendra":
        '''(experimental) Adds a resource of type data-source to the statement.

        https://docs.aws.amazon.com/kendra/latest/dg/data-source.html

        :param index_id: - Identifier for the indexId.
        :param data_source_id: - Identifier for the dataSourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d441fe6f1f79f46797fac8de8713a27cf80ea1289aa57ba6266e06d66d5c06b6)
            check_type(argname="argument index_id", value=index_id, expected_type=type_hints["index_id"])
            check_type(argname="argument data_source_id", value=data_source_id, expected_type=type_hints["data_source_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Kendra", jsii.invoke(self, "onDataSource", [index_id, data_source_id, account, region, partition]))

    @jsii.member(jsii_name="onExperience")
    def on_experience(
        self,
        index_id: builtins.str,
        experience_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Kendra":
        '''(experimental) Adds a resource of type experience to the statement.

        https://docs.aws.amazon.com/kendra/latest/dg/deploying-search-experience-no-code.html

        :param index_id: - Identifier for the indexId.
        :param experience_id: - Identifier for the experienceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8b7b1a8814575a83bd41044948492a48d384cc0c2b2818c20ea703d8334c6167)
            check_type(argname="argument index_id", value=index_id, expected_type=type_hints["index_id"])
            check_type(argname="argument experience_id", value=experience_id, expected_type=type_hints["experience_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Kendra", jsii.invoke(self, "onExperience", [index_id, experience_id, account, region, partition]))

    @jsii.member(jsii_name="onFaq")
    def on_faq(
        self,
        index_id: builtins.str,
        faq_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Kendra":
        '''(experimental) Adds a resource of type faq to the statement.

        https://docs.aws.amazon.com/kendra/latest/dg/faq.html

        :param index_id: - Identifier for the indexId.
        :param faq_id: - Identifier for the faqId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ec4927752c6781a26998063169d0757e6aa4a884efaf54e554c09fdf8f1cf4f3)
            check_type(argname="argument index_id", value=index_id, expected_type=type_hints["index_id"])
            check_type(argname="argument faq_id", value=faq_id, expected_type=type_hints["faq_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Kendra", jsii.invoke(self, "onFaq", [index_id, faq_id, account, region, partition]))

    @jsii.member(jsii_name="onIndex")
    def on_index(
        self,
        index_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Kendra":
        '''(experimental) Adds a resource of type index to the statement.

        https://docs.aws.amazon.com/kendra/latest/dg/index.html

        :param index_id: - Identifier for the indexId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5f107993cc714e0ef3377b105b26ea68e3458e9ea16d5d53ec3af1891e2463f6)
            check_type(argname="argument index_id", value=index_id, expected_type=type_hints["index_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Kendra", jsii.invoke(self, "onIndex", [index_id, account, region, partition]))

    @jsii.member(jsii_name="onQuerySuggestionsBlockList")
    def on_query_suggestions_block_list(
        self,
        index_id: builtins.str,
        query_suggestions_block_list_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Kendra":
        '''(experimental) Adds a resource of type query-suggestions-block-list to the statement.

        https://docs.aws.amazon.com/kendra/latest/dg/query-suggestions-block-list.html

        :param index_id: - Identifier for the indexId.
        :param query_suggestions_block_list_id: - Identifier for the querySuggestionsBlockListId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ad0570b04a43a325461041d750b47fa7752caeb0e30acd07c55766fb274bc95b)
            check_type(argname="argument index_id", value=index_id, expected_type=type_hints["index_id"])
            check_type(argname="argument query_suggestions_block_list_id", value=query_suggestions_block_list_id, expected_type=type_hints["query_suggestions_block_list_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Kendra", jsii.invoke(self, "onQuerySuggestionsBlockList", [index_id, query_suggestions_block_list_id, account, region, partition]))

    @jsii.member(jsii_name="onThesaurus")
    def on_thesaurus(
        self,
        index_id: builtins.str,
        thesaurus_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Kendra":
        '''(experimental) Adds a resource of type thesaurus to the statement.

        https://docs.aws.amazon.com/kendra/latest/dg/thesaurus.html

        :param index_id: - Identifier for the indexId.
        :param thesaurus_id: - Identifier for the thesaurusId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2207f4043a9adc17889257a06c92d726de78b9d3ee8965f50b91c4cd2c9e17e7)
            check_type(argname="argument index_id", value=index_id, expected_type=type_hints["index_id"])
            check_type(argname="argument thesaurus_id", value=thesaurus_id, expected_type=type_hints["thesaurus_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Kendra", jsii.invoke(self, "onThesaurus", [index_id, thesaurus_id, account, region, partition]))

    @jsii.member(jsii_name="toAssociateEntitiesToExperience")
    def to_associate_entities_to_experience(self) -> "Kendra":
        '''(experimental) Grants permission to put principal mapping in index.

        Access Level: Write

        https://docs.aws.amazon.com/kendra/latest/dg/API_PutPrincipalMapping.html

        :stability: experimental
        '''
        return typing.cast("Kendra", jsii.invoke(self, "toAssociateEntitiesToExperience", []))

    @jsii.member(jsii_name="toAssociatePersonasToEntities")
    def to_associate_personas_to_entities(self) -> "Kendra":
        '''(experimental) Defines the specific permissions of users or groups in your AWS SSO identity source with access to your Amazon Kendra experience.

        Access Level: Write

        https://docs.aws.amazon.com/kendra/latest/dg/API_AssociatePersonasToEntities.html

        :stability: experimental
        '''
        return typing.cast("Kendra", jsii.invoke(self, "toAssociatePersonasToEntities", []))

    @jsii.member(jsii_name="toBatchDeleteDocument")
    def to_batch_delete_document(self) -> "Kendra":
        '''(experimental) Grants permission to batch delete document.

        Access Level: Write

        https://docs.aws.amazon.com/kendra/latest/dg/API_BatchDeleteDocument.html

        :stability: experimental
        '''
        return typing.cast("Kendra", jsii.invoke(self, "toBatchDeleteDocument", []))

    @jsii.member(jsii_name="toBatchGetDocumentStatus")
    def to_batch_get_document_status(self) -> "Kendra":
        '''(experimental) Grants permission to do batch get document status.

        Access Level: Read

        https://docs.aws.amazon.com/kendra/latest/dg/API_BatchGetDocumentStatus.html

        :stability: experimental
        '''
        return typing.cast("Kendra", jsii.invoke(self, "toBatchGetDocumentStatus", []))

    @jsii.member(jsii_name="toBatchPutDocument")
    def to_batch_put_document(self) -> "Kendra":
        '''(experimental) Grants permission to batch put document.

        Access Level: Write

        https://docs.aws.amazon.com/kendra/latest/dg/API_BatchPutDocument.html

        :stability: experimental
        '''
        return typing.cast("Kendra", jsii.invoke(self, "toBatchPutDocument", []))

    @jsii.member(jsii_name="toClearQuerySuggestions")
    def to_clear_query_suggestions(self) -> "Kendra":
        '''(experimental) Grants permission to clear out the suggestions for a given index, generated so far.

        Access Level: Write

        https://docs.aws.amazon.com/kendra/latest/dg/API_ClearQuerySuggestions.html

        :stability: experimental
        '''
        return typing.cast("Kendra", jsii.invoke(self, "toClearQuerySuggestions", []))

    @jsii.member(jsii_name="toCreateDataSource")
    def to_create_data_source(self) -> "Kendra":
        '''(experimental) Grants permission to create a data source.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/kendra/latest/dg/API_CreateDataSource.html

        :stability: experimental
        '''
        return typing.cast("Kendra", jsii.invoke(self, "toCreateDataSource", []))

    @jsii.member(jsii_name="toCreateExperience")
    def to_create_experience(self) -> "Kendra":
        '''(experimental) Creates an Amazon Kendra experience such as a search application.

        Access Level: Write

        https://docs.aws.amazon.com/kendra/latest/dg/API_CreateExperience.html

        :stability: experimental
        '''
        return typing.cast("Kendra", jsii.invoke(self, "toCreateExperience", []))

    @jsii.member(jsii_name="toCreateFaq")
    def to_create_faq(self) -> "Kendra":
        '''(experimental) Grants permission to create an Faq.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/kendra/latest/dg/API_CreateFaq.html

        :stability: experimental
        '''
        return typing.cast("Kendra", jsii.invoke(self, "toCreateFaq", []))

    @jsii.member(jsii_name="toCreateIndex")
    def to_create_index(self) -> "Kendra":
        '''(experimental) Grants permission to create an Index.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/kendra/latest/dg/API_CreateIndex.html

        :stability: experimental
        '''
        return typing.cast("Kendra", jsii.invoke(self, "toCreateIndex", []))

    @jsii.member(jsii_name="toCreateQuerySuggestionsBlockList")
    def to_create_query_suggestions_block_list(self) -> "Kendra":
        '''(experimental) Grants permission to create a QuerySuggestions BlockList.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/kendra/latest/dg/API_CreateQuerySuggestionsBlockList.html

        :stability: experimental
        '''
        return typing.cast("Kendra", jsii.invoke(self, "toCreateQuerySuggestionsBlockList", []))

    @jsii.member(jsii_name="toCreateThesaurus")
    def to_create_thesaurus(self) -> "Kendra":
        '''(experimental) Grants permission to create a Thesaurus.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/kendra/latest/dg/API_CreateThesaurus.html

        :stability: experimental
        '''
        return typing.cast("Kendra", jsii.invoke(self, "toCreateThesaurus", []))

    @jsii.member(jsii_name="toDeleteDataSource")
    def to_delete_data_source(self) -> "Kendra":
        '''(experimental) Grants permission to delete a data source.

        Access Level: Write

        https://docs.aws.amazon.com/kendra/latest/dg/API_DeleteDataSource.html

        :stability: experimental
        '''
        return typing.cast("Kendra", jsii.invoke(self, "toDeleteDataSource", []))

    @jsii.member(jsii_name="toDeleteExperience")
    def to_delete_experience(self) -> "Kendra":
        '''(experimental) Deletes your Amazon Kendra experience such as a search application.

        Access Level: Write

        https://docs.aws.amazon.com/kendra/latest/dg/API_DeleteExperience.html

        :stability: experimental
        '''
        return typing.cast("Kendra", jsii.invoke(self, "toDeleteExperience", []))

    @jsii.member(jsii_name="toDeleteFaq")
    def to_delete_faq(self) -> "Kendra":
        '''(experimental) Grants permission to delete an Faq.

        Access Level: Write

        https://docs.aws.amazon.com/kendra/latest/dg/API_DeleteFaq.html

        :stability: experimental
        '''
        return typing.cast("Kendra", jsii.invoke(self, "toDeleteFaq", []))

    @jsii.member(jsii_name="toDeleteIndex")
    def to_delete_index(self) -> "Kendra":
        '''(experimental) Grants permission to delete an Index.

        Access Level: Write

        https://docs.aws.amazon.com/kendra/latest/dg/API_DeleteIndex.html

        :stability: experimental
        '''
        return typing.cast("Kendra", jsii.invoke(self, "toDeleteIndex", []))

    @jsii.member(jsii_name="toDeletePrincipalMapping")
    def to_delete_principal_mapping(self) -> "Kendra":
        '''(experimental) Grants permission to delete principal mapping from index.

        Access Level: Write

        https://docs.aws.amazon.com/kendra/latest/dg/API_DeletePrincipalMapping.html

        :stability: experimental
        '''
        return typing.cast("Kendra", jsii.invoke(self, "toDeletePrincipalMapping", []))

    @jsii.member(jsii_name="toDeleteQuerySuggestionsBlockList")
    def to_delete_query_suggestions_block_list(self) -> "Kendra":
        '''(experimental) Grants permission to delete a QuerySuggestions BlockList.

        Access Level: Write

        https://docs.aws.amazon.com/kendra/latest/dg/API_DeleteQuerySuggestionsBlockList.html

        :stability: experimental
        '''
        return typing.cast("Kendra", jsii.invoke(self, "toDeleteQuerySuggestionsBlockList", []))

    @jsii.member(jsii_name="toDeleteThesaurus")
    def to_delete_thesaurus(self) -> "Kendra":
        '''(experimental) Grants permission to delete a Thesaurus.

        Access Level: Write

        https://docs.aws.amazon.com/kendra/latest/dg/API_DeleteThesaurus.html

        :stability: experimental
        '''
        return typing.cast("Kendra", jsii.invoke(self, "toDeleteThesaurus", []))

    @jsii.member(jsii_name="toDescribeDataSource")
    def to_describe_data_source(self) -> "Kendra":
        '''(experimental) Grants permission to describe a data source.

        Access Level: Read

        https://docs.aws.amazon.com/kendra/latest/dg/API_DescribeDataSource.html

        :stability: experimental
        '''
        return typing.cast("Kendra", jsii.invoke(self, "toDescribeDataSource", []))

    @jsii.member(jsii_name="toDescribeExperience")
    def to_describe_experience(self) -> "Kendra":
        '''(experimental) Gets information about your Amazon Kendra experience such as a search application.

        Access Level: Read

        https://docs.aws.amazon.com/kendra/latest/dg/API_DescribeExperience.html

        :stability: experimental
        '''
        return typing.cast("Kendra", jsii.invoke(self, "toDescribeExperience", []))

    @jsii.member(jsii_name="toDescribeFaq")
    def to_describe_faq(self) -> "Kendra":
        '''(experimental) Grants permission to describe an Faq.

        Access Level: Read

        https://docs.aws.amazon.com/kendra/latest/dg/API_DescribeFaq.html

        :stability: experimental
        '''
        return typing.cast("Kendra", jsii.invoke(self, "toDescribeFaq", []))

    @jsii.member(jsii_name="toDescribeIndex")
    def to_describe_index(self) -> "Kendra":
        '''(experimental) Grants permission to describe an Index.

        Access Level: Read

        https://docs.aws.amazon.com/kendra/latest/dg/API_DescribeIndex.html

        :stability: experimental
        '''
        return typing.cast("Kendra", jsii.invoke(self, "toDescribeIndex", []))

    @jsii.member(jsii_name="toDescribePrincipalMapping")
    def to_describe_principal_mapping(self) -> "Kendra":
        '''(experimental) Grants permission to describe principal mapping from index.

        Access Level: Read

        https://docs.aws.amazon.com/kendra/latest/dg/API_DescribePrincipalMapping.html

        :stability: experimental
        '''
        return typing.cast("Kendra", jsii.invoke(self, "toDescribePrincipalMapping", []))

    @jsii.member(jsii_name="toDescribeQuerySuggestionsBlockList")
    def to_describe_query_suggestions_block_list(self) -> "Kendra":
        '''(experimental) Grants permission to describe a QuerySuggestions BlockList.

        Access Level: Read

        https://docs.aws.amazon.com/kendra/latest/dg/API_DescribeQuerySuggestionsBlockList.html

        :stability: experimental
        '''
        return typing.cast("Kendra", jsii.invoke(self, "toDescribeQuerySuggestionsBlockList", []))

    @jsii.member(jsii_name="toDescribeQuerySuggestionsConfig")
    def to_describe_query_suggestions_config(self) -> "Kendra":
        '''(experimental) Grants permission to describe the query suggestions configuration for an index.

        Access Level: Read

        https://docs.aws.amazon.com/kendra/latest/dg/API_DescribeQuerySuggestionsConfig.html

        :stability: experimental
        '''
        return typing.cast("Kendra", jsii.invoke(self, "toDescribeQuerySuggestionsConfig", []))

    @jsii.member(jsii_name="toDescribeThesaurus")
    def to_describe_thesaurus(self) -> "Kendra":
        '''(experimental) Grants permission to describe a Thesaurus.

        Access Level: Read

        https://docs.aws.amazon.com/kendra/latest/dg/API_DescribeThesaurus.html

        :stability: experimental
        '''
        return typing.cast("Kendra", jsii.invoke(self, "toDescribeThesaurus", []))

    @jsii.member(jsii_name="toDisassociateEntitiesFromExperience")
    def to_disassociate_entities_from_experience(self) -> "Kendra":
        '''(experimental) Prevents users or groups in your AWS SSO identity source from accessing your Amazon Kendra experience.

        Access Level: Write

        https://docs.aws.amazon.com/kendra/latest/dg/API_DisassociateEntitiesFromExperience.html

        :stability: experimental
        '''
        return typing.cast("Kendra", jsii.invoke(self, "toDisassociateEntitiesFromExperience", []))

    @jsii.member(jsii_name="toDisassociatePersonasFromEntities")
    def to_disassociate_personas_from_entities(self) -> "Kendra":
        '''(experimental) Removes the specific permissions of users or groups in your AWS SSO identity source with access to your Amazon Kendra experience.

        Access Level: Write

        https://docs.aws.amazon.com/kendra/latest/dg/API_DisassociatePersonasFromEntities.html

        :stability: experimental
        '''
        return typing.cast("Kendra", jsii.invoke(self, "toDisassociatePersonasFromEntities", []))

    @jsii.member(jsii_name="toGetQuerySuggestions")
    def to_get_query_suggestions(self) -> "Kendra":
        '''(experimental) Grants permission to get suggestions for a query prefix.

        Access Level: Read

        https://docs.aws.amazon.com/kendra/latest/dg/API_GetQuerySuggestions.html

        :stability: experimental
        '''
        return typing.cast("Kendra", jsii.invoke(self, "toGetQuerySuggestions", []))

    @jsii.member(jsii_name="toGetSnapshots")
    def to_get_snapshots(self) -> "Kendra":
        '''(experimental) Retrieves search metrics data.

        Access Level: Read

        https://docs.aws.amazon.com/kendra/latest/dg/API_GetSnapshots.html

        :stability: experimental
        '''
        return typing.cast("Kendra", jsii.invoke(self, "toGetSnapshots", []))

    @jsii.member(jsii_name="toListDataSources")
    def to_list_data_sources(self) -> "Kendra":
        '''(experimental) Grants permission to list the data sources.

        Access Level: List

        https://docs.aws.amazon.com/kendra/latest/dg/API_ListDataSources.html

        :stability: experimental
        '''
        return typing.cast("Kendra", jsii.invoke(self, "toListDataSources", []))

    @jsii.member(jsii_name="toListDataSourceSyncJobs")
    def to_list_data_source_sync_jobs(self) -> "Kendra":
        '''(experimental) Grants permission to get Data Source sync job history.

        Access Level: List

        https://docs.aws.amazon.com/kendra/latest/dg/API_ListDataSourceSyncJobs.html

        :stability: experimental
        '''
        return typing.cast("Kendra", jsii.invoke(self, "toListDataSourceSyncJobs", []))

    @jsii.member(jsii_name="toListEntityPersonas")
    def to_list_entity_personas(self) -> "Kendra":
        '''(experimental) Lists specific permissions of users and groups with access to your Amazon Kendra experience.

        Access Level: List

        https://docs.aws.amazon.com/kendra/latest/dg/API_ListEntityPersonas.html

        :stability: experimental
        '''
        return typing.cast("Kendra", jsii.invoke(self, "toListEntityPersonas", []))

    @jsii.member(jsii_name="toListExperienceEntities")
    def to_list_experience_entities(self) -> "Kendra":
        '''(experimental) Lists users or groups in your AWS SSO identity source that are granted access to your Amazon Kendra experience.

        Access Level: List

        https://docs.aws.amazon.com/kendra/latest/dg/API_ListExperienceEntities.html

        :stability: experimental
        '''
        return typing.cast("Kendra", jsii.invoke(self, "toListExperienceEntities", []))

    @jsii.member(jsii_name="toListExperiences")
    def to_list_experiences(self) -> "Kendra":
        '''(experimental) Lists one or more Amazon Kendra experiences. You can create an Amazon Kendra experience such as a search application.

        Access Level: List

        https://docs.aws.amazon.com/kendra/latest/dg/API_ListExperiences.html

        :stability: experimental
        '''
        return typing.cast("Kendra", jsii.invoke(self, "toListExperiences", []))

    @jsii.member(jsii_name="toListFaqs")
    def to_list_faqs(self) -> "Kendra":
        '''(experimental) Grants permission to list the Faqs.

        Access Level: List

        https://docs.aws.amazon.com/kendra/latest/dg/API_ListFaqs.html

        :stability: experimental
        '''
        return typing.cast("Kendra", jsii.invoke(self, "toListFaqs", []))

    @jsii.member(jsii_name="toListGroupsOlderThanOrderingId")
    def to_list_groups_older_than_ordering_id(self) -> "Kendra":
        '''(experimental) Grants permission to list groups that are older than an ordering id.

        Access Level: List

        https://docs.aws.amazon.com/kendra/latest/dg/API_ListGroupsOlderThanOrderingId.html

        :stability: experimental
        '''
        return typing.cast("Kendra", jsii.invoke(self, "toListGroupsOlderThanOrderingId", []))

    @jsii.member(jsii_name="toListIndices")
    def to_list_indices(self) -> "Kendra":
        '''(experimental) Grants permission to list the indexes.

        Access Level: List

        https://docs.aws.amazon.com/kendra/latest/dg/API_ListIndices.html

        :stability: experimental
        '''
        return typing.cast("Kendra", jsii.invoke(self, "toListIndices", []))

    @jsii.member(jsii_name="toListQuerySuggestionsBlockLists")
    def to_list_query_suggestions_block_lists(self) -> "Kendra":
        '''(experimental) Grants permission to list the QuerySuggestions BlockLists.

        Access Level: List

        https://docs.aws.amazon.com/kendra/latest/dg/API_ListQuerySuggestionsBlockLists.html

        :stability: experimental
        '''
        return typing.cast("Kendra", jsii.invoke(self, "toListQuerySuggestionsBlockLists", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Kendra":
        '''(experimental) Grants permission to list tags for a resource.

        Access Level: Read

        https://docs.aws.amazon.com/kendra/latest/dg/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("Kendra", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toListThesauri")
    def to_list_thesauri(self) -> "Kendra":
        '''(experimental) Grants permission to list the Thesauri.

        Access Level: List

        https://docs.aws.amazon.com/kendra/latest/dg/API_ListThesauri.html

        :stability: experimental
        '''
        return typing.cast("Kendra", jsii.invoke(self, "toListThesauri", []))

    @jsii.member(jsii_name="toPutPrincipalMapping")
    def to_put_principal_mapping(self) -> "Kendra":
        '''(experimental) Grants permission to put principal mapping in index.

        Access Level: Write

        https://docs.aws.amazon.com/kendra/latest/dg/API_PutPrincipalMapping.html

        :stability: experimental
        '''
        return typing.cast("Kendra", jsii.invoke(self, "toPutPrincipalMapping", []))

    @jsii.member(jsii_name="toQuery")
    def to_query(self) -> "Kendra":
        '''(experimental) Grants permission to query documents and faqs.

        Access Level: Read

        https://docs.aws.amazon.com/kendra/latest/dg/API_Query.html

        :stability: experimental
        '''
        return typing.cast("Kendra", jsii.invoke(self, "toQuery", []))

    @jsii.member(jsii_name="toStartDataSourceSyncJob")
    def to_start_data_source_sync_job(self) -> "Kendra":
        '''(experimental) Grants permission to start Data Source sync job.

        Access Level: Write

        https://docs.aws.amazon.com/kendra/latest/dg/API_StartDataSourceSyncJob.html

        :stability: experimental
        '''
        return typing.cast("Kendra", jsii.invoke(self, "toStartDataSourceSyncJob", []))

    @jsii.member(jsii_name="toStopDataSourceSyncJob")
    def to_stop_data_source_sync_job(self) -> "Kendra":
        '''(experimental) Grants permission to stop Data Source sync job.

        Access Level: Write

        https://docs.aws.amazon.com/kendra/latest/dg/API_StopDataSourceSyncJob.html

        :stability: experimental
        '''
        return typing.cast("Kendra", jsii.invoke(self, "toStopDataSourceSyncJob", []))

    @jsii.member(jsii_name="toSubmitFeedback")
    def to_submit_feedback(self) -> "Kendra":
        '''(experimental) Grants permission to send feedback about a query results.

        Access Level: Write

        https://docs.aws.amazon.com/kendra/latest/dg/API_SubmitFeedback.html

        :stability: experimental
        '''
        return typing.cast("Kendra", jsii.invoke(self, "toSubmitFeedback", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Kendra":
        '''(experimental) Grants permission to tag a resource with given key value pairs.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/kendra/latest/dg/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("Kendra", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Kendra":
        '''(experimental) Grants permission to remove the tag with the given key from a resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/kendra/latest/dg/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("Kendra", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateDataSource")
    def to_update_data_source(self) -> "Kendra":
        '''(experimental) Grants permission to update a data source.

        Access Level: Write

        https://docs.aws.amazon.com/kendra/latest/dg/API_UpdateDataSource.html

        :stability: experimental
        '''
        return typing.cast("Kendra", jsii.invoke(self, "toUpdateDataSource", []))

    @jsii.member(jsii_name="toUpdateExperience")
    def to_update_experience(self) -> "Kendra":
        '''(experimental) Updates your Amazon Kendra experience such as a search application.

        Access Level: Write

        https://docs.aws.amazon.com/kendra/latest/dg/API_UpdateExperience.html

        :stability: experimental
        '''
        return typing.cast("Kendra", jsii.invoke(self, "toUpdateExperience", []))

    @jsii.member(jsii_name="toUpdateIndex")
    def to_update_index(self) -> "Kendra":
        '''(experimental) Grants permission to update an Index.

        Access Level: Write

        https://docs.aws.amazon.com/kendra/latest/dg/API_UpdateIndex.html

        :stability: experimental
        '''
        return typing.cast("Kendra", jsii.invoke(self, "toUpdateIndex", []))

    @jsii.member(jsii_name="toUpdateQuerySuggestionsBlockList")
    def to_update_query_suggestions_block_list(self) -> "Kendra":
        '''(experimental) Grants permission to update a QuerySuggestions BlockList.

        Access Level: Write

        https://docs.aws.amazon.com/kendra/latest/dg/API_UpdateQuerySuggestionsBlockList.html

        :stability: experimental
        '''
        return typing.cast("Kendra", jsii.invoke(self, "toUpdateQuerySuggestionsBlockList", []))

    @jsii.member(jsii_name="toUpdateQuerySuggestionsConfig")
    def to_update_query_suggestions_config(self) -> "Kendra":
        '''(experimental) Grants permission to update the query suggestions configuration for an index.

        Access Level: Write

        https://docs.aws.amazon.com/kendra/latest/dg/API_UpdateQuerySuggestionsConfig.html

        :stability: experimental
        '''
        return typing.cast("Kendra", jsii.invoke(self, "toUpdateQuerySuggestionsConfig", []))

    @jsii.member(jsii_name="toUpdateThesaurus")
    def to_update_thesaurus(self) -> "Kendra":
        '''(experimental) Grants permission to update a thesaurus.

        Access Level: Write

        https://docs.aws.amazon.com/kendra/latest/dg/API_UpdateThesaurus.html

        :stability: experimental
        '''
        return typing.cast("Kendra", jsii.invoke(self, "toUpdateThesaurus", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__749ca5e36f2432905034f2414214d0f8a1a87be07ea16191578952e2869528d5)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__25834b8e0aa37ec920417c70a8e701b896130a20c4df813decbb35cb9b8a609c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Kinesis(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Kinesis",
):
    '''(experimental) Statement provider for service `kinesis <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonkinesis.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `kinesis <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonkinesis.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onConsumer")
    def on_consumer(
        self,
        stream_type: builtins.str,
        stream_name: builtins.str,
        consumer_name: builtins.str,
        consumer_creation_timpstamp: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Kinesis":
        '''(experimental) Adds a resource of type consumer to the statement.

        https://docs.aws.amazon.com/kinesis/latest/dev/amazon-kinesis-consumers.html

        :param stream_type: - Identifier for the streamType.
        :param stream_name: - Identifier for the streamName.
        :param consumer_name: - Identifier for the consumerName.
        :param consumer_creation_timpstamp: - Identifier for the consumerCreationTimpstamp.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__740a7da4cf7ecf997dd75e44ec17653cce9c1322d030eea6950f45f5a6fa3bc8)
            check_type(argname="argument stream_type", value=stream_type, expected_type=type_hints["stream_type"])
            check_type(argname="argument stream_name", value=stream_name, expected_type=type_hints["stream_name"])
            check_type(argname="argument consumer_name", value=consumer_name, expected_type=type_hints["consumer_name"])
            check_type(argname="argument consumer_creation_timpstamp", value=consumer_creation_timpstamp, expected_type=type_hints["consumer_creation_timpstamp"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Kinesis", jsii.invoke(self, "onConsumer", [stream_type, stream_name, consumer_name, consumer_creation_timpstamp, account, region, partition]))

    @jsii.member(jsii_name="onKmsKey")
    def on_kms_key(
        self,
        key_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Kinesis":
        '''(experimental) Adds a resource of type kmsKey to the statement.

        https://docs.aws.amazon.com/kinesis/latest/dev/concepts.html#kms_keys

        :param key_id: - Identifier for the keyId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9beab84cfcdbd21b4aac2d73b316e74fd44db5d496d9d4824cee9eb04daf23ad)
            check_type(argname="argument key_id", value=key_id, expected_type=type_hints["key_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Kinesis", jsii.invoke(self, "onKmsKey", [key_id, account, region, partition]))

    @jsii.member(jsii_name="onStream")
    def on_stream(
        self,
        stream_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Kinesis":
        '''(experimental) Adds a resource of type stream to the statement.

        https://docs.aws.amazon.com/kinesis/latest/dev/amazon-kinesis-streams.html

        :param stream_name: - Identifier for the streamName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8383bf77f0a210a51d28e0dd1899ec57204445ea45616c6b6c876848ad52359b)
            check_type(argname="argument stream_name", value=stream_name, expected_type=type_hints["stream_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Kinesis", jsii.invoke(self, "onStream", [stream_name, account, region, partition]))

    @jsii.member(jsii_name="toAddTagsToStream")
    def to_add_tags_to_stream(self) -> "Kinesis":
        '''(experimental) Grants permission to add or update tags for the specified Amazon Kinesis stream.

        Each stream can have up to 10 tags

        Access Level: Tagging

        https://docs.aws.amazon.com/kinesis/latest/APIReference/API_AddTagsToStream.html

        :stability: experimental
        '''
        return typing.cast("Kinesis", jsii.invoke(self, "toAddTagsToStream", []))

    @jsii.member(jsii_name="toCreateStream")
    def to_create_stream(self) -> "Kinesis":
        '''(experimental) Grants permission to create a Amazon Kinesis stream.

        Access Level: Write

        https://docs.aws.amazon.com/kinesis/latest/APIReference/API_CreateStream.html

        :stability: experimental
        '''
        return typing.cast("Kinesis", jsii.invoke(self, "toCreateStream", []))

    @jsii.member(jsii_name="toDecreaseStreamRetentionPeriod")
    def to_decrease_stream_retention_period(self) -> "Kinesis":
        '''(experimental) Grants permission to decrease the stream's retention period, which is the length of time data records are accessible after they are added to the stream.

        Access Level: Write

        https://docs.aws.amazon.com/kinesis/latest/APIReference/API_DecreaseStreamRetentionPeriod.html

        :stability: experimental
        '''
        return typing.cast("Kinesis", jsii.invoke(self, "toDecreaseStreamRetentionPeriod", []))

    @jsii.member(jsii_name="toDeleteStream")
    def to_delete_stream(self) -> "Kinesis":
        '''(experimental) Grants permission to delete a stream and all its shards and data.

        Access Level: Write

        https://docs.aws.amazon.com/kinesis/latest/APIReference/API_DeleteStream.html

        :stability: experimental
        '''
        return typing.cast("Kinesis", jsii.invoke(self, "toDeleteStream", []))

    @jsii.member(jsii_name="toDeregisterStreamConsumer")
    def to_deregister_stream_consumer(self) -> "Kinesis":
        '''(experimental) Grants permission to deregister a stream consumer with a Kinesis data stream.

        Access Level: Write

        https://docs.aws.amazon.com/kinesis/latest/APIReference/API_DeregisterStreamConsumer.html

        :stability: experimental
        '''
        return typing.cast("Kinesis", jsii.invoke(self, "toDeregisterStreamConsumer", []))

    @jsii.member(jsii_name="toDescribeLimits")
    def to_describe_limits(self) -> "Kinesis":
        '''(experimental) Grants permission to describe the shard limits and usage for the account.

        Access Level: Read

        https://docs.aws.amazon.com/kinesis/latest/APIReference/API_DescribeLimits.html

        :stability: experimental
        '''
        return typing.cast("Kinesis", jsii.invoke(self, "toDescribeLimits", []))

    @jsii.member(jsii_name="toDescribeStream")
    def to_describe_stream(self) -> "Kinesis":
        '''(experimental) Grants permission to describe the specified stream.

        Access Level: Read

        https://docs.aws.amazon.com/kinesis/latest/APIReference/API_DescribeStream.html

        :stability: experimental
        '''
        return typing.cast("Kinesis", jsii.invoke(self, "toDescribeStream", []))

    @jsii.member(jsii_name="toDescribeStreamConsumer")
    def to_describe_stream_consumer(self) -> "Kinesis":
        '''(experimental) Grants permission to get the description of a registered stream consumer.

        Access Level: Read

        https://docs.aws.amazon.com/kinesis/latest/APIReference/API_DescribeStreamConsumer.html

        :stability: experimental
        '''
        return typing.cast("Kinesis", jsii.invoke(self, "toDescribeStreamConsumer", []))

    @jsii.member(jsii_name="toDescribeStreamSummary")
    def to_describe_stream_summary(self) -> "Kinesis":
        '''(experimental) Grants permission to provide a summarized description of the specified Kinesis data stream without the shard list.

        Access Level: Read

        https://docs.aws.amazon.com/kinesis/latest/APIReference/API_DescribeStreamSummary.html

        :stability: experimental
        '''
        return typing.cast("Kinesis", jsii.invoke(self, "toDescribeStreamSummary", []))

    @jsii.member(jsii_name="toDisableEnhancedMonitoring")
    def to_disable_enhanced_monitoring(self) -> "Kinesis":
        '''(experimental) Grants permission to disables enhanced monitoring.

        Access Level: Write

        https://docs.aws.amazon.com/kinesis/latest/APIReference/API_DisableEnhancedMonitoring.html

        :stability: experimental
        '''
        return typing.cast("Kinesis", jsii.invoke(self, "toDisableEnhancedMonitoring", []))

    @jsii.member(jsii_name="toEnableEnhancedMonitoring")
    def to_enable_enhanced_monitoring(self) -> "Kinesis":
        '''(experimental) Grants permission to enable enhanced Kinesis data stream monitoring for shard-level metrics.

        Access Level: Write

        https://docs.aws.amazon.com/kinesis/latest/APIReference/API_EnableEnhancedMonitoring.html

        :stability: experimental
        '''
        return typing.cast("Kinesis", jsii.invoke(self, "toEnableEnhancedMonitoring", []))

    @jsii.member(jsii_name="toGetRecords")
    def to_get_records(self) -> "Kinesis":
        '''(experimental) Grants permission to get data records from a shard.

        Access Level: Read

        https://docs.aws.amazon.com/kinesis/latest/APIReference/API_GetRecords.html

        :stability: experimental
        '''
        return typing.cast("Kinesis", jsii.invoke(self, "toGetRecords", []))

    @jsii.member(jsii_name="toGetShardIterator")
    def to_get_shard_iterator(self) -> "Kinesis":
        '''(experimental) Grants permission to get a shard iterator.

        A shard iterator expires five minutes after it is returned to the requester

        Access Level: Read

        https://docs.aws.amazon.com/kinesis/latest/APIReference/API_GetShardIterator.html

        :stability: experimental
        '''
        return typing.cast("Kinesis", jsii.invoke(self, "toGetShardIterator", []))

    @jsii.member(jsii_name="toIncreaseStreamRetentionPeriod")
    def to_increase_stream_retention_period(self) -> "Kinesis":
        '''(experimental) Grants permission to increase the stream's retention period, which is the length of time data records are accessible after they are added to the stream.

        Access Level: Write

        https://docs.aws.amazon.com/kinesis/latest/APIReference/API_IncreaseStreamRetentionPeriod.html

        :stability: experimental
        '''
        return typing.cast("Kinesis", jsii.invoke(self, "toIncreaseStreamRetentionPeriod", []))

    @jsii.member(jsii_name="toListShards")
    def to_list_shards(self) -> "Kinesis":
        '''(experimental) Grants permission to list the shards in a stream and provides information about each shard.

        Access Level: List

        https://docs.aws.amazon.com/kinesis/latest/APIReference/API_ListShards.html

        :stability: experimental
        '''
        return typing.cast("Kinesis", jsii.invoke(self, "toListShards", []))

    @jsii.member(jsii_name="toListStreamConsumers")
    def to_list_stream_consumers(self) -> "Kinesis":
        '''(experimental) Grants permission to list the stream consumers registered to receive data from a Kinesis stream using enhanced fan-out, and provides information about each consumer.

        Access Level: List

        https://docs.aws.amazon.com/kinesis/latest/APIReference/API_ListStreamConsumers.html

        :stability: experimental
        '''
        return typing.cast("Kinesis", jsii.invoke(self, "toListStreamConsumers", []))

    @jsii.member(jsii_name="toListStreams")
    def to_list_streams(self) -> "Kinesis":
        '''(experimental) Grants permission to list your streams.

        Access Level: List

        https://docs.aws.amazon.com/kinesis/latest/APIReference/API_ListStreams.html

        :stability: experimental
        '''
        return typing.cast("Kinesis", jsii.invoke(self, "toListStreams", []))

    @jsii.member(jsii_name="toListTagsForStream")
    def to_list_tags_for_stream(self) -> "Kinesis":
        '''(experimental) Grants permission to list the tags for the specified Amazon Kinesis stream.

        Access Level: Read

        https://docs.aws.amazon.com/kinesis/latest/APIReference/API_ListTagsForStream.html

        :stability: experimental
        '''
        return typing.cast("Kinesis", jsii.invoke(self, "toListTagsForStream", []))

    @jsii.member(jsii_name="toMergeShards")
    def to_merge_shards(self) -> "Kinesis":
        '''(experimental) Grants permission to merge two adjacent shards in a stream and combines them into a single shard to reduce the stream's capacity to ingest and transport data.

        Access Level: Write

        https://docs.aws.amazon.com/kinesis/latest/APIReference/API_MergeShards.html

        :stability: experimental
        '''
        return typing.cast("Kinesis", jsii.invoke(self, "toMergeShards", []))

    @jsii.member(jsii_name="toPutRecord")
    def to_put_record(self) -> "Kinesis":
        '''(experimental) Grants permission to write a single data record from a producer into an Amazon Kinesis stream.

        Access Level: Write

        https://docs.aws.amazon.com/kinesis/latest/APIReference/API_PutRecord.html

        :stability: experimental
        '''
        return typing.cast("Kinesis", jsii.invoke(self, "toPutRecord", []))

    @jsii.member(jsii_name="toPutRecords")
    def to_put_records(self) -> "Kinesis":
        '''(experimental) Grants permission to write multiple data records from a producer into an Amazon Kinesis stream in a single call (also referred to as a PutRecords request).

        Access Level: Write

        https://docs.aws.amazon.com/kinesis/latest/APIReference/API_PutRecords.html

        :stability: experimental
        '''
        return typing.cast("Kinesis", jsii.invoke(self, "toPutRecords", []))

    @jsii.member(jsii_name="toRegisterStreamConsumer")
    def to_register_stream_consumer(self) -> "Kinesis":
        '''(experimental) Grants permission to register a stream consumer with a Kinesis data stream.

        Access Level: Write

        https://docs.aws.amazon.com/kinesis/latest/APIReference/API_RegisterStreamConsumer.html

        :stability: experimental
        '''
        return typing.cast("Kinesis", jsii.invoke(self, "toRegisterStreamConsumer", []))

    @jsii.member(jsii_name="toRemoveTagsFromStream")
    def to_remove_tags_from_stream(self) -> "Kinesis":
        '''(experimental) Grants permission to remove tags from the specified Kinesis data stream.

        Removed tags are deleted and cannot be recovered after this operation successfully completes

        Access Level: Tagging

        https://docs.aws.amazon.com/kinesis/latest/APIReference/API_RemoveTagsFromStream.html

        :stability: experimental
        '''
        return typing.cast("Kinesis", jsii.invoke(self, "toRemoveTagsFromStream", []))

    @jsii.member(jsii_name="toSplitShard")
    def to_split_shard(self) -> "Kinesis":
        '''(experimental) Grants permission to split a shard into two new shards in the Kinesis data stream, to increase the stream's capacity to ingest and transport data.

        Access Level: Write

        https://docs.aws.amazon.com/kinesis/latest/APIReference/API_SplitShard.html

        :stability: experimental
        '''
        return typing.cast("Kinesis", jsii.invoke(self, "toSplitShard", []))

    @jsii.member(jsii_name="toStartStreamEncryption")
    def to_start_stream_encryption(self) -> "Kinesis":
        '''(experimental) Grants permission to enable or update server-side encryption using an AWS KMS key for a specified stream.

        Access Level: Write

        https://docs.aws.amazon.com/kinesis/latest/APIReference/API_StartStreamEncryption.html

        :stability: experimental
        '''
        return typing.cast("Kinesis", jsii.invoke(self, "toStartStreamEncryption", []))

    @jsii.member(jsii_name="toStopStreamEncryption")
    def to_stop_stream_encryption(self) -> "Kinesis":
        '''(experimental) Grants permission to disable server-side encryption for a specified stream.

        Access Level: Write

        https://docs.aws.amazon.com/kinesis/latest/APIReference/API_StopStreamEncryption.html

        :stability: experimental
        '''
        return typing.cast("Kinesis", jsii.invoke(self, "toStopStreamEncryption", []))

    @jsii.member(jsii_name="toSubscribeToShard")
    def to_subscribe_to_shard(self) -> "Kinesis":
        '''(experimental) Grants permission to listen to a specific shard with enhanced fan-out.

        Access Level: Read

        https://docs.aws.amazon.com/kinesis/latest/APIReference/API_SubscribeToShard.html

        :stability: experimental
        '''
        return typing.cast("Kinesis", jsii.invoke(self, "toSubscribeToShard", []))

    @jsii.member(jsii_name="toUpdateShardCount")
    def to_update_shard_count(self) -> "Kinesis":
        '''(experimental) Grants permission to update the shard count of the specified stream to the specified number of shards.

        Access Level: Write

        https://docs.aws.amazon.com/kinesis/latest/APIReference/API_UpdateShardCount.html

        :stability: experimental
        '''
        return typing.cast("Kinesis", jsii.invoke(self, "toUpdateShardCount", []))

    @jsii.member(jsii_name="toUpdateStreamMode")
    def to_update_stream_mode(self) -> "Kinesis":
        '''(experimental) Grants permission to update the capacity mode of the data stream.

        Access Level: Write

        https://docs.aws.amazon.com/kinesis/latest/APIReference/API_UpdateStreamMode.html

        :stability: experimental
        '''
        return typing.cast("Kinesis", jsii.invoke(self, "toUpdateStreamMode", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fb033f5ae97e82e3e967c614552c76406b059dc67ba5afde78a85eb644fe1f7c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__52212f4d6a9f0972f35ef56f101ef9ae28e6ff724cb2b4c6b653dd2a006487cc)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Kinesisanalytics(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Kinesisanalytics",
):
    '''(experimental) Statement provider for service `kinesisanalytics <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonkinesisanalytics.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `kinesisanalytics <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonkinesisanalytics.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onApplication")
    def on_application(
        self,
        application_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Kinesisanalytics":
        '''(experimental) Adds a resource of type application to the statement.

        https://docs.aws.amazon.com/kinesisanalytics/latest/dev/how-it-works.html

        :param application_name: - Identifier for the applicationName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d73bf648557a283d0523290857719addf6283eed837479b7b45cd36d5491ab31)
            check_type(argname="argument application_name", value=application_name, expected_type=type_hints["application_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Kinesisanalytics", jsii.invoke(self, "onApplication", [application_name, account, region, partition]))

    @jsii.member(jsii_name="toAddApplicationInput")
    def to_add_application_input(self) -> "Kinesisanalytics":
        '''(experimental) Grants permission to add input to the application.

        Access Level: Write

        https://docs.aws.amazon.com/kinesisanalytics/latest/dev/API_AddApplicationInput.html

        :stability: experimental
        '''
        return typing.cast("Kinesisanalytics", jsii.invoke(self, "toAddApplicationInput", []))

    @jsii.member(jsii_name="toAddApplicationOutput")
    def to_add_application_output(self) -> "Kinesisanalytics":
        '''(experimental) Grants permission to add output to the application.

        Access Level: Write

        https://docs.aws.amazon.com/kinesisanalytics/latest/dev/API_AddApplicationOutput.html

        :stability: experimental
        '''
        return typing.cast("Kinesisanalytics", jsii.invoke(self, "toAddApplicationOutput", []))

    @jsii.member(jsii_name="toAddApplicationReferenceDataSource")
    def to_add_application_reference_data_source(self) -> "Kinesisanalytics":
        '''(experimental) Grants permission to add reference data source to the application.

        Access Level: Write

        https://docs.aws.amazon.com/kinesisanalytics/latest/dev/API_AddApplicationReferenceDataSource.html

        :stability: experimental
        '''
        return typing.cast("Kinesisanalytics", jsii.invoke(self, "toAddApplicationReferenceDataSource", []))

    @jsii.member(jsii_name="toCreateApplication")
    def to_create_application(self) -> "Kinesisanalytics":
        '''(experimental) Grants permission to create an application.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/kinesisanalytics/latest/dev/API_CreateApplication.html

        :stability: experimental
        '''
        return typing.cast("Kinesisanalytics", jsii.invoke(self, "toCreateApplication", []))

    @jsii.member(jsii_name="toDeleteApplication")
    def to_delete_application(self) -> "Kinesisanalytics":
        '''(experimental) Grants permission to delete the application.

        Access Level: Write

        https://docs.aws.amazon.com/kinesisanalytics/latest/dev/API_DeleteApplication.html

        :stability: experimental
        '''
        return typing.cast("Kinesisanalytics", jsii.invoke(self, "toDeleteApplication", []))

    @jsii.member(jsii_name="toDeleteApplicationOutput")
    def to_delete_application_output(self) -> "Kinesisanalytics":
        '''(experimental) Grants permission to delete the specified output of the application.

        Access Level: Write

        https://docs.aws.amazon.com/kinesisanalytics/latest/dev/API_DeleteApplicationOutput.html

        :stability: experimental
        '''
        return typing.cast("Kinesisanalytics", jsii.invoke(self, "toDeleteApplicationOutput", []))

    @jsii.member(jsii_name="toDeleteApplicationReferenceDataSource")
    def to_delete_application_reference_data_source(self) -> "Kinesisanalytics":
        '''(experimental) Grants permission to delete the specified reference data source of the application.

        Access Level: Write

        https://docs.aws.amazon.com/kinesisanalytics/latest/dev/API_DeleteApplicationReferenceDataSource.html

        :stability: experimental
        '''
        return typing.cast("Kinesisanalytics", jsii.invoke(self, "toDeleteApplicationReferenceDataSource", []))

    @jsii.member(jsii_name="toDescribeApplication")
    def to_describe_application(self) -> "Kinesisanalytics":
        '''(experimental) Grants permission to describe the specified application.

        Access Level: Read

        https://docs.aws.amazon.com/kinesisanalytics/latest/dev/API_DescribeApplication.html

        :stability: experimental
        '''
        return typing.cast("Kinesisanalytics", jsii.invoke(self, "toDescribeApplication", []))

    @jsii.member(jsii_name="toDiscoverInputSchema")
    def to_discover_input_schema(self) -> "Kinesisanalytics":
        '''(experimental) Grants permission to discover the input schema for the application.

        Access Level: Read

        https://docs.aws.amazon.com/kinesisanalytics/latest/dev/API_DiscoverInputSchema.html

        :stability: experimental
        '''
        return typing.cast("Kinesisanalytics", jsii.invoke(self, "toDiscoverInputSchema", []))

    @jsii.member(jsii_name="toGetApplicationState")
    def to_get_application_state(self) -> "Kinesisanalytics":
        '''(experimental) Grants permission to Kinesis Data Analytics console to display stream results for Kinesis Data Analytics SQL runtime applications.

        Access Level: Read

        https://docs.aws.amazon.com/kinesisanalytics/latest/dev/api-permissions-reference.html#api-permissions-reference-gas

        :stability: experimental
        '''
        return typing.cast("Kinesisanalytics", jsii.invoke(self, "toGetApplicationState", []))

    @jsii.member(jsii_name="toListApplications")
    def to_list_applications(self) -> "Kinesisanalytics":
        '''(experimental) Grants permission to list applications for the account.

        Access Level: List

        https://docs.aws.amazon.com/kinesisanalytics/latest/dev/API_ListApplications.html

        :stability: experimental
        '''
        return typing.cast("Kinesisanalytics", jsii.invoke(self, "toListApplications", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Kinesisanalytics":
        '''(experimental) Grants permission to fetch the tags associated with the application.

        Access Level: Read

        https://docs.aws.amazon.com/kinesisanalytics/latest/dev/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("Kinesisanalytics", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toStartApplication")
    def to_start_application(self) -> "Kinesisanalytics":
        '''(experimental) Grants permission to start the application.

        Access Level: Write

        https://docs.aws.amazon.com/kinesisanalytics/latest/dev/API_StartApplication.html

        :stability: experimental
        '''
        return typing.cast("Kinesisanalytics", jsii.invoke(self, "toStartApplication", []))

    @jsii.member(jsii_name="toStopApplication")
    def to_stop_application(self) -> "Kinesisanalytics":
        '''(experimental) Grants permission to stop the application.

        Access Level: Write

        https://docs.aws.amazon.com/kinesisanalytics/latest/dev/API_StopApplication.html

        :stability: experimental
        '''
        return typing.cast("Kinesisanalytics", jsii.invoke(self, "toStopApplication", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Kinesisanalytics":
        '''(experimental) Grants permission to add tags to the application.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/kinesisanalytics/latest/dev/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("Kinesisanalytics", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Kinesisanalytics":
        '''(experimental) Grants permission to remove the specified tags from the application.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/kinesisanalytics/latest/dev/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("Kinesisanalytics", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateApplication")
    def to_update_application(self) -> "Kinesisanalytics":
        '''(experimental) Grants permission to update the application.

        Access Level: Write

        https://docs.aws.amazon.com/kinesisanalytics/latest/dev/API_UpdateApplication.html

        :stability: experimental
        '''
        return typing.cast("Kinesisanalytics", jsii.invoke(self, "toUpdateApplication", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__765155d6a9fe26046d3c2436de9dbf057c16612c653ecbeca584f3aee6660602)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a63237ff55aa2553bc32304dd367027b949410ef0efbae687ec20cde342a20c5)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class KinesisanalyticsV2(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.KinesisanalyticsV2",
):
    '''(experimental) Statement provider for service `kinesisanalytics-v2 <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonkinesisanalyticsv2.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `kinesisanalytics-v2 <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonkinesisanalyticsv2.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onApplication")
    def on_application(
        self,
        application_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "KinesisanalyticsV2":
        '''(experimental) Adds a resource of type application to the statement.

        https://docs.aws.amazon.com/kinesisanalytics/latest/java/how-it-works.html

        :param application_name: - Identifier for the applicationName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3507db8a37321b67638d070e6ddff8da38de6da70dedca3d96f1035724075677)
            check_type(argname="argument application_name", value=application_name, expected_type=type_hints["application_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("KinesisanalyticsV2", jsii.invoke(self, "onApplication", [application_name, account, region, partition]))

    @jsii.member(jsii_name="toAddApplicationCloudWatchLoggingOption")
    def to_add_application_cloud_watch_logging_option(self) -> "KinesisanalyticsV2":
        '''(experimental) Grants permission to add cloudwatch logging option to the application.

        Access Level: Write

        https://docs.aws.amazon.com/kinesisanalytics/latest/apiv2/API_AddApplicationCloudWatchLoggingOption.html

        :stability: experimental
        '''
        return typing.cast("KinesisanalyticsV2", jsii.invoke(self, "toAddApplicationCloudWatchLoggingOption", []))

    @jsii.member(jsii_name="toAddApplicationInput")
    def to_add_application_input(self) -> "KinesisanalyticsV2":
        '''(experimental) Grants permission to add input to the application.

        Access Level: Write

        https://docs.aws.amazon.com/kinesisanalytics/latest/apiv2/API_AddApplicationInput.html

        :stability: experimental
        '''
        return typing.cast("KinesisanalyticsV2", jsii.invoke(self, "toAddApplicationInput", []))

    @jsii.member(jsii_name="toAddApplicationInputProcessingConfiguration")
    def to_add_application_input_processing_configuration(self) -> "KinesisanalyticsV2":
        '''(experimental) Grants permission to add input processing configuration to the application.

        Access Level: Write

        https://docs.aws.amazon.com/kinesisanalytics/latest/apiv2/API_AddApplicationInputProcessingConfiguration.html

        :stability: experimental
        '''
        return typing.cast("KinesisanalyticsV2", jsii.invoke(self, "toAddApplicationInputProcessingConfiguration", []))

    @jsii.member(jsii_name="toAddApplicationOutput")
    def to_add_application_output(self) -> "KinesisanalyticsV2":
        '''(experimental) Grants permission to add output to the application.

        Access Level: Write

        https://docs.aws.amazon.com/kinesisanalytics/latest/apiv2/API_AddApplicationOutput.html

        :stability: experimental
        '''
        return typing.cast("KinesisanalyticsV2", jsii.invoke(self, "toAddApplicationOutput", []))

    @jsii.member(jsii_name="toAddApplicationReferenceDataSource")
    def to_add_application_reference_data_source(self) -> "KinesisanalyticsV2":
        '''(experimental) Grants permission to add reference data source to the application.

        Access Level: Write

        https://docs.aws.amazon.com/kinesisanalytics/latest/apiv2/API_AddApplicationReferenceDataSource.html

        :stability: experimental
        '''
        return typing.cast("KinesisanalyticsV2", jsii.invoke(self, "toAddApplicationReferenceDataSource", []))

    @jsii.member(jsii_name="toAddApplicationVpcConfiguration")
    def to_add_application_vpc_configuration(self) -> "KinesisanalyticsV2":
        '''(experimental) Grants permission to add VPC configuration to the application.

        Access Level: Write

        https://docs.aws.amazon.com/kinesisanalytics/latest/apiv2/API_AddApplicationVpcConfiguration.html

        :stability: experimental
        '''
        return typing.cast("KinesisanalyticsV2", jsii.invoke(self, "toAddApplicationVpcConfiguration", []))

    @jsii.member(jsii_name="toCreateApplication")
    def to_create_application(self) -> "KinesisanalyticsV2":
        '''(experimental) Grants permission to create an application.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/kinesisanalytics/latest/apiv2/API_CreateApplication.html

        :stability: experimental
        '''
        return typing.cast("KinesisanalyticsV2", jsii.invoke(self, "toCreateApplication", []))

    @jsii.member(jsii_name="toCreateApplicationPresignedUrl")
    def to_create_application_presigned_url(self) -> "KinesisanalyticsV2":
        '''(experimental) Grants permission to create and return a URL that you can use to connect to an application's extension.

        Access Level: Read

        https://docs.aws.amazon.com/kinesisanalytics/latest/apiv2/API_CreateApplicationPresignedUrl.html

        :stability: experimental
        '''
        return typing.cast("KinesisanalyticsV2", jsii.invoke(self, "toCreateApplicationPresignedUrl", []))

    @jsii.member(jsii_name="toCreateApplicationSnapshot")
    def to_create_application_snapshot(self) -> "KinesisanalyticsV2":
        '''(experimental) Grants permission to create a snapshot for an application.

        Access Level: Write

        https://docs.aws.amazon.com/kinesisanalytics/latest/apiv2/API_CreateApplicationSnapshot.html

        :stability: experimental
        '''
        return typing.cast("KinesisanalyticsV2", jsii.invoke(self, "toCreateApplicationSnapshot", []))

    @jsii.member(jsii_name="toDeleteApplication")
    def to_delete_application(self) -> "KinesisanalyticsV2":
        '''(experimental) Grants permission to delete the application.

        Access Level: Write

        https://docs.aws.amazon.com/kinesisanalytics/latest/apiv2/API_DeleteApplication.html

        :stability: experimental
        '''
        return typing.cast("KinesisanalyticsV2", jsii.invoke(self, "toDeleteApplication", []))

    @jsii.member(jsii_name="toDeleteApplicationCloudWatchLoggingOption")
    def to_delete_application_cloud_watch_logging_option(self) -> "KinesisanalyticsV2":
        '''(experimental) Grants permission to delete the specified cloudwatch logging option of the application.

        Access Level: Write

        https://docs.aws.amazon.com/kinesisanalytics/latest/apiv2/API_DeleteApplicationCloudWatchLoggingOption.html

        :stability: experimental
        '''
        return typing.cast("KinesisanalyticsV2", jsii.invoke(self, "toDeleteApplicationCloudWatchLoggingOption", []))

    @jsii.member(jsii_name="toDeleteApplicationInputProcessingConfiguration")
    def to_delete_application_input_processing_configuration(
        self,
    ) -> "KinesisanalyticsV2":
        '''(experimental) Grants permission to delete the specified input processing configuration of the application.

        Access Level: Write

        https://docs.aws.amazon.com/kinesisanalytics/latest/apiv2/API_DeleteApplicationInputProcessingConfiguration.html

        :stability: experimental
        '''
        return typing.cast("KinesisanalyticsV2", jsii.invoke(self, "toDeleteApplicationInputProcessingConfiguration", []))

    @jsii.member(jsii_name="toDeleteApplicationOutput")
    def to_delete_application_output(self) -> "KinesisanalyticsV2":
        '''(experimental) Grants permission to delete the specified output of the application.

        Access Level: Write

        https://docs.aws.amazon.com/kinesisanalytics/latest/apiv2/API_DeleteApplicationOutput.html

        :stability: experimental
        '''
        return typing.cast("KinesisanalyticsV2", jsii.invoke(self, "toDeleteApplicationOutput", []))

    @jsii.member(jsii_name="toDeleteApplicationReferenceDataSource")
    def to_delete_application_reference_data_source(self) -> "KinesisanalyticsV2":
        '''(experimental) Grants permission to delete the specified reference data source of the application.

        Access Level: Write

        https://docs.aws.amazon.com/kinesisanalytics/latest/apiv2/API_DeleteApplicationReferenceDataSource.html

        :stability: experimental
        '''
        return typing.cast("KinesisanalyticsV2", jsii.invoke(self, "toDeleteApplicationReferenceDataSource", []))

    @jsii.member(jsii_name="toDeleteApplicationSnapshot")
    def to_delete_application_snapshot(self) -> "KinesisanalyticsV2":
        '''(experimental) Grants permission to delete a snapshot for an application.

        Access Level: Write

        https://docs.aws.amazon.com/kinesisanalytics/latest/apiv2/API_DeleteApplicationSnapshot.html

        :stability: experimental
        '''
        return typing.cast("KinesisanalyticsV2", jsii.invoke(self, "toDeleteApplicationSnapshot", []))

    @jsii.member(jsii_name="toDeleteApplicationVpcConfiguration")
    def to_delete_application_vpc_configuration(self) -> "KinesisanalyticsV2":
        '''(experimental) Grants permission to delete the specified VPC configuration of the application.

        Access Level: Write

        https://docs.aws.amazon.com/kinesisanalytics/latest/apiv2/API_DeleteApplicationVpcConfiguration.html

        :stability: experimental
        '''
        return typing.cast("KinesisanalyticsV2", jsii.invoke(self, "toDeleteApplicationVpcConfiguration", []))

    @jsii.member(jsii_name="toDescribeApplication")
    def to_describe_application(self) -> "KinesisanalyticsV2":
        '''(experimental) Grants permission to describe the specified application.

        Access Level: Read

        https://docs.aws.amazon.com/kinesisanalytics/latest/apiv2/API_DescribeApplication.html

        :stability: experimental
        '''
        return typing.cast("KinesisanalyticsV2", jsii.invoke(self, "toDescribeApplication", []))

    @jsii.member(jsii_name="toDescribeApplicationSnapshot")
    def to_describe_application_snapshot(self) -> "KinesisanalyticsV2":
        '''(experimental) Grants permission to describe an application snapshot.

        Access Level: Read

        https://docs.aws.amazon.com/kinesisanalytics/latest/apiv2/API_DescribeApplicationSnapshot.html

        :stability: experimental
        '''
        return typing.cast("KinesisanalyticsV2", jsii.invoke(self, "toDescribeApplicationSnapshot", []))

    @jsii.member(jsii_name="toDescribeApplicationVersion")
    def to_describe_application_version(self) -> "KinesisanalyticsV2":
        '''(experimental) Grants permission to describe the application version of an application.

        Access Level: Read

        https://docs.aws.amazon.com/kinesisanalytics/latest/apiv2/API_DescribeApplicationVersion.html

        :stability: experimental
        '''
        return typing.cast("KinesisanalyticsV2", jsii.invoke(self, "toDescribeApplicationVersion", []))

    @jsii.member(jsii_name="toDiscoverInputSchema")
    def to_discover_input_schema(self) -> "KinesisanalyticsV2":
        '''(experimental) Grants permission to discover the input schema for the application.

        Access Level: Read

        https://docs.aws.amazon.com/kinesisanalytics/latest/apiv2/API_DiscoverInputSchema.html

        :stability: experimental
        '''
        return typing.cast("KinesisanalyticsV2", jsii.invoke(self, "toDiscoverInputSchema", []))

    @jsii.member(jsii_name="toListApplications")
    def to_list_applications(self) -> "KinesisanalyticsV2":
        '''(experimental) Grants permission to list applications for the account.

        Access Level: List

        https://docs.aws.amazon.com/kinesisanalytics/latest/apiv2/API_ListApplications.html

        :stability: experimental
        '''
        return typing.cast("KinesisanalyticsV2", jsii.invoke(self, "toListApplications", []))

    @jsii.member(jsii_name="toListApplicationSnapshots")
    def to_list_application_snapshots(self) -> "KinesisanalyticsV2":
        '''(experimental) Grants permission to list the snapshots for an application.

        Access Level: Read

        https://docs.aws.amazon.com/kinesisanalytics/latest/apiv2/API_ListApplicationSnapshots.html

        :stability: experimental
        '''
        return typing.cast("KinesisanalyticsV2", jsii.invoke(self, "toListApplicationSnapshots", []))

    @jsii.member(jsii_name="toListApplicationVersions")
    def to_list_application_versions(self) -> "KinesisanalyticsV2":
        '''(experimental) Grants permission to list application versions of an application.

        Access Level: Read

        https://docs.aws.amazon.com/kinesisanalytics/latest/apiv2/API_ListApplicationVersions.html

        :stability: experimental
        '''
        return typing.cast("KinesisanalyticsV2", jsii.invoke(self, "toListApplicationVersions", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "KinesisanalyticsV2":
        '''(experimental) Grants permission to fetch the tags associated with the application.

        Access Level: Read

        https://docs.aws.amazon.com/kinesisanalytics/latest/apiv2/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("KinesisanalyticsV2", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toRollbackApplication")
    def to_rollback_application(self) -> "KinesisanalyticsV2":
        '''(experimental) Grants permission to perform rollback operation on an application.

        Access Level: Write

        https://docs.aws.amazon.com/kinesisanalytics/latest/apiv2/API_RollbackApplication.html

        :stability: experimental
        '''
        return typing.cast("KinesisanalyticsV2", jsii.invoke(self, "toRollbackApplication", []))

    @jsii.member(jsii_name="toStartApplication")
    def to_start_application(self) -> "KinesisanalyticsV2":
        '''(experimental) Grants permission to start the application.

        Access Level: Write

        https://docs.aws.amazon.com/kinesisanalytics/latest/apiv2/API_StartApplication.html

        :stability: experimental
        '''
        return typing.cast("KinesisanalyticsV2", jsii.invoke(self, "toStartApplication", []))

    @jsii.member(jsii_name="toStopApplication")
    def to_stop_application(self) -> "KinesisanalyticsV2":
        '''(experimental) Grants permission to stop the application.

        Access Level: Write

        https://docs.aws.amazon.com/kinesisanalytics/latest/apiv2/API_StopApplication.html

        :stability: experimental
        '''
        return typing.cast("KinesisanalyticsV2", jsii.invoke(self, "toStopApplication", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "KinesisanalyticsV2":
        '''(experimental) Grants permission to add tags to the application.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/kinesisanalytics/latest/apiv2/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("KinesisanalyticsV2", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "KinesisanalyticsV2":
        '''(experimental) Grants permission to remove the specified tags from the application.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/kinesisanalytics/latest/apiv2/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("KinesisanalyticsV2", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateApplication")
    def to_update_application(self) -> "KinesisanalyticsV2":
        '''(experimental) Grants permission to update the application.

        Access Level: Write

        https://docs.aws.amazon.com/kinesisanalytics/latest/apiv2/API_UpdateApplication.html

        :stability: experimental
        '''
        return typing.cast("KinesisanalyticsV2", jsii.invoke(self, "toUpdateApplication", []))

    @jsii.member(jsii_name="toUpdateApplicationMaintenanceConfiguration")
    def to_update_application_maintenance_configuration(self) -> "KinesisanalyticsV2":
        '''(experimental) Grants permission to update the maintenance configuration of an application.

        Access Level: Write

        https://docs.aws.amazon.com/kinesisanalytics/latest/apiv2/API_UpdateApplicationMaintenanceConfiguration.html

        :stability: experimental
        '''
        return typing.cast("KinesisanalyticsV2", jsii.invoke(self, "toUpdateApplicationMaintenanceConfiguration", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ff7a43675aef5cc54aab38963cf57ecc74038eb0f53f0d0a7fb0b960771649a3)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fab60e02f6c0400813e4e423391d557a5801b22b5b7ecf47a28c023c0ec49c79)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Kinesisvideo(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Kinesisvideo",
):
    '''(experimental) Statement provider for service `kinesisvideo <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonkinesisvideostreams.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `kinesisvideo <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonkinesisvideostreams.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onChannel")
    def on_channel(
        self,
        channel_name: builtins.str,
        creation_time: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Kinesisvideo":
        '''(experimental) Adds a resource of type channel to the statement.

        https://docs.aws.amazon.com/kinesisvideostreams-webrtc-dg/latest/devguide/kvswebrtc-how-it-works.html

        :param channel_name: - Identifier for the channelName.
        :param creation_time: - Identifier for the creationTime.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8b92168d050706476f4cdcd4e0af5205f0a58e2a62c56a2acb7df0ed4757ed3c)
            check_type(argname="argument channel_name", value=channel_name, expected_type=type_hints["channel_name"])
            check_type(argname="argument creation_time", value=creation_time, expected_type=type_hints["creation_time"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Kinesisvideo", jsii.invoke(self, "onChannel", [channel_name, creation_time, account, region, partition]))

    @jsii.member(jsii_name="onStream")
    def on_stream(
        self,
        stream_name: builtins.str,
        creation_time: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Kinesisvideo":
        '''(experimental) Adds a resource of type stream to the statement.

        https://docs.aws.amazon.com/kinesisvideostreams/latest/dg/how-it-works.html

        :param stream_name: - Identifier for the streamName.
        :param creation_time: - Identifier for the creationTime.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1bb0eaf7a4f98e6b66475b55183a2a46a341b907f40d60d1e285dfe38f0cd0d0)
            check_type(argname="argument stream_name", value=stream_name, expected_type=type_hints["stream_name"])
            check_type(argname="argument creation_time", value=creation_time, expected_type=type_hints["creation_time"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Kinesisvideo", jsii.invoke(self, "onStream", [stream_name, creation_time, account, region, partition]))

    @jsii.member(jsii_name="toConnectAsMaster")
    def to_connect_as_master(self) -> "Kinesisvideo":
        '''(experimental) Grants permission to connect as a master to the signaling channel specified by the endpoint.

        Access Level: Write

        https://docs.aws.amazon.com/kinesisvideostreams/latest/dg/API_ConnectAsMaster.html

        :stability: experimental
        '''
        return typing.cast("Kinesisvideo", jsii.invoke(self, "toConnectAsMaster", []))

    @jsii.member(jsii_name="toConnectAsViewer")
    def to_connect_as_viewer(self) -> "Kinesisvideo":
        '''(experimental) Grants permission to connect as a viewer to the signaling channel specified by the endpoint.

        Access Level: Write

        https://docs.aws.amazon.com/kinesisvideostreams/latest/dg/API_ConnectAsViewer.html

        :stability: experimental
        '''
        return typing.cast("Kinesisvideo", jsii.invoke(self, "toConnectAsViewer", []))

    @jsii.member(jsii_name="toCreateSignalingChannel")
    def to_create_signaling_channel(self) -> "Kinesisvideo":
        '''(experimental) Grants permission to create a signaling channel.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/kinesisvideostreams/latest/dg/API_CreateSignalingChannel.html

        :stability: experimental
        '''
        return typing.cast("Kinesisvideo", jsii.invoke(self, "toCreateSignalingChannel", []))

    @jsii.member(jsii_name="toCreateStream")
    def to_create_stream(self) -> "Kinesisvideo":
        '''(experimental) Grants permission to create a Kinesis video stream.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/kinesisvideostreams/latest/dg/API_CreateStream.html

        :stability: experimental
        '''
        return typing.cast("Kinesisvideo", jsii.invoke(self, "toCreateStream", []))

    @jsii.member(jsii_name="toDeleteSignalingChannel")
    def to_delete_signaling_channel(self) -> "Kinesisvideo":
        '''(experimental) Grants permission to delete an existing signaling channel.

        Access Level: Write

        https://docs.aws.amazon.com/kinesisvideostreams/latest/dg/API_DeleteSignalingChannel.html

        :stability: experimental
        '''
        return typing.cast("Kinesisvideo", jsii.invoke(self, "toDeleteSignalingChannel", []))

    @jsii.member(jsii_name="toDeleteStream")
    def to_delete_stream(self) -> "Kinesisvideo":
        '''(experimental) Grants permission to delete an existing Kinesis video stream.

        Access Level: Write

        https://docs.aws.amazon.com/kinesisvideostreams/latest/dg/API_DeleteStream.html

        :stability: experimental
        '''
        return typing.cast("Kinesisvideo", jsii.invoke(self, "toDeleteStream", []))

    @jsii.member(jsii_name="toDescribeEdgeConfiguration")
    def to_describe_edge_configuration(self) -> "Kinesisvideo":
        '''(experimental) Grants permission to describe the edge configuration of your Kinesis Video Stream.

        Access Level: Read

        https://docs.aws.amazon.com/kinesisvideostreams/latest/dg/API_DescribeEdgeConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Kinesisvideo", jsii.invoke(self, "toDescribeEdgeConfiguration", []))

    @jsii.member(jsii_name="toDescribeImageGenerationConfiguration")
    def to_describe_image_generation_configuration(self) -> "Kinesisvideo":
        '''(experimental) Grants permission to describe the image generation configuration of your Kinesis video stream.

        Access Level: Read

        https://docs.aws.amazon.com/kinesisvideostreams/latest/dg/API_DescribeImageGenerationConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Kinesisvideo", jsii.invoke(self, "toDescribeImageGenerationConfiguration", []))

    @jsii.member(jsii_name="toDescribeNotificationConfiguration")
    def to_describe_notification_configuration(self) -> "Kinesisvideo":
        '''(experimental) Grants permission to describe the notification configuration of your Kinesis video stream.

        Access Level: Read

        https://docs.aws.amazon.com/kinesisvideostreams/latest/dg/API_DescribeNotificationConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Kinesisvideo", jsii.invoke(self, "toDescribeNotificationConfiguration", []))

    @jsii.member(jsii_name="toDescribeSignalingChannel")
    def to_describe_signaling_channel(self) -> "Kinesisvideo":
        '''(experimental) Grants permission to describe the specified signaling channel.

        Access Level: List

        https://docs.aws.amazon.com/kinesisvideostreams/latest/dg/API_DescribeSignalingChannel.html

        :stability: experimental
        '''
        return typing.cast("Kinesisvideo", jsii.invoke(self, "toDescribeSignalingChannel", []))

    @jsii.member(jsii_name="toDescribeStream")
    def to_describe_stream(self) -> "Kinesisvideo":
        '''(experimental) Grants permission to describe the specified Kinesis video stream.

        Access Level: List

        https://docs.aws.amazon.com/kinesisvideostreams/latest/dg/API_DescribeStream.html

        :stability: experimental
        '''
        return typing.cast("Kinesisvideo", jsii.invoke(self, "toDescribeStream", []))

    @jsii.member(jsii_name="toGetClip")
    def to_get_clip(self) -> "Kinesisvideo":
        '''(experimental) Grants permission to get a media clip from a video stream.

        Access Level: Read

        https://docs.aws.amazon.com/kinesisvideostreams/latest/dg/API_reader_GetClip.html

        :stability: experimental
        '''
        return typing.cast("Kinesisvideo", jsii.invoke(self, "toGetClip", []))

    @jsii.member(jsii_name="toGetDASHStreamingSessionURL")
    def to_get_dash_streaming_session_url(self) -> "Kinesisvideo":
        '''(experimental) Grants permission to create a URL for MPEG-DASH video streaming.

        Access Level: Read

        https://docs.aws.amazon.com/kinesisvideostreams/latest/dg/API_reader_GetDASHStreamingSessionURL.html

        :stability: experimental
        '''
        return typing.cast("Kinesisvideo", jsii.invoke(self, "toGetDASHStreamingSessionURL", []))

    @jsii.member(jsii_name="toGetDataEndpoint")
    def to_get_data_endpoint(self) -> "Kinesisvideo":
        '''(experimental) Grants permission to get an endpoint for a specified stream for either reading or writing media data to Kinesis Video Streams.

        Access Level: Read

        https://docs.aws.amazon.com/kinesisvideostreams/latest/dg/API_GetDataEndpoint.html

        :stability: experimental
        '''
        return typing.cast("Kinesisvideo", jsii.invoke(self, "toGetDataEndpoint", []))

    @jsii.member(jsii_name="toGetHLSStreamingSessionURL")
    def to_get_hls_streaming_session_url(self) -> "Kinesisvideo":
        '''(experimental) Grants permission to create a URL for HLS video streaming.

        Access Level: Read

        https://docs.aws.amazon.com/kinesisvideostreams/latest/dg/API_reader_GetHLSStreamingSessionURL.html

        :stability: experimental
        '''
        return typing.cast("Kinesisvideo", jsii.invoke(self, "toGetHLSStreamingSessionURL", []))

    @jsii.member(jsii_name="toGetIceServerConfig")
    def to_get_ice_server_config(self) -> "Kinesisvideo":
        '''(experimental) Grants permission to get the ICE server configuration.

        Access Level: Read

        https://docs.aws.amazon.com/kinesisvideostreams/latest/dg/API_AWSAcuitySignalingService_GetIceServerConfig.html

        :stability: experimental
        '''
        return typing.cast("Kinesisvideo", jsii.invoke(self, "toGetIceServerConfig", []))

    @jsii.member(jsii_name="toGetImages")
    def to_get_images(self) -> "Kinesisvideo":
        '''(experimental) Grants permission to get generated images from your Kinesis video stream.

        Access Level: Read

        https://docs.aws.amazon.com/kinesisvideostreams/latest/dg/API_reader_GetImages.html

        :stability: experimental
        '''
        return typing.cast("Kinesisvideo", jsii.invoke(self, "toGetImages", []))

    @jsii.member(jsii_name="toGetMedia")
    def to_get_media(self) -> "Kinesisvideo":
        '''(experimental) Grants permission to return media content of a Kinesis video stream.

        Access Level: Read

        https://docs.aws.amazon.com/kinesisvideostreams/latest/dg/API_dataplane_GetMedia.html

        :stability: experimental
        '''
        return typing.cast("Kinesisvideo", jsii.invoke(self, "toGetMedia", []))

    @jsii.member(jsii_name="toGetMediaForFragmentList")
    def to_get_media_for_fragment_list(self) -> "Kinesisvideo":
        '''(experimental) Grants permission to read and return media data only from persisted storage.

        Access Level: Read

        https://docs.aws.amazon.com/kinesisvideostreams/latest/dg/API_reader_GetMediaForFragmentList.html

        :stability: experimental
        '''
        return typing.cast("Kinesisvideo", jsii.invoke(self, "toGetMediaForFragmentList", []))

    @jsii.member(jsii_name="toGetSignalingChannelEndpoint")
    def to_get_signaling_channel_endpoint(self) -> "Kinesisvideo":
        '''(experimental) Grants permission to get endpoints for a specified combination of protocol and role for a signaling channel.

        Access Level: Read

        https://docs.aws.amazon.com/kinesisvideostreams/latest/dg/API_GetSignalingChannelEndpoint.html

        :stability: experimental
        '''
        return typing.cast("Kinesisvideo", jsii.invoke(self, "toGetSignalingChannelEndpoint", []))

    @jsii.member(jsii_name="toListFragments")
    def to_list_fragments(self) -> "Kinesisvideo":
        '''(experimental) Grants permission to list the fragments from archival storage based on the pagination token or selector type with range specified.

        Access Level: List

        https://docs.aws.amazon.com/kinesisvideostreams/latest/dg/API_reader_ListFragments.html

        :stability: experimental
        '''
        return typing.cast("Kinesisvideo", jsii.invoke(self, "toListFragments", []))

    @jsii.member(jsii_name="toListSignalingChannels")
    def to_list_signaling_channels(self) -> "Kinesisvideo":
        '''(experimental) Grants permission to list your signaling channels.

        Access Level: List

        https://docs.aws.amazon.com/kinesisvideostreams/latest/dg/API_ListSignalingChannels.html

        :stability: experimental
        '''
        return typing.cast("Kinesisvideo", jsii.invoke(self, "toListSignalingChannels", []))

    @jsii.member(jsii_name="toListStreams")
    def to_list_streams(self) -> "Kinesisvideo":
        '''(experimental) Grants permission to list your Kinesis video streams.

        Access Level: List

        https://docs.aws.amazon.com/kinesisvideostreams/latest/dg/API_ListStreams.html

        :stability: experimental
        '''
        return typing.cast("Kinesisvideo", jsii.invoke(self, "toListStreams", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Kinesisvideo":
        '''(experimental) Grants permission to fetch the tags associated with your resource.

        Access Level: Read

        https://docs.aws.amazon.com/kinesisvideostreams/latest/dg/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("Kinesisvideo", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toListTagsForStream")
    def to_list_tags_for_stream(self) -> "Kinesisvideo":
        '''(experimental) Grants permission to fetch the tags associated with Kinesis video stream.

        Access Level: Read

        https://docs.aws.amazon.com/kinesisvideostreams/latest/dg/API_ListTagsForStream.html

        :stability: experimental
        '''
        return typing.cast("Kinesisvideo", jsii.invoke(self, "toListTagsForStream", []))

    @jsii.member(jsii_name="toPutMedia")
    def to_put_media(self) -> "Kinesisvideo":
        '''(experimental) Grants permission to send media data to a Kinesis video stream.

        Access Level: Write

        https://docs.aws.amazon.com/kinesisvideostreams/latest/dg/API_dataplane_PutMedia.html

        :stability: experimental
        '''
        return typing.cast("Kinesisvideo", jsii.invoke(self, "toPutMedia", []))

    @jsii.member(jsii_name="toSendAlexaOfferToMaster")
    def to_send_alexa_offer_to_master(self) -> "Kinesisvideo":
        '''(experimental) Grants permission to send the Alexa SDP offer to the master.

        Access Level: Write

        https://docs.aws.amazon.com/kinesisvideostreams/latest/dg/API_AWSAcuitySignalingService_SendAlexaOfferToMaster.html

        :stability: experimental
        '''
        return typing.cast("Kinesisvideo", jsii.invoke(self, "toSendAlexaOfferToMaster", []))

    @jsii.member(jsii_name="toStartEdgeConfigurationUpdate")
    def to_start_edge_configuration_update(self) -> "Kinesisvideo":
        '''(experimental) Grants permission to start edge configuration update of your Kinesis Video Stream.

        Access Level: Write

        https://docs.aws.amazon.com/kinesisvideostreams/latest/dg/API_StartEdgeConfigurationUpdate.html

        :stability: experimental
        '''
        return typing.cast("Kinesisvideo", jsii.invoke(self, "toStartEdgeConfigurationUpdate", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Kinesisvideo":
        '''(experimental) Grants permission to attach set of tags to your resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/kinesisvideostreams/latest/dg/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("Kinesisvideo", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toTagStream")
    def to_tag_stream(self) -> "Kinesisvideo":
        '''(experimental) Grants permission to attach set of tags to your Kinesis video streams.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/kinesisvideostreams/latest/dg/API_TagStream.html

        :stability: experimental
        '''
        return typing.cast("Kinesisvideo", jsii.invoke(self, "toTagStream", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Kinesisvideo":
        '''(experimental) Grants permission to remove one or more tags from your resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/kinesisvideostreams/latest/dg/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("Kinesisvideo", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUntagStream")
    def to_untag_stream(self) -> "Kinesisvideo":
        '''(experimental) Grants permission to remove one or more tags from your Kinesis video streams.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/kinesisvideostreams/latest/dg/API_UntagStream.html

        :stability: experimental
        '''
        return typing.cast("Kinesisvideo", jsii.invoke(self, "toUntagStream", []))

    @jsii.member(jsii_name="toUpdateDataRetention")
    def to_update_data_retention(self) -> "Kinesisvideo":
        '''(experimental) Grants permission to update the data retention period of your Kinesis video stream.

        Access Level: Write

        https://docs.aws.amazon.com/kinesisvideostreams/latest/dg/API_UpdateDataRetention.html

        :stability: experimental
        '''
        return typing.cast("Kinesisvideo", jsii.invoke(self, "toUpdateDataRetention", []))

    @jsii.member(jsii_name="toUpdateImageGenerationConfiguration")
    def to_update_image_generation_configuration(self) -> "Kinesisvideo":
        '''(experimental) Grants permission to update the image generation configuration of your Kinesis video stream.

        Access Level: Write

        https://docs.aws.amazon.com/kinesisvideostreams/latest/dg/API_UpdateImageGenerationConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Kinesisvideo", jsii.invoke(self, "toUpdateImageGenerationConfiguration", []))

    @jsii.member(jsii_name="toUpdateNotificationConfiguration")
    def to_update_notification_configuration(self) -> "Kinesisvideo":
        '''(experimental) Grants permission to update the notification configuration of your Kinesis video stream.

        Access Level: Write

        https://docs.aws.amazon.com/kinesisvideostreams/latest/dg/API_UpdateNotificationConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Kinesisvideo", jsii.invoke(self, "toUpdateNotificationConfiguration", []))

    @jsii.member(jsii_name="toUpdateSignalingChannel")
    def to_update_signaling_channel(self) -> "Kinesisvideo":
        '''(experimental) Grants permission to update an existing signaling channel.

        Access Level: Write

        https://docs.aws.amazon.com/kinesisvideostreams/latest/dg/API_UpdateSignalingChannel.html

        :stability: experimental
        '''
        return typing.cast("Kinesisvideo", jsii.invoke(self, "toUpdateSignalingChannel", []))

    @jsii.member(jsii_name="toUpdateStream")
    def to_update_stream(self) -> "Kinesisvideo":
        '''(experimental) Grants permission to update an existing Kinesis video stream.

        Access Level: Write

        https://docs.aws.amazon.com/kinesisvideostreams/latest/dg/API_UpdateStream.html

        :stability: experimental
        '''
        return typing.cast("Kinesisvideo", jsii.invoke(self, "toUpdateStream", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__20a50553258eaa2c8e6fc3262c99cd694cf6c0d6062766fd3679dfcdbb8e67c1)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2148fcd9e60e772957a97ba39ee92fb809e4c0936281dcd7ce44463275ad3682)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Kms(PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Kms"):
    '''(experimental) Statement provider for service `kms <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awskeymanagementservice.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `kms <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awskeymanagementservice.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="ifBypassPolicyLockoutSafetyCheck")
    def if_bypass_policy_lockout_safety_check(
        self,
        value: typing.Optional[builtins.bool] = None,
    ) -> "Kms":
        '''(experimental) Filters access to the CreateKey and PutKeyPolicy operations based on the value of the BypassPolicyLockoutSafetyCheck parameter in the request.

        https://docs.aws.amazon.com/kms/latest/developerguide/policy-conditions.html#conditions-kms-bypass-policy-lockout-safety-check

        Applies to actions:

        - .toCreateKey()
        - .toPutKeyPolicy()

        :param value: ``true`` or ``false``. **Default:** ``true``

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__876bfe7ed8ac84cd3571d192ef0fc9076938e1fcd7dcdc22a07cbda41b2a2f26)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast("Kms", jsii.invoke(self, "ifBypassPolicyLockoutSafetyCheck", [value]))

    @jsii.member(jsii_name="ifCallerAccount")
    def if_caller_account(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Kms":
        '''(experimental) Filters access to specified AWS KMS operations based on the AWS account ID of the caller.

        You can use this condition key to allow or deny access to all IAM users and roles in an AWS account in a single policy statement

        https://docs.aws.amazon.com/kms/latest/developerguide/policy-conditions.html#conditions-kms-caller-account

        Applies to actions:

        - .toCancelKeyDeletion()
        - .toConnectCustomKeyStore()
        - .toCreateAlias()
        - .toCreateCustomKeyStore()
        - .toCreateGrant()
        - .toCreateKey()
        - .toDecrypt()
        - .toDeleteAlias()
        - .toDeleteCustomKeyStore()
        - .toDeleteImportedKeyMaterial()
        - .toDescribeCustomKeyStores()
        - .toDescribeKey()
        - .toDisableKey()
        - .toDisableKeyRotation()
        - .toDisconnectCustomKeyStore()
        - .toEnableKey()
        - .toEnableKeyRotation()
        - .toEncrypt()
        - .toGenerateDataKey()
        - .toGenerateDataKeyPair()
        - .toGenerateDataKeyPairWithoutPlaintext()
        - .toGenerateDataKeyWithoutPlaintext()
        - .toGenerateMac()
        - .toGetKeyPolicy()
        - .toGetKeyRotationStatus()
        - .toGetParametersForImport()
        - .toGetPublicKey()
        - .toImportKeyMaterial()
        - .toListGrants()
        - .toListKeyPolicies()
        - .toListResourceTags()
        - .toPutKeyPolicy()
        - .toReEncryptFrom()
        - .toReEncryptTo()
        - .toReplicateKey()
        - .toRevokeGrant()
        - .toScheduleKeyDeletion()
        - .toSign()
        - .toTagResource()
        - .toUntagResource()
        - .toUpdateAlias()
        - .toUpdateCustomKeyStore()
        - .toUpdateKeyDescription()
        - .toUpdatePrimaryRegion()
        - .toVerify()
        - .toVerifyMac()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ecf2246c37bc05e2169b467908f8e9ae28d704bf9920df3cd78c2909707e49c0)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Kms", jsii.invoke(self, "ifCallerAccount", [value, operator]))

    @jsii.member(jsii_name="ifCustomerMasterKeySpec")
    def if_customer_master_key_spec(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Kms":
        '''(experimental) The kms:CustomerMasterKeySpec condition key is deprecated. Instead, use the kms:KeySpec condition key.

        https://docs.aws.amazon.com/kms/latest/developerguide/policy-conditions.html#conditions-kms-key-spec-replaced

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__29c11f1739acd2ddf5e29a311f0087ebe401ff18d13e349f5ee779c1cf471c3f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Kms", jsii.invoke(self, "ifCustomerMasterKeySpec", [value, operator]))

    @jsii.member(jsii_name="ifCustomerMasterKeyUsage")
    def if_customer_master_key_usage(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Kms":
        '''(experimental) The kms:CustomerMasterKeyUsage condition key is deprecated. Instead, use the kms:KeyUsage condition key.

        https://docs.aws.amazon.com/kms/latest/developerguide/policy-conditions.html#conditions-kms-key-usage-replaced

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9b2cfba12bfb768c57e0858dd68e9818001ee84cf8de710738bed8ce7a1375b0)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Kms", jsii.invoke(self, "ifCustomerMasterKeyUsage", [value, operator]))

    @jsii.member(jsii_name="ifDataKeyPairSpec")
    def if_data_key_pair_spec(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Kms":
        '''(experimental) Filters access to GenerateDataKeyPair and GenerateDataKeyPairWithoutPlaintext operations based on the value of the KeyPairSpec parameter in the request.

        https://docs.aws.amazon.com/kms/latest/developerguide/policy-conditions.html#conditions-kms-data-key-pair-spec

        Applies to actions:

        - .toGenerateDataKeyPair()
        - .toGenerateDataKeyPairWithoutPlaintext()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fd2fac97bd7e3c378ac4f8b38ce0817b773039e083f6f31c328b0c6291bcaa29)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Kms", jsii.invoke(self, "ifDataKeyPairSpec", [value, operator]))

    @jsii.member(jsii_name="ifEncryptionAlgorithm")
    def if_encryption_algorithm(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Kms":
        '''(experimental) Filters access to encryption operations based on the value of the encryption algorithm in the request.

        https://docs.aws.amazon.com/kms/latest/developerguide/policy-conditions.html#conditions-kms-encryption-algorithm

        Applies to actions:

        - .toDecrypt()
        - .toEncrypt()
        - .toGenerateDataKey()
        - .toGenerateDataKeyPair()
        - .toGenerateDataKeyPairWithoutPlaintext()
        - .toGenerateDataKeyWithoutPlaintext()
        - .toReEncryptFrom()
        - .toReEncryptTo()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3578bd6dc21f27e49266d7f4084a97b6f2f8cd4760c369f064e9014da0430c6b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Kms", jsii.invoke(self, "ifEncryptionAlgorithm", [value, operator]))

    @jsii.member(jsii_name="ifEncryptionContext")
    def if_encryption_context(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Kms":
        '''(experimental) Filters access to a symmetric AWS KMS key based on the encryption context in a cryptographic operation.

        This condition evaluates the key and value in each key-value encryption context pair

        https://docs.aws.amazon.com/kms/latest/developerguide/policy-conditions.html#conditions-kms-encryption-context

        Applies to actions:

        - .toCreateGrant()
        - .toDecrypt()
        - .toEncrypt()
        - .toGenerateDataKey()
        - .toGenerateDataKeyPair()
        - .toGenerateDataKeyPairWithoutPlaintext()
        - .toGenerateDataKeyWithoutPlaintext()
        - .toReEncryptFrom()
        - .toReEncryptTo()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__048dd2c731904d85ed7414bda83e7eeeeab77d9b961f67256071087a25244867)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Kms", jsii.invoke(self, "ifEncryptionContext", [value, operator]))

    @jsii.member(jsii_name="ifEncryptionContextKeys")
    def if_encryption_context_keys(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Kms":
        '''(experimental) Filters access to a symmetric AWS KMS key based on the encryption context in a cryptographic operation.

        This condition key evaluates only the key in each key-value encryption context pair

        https://docs.aws.amazon.com/kms/latest/developerguide/policy-conditions.html#conditions-kms-encryption-context-keys

        Applies to actions:

        - .toCreateGrant()
        - .toDecrypt()
        - .toEncrypt()
        - .toGenerateDataKey()
        - .toGenerateDataKeyPair()
        - .toGenerateDataKeyPairWithoutPlaintext()
        - .toGenerateDataKeyWithoutPlaintext()
        - .toReEncryptFrom()
        - .toReEncryptTo()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__27e723ec14aaee9351736015444a1fc7b9c4524eb0feff57cc52209fa96ff94b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Kms", jsii.invoke(self, "ifEncryptionContextKeys", [value, operator]))

    @jsii.member(jsii_name="ifExpirationModel")
    def if_expiration_model(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Kms":
        '''(experimental) Filters access to the ImportKeyMaterial operation based on the value of the ExpirationModel parameter in the request.

        https://docs.aws.amazon.com/kms/latest/developerguide/policy-conditions.html#conditions-kms-expiration-model

        Applies to actions:

        - .toImportKeyMaterial()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e1ce0dfad2d1bb3d706d1fbefd6ef2b48ddb5d6f80c049791c986607e96b9a7e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Kms", jsii.invoke(self, "ifExpirationModel", [value, operator]))

    @jsii.member(jsii_name="ifGrantConstraintType")
    def if_grant_constraint_type(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Kms":
        '''(experimental) Filters access to the CreateGrant operation based on the grant constraint in the request.

        https://docs.aws.amazon.com/kms/latest/developerguide/policy-conditions.html#conditions-kms-grant-constraint-type

        Applies to actions:

        - .toCreateGrant()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7c886d67449c69f6a447d23fd0ba211e66f77e0f5d34851b71a417cc5997ca58)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Kms", jsii.invoke(self, "ifGrantConstraintType", [value, operator]))

    @jsii.member(jsii_name="ifGranteePrincipal")
    def if_grantee_principal(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Kms":
        '''(experimental) Filters access to the CreateGrant operation based on the grantee principal in the grant.

        https://docs.aws.amazon.com/kms/latest/developerguide/policy-conditions.html#conditions-kms-grantee-principal

        Applies to actions:

        - .toCreateGrant()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__54281da5c435b8b10bc9b57235bab8ec6a1be12d0079251acfb79605172c6e1b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Kms", jsii.invoke(self, "ifGranteePrincipal", [value, operator]))

    @jsii.member(jsii_name="ifGrantIsForAWSResource")
    def if_grant_is_for_aws_resource(
        self,
        value: typing.Optional[builtins.bool] = None,
    ) -> "Kms":
        '''(experimental) Filters access to the CreateGrant operation when the request comes from a specified AWS service.

        https://docs.aws.amazon.com/kms/latest/developerguide/policy-conditions.html#conditions-kms-grant-is-for-aws-resource

        Applies to actions:

        - .toCreateGrant()
        - .toListGrants()
        - .toRevokeGrant()

        :param value: ``true`` or ``false``. **Default:** ``true``

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e6cc4a45c9dde758919c7a37b37957f02b10cbd41017c5cc7c80e4adadee4578)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast("Kms", jsii.invoke(self, "ifGrantIsForAWSResource", [value]))

    @jsii.member(jsii_name="ifGrantOperations")
    def if_grant_operations(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Kms":
        '''(experimental) Filters access to the CreateGrant operation based on the operations in the grant.

        https://docs.aws.amazon.com/kms/latest/developerguide/policy-conditions.html#conditions-kms-grant-operations

        Applies to actions:

        - .toCreateGrant()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d05fa8ce8a11b048b2a9d0ef500f40ec94a3e3d17472051397e7dcd8ab7f5167)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Kms", jsii.invoke(self, "ifGrantOperations", [value, operator]))

    @jsii.member(jsii_name="ifKeyOrigin")
    def if_key_origin(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Kms":
        '''(experimental) Filters access to an API operation based on the Origin property of the AWS KMS key created by or used in the operation.

        Use it to qualify authorization of the CreateKey operation or any operation that is authorized for a KMS key

        https://docs.aws.amazon.com/kms/latest/developerguide/policy-conditions.html#conditions-kms-key-origin

        Applies to actions:

        - .toCreateKey()

        Applies to resource types:

        - key

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a156f6ba3756efde67a040793eda81a68a863f8ef06099daae7522da13b316b4)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Kms", jsii.invoke(self, "ifKeyOrigin", [value, operator]))

    @jsii.member(jsii_name="ifKeySpec")
    def if_key_spec(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Kms":
        '''(experimental) Filters access to an API operation based on the KeySpec property of the AWS KMS key that is created by or used in the operation.

        Use it to qualify authorization of the CreateKey operation or any operation that is authorized for a KMS key resource

        https://docs.aws.amazon.com/kms/latest/developerguide/policy-conditions.html#conditions-kms-key-spec

        Applies to actions:

        - .toCreateKey()

        Applies to resource types:

        - key

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__197e83cc2a60dfb8d36e5dbe92ccfdee4fd2eb5b5f9786f104bb1c5de8054042)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Kms", jsii.invoke(self, "ifKeySpec", [value, operator]))

    @jsii.member(jsii_name="ifKeyUsage")
    def if_key_usage(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Kms":
        '''(experimental) Filters access to an API operation based on the KeyUsage property of the AWS KMS key created by or used in the operation.

        Use it to qualify authorization of the CreateKey operation or any operation that is authorized for a KMS key resource

        https://docs.aws.amazon.com/kms/latest/developerguide/policy-conditions.html#conditions-kms-key-usage

        Applies to actions:

        - .toCreateKey()

        Applies to resource types:

        - key

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e8afe45f37770484ce16f08c88910e7c58841a0ccea473aff3a63f43217d870e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Kms", jsii.invoke(self, "ifKeyUsage", [value, operator]))

    @jsii.member(jsii_name="ifMacAlgorithm")
    def if_mac_algorithm(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Kms":
        '''(experimental) Filters access to the GenerateMac and VerifyMac operations based on the MacAlgorithm parameter in the request.

        https://docs.aws.amazon.com/kms/latest/developerguide/policy-conditions.html#conditions-kms-mac-algorithm

        Applies to actions:

        - .toGenerateMac()
        - .toVerifyMac()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d3a706d32ae14ddce95fcd9421a7b21b2d569cf0c818ccd8ece35b305d32c918)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Kms", jsii.invoke(self, "ifMacAlgorithm", [value, operator]))

    @jsii.member(jsii_name="ifMessageType")
    def if_message_type(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Kms":
        '''(experimental) Filters access to the Sign and Verify operations based on the value of the MessageType parameter in the request.

        https://docs.aws.amazon.com/kms/latest/developerguide/policy-conditions.html#conditions-kms-message-type

        Applies to actions:

        - .toSign()
        - .toVerify()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5ad82f239fd3a22af14a5c8c1cd683a1349e51f71cf2c8249e0e188515f3ffc8)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Kms", jsii.invoke(self, "ifMessageType", [value, operator]))

    @jsii.member(jsii_name="ifMultiRegion")
    def if_multi_region(self, value: typing.Optional[builtins.bool] = None) -> "Kms":
        '''(experimental) Filters access to an API operation based on the MultiRegion property of the AWS KMS key created by or used in the operation.

        Use it to qualify authorization of the CreateKey operation or any operation that is authorized for a KMS key resource

        https://docs.aws.amazon.com/kms/latest/developerguide/policy-conditions.html#conditions-kms-multi-region

        Applies to actions:

        - .toCreateKey()

        Applies to resource types:

        - key

        :param value: ``true`` or ``false``. **Default:** ``true``

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__57ae3008367cc817889973e74d8d41a98e0548a7a767a5514ca51a5aafb96ca7)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast("Kms", jsii.invoke(self, "ifMultiRegion", [value]))

    @jsii.member(jsii_name="ifMultiRegionKeyType")
    def if_multi_region_key_type(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Kms":
        '''(experimental) Filters access to an API operation based on the MultiRegionKeyType property of the AWS KMS key created by or used in the operation.

        Use it to qualify authorization of the CreateKey operation or any operation that is authorized for a KMS key resource

        https://docs.aws.amazon.com/kms/latest/developerguide/policy-conditions.html#conditions-kms-multi-region-key-type

        Applies to actions:

        - .toCreateKey()

        Applies to resource types:

        - key

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5207c2a63e3e9bff85e9493a5a6ffe0ac7a782ecd96d1ad11a7e1e0d73427dac)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Kms", jsii.invoke(self, "ifMultiRegionKeyType", [value, operator]))

    @jsii.member(jsii_name="ifPrimaryRegion")
    def if_primary_region(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Kms":
        '''(experimental) Filters access to the UpdatePrimaryRegion operation based on the value of the PrimaryRegion parameter in the request.

        https://docs.aws.amazon.com/kms/latest/developerguide/policy-conditions.html#conditions-kms-primary-region

        Applies to actions:

        - .toUpdatePrimaryRegion()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5efec41e22d85e465bdfc857ef7deeecf61a46cd16d40bb97347fea9661b75b7)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Kms", jsii.invoke(self, "ifPrimaryRegion", [value, operator]))

    @jsii.member(jsii_name="ifRecipientAttestation")
    def if_recipient_attestation(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Kms":
        '''(experimental) Filters access to the Decrypt, GenerateDataKey, and GenerateRandom operations based on the image hash in the attestation document in the request.

        https://docs.aws.amazon.com/kms/latest/developerguide/policy-conditions.html#conditions-kms-recipient-attestation

        Applies to actions:

        - .toDecrypt()
        - .toGenerateDataKey()
        - .toGenerateRandom()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f3d007a832fa1935b1e16b1e64bde4b9fde306e7ea3517aed59505b71f6c03db)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Kms", jsii.invoke(self, "ifRecipientAttestation", [value, operator]))

    @jsii.member(jsii_name="ifReEncryptOnSameKey")
    def if_re_encrypt_on_same_key(
        self,
        value: typing.Optional[builtins.bool] = None,
    ) -> "Kms":
        '''(experimental) Filters access to the ReEncrypt operation when it uses the same AWS KMS key that was used for the Encrypt operation.

        https://docs.aws.amazon.com/kms/latest/developerguide/policy-conditions.html#conditions-kms-reencrypt-on-same-key

        Applies to actions:

        - .toReEncryptFrom()
        - .toReEncryptTo()

        :param value: ``true`` or ``false``. **Default:** ``true``

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__107213557782de7fc1f02538a4b64dbe34c9101bf96b2995c5a1f02978d22e25)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        return typing.cast("Kms", jsii.invoke(self, "ifReEncryptOnSameKey", [value]))

    @jsii.member(jsii_name="ifReplicaRegion")
    def if_replica_region(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Kms":
        '''(experimental) Filters access to the ReplicateKey operation based on the value of the ReplicaRegion parameter in the request.

        https://docs.aws.amazon.com/kms/latest/developerguide/policy-conditions.html#conditions-kms-replica-region

        Applies to actions:

        - .toReplicateKey()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__945c53affdeb0810c4bb48b417a8e34606a2b0968ca02fc9db5c18e5ca7230a0)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Kms", jsii.invoke(self, "ifReplicaRegion", [value, operator]))

    @jsii.member(jsii_name="ifRequestAlias")
    def if_request_alias(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Kms":
        '''(experimental) Filters access to cryptographic operations, DescribeKey, and GetPublicKey based on the alias in the request.

        https://docs.aws.amazon.com/kms/latest/developerguide/policy-conditions.html#conditions-kms-request-alias

        Applies to actions:

        - .toDecrypt()
        - .toDescribeKey()
        - .toEncrypt()
        - .toGenerateDataKey()
        - .toGenerateDataKeyPair()
        - .toGenerateDataKeyPairWithoutPlaintext()
        - .toGenerateDataKeyWithoutPlaintext()
        - .toGenerateMac()
        - .toGetPublicKey()
        - .toReEncryptFrom()
        - .toReEncryptTo()
        - .toSign()
        - .toVerify()
        - .toVerifyMac()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__606002d57093448162ceb917eb1d7b46669047b45eb5b140bb74967836c28df7)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Kms", jsii.invoke(self, "ifRequestAlias", [value, operator]))

    @jsii.member(jsii_name="ifResourceAliases")
    def if_resource_aliases(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Kms":
        '''(experimental) Filters access to specified AWS KMS operations based on aliases associated with the AWS KMS key.

        https://docs.aws.amazon.com/kms/latest/developerguide/policy-conditions.html#conditions-kms-resource-aliases

        Applies to resource types:

        - key

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d6a5e0555cbcc5fac0830ba38bcb08479dcf272be7b7f563f680521ec78323cd)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Kms", jsii.invoke(self, "ifResourceAliases", [value, operator]))

    @jsii.member(jsii_name="ifRetiringPrincipal")
    def if_retiring_principal(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Kms":
        '''(experimental) Filters access to the CreateGrant operation based on the retiring principal in the grant.

        https://docs.aws.amazon.com/kms/latest/developerguide/policy-conditions.html#conditions-kms-retiring-principal

        Applies to actions:

        - .toCreateGrant()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0c6b548977a01172557352fa120a3c26bf83d57193b9a22d562a2fb0b1f23fd5)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Kms", jsii.invoke(self, "ifRetiringPrincipal", [value, operator]))

    @jsii.member(jsii_name="ifSigningAlgorithm")
    def if_signing_algorithm(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Kms":
        '''(experimental) Filters access to the Sign and Verify operations based on the signing algorithm in the request.

        https://docs.aws.amazon.com/kms/latest/developerguide/policy-conditions.html#conditions-kms-signing-algorithm

        Applies to actions:

        - .toSign()
        - .toVerify()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1f2803c3142a593dc19ed357266a5d41bb943cca38d1bae23cc69f9f2bb7c3d6)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Kms", jsii.invoke(self, "ifSigningAlgorithm", [value, operator]))

    @jsii.member(jsii_name="ifValidTo")
    def if_valid_to(
        self,
        value: typing.Union[builtins.str, datetime.datetime, typing.Sequence[typing.Union[builtins.str, datetime.datetime]]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Kms":
        '''(experimental) Filters access to the ImportKeyMaterial operation based on the value of the ValidTo parameter in the request.

        You can use this condition key to allow users to import key material only when it expires by the specified date

        https://docs.aws.amazon.com/kms/latest/developerguide/policy-conditions.html#conditions-kms-valid-to

        Applies to actions:

        - .toImportKeyMaterial()

        :param value: The value(s) to check.
        :param operator: Works with `date operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_Date>`_. **Default:** ``DateEquals``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__89c842c873b72888ec48597f76a5594e62fcc27c20246b9d5cbf135534226e20)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Kms", jsii.invoke(self, "ifValidTo", [value, operator]))

    @jsii.member(jsii_name="ifViaService")
    def if_via_service(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Kms":
        '''(experimental) Filters access when a request made on the principal's behalf comes from a specified AWS service.

        https://docs.aws.amazon.com/kms/latest/developerguide/policy-conditions.html#conditions-kms-via-service

        Applies to actions:

        - .toCancelKeyDeletion()
        - .toCreateAlias()
        - .toCreateGrant()
        - .toCreateKey()
        - .toDecrypt()
        - .toDeleteAlias()
        - .toDeleteImportedKeyMaterial()
        - .toDescribeKey()
        - .toDisableKey()
        - .toDisableKeyRotation()
        - .toEnableKey()
        - .toEnableKeyRotation()
        - .toEncrypt()
        - .toGenerateDataKey()
        - .toGenerateDataKeyPair()
        - .toGenerateDataKeyPairWithoutPlaintext()
        - .toGenerateDataKeyWithoutPlaintext()
        - .toGenerateMac()
        - .toGetKeyPolicy()
        - .toGetKeyRotationStatus()
        - .toGetParametersForImport()
        - .toGetPublicKey()
        - .toImportKeyMaterial()
        - .toListGrants()
        - .toListKeyPolicies()
        - .toListResourceTags()
        - .toPutKeyPolicy()
        - .toReEncryptFrom()
        - .toReEncryptTo()
        - .toReplicateKey()
        - .toRevokeGrant()
        - .toScheduleKeyDeletion()
        - .toSign()
        - .toTagResource()
        - .toUntagResource()
        - .toUpdateAlias()
        - .toUpdateKeyDescription()
        - .toUpdatePrimaryRegion()
        - .toVerify()
        - .toVerifyMac()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f3a472e33056dc7f6419476b46acc1a1aa677213ccc13c1b3badf8bfe9e53a54)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Kms", jsii.invoke(self, "ifViaService", [value, operator]))

    @jsii.member(jsii_name="ifWrappingAlgorithm")
    def if_wrapping_algorithm(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Kms":
        '''(experimental) Filters access to the GetParametersForImport operation based on the value of the WrappingAlgorithm parameter in the request.

        https://docs.aws.amazon.com/kms/latest/developerguide/policy-conditions.html#conditions-kms-wrapping-algorithm

        Applies to actions:

        - .toGetParametersForImport()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b251c0029ff392a81c608d81d1f9e65bd15761559c62ce24faae46b364dc8ab4)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Kms", jsii.invoke(self, "ifWrappingAlgorithm", [value, operator]))

    @jsii.member(jsii_name="ifWrappingKeySpec")
    def if_wrapping_key_spec(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Kms":
        '''(experimental) Filters access to the GetParametersForImport operation based on the value of the WrappingKeySpec parameter in the request.

        https://docs.aws.amazon.com/kms/latest/developerguide/policy-conditions.html#conditions-kms-wrapping-key-spec

        Applies to actions:

        - .toGetParametersForImport()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7a846098309d43511381313e6eec7f35d04100e05582410eaa79ff3d2ef96837)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Kms", jsii.invoke(self, "ifWrappingKeySpec", [value, operator]))

    @jsii.member(jsii_name="onAlias")
    def on_alias(
        self,
        alias: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Kms":
        '''(experimental) Adds a resource of type alias to the statement.

        https://docs.aws.amazon.com/kms/latest/developerguide/programming-aliases.html

        :param alias: - Identifier for the alias.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__96d3973b71f6531377a73c799ad5bb9dfc7c211f5d22a3fef8939bf5b809c551)
            check_type(argname="argument alias", value=alias, expected_type=type_hints["alias"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Kms", jsii.invoke(self, "onAlias", [alias, account, region, partition]))

    @jsii.member(jsii_name="onKey")
    def on_key(
        self,
        key_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Kms":
        '''(experimental) Adds a resource of type key to the statement.

        https://docs.aws.amazon.com/kms/latest/developerguide/concepts.html#kms_keys

        :param key_id: - Identifier for the keyId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag() - .ifKeyOrigin() - .ifKeySpec() - .ifKeyUsage() - .ifMultiRegion() - .ifMultiRegionKeyType() - .ifResourceAliases()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bc6fcad930c73ef810a6ceda66c5f827d22a9a72c9122b001de8f09955a8bf06)
            check_type(argname="argument key_id", value=key_id, expected_type=type_hints["key_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Kms", jsii.invoke(self, "onKey", [key_id, account, region, partition]))

    @jsii.member(jsii_name="toCancelKeyDeletion")
    def to_cancel_key_deletion(self) -> "Kms":
        '''(experimental) Controls permission to cancel the scheduled deletion of an AWS KMS key.

        Access Level: Write

        Possible conditions:

        - .ifCallerAccount()
        - .ifViaService()

        https://docs.aws.amazon.com/kms/latest/APIReference/API_CancelKeyDeletion.html

        :stability: experimental
        '''
        return typing.cast("Kms", jsii.invoke(self, "toCancelKeyDeletion", []))

    @jsii.member(jsii_name="toConnectCustomKeyStore")
    def to_connect_custom_key_store(self) -> "Kms":
        '''(experimental) Controls permission to connect or reconnect a custom key store to its associated AWS CloudHSM cluster.

        Access Level: Write

        Possible conditions:

        - .ifCallerAccount()

        https://docs.aws.amazon.com/kms/latest/APIReference/API_ConnectCustomKeyStore.html

        :stability: experimental
        '''
        return typing.cast("Kms", jsii.invoke(self, "toConnectCustomKeyStore", []))

    @jsii.member(jsii_name="toCreateAlias")
    def to_create_alias(self) -> "Kms":
        '''(experimental) Controls permission to create an alias for an AWS KMS key.

        Aliases are optional friendly names that you can associate with KMS keys

        Access Level: Write

        Possible conditions:

        - .ifCallerAccount()
        - .ifViaService()

        https://docs.aws.amazon.com/kms/latest/APIReference/API_CreateAlias.html

        :stability: experimental
        '''
        return typing.cast("Kms", jsii.invoke(self, "toCreateAlias", []))

    @jsii.member(jsii_name="toCreateCustomKeyStore")
    def to_create_custom_key_store(self) -> "Kms":
        '''(experimental) Controls permission to create a custom key store that is associated with an AWS CloudHSM cluster that you own and manage.

        Access Level: Write

        Possible conditions:

        - .ifCallerAccount()

        Dependent actions:

        - cloudhsm:DescribeClusters
        - iam:CreateServiceLinkedRole

        https://docs.aws.amazon.com/kms/latest/APIReference/API_CreateCustomKeyStore.html

        :stability: experimental
        '''
        return typing.cast("Kms", jsii.invoke(self, "toCreateCustomKeyStore", []))

    @jsii.member(jsii_name="toCreateGrant")
    def to_create_grant(self) -> "Kms":
        '''(experimental) Controls permission to add a grant to an AWS KMS key.

        You can use grants to add permissions without changing the key policy or IAM policy

        Access Level: Permissions management

        Possible conditions:

        - .ifCallerAccount()
        - .ifEncryptionContext()
        - .ifEncryptionContextKeys()
        - .ifGrantConstraintType()
        - .ifGranteePrincipal()
        - .ifGrantIsForAWSResource()
        - .ifGrantOperations()
        - .ifRetiringPrincipal()
        - .ifViaService()

        https://docs.aws.amazon.com/kms/latest/APIReference/API_CreateGrant.html

        :stability: experimental
        '''
        return typing.cast("Kms", jsii.invoke(self, "toCreateGrant", []))

    @jsii.member(jsii_name="toCreateKey")
    def to_create_key(self) -> "Kms":
        '''(experimental) Controls permission to create an AWS KMS key that can be used to protect data keys and other sensitive information.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()
        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifBypassPolicyLockoutSafetyCheck()
        - .ifCallerAccount()
        - .ifKeySpec()
        - .ifKeyUsage()
        - .ifKeyOrigin()
        - .ifMultiRegion()
        - .ifMultiRegionKeyType()
        - .ifViaService()

        Dependent actions:

        - iam:CreateServiceLinkedRole
        - kms:PutKeyPolicy
        - kms:TagResource

        https://docs.aws.amazon.com/kms/latest/APIReference/API_CreateKey.html

        :stability: experimental
        '''
        return typing.cast("Kms", jsii.invoke(self, "toCreateKey", []))

    @jsii.member(jsii_name="toDecrypt")
    def to_decrypt(self) -> "Kms":
        '''(experimental) Controls permission to decrypt ciphertext that was encrypted under an AWS KMS key.

        Access Level: Write

        Possible conditions:

        - .ifCallerAccount()
        - .ifEncryptionAlgorithm()
        - .ifEncryptionContext()
        - .ifEncryptionContextKeys()
        - .ifRecipientAttestation()
        - .ifRequestAlias()
        - .ifViaService()

        https://docs.aws.amazon.com/kms/latest/APIReference/API_Decrypt.html

        :stability: experimental
        '''
        return typing.cast("Kms", jsii.invoke(self, "toDecrypt", []))

    @jsii.member(jsii_name="toDeleteAlias")
    def to_delete_alias(self) -> "Kms":
        '''(experimental) Controls permission to delete an alias. Aliases are optional friendly names that you can associate with AWS KMS keys.

        Access Level: Write

        Possible conditions:

        - .ifCallerAccount()
        - .ifViaService()

        https://docs.aws.amazon.com/kms/latest/APIReference/API_DeleteAlias.html

        :stability: experimental
        '''
        return typing.cast("Kms", jsii.invoke(self, "toDeleteAlias", []))

    @jsii.member(jsii_name="toDeleteCustomKeyStore")
    def to_delete_custom_key_store(self) -> "Kms":
        '''(experimental) Controls permission to delete a custom key store.

        Access Level: Write

        Possible conditions:

        - .ifCallerAccount()

        https://docs.aws.amazon.com/kms/latest/APIReference/API_DeleteCustomKeyStore.html

        :stability: experimental
        '''
        return typing.cast("Kms", jsii.invoke(self, "toDeleteCustomKeyStore", []))

    @jsii.member(jsii_name="toDeleteImportedKeyMaterial")
    def to_delete_imported_key_material(self) -> "Kms":
        '''(experimental) Controls permission to delete cryptographic material that you imported into an AWS KMS key.

        This action makes the key unusable

        Access Level: Write

        Possible conditions:

        - .ifCallerAccount()
        - .ifViaService()

        https://docs.aws.amazon.com/kms/latest/APIReference/API_DeleteImportedKeyMaterial.html

        :stability: experimental
        '''
        return typing.cast("Kms", jsii.invoke(self, "toDeleteImportedKeyMaterial", []))

    @jsii.member(jsii_name="toDescribeCustomKeyStores")
    def to_describe_custom_key_stores(self) -> "Kms":
        '''(experimental) Controls permission to view detailed information about custom key stores in the account and region.

        Access Level: Read

        Possible conditions:

        - .ifCallerAccount()

        https://docs.aws.amazon.com/kms/latest/APIReference/API_DescribeCustomKeyStores.html

        :stability: experimental
        '''
        return typing.cast("Kms", jsii.invoke(self, "toDescribeCustomKeyStores", []))

    @jsii.member(jsii_name="toDescribeKey")
    def to_describe_key(self) -> "Kms":
        '''(experimental) Controls permission to view detailed information about an AWS KMS key.

        Access Level: Read

        Possible conditions:

        - .ifCallerAccount()
        - .ifRequestAlias()
        - .ifViaService()

        https://docs.aws.amazon.com/kms/latest/APIReference/API_DescribeKey.html

        :stability: experimental
        '''
        return typing.cast("Kms", jsii.invoke(self, "toDescribeKey", []))

    @jsii.member(jsii_name="toDisableKey")
    def to_disable_key(self) -> "Kms":
        '''(experimental) Controls permission to disable an AWS KMS key, which prevents it from being used in cryptographic operations.

        Access Level: Write

        Possible conditions:

        - .ifCallerAccount()
        - .ifViaService()

        https://docs.aws.amazon.com/kms/latest/APIReference/API_DisableKey.html

        :stability: experimental
        '''
        return typing.cast("Kms", jsii.invoke(self, "toDisableKey", []))

    @jsii.member(jsii_name="toDisableKeyRotation")
    def to_disable_key_rotation(self) -> "Kms":
        '''(experimental) Controls permission to disable automatic rotation of a customer managed AWS KMS key.

        Access Level: Write

        Possible conditions:

        - .ifCallerAccount()
        - .ifViaService()

        https://docs.aws.amazon.com/kms/latest/APIReference/API_DisableKeyRotation.html

        :stability: experimental
        '''
        return typing.cast("Kms", jsii.invoke(self, "toDisableKeyRotation", []))

    @jsii.member(jsii_name="toDisconnectCustomKeyStore")
    def to_disconnect_custom_key_store(self) -> "Kms":
        '''(experimental) Controls permission to disconnect the custom key store from its associated AWS CloudHSM cluster.

        Access Level: Write

        Possible conditions:

        - .ifCallerAccount()

        https://docs.aws.amazon.com/kms/latest/APIReference/API_DisconnectCustomKeyStore.html

        :stability: experimental
        '''
        return typing.cast("Kms", jsii.invoke(self, "toDisconnectCustomKeyStore", []))

    @jsii.member(jsii_name="toEnableKey")
    def to_enable_key(self) -> "Kms":
        '''(experimental) Controls permission to change the state of an AWS KMS key to enabled.

        This allows the KMS key to be used in cryptographic operations

        Access Level: Write

        Possible conditions:

        - .ifCallerAccount()
        - .ifViaService()

        https://docs.aws.amazon.com/kms/latest/APIReference/API_EnableKey.html

        :stability: experimental
        '''
        return typing.cast("Kms", jsii.invoke(self, "toEnableKey", []))

    @jsii.member(jsii_name="toEnableKeyRotation")
    def to_enable_key_rotation(self) -> "Kms":
        '''(experimental) Controls permission to enable automatic rotation of the cryptographic material in an AWS KMS key.

        Access Level: Write

        Possible conditions:

        - .ifCallerAccount()
        - .ifViaService()

        https://docs.aws.amazon.com/kms/latest/APIReference/API_EnableKeyRotation.html

        :stability: experimental
        '''
        return typing.cast("Kms", jsii.invoke(self, "toEnableKeyRotation", []))

    @jsii.member(jsii_name="toEncrypt")
    def to_encrypt(self) -> "Kms":
        '''(experimental) Controls permission to use the specified AWS KMS key to encrypt data and data keys.

        Access Level: Write

        Possible conditions:

        - .ifCallerAccount()
        - .ifEncryptionAlgorithm()
        - .ifEncryptionContext()
        - .ifEncryptionContextKeys()
        - .ifRequestAlias()
        - .ifViaService()

        https://docs.aws.amazon.com/kms/latest/APIReference/API_Encrypt.html

        :stability: experimental
        '''
        return typing.cast("Kms", jsii.invoke(self, "toEncrypt", []))

    @jsii.member(jsii_name="toGenerateDataKey")
    def to_generate_data_key(self) -> "Kms":
        '''(experimental) Controls permission to use the AWS KMS key to generate data keys.

        You can use the data keys to encrypt data outside of AWS KMS

        Access Level: Write

        Possible conditions:

        - .ifCallerAccount()
        - .ifEncryptionAlgorithm()
        - .ifEncryptionContext()
        - .ifEncryptionContextKeys()
        - .ifRecipientAttestation()
        - .ifRequestAlias()
        - .ifViaService()

        https://docs.aws.amazon.com/kms/latest/APIReference/API_GenerateDataKey.html

        :stability: experimental
        '''
        return typing.cast("Kms", jsii.invoke(self, "toGenerateDataKey", []))

    @jsii.member(jsii_name="toGenerateDataKeyPair")
    def to_generate_data_key_pair(self) -> "Kms":
        '''(experimental) Controls permission to use the AWS KMS key to generate data key pairs.

        Access Level: Write

        Possible conditions:

        - .ifCallerAccount()
        - .ifDataKeyPairSpec()
        - .ifEncryptionAlgorithm()
        - .ifEncryptionContext()
        - .ifEncryptionContextKeys()
        - .ifRequestAlias()
        - .ifViaService()

        https://docs.aws.amazon.com/kms/latest/APIReference/API_GenerateDataKeyPair.html

        :stability: experimental
        '''
        return typing.cast("Kms", jsii.invoke(self, "toGenerateDataKeyPair", []))

    @jsii.member(jsii_name="toGenerateDataKeyPairWithoutPlaintext")
    def to_generate_data_key_pair_without_plaintext(self) -> "Kms":
        '''(experimental) Controls permission to use the AWS KMS key to generate data key pairs.

        Unlike the GenerateDataKeyPair operation, this operation returns an encrypted private key without a plaintext copy

        Access Level: Write

        Possible conditions:

        - .ifCallerAccount()
        - .ifDataKeyPairSpec()
        - .ifEncryptionAlgorithm()
        - .ifEncryptionContext()
        - .ifEncryptionContextKeys()
        - .ifRequestAlias()
        - .ifViaService()

        https://docs.aws.amazon.com/kms/latest/APIReference/API_GenerateDataKeyPairWithoutPlaintext.html

        :stability: experimental
        '''
        return typing.cast("Kms", jsii.invoke(self, "toGenerateDataKeyPairWithoutPlaintext", []))

    @jsii.member(jsii_name="toGenerateDataKeyWithoutPlaintext")
    def to_generate_data_key_without_plaintext(self) -> "Kms":
        '''(experimental) Controls permission to use the AWS KMS key to generate a data key.

        Unlike the GenerateDataKey operation, this operation returns an encrypted data key without a plaintext version of the data key

        Access Level: Write

        Possible conditions:

        - .ifCallerAccount()
        - .ifEncryptionAlgorithm()
        - .ifEncryptionContext()
        - .ifEncryptionContextKeys()
        - .ifRequestAlias()
        - .ifViaService()

        https://docs.aws.amazon.com/kms/latest/APIReference/API_GenerateDataKeyWithoutPlaintext.html

        :stability: experimental
        '''
        return typing.cast("Kms", jsii.invoke(self, "toGenerateDataKeyWithoutPlaintext", []))

    @jsii.member(jsii_name="toGenerateMac")
    def to_generate_mac(self) -> "Kms":
        '''(experimental) Controls permission to use the AWS KMS key to generate message authentication codes.

        Access Level: Write

        Possible conditions:

        - .ifCallerAccount()
        - .ifMacAlgorithm()
        - .ifRequestAlias()
        - .ifViaService()

        https://docs.aws.amazon.com/kms/latest/APIReference/API_GenerateMac.html

        :stability: experimental
        '''
        return typing.cast("Kms", jsii.invoke(self, "toGenerateMac", []))

    @jsii.member(jsii_name="toGenerateRandom")
    def to_generate_random(self) -> "Kms":
        '''(experimental) Controls permission to get a cryptographically secure random byte string from AWS KMS.

        Access Level: Write

        Possible conditions:

        - .ifRecipientAttestation()

        https://docs.aws.amazon.com/kms/latest/APIReference/API_GenerateRandom.html

        :stability: experimental
        '''
        return typing.cast("Kms", jsii.invoke(self, "toGenerateRandom", []))

    @jsii.member(jsii_name="toGetKeyPolicy")
    def to_get_key_policy(self) -> "Kms":
        '''(experimental) Controls permission to view the key policy for the specified AWS KMS key.

        Access Level: Read

        Possible conditions:

        - .ifCallerAccount()
        - .ifViaService()

        https://docs.aws.amazon.com/kms/latest/APIReference/API_GetKeyPolicy.html

        :stability: experimental
        '''
        return typing.cast("Kms", jsii.invoke(self, "toGetKeyPolicy", []))

    @jsii.member(jsii_name="toGetKeyRotationStatus")
    def to_get_key_rotation_status(self) -> "Kms":
        '''(experimental) Controls permission to determine whether automatic key rotation is enabled on the AWS KMS key.

        Access Level: Read

        Possible conditions:

        - .ifCallerAccount()
        - .ifViaService()

        https://docs.aws.amazon.com/kms/latest/APIReference/API_GetKeyRotationStatus.html

        :stability: experimental
        '''
        return typing.cast("Kms", jsii.invoke(self, "toGetKeyRotationStatus", []))

    @jsii.member(jsii_name="toGetParametersForImport")
    def to_get_parameters_for_import(self) -> "Kms":
        '''(experimental) Controls permission to get data that is required to import cryptographic material into a customer managed key, including a public key and import token.

        Access Level: Read

        Possible conditions:

        - .ifCallerAccount()
        - .ifViaService()
        - .ifWrappingAlgorithm()
        - .ifWrappingKeySpec()

        https://docs.aws.amazon.com/kms/latest/APIReference/API_GetParametersForImport.html

        :stability: experimental
        '''
        return typing.cast("Kms", jsii.invoke(self, "toGetParametersForImport", []))

    @jsii.member(jsii_name="toGetPublicKey")
    def to_get_public_key(self) -> "Kms":
        '''(experimental) Controls permission to download the public key of an asymmetric AWS KMS key.

        Access Level: Read

        Possible conditions:

        - .ifCallerAccount()
        - .ifRequestAlias()
        - .ifViaService()

        https://docs.aws.amazon.com/kms/latest/APIReference/API_GetPublicKey.html

        :stability: experimental
        '''
        return typing.cast("Kms", jsii.invoke(self, "toGetPublicKey", []))

    @jsii.member(jsii_name="toImportKeyMaterial")
    def to_import_key_material(self) -> "Kms":
        '''(experimental) Controls permission to import cryptographic material into an AWS KMS key.

        Access Level: Write

        Possible conditions:

        - .ifCallerAccount()
        - .ifExpirationModel()
        - .ifValidTo()
        - .ifViaService()

        https://docs.aws.amazon.com/kms/latest/APIReference/API_ImportKeyMaterial.html

        :stability: experimental
        '''
        return typing.cast("Kms", jsii.invoke(self, "toImportKeyMaterial", []))

    @jsii.member(jsii_name="toListAliases")
    def to_list_aliases(self) -> "Kms":
        '''(experimental) Controls permission to view the aliases that are defined in the account.

        Aliases are optional friendly names that you can associate with AWS KMS keys

        Access Level: List

        https://docs.aws.amazon.com/kms/latest/APIReference/API_ListAliases.html

        :stability: experimental
        '''
        return typing.cast("Kms", jsii.invoke(self, "toListAliases", []))

    @jsii.member(jsii_name="toListGrants")
    def to_list_grants(self) -> "Kms":
        '''(experimental) Controls permission to view all grants for an AWS KMS key.

        Access Level: List

        Possible conditions:

        - .ifCallerAccount()
        - .ifGrantIsForAWSResource()
        - .ifViaService()

        https://docs.aws.amazon.com/kms/latest/APIReference/API_ListGrants.html

        :stability: experimental
        '''
        return typing.cast("Kms", jsii.invoke(self, "toListGrants", []))

    @jsii.member(jsii_name="toListKeyPolicies")
    def to_list_key_policies(self) -> "Kms":
        '''(experimental) Controls permission to view the names of key policies for an AWS KMS key.

        Access Level: List

        Possible conditions:

        - .ifCallerAccount()
        - .ifViaService()

        https://docs.aws.amazon.com/kms/latest/APIReference/API_ListKeyPolicies.html

        :stability: experimental
        '''
        return typing.cast("Kms", jsii.invoke(self, "toListKeyPolicies", []))

    @jsii.member(jsii_name="toListKeys")
    def to_list_keys(self) -> "Kms":
        '''(experimental) Controls permission to view the key ID and Amazon Resource Name (ARN) of all AWS KMS keys in the account.

        Access Level: List

        https://docs.aws.amazon.com/kms/latest/APIReference/API_ListKeys.html

        :stability: experimental
        '''
        return typing.cast("Kms", jsii.invoke(self, "toListKeys", []))

    @jsii.member(jsii_name="toListResourceTags")
    def to_list_resource_tags(self) -> "Kms":
        '''(experimental) Controls permission to view all tags that are attached to an AWS KMS key.

        Access Level: List

        Possible conditions:

        - .ifCallerAccount()
        - .ifViaService()

        https://docs.aws.amazon.com/kms/latest/APIReference/API_ListResourceTags.html

        :stability: experimental
        '''
        return typing.cast("Kms", jsii.invoke(self, "toListResourceTags", []))

    @jsii.member(jsii_name="toListRetirableGrants")
    def to_list_retirable_grants(self) -> "Kms":
        '''(experimental) Controls permission to view grants in which the specified principal is the retiring principal.

        Other principals might be able to retire the grant and this principal might be able to retire other grants

        Access Level: List

        https://docs.aws.amazon.com/kms/latest/APIReference/API_ListRetirableGrants.html

        :stability: experimental
        '''
        return typing.cast("Kms", jsii.invoke(self, "toListRetirableGrants", []))

    @jsii.member(jsii_name="toPutKeyPolicy")
    def to_put_key_policy(self) -> "Kms":
        '''(experimental) Controls permission to replace the key policy for the specified AWS KMS key.

        Access Level: Permissions management

        Possible conditions:

        - .ifBypassPolicyLockoutSafetyCheck()
        - .ifCallerAccount()
        - .ifViaService()

        https://docs.aws.amazon.com/kms/latest/APIReference/API_PutKeyPolicy.html

        :stability: experimental
        '''
        return typing.cast("Kms", jsii.invoke(self, "toPutKeyPolicy", []))

    @jsii.member(jsii_name="toReEncryptFrom")
    def to_re_encrypt_from(self) -> "Kms":
        '''(experimental) Controls permission to decrypt data as part of the process that decrypts and reencrypts the data within AWS KMS.

        Access Level: Write

        Possible conditions:

        - .ifCallerAccount()
        - .ifEncryptionAlgorithm()
        - .ifEncryptionContext()
        - .ifEncryptionContextKeys()
        - .ifReEncryptOnSameKey()
        - .ifRequestAlias()
        - .ifViaService()

        https://docs.aws.amazon.com/kms/latest/APIReference/API_ReEncrypt.html

        :stability: experimental
        '''
        return typing.cast("Kms", jsii.invoke(self, "toReEncryptFrom", []))

    @jsii.member(jsii_name="toReEncryptTo")
    def to_re_encrypt_to(self) -> "Kms":
        '''(experimental) Controls permission to encrypt data as part of the process that decrypts and reencrypts the data within AWS KMS.

        Access Level: Write

        Possible conditions:

        - .ifCallerAccount()
        - .ifEncryptionAlgorithm()
        - .ifEncryptionContext()
        - .ifEncryptionContextKeys()
        - .ifReEncryptOnSameKey()
        - .ifRequestAlias()
        - .ifViaService()

        https://docs.aws.amazon.com/kms/latest/APIReference/API_ReEncrypt.html

        :stability: experimental
        '''
        return typing.cast("Kms", jsii.invoke(self, "toReEncryptTo", []))

    @jsii.member(jsii_name="toReplicateKey")
    def to_replicate_key(self) -> "Kms":
        '''(experimental) Controls permission to replicate a multi-Region primary key.

        Access Level: Write

        Possible conditions:

        - .ifCallerAccount()
        - .ifReplicaRegion()
        - .ifViaService()

        Dependent actions:

        - iam:CreateServiceLinkedRole
        - kms:CreateKey
        - kms:PutKeyPolicy
        - kms:TagResource

        https://docs.aws.amazon.com/kms/latest/APIReference/API_ReplicateKey.html

        :stability: experimental
        '''
        return typing.cast("Kms", jsii.invoke(self, "toReplicateKey", []))

    @jsii.member(jsii_name="toRetireGrant")
    def to_retire_grant(self) -> "Kms":
        '''(experimental) Controls permission to retire a grant.

        The RetireGrant operation is typically called by the grant user after they complete the tasks that the grant allowed them to perform

        Access Level: Permissions management

        https://docs.aws.amazon.com/kms/latest/APIReference/API_RetireGrant.html

        :stability: experimental
        '''
        return typing.cast("Kms", jsii.invoke(self, "toRetireGrant", []))

    @jsii.member(jsii_name="toRevokeGrant")
    def to_revoke_grant(self) -> "Kms":
        '''(experimental) Controls permission to revoke a grant, which denies permission for all operations that depend on the grant.

        Access Level: Permissions management

        Possible conditions:

        - .ifCallerAccount()
        - .ifGrantIsForAWSResource()
        - .ifViaService()

        https://docs.aws.amazon.com/kms/latest/APIReference/API_RevokeGrant.html

        :stability: experimental
        '''
        return typing.cast("Kms", jsii.invoke(self, "toRevokeGrant", []))

    @jsii.member(jsii_name="toScheduleKeyDeletion")
    def to_schedule_key_deletion(self) -> "Kms":
        '''(experimental) Controls permission to schedule deletion of an AWS KMS key.

        Access Level: Write

        Possible conditions:

        - .ifCallerAccount()
        - .ifViaService()

        https://docs.aws.amazon.com/kms/latest/APIReference/API_ScheduleKeyDeletion.html

        :stability: experimental
        '''
        return typing.cast("Kms", jsii.invoke(self, "toScheduleKeyDeletion", []))

    @jsii.member(jsii_name="toSign")
    def to_sign(self) -> "Kms":
        '''(experimental) Controls permission to produce a digital signature for a message.

        Access Level: Write

        Possible conditions:

        - .ifCallerAccount()
        - .ifMessageType()
        - .ifRequestAlias()
        - .ifSigningAlgorithm()
        - .ifViaService()

        https://docs.aws.amazon.com/kms/latest/APIReference/API_Sign.html

        :stability: experimental
        '''
        return typing.cast("Kms", jsii.invoke(self, "toSign", []))

    @jsii.member(jsii_name="toSynchronizeMultiRegionKey")
    def to_synchronize_multi_region_key(self) -> "Kms":
        '''(experimental) Controls access to internal APIs that synchronize multi-Region keys.

        Access Level: Write

        https://docs.aws.amazon.com/kms/latest/developerguide/multi-region-keys-auth.html#multi-region-auth-slr

        :stability: experimental
        '''
        return typing.cast("Kms", jsii.invoke(self, "toSynchronizeMultiRegionKey", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Kms":
        '''(experimental) Controls permission to create or update tags that are attached to an AWS KMS key.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifCallerAccount()
        - .ifViaService()

        https://docs.aws.amazon.com/kms/latest/APIReference/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("Kms", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Kms":
        '''(experimental) Controls permission to delete tags that are attached to an AWS KMS key.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifCallerAccount()
        - .ifViaService()

        https://docs.aws.amazon.com/kms/latest/APIReference/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("Kms", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateAlias")
    def to_update_alias(self) -> "Kms":
        '''(experimental) Controls permission to associate an alias with a different AWS KMS key.

        An alias is an optional friendly name that you can associate with a KMS key

        Access Level: Write

        Possible conditions:

        - .ifCallerAccount()
        - .ifViaService()

        https://docs.aws.amazon.com/kms/latest/APIReference/API_UpdateAlias.html

        :stability: experimental
        '''
        return typing.cast("Kms", jsii.invoke(self, "toUpdateAlias", []))

    @jsii.member(jsii_name="toUpdateCustomKeyStore")
    def to_update_custom_key_store(self) -> "Kms":
        '''(experimental) Controls permission to change the properties of a custom key store.

        Access Level: Write

        Possible conditions:

        - .ifCallerAccount()

        https://docs.aws.amazon.com/kms/latest/APIReference/API_UpdateCustomKeyStore.html

        :stability: experimental
        '''
        return typing.cast("Kms", jsii.invoke(self, "toUpdateCustomKeyStore", []))

    @jsii.member(jsii_name="toUpdateKeyDescription")
    def to_update_key_description(self) -> "Kms":
        '''(experimental) Controls permission to delete or change the description of an AWS KMS key.

        Access Level: Write

        Possible conditions:

        - .ifCallerAccount()
        - .ifViaService()

        https://docs.aws.amazon.com/kms/latest/APIReference/API_UpdateKeyDescription.html

        :stability: experimental
        '''
        return typing.cast("Kms", jsii.invoke(self, "toUpdateKeyDescription", []))

    @jsii.member(jsii_name="toUpdatePrimaryRegion")
    def to_update_primary_region(self) -> "Kms":
        '''(experimental) Controls permission to update the primary Region of a multi-Region primary key.

        Access Level: Write

        Possible conditions:

        - .ifCallerAccount()
        - .ifPrimaryRegion()
        - .ifViaService()

        https://docs.aws.amazon.com/kms/latest/APIReference/API_UpdatePrimaryRegion.html

        :stability: experimental
        '''
        return typing.cast("Kms", jsii.invoke(self, "toUpdatePrimaryRegion", []))

    @jsii.member(jsii_name="toVerify")
    def to_verify(self) -> "Kms":
        '''(experimental) Controls permission to use the specified AWS KMS key to verify digital signatures.

        Access Level: Write

        Possible conditions:

        - .ifCallerAccount()
        - .ifMessageType()
        - .ifRequestAlias()
        - .ifSigningAlgorithm()
        - .ifViaService()

        https://docs.aws.amazon.com/kms/latest/APIReference/API_Verify.html

        :stability: experimental
        '''
        return typing.cast("Kms", jsii.invoke(self, "toVerify", []))

    @jsii.member(jsii_name="toVerifyMac")
    def to_verify_mac(self) -> "Kms":
        '''(experimental) Controls permission to use the AWS KMS key to verify message authentication codes.

        Access Level: Write

        Possible conditions:

        - .ifCallerAccount()
        - .ifMacAlgorithm()
        - .ifRequestAlias()
        - .ifViaService()

        https://docs.aws.amazon.com/kms/latest/APIReference/API_VerifyMac.html

        :stability: experimental
        '''
        return typing.cast("Kms", jsii.invoke(self, "toVerifyMac", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__557b4124a80534680bcfa1a43bbe9e0445f21cd5177c2a70941f31860edb7d79)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__20cf584aa788f30d056fd8c602dbc54b1163e1f26d707e4edbf96028efd6ab81)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Lakeformation(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Lakeformation",
):
    '''(experimental) Statement provider for service `lakeformation <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awslakeformation.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `lakeformation <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awslakeformation.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="toAddLFTagsToResource")
    def to_add_lf_tags_to_resource(self) -> "Lakeformation":
        '''(experimental) Grants permission to attach Lake Formation tags to catalog resources.

        Access Level: Tagging

        https://docs.aws.amazon.com/lake-formation/latest/dg/aws-lake-formation-api-tagging-api.html#aws-lake-formation-api-tagging-api-AddLFTagsToResource

        :stability: experimental
        '''
        return typing.cast("Lakeformation", jsii.invoke(self, "toAddLFTagsToResource", []))

    @jsii.member(jsii_name="toBatchGrantPermissions")
    def to_batch_grant_permissions(self) -> "Lakeformation":
        '''(experimental) Grants permission to data lake permissions to one or more principals in a batch.

        Access Level: Permissions management

        https://docs.aws.amazon.com/lake-formation/latest/dg/aws-lake-formation-api-tagging-api.html#aws-lake-formation-api-tagging-api-BatchGrantPermissions

        :stability: experimental
        '''
        return typing.cast("Lakeformation", jsii.invoke(self, "toBatchGrantPermissions", []))

    @jsii.member(jsii_name="toBatchRevokePermissions")
    def to_batch_revoke_permissions(self) -> "Lakeformation":
        '''(experimental) Grants permission to revoke data lake permissions from one or more principals in a batch.

        Access Level: Permissions management

        https://docs.aws.amazon.com/lake-formation/latest/dg/aws-lake-formation-api-tagging-api.html#aws-lake-formation-api-tagging-api-BatchRevokePermissions

        :stability: experimental
        '''
        return typing.cast("Lakeformation", jsii.invoke(self, "toBatchRevokePermissions", []))

    @jsii.member(jsii_name="toCancelTransaction")
    def to_cancel_transaction(self) -> "Lakeformation":
        '''(experimental) Grants permission to cancel the given transaction.

        Access Level: Write

        https://docs.aws.amazon.com/lake-formation/latest/dg/aws-lake-formation-api-transactions-api.html#aws-lake-formation-api-transactions-api-CancelTransaction

        :stability: experimental
        '''
        return typing.cast("Lakeformation", jsii.invoke(self, "toCancelTransaction", []))

    @jsii.member(jsii_name="toCommitTransaction")
    def to_commit_transaction(self) -> "Lakeformation":
        '''(experimental) Grants permission to commit the given transaction.

        Access Level: Write

        https://docs.aws.amazon.com/lake-formation/latest/dg/aws-lake-formation-api-transactions-api.html#aws-lake-formation-api-transactions-api-CommitTransaction

        :stability: experimental
        '''
        return typing.cast("Lakeformation", jsii.invoke(self, "toCommitTransaction", []))

    @jsii.member(jsii_name="toCreateDataCellsFilter")
    def to_create_data_cells_filter(self) -> "Lakeformation":
        '''(experimental) Grants permission to create a Lake Formation data cell filter.

        Access Level: Write

        https://docs.aws.amazon.com/lake-formation/latest/dg/aws-lake-formation-api-data-filter.html#aws-lake-formation-api-data-filter-CreateDataCellsFilter

        :stability: experimental
        '''
        return typing.cast("Lakeformation", jsii.invoke(self, "toCreateDataCellsFilter", []))

    @jsii.member(jsii_name="toCreateLFTag")
    def to_create_lf_tag(self) -> "Lakeformation":
        '''(experimental) Grants permission to create a Lake Formation tag.

        Access Level: Write

        https://docs.aws.amazon.com/lake-formation/latest/dg/aws-lake-formation-api-tagging-api.html#aws-lake-formation-api-tagging-api-CreateLFTag

        :stability: experimental
        '''
        return typing.cast("Lakeformation", jsii.invoke(self, "toCreateLFTag", []))

    @jsii.member(jsii_name="toDeleteDataCellsFilter")
    def to_delete_data_cells_filter(self) -> "Lakeformation":
        '''(experimental) Grants permission to delete a Lake Formation data cell filter.

        Access Level: Write

        https://docs.aws.amazon.com/lake-formation/latest/dg/aws-lake-formation-api-data-filter.html#aws-lake-formation-api-data-filter-DeleteDataCellsFilter

        :stability: experimental
        '''
        return typing.cast("Lakeformation", jsii.invoke(self, "toDeleteDataCellsFilter", []))

    @jsii.member(jsii_name="toDeleteLFTag")
    def to_delete_lf_tag(self) -> "Lakeformation":
        '''(experimental) Grants permission to delete a Lake Formation tag.

        Access Level: Write

        https://docs.aws.amazon.com/lake-formation/latest/dg/aws-lake-formation-api-tagging-api.html#aws-lake-formation-api-tagging-api-DeleteLFTag

        :stability: experimental
        '''
        return typing.cast("Lakeformation", jsii.invoke(self, "toDeleteLFTag", []))

    @jsii.member(jsii_name="toDeleteObjectsOnCancel")
    def to_delete_objects_on_cancel(self) -> "Lakeformation":
        '''(experimental) Grants permission to delete the specified objects if the transaction is canceled.

        Access Level: Write

        https://docs.aws.amazon.com/lake-formation/latest/dg/aws-lake-formation-api-transactions-api.html#aws-lake-formation-api-transactions-api-DeleteObjectsOnCancel

        :stability: experimental
        '''
        return typing.cast("Lakeformation", jsii.invoke(self, "toDeleteObjectsOnCancel", []))

    @jsii.member(jsii_name="toDeregisterResource")
    def to_deregister_resource(self) -> "Lakeformation":
        '''(experimental) Grants permission to deregister a registered location.

        Access Level: Write

        https://docs.aws.amazon.com/lake-formation/latest/dg/aws-lake-formation-api-tagging-api.html#aws-lake-formation-api-tagging-api-DeregisterResource

        :stability: experimental
        '''
        return typing.cast("Lakeformation", jsii.invoke(self, "toDeregisterResource", []))

    @jsii.member(jsii_name="toDescribeResource")
    def to_describe_resource(self) -> "Lakeformation":
        '''(experimental) Grants permission to describe a registered location.

        Access Level: Read

        https://docs.aws.amazon.com/lake-formation/latest/dg/aws-lake-formation-api-tagging-api.html#aws-lake-formation-api-tagging-api-DescribeResource

        :stability: experimental
        '''
        return typing.cast("Lakeformation", jsii.invoke(self, "toDescribeResource", []))

    @jsii.member(jsii_name="toDescribeTransaction")
    def to_describe_transaction(self) -> "Lakeformation":
        '''(experimental) Grants permission to get status of the given transaction.

        Access Level: Read

        https://docs.aws.amazon.com/lake-formation/latest/dg/aws-lake-formation-api-transactions-api.html#aws-lake-formation-api-transactions-api-DescribeTransaction

        :stability: experimental
        '''
        return typing.cast("Lakeformation", jsii.invoke(self, "toDescribeTransaction", []))

    @jsii.member(jsii_name="toExtendTransaction")
    def to_extend_transaction(self) -> "Lakeformation":
        '''(experimental) Grants permission to extend the timeout of the given transaction.

        Access Level: Write

        https://docs.aws.amazon.com/lake-formation/latest/dg/aws-lake-formation-api-transactions-api.html#aws-lake-formation-api-transactions-api-ExtendTransaction

        :stability: experimental
        '''
        return typing.cast("Lakeformation", jsii.invoke(self, "toExtendTransaction", []))

    @jsii.member(jsii_name="toGetDataAccess")
    def to_get_data_access(self) -> "Lakeformation":
        '''(experimental) Grants permission to virtual data lake access.

        Access Level: Write

        https://docs.aws.amazon.com/lake-formation/latest/dg/aws-lake-formation-api-tagging-api.html#aws-lake-formation-api-tagging-api-GetDataAccess

        :stability: experimental
        '''
        return typing.cast("Lakeformation", jsii.invoke(self, "toGetDataAccess", []))

    @jsii.member(jsii_name="toGetDataLakeSettings")
    def to_get_data_lake_settings(self) -> "Lakeformation":
        '''(experimental) Grants permission to retrieve data lake settings such as the list of data lake administrators and database and table default permissions.

        Access Level: Read

        https://docs.aws.amazon.com/lake-formation/latest/dg/aws-lake-formation-api-tagging-api.html#aws-lake-formation-api-tagging-api-GetDataLakeSettings

        :stability: experimental
        '''
        return typing.cast("Lakeformation", jsii.invoke(self, "toGetDataLakeSettings", []))

    @jsii.member(jsii_name="toGetEffectivePermissionsForPath")
    def to_get_effective_permissions_for_path(self) -> "Lakeformation":
        '''(experimental) Grants permission to retrieve permissions attached to resources in the given path.

        Access Level: Read

        https://docs.aws.amazon.com/lake-formation/latest/dg/aws-lake-formation-api-tagging-api.html#aws-lake-formation-api-tagging-api-GetEffectivePermissionsForPath

        :stability: experimental
        '''
        return typing.cast("Lakeformation", jsii.invoke(self, "toGetEffectivePermissionsForPath", []))

    @jsii.member(jsii_name="toGetLFTag")
    def to_get_lf_tag(self) -> "Lakeformation":
        '''(experimental) Grants permission to retrieve a Lake Formation tag.

        Access Level: Read

        https://docs.aws.amazon.com/lake-formation/latest/dg/aws-lake-formation-api-tagging-api.html#aws-lake-formation-api-tagging-api-GetLFTag

        :stability: experimental
        '''
        return typing.cast("Lakeformation", jsii.invoke(self, "toGetLFTag", []))

    @jsii.member(jsii_name="toGetQueryState")
    def to_get_query_state(self) -> "Lakeformation":
        '''(experimental) Grants permission to retrieve the state of the given query.

        Access Level: Read

        Dependent actions:

        - lakeformation:StartQueryPlanning

        https://docs.aws.amazon.com/lake-formation/latest/dg/aws-lake-formation-api-querying.html#aws-lake-formation-api-querying-GetQueryState

        :stability: experimental
        '''
        return typing.cast("Lakeformation", jsii.invoke(self, "toGetQueryState", []))

    @jsii.member(jsii_name="toGetQueryStatistics")
    def to_get_query_statistics(self) -> "Lakeformation":
        '''(experimental) Grants permission to retrieve the statistics for the given query.

        Access Level: Read

        Dependent actions:

        - lakeformation:StartQueryPlanning

        https://docs.aws.amazon.com/lake-formation/latest/dg/aws-lake-formation-api-querying.html#aws-lake-formation-api-querying-GetQueryStatistics

        :stability: experimental
        '''
        return typing.cast("Lakeformation", jsii.invoke(self, "toGetQueryStatistics", []))

    @jsii.member(jsii_name="toGetResourceLFTags")
    def to_get_resource_lf_tags(self) -> "Lakeformation":
        '''(experimental) Grants permission to retrieve lakeformation tags on a catalog resource.

        Access Level: Read

        https://docs.aws.amazon.com/lake-formation/latest/dg/aws-lake-formation-api-tagging-api.html#aws-lake-formation-api-tagging-api-GetResourceLFTags

        :stability: experimental
        '''
        return typing.cast("Lakeformation", jsii.invoke(self, "toGetResourceLFTags", []))

    @jsii.member(jsii_name="toGetTableObjects")
    def to_get_table_objects(self) -> "Lakeformation":
        '''(experimental) Grants permission to retrieve objects from a table.

        Access Level: Read

        https://docs.aws.amazon.com/lake-formation/latest/dg/aws-lake-formation-api-objects.html#aws-lake-formation-api-objects-GetTableObjects

        :stability: experimental
        '''
        return typing.cast("Lakeformation", jsii.invoke(self, "toGetTableObjects", []))

    @jsii.member(jsii_name="toGetWorkUnitResults")
    def to_get_work_unit_results(self) -> "Lakeformation":
        '''(experimental) Grants permission to retrieve the results for the given work units.

        Access Level: Read

        Dependent actions:

        - lakeformation:GetWorkUnits
        - lakeformation:StartQueryPlanning

        https://docs.aws.amazon.com/lake-formation/latest/dg/aws-lake-formation-api-querying.html#aws-lake-formation-api-querying-GetWorkUnitResults

        :stability: experimental
        '''
        return typing.cast("Lakeformation", jsii.invoke(self, "toGetWorkUnitResults", []))

    @jsii.member(jsii_name="toGetWorkUnits")
    def to_get_work_units(self) -> "Lakeformation":
        '''(experimental) Grants permission to retrieve the work units for the given query.

        Access Level: Read

        Dependent actions:

        - lakeformation:StartQueryPlanning

        https://docs.aws.amazon.com/lake-formation/latest/dg/aws-lake-formation-api-querying.html#aws-lake-formation-api-querying-GetWorkUnits

        :stability: experimental
        '''
        return typing.cast("Lakeformation", jsii.invoke(self, "toGetWorkUnits", []))

    @jsii.member(jsii_name="toGrantPermissions")
    def to_grant_permissions(self) -> "Lakeformation":
        '''(experimental) Grants permission to data lake permissions to a principal.

        Access Level: Permissions management

        https://docs.aws.amazon.com/lake-formation/latest/dg/aws-lake-formation-api-tagging-api.html#aws-lake-formation-api-tagging-api-GrantPermissions

        :stability: experimental
        '''
        return typing.cast("Lakeformation", jsii.invoke(self, "toGrantPermissions", []))

    @jsii.member(jsii_name="toListDataCellsFilter")
    def to_list_data_cells_filter(self) -> "Lakeformation":
        '''(experimental) Grants permission to list cell filters.

        Access Level: List

        https://docs.aws.amazon.com/lake-formation/latest/dg/aws-lake-formation-api-data-filter.html#aws-lake-formation-api-data-filter-ListDataCellsFilter

        :stability: experimental
        '''
        return typing.cast("Lakeformation", jsii.invoke(self, "toListDataCellsFilter", []))

    @jsii.member(jsii_name="toListLFTags")
    def to_list_lf_tags(self) -> "Lakeformation":
        '''(experimental) Grants permission to list Lake Formation tags.

        Access Level: Read

        https://docs.aws.amazon.com/lake-formation/latest/dg/aws-lake-formation-api-tagging-api.html#aws-lake-formation-api-tagging-api-ListLFTags

        :stability: experimental
        '''
        return typing.cast("Lakeformation", jsii.invoke(self, "toListLFTags", []))

    @jsii.member(jsii_name="toListPermissions")
    def to_list_permissions(self) -> "Lakeformation":
        '''(experimental) Grants permission to list permissions filtered by principal or resource.

        Access Level: List

        https://docs.aws.amazon.com/lake-formation/latest/dg/aws-lake-formation-api-tagging-api.html#aws-lake-formation-api-tagging-api-ListPermissions

        :stability: experimental
        '''
        return typing.cast("Lakeformation", jsii.invoke(self, "toListPermissions", []))

    @jsii.member(jsii_name="toListResources")
    def to_list_resources(self) -> "Lakeformation":
        '''(experimental) Grants permission to List registered locations.

        Access Level: List

        https://docs.aws.amazon.com/lake-formation/latest/dg/aws-lake-formation-api-tagging-api.html#aws-lake-formation-api-tagging-api-ListResources

        :stability: experimental
        '''
        return typing.cast("Lakeformation", jsii.invoke(self, "toListResources", []))

    @jsii.member(jsii_name="toListTableStorageOptimizers")
    def to_list_table_storage_optimizers(self) -> "Lakeformation":
        '''(experimental) Grants permission to list all the storage optimizers for the Governed table.

        Access Level: List

        https://docs.aws.amazon.com/lake-formation/latest/dg/aws-lake-formation-api-optimizers.html#aws-lake-formation-api-optimizers-ListTableStorageOptimizers

        :stability: experimental
        '''
        return typing.cast("Lakeformation", jsii.invoke(self, "toListTableStorageOptimizers", []))

    @jsii.member(jsii_name="toListTransactions")
    def to_list_transactions(self) -> "Lakeformation":
        '''(experimental) Grants permission to list all transactions in the system.

        Access Level: List

        https://docs.aws.amazon.com/lake-formation/latest/dg/aws-lake-formation-api-transactions-api.html#aws-lake-formation-api-transactions-api-ListTransactions

        :stability: experimental
        '''
        return typing.cast("Lakeformation", jsii.invoke(self, "toListTransactions", []))

    @jsii.member(jsii_name="toPutDataLakeSettings")
    def to_put_data_lake_settings(self) -> "Lakeformation":
        '''(experimental) Grants permission to overwrite data lake settings such as the list of data lake administrators and database and table default permissions.

        Access Level: Permissions management

        https://docs.aws.amazon.com/lake-formation/latest/dg/aws-lake-formation-api-tagging-api.html#aws-lake-formation-api-tagging-api-PutDataLakeSettings

        :stability: experimental
        '''
        return typing.cast("Lakeformation", jsii.invoke(self, "toPutDataLakeSettings", []))

    @jsii.member(jsii_name="toRegisterResource")
    def to_register_resource(self) -> "Lakeformation":
        '''(experimental) Grants permission to register a new location to be managed by Lake Formation.

        Access Level: Write

        https://docs.aws.amazon.com/lake-formation/latest/dg/aws-lake-formation-api-tagging-api.html#aws-lake-formation-api-tagging-api-RegisterResource

        :stability: experimental
        '''
        return typing.cast("Lakeformation", jsii.invoke(self, "toRegisterResource", []))

    @jsii.member(jsii_name="toRemoveLFTagsFromResource")
    def to_remove_lf_tags_from_resource(self) -> "Lakeformation":
        '''(experimental) Grants permission to remove lakeformation tags from catalog resources.

        Access Level: Tagging

        https://docs.aws.amazon.com/lake-formation/latest/dg/aws-lake-formation-api-tagging-api.html#aws-lake-formation-api-tagging-api-RemoveLFTagsFromResource

        :stability: experimental
        '''
        return typing.cast("Lakeformation", jsii.invoke(self, "toRemoveLFTagsFromResource", []))

    @jsii.member(jsii_name="toRevokePermissions")
    def to_revoke_permissions(self) -> "Lakeformation":
        '''(experimental) Grants permission to revoke data lake permissions from a principal.

        Access Level: Permissions management

        https://docs.aws.amazon.com/lake-formation/latest/dg/aws-lake-formation-api-tagging-api.html#aws-lake-formation-api-tagging-api-RevokePermissions

        :stability: experimental
        '''
        return typing.cast("Lakeformation", jsii.invoke(self, "toRevokePermissions", []))

    @jsii.member(jsii_name="toSearchDatabasesByLFTags")
    def to_search_databases_by_lf_tags(self) -> "Lakeformation":
        '''(experimental) Grants permission to list catalog databases with Lake Formation tags.

        Access Level: Read

        https://docs.aws.amazon.com/lake-formation/latest/dg/aws-lake-formation-api-tagging-api.html#aws-lake-formation-api-tagging-api-SearchDatabasesByLFTags

        :stability: experimental
        '''
        return typing.cast("Lakeformation", jsii.invoke(self, "toSearchDatabasesByLFTags", []))

    @jsii.member(jsii_name="toSearchTablesByLFTags")
    def to_search_tables_by_lf_tags(self) -> "Lakeformation":
        '''(experimental) Grants permission to list catalog tables with Lake Formation tags.

        Access Level: Read

        https://docs.aws.amazon.com/lake-formation/latest/dg/aws-lake-formation-api-tagging-api.html#aws-lake-formation-api-tagging-api-SearchTablesByLFTags

        :stability: experimental
        '''
        return typing.cast("Lakeformation", jsii.invoke(self, "toSearchTablesByLFTags", []))

    @jsii.member(jsii_name="toStartQueryPlanning")
    def to_start_query_planning(self) -> "Lakeformation":
        '''(experimental) Grants permission to initiate the planning of the given query.

        Access Level: Write

        https://docs.aws.amazon.com/lake-formation/latest/dg/aws-lake-formation-api-querying.html#aws-lake-formation-api-querying-StartQueryPlanning

        :stability: experimental
        '''
        return typing.cast("Lakeformation", jsii.invoke(self, "toStartQueryPlanning", []))

    @jsii.member(jsii_name="toStartTransaction")
    def to_start_transaction(self) -> "Lakeformation":
        '''(experimental) Grants permission to start a new transaction.

        Access Level: Write

        https://docs.aws.amazon.com/lake-formation/latest/dg/aws-lake-formation-api-transactions-api.html#aws-lake-formation-api-transactions-api-StartTransaction

        :stability: experimental
        '''
        return typing.cast("Lakeformation", jsii.invoke(self, "toStartTransaction", []))

    @jsii.member(jsii_name="toUpdateLFTag")
    def to_update_lf_tag(self) -> "Lakeformation":
        '''(experimental) Grants permission to update a Lake Formation tag.

        Access Level: Write

        https://docs.aws.amazon.com/lake-formation/latest/dg/aws-lake-formation-api-tagging-api.html#aws-lake-formation-api-tagging-api-UpdateLFTag

        :stability: experimental
        '''
        return typing.cast("Lakeformation", jsii.invoke(self, "toUpdateLFTag", []))

    @jsii.member(jsii_name="toUpdateResource")
    def to_update_resource(self) -> "Lakeformation":
        '''(experimental) Grants permission to update a registered location.

        Access Level: Write

        https://docs.aws.amazon.com/lake-formation/latest/dg/aws-lake-formation-api-tagging-api.html#aws-lake-formation-api-tagging-api-UpdateResource

        :stability: experimental
        '''
        return typing.cast("Lakeformation", jsii.invoke(self, "toUpdateResource", []))

    @jsii.member(jsii_name="toUpdateTableObjects")
    def to_update_table_objects(self) -> "Lakeformation":
        '''(experimental) Grants permission to add or delete the specified objects to or from a table.

        Access Level: Write

        https://docs.aws.amazon.com/lake-formation/latest/dg/aws-lake-formation-api-objects.html#aws-lake-formation-api-objects-UpdateTableObjects

        :stability: experimental
        '''
        return typing.cast("Lakeformation", jsii.invoke(self, "toUpdateTableObjects", []))

    @jsii.member(jsii_name="toUpdateTableStorageOptimizer")
    def to_update_table_storage_optimizer(self) -> "Lakeformation":
        '''(experimental) Grants permission to update the configuration of the storage optimizer for the Governed table.

        Access Level: Write

        https://docs.aws.amazon.com/lake-formation/latest/dg/aws-lake-formation-api-optimizers.html#aws-lake-formation-api-optimizers-UpdateTableStorageOptimizer

        :stability: experimental
        '''
        return typing.cast("Lakeformation", jsii.invoke(self, "toUpdateTableStorageOptimizer", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__645d66561d4282e87d4497cb84e6e72ec886291940243b97d3d18df96355f0b4)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8c78631a688eab5e8ec869111b2d502f30835e5a2502e979f3660d6e8bdee9c3)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Lambda(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Lambda",
):
    '''(experimental) Statement provider for service `lambda <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awslambda.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `lambda <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awslambda.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="ifCodeSigningConfigArn")
    def if_code_signing_config_arn(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Lambda":
        '''(experimental) Filters access by the ARN of an AWS Lambda code signing config.

        https://docs.aws.amazon.com/lambda/latest/dg/lambda-api-permissions-ref.html

        Applies to actions:

        - .toCreateFunction()
        - .toPutFunctionCodeSigningConfig()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__769f86ce31dee0fae76d7469a1eeb974c14c8bc96a3296f71d1a16bf8f74fe3d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Lambda", jsii.invoke(self, "ifCodeSigningConfigArn", [value, operator]))

    @jsii.member(jsii_name="ifFunctionArn")
    def if_function_arn(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Lambda":
        '''(experimental) Filters access by the ARN of an AWS Lambda function.

        https://docs.aws.amazon.com/lambda/latest/dg/lambda-api-permissions-ref.html

        Applies to actions:

        - .toCreateEventSourceMapping()
        - .toCreateFunctionUrlConfig()
        - .toDeleteEventSourceMapping()
        - .toDeleteFunctionUrlConfig()
        - .toGetEventSourceMapping()
        - .toGetFunctionUrlConfig()
        - .toInvokeFunctionUrl()
        - .toUpdateEventSourceMapping()
        - .toUpdateFunctionUrlConfig()

        :param value: The value(s) to check.
        :param operator: Works with `arn operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_ARN>`_. **Default:** ``ArnLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f652cc13d3ebfaebfdb435a183dc716cfeabd87377e383ea377b4fe9fba7c637)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Lambda", jsii.invoke(self, "ifFunctionArn", [value, operator]))

    @jsii.member(jsii_name="ifFunctionUrlAuthType")
    def if_function_url_auth_type(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Lambda":
        '''(experimental) Filters access by authorization type specified in request. Available during CreateFunctionUrlConfig, UpdateFunctionUrlConfig, DeleteFunctionUrlConfig, GetFunctionUrlConfig, ListFunctionUrlConfig, AddPermission and RemovePermission operations.

        https://docs.aws.amazon.com/lambda/latest/dg/lambda-api-permissions-ref.html

        Applies to actions:

        - .toAddPermission()
        - .toCreateFunctionUrlConfig()
        - .toDeleteFunctionUrlConfig()
        - .toGetFunctionUrlConfig()
        - .toInvokeFunctionUrl()
        - .toListFunctionUrlConfigs()
        - .toRemovePermission()
        - .toUpdateFunctionUrlConfig()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9fe938029e33251acb34cb7c721e12d54465bc3006859962bf48dc17938010f9)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Lambda", jsii.invoke(self, "ifFunctionUrlAuthType", [value, operator]))

    @jsii.member(jsii_name="ifLayer")
    def if_layer(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Lambda":
        '''(experimental) Filters access by the ARN of a version of an AWS Lambda layer.

        https://docs.aws.amazon.com/lambda/latest/dg/lambda-api-permissions-ref.html

        Applies to actions:

        - .toCreateFunction()
        - .toUpdateFunctionConfiguration()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__da9c8c3c4a68bb4292e6146b68a4d20ef996ac763beef813774a1c0e56bec606)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Lambda", jsii.invoke(self, "ifLayer", [value, operator]))

    @jsii.member(jsii_name="ifPrincipal")
    def if_principal(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Lambda":
        '''(experimental) Filters access by restricting the AWS service or account that can invoke a function.

        https://docs.aws.amazon.com/lambda/latest/dg/lambda-api-permissions-ref.html

        Applies to actions:

        - .toAddPermission()
        - .toRemovePermission()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9dfd9befa17d270167695cde12a8b77704e82d3649ad1fdaeaa4db9cbf22a2be)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Lambda", jsii.invoke(self, "ifPrincipal", [value, operator]))

    @jsii.member(jsii_name="ifSecurityGroupIds")
    def if_security_group_ids(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Lambda":
        '''(experimental) Filters access by the ID of security groups configured for the AWS Lambda function.

        https://docs.aws.amazon.com/lambda/latest/dg/lambda-api-permissions-ref.html

        Applies to actions:

        - .toCreateFunction()
        - .toUpdateFunctionConfiguration()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f7e522985c9ec1f61b39ded1000d0d1ec488391801ea66aca7fb70da8402a948)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Lambda", jsii.invoke(self, "ifSecurityGroupIds", [value, operator]))

    @jsii.member(jsii_name="ifSourceFunctionArn")
    def if_source_function_arn(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Lambda":
        '''(experimental) Filters access by the ARN of the AWS Lambda function from which the request originated.

        https://docs.aws.amazon.com/lambda/latest/dg/lambda-api-permissions-ref.html

        :param value: The value(s) to check.
        :param operator: Works with `arn operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_ARN>`_. **Default:** ``ArnLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a1fdcc32279abe1cd49804bf6533633936a5a0a81ae7ef402a6608552737872a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Lambda", jsii.invoke(self, "ifSourceFunctionArn", [value, operator]))

    @jsii.member(jsii_name="ifSubnetIds")
    def if_subnet_ids(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Lambda":
        '''(experimental) Filters access by the ID of subnets configured for the AWS Lambda function.

        https://docs.aws.amazon.com/lambda/latest/dg/lambda-api-permissions-ref.html

        Applies to actions:

        - .toCreateFunction()
        - .toUpdateFunctionConfiguration()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8e083f01db235c89bca545f1809c360be1f94a36f2e183d223d53345b1609bc2)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Lambda", jsii.invoke(self, "ifSubnetIds", [value, operator]))

    @jsii.member(jsii_name="ifVpcIds")
    def if_vpc_ids(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Lambda":
        '''(experimental) Filters access by the ID of the VPC configured for the AWS Lambda function.

        https://docs.aws.amazon.com/lambda/latest/dg/lambda-api-permissions-ref.html

        Applies to actions:

        - .toCreateFunction()
        - .toUpdateFunctionConfiguration()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7ce4bab254ad97a0f0fa5af0b032e6c2b9dd382b9275c9959273dec77366f668)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Lambda", jsii.invoke(self, "ifVpcIds", [value, operator]))

    @jsii.member(jsii_name="onCodeSigningConfig")
    def on_code_signing_config(
        self,
        code_signing_config_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Lambda":
        '''(experimental) Adds a resource of type code signing config to the statement.

        https://docs.aws.amazon.com/lambda/latest/dg/lambda-api-permissions-ref.html

        :param code_signing_config_id: - Identifier for the codeSigningConfigId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ebac1ff0968a23664f59d5e8a6441e003934dd3f8e8d9c2d643cda8e0ef4c22f)
            check_type(argname="argument code_signing_config_id", value=code_signing_config_id, expected_type=type_hints["code_signing_config_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Lambda", jsii.invoke(self, "onCodeSigningConfig", [code_signing_config_id, account, region, partition]))

    @jsii.member(jsii_name="onEventSourceMapping")
    def on_event_source_mapping(
        self,
        u_uid: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Lambda":
        '''(experimental) Adds a resource of type eventSourceMapping to the statement.

        https://docs.aws.amazon.com/lambda/latest/dg/lambda-api-permissions-ref.html

        :param u_uid: - Identifier for the uUID.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7f534f3849e9cf840c8b353cbd771fc2a3711363b6c9618ab0231a013e924301)
            check_type(argname="argument u_uid", value=u_uid, expected_type=type_hints["u_uid"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Lambda", jsii.invoke(self, "onEventSourceMapping", [u_uid, account, region, partition]))

    @jsii.member(jsii_name="onFunction")
    def on_function(
        self,
        function_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Lambda":
        '''(experimental) Adds a resource of type function to the statement.

        https://docs.aws.amazon.com/lambda/latest/dg/lambda-api-permissions-ref.html

        :param function_name: - Identifier for the functionName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__765214e7369929cac77b4df2561ca87df19dd8d4a74141ba16a8c6ba4f0a5e93)
            check_type(argname="argument function_name", value=function_name, expected_type=type_hints["function_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Lambda", jsii.invoke(self, "onFunction", [function_name, account, region, partition]))

    @jsii.member(jsii_name="onFunctionAlias")
    def on_function_alias(
        self,
        function_name: builtins.str,
        alias: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Lambda":
        '''(experimental) Adds a resource of type function alias to the statement.

        https://docs.aws.amazon.com/lambda/latest/dg/lambda-api-permissions-ref.html

        :param function_name: - Identifier for the functionName.
        :param alias: - Identifier for the alias.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2f02f0cb9d77b12d420b9a5e33237b4a6abdaec0aae16f2a49eed97ee379868c)
            check_type(argname="argument function_name", value=function_name, expected_type=type_hints["function_name"])
            check_type(argname="argument alias", value=alias, expected_type=type_hints["alias"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Lambda", jsii.invoke(self, "onFunctionAlias", [function_name, alias, account, region, partition]))

    @jsii.member(jsii_name="onFunctionVersion")
    def on_function_version(
        self,
        function_name: builtins.str,
        version: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Lambda":
        '''(experimental) Adds a resource of type function version to the statement.

        https://docs.aws.amazon.com/lambda/latest/dg/lambda-api-permissions-ref.html

        :param function_name: - Identifier for the functionName.
        :param version: - Identifier for the version.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__78bbd83e27dfc2ce2b189e3809dc45452bbfb910c5f150bf07b3cbd970176f0f)
            check_type(argname="argument function_name", value=function_name, expected_type=type_hints["function_name"])
            check_type(argname="argument version", value=version, expected_type=type_hints["version"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Lambda", jsii.invoke(self, "onFunctionVersion", [function_name, version, account, region, partition]))

    @jsii.member(jsii_name="onLayer")
    def on_layer(
        self,
        layer_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Lambda":
        '''(experimental) Adds a resource of type layer to the statement.

        https://docs.aws.amazon.com/lambda/latest/dg/lambda-api-permissions-ref.html

        :param layer_name: - Identifier for the layerName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__52540b4820039eebd656ef2ba02e0a7341db4c09c5d4c65b5f5aa58e7b037f37)
            check_type(argname="argument layer_name", value=layer_name, expected_type=type_hints["layer_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Lambda", jsii.invoke(self, "onLayer", [layer_name, account, region, partition]))

    @jsii.member(jsii_name="onLayerVersion")
    def on_layer_version(
        self,
        layer_name: builtins.str,
        layer_version: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Lambda":
        '''(experimental) Adds a resource of type layerVersion to the statement.

        https://docs.aws.amazon.com/lambda/latest/dg/lambda-api-permissions-ref.html

        :param layer_name: - Identifier for the layerName.
        :param layer_version: - Identifier for the layerVersion.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__27926fc5fe87ac14087cf36107cdcaf81549f3e7b0c7134e1d6aabc721b5baac)
            check_type(argname="argument layer_name", value=layer_name, expected_type=type_hints["layer_name"])
            check_type(argname="argument layer_version", value=layer_version, expected_type=type_hints["layer_version"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Lambda", jsii.invoke(self, "onLayerVersion", [layer_name, layer_version, account, region, partition]))

    @jsii.member(jsii_name="toAddLayerVersionPermission")
    def to_add_layer_version_permission(self) -> "Lambda":
        '''(experimental) Grants permission to add permissions to the resource-based policy of a version of an AWS Lambda layer.

        Access Level: Permissions management

        https://docs.aws.amazon.com/lambda/latest/dg/API_AddLayerVersionPermission.html

        :stability: experimental
        '''
        return typing.cast("Lambda", jsii.invoke(self, "toAddLayerVersionPermission", []))

    @jsii.member(jsii_name="toAddPermission")
    def to_add_permission(self) -> "Lambda":
        '''(experimental) Grants permission to give an AWS service or another account permission to use an AWS Lambda function.

        Access Level: Permissions management

        Possible conditions:

        - .ifPrincipal()
        - .ifFunctionUrlAuthType()

        https://docs.aws.amazon.com/lambda/latest/dg/API_AddPermission.html

        :stability: experimental
        '''
        return typing.cast("Lambda", jsii.invoke(self, "toAddPermission", []))

    @jsii.member(jsii_name="toCreateAlias")
    def to_create_alias(self) -> "Lambda":
        '''(experimental) Grants permission to create an alias for a Lambda function version.

        Access Level: Write

        https://docs.aws.amazon.com/lambda/latest/dg/API_CreateAlias.html

        :stability: experimental
        '''
        return typing.cast("Lambda", jsii.invoke(self, "toCreateAlias", []))

    @jsii.member(jsii_name="toCreateCodeSigningConfig")
    def to_create_code_signing_config(self) -> "Lambda":
        '''(experimental) Grants permission to create an AWS Lambda code signing config.

        Access Level: Write

        https://docs.aws.amazon.com/lambda/latest/dg/API_CreateCodeSigningConfig.html

        :stability: experimental
        '''
        return typing.cast("Lambda", jsii.invoke(self, "toCreateCodeSigningConfig", []))

    @jsii.member(jsii_name="toCreateEventSourceMapping")
    def to_create_event_source_mapping(self) -> "Lambda":
        '''(experimental) Grants permission to create a mapping between an event source and an AWS Lambda function.

        Access Level: Write

        Possible conditions:

        - .ifFunctionArn()

        https://docs.aws.amazon.com/lambda/latest/dg/API_CreateEventSourceMapping.html

        :stability: experimental
        '''
        return typing.cast("Lambda", jsii.invoke(self, "toCreateEventSourceMapping", []))

    @jsii.member(jsii_name="toCreateFunction")
    def to_create_function(self) -> "Lambda":
        '''(experimental) Grants permission to create an AWS Lambda function.

        Access Level: Write

        Possible conditions:

        - .ifLayer()
        - .ifVpcIds()
        - .ifSubnetIds()
        - .ifSecurityGroupIds()
        - .ifCodeSigningConfigArn()
        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - iam:PassRole

        https://docs.aws.amazon.com/lambda/latest/dg/API_CreateFunction.html

        :stability: experimental
        '''
        return typing.cast("Lambda", jsii.invoke(self, "toCreateFunction", []))

    @jsii.member(jsii_name="toCreateFunctionUrlConfig")
    def to_create_function_url_config(self) -> "Lambda":
        '''(experimental) Grants permission to create a function url configuration for a Lambda function.

        Access Level: Write

        Possible conditions:

        - .ifFunctionUrlAuthType()
        - .ifFunctionArn()

        https://docs.aws.amazon.com/lambda/latest/dg/API_CreateFunctionUrlConfig.html

        :stability: experimental
        '''
        return typing.cast("Lambda", jsii.invoke(self, "toCreateFunctionUrlConfig", []))

    @jsii.member(jsii_name="toDeleteAlias")
    def to_delete_alias(self) -> "Lambda":
        '''(experimental) Grants permission to delete an AWS Lambda function alias.

        Access Level: Write

        https://docs.aws.amazon.com/lambda/latest/dg/API_DeleteAlias.html

        :stability: experimental
        '''
        return typing.cast("Lambda", jsii.invoke(self, "toDeleteAlias", []))

    @jsii.member(jsii_name="toDeleteCodeSigningConfig")
    def to_delete_code_signing_config(self) -> "Lambda":
        '''(experimental) Grants permission to delete an AWS Lambda code signing config.

        Access Level: Write

        https://docs.aws.amazon.com/lambda/latest/dg/API_DeleteCodeSigningConfig.html

        :stability: experimental
        '''
        return typing.cast("Lambda", jsii.invoke(self, "toDeleteCodeSigningConfig", []))

    @jsii.member(jsii_name="toDeleteEventSourceMapping")
    def to_delete_event_source_mapping(self) -> "Lambda":
        '''(experimental) Grants permission to delete an AWS Lambda event source mapping.

        Access Level: Write

        Possible conditions:

        - .ifFunctionArn()

        https://docs.aws.amazon.com/lambda/latest/dg/API_DeleteEventSourceMapping.html

        :stability: experimental
        '''
        return typing.cast("Lambda", jsii.invoke(self, "toDeleteEventSourceMapping", []))

    @jsii.member(jsii_name="toDeleteFunction")
    def to_delete_function(self) -> "Lambda":
        '''(experimental) Grants permission to delete an AWS Lambda function.

        Access Level: Write

        https://docs.aws.amazon.com/lambda/latest/dg/API_DeleteFunction.html

        :stability: experimental
        '''
        return typing.cast("Lambda", jsii.invoke(self, "toDeleteFunction", []))

    @jsii.member(jsii_name="toDeleteFunctionCodeSigningConfig")
    def to_delete_function_code_signing_config(self) -> "Lambda":
        '''(experimental) Grants permission to detach a code signing config from an AWS Lambda function.

        Access Level: Write

        https://docs.aws.amazon.com/lambda/latest/dg/API_DeleteFunctionCodeSigningConfig.html

        :stability: experimental
        '''
        return typing.cast("Lambda", jsii.invoke(self, "toDeleteFunctionCodeSigningConfig", []))

    @jsii.member(jsii_name="toDeleteFunctionConcurrency")
    def to_delete_function_concurrency(self) -> "Lambda":
        '''(experimental) Grants permission to remove a concurrent execution limit from an AWS Lambda function.

        Access Level: Write

        https://docs.aws.amazon.com/lambda/latest/dg/API_DeleteFunctionConcurrency.html

        :stability: experimental
        '''
        return typing.cast("Lambda", jsii.invoke(self, "toDeleteFunctionConcurrency", []))

    @jsii.member(jsii_name="toDeleteFunctionEventInvokeConfig")
    def to_delete_function_event_invoke_config(self) -> "Lambda":
        '''(experimental) Grants permission to delete the configuration for asynchronous invocation for an AWS Lambda function, version, or alias.

        Access Level: Write

        https://docs.aws.amazon.com/lambda/latest/dg/API_DeleteFunctionEventInvokeConfig.html

        :stability: experimental
        '''
        return typing.cast("Lambda", jsii.invoke(self, "toDeleteFunctionEventInvokeConfig", []))

    @jsii.member(jsii_name="toDeleteFunctionUrlConfig")
    def to_delete_function_url_config(self) -> "Lambda":
        '''(experimental) Grants permission to delete function url configuration for a Lambda function.

        Access Level: Write

        Possible conditions:

        - .ifFunctionUrlAuthType()
        - .ifFunctionArn()

        https://docs.aws.amazon.com/lambda/latest/dg/API_DeleteFunctionUrlConfig.html

        :stability: experimental
        '''
        return typing.cast("Lambda", jsii.invoke(self, "toDeleteFunctionUrlConfig", []))

    @jsii.member(jsii_name="toDeleteLayerVersion")
    def to_delete_layer_version(self) -> "Lambda":
        '''(experimental) Grants permission to delete a version of an AWS Lambda layer.

        Access Level: Write

        https://docs.aws.amazon.com/lambda/latest/dg/API_DeleteLayerVersion.html

        :stability: experimental
        '''
        return typing.cast("Lambda", jsii.invoke(self, "toDeleteLayerVersion", []))

    @jsii.member(jsii_name="toDeleteProvisionedConcurrencyConfig")
    def to_delete_provisioned_concurrency_config(self) -> "Lambda":
        '''(experimental) Grants permission to delete the provisioned concurrency configuration for an AWS Lambda function.

        Access Level: Write

        https://docs.aws.amazon.com/lambda/latest/dg/API_DeleteProvisionedConcurrencyConfig.html

        :stability: experimental
        '''
        return typing.cast("Lambda", jsii.invoke(self, "toDeleteProvisionedConcurrencyConfig", []))

    @jsii.member(jsii_name="toDisableReplication")
    def to_disable_replication(self) -> "Lambda":
        '''(experimental) Grants permission to disable replication for a Lambda@Edge function.

        Access Level: Permissions management

        :stability: experimental
        '''
        return typing.cast("Lambda", jsii.invoke(self, "toDisableReplication", []))

    @jsii.member(jsii_name="toEnableReplication")
    def to_enable_replication(self) -> "Lambda":
        '''(experimental) Grants permission to enable replication for a Lambda@Edge function.

        Access Level: Permissions management

        :stability: experimental
        '''
        return typing.cast("Lambda", jsii.invoke(self, "toEnableReplication", []))

    @jsii.member(jsii_name="toGetAccountSettings")
    def to_get_account_settings(self) -> "Lambda":
        '''(experimental) Grants permission to view details about an account's limits and usage in an AWS Region.

        Access Level: Read

        https://docs.aws.amazon.com/lambda/latest/dg/API_GetAccountSettings.html

        :stability: experimental
        '''
        return typing.cast("Lambda", jsii.invoke(self, "toGetAccountSettings", []))

    @jsii.member(jsii_name="toGetAlias")
    def to_get_alias(self) -> "Lambda":
        '''(experimental) Grants permission to view details about an AWS Lambda function alias.

        Access Level: Read

        https://docs.aws.amazon.com/lambda/latest/dg/API_GetAlias.html

        :stability: experimental
        '''
        return typing.cast("Lambda", jsii.invoke(self, "toGetAlias", []))

    @jsii.member(jsii_name="toGetCodeSigningConfig")
    def to_get_code_signing_config(self) -> "Lambda":
        '''(experimental) Grants permission to view details about an AWS Lambda code signing config.

        Access Level: Read

        https://docs.aws.amazon.com/lambda/latest/dg/API_GetCodeSigningConfig.html

        :stability: experimental
        '''
        return typing.cast("Lambda", jsii.invoke(self, "toGetCodeSigningConfig", []))

    @jsii.member(jsii_name="toGetEventSourceMapping")
    def to_get_event_source_mapping(self) -> "Lambda":
        '''(experimental) Grants permission to view details about an AWS Lambda event source mapping.

        Access Level: Read

        Possible conditions:

        - .ifFunctionArn()

        https://docs.aws.amazon.com/lambda/latest/dg/API_GetEventSourceMapping.html

        :stability: experimental
        '''
        return typing.cast("Lambda", jsii.invoke(self, "toGetEventSourceMapping", []))

    @jsii.member(jsii_name="toGetFunction")
    def to_get_function(self) -> "Lambda":
        '''(experimental) Grants permission to view details about an AWS Lambda function.

        Access Level: Read

        https://docs.aws.amazon.com/lambda/latest/dg/API_GetFunction.html

        :stability: experimental
        '''
        return typing.cast("Lambda", jsii.invoke(self, "toGetFunction", []))

    @jsii.member(jsii_name="toGetFunctionCodeSigningConfig")
    def to_get_function_code_signing_config(self) -> "Lambda":
        '''(experimental) Grants permission to view the code signing config arn attached to an AWS Lambda function.

        Access Level: Read

        https://docs.aws.amazon.com/lambda/latest/dg/API_GetFunctionCodeSigningConfig.html

        :stability: experimental
        '''
        return typing.cast("Lambda", jsii.invoke(self, "toGetFunctionCodeSigningConfig", []))

    @jsii.member(jsii_name="toGetFunctionConcurrency")
    def to_get_function_concurrency(self) -> "Lambda":
        '''(experimental) Grants permission to view details about the reserved concurrency configuration for a function.

        Access Level: Read

        https://docs.aws.amazon.com/lambda/latest/dg/API_GetFunctionConcurrency.html

        :stability: experimental
        '''
        return typing.cast("Lambda", jsii.invoke(self, "toGetFunctionConcurrency", []))

    @jsii.member(jsii_name="toGetFunctionConfiguration")
    def to_get_function_configuration(self) -> "Lambda":
        '''(experimental) Grants permission to view details about the version-specific settings of an AWS Lambda function or version.

        Access Level: Read

        https://docs.aws.amazon.com/lambda/latest/dg/API_GetFunctionConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Lambda", jsii.invoke(self, "toGetFunctionConfiguration", []))

    @jsii.member(jsii_name="toGetFunctionEventInvokeConfig")
    def to_get_function_event_invoke_config(self) -> "Lambda":
        '''(experimental) Grants permission to view the configuration for asynchronous invocation for a function, version, or alias.

        Access Level: Read

        https://docs.aws.amazon.com/lambda/latest/dg/API_GetFunctionEventInvokeConfig.html

        :stability: experimental
        '''
        return typing.cast("Lambda", jsii.invoke(self, "toGetFunctionEventInvokeConfig", []))

    @jsii.member(jsii_name="toGetFunctionUrlConfig")
    def to_get_function_url_config(self) -> "Lambda":
        '''(experimental) Grants permission to read function url configuration for a Lambda function.

        Access Level: Read

        Possible conditions:

        - .ifFunctionUrlAuthType()
        - .ifFunctionArn()

        https://docs.aws.amazon.com/lambda/latest/dg/API_GetFunctionUrlConfig.html

        :stability: experimental
        '''
        return typing.cast("Lambda", jsii.invoke(self, "toGetFunctionUrlConfig", []))

    @jsii.member(jsii_name="toGetLayerVersion")
    def to_get_layer_version(self) -> "Lambda":
        '''(experimental) Grants permission to view details about a version of an AWS Lambda layer.

        Note this action also supports GetLayerVersionByArn API

        Access Level: Read

        https://docs.aws.amazon.com/lambda/latest/dg/API_GetLayerVersion.html

        :stability: experimental
        '''
        return typing.cast("Lambda", jsii.invoke(self, "toGetLayerVersion", []))

    @jsii.member(jsii_name="toGetLayerVersionPolicy")
    def to_get_layer_version_policy(self) -> "Lambda":
        '''(experimental) Grants permission to view the resource-based policy for a version of an AWS Lambda layer.

        Access Level: Read

        https://docs.aws.amazon.com/lambda/latest/dg/API_GetLayerVersionPolicy.html

        :stability: experimental
        '''
        return typing.cast("Lambda", jsii.invoke(self, "toGetLayerVersionPolicy", []))

    @jsii.member(jsii_name="toGetPolicy")
    def to_get_policy(self) -> "Lambda":
        '''(experimental) Grants permission to view the resource-based policy for an AWS Lambda function, version, or alias.

        Access Level: Read

        https://docs.aws.amazon.com/lambda/latest/dg/API_GetPolicy.html

        :stability: experimental
        '''
        return typing.cast("Lambda", jsii.invoke(self, "toGetPolicy", []))

    @jsii.member(jsii_name="toGetProvisionedConcurrencyConfig")
    def to_get_provisioned_concurrency_config(self) -> "Lambda":
        '''(experimental) Grants permission to view the provisioned concurrency configuration for an AWS Lambda function's alias or version.

        Access Level: Read

        https://docs.aws.amazon.com/lambda/latest/dg/API_GetProvisionedConcurrencyConfig.html

        :stability: experimental
        '''
        return typing.cast("Lambda", jsii.invoke(self, "toGetProvisionedConcurrencyConfig", []))

    @jsii.member(jsii_name="toInvokeAsync")
    def to_invoke_async(self) -> "Lambda":
        '''(experimental) Grants permission to invoke a function asynchronously (Deprecated).

        Access Level: Write

        https://docs.aws.amazon.com/lambda/latest/dg/API_InvokeAsync.html

        :stability: experimental
        '''
        return typing.cast("Lambda", jsii.invoke(self, "toInvokeAsync", []))

    @jsii.member(jsii_name="toInvokeFunction")
    def to_invoke_function(self) -> "Lambda":
        '''(experimental) Grants permission to invoke an AWS Lambda function.

        Access Level: Write

        https://docs.aws.amazon.com/lambda/latest/dg/API_Invoke.html

        :stability: experimental
        '''
        return typing.cast("Lambda", jsii.invoke(self, "toInvokeFunction", []))

    @jsii.member(jsii_name="toInvokeFunctionUrl")
    def to_invoke_function_url(self) -> "Lambda":
        '''(experimental) Grants permission to invoke an AWS Lambda function through url.

        Access Level: Write

        Possible conditions:

        - .ifFunctionUrlAuthType()
        - .ifFunctionArn()

        https://docs.aws.amazon.com/lambda/latest/dg/API_InvokeFunctionUrl.html

        :stability: experimental
        '''
        return typing.cast("Lambda", jsii.invoke(self, "toInvokeFunctionUrl", []))

    @jsii.member(jsii_name="toListAliases")
    def to_list_aliases(self) -> "Lambda":
        '''(experimental) Grants permission to retrieve a list of aliases for an AWS Lambda function.

        Access Level: List

        https://docs.aws.amazon.com/lambda/latest/dg/API_ListAliases.html

        :stability: experimental
        '''
        return typing.cast("Lambda", jsii.invoke(self, "toListAliases", []))

    @jsii.member(jsii_name="toListCodeSigningConfigs")
    def to_list_code_signing_configs(self) -> "Lambda":
        '''(experimental) Grants permission to retrieve a list of AWS Lambda code signing configs.

        Access Level: List

        https://docs.aws.amazon.com/lambda/latest/dg/API_ListCodeSigningConfigs.html

        :stability: experimental
        '''
        return typing.cast("Lambda", jsii.invoke(self, "toListCodeSigningConfigs", []))

    @jsii.member(jsii_name="toListEventSourceMappings")
    def to_list_event_source_mappings(self) -> "Lambda":
        '''(experimental) Grants permission to retrieve a list of AWS Lambda event source mappings.

        Access Level: List

        https://docs.aws.amazon.com/lambda/latest/dg/API_ListEventSourceMappings.html

        :stability: experimental
        '''
        return typing.cast("Lambda", jsii.invoke(self, "toListEventSourceMappings", []))

    @jsii.member(jsii_name="toListFunctionEventInvokeConfigs")
    def to_list_function_event_invoke_configs(self) -> "Lambda":
        '''(experimental) Grants permission to retrieve a list of configurations for asynchronous invocation for a function.

        Access Level: List

        https://docs.aws.amazon.com/lambda/latest/dg/API_ListFunctionEventInvokeConfigs.html

        :stability: experimental
        '''
        return typing.cast("Lambda", jsii.invoke(self, "toListFunctionEventInvokeConfigs", []))

    @jsii.member(jsii_name="toListFunctions")
    def to_list_functions(self) -> "Lambda":
        '''(experimental) Grants permission to retrieve a list of AWS Lambda functions, with the version-specific configuration of each function.

        Access Level: List

        https://docs.aws.amazon.com/lambda/latest/dg/API_ListFunctions.html

        :stability: experimental
        '''
        return typing.cast("Lambda", jsii.invoke(self, "toListFunctions", []))

    @jsii.member(jsii_name="toListFunctionsByCodeSigningConfig")
    def to_list_functions_by_code_signing_config(self) -> "Lambda":
        '''(experimental) Grants permission to retrieve a list of AWS Lambda functions by the code signing config assigned.

        Access Level: List

        https://docs.aws.amazon.com/lambda/latest/dg/API_ListFunctionsByCodeSigningConfig.html

        :stability: experimental
        '''
        return typing.cast("Lambda", jsii.invoke(self, "toListFunctionsByCodeSigningConfig", []))

    @jsii.member(jsii_name="toListFunctionUrlConfigs")
    def to_list_function_url_configs(self) -> "Lambda":
        '''(experimental) Grants permission to read function url configurations for a function.

        Access Level: List

        Possible conditions:

        - .ifFunctionUrlAuthType()

        https://docs.aws.amazon.com/lambda/latest/dg/API_ListFunctionUrlConfigs.html

        :stability: experimental
        '''
        return typing.cast("Lambda", jsii.invoke(self, "toListFunctionUrlConfigs", []))

    @jsii.member(jsii_name="toListLayers")
    def to_list_layers(self) -> "Lambda":
        '''(experimental) Grants permission to retrieve a list of AWS Lambda layers, with details about the latest version of each layer.

        Access Level: List

        https://docs.aws.amazon.com/lambda/latest/dg/API_ListLayers.html

        :stability: experimental
        '''
        return typing.cast("Lambda", jsii.invoke(self, "toListLayers", []))

    @jsii.member(jsii_name="toListLayerVersions")
    def to_list_layer_versions(self) -> "Lambda":
        '''(experimental) Grants permission to retrieve a list of versions of an AWS Lambda layer.

        Access Level: List

        https://docs.aws.amazon.com/lambda/latest/dg/API_ListLayerVersions.html

        :stability: experimental
        '''
        return typing.cast("Lambda", jsii.invoke(self, "toListLayerVersions", []))

    @jsii.member(jsii_name="toListProvisionedConcurrencyConfigs")
    def to_list_provisioned_concurrency_configs(self) -> "Lambda":
        '''(experimental) Grants permission to retrieve a list of provisioned concurrency configurations for an AWS Lambda function.

        Access Level: List

        https://docs.aws.amazon.com/lambda/latest/dg/API_ListProvisionedConcurrencyConfigs.html

        :stability: experimental
        '''
        return typing.cast("Lambda", jsii.invoke(self, "toListProvisionedConcurrencyConfigs", []))

    @jsii.member(jsii_name="toListTags")
    def to_list_tags(self) -> "Lambda":
        '''(experimental) Grants permission to retrieve a list of tags for an AWS Lambda function.

        Access Level: Read

        https://docs.aws.amazon.com/lambda/latest/dg/API_ListTags.html

        :stability: experimental
        '''
        return typing.cast("Lambda", jsii.invoke(self, "toListTags", []))

    @jsii.member(jsii_name="toListVersionsByFunction")
    def to_list_versions_by_function(self) -> "Lambda":
        '''(experimental) Grants permission to retrieve a list of versions for an AWS Lambda function.

        Access Level: List

        https://docs.aws.amazon.com/lambda/latest/dg/API_ListVersionsByFunction.html

        :stability: experimental
        '''
        return typing.cast("Lambda", jsii.invoke(self, "toListVersionsByFunction", []))

    @jsii.member(jsii_name="toPublishLayerVersion")
    def to_publish_layer_version(self) -> "Lambda":
        '''(experimental) Grants permission to create an AWS Lambda layer.

        Access Level: Write

        https://docs.aws.amazon.com/lambda/latest/dg/API_PublishLayerVersion.html

        :stability: experimental
        '''
        return typing.cast("Lambda", jsii.invoke(self, "toPublishLayerVersion", []))

    @jsii.member(jsii_name="toPublishVersion")
    def to_publish_version(self) -> "Lambda":
        '''(experimental) Grants permission to create an AWS Lambda function version.

        Access Level: Write

        https://docs.aws.amazon.com/lambda/latest/dg/API_PublishVersion.html

        :stability: experimental
        '''
        return typing.cast("Lambda", jsii.invoke(self, "toPublishVersion", []))

    @jsii.member(jsii_name="toPutFunctionCodeSigningConfig")
    def to_put_function_code_signing_config(self) -> "Lambda":
        '''(experimental) Grants permission to attach a code signing config to an AWS Lambda function.

        Access Level: Write

        Possible conditions:

        - .ifCodeSigningConfigArn()

        https://docs.aws.amazon.com/lambda/latest/dg/API_PutFunctionCodeSigningConfig.html

        :stability: experimental
        '''
        return typing.cast("Lambda", jsii.invoke(self, "toPutFunctionCodeSigningConfig", []))

    @jsii.member(jsii_name="toPutFunctionConcurrency")
    def to_put_function_concurrency(self) -> "Lambda":
        '''(experimental) Grants permission to configure reserved concurrency for an AWS Lambda function.

        Access Level: Write

        https://docs.aws.amazon.com/lambda/latest/dg/API_PutFunctionConcurrency.html

        :stability: experimental
        '''
        return typing.cast("Lambda", jsii.invoke(self, "toPutFunctionConcurrency", []))

    @jsii.member(jsii_name="toPutFunctionEventInvokeConfig")
    def to_put_function_event_invoke_config(self) -> "Lambda":
        '''(experimental) Grants permission to configures options for asynchronous invocation on an AWS Lambda function, version, or alias.

        Access Level: Write

        https://docs.aws.amazon.com/lambda/latest/dg/API_PutFunctionEventInvokeConfig.html

        :stability: experimental
        '''
        return typing.cast("Lambda", jsii.invoke(self, "toPutFunctionEventInvokeConfig", []))

    @jsii.member(jsii_name="toPutProvisionedConcurrencyConfig")
    def to_put_provisioned_concurrency_config(self) -> "Lambda":
        '''(experimental) Grants permission to configure provisioned concurrency for an AWS Lambda function's alias or version.

        Access Level: Write

        https://docs.aws.amazon.com/lambda/latest/dg/API_PutProvisionedConcurrencyConfig.html

        :stability: experimental
        '''
        return typing.cast("Lambda", jsii.invoke(self, "toPutProvisionedConcurrencyConfig", []))

    @jsii.member(jsii_name="toRemoveLayerVersionPermission")
    def to_remove_layer_version_permission(self) -> "Lambda":
        '''(experimental) Grants permission to remove a statement from the permissions policy for a version of an AWS Lambda layer.

        Access Level: Permissions management

        https://docs.aws.amazon.com/lambda/latest/dg/API_RemoveLayerVersionPermission.html

        :stability: experimental
        '''
        return typing.cast("Lambda", jsii.invoke(self, "toRemoveLayerVersionPermission", []))

    @jsii.member(jsii_name="toRemovePermission")
    def to_remove_permission(self) -> "Lambda":
        '''(experimental) Grants permission to revoke function-use permission from an AWS service or another account.

        Access Level: Permissions management

        Possible conditions:

        - .ifPrincipal()
        - .ifFunctionUrlAuthType()

        https://docs.aws.amazon.com/lambda/latest/dg/API_RemovePermission.html

        :stability: experimental
        '''
        return typing.cast("Lambda", jsii.invoke(self, "toRemovePermission", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Lambda":
        '''(experimental) Grants permission to add tags to an AWS Lambda function.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/lambda/latest/dg/API_TagResources.html

        :stability: experimental
        '''
        return typing.cast("Lambda", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Lambda":
        '''(experimental) Grants permission to remove tags from an AWS Lambda function.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/lambda/latest/dg/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("Lambda", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateAlias")
    def to_update_alias(self) -> "Lambda":
        '''(experimental) Grants permission to update the configuration of an AWS Lambda function's alias.

        Access Level: Write

        https://docs.aws.amazon.com/lambda/latest/dg/API_UpdateAlias.html

        :stability: experimental
        '''
        return typing.cast("Lambda", jsii.invoke(self, "toUpdateAlias", []))

    @jsii.member(jsii_name="toUpdateCodeSigningConfig")
    def to_update_code_signing_config(self) -> "Lambda":
        '''(experimental) Grants permission to update an AWS Lambda code signing config.

        Access Level: Write

        https://docs.aws.amazon.com/lambda/latest/dg/API_UpdateCodeSigningConfig.html

        :stability: experimental
        '''
        return typing.cast("Lambda", jsii.invoke(self, "toUpdateCodeSigningConfig", []))

    @jsii.member(jsii_name="toUpdateEventSourceMapping")
    def to_update_event_source_mapping(self) -> "Lambda":
        '''(experimental) Grants permission to update the configuration of an AWS Lambda event source mapping.

        Access Level: Write

        Possible conditions:

        - .ifFunctionArn()

        https://docs.aws.amazon.com/lambda/latest/dg/API_UpdateEventSourceMapping.html

        :stability: experimental
        '''
        return typing.cast("Lambda", jsii.invoke(self, "toUpdateEventSourceMapping", []))

    @jsii.member(jsii_name="toUpdateFunctionCode")
    def to_update_function_code(self) -> "Lambda":
        '''(experimental) Grants permission to update the code of an AWS Lambda function.

        Access Level: Write

        https://docs.aws.amazon.com/lambda/latest/dg/API_UpdateFunctionCode.html

        :stability: experimental
        '''
        return typing.cast("Lambda", jsii.invoke(self, "toUpdateFunctionCode", []))

    @jsii.member(jsii_name="toUpdateFunctionCodeSigningConfig")
    def to_update_function_code_signing_config(self) -> "Lambda":
        '''(experimental) Grants permission to update the code signing config of an AWS Lambda function.

        Access Level: Write

        https://docs.aws.amazon.com/lambda/latest/dg/API_UpdateFunctionCodeSigningConfig.html

        :stability: experimental
        '''
        return typing.cast("Lambda", jsii.invoke(self, "toUpdateFunctionCodeSigningConfig", []))

    @jsii.member(jsii_name="toUpdateFunctionConfiguration")
    def to_update_function_configuration(self) -> "Lambda":
        '''(experimental) Grants permission to modify the version-specific settings of an AWS Lambda function.

        Access Level: Write

        Possible conditions:

        - .ifLayer()
        - .ifVpcIds()
        - .ifSubnetIds()
        - .ifSecurityGroupIds()

        https://docs.aws.amazon.com/lambda/latest/dg/API_UpdateFunctionConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Lambda", jsii.invoke(self, "toUpdateFunctionConfiguration", []))

    @jsii.member(jsii_name="toUpdateFunctionEventInvokeConfig")
    def to_update_function_event_invoke_config(self) -> "Lambda":
        '''(experimental) Grants permission to modify the configuration for asynchronous invocation for an AWS Lambda function, version, or alias.

        Access Level: Write

        https://docs.aws.amazon.com/lambda/latest/dg/API_UpdateFunctionEventInvokeConfig.html

        :stability: experimental
        '''
        return typing.cast("Lambda", jsii.invoke(self, "toUpdateFunctionEventInvokeConfig", []))

    @jsii.member(jsii_name="toUpdateFunctionUrlConfig")
    def to_update_function_url_config(self) -> "Lambda":
        '''(experimental) Grants permission to update a function url configuration for a Lambda function.

        Access Level: Write

        Possible conditions:

        - .ifFunctionUrlAuthType()
        - .ifFunctionArn()

        https://docs.aws.amazon.com/lambda/latest/dg/API_UpdateFunctionUrlConfig.html

        :stability: experimental
        '''
        return typing.cast("Lambda", jsii.invoke(self, "toUpdateFunctionUrlConfig", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__118b83771aa49de3badbd21bf6d46462cb1d2e31b99014d91c73e99813af80c7)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5a640b064f962fe1e9eeb0ddd8d689f6dc0d053d05d944167802f1cbf9e4ed77)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Launchwizard(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Launchwizard",
):
    '''(experimental) Statement provider for service `launchwizard <https://docs.aws.amazon.com/service-authorization/latest/reference/list_launchwizard.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `launchwizard <https://docs.aws.amazon.com/service-authorization/latest/reference/list_launchwizard.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="toDeleteApp")
    def to_delete_app(self) -> "Launchwizard":
        '''(experimental) Delete an application.

        Access Level: Write

        https://docs.aws.amazon.com/launchwizard/

        :stability: experimental
        '''
        return typing.cast("Launchwizard", jsii.invoke(self, "toDeleteApp", []))

    @jsii.member(jsii_name="toDescribeProvisionedApp")
    def to_describe_provisioned_app(self) -> "Launchwizard":
        '''(experimental) Describe provisioning applications.

        Access Level: Read

        https://docs.aws.amazon.com/launchwizard/

        :stability: experimental
        '''
        return typing.cast("Launchwizard", jsii.invoke(self, "toDescribeProvisionedApp", []))

    @jsii.member(jsii_name="toDescribeProvisioningEvents")
    def to_describe_provisioning_events(self) -> "Launchwizard":
        '''(experimental) Describe provisioning events.

        Access Level: Read

        https://docs.aws.amazon.com/launchwizard/

        :stability: experimental
        '''
        return typing.cast("Launchwizard", jsii.invoke(self, "toDescribeProvisioningEvents", []))

    @jsii.member(jsii_name="toGetInfrastructureSuggestion")
    def to_get_infrastructure_suggestion(self) -> "Launchwizard":
        '''(experimental) Get infrastructure suggestion.

        Access Level: Read

        https://docs.aws.amazon.com/launchwizard/

        :stability: experimental
        '''
        return typing.cast("Launchwizard", jsii.invoke(self, "toGetInfrastructureSuggestion", []))

    @jsii.member(jsii_name="toGetIpAddress")
    def to_get_ip_address(self) -> "Launchwizard":
        '''(experimental) Get customer's ip address.

        Access Level: Read

        https://docs.aws.amazon.com/launchwizard/

        :stability: experimental
        '''
        return typing.cast("Launchwizard", jsii.invoke(self, "toGetIpAddress", []))

    @jsii.member(jsii_name="toGetResourceCostEstimate")
    def to_get_resource_cost_estimate(self) -> "Launchwizard":
        '''(experimental) Get resource cost estimate.

        Access Level: Read

        https://docs.aws.amazon.com/launchwizard/

        :stability: experimental
        '''
        return typing.cast("Launchwizard", jsii.invoke(self, "toGetResourceCostEstimate", []))

    @jsii.member(jsii_name="toListProvisionedApps")
    def to_list_provisioned_apps(self) -> "Launchwizard":
        '''(experimental) List provisioning applications.

        Access Level: List

        https://docs.aws.amazon.com/launchwizard/

        :stability: experimental
        '''
        return typing.cast("Launchwizard", jsii.invoke(self, "toListProvisionedApps", []))

    @jsii.member(jsii_name="toStartProvisioning")
    def to_start_provisioning(self) -> "Launchwizard":
        '''(experimental) Start a provisioning.

        Access Level: Write

        https://docs.aws.amazon.com/launchwizard/

        :stability: experimental
        '''
        return typing.cast("Launchwizard", jsii.invoke(self, "toStartProvisioning", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__359496a58d30e09b570ddc0f15feac91bdc746e1b126449d00d899adcd69f175)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e03d77fbb9a614ba95f260d8c88b53d3e18543bc0e45d44bb8a620a60466960b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Lex(PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Lex"):
    '''(experimental) Statement provider for service `lex <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonlex.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `lex <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonlex.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="ifAssociatedIntents")
    def if_associated_intents(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Lex":
        '''(experimental) Enables you to control access based on the intents included in the request.

        https://docs.aws.amazon.com/lex/latest/dg/security_iam_service-with-iam.html

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6da6bed4aa7f6dc159270f29ed3c6d6cdf4f19af394516c203f9a5109e8b45fc)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Lex", jsii.invoke(self, "ifAssociatedIntents", [value, operator]))

    @jsii.member(jsii_name="ifAssociatedSlotTypes")
    def if_associated_slot_types(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Lex":
        '''(experimental) Enables you to control access based on the slot types included in the request.

        https://docs.aws.amazon.com/lex/latest/dg/security_iam_service-with-iam.html

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1960ada759f559324a099c671c09a366b2b2a7e8e5e7542ee5870a1db53e3f01)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Lex", jsii.invoke(self, "ifAssociatedSlotTypes", [value, operator]))

    @jsii.member(jsii_name="ifChannelType")
    def if_channel_type(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Lex":
        '''(experimental) Enables you to control access based on the channel type included in the request.

        https://docs.aws.amazon.com/lex/latest/dg/security_iam_service-with-iam.html

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fdc28d7895f86ce5f27f0a8a8e1c4f39eb9f00ce3eee4e905cbc2ab839a4e184)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Lex", jsii.invoke(self, "ifChannelType", [value, operator]))

    @jsii.member(jsii_name="onBot")
    def on_bot(
        self,
        bot_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Lex":
        '''(experimental) Adds a resource of type bot to the statement.

        https://docs.aws.amazon.com/lex/latest/dg/API_BotMetadata.html

        :param bot_name: - Identifier for the botName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__62d2fcc8725f7d197ed6b89df0831eef201260714d5cc84fc6defa66e80ea9a7)
            check_type(argname="argument bot_name", value=bot_name, expected_type=type_hints["bot_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Lex", jsii.invoke(self, "onBot", [bot_name, account, region, partition]))

    @jsii.member(jsii_name="onBotAlias")
    def on_bot_alias(
        self,
        bot_name: builtins.str,
        bot_alias: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Lex":
        '''(experimental) Adds a resource of type bot alias to the statement.

        https://docs.aws.amazon.com/lex/latest/dg/API_BotAliasMetadata.html

        :param bot_name: - Identifier for the botName.
        :param bot_alias: - Identifier for the botAlias.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5cc3d8ff2e7d538222e0748abddef20c2145e2c14d05395040f8fd76a06974b4)
            check_type(argname="argument bot_name", value=bot_name, expected_type=type_hints["bot_name"])
            check_type(argname="argument bot_alias", value=bot_alias, expected_type=type_hints["bot_alias"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Lex", jsii.invoke(self, "onBotAlias", [bot_name, bot_alias, account, region, partition]))

    @jsii.member(jsii_name="onBotVersion")
    def on_bot_version(
        self,
        bot_name: builtins.str,
        bot_version: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Lex":
        '''(experimental) Adds a resource of type bot version to the statement.

        https://docs.aws.amazon.com/lex/latest/dg/API_BotMetadata.html

        :param bot_name: - Identifier for the botName.
        :param bot_version: - Identifier for the botVersion.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1ee3675f179c08556819ced22806b447741cdb52f7a927e73733e7af93bf461b)
            check_type(argname="argument bot_name", value=bot_name, expected_type=type_hints["bot_name"])
            check_type(argname="argument bot_version", value=bot_version, expected_type=type_hints["bot_version"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Lex", jsii.invoke(self, "onBotVersion", [bot_name, bot_version, account, region, partition]))

    @jsii.member(jsii_name="onChannel")
    def on_channel(
        self,
        bot_name: builtins.str,
        bot_alias: builtins.str,
        channel_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Lex":
        '''(experimental) Adds a resource of type channel to the statement.

        https://docs.aws.amazon.com/lex/latest/dg/API_BotChannelAssociation.html

        :param bot_name: - Identifier for the botName.
        :param bot_alias: - Identifier for the botAlias.
        :param channel_name: - Identifier for the channelName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4d2128df0fe3efc8a36bddf8c15ea715bcc3f764324d145ff9edf22eac5c9356)
            check_type(argname="argument bot_name", value=bot_name, expected_type=type_hints["bot_name"])
            check_type(argname="argument bot_alias", value=bot_alias, expected_type=type_hints["bot_alias"])
            check_type(argname="argument channel_name", value=channel_name, expected_type=type_hints["channel_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Lex", jsii.invoke(self, "onChannel", [bot_name, bot_alias, channel_name, account, region, partition]))

    @jsii.member(jsii_name="onIntentVersion")
    def on_intent_version(
        self,
        intent_name: builtins.str,
        intent_version: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Lex":
        '''(experimental) Adds a resource of type intent version to the statement.

        https://docs.aws.amazon.com/lex/latest/dg/API_Intent.html

        :param intent_name: - Identifier for the intentName.
        :param intent_version: - Identifier for the intentVersion.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__89b87618b5b45c25a2a64959901a4f109322b22028a910f4a1e1d9c6f9d25d79)
            check_type(argname="argument intent_name", value=intent_name, expected_type=type_hints["intent_name"])
            check_type(argname="argument intent_version", value=intent_version, expected_type=type_hints["intent_version"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Lex", jsii.invoke(self, "onIntentVersion", [intent_name, intent_version, account, region, partition]))

    @jsii.member(jsii_name="onSlottypeVersion")
    def on_slottype_version(
        self,
        slot_name: builtins.str,
        slot_version: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Lex":
        '''(experimental) Adds a resource of type slottype version to the statement.

        https://docs.aws.amazon.com/lex/latest/dg/API_SlotTypeMetadata.html

        :param slot_name: - Identifier for the slotName.
        :param slot_version: - Identifier for the slotVersion.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__81c790a870def4dced85af58d0c138febe7a0c109b7854bd00bdb95e9eb1c14e)
            check_type(argname="argument slot_name", value=slot_name, expected_type=type_hints["slot_name"])
            check_type(argname="argument slot_version", value=slot_version, expected_type=type_hints["slot_version"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Lex", jsii.invoke(self, "onSlottypeVersion", [slot_name, slot_version, account, region, partition]))

    @jsii.member(jsii_name="toCreateBotVersion")
    def to_create_bot_version(self) -> "Lex":
        '''(experimental) Creates a new version based on the $LATEST version of the specified bot.

        Access Level: Write

        https://docs.aws.amazon.com/lex/latest/dg/API_CreateBotVersion.html

        :stability: experimental
        '''
        return typing.cast("Lex", jsii.invoke(self, "toCreateBotVersion", []))

    @jsii.member(jsii_name="toCreateIntentVersion")
    def to_create_intent_version(self) -> "Lex":
        '''(experimental) Creates a new version based on the $LATEST version of the specified intent.

        Access Level: Write

        https://docs.aws.amazon.com/lex/latest/dg/API_CreateIntentVersion.html

        :stability: experimental
        '''
        return typing.cast("Lex", jsii.invoke(self, "toCreateIntentVersion", []))

    @jsii.member(jsii_name="toCreateSlotTypeVersion")
    def to_create_slot_type_version(self) -> "Lex":
        '''(experimental) Creates a new version based on the $LATEST version of the specified slot type.

        Access Level: Write

        https://docs.aws.amazon.com/lex/latest/dg/API_CreateSlotTypeVersion.html

        :stability: experimental
        '''
        return typing.cast("Lex", jsii.invoke(self, "toCreateSlotTypeVersion", []))

    @jsii.member(jsii_name="toDeleteBot")
    def to_delete_bot(self) -> "Lex":
        '''(experimental) Deletes all versions of a bot.

        Access Level: Write

        https://docs.aws.amazon.com/lex/latest/dg/API_DeleteBot.html

        :stability: experimental
        '''
        return typing.cast("Lex", jsii.invoke(self, "toDeleteBot", []))

    @jsii.member(jsii_name="toDeleteBotAlias")
    def to_delete_bot_alias(self) -> "Lex":
        '''(experimental) Deletes an alias for a specific bot.

        Access Level: Write

        https://docs.aws.amazon.com/lex/latest/dg/API_DeleteBotAlias.html

        :stability: experimental
        '''
        return typing.cast("Lex", jsii.invoke(self, "toDeleteBotAlias", []))

    @jsii.member(jsii_name="toDeleteBotChannelAssociation")
    def to_delete_bot_channel_association(self) -> "Lex":
        '''(experimental) Deletes the association between a Amazon Lex bot alias and a messaging platform.

        Access Level: Write

        https://docs.aws.amazon.com/lex/latest/dg/API_DeleteBotChannelAssociation.html

        :stability: experimental
        '''
        return typing.cast("Lex", jsii.invoke(self, "toDeleteBotChannelAssociation", []))

    @jsii.member(jsii_name="toDeleteBotVersion")
    def to_delete_bot_version(self) -> "Lex":
        '''(experimental) Deletes a specific version of a bot.

        Access Level: Write

        https://docs.aws.amazon.com/lex/latest/dg/API_DeleteBotVersion.html

        :stability: experimental
        '''
        return typing.cast("Lex", jsii.invoke(self, "toDeleteBotVersion", []))

    @jsii.member(jsii_name="toDeleteIntent")
    def to_delete_intent(self) -> "Lex":
        '''(experimental) Deletes all versions of an intent.

        Access Level: Write

        https://docs.aws.amazon.com/lex/latest/dg/API_DeleteIntent.html

        :stability: experimental
        '''
        return typing.cast("Lex", jsii.invoke(self, "toDeleteIntent", []))

    @jsii.member(jsii_name="toDeleteIntentVersion")
    def to_delete_intent_version(self) -> "Lex":
        '''(experimental) Deletes a specific version of an intent.

        Access Level: Write

        https://docs.aws.amazon.com/lex/latest/dg/API_DeleteIntentVersion.html

        :stability: experimental
        '''
        return typing.cast("Lex", jsii.invoke(self, "toDeleteIntentVersion", []))

    @jsii.member(jsii_name="toDeleteSession")
    def to_delete_session(self) -> "Lex":
        '''(experimental) Removes session information for a specified bot, alias, and user ID.

        Access Level: Write

        https://docs.aws.amazon.com/lex/latest/dg/API_runtime_DeleteSession.html

        :stability: experimental
        '''
        return typing.cast("Lex", jsii.invoke(self, "toDeleteSession", []))

    @jsii.member(jsii_name="toDeleteSlotType")
    def to_delete_slot_type(self) -> "Lex":
        '''(experimental) Deletes all versions of a slot type.

        Access Level: Write

        https://docs.aws.amazon.com/lex/latest/dg/API_DeleteSlotType.html

        :stability: experimental
        '''
        return typing.cast("Lex", jsii.invoke(self, "toDeleteSlotType", []))

    @jsii.member(jsii_name="toDeleteSlotTypeVersion")
    def to_delete_slot_type_version(self) -> "Lex":
        '''(experimental) Deletes a specific version of a slot type.

        Access Level: Write

        https://docs.aws.amazon.com/lex/latest/dg/API_DeleteSlotTypeVersion.html

        :stability: experimental
        '''
        return typing.cast("Lex", jsii.invoke(self, "toDeleteSlotTypeVersion", []))

    @jsii.member(jsii_name="toDeleteUtterances")
    def to_delete_utterances(self) -> "Lex":
        '''(experimental) Deletes the information Amazon Lex maintains for utterances on a specific bot and userId.

        Access Level: Write

        https://docs.aws.amazon.com/lex/latest/dg/API_DeleteUtterances.html

        :stability: experimental
        '''
        return typing.cast("Lex", jsii.invoke(self, "toDeleteUtterances", []))

    @jsii.member(jsii_name="toGetBot")
    def to_get_bot(self) -> "Lex":
        '''(experimental) Returns information for a specific bot. In addition to the bot name, the bot version or alias is required.

        Access Level: Read

        https://docs.aws.amazon.com/lex/latest/dg/API_GetBot.html

        :stability: experimental
        '''
        return typing.cast("Lex", jsii.invoke(self, "toGetBot", []))

    @jsii.member(jsii_name="toGetBotAlias")
    def to_get_bot_alias(self) -> "Lex":
        '''(experimental) Returns information about a Amazon Lex bot alias.

        Access Level: Read

        https://docs.aws.amazon.com/lex/latest/dg/API_GetBotAlias.html

        :stability: experimental
        '''
        return typing.cast("Lex", jsii.invoke(self, "toGetBotAlias", []))

    @jsii.member(jsii_name="toGetBotAliases")
    def to_get_bot_aliases(self) -> "Lex":
        '''(experimental) Returns a list of aliases for a given Amazon Lex bot.

        Access Level: List

        https://docs.aws.amazon.com/lex/latest/dg/API_GetBotAliases.html

        :stability: experimental
        '''
        return typing.cast("Lex", jsii.invoke(self, "toGetBotAliases", []))

    @jsii.member(jsii_name="toGetBotChannelAssociation")
    def to_get_bot_channel_association(self) -> "Lex":
        '''(experimental) Returns information about the association between a Amazon Lex bot and a messaging platform.

        Access Level: Read

        https://docs.aws.amazon.com/lex/latest/dg/API_GetBotChannelAssociation.html

        :stability: experimental
        '''
        return typing.cast("Lex", jsii.invoke(self, "toGetBotChannelAssociation", []))

    @jsii.member(jsii_name="toGetBotChannelAssociations")
    def to_get_bot_channel_associations(self) -> "Lex":
        '''(experimental) Returns a list of all of the channels associated with a single bot.

        Access Level: List

        https://docs.aws.amazon.com/lex/latest/dg/API_GetBotChannelAssociations.html

        :stability: experimental
        '''
        return typing.cast("Lex", jsii.invoke(self, "toGetBotChannelAssociations", []))

    @jsii.member(jsii_name="toGetBots")
    def to_get_bots(self) -> "Lex":
        '''(experimental) Returns information for the $LATEST version of all bots, subject to filters provided by the client.

        Access Level: List

        https://docs.aws.amazon.com/lex/latest/dg/API_GetBots.html

        :stability: experimental
        '''
        return typing.cast("Lex", jsii.invoke(self, "toGetBots", []))

    @jsii.member(jsii_name="toGetBotVersions")
    def to_get_bot_versions(self) -> "Lex":
        '''(experimental) Returns information for all versions of a specific bot.

        Access Level: List

        https://docs.aws.amazon.com/lex/latest/dg/API_GetBotVersions.html

        :stability: experimental
        '''
        return typing.cast("Lex", jsii.invoke(self, "toGetBotVersions", []))

    @jsii.member(jsii_name="toGetBuiltinIntent")
    def to_get_builtin_intent(self) -> "Lex":
        '''(experimental) Returns information about a built-in intent.

        Access Level: Read

        https://docs.aws.amazon.com/lex/latest/dg/API_GetBuiltinIntent.html

        :stability: experimental
        '''
        return typing.cast("Lex", jsii.invoke(self, "toGetBuiltinIntent", []))

    @jsii.member(jsii_name="toGetBuiltinIntents")
    def to_get_builtin_intents(self) -> "Lex":
        '''(experimental) Gets a list of built-in intents that meet the specified criteria.

        Access Level: Read

        https://docs.aws.amazon.com/lex/latest/dg/API_GetBuiltinIntents.html

        :stability: experimental
        '''
        return typing.cast("Lex", jsii.invoke(self, "toGetBuiltinIntents", []))

    @jsii.member(jsii_name="toGetBuiltinSlotTypes")
    def to_get_builtin_slot_types(self) -> "Lex":
        '''(experimental) Gets a list of built-in slot types that meet the specified criteria.

        Access Level: Read

        https://docs.aws.amazon.com/lex/latest/dg/API_GetBuiltinSlotTypes.html

        :stability: experimental
        '''
        return typing.cast("Lex", jsii.invoke(self, "toGetBuiltinSlotTypes", []))

    @jsii.member(jsii_name="toGetExport")
    def to_get_export(self) -> "Lex":
        '''(experimental) Exports Amazon Lex Resource in a requested format.

        Access Level: Read

        https://docs.aws.amazon.com/lex/latest/dg/API_GetExport.html

        :stability: experimental
        '''
        return typing.cast("Lex", jsii.invoke(self, "toGetExport", []))

    @jsii.member(jsii_name="toGetImport")
    def to_get_import(self) -> "Lex":
        '''(experimental) Gets information about an import job started with StartImport.

        Access Level: Read

        https://docs.aws.amazon.com/lex/latest/dg/API_GetImport.html

        :stability: experimental
        '''
        return typing.cast("Lex", jsii.invoke(self, "toGetImport", []))

    @jsii.member(jsii_name="toGetIntent")
    def to_get_intent(self) -> "Lex":
        '''(experimental) Returns information for a specific intent. In addition to the intent name, you must also specify the intent version.

        Access Level: Read

        https://docs.aws.amazon.com/lex/latest/dg/API_GetIntent.html

        :stability: experimental
        '''
        return typing.cast("Lex", jsii.invoke(self, "toGetIntent", []))

    @jsii.member(jsii_name="toGetIntents")
    def to_get_intents(self) -> "Lex":
        '''(experimental) Returns information for the $LATEST version of all intents, subject to filters provided by the client.

        Access Level: List

        https://docs.aws.amazon.com/lex/latest/dg/API_GetIntents.html

        :stability: experimental
        '''
        return typing.cast("Lex", jsii.invoke(self, "toGetIntents", []))

    @jsii.member(jsii_name="toGetIntentVersions")
    def to_get_intent_versions(self) -> "Lex":
        '''(experimental) Returns information for all versions of a specific intent.

        Access Level: List

        https://docs.aws.amazon.com/lex/latest/dg/API_GetIntentVersions.html

        :stability: experimental
        '''
        return typing.cast("Lex", jsii.invoke(self, "toGetIntentVersions", []))

    @jsii.member(jsii_name="toGetMigration")
    def to_get_migration(self) -> "Lex":
        '''(experimental) Grants permission to view an ongoing or completed migration.

        Access Level: Read

        https://docs.aws.amazon.com/lex/latest/dg/API_GetMigration.html

        :stability: experimental
        '''
        return typing.cast("Lex", jsii.invoke(self, "toGetMigration", []))

    @jsii.member(jsii_name="toGetMigrations")
    def to_get_migrations(self) -> "Lex":
        '''(experimental) Grants permission to view list of migrations from Amazon Lex v1 to Amazon Lex v2.

        Access Level: List

        https://docs.aws.amazon.com/lex/latest/dg/API_GetMigrations.html

        :stability: experimental
        '''
        return typing.cast("Lex", jsii.invoke(self, "toGetMigrations", []))

    @jsii.member(jsii_name="toGetSession")
    def to_get_session(self) -> "Lex":
        '''(experimental) Returns session information for a specified bot, alias, and user ID.

        Access Level: Read

        https://docs.aws.amazon.com/lex/latest/dg/API_runtime_GetSession.html

        :stability: experimental
        '''
        return typing.cast("Lex", jsii.invoke(self, "toGetSession", []))

    @jsii.member(jsii_name="toGetSlotType")
    def to_get_slot_type(self) -> "Lex":
        '''(experimental) Returns information about a specific version of a slot type.

        In addition to specifying the slot type name, you must also specify the slot type version

        Access Level: Read

        https://docs.aws.amazon.com/lex/latest/dg/API_GetSlotType.html

        :stability: experimental
        '''
        return typing.cast("Lex", jsii.invoke(self, "toGetSlotType", []))

    @jsii.member(jsii_name="toGetSlotTypes")
    def to_get_slot_types(self) -> "Lex":
        '''(experimental) Returns information for the $LATEST version of all slot types, subject to filters provided by the client.

        Access Level: List

        https://docs.aws.amazon.com/lex/latest/dg/API_GetSlotTypes.html

        :stability: experimental
        '''
        return typing.cast("Lex", jsii.invoke(self, "toGetSlotTypes", []))

    @jsii.member(jsii_name="toGetSlotTypeVersions")
    def to_get_slot_type_versions(self) -> "Lex":
        '''(experimental) Returns information for all versions of a specific slot type.

        Access Level: List

        https://docs.aws.amazon.com/lex/latest/dg/API_GetSlotTypeVersions.html

        :stability: experimental
        '''
        return typing.cast("Lex", jsii.invoke(self, "toGetSlotTypeVersions", []))

    @jsii.member(jsii_name="toGetUtterancesView")
    def to_get_utterances_view(self) -> "Lex":
        '''(experimental) Returns a view of aggregate utterance data for versions of a bot for a recent time period.

        Access Level: List

        https://docs.aws.amazon.com/lex/latest/dg/API_GetUtterancesView.html

        :stability: experimental
        '''
        return typing.cast("Lex", jsii.invoke(self, "toGetUtterancesView", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Lex":
        '''(experimental) Lists tags for a Lex resource.

        Access Level: Read

        https://docs.aws.amazon.com/lex/latest/dg/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("Lex", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toPostContent")
    def to_post_content(self) -> "Lex":
        '''(experimental) Sends user input (text or speech) to Amazon Lex.

        Access Level: Write

        https://docs.aws.amazon.com/lex/latest/dg/API_runtime_PostContent.html

        :stability: experimental
        '''
        return typing.cast("Lex", jsii.invoke(self, "toPostContent", []))

    @jsii.member(jsii_name="toPostText")
    def to_post_text(self) -> "Lex":
        '''(experimental) Sends user input (text-only) to Amazon Lex.

        Access Level: Write

        https://docs.aws.amazon.com/lex/latest/dg/API_runtime_PostText.html

        :stability: experimental
        '''
        return typing.cast("Lex", jsii.invoke(self, "toPostText", []))

    @jsii.member(jsii_name="toPutBot")
    def to_put_bot(self) -> "Lex":
        '''(experimental) Creates or updates the $LATEST version of a Amazon Lex conversational bot.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/lex/latest/dg/API_PutBot.html

        :stability: experimental
        '''
        return typing.cast("Lex", jsii.invoke(self, "toPutBot", []))

    @jsii.member(jsii_name="toPutBotAlias")
    def to_put_bot_alias(self) -> "Lex":
        '''(experimental) Creates or updates an alias for the specific bot.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/lex/latest/dg/API_PutBotAlias.html

        :stability: experimental
        '''
        return typing.cast("Lex", jsii.invoke(self, "toPutBotAlias", []))

    @jsii.member(jsii_name="toPutIntent")
    def to_put_intent(self) -> "Lex":
        '''(experimental) Creates or updates the $LATEST version of an intent.

        Access Level: Write

        https://docs.aws.amazon.com/lex/latest/dg/API_PutIntent.html

        :stability: experimental
        '''
        return typing.cast("Lex", jsii.invoke(self, "toPutIntent", []))

    @jsii.member(jsii_name="toPutSession")
    def to_put_session(self) -> "Lex":
        '''(experimental) Creates a new session or modifies an existing session with an Amazon Lex bot.

        Access Level: Write

        https://docs.aws.amazon.com/lex/latest/dg/API_runtime_PutSession.html

        :stability: experimental
        '''
        return typing.cast("Lex", jsii.invoke(self, "toPutSession", []))

    @jsii.member(jsii_name="toPutSlotType")
    def to_put_slot_type(self) -> "Lex":
        '''(experimental) Creates or updates the $LATEST version of a slot type.

        Access Level: Write

        https://docs.aws.amazon.com/lex/latest/dg/API_PutSlotType.html

        :stability: experimental
        '''
        return typing.cast("Lex", jsii.invoke(self, "toPutSlotType", []))

    @jsii.member(jsii_name="toStartImport")
    def to_start_import(self) -> "Lex":
        '''(experimental) Starts a job to import a resource to Amazon Lex.

        Access Level: Write

        https://docs.aws.amazon.com/lex/latest/dg/API_StartImport.html

        :stability: experimental
        '''
        return typing.cast("Lex", jsii.invoke(self, "toStartImport", []))

    @jsii.member(jsii_name="toStartMigration")
    def to_start_migration(self) -> "Lex":
        '''(experimental) Grants permission to migrate a bot from Amazon Lex v1 to Amazon Lex v2.

        Access Level: Write

        https://docs.aws.amazon.com/lex/latest/dg/API_StartMigration.html

        :stability: experimental
        '''
        return typing.cast("Lex", jsii.invoke(self, "toStartMigration", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Lex":
        '''(experimental) Adds or overwrites tags to a Lex resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/lex/latest/dg/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("Lex", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Lex":
        '''(experimental) Removes tags from a Lex resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/lex/latest/dg/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("Lex", jsii.invoke(self, "toUntagResource", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a794fbc30c1ea6060a01b9a8558ce1f0691076194403dfe93de05213ef386109)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a1f9b4d060b995e84fdf147eead71cb4449d566d3ddb8aa70c83b6d127d18ab6)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class LexV2(PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.LexV2"):
    '''(experimental) Statement provider for service `lex-v2 <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonlexv2.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `lex-v2 <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonlexv2.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onBot")
    def on_bot(
        self,
        bot_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "LexV2":
        '''(experimental) Adds a resource of type bot to the statement.

        https://docs.aws.amazon.com/lexv2/latest/dg/how-it-works.html

        :param bot_id: - Identifier for the botId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__375b3aaac47ce0301fb5b4c32d8797690e2eeaf91d428fc907246ceed9f4a433)
            check_type(argname="argument bot_id", value=bot_id, expected_type=type_hints["bot_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("LexV2", jsii.invoke(self, "onBot", [bot_id, account, region, partition]))

    @jsii.member(jsii_name="onBotAlias")
    def on_bot_alias(
        self,
        bot_id: builtins.str,
        bot_alias_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "LexV2":
        '''(experimental) Adds a resource of type bot alias to the statement.

        https://docs.aws.amazon.com/lexv2/latest/dg/how-it-works.html

        :param bot_id: - Identifier for the botId.
        :param bot_alias_id: - Identifier for the botAliasId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__58cd49ce0508e2ed0f74f84d7c7344b732dc70188c5b5b2f8658ed0f38c4825d)
            check_type(argname="argument bot_id", value=bot_id, expected_type=type_hints["bot_id"])
            check_type(argname="argument bot_alias_id", value=bot_alias_id, expected_type=type_hints["bot_alias_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("LexV2", jsii.invoke(self, "onBotAlias", [bot_id, bot_alias_id, account, region, partition]))

    @jsii.member(jsii_name="toBatchCreateCustomVocabularyItem")
    def to_batch_create_custom_vocabulary_item(self) -> "LexV2":
        '''(experimental) Grants permission to create new items in an existing custom vocabulary.

        Access Level: Write

        https://docs.aws.amazon.com/lexv2/latest/dg/API_BatchCreateCustomVocabularyItem.html

        :stability: experimental
        '''
        return typing.cast("LexV2", jsii.invoke(self, "toBatchCreateCustomVocabularyItem", []))

    @jsii.member(jsii_name="toBatchDeleteCustomVocabularyItem")
    def to_batch_delete_custom_vocabulary_item(self) -> "LexV2":
        '''(experimental) Grants permission to delete existing items in an existing custom vocabulary.

        Access Level: Write

        https://docs.aws.amazon.com/lexv2/latest/dg/API_BatchDeleteCustomVocabularyItem.html

        :stability: experimental
        '''
        return typing.cast("LexV2", jsii.invoke(self, "toBatchDeleteCustomVocabularyItem", []))

    @jsii.member(jsii_name="toBatchUpdateCustomVocabularyItem")
    def to_batch_update_custom_vocabulary_item(self) -> "LexV2":
        '''(experimental) Grants permission to update existing items in an existing custom vocabulary.

        Access Level: Write

        https://docs.aws.amazon.com/lexv2/latest/dg/API_BatchUpdateCustomVocabularyItem.html

        :stability: experimental
        '''
        return typing.cast("LexV2", jsii.invoke(self, "toBatchUpdateCustomVocabularyItem", []))

    @jsii.member(jsii_name="toBuildBotLocale")
    def to_build_bot_locale(self) -> "LexV2":
        '''(experimental) Grants permission to build an existing bot locale in a bot.

        Access Level: Write

        https://docs.aws.amazon.com/lexv2/latest/dg/API_BuildBotLocale.html

        :stability: experimental
        '''
        return typing.cast("LexV2", jsii.invoke(self, "toBuildBotLocale", []))

    @jsii.member(jsii_name="toCreateBot")
    def to_create_bot(self) -> "LexV2":
        '''(experimental) Grants permission to create a new bot and a test bot alias pointing to the DRAFT bot version.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/lexv2/latest/dg/API_CreateBot.html

        :stability: experimental
        '''
        return typing.cast("LexV2", jsii.invoke(self, "toCreateBot", []))

    @jsii.member(jsii_name="toCreateBotAlias")
    def to_create_bot_alias(self) -> "LexV2":
        '''(experimental) Grants permission to create a new bot alias in a bot.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/lexv2/latest/dg/API_CreateBotAlias.html

        :stability: experimental
        '''
        return typing.cast("LexV2", jsii.invoke(self, "toCreateBotAlias", []))

    @jsii.member(jsii_name="toCreateBotChannel")
    def to_create_bot_channel(self) -> "LexV2":
        '''(experimental) Grants permission to create a bot channel in an existing bot.

        Access Level: Write

        https://docs.aws.amazon.com/lexv2/latest/dg/deploying-messaging-platform.html

        :stability: experimental
        '''
        return typing.cast("LexV2", jsii.invoke(self, "toCreateBotChannel", []))

    @jsii.member(jsii_name="toCreateBotLocale")
    def to_create_bot_locale(self) -> "LexV2":
        '''(experimental) Grants permission to create a new bot locale in an existing bot.

        Access Level: Write

        https://docs.aws.amazon.com/lexv2/latest/dg/API_CreateBotLocale.html

        :stability: experimental
        '''
        return typing.cast("LexV2", jsii.invoke(self, "toCreateBotLocale", []))

    @jsii.member(jsii_name="toCreateBotVersion")
    def to_create_bot_version(self) -> "LexV2":
        '''(experimental) Grants permission to create a new version of an existing bot.

        Access Level: Write

        https://docs.aws.amazon.com/lexv2/latest/dg/API_CreateBotVersion.html

        :stability: experimental
        '''
        return typing.cast("LexV2", jsii.invoke(self, "toCreateBotVersion", []))

    @jsii.member(jsii_name="toCreateCustomVocabulary")
    def to_create_custom_vocabulary(self) -> "LexV2":
        '''(experimental) Grants permission to create a new custom vocabulary in an existing bot locale.

        Access Level: Write

        https://docs.aws.amazon.com/lexv2/latest/dg/vocab.html

        :stability: experimental
        '''
        return typing.cast("LexV2", jsii.invoke(self, "toCreateCustomVocabulary", []))

    @jsii.member(jsii_name="toCreateExport")
    def to_create_export(self) -> "LexV2":
        '''(experimental) Grants permission to create an export for an existing resource.

        Access Level: Write

        https://docs.aws.amazon.com/lexv2/latest/dg/API_CreateExport.html

        :stability: experimental
        '''
        return typing.cast("LexV2", jsii.invoke(self, "toCreateExport", []))

    @jsii.member(jsii_name="toCreateIntent")
    def to_create_intent(self) -> "LexV2":
        '''(experimental) Grants permission to create a new intent in an existing bot locale.

        Access Level: Write

        https://docs.aws.amazon.com/lexv2/latest/dg/API_CreateIntent.html

        :stability: experimental
        '''
        return typing.cast("LexV2", jsii.invoke(self, "toCreateIntent", []))

    @jsii.member(jsii_name="toCreateResourcePolicy")
    def to_create_resource_policy(self) -> "LexV2":
        '''(experimental) Grants permission to create a new resource policy for a Lex resource.

        Access Level: Write

        https://docs.aws.amazon.com/lexv2/latest/dg/API_CreateResourcePolicy.html

        :stability: experimental
        '''
        return typing.cast("LexV2", jsii.invoke(self, "toCreateResourcePolicy", []))

    @jsii.member(jsii_name="toCreateSlot")
    def to_create_slot(self) -> "LexV2":
        '''(experimental) Grants permission to create a new slot in an intent.

        Access Level: Write

        https://docs.aws.amazon.com/lexv2/latest/dg/API_CreateSlot.html

        :stability: experimental
        '''
        return typing.cast("LexV2", jsii.invoke(self, "toCreateSlot", []))

    @jsii.member(jsii_name="toCreateSlotType")
    def to_create_slot_type(self) -> "LexV2":
        '''(experimental) Grants permission to create a new slot type in an existing bot locale.

        Access Level: Write

        https://docs.aws.amazon.com/lexv2/latest/dg/API_CreateSlotType.html

        :stability: experimental
        '''
        return typing.cast("LexV2", jsii.invoke(self, "toCreateSlotType", []))

    @jsii.member(jsii_name="toCreateUploadUrl")
    def to_create_upload_url(self) -> "LexV2":
        '''(experimental) Grants permission to create an upload url for import file.

        Access Level: Write

        https://docs.aws.amazon.com/lexv2/latest/dg/API_CreateUploadUrl.html

        :stability: experimental
        '''
        return typing.cast("LexV2", jsii.invoke(self, "toCreateUploadUrl", []))

    @jsii.member(jsii_name="toDeleteBot")
    def to_delete_bot(self) -> "LexV2":
        '''(experimental) Grants permission to delete an existing bot.

        Access Level: Write

        Dependent actions:

        - lex:DeleteBotAlias
        - lex:DeleteBotChannel
        - lex:DeleteBotLocale
        - lex:DeleteBotVersion
        - lex:DeleteIntent
        - lex:DeleteSlot
        - lex:DeleteSlotType

        https://docs.aws.amazon.com/lexv2/latest/dg/API_DeleteBot.html

        :stability: experimental
        '''
        return typing.cast("LexV2", jsii.invoke(self, "toDeleteBot", []))

    @jsii.member(jsii_name="toDeleteBotAlias")
    def to_delete_bot_alias(self) -> "LexV2":
        '''(experimental) Grants permission to delete an existing bot alias in a bot.

        Access Level: Write

        https://docs.aws.amazon.com/lexv2/latest/dg/API_DeleteBotAlias.html

        :stability: experimental
        '''
        return typing.cast("LexV2", jsii.invoke(self, "toDeleteBotAlias", []))

    @jsii.member(jsii_name="toDeleteBotChannel")
    def to_delete_bot_channel(self) -> "LexV2":
        '''(experimental) Grants permission to delete an existing bot channel.

        Access Level: Write

        https://docs.aws.amazon.com/lexv2/latest/dg/deploying-messaging-platform.html

        :stability: experimental
        '''
        return typing.cast("LexV2", jsii.invoke(self, "toDeleteBotChannel", []))

    @jsii.member(jsii_name="toDeleteBotLocale")
    def to_delete_bot_locale(self) -> "LexV2":
        '''(experimental) Grants permission to delete an existing bot locale in a bot.

        Access Level: Write

        Dependent actions:

        - lex:DeleteIntent
        - lex:DeleteSlot
        - lex:DeleteSlotType

        https://docs.aws.amazon.com/lexv2/latest/dg/API_DeleteBotLocale.html

        :stability: experimental
        '''
        return typing.cast("LexV2", jsii.invoke(self, "toDeleteBotLocale", []))

    @jsii.member(jsii_name="toDeleteBotVersion")
    def to_delete_bot_version(self) -> "LexV2":
        '''(experimental) Grants permission to delete an existing bot version.

        Access Level: Write

        https://docs.aws.amazon.com/lexv2/latest/dg/API_DeleteBotVersion.html

        :stability: experimental
        '''
        return typing.cast("LexV2", jsii.invoke(self, "toDeleteBotVersion", []))

    @jsii.member(jsii_name="toDeleteCustomVocabulary")
    def to_delete_custom_vocabulary(self) -> "LexV2":
        '''(experimental) Grants permission to delete an existing custom vocabulary in a bot locale.

        Access Level: Write

        https://docs.aws.amazon.com/lexv2/latest/dg/API_DeleteCustomVocabulary.html

        :stability: experimental
        '''
        return typing.cast("LexV2", jsii.invoke(self, "toDeleteCustomVocabulary", []))

    @jsii.member(jsii_name="toDeleteExport")
    def to_delete_export(self) -> "LexV2":
        '''(experimental) Grants permission to delete an existing export.

        Access Level: Write

        https://docs.aws.amazon.com/lexv2/latest/dg/API_DeleteExport.html

        :stability: experimental
        '''
        return typing.cast("LexV2", jsii.invoke(self, "toDeleteExport", []))

    @jsii.member(jsii_name="toDeleteImport")
    def to_delete_import(self) -> "LexV2":
        '''(experimental) Grants permission to delete an existing import.

        Access Level: Write

        https://docs.aws.amazon.com/lexv2/latest/dg/API_DeleteImport.html

        :stability: experimental
        '''
        return typing.cast("LexV2", jsii.invoke(self, "toDeleteImport", []))

    @jsii.member(jsii_name="toDeleteIntent")
    def to_delete_intent(self) -> "LexV2":
        '''(experimental) Grants permission to delete an existing intent in a bot locale.

        Access Level: Write

        https://docs.aws.amazon.com/lexv2/latest/dg/API_DeleteIntent.html

        :stability: experimental
        '''
        return typing.cast("LexV2", jsii.invoke(self, "toDeleteIntent", []))

    @jsii.member(jsii_name="toDeleteResourcePolicy")
    def to_delete_resource_policy(self) -> "LexV2":
        '''(experimental) Grants permission to delete an existing resource policy for a Lex resource.

        Access Level: Write

        https://docs.aws.amazon.com/lexv2/latest/dg/API_DeleteResourcePolicy.html

        :stability: experimental
        '''
        return typing.cast("LexV2", jsii.invoke(self, "toDeleteResourcePolicy", []))

    @jsii.member(jsii_name="toDeleteSession")
    def to_delete_session(self) -> "LexV2":
        '''(experimental) Grants permission to delete session information for a bot alias and user ID.

        Access Level: Write

        https://docs.aws.amazon.com/lexv2/latest/dg/API_runtime_DeleteSession.html

        :stability: experimental
        '''
        return typing.cast("LexV2", jsii.invoke(self, "toDeleteSession", []))

    @jsii.member(jsii_name="toDeleteSlot")
    def to_delete_slot(self) -> "LexV2":
        '''(experimental) Grants permission to delete an existing slot in an intent.

        Access Level: Write

        https://docs.aws.amazon.com/lexv2/latest/dg/API_DeleteSlot.html

        :stability: experimental
        '''
        return typing.cast("LexV2", jsii.invoke(self, "toDeleteSlot", []))

    @jsii.member(jsii_name="toDeleteSlotType")
    def to_delete_slot_type(self) -> "LexV2":
        '''(experimental) Grants permission to delete an existing slot type in a bot locale.

        Access Level: Write

        https://docs.aws.amazon.com/lexv2/latest/dg/API_DeleteSlotType.html

        :stability: experimental
        '''
        return typing.cast("LexV2", jsii.invoke(self, "toDeleteSlotType", []))

    @jsii.member(jsii_name="toDeleteUtterances")
    def to_delete_utterances(self) -> "LexV2":
        '''(experimental) Grants permission to delete utterance data for a bot.

        Access Level: Write

        https://docs.aws.amazon.com/lexv2/latest/dg/API_DeleteUtterances.html

        :stability: experimental
        '''
        return typing.cast("LexV2", jsii.invoke(self, "toDeleteUtterances", []))

    @jsii.member(jsii_name="toDescribeBot")
    def to_describe_bot(self) -> "LexV2":
        '''(experimental) Grants permission to retrieve an existing bot.

        Access Level: Read

        https://docs.aws.amazon.com/lexv2/latest/dg/API_DescribeBot.html

        :stability: experimental
        '''
        return typing.cast("LexV2", jsii.invoke(self, "toDescribeBot", []))

    @jsii.member(jsii_name="toDescribeBotAlias")
    def to_describe_bot_alias(self) -> "LexV2":
        '''(experimental) Grants permission to retrieve an existing bot alias.

        Access Level: Read

        https://docs.aws.amazon.com/lexv2/latest/dg/API_DescribeBotAlias.html

        :stability: experimental
        '''
        return typing.cast("LexV2", jsii.invoke(self, "toDescribeBotAlias", []))

    @jsii.member(jsii_name="toDescribeBotChannel")
    def to_describe_bot_channel(self) -> "LexV2":
        '''(experimental) Grants permission to retrieve an existing bot channel.

        Access Level: Read

        https://docs.aws.amazon.com/lexv2/latest/dg/deploying-messaging-platform.html

        :stability: experimental
        '''
        return typing.cast("LexV2", jsii.invoke(self, "toDescribeBotChannel", []))

    @jsii.member(jsii_name="toDescribeBotLocale")
    def to_describe_bot_locale(self) -> "LexV2":
        '''(experimental) Grants permission to retrieve an existing bot locale.

        Access Level: Read

        https://docs.aws.amazon.com/lexv2/latest/dg/API_DescribeBotLocale.html

        :stability: experimental
        '''
        return typing.cast("LexV2", jsii.invoke(self, "toDescribeBotLocale", []))

    @jsii.member(jsii_name="toDescribeBotRecommendation")
    def to_describe_bot_recommendation(self) -> "LexV2":
        '''(experimental) Grants permission to retrieve metadata information about a bot recommendation.

        Access Level: Read

        https://docs.aws.amazon.com/lexv2/latest/dg/API_DescribeBotRecommendation.html

        :stability: experimental
        '''
        return typing.cast("LexV2", jsii.invoke(self, "toDescribeBotRecommendation", []))

    @jsii.member(jsii_name="toDescribeBotVersion")
    def to_describe_bot_version(self) -> "LexV2":
        '''(experimental) Grants permission to retrieve an existing bot version.

        Access Level: Read

        https://docs.aws.amazon.com/lexv2/latest/dg/API_DescribeBotVersion.html

        :stability: experimental
        '''
        return typing.cast("LexV2", jsii.invoke(self, "toDescribeBotVersion", []))

    @jsii.member(jsii_name="toDescribeCustomVocabulary")
    def to_describe_custom_vocabulary(self) -> "LexV2":
        '''(experimental) Grants permission to retrieve an existing custom vocabulary.

        Access Level: Read

        https://docs.aws.amazon.com/lexv2/latest/dg/vocab.html

        :stability: experimental
        '''
        return typing.cast("LexV2", jsii.invoke(self, "toDescribeCustomVocabulary", []))

    @jsii.member(jsii_name="toDescribeCustomVocabularyMetadata")
    def to_describe_custom_vocabulary_metadata(self) -> "LexV2":
        '''(experimental) Grants permission to retrieve metadata of an existing custom vocabulary.

        Access Level: Read

        https://docs.aws.amazon.com/lexv2/latest/dg/API_DescribeCustomVocabularyMetadata.html

        :stability: experimental
        '''
        return typing.cast("LexV2", jsii.invoke(self, "toDescribeCustomVocabularyMetadata", []))

    @jsii.member(jsii_name="toDescribeExport")
    def to_describe_export(self) -> "LexV2":
        '''(experimental) Grants permission to retrieve an existing export.

        Access Level: Read

        Dependent actions:

        - lex:DescribeBot
        - lex:DescribeBotLocale
        - lex:DescribeIntent
        - lex:DescribeSlot
        - lex:DescribeSlotType
        - lex:ListBotLocales
        - lex:ListIntents
        - lex:ListSlotTypes
        - lex:ListSlots

        https://docs.aws.amazon.com/lexv2/latest/dg/API_DescribeExport.html

        :stability: experimental
        '''
        return typing.cast("LexV2", jsii.invoke(self, "toDescribeExport", []))

    @jsii.member(jsii_name="toDescribeImport")
    def to_describe_import(self) -> "LexV2":
        '''(experimental) Grants permission to retrieve an existing import.

        Access Level: Read

        https://docs.aws.amazon.com/lexv2/latest/dg/API_DescribeImport.html

        :stability: experimental
        '''
        return typing.cast("LexV2", jsii.invoke(self, "toDescribeImport", []))

    @jsii.member(jsii_name="toDescribeIntent")
    def to_describe_intent(self) -> "LexV2":
        '''(experimental) Grants permission to retrieve an existing intent.

        Access Level: Read

        https://docs.aws.amazon.com/lexv2/latest/dg/API_DescribeIntent.html

        :stability: experimental
        '''
        return typing.cast("LexV2", jsii.invoke(self, "toDescribeIntent", []))

    @jsii.member(jsii_name="toDescribeResourcePolicy")
    def to_describe_resource_policy(self) -> "LexV2":
        '''(experimental) Grants permission to retrieve an existing resource policy for a Lex resource.

        Access Level: Read

        https://docs.aws.amazon.com/lexv2/latest/dg/API_DescribeResourcePolicy.html

        :stability: experimental
        '''
        return typing.cast("LexV2", jsii.invoke(self, "toDescribeResourcePolicy", []))

    @jsii.member(jsii_name="toDescribeSlot")
    def to_describe_slot(self) -> "LexV2":
        '''(experimental) Grants permission to retrieve an existing slot.

        Access Level: Read

        https://docs.aws.amazon.com/lexv2/latest/dg/API_DescribeSlot.html

        :stability: experimental
        '''
        return typing.cast("LexV2", jsii.invoke(self, "toDescribeSlot", []))

    @jsii.member(jsii_name="toDescribeSlotType")
    def to_describe_slot_type(self) -> "LexV2":
        '''(experimental) Grants permission to retrieve an existing slot type.

        Access Level: Read

        https://docs.aws.amazon.com/lexv2/latest/dg/API_DescribeSlotType.html

        :stability: experimental
        '''
        return typing.cast("LexV2", jsii.invoke(self, "toDescribeSlotType", []))

    @jsii.member(jsii_name="toGetSession")
    def to_get_session(self) -> "LexV2":
        '''(experimental) Grants permission to retrieve session information for a bot alias and user ID.

        Access Level: Read

        https://docs.aws.amazon.com/lexv2/latest/dg/API_runtime_GetSession.html

        :stability: experimental
        '''
        return typing.cast("LexV2", jsii.invoke(self, "toGetSession", []))

    @jsii.member(jsii_name="toListAggregatedUtterances")
    def to_list_aggregated_utterances(self) -> "LexV2":
        '''(experimental) Grants permission to list utterances and statistics for a bot.

        Access Level: List

        https://docs.aws.amazon.com/lexv2/latest/dg/API_ListAggregatedUtterances.html

        :stability: experimental
        '''
        return typing.cast("LexV2", jsii.invoke(self, "toListAggregatedUtterances", []))

    @jsii.member(jsii_name="toListBotAliases")
    def to_list_bot_aliases(self) -> "LexV2":
        '''(experimental) Grants permission to list bot aliases in an bot.

        Access Level: List

        https://docs.aws.amazon.com/lexv2/latest/dg/API_ListBotAliases.html

        :stability: experimental
        '''
        return typing.cast("LexV2", jsii.invoke(self, "toListBotAliases", []))

    @jsii.member(jsii_name="toListBotChannels")
    def to_list_bot_channels(self) -> "LexV2":
        '''(experimental) Grants permission to list bot channels.

        Access Level: List

        https://docs.aws.amazon.com/lexv2/latest/dg/deploying-messaging-platform.html

        :stability: experimental
        '''
        return typing.cast("LexV2", jsii.invoke(self, "toListBotChannels", []))

    @jsii.member(jsii_name="toListBotLocales")
    def to_list_bot_locales(self) -> "LexV2":
        '''(experimental) Grants permission to list bot locales in a bot.

        Access Level: List

        https://docs.aws.amazon.com/lexv2/latest/dg/API_ListBotLocales.html

        :stability: experimental
        '''
        return typing.cast("LexV2", jsii.invoke(self, "toListBotLocales", []))

    @jsii.member(jsii_name="toListBotRecommendations")
    def to_list_bot_recommendations(self) -> "LexV2":
        '''(experimental) Grants permission to get a list of bot recommendations that meet the specified criteria.

        Access Level: List

        https://docs.aws.amazon.com/lexv2/latest/dg/API_ListBotRecommendations.html

        :stability: experimental
        '''
        return typing.cast("LexV2", jsii.invoke(self, "toListBotRecommendations", []))

    @jsii.member(jsii_name="toListBots")
    def to_list_bots(self) -> "LexV2":
        '''(experimental) Grants permission to list existing bots.

        Access Level: List

        https://docs.aws.amazon.com/lexv2/latest/dg/API_ListBots.html

        :stability: experimental
        '''
        return typing.cast("LexV2", jsii.invoke(self, "toListBots", []))

    @jsii.member(jsii_name="toListBotVersions")
    def to_list_bot_versions(self) -> "LexV2":
        '''(experimental) Grants permission to list existing bot versions.

        Access Level: List

        https://docs.aws.amazon.com/lexv2/latest/dg/API_ListBotVersions.html

        :stability: experimental
        '''
        return typing.cast("LexV2", jsii.invoke(self, "toListBotVersions", []))

    @jsii.member(jsii_name="toListBuiltInIntents")
    def to_list_built_in_intents(self) -> "LexV2":
        '''(experimental) Grants permission to list built-in intents.

        Access Level: List

        https://docs.aws.amazon.com/lexv2/latest/dg/API_ListBuiltInIntents.html

        :stability: experimental
        '''
        return typing.cast("LexV2", jsii.invoke(self, "toListBuiltInIntents", []))

    @jsii.member(jsii_name="toListBuiltInSlotTypes")
    def to_list_built_in_slot_types(self) -> "LexV2":
        '''(experimental) Grants permission to list built-in slot types.

        Access Level: List

        https://docs.aws.amazon.com/lexv2/latest/dg/API_ListBuiltInSlotTypes.html

        :stability: experimental
        '''
        return typing.cast("LexV2", jsii.invoke(self, "toListBuiltInSlotTypes", []))

    @jsii.member(jsii_name="toListCustomVocabularyItems")
    def to_list_custom_vocabulary_items(self) -> "LexV2":
        '''(experimental) Grants permission to list items of an existing custom vocabulary.

        Access Level: List

        https://docs.aws.amazon.com/lexv2/latest/dg/API_ListCustomVocabularyItems.html

        :stability: experimental
        '''
        return typing.cast("LexV2", jsii.invoke(self, "toListCustomVocabularyItems", []))

    @jsii.member(jsii_name="toListExports")
    def to_list_exports(self) -> "LexV2":
        '''(experimental) Grants permission to list existing exports.

        Access Level: List

        https://docs.aws.amazon.com/lexv2/latest/dg/API_ListExports.html

        :stability: experimental
        '''
        return typing.cast("LexV2", jsii.invoke(self, "toListExports", []))

    @jsii.member(jsii_name="toListImports")
    def to_list_imports(self) -> "LexV2":
        '''(experimental) Grants permission to list existing imports.

        Access Level: List

        https://docs.aws.amazon.com/lexv2/latest/dg/API_ListImports.html

        :stability: experimental
        '''
        return typing.cast("LexV2", jsii.invoke(self, "toListImports", []))

    @jsii.member(jsii_name="toListIntents")
    def to_list_intents(self) -> "LexV2":
        '''(experimental) Grants permission to list intents in a bot.

        Access Level: List

        https://docs.aws.amazon.com/lexv2/latest/dg/API_ListIntents.html

        :stability: experimental
        '''
        return typing.cast("LexV2", jsii.invoke(self, "toListIntents", []))

    @jsii.member(jsii_name="toListRecommendedIntents")
    def to_list_recommended_intents(self) -> "LexV2":
        '''(experimental) Grants permission to get a list of recommended intents provided by the bot recommendation.

        Access Level: List

        https://docs.aws.amazon.com/lexv2/latest/dg/API_ListRecommendedIntents.html

        :stability: experimental
        '''
        return typing.cast("LexV2", jsii.invoke(self, "toListRecommendedIntents", []))

    @jsii.member(jsii_name="toListSlots")
    def to_list_slots(self) -> "LexV2":
        '''(experimental) Grants permission to list slots in an intent.

        Access Level: List

        https://docs.aws.amazon.com/lexv2/latest/dg/API_ListSlots.html

        :stability: experimental
        '''
        return typing.cast("LexV2", jsii.invoke(self, "toListSlots", []))

    @jsii.member(jsii_name="toListSlotTypes")
    def to_list_slot_types(self) -> "LexV2":
        '''(experimental) Grants permission to list slot types in a bot.

        Access Level: List

        https://docs.aws.amazon.com/lexv2/latest/dg/API_ListSlotTypes.html

        :stability: experimental
        '''
        return typing.cast("LexV2", jsii.invoke(self, "toListSlotTypes", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "LexV2":
        '''(experimental) Grants permission to lists tags for a Lex resource.

        Access Level: Read

        https://docs.aws.amazon.com/lexv2/latest/dg/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("LexV2", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toPutSession")
    def to_put_session(self) -> "LexV2":
        '''(experimental) Grants permission to create a new session or modify an existing session for a bot alias and user ID.

        Access Level: Write

        https://docs.aws.amazon.com/lexv2/latest/dg/API_runtime_PutSession.html

        :stability: experimental
        '''
        return typing.cast("LexV2", jsii.invoke(self, "toPutSession", []))

    @jsii.member(jsii_name="toRecognizeText")
    def to_recognize_text(self) -> "LexV2":
        '''(experimental) Grants permission to send user input (text-only) to an bot alias.

        Access Level: Write

        https://docs.aws.amazon.com/lexv2/latest/dg/API_runtime_RecognizeText.html

        :stability: experimental
        '''
        return typing.cast("LexV2", jsii.invoke(self, "toRecognizeText", []))

    @jsii.member(jsii_name="toRecognizeUtterance")
    def to_recognize_utterance(self) -> "LexV2":
        '''(experimental) Grants permission to send user input (text or speech) to an bot alias.

        Access Level: Write

        https://docs.aws.amazon.com/lexv2/latest/dg/API_runtime_RecognizeUtterance.html

        :stability: experimental
        '''
        return typing.cast("LexV2", jsii.invoke(self, "toRecognizeUtterance", []))

    @jsii.member(jsii_name="toSearchAssociatedTranscripts")
    def to_search_associated_transcripts(self) -> "LexV2":
        '''(experimental) Grants permission to search for associated transcripts that meet the specified criteria.

        Access Level: List

        https://docs.aws.amazon.com/lexv2/latest/dg/API_SearchAssociatedTranscripts.html

        :stability: experimental
        '''
        return typing.cast("LexV2", jsii.invoke(self, "toSearchAssociatedTranscripts", []))

    @jsii.member(jsii_name="toStartBotRecommendation")
    def to_start_bot_recommendation(self) -> "LexV2":
        '''(experimental) Grants permission to start a bot recommendation for an existing bot locale.

        Access Level: Write

        https://docs.aws.amazon.com/lexv2/latest/dg/API_StartBotRecommendation.html

        :stability: experimental
        '''
        return typing.cast("LexV2", jsii.invoke(self, "toStartBotRecommendation", []))

    @jsii.member(jsii_name="toStartConversation")
    def to_start_conversation(self) -> "LexV2":
        '''(experimental) Grants permission to stream user input (speech/text/DTMF) to a bot alias.

        Access Level: Write

        https://docs.aws.amazon.com/lexv2/latest/dg/API_runtime_StartConversation.html

        :stability: experimental
        '''
        return typing.cast("LexV2", jsii.invoke(self, "toStartConversation", []))

    @jsii.member(jsii_name="toStartImport")
    def to_start_import(self) -> "LexV2":
        '''(experimental) Grants permission to start a new import with the uploaded import file.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        Dependent actions:

        - lex:CreateBot
        - lex:CreateBotLocale
        - lex:CreateIntent
        - lex:CreateSlot
        - lex:CreateSlotType
        - lex:DeleteBotLocale
        - lex:DeleteIntent
        - lex:DeleteSlot
        - lex:DeleteSlotType
        - lex:UpdateBot
        - lex:UpdateBotLocale
        - lex:UpdateIntent
        - lex:UpdateSlot
        - lex:UpdateSlotType

        https://docs.aws.amazon.com/lexv2/latest/dg/API_StartImport.html

        :stability: experimental
        '''
        return typing.cast("LexV2", jsii.invoke(self, "toStartImport", []))

    @jsii.member(jsii_name="toStopBotRecommendation")
    def to_stop_bot_recommendation(self) -> "LexV2":
        '''(experimental) Grants permission to stop a bot recommendation for an existing bot locale.

        Access Level: Write

        https://docs.aws.amazon.com/lexv2/latest/dg/API_StopBotRecommendation.html

        :stability: experimental
        '''
        return typing.cast("LexV2", jsii.invoke(self, "toStopBotRecommendation", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "LexV2":
        '''(experimental) Grants permission to add or overwrite tags of a Lex resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/lexv2/latest/dg/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("LexV2", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "LexV2":
        '''(experimental) Grants permission to remove tags from a Lex resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/lexv2/latest/dg/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("LexV2", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateBot")
    def to_update_bot(self) -> "LexV2":
        '''(experimental) Grants permission to update an existing bot.

        Access Level: Write

        https://docs.aws.amazon.com/lexv2/latest/dg/API_UpdateBot.html

        :stability: experimental
        '''
        return typing.cast("LexV2", jsii.invoke(self, "toUpdateBot", []))

    @jsii.member(jsii_name="toUpdateBotAlias")
    def to_update_bot_alias(self) -> "LexV2":
        '''(experimental) Grants permission to update an existing bot alias.

        Access Level: Write

        https://docs.aws.amazon.com/lexv2/latest/dg/API_UpdateBotAlias.html

        :stability: experimental
        '''
        return typing.cast("LexV2", jsii.invoke(self, "toUpdateBotAlias", []))

    @jsii.member(jsii_name="toUpdateBotLocale")
    def to_update_bot_locale(self) -> "LexV2":
        '''(experimental) Grants permission to update an existing bot locale.

        Access Level: Write

        https://docs.aws.amazon.com/lexv2/latest/dg/API_UpdateBotLocale.html

        :stability: experimental
        '''
        return typing.cast("LexV2", jsii.invoke(self, "toUpdateBotLocale", []))

    @jsii.member(jsii_name="toUpdateBotRecommendation")
    def to_update_bot_recommendation(self) -> "LexV2":
        '''(experimental) Grants permission to update an existing bot recommendation request.

        Access Level: Write

        https://docs.aws.amazon.com/lexv2/latest/dg/API_UpdateBotRecommendation.html

        :stability: experimental
        '''
        return typing.cast("LexV2", jsii.invoke(self, "toUpdateBotRecommendation", []))

    @jsii.member(jsii_name="toUpdateCustomVocabulary")
    def to_update_custom_vocabulary(self) -> "LexV2":
        '''(experimental) Grants permission to update an existing custom vocabulary.

        Access Level: Write

        https://docs.aws.amazon.com/lexv2/latest/dg/vocab.html

        :stability: experimental
        '''
        return typing.cast("LexV2", jsii.invoke(self, "toUpdateCustomVocabulary", []))

    @jsii.member(jsii_name="toUpdateExport")
    def to_update_export(self) -> "LexV2":
        '''(experimental) Grants permission to update an existing export.

        Access Level: Write

        https://docs.aws.amazon.com/lexv2/latest/dg/API_UpdateExport.html

        :stability: experimental
        '''
        return typing.cast("LexV2", jsii.invoke(self, "toUpdateExport", []))

    @jsii.member(jsii_name="toUpdateIntent")
    def to_update_intent(self) -> "LexV2":
        '''(experimental) Grants permission to update an existing intent.

        Access Level: Write

        https://docs.aws.amazon.com/lexv2/latest/dg/API_UpdateIntent.html

        :stability: experimental
        '''
        return typing.cast("LexV2", jsii.invoke(self, "toUpdateIntent", []))

    @jsii.member(jsii_name="toUpdateResourcePolicy")
    def to_update_resource_policy(self) -> "LexV2":
        '''(experimental) Grants permission to update an existing resource policy for a Lex resource.

        Access Level: Write

        https://docs.aws.amazon.com/lexv2/latest/dg/API_UpdateResourcePolicy.html

        :stability: experimental
        '''
        return typing.cast("LexV2", jsii.invoke(self, "toUpdateResourcePolicy", []))

    @jsii.member(jsii_name="toUpdateSlot")
    def to_update_slot(self) -> "LexV2":
        '''(experimental) Grants permission to update an existing slot.

        Access Level: Write

        https://docs.aws.amazon.com/lexv2/latest/dg/API_UpdateSlot.html

        :stability: experimental
        '''
        return typing.cast("LexV2", jsii.invoke(self, "toUpdateSlot", []))

    @jsii.member(jsii_name="toUpdateSlotType")
    def to_update_slot_type(self) -> "LexV2":
        '''(experimental) Grants permission to update an existing slot type.

        Access Level: Write

        https://docs.aws.amazon.com/lexv2/latest/dg/API_UpdateSlotType.html

        :stability: experimental
        '''
        return typing.cast("LexV2", jsii.invoke(self, "toUpdateSlotType", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__53ecf92774f850348b7985a4dadb8dcee557848e23702691c3434a5a7a88339b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0cdf86f660fdedda95728c68cc9548e45cfe910acf52bc58e67d8cdf40685aaf)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class LicenseManager(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.LicenseManager",
):
    '''(experimental) Statement provider for service `license-manager <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awslicensemanager.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `license-manager <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awslicensemanager.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="ifResourceTag")
    def if_resource_tag(
        self,
        tag_key: builtins.str,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "LicenseManager":
        '''(experimental) Filters access by the tag key-value pairs attached to the resource.

        https://docs.aws.amazon.com/license-manager/latest/userguide/identity-access-management.html

        Applies to resource types:

        - license-configuration
        - report-generator

        :param tag_key: The tag key to check.
        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a06416cb5b144c144eea6b9b3f240cc2efb62c6a31eec630cdc43ff959b197fa)
            check_type(argname="argument tag_key", value=tag_key, expected_type=type_hints["tag_key"])
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("LicenseManager", jsii.invoke(self, "ifResourceTag", [tag_key, value, operator]))

    @jsii.member(jsii_name="onGrant")
    def on_grant(
        self,
        grant_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "LicenseManager":
        '''(experimental) Adds a resource of type grant to the statement.

        https://docs.aws.amazon.com/license-manager/latest/userguide/granted-licenses.html

        :param grant_id: - Identifier for the grantId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b3bd28fbce7eb014a62380c98c1b0a78b66ff2dbc19478bb0117e6cdb504fc89)
            check_type(argname="argument grant_id", value=grant_id, expected_type=type_hints["grant_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("LicenseManager", jsii.invoke(self, "onGrant", [grant_id, account, partition]))

    @jsii.member(jsii_name="onLicense")
    def on_license(
        self,
        license_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "LicenseManager":
        '''(experimental) Adds a resource of type license to the statement.

        https://docs.aws.amazon.com/license-manager/latest/userguide/seller-issued-licenses.html

        :param license_id: - Identifier for the licenseId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ad82a6b497e2bbbb12e72726fe72ebc40b93db43e45f6282d1a20881bf8b7a0a)
            check_type(argname="argument license_id", value=license_id, expected_type=type_hints["license_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("LicenseManager", jsii.invoke(self, "onLicense", [license_id, account, partition]))

    @jsii.member(jsii_name="onLicenseConfiguration")
    def on_license_configuration(
        self,
        license_configuration_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "LicenseManager":
        '''(experimental) Adds a resource of type license-configuration to the statement.

        https://docs.aws.amazon.com/license-manager/latest/userguide/license-configurations.html

        :param license_configuration_id: - Identifier for the licenseConfigurationId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fa556e1040be985898d1367b2a119f62e7c8f30342b0c69c0a9b91cc921392ce)
            check_type(argname="argument license_configuration_id", value=license_configuration_id, expected_type=type_hints["license_configuration_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("LicenseManager", jsii.invoke(self, "onLicenseConfiguration", [license_configuration_id, account, region, partition]))

    @jsii.member(jsii_name="onReportGenerator")
    def on_report_generator(
        self,
        report_generator_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "LicenseManager":
        '''(experimental) Adds a resource of type report-generator to the statement.

        https://docs.aws.amazon.com/license-manager/latest/userguide/report-generators.html

        :param report_generator_id: - Identifier for the reportGeneratorId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f2c999921f3c2987757901e29eb58157d334ddca2e73dde6b57be86ada6d93e3)
            check_type(argname="argument report_generator_id", value=report_generator_id, expected_type=type_hints["report_generator_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("LicenseManager", jsii.invoke(self, "onReportGenerator", [report_generator_id, account, region, partition]))

    @jsii.member(jsii_name="toAcceptGrant")
    def to_accept_grant(self) -> "LicenseManager":
        '''(experimental) Grants permission to accept a grant.

        Access Level: Write

        https://docs.aws.amazon.com/license-manager/latest/APIReference/API_AcceptGrant.html

        :stability: experimental
        '''
        return typing.cast("LicenseManager", jsii.invoke(self, "toAcceptGrant", []))

    @jsii.member(jsii_name="toCheckInLicense")
    def to_check_in_license(self) -> "LicenseManager":
        '''(experimental) Grants permission to check in license entitlements back to pool.

        Access Level: Write

        https://docs.aws.amazon.com/license-manager/latest/APIReference/API_CheckInLicense.html

        :stability: experimental
        '''
        return typing.cast("LicenseManager", jsii.invoke(self, "toCheckInLicense", []))

    @jsii.member(jsii_name="toCheckoutBorrowLicense")
    def to_checkout_borrow_license(self) -> "LicenseManager":
        '''(experimental) Grants permission to check out license entitlements for borrow use case.

        Access Level: Write

        https://docs.aws.amazon.com/license-manager/latest/APIReference/API_CheckoutBorrowLicense.html

        :stability: experimental
        '''
        return typing.cast("LicenseManager", jsii.invoke(self, "toCheckoutBorrowLicense", []))

    @jsii.member(jsii_name="toCheckoutLicense")
    def to_checkout_license(self) -> "LicenseManager":
        '''(experimental) Grants permission to check out license entitlements.

        Access Level: Write

        https://docs.aws.amazon.com/license-manager/latest/APIReference/API_CheckoutLicense.html

        :stability: experimental
        '''
        return typing.cast("LicenseManager", jsii.invoke(self, "toCheckoutLicense", []))

    @jsii.member(jsii_name="toCreateGrant")
    def to_create_grant(self) -> "LicenseManager":
        '''(experimental) Grants permission to create a new grant for license.

        Access Level: Write

        https://docs.aws.amazon.com/license-manager/latest/APIReference/API_CreateGrant.html

        :stability: experimental
        '''
        return typing.cast("LicenseManager", jsii.invoke(self, "toCreateGrant", []))

    @jsii.member(jsii_name="toCreateGrantVersion")
    def to_create_grant_version(self) -> "LicenseManager":
        '''(experimental) Grants permission to create new version of grant.

        Access Level: Write

        https://docs.aws.amazon.com/license-manager/latest/APIReference/API_CreateGrantVersion.html

        :stability: experimental
        '''
        return typing.cast("LicenseManager", jsii.invoke(self, "toCreateGrantVersion", []))

    @jsii.member(jsii_name="toCreateLicense")
    def to_create_license(self) -> "LicenseManager":
        '''(experimental) Grants permission to create a new license.

        Access Level: Write

        https://docs.aws.amazon.com/license-manager/latest/APIReference/API_CreateLicense.html

        :stability: experimental
        '''
        return typing.cast("LicenseManager", jsii.invoke(self, "toCreateLicense", []))

    @jsii.member(jsii_name="toCreateLicenseConfiguration")
    def to_create_license_configuration(self) -> "LicenseManager":
        '''(experimental) Grants permission to create a new license configuration.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/license-manager/latest/APIReference/API_CreateLicenseConfiguration.html

        :stability: experimental
        '''
        return typing.cast("LicenseManager", jsii.invoke(self, "toCreateLicenseConfiguration", []))

    @jsii.member(jsii_name="toCreateLicenseConversionTaskForResource")
    def to_create_license_conversion_task_for_resource(self) -> "LicenseManager":
        '''(experimental) Grants permission to create a license conversion task for a resource.

        Access Level: Write

        https://docs.aws.amazon.com/license-manager/latest/APIReference/API_CreateLicenseConversionTaskForResource.html

        :stability: experimental
        '''
        return typing.cast("LicenseManager", jsii.invoke(self, "toCreateLicenseConversionTaskForResource", []))

    @jsii.member(jsii_name="toCreateLicenseManagerReportGenerator")
    def to_create_license_manager_report_generator(self) -> "LicenseManager":
        '''(experimental) Grants permission to create a report generator for a license configuration.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/license-manager/latest/APIReference/API_CreateLicenseManagerReportGenerator.html

        :stability: experimental
        '''
        return typing.cast("LicenseManager", jsii.invoke(self, "toCreateLicenseManagerReportGenerator", []))

    @jsii.member(jsii_name="toCreateLicenseVersion")
    def to_create_license_version(self) -> "LicenseManager":
        '''(experimental) Grants permission to create new version of license.

        Access Level: Write

        https://docs.aws.amazon.com/license-manager/latest/APIReference/API_CreateLicenseVersion.html

        :stability: experimental
        '''
        return typing.cast("LicenseManager", jsii.invoke(self, "toCreateLicenseVersion", []))

    @jsii.member(jsii_name="toCreateToken")
    def to_create_token(self) -> "LicenseManager":
        '''(experimental) Grants permission to create a new token for license.

        Access Level: Write

        https://docs.aws.amazon.com/license-manager/latest/APIReference/API_CreateToken.html

        :stability: experimental
        '''
        return typing.cast("LicenseManager", jsii.invoke(self, "toCreateToken", []))

    @jsii.member(jsii_name="toDeleteGrant")
    def to_delete_grant(self) -> "LicenseManager":
        '''(experimental) Grants permission to delete a grant.

        Access Level: Write

        https://docs.aws.amazon.com/license-manager/latest/APIReference/API_DeleteGrant.html

        :stability: experimental
        '''
        return typing.cast("LicenseManager", jsii.invoke(self, "toDeleteGrant", []))

    @jsii.member(jsii_name="toDeleteLicense")
    def to_delete_license(self) -> "LicenseManager":
        '''(experimental) Grants permission to delete a license.

        Access Level: Write

        https://docs.aws.amazon.com/license-manager/latest/APIReference/API_DeleteLicense.html

        :stability: experimental
        '''
        return typing.cast("LicenseManager", jsii.invoke(self, "toDeleteLicense", []))

    @jsii.member(jsii_name="toDeleteLicenseConfiguration")
    def to_delete_license_configuration(self) -> "LicenseManager":
        '''(experimental) Grants permission to permanently delete a license configuration.

        Access Level: Write

        https://docs.aws.amazon.com/license-manager/latest/APIReference/API_DeleteLicenseConfiguration.html

        :stability: experimental
        '''
        return typing.cast("LicenseManager", jsii.invoke(self, "toDeleteLicenseConfiguration", []))

    @jsii.member(jsii_name="toDeleteLicenseManagerReportGenerator")
    def to_delete_license_manager_report_generator(self) -> "LicenseManager":
        '''(experimental) Grants permission to delete a report generator.

        Access Level: Write

        https://docs.aws.amazon.com/license-manager/latest/APIReference/API_DeleteLicenseManagerReportGenerator.html

        :stability: experimental
        '''
        return typing.cast("LicenseManager", jsii.invoke(self, "toDeleteLicenseManagerReportGenerator", []))

    @jsii.member(jsii_name="toDeleteToken")
    def to_delete_token(self) -> "LicenseManager":
        '''(experimental) Grants permission to delete token.

        Access Level: Write

        https://docs.aws.amazon.com/license-manager/latest/APIReference/API_DeleteToken.html

        :stability: experimental
        '''
        return typing.cast("LicenseManager", jsii.invoke(self, "toDeleteToken", []))

    @jsii.member(jsii_name="toExtendLicenseConsumption")
    def to_extend_license_consumption(self) -> "LicenseManager":
        '''(experimental) Grants permission to extend consumption period of already checkout license entitlements.

        Access Level: Write

        https://docs.aws.amazon.com/license-manager/latest/APIReference/API_ExtendLicenseConsumption.html

        :stability: experimental
        '''
        return typing.cast("LicenseManager", jsii.invoke(self, "toExtendLicenseConsumption", []))

    @jsii.member(jsii_name="toGetAccessToken")
    def to_get_access_token(self) -> "LicenseManager":
        '''(experimental) Grants permission to get access token.

        Access Level: Read

        https://docs.aws.amazon.com/license-manager/latest/APIReference/API_GetAccessToken.html

        :stability: experimental
        '''
        return typing.cast("LicenseManager", jsii.invoke(self, "toGetAccessToken", []))

    @jsii.member(jsii_name="toGetGrant")
    def to_get_grant(self) -> "LicenseManager":
        '''(experimental) Grants permission to get a grant.

        Access Level: Read

        https://docs.aws.amazon.com/license-manager/latest/APIReference/API_GetGrant.html

        :stability: experimental
        '''
        return typing.cast("LicenseManager", jsii.invoke(self, "toGetGrant", []))

    @jsii.member(jsii_name="toGetLicense")
    def to_get_license(self) -> "LicenseManager":
        '''(experimental) Grants permission to get a license.

        Access Level: Read

        https://docs.aws.amazon.com/license-manager/latest/APIReference/API_GetLicense.html

        :stability: experimental
        '''
        return typing.cast("LicenseManager", jsii.invoke(self, "toGetLicense", []))

    @jsii.member(jsii_name="toGetLicenseConfiguration")
    def to_get_license_configuration(self) -> "LicenseManager":
        '''(experimental) Grants permission to get a license configuration.

        Access Level: Read

        https://docs.aws.amazon.com/license-manager/latest/APIReference/API_GetLicenseConfiguration.html

        :stability: experimental
        '''
        return typing.cast("LicenseManager", jsii.invoke(self, "toGetLicenseConfiguration", []))

    @jsii.member(jsii_name="toGetLicenseConversionTask")
    def to_get_license_conversion_task(self) -> "LicenseManager":
        '''(experimental) Grants permission to retrieve a license conversion task.

        Access Level: Read

        https://docs.aws.amazon.com/license-manager/latest/APIReference/API_GetLicenseConversionTask.html

        :stability: experimental
        '''
        return typing.cast("LicenseManager", jsii.invoke(self, "toGetLicenseConversionTask", []))

    @jsii.member(jsii_name="toGetLicenseManagerReportGenerator")
    def to_get_license_manager_report_generator(self) -> "LicenseManager":
        '''(experimental) Grants permission to get a report generator.

        Access Level: Read

        https://docs.aws.amazon.com/license-manager/latest/APIReference/API_GetLicenseManagerReportGenerator.html

        :stability: experimental
        '''
        return typing.cast("LicenseManager", jsii.invoke(self, "toGetLicenseManagerReportGenerator", []))

    @jsii.member(jsii_name="toGetLicenseUsage")
    def to_get_license_usage(self) -> "LicenseManager":
        '''(experimental) Grants permission to get a license usage.

        Access Level: Read

        https://docs.aws.amazon.com/license-manager/latest/APIReference/API_GetLicenseUsage.html

        :stability: experimental
        '''
        return typing.cast("LicenseManager", jsii.invoke(self, "toGetLicenseUsage", []))

    @jsii.member(jsii_name="toGetServiceSettings")
    def to_get_service_settings(self) -> "LicenseManager":
        '''(experimental) Grants permission to get service settings.

        Access Level: List

        https://docs.aws.amazon.com/license-manager/latest/APIReference/API_GetServiceSettings.html

        :stability: experimental
        '''
        return typing.cast("LicenseManager", jsii.invoke(self, "toGetServiceSettings", []))

    @jsii.member(jsii_name="toListAssociationsForLicenseConfiguration")
    def to_list_associations_for_license_configuration(self) -> "LicenseManager":
        '''(experimental) Grants permission to list associations for a selected license configuration.

        Access Level: List

        https://docs.aws.amazon.com/license-manager/latest/APIReference/API_ListAssociationsForLicenseConfiguration.html

        :stability: experimental
        '''
        return typing.cast("LicenseManager", jsii.invoke(self, "toListAssociationsForLicenseConfiguration", []))

    @jsii.member(jsii_name="toListDistributedGrants")
    def to_list_distributed_grants(self) -> "LicenseManager":
        '''(experimental) Grants permission to list distributed grants.

        Access Level: List

        https://docs.aws.amazon.com/license-manager/latest/APIReference/API_ListDistributedGrants.html

        :stability: experimental
        '''
        return typing.cast("LicenseManager", jsii.invoke(self, "toListDistributedGrants", []))

    @jsii.member(jsii_name="toListFailuresForLicenseConfigurationOperations")
    def to_list_failures_for_license_configuration_operations(self) -> "LicenseManager":
        '''(experimental) Grants permission to list the license configuration operations that failed.

        Access Level: List

        https://docs.aws.amazon.com/license-manager/latest/APIReference/API_ListFailuresForLicenseConfigurationOperations.html

        :stability: experimental
        '''
        return typing.cast("LicenseManager", jsii.invoke(self, "toListFailuresForLicenseConfigurationOperations", []))

    @jsii.member(jsii_name="toListLicenseConfigurations")
    def to_list_license_configurations(self) -> "LicenseManager":
        '''(experimental) Grants permission to list license configurations.

        Access Level: Read

        https://docs.aws.amazon.com/license-manager/latest/APIReference/API_ListLicenseConfigurations.html

        :stability: experimental
        '''
        return typing.cast("LicenseManager", jsii.invoke(self, "toListLicenseConfigurations", []))

    @jsii.member(jsii_name="toListLicenseConversionTasks")
    def to_list_license_conversion_tasks(self) -> "LicenseManager":
        '''(experimental) Grants permission to list license conversion tasks.

        Access Level: List

        https://docs.aws.amazon.com/license-manager/latest/APIReference/API_ListLicenseConversionTasks.html

        :stability: experimental
        '''
        return typing.cast("LicenseManager", jsii.invoke(self, "toListLicenseConversionTasks", []))

    @jsii.member(jsii_name="toListLicenseManagerReportGenerators")
    def to_list_license_manager_report_generators(self) -> "LicenseManager":
        '''(experimental) Grants permission to list report generators.

        Access Level: List

        https://docs.aws.amazon.com/license-manager/latest/APIReference/API_ListLicenseManagerReportGenerators.html

        :stability: experimental
        '''
        return typing.cast("LicenseManager", jsii.invoke(self, "toListLicenseManagerReportGenerators", []))

    @jsii.member(jsii_name="toListLicenses")
    def to_list_licenses(self) -> "LicenseManager":
        '''(experimental) Grants permission to list licenses.

        Access Level: Read

        https://docs.aws.amazon.com/license-manager/latest/APIReference/API_ListLicenses.html

        :stability: experimental
        '''
        return typing.cast("LicenseManager", jsii.invoke(self, "toListLicenses", []))

    @jsii.member(jsii_name="toListLicenseSpecificationsForResource")
    def to_list_license_specifications_for_resource(self) -> "LicenseManager":
        '''(experimental) Grants permission to list license specifications associated with a selected resource.

        Access Level: List

        https://docs.aws.amazon.com/license-manager/latest/APIReference/API_ListLicenseSpecificationsForResource.html

        :stability: experimental
        '''
        return typing.cast("LicenseManager", jsii.invoke(self, "toListLicenseSpecificationsForResource", []))

    @jsii.member(jsii_name="toListLicenseVersions")
    def to_list_license_versions(self) -> "LicenseManager":
        '''(experimental) Grants permission to list license versions.

        Access Level: List

        https://docs.aws.amazon.com/license-manager/latest/APIReference/API_ListLicenseVersions.html

        :stability: experimental
        '''
        return typing.cast("LicenseManager", jsii.invoke(self, "toListLicenseVersions", []))

    @jsii.member(jsii_name="toListReceivedGrants")
    def to_list_received_grants(self) -> "LicenseManager":
        '''(experimental) Grants permission to list received grants.

        Access Level: List

        https://docs.aws.amazon.com/license-manager/latest/APIReference/API_ListReceivedGrants.html

        :stability: experimental
        '''
        return typing.cast("LicenseManager", jsii.invoke(self, "toListReceivedGrants", []))

    @jsii.member(jsii_name="toListReceivedGrantsForOrganization")
    def to_list_received_grants_for_organization(self) -> "LicenseManager":
        '''(experimental) Grants permission to list received grants for organization.

        Access Level: List

        https://docs.aws.amazon.com/license-manager/latest/APIReference/API_ListReceivedGrantsForOrganization.html

        :stability: experimental
        '''
        return typing.cast("LicenseManager", jsii.invoke(self, "toListReceivedGrantsForOrganization", []))

    @jsii.member(jsii_name="toListReceivedLicenses")
    def to_list_received_licenses(self) -> "LicenseManager":
        '''(experimental) Grants permission to list received licenses.

        Access Level: List

        https://docs.aws.amazon.com/license-manager/latest/APIReference/API_ListReceivedLicenses.html

        :stability: experimental
        '''
        return typing.cast("LicenseManager", jsii.invoke(self, "toListReceivedLicenses", []))

    @jsii.member(jsii_name="toListReceivedLicensesForOrganization")
    def to_list_received_licenses_for_organization(self) -> "LicenseManager":
        '''(experimental) Grants permission to list received licenses for organization.

        Access Level: List

        https://docs.aws.amazon.com/license-manager/latest/APIReference/API_ListReceivedLicensesForOrganization.html

        :stability: experimental
        '''
        return typing.cast("LicenseManager", jsii.invoke(self, "toListReceivedLicensesForOrganization", []))

    @jsii.member(jsii_name="toListResourceInventory")
    def to_list_resource_inventory(self) -> "LicenseManager":
        '''(experimental) Grants permission to list resource inventory.

        Access Level: List

        https://docs.aws.amazon.com/license-manager/latest/APIReference/API_ListResourceInventory.html

        :stability: experimental
        '''
        return typing.cast("LicenseManager", jsii.invoke(self, "toListResourceInventory", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "LicenseManager":
        '''(experimental) Grants permission to list tags for a selected resource.

        Access Level: Read

        https://docs.aws.amazon.com/license-manager/latest/APIReference/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("LicenseManager", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toListTokens")
    def to_list_tokens(self) -> "LicenseManager":
        '''(experimental) Grants permission to list tokens.

        Access Level: List

        https://docs.aws.amazon.com/license-manager/latest/APIReference/API_ListTokens.html

        :stability: experimental
        '''
        return typing.cast("LicenseManager", jsii.invoke(self, "toListTokens", []))

    @jsii.member(jsii_name="toListUsageForLicenseConfiguration")
    def to_list_usage_for_license_configuration(self) -> "LicenseManager":
        '''(experimental) Grants permission to list usage records for selected license configuration.

        Access Level: List

        https://docs.aws.amazon.com/license-manager/latest/APIReference/API_ListUsageForLicenseConfiguration.html

        :stability: experimental
        '''
        return typing.cast("LicenseManager", jsii.invoke(self, "toListUsageForLicenseConfiguration", []))

    @jsii.member(jsii_name="toRejectGrant")
    def to_reject_grant(self) -> "LicenseManager":
        '''(experimental) Grants permission to reject a grant.

        Access Level: Write

        https://docs.aws.amazon.com/license-manager/latest/APIReference/API_RejectGrant.html

        :stability: experimental
        '''
        return typing.cast("LicenseManager", jsii.invoke(self, "toRejectGrant", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "LicenseManager":
        '''(experimental) Grants permission to tag a selected resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/license-manager/latest/APIReference/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("LicenseManager", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "LicenseManager":
        '''(experimental) Grants permission to untag a selected resource.

        Access Level: Tagging

        https://docs.aws.amazon.com/license-manager/latest/APIReference/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("LicenseManager", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateLicenseConfiguration")
    def to_update_license_configuration(self) -> "LicenseManager":
        '''(experimental) Grants permission to update an existing license configuration.

        Access Level: Write

        https://docs.aws.amazon.com/license-manager/latest/APIReference/API_UpdateLicenseConfiguration.html

        :stability: experimental
        '''
        return typing.cast("LicenseManager", jsii.invoke(self, "toUpdateLicenseConfiguration", []))

    @jsii.member(jsii_name="toUpdateLicenseManagerReportGenerator")
    def to_update_license_manager_report_generator(self) -> "LicenseManager":
        '''(experimental) Grants permission to update a report generator for a license configuration.

        Access Level: Write

        https://docs.aws.amazon.com/license-manager/latest/APIReference/API_UpdateLicenseManagerReportGenerator.html

        :stability: experimental
        '''
        return typing.cast("LicenseManager", jsii.invoke(self, "toUpdateLicenseManagerReportGenerator", []))

    @jsii.member(jsii_name="toUpdateLicenseSpecificationsForResource")
    def to_update_license_specifications_for_resource(self) -> "LicenseManager":
        '''(experimental) Grants permission to updates license specifications for a selected resource.

        Access Level: Write

        https://docs.aws.amazon.com/license-manager/latest/APIReference/API_UpdateLicenseSpecificationsForResource.html

        :stability: experimental
        '''
        return typing.cast("LicenseManager", jsii.invoke(self, "toUpdateLicenseSpecificationsForResource", []))

    @jsii.member(jsii_name="toUpdateServiceSettings")
    def to_update_service_settings(self) -> "LicenseManager":
        '''(experimental) Grants permission to updates service settings.

        Access Level: Permissions management

        https://docs.aws.amazon.com/license-manager/latest/APIReference/API_UpdateServiceSettings.html

        :stability: experimental
        '''
        return typing.cast("LicenseManager", jsii.invoke(self, "toUpdateServiceSettings", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c704090f94d7b6b5ecd07d999cef6118936deacd8dd5066ae3a9ba666e7d6dec)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__cea42467a8b93f55a70e2d6ffa8b000ec3c10613e828c69404eaf9fef80dd53a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class LicenseManagerLinuxSubscriptions(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.LicenseManagerLinuxSubscriptions",
):
    '''(experimental) Statement provider for service `license-manager-linux-subscriptions <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awslicensemanagerlinuxsubscriptionsmanager.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `license-manager-linux-subscriptions <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awslicensemanagerlinuxsubscriptionsmanager.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="toGetServiceSettings")
    def to_get_service_settings(self) -> "LicenseManagerLinuxSubscriptions":
        '''(experimental) Grants permission to get the service settings for Linux subscriptions in AWS License Manager.

        Access Level: Write

        https://docs.aws.amazon.com/license-manager/latest/APIReference/API_GetServiceSettings.html

        :stability: experimental
        '''
        return typing.cast("LicenseManagerLinuxSubscriptions", jsii.invoke(self, "toGetServiceSettings", []))

    @jsii.member(jsii_name="toListLinuxSubscriptionInstances")
    def to_list_linux_subscription_instances(
        self,
    ) -> "LicenseManagerLinuxSubscriptions":
        '''(experimental) Grants permission to list all instances with Linux subscriptions in AWS License Manager.

        Access Level: Write

        https://docs.aws.amazon.com/license-manager/latest/APIReference/API_ListLinuxSubscriptionInstances.html

        :stability: experimental
        '''
        return typing.cast("LicenseManagerLinuxSubscriptions", jsii.invoke(self, "toListLinuxSubscriptionInstances", []))

    @jsii.member(jsii_name="toListLinuxSubscriptions")
    def to_list_linux_subscriptions(self) -> "LicenseManagerLinuxSubscriptions":
        '''(experimental) Grants permission to list all Linux subscriptions in AWS License Manager.

        Access Level: Write

        https://docs.aws.amazon.com/license-manager/latest/APIReference/API_ListLinuxSubscriptions.html

        :stability: experimental
        '''
        return typing.cast("LicenseManagerLinuxSubscriptions", jsii.invoke(self, "toListLinuxSubscriptions", []))

    @jsii.member(jsii_name="toUpdateServiceSettings")
    def to_update_service_settings(self) -> "LicenseManagerLinuxSubscriptions":
        '''(experimental) Grants permission to update the service settings for Linux subscriptions in AWS License Manager.

        Access Level: Write

        https://docs.aws.amazon.com/license-manager/latest/APIReference/API_UpdateServiceSettings.html

        :stability: experimental
        '''
        return typing.cast("LicenseManagerLinuxSubscriptions", jsii.invoke(self, "toUpdateServiceSettings", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fd51e23e77e7c8f79d99094838f2108450c872a04bf1eb5f9517cd971fffaecc)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c91c73ce57c5466a8d7cc13978cf6ac99a10ca4612025038309bac3098949cea)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class LicenseManagerUserSubscriptions(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.LicenseManagerUserSubscriptions",
):
    '''(experimental) Statement provider for service `license-manager-user-subscriptions <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awslicensemanagerusersubscriptions.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `license-manager-user-subscriptions <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awslicensemanagerusersubscriptions.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="toAssociateUser")
    def to_associate_user(self) -> "LicenseManagerUserSubscriptions":
        '''(experimental) Grants permission to associate a subscribed user to an instance launched with license manager user subscriptions products.

        Access Level: Write

        https://docs.aws.amazon.com/license-manager-user-subscriptions/latest/APIReference/API_AssociateUser.html

        :stability: experimental
        '''
        return typing.cast("LicenseManagerUserSubscriptions", jsii.invoke(self, "toAssociateUser", []))

    @jsii.member(jsii_name="toDeregisterIdentityProvider")
    def to_deregister_identity_provider(self) -> "LicenseManagerUserSubscriptions":
        '''(experimental) Grants permission to deregister Microsoft Active Directory with license-manager-user-subscriptions for a product.

        Access Level: Write

        https://docs.aws.amazon.com/license-manager-user-subscriptions/latest/APIReference/API_DeregisterIdentityProvider.html

        :stability: experimental
        '''
        return typing.cast("LicenseManagerUserSubscriptions", jsii.invoke(self, "toDeregisterIdentityProvider", []))

    @jsii.member(jsii_name="toDisassociateUser")
    def to_disassociate_user(self) -> "LicenseManagerUserSubscriptions":
        '''(experimental) Grants permission to disassociate a subscribed user from an instance launched with license manager user subscriptions products.

        Access Level: Write

        https://docs.aws.amazon.com/license-manager-user-subscriptions/latest/APIReference/API_DisassociateUser.html

        :stability: experimental
        '''
        return typing.cast("LicenseManagerUserSubscriptions", jsii.invoke(self, "toDisassociateUser", []))

    @jsii.member(jsii_name="toListIdentityProviders")
    def to_list_identity_providers(self) -> "LicenseManagerUserSubscriptions":
        '''(experimental) Grants permission to list all the identity providers on license manager user subscriptions.

        Access Level: List

        https://docs.aws.amazon.com/license-manager-user-subscriptions/latest/APIReference/API_ListIdentityProviders.html

        :stability: experimental
        '''
        return typing.cast("LicenseManagerUserSubscriptions", jsii.invoke(self, "toListIdentityProviders", []))

    @jsii.member(jsii_name="toListInstances")
    def to_list_instances(self) -> "LicenseManagerUserSubscriptions":
        '''(experimental) Grants permission to list all the instances launched with license manager user subscription products.

        Access Level: List

        https://docs.aws.amazon.com/license-manager-user-subscriptions/latest/APIReference/API_ListInstances.html

        :stability: experimental
        '''
        return typing.cast("LicenseManagerUserSubscriptions", jsii.invoke(self, "toListInstances", []))

    @jsii.member(jsii_name="toListProductSubscriptions")
    def to_list_product_subscriptions(self) -> "LicenseManagerUserSubscriptions":
        '''(experimental) Grants permission to lists all the product subscriptions for a product and identity provider.

        Access Level: List

        https://docs.aws.amazon.com/license-manager-user-subscriptions/latest/APIReference/API_ListProductSubscriptions.html

        :stability: experimental
        '''
        return typing.cast("LicenseManagerUserSubscriptions", jsii.invoke(self, "toListProductSubscriptions", []))

    @jsii.member(jsii_name="toListUserAssociations")
    def to_list_user_associations(self) -> "LicenseManagerUserSubscriptions":
        '''(experimental) Grants permission to list all the users associated to an instance launched for a product.

        Access Level: List

        https://docs.aws.amazon.com/license-manager-user-subscriptions/latest/APIReference/API_ListUserAssociations.html

        :stability: experimental
        '''
        return typing.cast("LicenseManagerUserSubscriptions", jsii.invoke(self, "toListUserAssociations", []))

    @jsii.member(jsii_name="toRegisterIdentityProvider")
    def to_register_identity_provider(self) -> "LicenseManagerUserSubscriptions":
        '''(experimental) Grants permission to registers Microsoft Active Directory with license-manager-user-subscriptions for a product.

        Access Level: Write

        https://docs.aws.amazon.com/license-manager-user-subscriptions/latest/APIReference/API_RegisterIdentityProvider.html

        :stability: experimental
        '''
        return typing.cast("LicenseManagerUserSubscriptions", jsii.invoke(self, "toRegisterIdentityProvider", []))

    @jsii.member(jsii_name="toStartProductSubscription")
    def to_start_product_subscription(self) -> "LicenseManagerUserSubscriptions":
        '''(experimental) Grants permission to start product subscription for a user on a registered active directory for a product.

        Access Level: Write

        https://docs.aws.amazon.com/license-manager-user-subscriptions/latest/APIReference/API_StartProductSubscription.html

        :stability: experimental
        '''
        return typing.cast("LicenseManagerUserSubscriptions", jsii.invoke(self, "toStartProductSubscription", []))

    @jsii.member(jsii_name="toStopProductSubscription")
    def to_stop_product_subscription(self) -> "LicenseManagerUserSubscriptions":
        '''(experimental) Grants permission to stop product subscription for a user on a registered active directory for a product.

        Access Level: Write

        https://docs.aws.amazon.com/license-manager-user-subscriptions/latest/APIReference/API_StopProductSubscription.html

        :stability: experimental
        '''
        return typing.cast("LicenseManagerUserSubscriptions", jsii.invoke(self, "toStopProductSubscription", []))

    @jsii.member(jsii_name="toUpdateIdentityProviderSettings")
    def to_update_identity_provider_settings(self) -> "LicenseManagerUserSubscriptions":
        '''(experimental) Grants permission to update the identity provider configuration.

        Access Level: Write

        https://docs.aws.amazon.com/license-manager-user-subscriptions/latest/APIReference/API_UpdateIdentityProviderSettings.html

        :stability: experimental
        '''
        return typing.cast("LicenseManagerUserSubscriptions", jsii.invoke(self, "toUpdateIdentityProviderSettings", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__28a2729e14095bfa525a661391f3ecd8da62363651c604521ec349edf1bc3c6e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__192c6120ef7f71764b9eba5499650a3ce1ff87b6f509ef7264511208ee7e76d9)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Lightsail(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Lightsail",
):
    '''(experimental) Statement provider for service `lightsail <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonlightsail.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `lightsail <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonlightsail.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onAlarm")
    def on_alarm(
        self,
        id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Lightsail":
        '''(experimental) Adds a resource of type Alarm to the statement.

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_Alarm.html

        :param id: - Identifier for the id.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c94f365b2d463a8a81e4e5f51dfef2166232da609782f966cd44cc8a26ffccbb)
            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Lightsail", jsii.invoke(self, "onAlarm", [id, account, region, partition]))

    @jsii.member(jsii_name="onBucket")
    def on_bucket(
        self,
        id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Lightsail":
        '''(experimental) Adds a resource of type Bucket to the statement.

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_Bucket.html

        :param id: - Identifier for the id.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a2a33a9547aabc076b78ca215b6cd025160a26a92faad438a401a189d64ac646)
            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Lightsail", jsii.invoke(self, "onBucket", [id, account, region, partition]))

    @jsii.member(jsii_name="onCertificate")
    def on_certificate(
        self,
        id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Lightsail":
        '''(experimental) Adds a resource of type Certificate to the statement.

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_Certificate.html

        :param id: - Identifier for the id.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4457418c4d0f02532b3df0ca344e01d0b0c5ac781499ea6809f4c30e045e8a08)
            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Lightsail", jsii.invoke(self, "onCertificate", [id, account, region, partition]))

    @jsii.member(jsii_name="onCloudFormationStackRecord")
    def on_cloud_formation_stack_record(
        self,
        id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Lightsail":
        '''(experimental) Adds a resource of type CloudFormationStackRecord to the statement.

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_CloudFormationStackRecord.html

        :param id: - Identifier for the id.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__964523e1f98ff9147d28c0424fcf739b8d36b6d1ff6449a8aa07a41e16548259)
            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Lightsail", jsii.invoke(self, "onCloudFormationStackRecord", [id, account, region, partition]))

    @jsii.member(jsii_name="onContactMethod")
    def on_contact_method(
        self,
        id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Lightsail":
        '''(experimental) Adds a resource of type ContactMethod to the statement.

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_ContactMethod.html

        :param id: - Identifier for the id.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__36286a50e90f5136206c28fcfcc3a24636884abc6f8cb42cdcce61a428fbf6de)
            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Lightsail", jsii.invoke(self, "onContactMethod", [id, account, region, partition]))

    @jsii.member(jsii_name="onContainerService")
    def on_container_service(
        self,
        id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Lightsail":
        '''(experimental) Adds a resource of type ContainerService to the statement.

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_ContainerService.html

        :param id: - Identifier for the id.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3c77aa591d54796ee86640b733404fc4b9beb4a64c47e7b4bbe071a80b30b2e8)
            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Lightsail", jsii.invoke(self, "onContainerService", [id, account, region, partition]))

    @jsii.member(jsii_name="onDisk")
    def on_disk(
        self,
        id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Lightsail":
        '''(experimental) Adds a resource of type Disk to the statement.

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_Disk.html

        :param id: - Identifier for the id.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a1b32b7a76b44efeae33a22f978a0033d432f751ddb2889e48db94c62609155b)
            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Lightsail", jsii.invoke(self, "onDisk", [id, account, region, partition]))

    @jsii.member(jsii_name="onDiskSnapshot")
    def on_disk_snapshot(
        self,
        id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Lightsail":
        '''(experimental) Adds a resource of type DiskSnapshot to the statement.

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_DiskSnapshot.html

        :param id: - Identifier for the id.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__08dbc7935bc9a6bb2a6d770ec2c7f5878838d3229a3d54a949d39249f643cb2e)
            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Lightsail", jsii.invoke(self, "onDiskSnapshot", [id, account, region, partition]))

    @jsii.member(jsii_name="onDistribution")
    def on_distribution(
        self,
        id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Lightsail":
        '''(experimental) Adds a resource of type Distribution to the statement.

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_LightsailDistribution.html

        :param id: - Identifier for the id.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0aa9e73b2f63b5c796ca5166cc8024bc8bdef95091a97472bdd0db49de5d8f74)
            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Lightsail", jsii.invoke(self, "onDistribution", [id, account, region, partition]))

    @jsii.member(jsii_name="onDomain")
    def on_domain(
        self,
        id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Lightsail":
        '''(experimental) Adds a resource of type Domain to the statement.

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_Domain.html

        :param id: - Identifier for the id.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__571cf8c35f3b31da07f76f0b72984e9aec3203a351e1c4995060c238e995cdda)
            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Lightsail", jsii.invoke(self, "onDomain", [id, account, region, partition]))

    @jsii.member(jsii_name="onExportSnapshotRecord")
    def on_export_snapshot_record(
        self,
        id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Lightsail":
        '''(experimental) Adds a resource of type ExportSnapshotRecord to the statement.

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_ExportSnapshotRecord.html

        :param id: - Identifier for the id.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c9535141118064f46b681c98b4f9d086aedeb06d628cade7ac68fdb0bef318d3)
            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Lightsail", jsii.invoke(self, "onExportSnapshotRecord", [id, account, region, partition]))

    @jsii.member(jsii_name="onInstance")
    def on_instance(
        self,
        id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Lightsail":
        '''(experimental) Adds a resource of type Instance to the statement.

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_Instance.html

        :param id: - Identifier for the id.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bf237e9660cfb791fd15f9822dd15eefacdd8448117bb12daac796af39caa75e)
            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Lightsail", jsii.invoke(self, "onInstance", [id, account, region, partition]))

    @jsii.member(jsii_name="onInstanceSnapshot")
    def on_instance_snapshot(
        self,
        id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Lightsail":
        '''(experimental) Adds a resource of type InstanceSnapshot to the statement.

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_InstanceSnapshot.html

        :param id: - Identifier for the id.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0242a7c87d5fc20a6cc7f0d1b98ea93b55ff5851776f1cc59c19d95e76a65755)
            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Lightsail", jsii.invoke(self, "onInstanceSnapshot", [id, account, region, partition]))

    @jsii.member(jsii_name="onKeyPair")
    def on_key_pair(
        self,
        id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Lightsail":
        '''(experimental) Adds a resource of type KeyPair to the statement.

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_KeyPair.html

        :param id: - Identifier for the id.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7f7eea478dec74998fd5bd31ea8dd2b18e56aca888aa76f08e74a328e60ef3ed)
            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Lightsail", jsii.invoke(self, "onKeyPair", [id, account, region, partition]))

    @jsii.member(jsii_name="onLoadBalancer")
    def on_load_balancer(
        self,
        id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Lightsail":
        '''(experimental) Adds a resource of type LoadBalancer to the statement.

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_LoadBalancer.html

        :param id: - Identifier for the id.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5de29c62c7a3a3528ff754c87c764f37b8e6a5785152bd348437264c48c98af1)
            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Lightsail", jsii.invoke(self, "onLoadBalancer", [id, account, region, partition]))

    @jsii.member(jsii_name="onLoadBalancerTlsCertificate")
    def on_load_balancer_tls_certificate(
        self,
        id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Lightsail":
        '''(experimental) Adds a resource of type LoadBalancerTlsCertificate to the statement.

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_LoadBalancerTlsCertificate.html

        :param id: - Identifier for the id.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2c02ed03860917a1066961aacb8896c9299e526c29c62961133d6b42cfb3b1d1)
            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Lightsail", jsii.invoke(self, "onLoadBalancerTlsCertificate", [id, account, region, partition]))

    @jsii.member(jsii_name="onRelationalDatabase")
    def on_relational_database(
        self,
        id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Lightsail":
        '''(experimental) Adds a resource of type RelationalDatabase to the statement.

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_RelationalDatabase.html

        :param id: - Identifier for the id.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__37001cc96e803297e02b91e3d7868854bf9003037bff95c2ca0f12e84ebdef94)
            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Lightsail", jsii.invoke(self, "onRelationalDatabase", [id, account, region, partition]))

    @jsii.member(jsii_name="onRelationalDatabaseSnapshot")
    def on_relational_database_snapshot(
        self,
        id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Lightsail":
        '''(experimental) Adds a resource of type RelationalDatabaseSnapshot to the statement.

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_RelationalDatabaseSnapshot.html

        :param id: - Identifier for the id.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__143232513c70551ae647422633b55bb968a45d5d3ff41529f14a69eb0d72f744)
            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Lightsail", jsii.invoke(self, "onRelationalDatabaseSnapshot", [id, account, region, partition]))

    @jsii.member(jsii_name="onStaticIp")
    def on_static_ip(
        self,
        id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Lightsail":
        '''(experimental) Adds a resource of type StaticIp to the statement.

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_StaticIp.html

        :param id: - Identifier for the id.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__53f90de9c8b5874b7f46332ca8e18c0473d90b2ab7ce0553397c58f550c78926)
            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Lightsail", jsii.invoke(self, "onStaticIp", [id, account, region, partition]))

    @jsii.member(jsii_name="toAllocateStaticIp")
    def to_allocate_static_ip(self) -> "Lightsail":
        '''(experimental) Grants permission to create a static IP address that can be attached to an instance.

        Access Level: Write

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_AllocateStaticIp.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toAllocateStaticIp", []))

    @jsii.member(jsii_name="toAttachCertificateToDistribution")
    def to_attach_certificate_to_distribution(self) -> "Lightsail":
        '''(experimental) Grants permission to attach an SSL/TLS certificate to your Amazon Lightsail content delivery network (CDN) distribution.

        Access Level: Write

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_AttachCertificateToDistribution.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toAttachCertificateToDistribution", []))

    @jsii.member(jsii_name="toAttachDisk")
    def to_attach_disk(self) -> "Lightsail":
        '''(experimental) Grants permission to attach a disk to an instance.

        Access Level: Write

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_AttachDisk.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toAttachDisk", []))

    @jsii.member(jsii_name="toAttachInstancesToLoadBalancer")
    def to_attach_instances_to_load_balancer(self) -> "Lightsail":
        '''(experimental) Grants permission to attach one or more instances to a load balancer.

        Access Level: Write

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_AttachInstancesToLoadBalancer.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toAttachInstancesToLoadBalancer", []))

    @jsii.member(jsii_name="toAttachLoadBalancerTlsCertificate")
    def to_attach_load_balancer_tls_certificate(self) -> "Lightsail":
        '''(experimental) Grants permission to attach a TLS certificate to a load balancer.

        Access Level: Write

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_AttachLoadBalancerTlsCertificate.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toAttachLoadBalancerTlsCertificate", []))

    @jsii.member(jsii_name="toAttachStaticIp")
    def to_attach_static_ip(self) -> "Lightsail":
        '''(experimental) Grants permission to attach a static IP address to an instance.

        Access Level: Write

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_AttachStaticIp.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toAttachStaticIp", []))

    @jsii.member(jsii_name="toCloseInstancePublicPorts")
    def to_close_instance_public_ports(self) -> "Lightsail":
        '''(experimental) Grants permission to close a public port of an instance.

        Access Level: Write

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_CloseInstancePublicPorts.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toCloseInstancePublicPorts", []))

    @jsii.member(jsii_name="toCopySnapshot")
    def to_copy_snapshot(self) -> "Lightsail":
        '''(experimental) Grants permission to copy a snapshot from one AWS Region to another in Amazon Lightsail.

        Access Level: Write

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_CopySnapshot.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toCopySnapshot", []))

    @jsii.member(jsii_name="toCreateBucket")
    def to_create_bucket(self) -> "Lightsail":
        '''(experimental) Grants permission to create an Amazon Lightsail bucket.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_CreateBucket.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toCreateBucket", []))

    @jsii.member(jsii_name="toCreateBucketAccessKey")
    def to_create_bucket_access_key(self) -> "Lightsail":
        '''(experimental) Grants permission to create a new access key for the specified bucket.

        Access Level: Write

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_CreateBucketAccessKey.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toCreateBucketAccessKey", []))

    @jsii.member(jsii_name="toCreateCertificate")
    def to_create_certificate(self) -> "Lightsail":
        '''(experimental) Grants permission to create an SSL/TLS certificate.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_CreateCertificate.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toCreateCertificate", []))

    @jsii.member(jsii_name="toCreateCloudFormationStack")
    def to_create_cloud_formation_stack(self) -> "Lightsail":
        '''(experimental) Grants permission to create a new Amazon EC2 instance from an exported Amazon Lightsail snapshot.

        Access Level: Write

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_CreateCloudFormationStack.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toCreateCloudFormationStack", []))

    @jsii.member(jsii_name="toCreateContactMethod")
    def to_create_contact_method(self) -> "Lightsail":
        '''(experimental) Grants permission to create an email or SMS text message contact method.

        Access Level: Write

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_CreateContactMethod.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toCreateContactMethod", []))

    @jsii.member(jsii_name="toCreateContainerService")
    def to_create_container_service(self) -> "Lightsail":
        '''(experimental) Grants permission to create an Amazon Lightsail container service.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_CreateContainerService.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toCreateContainerService", []))

    @jsii.member(jsii_name="toCreateContainerServiceDeployment")
    def to_create_container_service_deployment(self) -> "Lightsail":
        '''(experimental) Grants permission to create a deployment for your Amazon Lightsail container service.

        Access Level: Write

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_CreateContainerServiceDeployment.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toCreateContainerServiceDeployment", []))

    @jsii.member(jsii_name="toCreateContainerServiceRegistryLogin")
    def to_create_container_service_registry_login(self) -> "Lightsail":
        '''(experimental) Grants permission to create a temporary set of log in credentials that you can use to log in to the Docker process on your local machine.

        Access Level: Write

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_CreateContainerServiceRegistryLogin.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toCreateContainerServiceRegistryLogin", []))

    @jsii.member(jsii_name="toCreateDisk")
    def to_create_disk(self) -> "Lightsail":
        '''(experimental) Grants permission to create a disk.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_CreateDisk.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toCreateDisk", []))

    @jsii.member(jsii_name="toCreateDiskFromSnapshot")
    def to_create_disk_from_snapshot(self) -> "Lightsail":
        '''(experimental) Grants permission to create a disk from snapshot.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_CreateDiskFromSnapshot.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toCreateDiskFromSnapshot", []))

    @jsii.member(jsii_name="toCreateDiskSnapshot")
    def to_create_disk_snapshot(self) -> "Lightsail":
        '''(experimental) Grants permission to create a disk snapshot.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_CreateDiskSnapshot.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toCreateDiskSnapshot", []))

    @jsii.member(jsii_name="toCreateDistribution")
    def to_create_distribution(self) -> "Lightsail":
        '''(experimental) Grants permission to create an Amazon Lightsail content delivery network (CDN) distribution.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_CreateDistribution.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toCreateDistribution", []))

    @jsii.member(jsii_name="toCreateDomain")
    def to_create_domain(self) -> "Lightsail":
        '''(experimental) Grants permission to create a domain resource for the specified domain name.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_CreateDomain.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toCreateDomain", []))

    @jsii.member(jsii_name="toCreateDomainEntry")
    def to_create_domain_entry(self) -> "Lightsail":
        '''(experimental) Grants permission to create one or more DNS record entries for a domain resource: Address (A), canonical name (CNAME), mail exchanger (MX), name server (NS), start of authority (SOA), service locator (SRV), or text (TXT).

        Access Level: Write

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_CreateDomainEntry.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toCreateDomainEntry", []))

    @jsii.member(jsii_name="toCreateInstances")
    def to_create_instances(self) -> "Lightsail":
        '''(experimental) Grants permission to create one or more instances.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_CreateInstances.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toCreateInstances", []))

    @jsii.member(jsii_name="toCreateInstancesFromSnapshot")
    def to_create_instances_from_snapshot(self) -> "Lightsail":
        '''(experimental) Grants permission to create one or more instances based on an instance snapshot.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_CreateInstancesFromSnapshot.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toCreateInstancesFromSnapshot", []))

    @jsii.member(jsii_name="toCreateInstanceSnapshot")
    def to_create_instance_snapshot(self) -> "Lightsail":
        '''(experimental) Grants permission to create an instance snapshot.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_CreateInstanceSnapshot.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toCreateInstanceSnapshot", []))

    @jsii.member(jsii_name="toCreateKeyPair")
    def to_create_key_pair(self) -> "Lightsail":
        '''(experimental) Grants permission to create a key pair used to authenticate and connect to an instance.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_CreateKeyPair.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toCreateKeyPair", []))

    @jsii.member(jsii_name="toCreateLoadBalancer")
    def to_create_load_balancer(self) -> "Lightsail":
        '''(experimental) Grants permission to create a load balancer.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_CreateLoadBalancer.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toCreateLoadBalancer", []))

    @jsii.member(jsii_name="toCreateLoadBalancerTlsCertificate")
    def to_create_load_balancer_tls_certificate(self) -> "Lightsail":
        '''(experimental) Grants permission to create a load balancer TLS certificate.

        Access Level: Write

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_CreateLoadBalancerTlsCertificate.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toCreateLoadBalancerTlsCertificate", []))

    @jsii.member(jsii_name="toCreateRelationalDatabase")
    def to_create_relational_database(self) -> "Lightsail":
        '''(experimental) Grants permission to create a new relational database.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_CreateRelationalDatabase.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toCreateRelationalDatabase", []))

    @jsii.member(jsii_name="toCreateRelationalDatabaseFromSnapshot")
    def to_create_relational_database_from_snapshot(self) -> "Lightsail":
        '''(experimental) Grants permission to create a new relational database from a snapshot.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_CreateRelationalDatabaseFromSnapshot.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toCreateRelationalDatabaseFromSnapshot", []))

    @jsii.member(jsii_name="toCreateRelationalDatabaseSnapshot")
    def to_create_relational_database_snapshot(self) -> "Lightsail":
        '''(experimental) Grants permission to create a relational database snapshot.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_CreateRelationalDatabaseSnapshot.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toCreateRelationalDatabaseSnapshot", []))

    @jsii.member(jsii_name="toDeleteAlarm")
    def to_delete_alarm(self) -> "Lightsail":
        '''(experimental) Grants permission to delete an alarm.

        Access Level: Write

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_DeleteAlarm.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toDeleteAlarm", []))

    @jsii.member(jsii_name="toDeleteAutoSnapshot")
    def to_delete_auto_snapshot(self) -> "Lightsail":
        '''(experimental) Grants permission to delete an automatic snapshot of an instance or disk.

        Access Level: Write

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_DeleteAutoSnapshot.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toDeleteAutoSnapshot", []))

    @jsii.member(jsii_name="toDeleteBucket")
    def to_delete_bucket(self) -> "Lightsail":
        '''(experimental) Grants permission to delete an Amazon Lightsail bucket.

        Access Level: Write

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_DeleteBucket.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toDeleteBucket", []))

    @jsii.member(jsii_name="toDeleteBucketAccessKey")
    def to_delete_bucket_access_key(self) -> "Lightsail":
        '''(experimental) Grants permission to delete an access key for the specified Amazon Lightsail bucket.

        Access Level: Write

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_DeleteBucketAccessKey.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toDeleteBucketAccessKey", []))

    @jsii.member(jsii_name="toDeleteCertificate")
    def to_delete_certificate(self) -> "Lightsail":
        '''(experimental) Grants permission to delete an SSL/TLS certificate.

        Access Level: Write

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_DeleteCertificate.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toDeleteCertificate", []))

    @jsii.member(jsii_name="toDeleteContactMethod")
    def to_delete_contact_method(self) -> "Lightsail":
        '''(experimental) Grants permission to delete a contact method.

        Access Level: Write

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_DeleteContactMethod.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toDeleteContactMethod", []))

    @jsii.member(jsii_name="toDeleteContainerImage")
    def to_delete_container_image(self) -> "Lightsail":
        '''(experimental) Grants permission to delete a container image that is registered to your Amazon Lightsail container service.

        Access Level: Write

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_DeleteContainerImage.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toDeleteContainerImage", []))

    @jsii.member(jsii_name="toDeleteContainerService")
    def to_delete_container_service(self) -> "Lightsail":
        '''(experimental) Grants permission to delete your Amazon Lightsail container service.

        Access Level: Write

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_DeleteContainerService.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toDeleteContainerService", []))

    @jsii.member(jsii_name="toDeleteDisk")
    def to_delete_disk(self) -> "Lightsail":
        '''(experimental) Grants permission to delete a disk.

        Access Level: Write

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_DeleteDisk.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toDeleteDisk", []))

    @jsii.member(jsii_name="toDeleteDiskSnapshot")
    def to_delete_disk_snapshot(self) -> "Lightsail":
        '''(experimental) Grants permission to delete a disk snapshot.

        Access Level: Write

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_DeleteDiskSnapshot.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toDeleteDiskSnapshot", []))

    @jsii.member(jsii_name="toDeleteDistribution")
    def to_delete_distribution(self) -> "Lightsail":
        '''(experimental) Grants permission to delete your Amazon Lightsail content delivery network (CDN) distribution.

        Access Level: Write

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_DeleteDistribution.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toDeleteDistribution", []))

    @jsii.member(jsii_name="toDeleteDomain")
    def to_delete_domain(self) -> "Lightsail":
        '''(experimental) Grants permission to delete a domain resource and all of its DNS records.

        Access Level: Write

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_DeleteDomain.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toDeleteDomain", []))

    @jsii.member(jsii_name="toDeleteDomainEntry")
    def to_delete_domain_entry(self) -> "Lightsail":
        '''(experimental) Grants permission to delete a DNS record entry for a domain resource.

        Access Level: Write

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_DeleteDomainEntry.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toDeleteDomainEntry", []))

    @jsii.member(jsii_name="toDeleteInstance")
    def to_delete_instance(self) -> "Lightsail":
        '''(experimental) Grants permission to delete an instance.

        Access Level: Write

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_DeleteInstance.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toDeleteInstance", []))

    @jsii.member(jsii_name="toDeleteInstanceSnapshot")
    def to_delete_instance_snapshot(self) -> "Lightsail":
        '''(experimental) Grants permission to delete an instance snapshot.

        Access Level: Write

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_DeleteInstanceSnapshot.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toDeleteInstanceSnapshot", []))

    @jsii.member(jsii_name="toDeleteKeyPair")
    def to_delete_key_pair(self) -> "Lightsail":
        '''(experimental) Grants permission to delete a key pair used to authenticate and connect to an instance.

        Access Level: Write

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_DeleteKeyPair.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toDeleteKeyPair", []))

    @jsii.member(jsii_name="toDeleteKnownHostKeys")
    def to_delete_known_host_keys(self) -> "Lightsail":
        '''(experimental) Grants permission to delete the known host key or certificate used by the Amazon Lightsail browser-based SSH or RDP clients to authenticate an instance.

        Access Level: Write

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_DeleteKnownHostKeys.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toDeleteKnownHostKeys", []))

    @jsii.member(jsii_name="toDeleteLoadBalancer")
    def to_delete_load_balancer(self) -> "Lightsail":
        '''(experimental) Grants permission to delete a load balancer.

        Access Level: Write

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_DeleteLoadBalancer.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toDeleteLoadBalancer", []))

    @jsii.member(jsii_name="toDeleteLoadBalancerTlsCertificate")
    def to_delete_load_balancer_tls_certificate(self) -> "Lightsail":
        '''(experimental) Grants permission to delete a load balancer TLS certificate.

        Access Level: Write

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_DeleteLoadBalancerTlsCertificate.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toDeleteLoadBalancerTlsCertificate", []))

    @jsii.member(jsii_name="toDeleteRelationalDatabase")
    def to_delete_relational_database(self) -> "Lightsail":
        '''(experimental) Grants permission to delete a relational database.

        Access Level: Write

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_DeleteRelationalDatabase.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toDeleteRelationalDatabase", []))

    @jsii.member(jsii_name="toDeleteRelationalDatabaseSnapshot")
    def to_delete_relational_database_snapshot(self) -> "Lightsail":
        '''(experimental) Grants permission to delete a relational database snapshot.

        Access Level: Write

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_DeleteRelationalDatabaseSnapshot.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toDeleteRelationalDatabaseSnapshot", []))

    @jsii.member(jsii_name="toDetachCertificateFromDistribution")
    def to_detach_certificate_from_distribution(self) -> "Lightsail":
        '''(experimental) Grants permission to detach an SSL/TLS certificate from your Amazon Lightsail content delivery network (CDN) distribution.

        Access Level: Write

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_DetachCertificateFromDistribution.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toDetachCertificateFromDistribution", []))

    @jsii.member(jsii_name="toDetachDisk")
    def to_detach_disk(self) -> "Lightsail":
        '''(experimental) Grants permission to detach a disk from an instance.

        Access Level: Write

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_DetachDisk.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toDetachDisk", []))

    @jsii.member(jsii_name="toDetachInstancesFromLoadBalancer")
    def to_detach_instances_from_load_balancer(self) -> "Lightsail":
        '''(experimental) Grants permission to detach one or more instances from a load balancer.

        Access Level: Write

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_DetachInstancesFromLoadBalancer.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toDetachInstancesFromLoadBalancer", []))

    @jsii.member(jsii_name="toDetachStaticIp")
    def to_detach_static_ip(self) -> "Lightsail":
        '''(experimental) Grants permission to detach a static IP from an instance to which it is attached.

        Access Level: Write

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_DetachStaticIp.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toDetachStaticIp", []))

    @jsii.member(jsii_name="toDisableAddOn")
    def to_disable_add_on(self) -> "Lightsail":
        '''(experimental) Grants permission to disable an add-on for an Amazon Lightsail resource.

        Access Level: Write

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_DisableAddOn.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toDisableAddOn", []))

    @jsii.member(jsii_name="toDownloadDefaultKeyPair")
    def to_download_default_key_pair(self) -> "Lightsail":
        '''(experimental) Grants permission to download the default key pair used to authenticate and connect to instances in a specific AWS Region.

        Access Level: Write

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_DownloadDefaultKeyPair.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toDownloadDefaultKeyPair", []))

    @jsii.member(jsii_name="toEnableAddOn")
    def to_enable_add_on(self) -> "Lightsail":
        '''(experimental) Grants permission to enable or modify an add-on for an Amazon Lightsail resource.

        Access Level: Write

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_EnableAddOn.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toEnableAddOn", []))

    @jsii.member(jsii_name="toExportSnapshot")
    def to_export_snapshot(self) -> "Lightsail":
        '''(experimental) Grants permission to export an Amazon Lightsail snapshot to Amazon EC2.

        Access Level: Write

        Dependent actions:

        - iam:CreateServiceLinkedRole
        - iam:PutRolePolicy

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_ExportSnapshot.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toExportSnapshot", []))

    @jsii.member(jsii_name="toGetActiveNames")
    def to_get_active_names(self) -> "Lightsail":
        '''(experimental) Grants permission to get the names of all active (not deleted) resources.

        Access Level: Read

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_GetActiveNames.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toGetActiveNames", []))

    @jsii.member(jsii_name="toGetAlarms")
    def to_get_alarms(self) -> "Lightsail":
        '''(experimental) Grants permission to view information about the configured alarms.

        Access Level: Read

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_GetAlarms.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toGetAlarms", []))

    @jsii.member(jsii_name="toGetAutoSnapshots")
    def to_get_auto_snapshots(self) -> "Lightsail":
        '''(experimental) Grants permission to view the available automatic snapshots for an instance or disk.

        Access Level: Read

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_GetAutoSnapshots.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toGetAutoSnapshots", []))

    @jsii.member(jsii_name="toGetBlueprints")
    def to_get_blueprints(self) -> "Lightsail":
        '''(experimental) Grants permission to get a list of instance images, or blueprints.

        You can use a blueprint to create a new instance already running a specific operating system, as well as a pre-installed application or development stack. The software that runs on your instance depends on the blueprint you define when creating the instance

        Access Level: Read

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_GetBlueprints.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toGetBlueprints", []))

    @jsii.member(jsii_name="toGetBucketAccessKeys")
    def to_get_bucket_access_keys(self) -> "Lightsail":
        '''(experimental) Grants permission to get the existing access key IDs for the specified Amazon Lightsail bucket.

        Access Level: Read

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_GetBucketAccessKeys.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toGetBucketAccessKeys", []))

    @jsii.member(jsii_name="toGetBucketBundles")
    def to_get_bucket_bundles(self) -> "Lightsail":
        '''(experimental) Grants permission to get the bundles that can be applied to an Amazon Lightsail bucket.

        Access Level: Read

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_GetBucketBundles.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toGetBucketBundles", []))

    @jsii.member(jsii_name="toGetBucketMetricData")
    def to_get_bucket_metric_data(self) -> "Lightsail":
        '''(experimental) Grants permission to get the data points of a specific metric for an Amazon Lightsail bucket.

        Access Level: Read

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_GetBucketMetricData.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toGetBucketMetricData", []))

    @jsii.member(jsii_name="toGetBuckets")
    def to_get_buckets(self) -> "Lightsail":
        '''(experimental) Grants permission to get information about one or more Amazon Lightsail buckets.

        Access Level: Read

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_GetBuckets.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toGetBuckets", []))

    @jsii.member(jsii_name="toGetBundles")
    def to_get_bundles(self) -> "Lightsail":
        '''(experimental) Grants permission to get a list of instance bundles.

        You can use a bundle to create a new instance with a set of performance specifications, such as CPU count, disk size, RAM size, and network transfer allowance. The cost of your instance depends on the bundle you define when creating the instance

        Access Level: Read

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_GetBundles.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toGetBundles", []))

    @jsii.member(jsii_name="toGetCertificates")
    def to_get_certificates(self) -> "Lightsail":
        '''(experimental) Grants permission to view information about one or more Amazon Lightsail SSL/TLS certificates.

        Access Level: Read

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_GetCertificates.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toGetCertificates", []))

    @jsii.member(jsii_name="toGetCloudFormationStackRecords")
    def to_get_cloud_formation_stack_records(self) -> "Lightsail":
        '''(experimental) Grants permission to get information about all CloudFormation stacks used to create Amazon EC2 resources from exported Amazon Lightsail snapshots.

        Access Level: Read

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_GetCloudFormationStackRecords.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toGetCloudFormationStackRecords", []))

    @jsii.member(jsii_name="toGetContactMethods")
    def to_get_contact_methods(self) -> "Lightsail":
        '''(experimental) Grants permission to view information about the configured contact methods.

        Access Level: Read

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_GetContactMethods.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toGetContactMethods", []))

    @jsii.member(jsii_name="toGetContainerAPIMetadata")
    def to_get_container_api_metadata(self) -> "Lightsail":
        '''(experimental) Grants permission to view information about Amazon Lightsail containers, such as the current version of the Lightsail Control (lightsailctl) plugin.

        Access Level: Read

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_GetContainerAPIMetadata.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toGetContainerAPIMetadata", []))

    @jsii.member(jsii_name="toGetContainerImages")
    def to_get_container_images(self) -> "Lightsail":
        '''(experimental) Grants permission to view the container images that are registered to your Amazon Lightsail container service.

        Access Level: Read

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_GetContainerImages.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toGetContainerImages", []))

    @jsii.member(jsii_name="toGetContainerLog")
    def to_get_container_log(self) -> "Lightsail":
        '''(experimental) Grants permission to view the log events of a container of your Amazon Lightsail container service.

        Access Level: Read

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_GetContainerLog.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toGetContainerLog", []))

    @jsii.member(jsii_name="toGetContainerServiceDeployments")
    def to_get_container_service_deployments(self) -> "Lightsail":
        '''(experimental) Grants permission to view the deployments for your Amazon Lightsail container service.

        Access Level: Read

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_GetContainerServiceDeployments.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toGetContainerServiceDeployments", []))

    @jsii.member(jsii_name="toGetContainerServiceMetricData")
    def to_get_container_service_metric_data(self) -> "Lightsail":
        '''(experimental) Grants permission to view the data points of a specific metric of your Amazon Lightsail container service.

        Access Level: Read

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_GetContainerServiceMetricData.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toGetContainerServiceMetricData", []))

    @jsii.member(jsii_name="toGetContainerServicePowers")
    def to_get_container_service_powers(self) -> "Lightsail":
        '''(experimental) Grants permission to view the list of powers that can be specified for your Amazon Lightsail container services.

        Access Level: Read

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_GetContainerServicePowers.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toGetContainerServicePowers", []))

    @jsii.member(jsii_name="toGetContainerServices")
    def to_get_container_services(self) -> "Lightsail":
        '''(experimental) Grants permission to view information about one or more of your Amazon Lightsail container services.

        Access Level: Read

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_GetContainerServices.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toGetContainerServices", []))

    @jsii.member(jsii_name="toGetDisk")
    def to_get_disk(self) -> "Lightsail":
        '''(experimental) Grants permission to get information about a disk.

        Access Level: Read

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_GetDisk.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toGetDisk", []))

    @jsii.member(jsii_name="toGetDisks")
    def to_get_disks(self) -> "Lightsail":
        '''(experimental) Grants permission to get information about all disks.

        Access Level: Read

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_GetDisks.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toGetDisks", []))

    @jsii.member(jsii_name="toGetDiskSnapshot")
    def to_get_disk_snapshot(self) -> "Lightsail":
        '''(experimental) Grants permission to get information about a disk snapshot.

        Access Level: Read

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_GetDiskSnapshot.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toGetDiskSnapshot", []))

    @jsii.member(jsii_name="toGetDiskSnapshots")
    def to_get_disk_snapshots(self) -> "Lightsail":
        '''(experimental) Grants permission to get information about all disk snapshots.

        Access Level: Read

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_GetDiskSnapshots.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toGetDiskSnapshots", []))

    @jsii.member(jsii_name="toGetDistributionBundles")
    def to_get_distribution_bundles(self) -> "Lightsail":
        '''(experimental) Grants permission to view the list of bundles that can be applied to you Amazon Lightsail content delivery network (CDN) distributions.

        Access Level: Read

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_GetDistributionBundles.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toGetDistributionBundles", []))

    @jsii.member(jsii_name="toGetDistributionLatestCacheReset")
    def to_get_distribution_latest_cache_reset(self) -> "Lightsail":
        '''(experimental) Grants permission to view the timestamp and status of the last cache reset of a specific Amazon Lightsail content delivery network (CDN) distribution.

        Access Level: Read

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_GetDistributionLatestCacheReset.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toGetDistributionLatestCacheReset", []))

    @jsii.member(jsii_name="toGetDistributionMetricData")
    def to_get_distribution_metric_data(self) -> "Lightsail":
        '''(experimental) Grants permission to view the data points of a specific metric for an Amazon Lightsail content delivery network (CDN) distribution.

        Access Level: Read

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_GetDistributionMetricData.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toGetDistributionMetricData", []))

    @jsii.member(jsii_name="toGetDistributions")
    def to_get_distributions(self) -> "Lightsail":
        '''(experimental) Grants permission to view information about one or more of your Amazon Lightsail content delivery network (CDN) distributions.

        Access Level: Read

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_GetDistributions.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toGetDistributions", []))

    @jsii.member(jsii_name="toGetDomain")
    def to_get_domain(self) -> "Lightsail":
        '''(experimental) Grants permission to get DNS records for a domain resource.

        Access Level: Read

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_GetDomain.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toGetDomain", []))

    @jsii.member(jsii_name="toGetDomains")
    def to_get_domains(self) -> "Lightsail":
        '''(experimental) Grants permission to get DNS records for all domain resources.

        Access Level: Read

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_GetDomains.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toGetDomains", []))

    @jsii.member(jsii_name="toGetExportSnapshotRecords")
    def to_get_export_snapshot_records(self) -> "Lightsail":
        '''(experimental) Grants permission to get information about all records of exported Amazon Lightsail snapshots to Amazon EC2.

        Access Level: Read

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_GetExportSnapshotRecords.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toGetExportSnapshotRecords", []))

    @jsii.member(jsii_name="toGetInstance")
    def to_get_instance(self) -> "Lightsail":
        '''(experimental) Grants permission to get information about an instance.

        Access Level: Read

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_GetInstance.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toGetInstance", []))

    @jsii.member(jsii_name="toGetInstanceAccessDetails")
    def to_get_instance_access_details(self) -> "Lightsail":
        '''(experimental) Grants permission to get temporary keys you can use to authenticate and connect to an instance.

        Access Level: Write

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_GetInstanceAccessDetails.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toGetInstanceAccessDetails", []))

    @jsii.member(jsii_name="toGetInstanceMetricData")
    def to_get_instance_metric_data(self) -> "Lightsail":
        '''(experimental) Grants permission to get the data points for the specified metric of an instance.

        Access Level: Read

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_GetInstanceMetricData.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toGetInstanceMetricData", []))

    @jsii.member(jsii_name="toGetInstancePortStates")
    def to_get_instance_port_states(self) -> "Lightsail":
        '''(experimental) Grants permission to get the port states of an instance.

        Access Level: Read

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_GetInstancePortStates.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toGetInstancePortStates", []))

    @jsii.member(jsii_name="toGetInstances")
    def to_get_instances(self) -> "Lightsail":
        '''(experimental) Grants permission to get information about all instances.

        Access Level: Read

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_GetInstances.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toGetInstances", []))

    @jsii.member(jsii_name="toGetInstanceSnapshot")
    def to_get_instance_snapshot(self) -> "Lightsail":
        '''(experimental) Grants permission to get information about an instance snapshot.

        Access Level: Read

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_GetInstanceSnapshot.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toGetInstanceSnapshot", []))

    @jsii.member(jsii_name="toGetInstanceSnapshots")
    def to_get_instance_snapshots(self) -> "Lightsail":
        '''(experimental) Grants permission to get information about all instance snapshots.

        Access Level: Read

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_GetInstanceSnapshots.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toGetInstanceSnapshots", []))

    @jsii.member(jsii_name="toGetInstanceState")
    def to_get_instance_state(self) -> "Lightsail":
        '''(experimental) Grants permission to get the state of an instance.

        Access Level: Read

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_GetInstanceState.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toGetInstanceState", []))

    @jsii.member(jsii_name="toGetKeyPair")
    def to_get_key_pair(self) -> "Lightsail":
        '''(experimental) Grants permission to get information about a key pair.

        Access Level: Read

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_GetKeyPair.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toGetKeyPair", []))

    @jsii.member(jsii_name="toGetKeyPairs")
    def to_get_key_pairs(self) -> "Lightsail":
        '''(experimental) Grants permission to get information about all key pairs.

        Access Level: Read

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_GetKeyPairs.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toGetKeyPairs", []))

    @jsii.member(jsii_name="toGetLoadBalancer")
    def to_get_load_balancer(self) -> "Lightsail":
        '''(experimental) Grants permission to get information about a load balancer.

        Access Level: Read

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_GetLoadBalancer.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toGetLoadBalancer", []))

    @jsii.member(jsii_name="toGetLoadBalancerMetricData")
    def to_get_load_balancer_metric_data(self) -> "Lightsail":
        '''(experimental) Grants permission to get the data points for the specified metric of a load balancer.

        Access Level: Read

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_GetLoadBalancerMetricData.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toGetLoadBalancerMetricData", []))

    @jsii.member(jsii_name="toGetLoadBalancers")
    def to_get_load_balancers(self) -> "Lightsail":
        '''(experimental) Grants permission to get information about load balancers.

        Access Level: Read

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_GetLoadBalancers.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toGetLoadBalancers", []))

    @jsii.member(jsii_name="toGetLoadBalancerTlsCertificates")
    def to_get_load_balancer_tls_certificates(self) -> "Lightsail":
        '''(experimental) Grants permission to get information about a load balancer's TLS certificates.

        Access Level: Read

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_GetLoadBalancerTlsCertificates.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toGetLoadBalancerTlsCertificates", []))

    @jsii.member(jsii_name="toGetLoadBalancerTlsPolicies")
    def to_get_load_balancer_tls_policies(self) -> "Lightsail":
        '''(experimental) Grants permission to get a list of TLS security policies that you can apply to Lightsail load balancers.

        Access Level: Read

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_GetLoadBalancerTlsPolicies.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toGetLoadBalancerTlsPolicies", []))

    @jsii.member(jsii_name="toGetOperation")
    def to_get_operation(self) -> "Lightsail":
        '''(experimental) Grants permission to get information about an operation.

        Operations include events such as when you create an instance, allocate a static IP, attach a static IP, and so on

        Access Level: Read

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_GetOperation.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toGetOperation", []))

    @jsii.member(jsii_name="toGetOperations")
    def to_get_operations(self) -> "Lightsail":
        '''(experimental) Grants permission to get information about all operations.

        Operations include events such as when you create an instance, allocate a static IP, attach a static IP, and so on

        Access Level: Read

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_GetOperations.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toGetOperations", []))

    @jsii.member(jsii_name="toGetOperationsForResource")
    def to_get_operations_for_resource(self) -> "Lightsail":
        '''(experimental) Grants permission to get operations for a resource.

        Access Level: Read

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_GetOperationsForResource.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toGetOperationsForResource", []))

    @jsii.member(jsii_name="toGetRegions")
    def to_get_regions(self) -> "Lightsail":
        '''(experimental) Grants permission to get a list of all valid AWS Regions for Amazon Lightsail.

        Access Level: Read

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_GetRegions.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toGetRegions", []))

    @jsii.member(jsii_name="toGetRelationalDatabase")
    def to_get_relational_database(self) -> "Lightsail":
        '''(experimental) Grants permission to get information about a relational database.

        Access Level: Read

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_GetRelationalDatabase.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toGetRelationalDatabase", []))

    @jsii.member(jsii_name="toGetRelationalDatabaseBlueprints")
    def to_get_relational_database_blueprints(self) -> "Lightsail":
        '''(experimental) Grants permission to get a list of relational database images, or blueprints.

        You can use a blueprint to create a new database running a specific database engine. The database engine that runs on your database depends on the blueprint you define when creating the relational database

        Access Level: Read

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_GetRelationalDatabaseBlueprints.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toGetRelationalDatabaseBlueprints", []))

    @jsii.member(jsii_name="toGetRelationalDatabaseBundles")
    def to_get_relational_database_bundles(self) -> "Lightsail":
        '''(experimental) Grants permission to get a list of relational database bundles.

        You can use a bundle to create a new database with a set of performance specifications, such as CPU count, disk size, RAM size, network transfer allowance, and standard of high availability. The cost of your database depends on the bundle you define when creating the relational database

        Access Level: Read

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_GetRelationalDatabaseBundles.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toGetRelationalDatabaseBundles", []))

    @jsii.member(jsii_name="toGetRelationalDatabaseEvents")
    def to_get_relational_database_events(self) -> "Lightsail":
        '''(experimental) Grants permission to get events for a relational database.

        Access Level: Read

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_GetRelationalDatabaseEvents.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toGetRelationalDatabaseEvents", []))

    @jsii.member(jsii_name="toGetRelationalDatabaseLogEvents")
    def to_get_relational_database_log_events(self) -> "Lightsail":
        '''(experimental) Grants permission to get events for the specified log stream of a relational database.

        Access Level: Read

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_GetRelationalDatabaseLogEvents.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toGetRelationalDatabaseLogEvents", []))

    @jsii.member(jsii_name="toGetRelationalDatabaseLogStreams")
    def to_get_relational_database_log_streams(self) -> "Lightsail":
        '''(experimental) Grants permission to get the log streams available for a relational database.

        Access Level: Read

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_GetRelationalDatabaseLogStreams.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toGetRelationalDatabaseLogStreams", []))

    @jsii.member(jsii_name="toGetRelationalDatabaseMasterUserPassword")
    def to_get_relational_database_master_user_password(self) -> "Lightsail":
        '''(experimental) Grants permission to get the master user password of a relational database.

        Access Level: Write

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_GetRelationalDatabaseMasterUserPassword.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toGetRelationalDatabaseMasterUserPassword", []))

    @jsii.member(jsii_name="toGetRelationalDatabaseMetricData")
    def to_get_relational_database_metric_data(self) -> "Lightsail":
        '''(experimental) Grants permission to get the data points for the specified metric of a relational database.

        Access Level: Read

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_GetRelationalDatabaseMetricData.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toGetRelationalDatabaseMetricData", []))

    @jsii.member(jsii_name="toGetRelationalDatabaseParameters")
    def to_get_relational_database_parameters(self) -> "Lightsail":
        '''(experimental) Grants permission to get the parameters of a relational database.

        Access Level: Read

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_GetRelationalDatabaseParameters.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toGetRelationalDatabaseParameters", []))

    @jsii.member(jsii_name="toGetRelationalDatabases")
    def to_get_relational_databases(self) -> "Lightsail":
        '''(experimental) Grants permission to get information about all relational databases.

        Access Level: Read

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_GetRelationalDatabases.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toGetRelationalDatabases", []))

    @jsii.member(jsii_name="toGetRelationalDatabaseSnapshot")
    def to_get_relational_database_snapshot(self) -> "Lightsail":
        '''(experimental) Grants permission to get information about a relational database snapshot.

        Access Level: Read

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_GetRelationalDatabaseSnapshot.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toGetRelationalDatabaseSnapshot", []))

    @jsii.member(jsii_name="toGetRelationalDatabaseSnapshots")
    def to_get_relational_database_snapshots(self) -> "Lightsail":
        '''(experimental) Grants permission to get information about all relational database snapshots.

        Access Level: Read

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_GetRelationalDatabaseSnapshots.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toGetRelationalDatabaseSnapshots", []))

    @jsii.member(jsii_name="toGetStaticIp")
    def to_get_static_ip(self) -> "Lightsail":
        '''(experimental) Grants permission to get information about a static IP.

        Access Level: Read

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_GetStaticIp.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toGetStaticIp", []))

    @jsii.member(jsii_name="toGetStaticIps")
    def to_get_static_ips(self) -> "Lightsail":
        '''(experimental) Grants permission to get information about all static IPs.

        Access Level: Read

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_GetStaticIps.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toGetStaticIps", []))

    @jsii.member(jsii_name="toImportKeyPair")
    def to_import_key_pair(self) -> "Lightsail":
        '''(experimental) Grants permission to import a public key from a key pair.

        Access Level: Write

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_ImportKeyPair.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toImportKeyPair", []))

    @jsii.member(jsii_name="toIsVpcPeered")
    def to_is_vpc_peered(self) -> "Lightsail":
        '''(experimental) Grants permission to get a boolean value indicating whether the Amazon Lightsail virtual private cloud (VPC) is peered.

        Access Level: Read

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_IsVpcPeered.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toIsVpcPeered", []))

    @jsii.member(jsii_name="toOpenInstancePublicPorts")
    def to_open_instance_public_ports(self) -> "Lightsail":
        '''(experimental) Grants permission to add, or open a public port of an instance.

        Access Level: Write

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_OpenInstancePublicPorts.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toOpenInstancePublicPorts", []))

    @jsii.member(jsii_name="toPeerVpc")
    def to_peer_vpc(self) -> "Lightsail":
        '''(experimental) Grants permission to try to peer the Amazon Lightsail virtual private cloud (VPC) with the default VPC.

        Access Level: Write

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_PeerVpc.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toPeerVpc", []))

    @jsii.member(jsii_name="toPutAlarm")
    def to_put_alarm(self) -> "Lightsail":
        '''(experimental) Grants permission to creates or update an alarm, and associate it with the specified metric.

        Access Level: Write

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_PutAlarm.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toPutAlarm", []))

    @jsii.member(jsii_name="toPutInstancePublicPorts")
    def to_put_instance_public_ports(self) -> "Lightsail":
        '''(experimental) Grants permission to set the specified open ports for an instance, and closes all ports for every protocol not included in the request.

        Access Level: Write

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_PutInstancePublicPorts.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toPutInstancePublicPorts", []))

    @jsii.member(jsii_name="toRebootInstance")
    def to_reboot_instance(self) -> "Lightsail":
        '''(experimental) Grants permission to reboot an instance that is in a running state.

        Access Level: Write

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_RebootInstance.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toRebootInstance", []))

    @jsii.member(jsii_name="toRebootRelationalDatabase")
    def to_reboot_relational_database(self) -> "Lightsail":
        '''(experimental) Grants permission to reboot a relational database that is in a running state.

        Access Level: Write

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_RebootRelationalDatabase.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toRebootRelationalDatabase", []))

    @jsii.member(jsii_name="toRegisterContainerImage")
    def to_register_container_image(self) -> "Lightsail":
        '''(experimental) Grants permission to register a container image to your Amazon Lightsail container service.

        Access Level: Write

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_RegisterContainerImage.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toRegisterContainerImage", []))

    @jsii.member(jsii_name="toReleaseStaticIp")
    def to_release_static_ip(self) -> "Lightsail":
        '''(experimental) Grants permission to delete a static IP.

        Access Level: Write

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_ReleaseStaticIp.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toReleaseStaticIp", []))

    @jsii.member(jsii_name="toResetDistributionCache")
    def to_reset_distribution_cache(self) -> "Lightsail":
        '''(experimental) Grants permission to delete currently cached content from your Amazon Lightsail content delivery network (CDN) distribution.

        Access Level: Write

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_ResetDistributionCache.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toResetDistributionCache", []))

    @jsii.member(jsii_name="toSendContactMethodVerification")
    def to_send_contact_method_verification(self) -> "Lightsail":
        '''(experimental) Grants permission to send a verification request to an email contact method to ensure it's owned by the requester.

        Access Level: Write

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_SendContactMethodVerification.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toSendContactMethodVerification", []))

    @jsii.member(jsii_name="toSetIpAddressType")
    def to_set_ip_address_type(self) -> "Lightsail":
        '''(experimental) Grants permission to set the IP address type for a Amazon Lightsail resource.

        Access Level: Write

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_SetIpAddressType.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toSetIpAddressType", []))

    @jsii.member(jsii_name="toSetResourceAccessForBucket")
    def to_set_resource_access_for_bucket(self) -> "Lightsail":
        '''(experimental) Grants permission to set the Amazon Lightsail resources that can access the specified Amazon Lightsail bucket.

        Access Level: Write

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_SetResourceAccessForBucket.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toSetResourceAccessForBucket", []))

    @jsii.member(jsii_name="toStartInstance")
    def to_start_instance(self) -> "Lightsail":
        '''(experimental) Grants permission to start an instance that is in a stopped state.

        Access Level: Write

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_StartInstance.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toStartInstance", []))

    @jsii.member(jsii_name="toStartRelationalDatabase")
    def to_start_relational_database(self) -> "Lightsail":
        '''(experimental) Grants permission to start a relational database that is in a stopped state.

        Access Level: Write

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_StartRelationalDatabase.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toStartRelationalDatabase", []))

    @jsii.member(jsii_name="toStopInstance")
    def to_stop_instance(self) -> "Lightsail":
        '''(experimental) Grants permission to stop an instance that is in a running state.

        Access Level: Write

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_StopInstance.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toStopInstance", []))

    @jsii.member(jsii_name="toStopRelationalDatabase")
    def to_stop_relational_database(self) -> "Lightsail":
        '''(experimental) Grants permission to stop a relational database that is in a running state.

        Access Level: Write

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_StopRelationalDatabase.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toStopRelationalDatabase", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Lightsail":
        '''(experimental) Grants permission to tag a resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toTestAlarm")
    def to_test_alarm(self) -> "Lightsail":
        '''(experimental) Grants permission to test an alarm by displaying a banner on the Amazon Lightsail console or if a notification trigger is configured for the specified alarm, by sending a notification to the notification protocol.

        Access Level: Write

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_TestAlarm.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toTestAlarm", []))

    @jsii.member(jsii_name="toUnpeerVpc")
    def to_unpeer_vpc(self) -> "Lightsail":
        '''(experimental) Grants permission to try to unpeer the Amazon Lightsail virtual private cloud (VPC) from the default VPC.

        Access Level: Write

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_UnpeerVpc.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toUnpeerVpc", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Lightsail":
        '''(experimental) Grants permission to untag a resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateBucket")
    def to_update_bucket(self) -> "Lightsail":
        '''(experimental) Grants permission to update an existing Amazon Lightsail bucket.

        Access Level: Write

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_UpdateBucket.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toUpdateBucket", []))

    @jsii.member(jsii_name="toUpdateBucketBundle")
    def to_update_bucket_bundle(self) -> "Lightsail":
        '''(experimental) Grants permission to update the bundle, or storage plan, of an existing Amazon Lightsail bucket.

        Access Level: Write

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_UpdateBucketBundle.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toUpdateBucketBundle", []))

    @jsii.member(jsii_name="toUpdateContainerService")
    def to_update_container_service(self) -> "Lightsail":
        '''(experimental) Grants permission to update the configuration of your Amazon Lightsail container service, such as its power, scale, and public domain names.

        Access Level: Write

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_UpdateContainerService.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toUpdateContainerService", []))

    @jsii.member(jsii_name="toUpdateDistribution")
    def to_update_distribution(self) -> "Lightsail":
        '''(experimental) Grants permission to update an existing Amazon Lightsail content delivery network (CDN) distribution or its configuration.

        Access Level: Write

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_UpdateDistribution.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toUpdateDistribution", []))

    @jsii.member(jsii_name="toUpdateDistributionBundle")
    def to_update_distribution_bundle(self) -> "Lightsail":
        '''(experimental) Grants permission to update the bundle of your Amazon Lightsail content delivery network (CDN) distribution.

        Access Level: Write

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_UpdateDistributionBundle.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toUpdateDistributionBundle", []))

    @jsii.member(jsii_name="toUpdateDomainEntry")
    def to_update_domain_entry(self) -> "Lightsail":
        '''(experimental) Grants permission to update a domain recordset after it is created.

        Access Level: Write

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_UpdateDomainEntry.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toUpdateDomainEntry", []))

    @jsii.member(jsii_name="toUpdateInstanceMetadataOptions")
    def to_update_instance_metadata_options(self) -> "Lightsail":
        '''(experimental) Grants permission to update metadata options for an instance.

        Access Level: Write

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_UpdateInstanceMetadataOptions.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toUpdateInstanceMetadataOptions", []))

    @jsii.member(jsii_name="toUpdateLoadBalancerAttribute")
    def to_update_load_balancer_attribute(self) -> "Lightsail":
        '''(experimental) Grants permission to update a load balancer attribute, such as the health check path and session stickiness.

        Access Level: Write

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_DetachInstancesFromLoadBalancer.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toUpdateLoadBalancerAttribute", []))

    @jsii.member(jsii_name="toUpdateRelationalDatabase")
    def to_update_relational_database(self) -> "Lightsail":
        '''(experimental) Grants permission to update a relational database.

        Access Level: Write

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_UpdateRelationalDatabase.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toUpdateRelationalDatabase", []))

    @jsii.member(jsii_name="toUpdateRelationalDatabaseParameters")
    def to_update_relational_database_parameters(self) -> "Lightsail":
        '''(experimental) Grants permission to update the parameters of a relational database.

        Access Level: Write

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_UpdateRelationalDatabaseParameters.html

        :stability: experimental
        '''
        return typing.cast("Lightsail", jsii.invoke(self, "toUpdateRelationalDatabaseParameters", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c154e593172fd2cbf4a2bfb4b3dde88f9dbd8b4897d5bbf0db114eea0af73103)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__66b4c96ab8f50365e33b90acc4351b1add34928efb9da0ebef4e39de260e5545)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Logs(PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Logs"):
    '''(experimental) Statement provider for service `logs <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazoncloudwatchlogs.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `logs <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazoncloudwatchlogs.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onDestination")
    def on_destination(
        self,
        destination_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Logs":
        '''(experimental) Adds a resource of type destination to the statement.

        https://docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_Destination.html

        :param destination_name: - Identifier for the destinationName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4aa5aafd229941a7d9179199f228df79f712e5e80c4b3bb2c7f6f34697383357)
            check_type(argname="argument destination_name", value=destination_name, expected_type=type_hints["destination_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Logs", jsii.invoke(self, "onDestination", [destination_name, account, region, partition]))

    @jsii.member(jsii_name="onLogGroup")
    def on_log_group(
        self,
        log_group_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Logs":
        '''(experimental) Adds a resource of type log-group to the statement.

        https://docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_LogGroup.html

        :param log_group_name: - Identifier for the logGroupName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__39779120fcd84596438ab6fc1a5c4e0806025c5efe38f1010b2c7d9019f709fa)
            check_type(argname="argument log_group_name", value=log_group_name, expected_type=type_hints["log_group_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Logs", jsii.invoke(self, "onLogGroup", [log_group_name, account, region, partition]))

    @jsii.member(jsii_name="onLogStream")
    def on_log_stream(
        self,
        log_group_name: builtins.str,
        log_stream_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Logs":
        '''(experimental) Adds a resource of type log-stream to the statement.

        https://docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_LogStream.html

        :param log_group_name: - Identifier for the logGroupName.
        :param log_stream_name: - Identifier for the logStreamName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__26117259ce4a59988e5801ae286d36f5770345154ba4695ff3e1763aa04aa541)
            check_type(argname="argument log_group_name", value=log_group_name, expected_type=type_hints["log_group_name"])
            check_type(argname="argument log_stream_name", value=log_stream_name, expected_type=type_hints["log_stream_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Logs", jsii.invoke(self, "onLogStream", [log_group_name, log_stream_name, account, region, partition]))

    @jsii.member(jsii_name="toAssociateKmsKey")
    def to_associate_kms_key(self) -> "Logs":
        '''(experimental) Grants permission to associate the specified AWS Key Management Service (AWS KMS) customer master key (CMK) with the specified log group.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_AssociateKmsKey.html

        :stability: experimental
        '''
        return typing.cast("Logs", jsii.invoke(self, "toAssociateKmsKey", []))

    @jsii.member(jsii_name="toCancelExportTask")
    def to_cancel_export_task(self) -> "Logs":
        '''(experimental) Grants permission to cancel an export task if it is in PENDING or RUNNING state.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_CancelExportTask.html

        :stability: experimental
        '''
        return typing.cast("Logs", jsii.invoke(self, "toCancelExportTask", []))

    @jsii.member(jsii_name="toCreateExportTask")
    def to_create_export_task(self) -> "Logs":
        '''(experimental) Grants permission to create an ExportTask which allows you to efficiently export data from a Log Group to your Amazon S3 bucket.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_CreateExportTask.html

        :stability: experimental
        '''
        return typing.cast("Logs", jsii.invoke(self, "toCreateExportTask", []))

    @jsii.member(jsii_name="toCreateLogDelivery")
    def to_create_log_delivery(self) -> "Logs":
        '''(experimental) Grants permission to create the log delivery.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonCloudWatch/latest/logs/AWS-logs-and-resource-policy.html

        :stability: experimental
        '''
        return typing.cast("Logs", jsii.invoke(self, "toCreateLogDelivery", []))

    @jsii.member(jsii_name="toCreateLogGroup")
    def to_create_log_group(self) -> "Logs":
        '''(experimental) Grants permission to create a new log group with the specified name.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_CreateLogGroup.html

        :stability: experimental
        '''
        return typing.cast("Logs", jsii.invoke(self, "toCreateLogGroup", []))

    @jsii.member(jsii_name="toCreateLogStream")
    def to_create_log_stream(self) -> "Logs":
        '''(experimental) Grants permission to create a new log stream with the specified name.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_CreateLogStream.html

        :stability: experimental
        '''
        return typing.cast("Logs", jsii.invoke(self, "toCreateLogStream", []))

    @jsii.member(jsii_name="toDeleteDataProtectionPolicy")
    def to_delete_data_protection_policy(self) -> "Logs":
        '''(experimental) Grants permission to delete a data protection policy attached to a log group.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_DeleteDataProtectionPolicy.html

        :stability: experimental
        '''
        return typing.cast("Logs", jsii.invoke(self, "toDeleteDataProtectionPolicy", []))

    @jsii.member(jsii_name="toDeleteDestination")
    def to_delete_destination(self) -> "Logs":
        '''(experimental) Grants permission to delete the destination with the specified name.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_DeleteDestination.html

        :stability: experimental
        '''
        return typing.cast("Logs", jsii.invoke(self, "toDeleteDestination", []))

    @jsii.member(jsii_name="toDeleteLogDelivery")
    def to_delete_log_delivery(self) -> "Logs":
        '''(experimental) Grants permission to delete the log delivery information for specified log delivery.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonCloudWatch/latest/logs/AWS-logs-and-resource-policy.html

        :stability: experimental
        '''
        return typing.cast("Logs", jsii.invoke(self, "toDeleteLogDelivery", []))

    @jsii.member(jsii_name="toDeleteLogGroup")
    def to_delete_log_group(self) -> "Logs":
        '''(experimental) Grants permission to delete the log group with the specified name.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_DeleteLogGroup.html

        :stability: experimental
        '''
        return typing.cast("Logs", jsii.invoke(self, "toDeleteLogGroup", []))

    @jsii.member(jsii_name="toDeleteLogStream")
    def to_delete_log_stream(self) -> "Logs":
        '''(experimental) Grants permission to delete a log stream.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_DeleteLogStream.html

        :stability: experimental
        '''
        return typing.cast("Logs", jsii.invoke(self, "toDeleteLogStream", []))

    @jsii.member(jsii_name="toDeleteMetricFilter")
    def to_delete_metric_filter(self) -> "Logs":
        '''(experimental) Grants permission to delete a metric filter associated with the specified log group.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_DeleteMetricFilter.html

        :stability: experimental
        '''
        return typing.cast("Logs", jsii.invoke(self, "toDeleteMetricFilter", []))

    @jsii.member(jsii_name="toDeleteQueryDefinition")
    def to_delete_query_definition(self) -> "Logs":
        '''(experimental) Grants permission to delete a saved CloudWatch Logs Insights query definition.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_DeleteQueryDefinition.html

        :stability: experimental
        '''
        return typing.cast("Logs", jsii.invoke(self, "toDeleteQueryDefinition", []))

    @jsii.member(jsii_name="toDeleteResourcePolicy")
    def to_delete_resource_policy(self) -> "Logs":
        '''(experimental) Grants permission to delete a resource policy from this account.

        Access Level: Permissions management

        https://docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_DeleteResourcePolicy.html

        :stability: experimental
        '''
        return typing.cast("Logs", jsii.invoke(self, "toDeleteResourcePolicy", []))

    @jsii.member(jsii_name="toDeleteRetentionPolicy")
    def to_delete_retention_policy(self) -> "Logs":
        '''(experimental) Grants permission to delete the retention policy of the specified log group.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_DeleteRetentionPolicy.html

        :stability: experimental
        '''
        return typing.cast("Logs", jsii.invoke(self, "toDeleteRetentionPolicy", []))

    @jsii.member(jsii_name="toDeleteSubscriptionFilter")
    def to_delete_subscription_filter(self) -> "Logs":
        '''(experimental) Grants permission to delete a subscription filter associated with the specified log group.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_DeleteSubscriptionFilter.html

        :stability: experimental
        '''
        return typing.cast("Logs", jsii.invoke(self, "toDeleteSubscriptionFilter", []))

    @jsii.member(jsii_name="toDescribeDestinations")
    def to_describe_destinations(self) -> "Logs":
        '''(experimental) Grants permission to return all the destinations that are associated with the AWS account making the request.

        Access Level: List

        https://docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_DescribeDestinations.html

        :stability: experimental
        '''
        return typing.cast("Logs", jsii.invoke(self, "toDescribeDestinations", []))

    @jsii.member(jsii_name="toDescribeExportTasks")
    def to_describe_export_tasks(self) -> "Logs":
        '''(experimental) Grants permission to return all the export tasks that are associated with the AWS account making the request.

        Access Level: List

        https://docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_DescribeExportTasks.html

        :stability: experimental
        '''
        return typing.cast("Logs", jsii.invoke(self, "toDescribeExportTasks", []))

    @jsii.member(jsii_name="toDescribeLogGroups")
    def to_describe_log_groups(self) -> "Logs":
        '''(experimental) Grants permission to return all the log groups that are associated with the AWS account making the request.

        Access Level: List

        https://docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_DescribeLogGroups.html

        :stability: experimental
        '''
        return typing.cast("Logs", jsii.invoke(self, "toDescribeLogGroups", []))

    @jsii.member(jsii_name="toDescribeLogStreams")
    def to_describe_log_streams(self) -> "Logs":
        '''(experimental) Grants permission to return all the log streams that are associated with the specified log group.

        Access Level: List

        https://docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_DescribeLogStreams.html

        :stability: experimental
        '''
        return typing.cast("Logs", jsii.invoke(self, "toDescribeLogStreams", []))

    @jsii.member(jsii_name="toDescribeMetricFilters")
    def to_describe_metric_filters(self) -> "Logs":
        '''(experimental) Grants permission to return all the metrics filters associated with the specified log group.

        Access Level: List

        https://docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_DescribeMetricFilters.html

        :stability: experimental
        '''
        return typing.cast("Logs", jsii.invoke(self, "toDescribeMetricFilters", []))

    @jsii.member(jsii_name="toDescribeQueries")
    def to_describe_queries(self) -> "Logs":
        '''(experimental) Grants permission to return a list of CloudWatch Logs Insights queries that are scheduled, executing, or have been executed recently in this account.

        Access Level: List

        https://docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_DescribeQueries.html

        :stability: experimental
        '''
        return typing.cast("Logs", jsii.invoke(self, "toDescribeQueries", []))

    @jsii.member(jsii_name="toDescribeQueryDefinitions")
    def to_describe_query_definitions(self) -> "Logs":
        '''(experimental) Grants permission to return a paginated list of your saved CloudWatch Logs Insights query definitions.

        Access Level: List

        https://docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_DescribeQueryDefinitions.html

        :stability: experimental
        '''
        return typing.cast("Logs", jsii.invoke(self, "toDescribeQueryDefinitions", []))

    @jsii.member(jsii_name="toDescribeResourcePolicies")
    def to_describe_resource_policies(self) -> "Logs":
        '''(experimental) Grants permission to return all the resource policies in this account.

        Access Level: List

        https://docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_DescribeResourcePolicies.html

        :stability: experimental
        '''
        return typing.cast("Logs", jsii.invoke(self, "toDescribeResourcePolicies", []))

    @jsii.member(jsii_name="toDescribeSubscriptionFilters")
    def to_describe_subscription_filters(self) -> "Logs":
        '''(experimental) Grants permission to return all the subscription filters associated with the specified log group.

        Access Level: List

        https://docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_DescribeSubscriptionFilters.html

        :stability: experimental
        '''
        return typing.cast("Logs", jsii.invoke(self, "toDescribeSubscriptionFilters", []))

    @jsii.member(jsii_name="toDisassociateKmsKey")
    def to_disassociate_kms_key(self) -> "Logs":
        '''(experimental) Grants permission to disassociate the associated AWS Key Management Service (AWS KMS) customer master key (CMK) from the specified log group.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_DisassociateKmsKey.html

        :stability: experimental
        '''
        return typing.cast("Logs", jsii.invoke(self, "toDisassociateKmsKey", []))

    @jsii.member(jsii_name="toFilterLogEvents")
    def to_filter_log_events(self) -> "Logs":
        '''(experimental) Grants permission to retrieve log events, optionally filtered by a filter pattern from the specified log group.

        Access Level: Read

        https://docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_FilterLogEvents.html

        :stability: experimental
        '''
        return typing.cast("Logs", jsii.invoke(self, "toFilterLogEvents", []))

    @jsii.member(jsii_name="toGetDataProtectionPolicy")
    def to_get_data_protection_policy(self) -> "Logs":
        '''(experimental) Grants permission to retrieve a data protection policy attached to a log group.

        Access Level: Read

        https://docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_GetDataProtectionPolicy.html

        :stability: experimental
        '''
        return typing.cast("Logs", jsii.invoke(self, "toGetDataProtectionPolicy", []))

    @jsii.member(jsii_name="toGetLogDelivery")
    def to_get_log_delivery(self) -> "Logs":
        '''(experimental) Grants permission to get the log delivery information for specified log delivery.

        Access Level: Read

        https://docs.aws.amazon.com/AmazonCloudWatch/latest/logs/AWS-logs-and-resource-policy.html

        :stability: experimental
        '''
        return typing.cast("Logs", jsii.invoke(self, "toGetLogDelivery", []))

    @jsii.member(jsii_name="toGetLogEvents")
    def to_get_log_events(self) -> "Logs":
        '''(experimental) Grants permission to retrieve log events from the specified log stream.

        Access Level: Read

        https://docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_GetLogEvents.html

        :stability: experimental
        '''
        return typing.cast("Logs", jsii.invoke(self, "toGetLogEvents", []))

    @jsii.member(jsii_name="toGetLogGroupFields")
    def to_get_log_group_fields(self) -> "Logs":
        '''(experimental) Grants permission to return a list of the fields that are included in log events in the specified log group, along with the percentage of log events that contain each field.

        Access Level: Read

        https://docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_GetLogGroupFields.html

        :stability: experimental
        '''
        return typing.cast("Logs", jsii.invoke(self, "toGetLogGroupFields", []))

    @jsii.member(jsii_name="toGetLogRecord")
    def to_get_log_record(self) -> "Logs":
        '''(experimental) Grants permission to retrieve all the fields and values of a single log event.

        Access Level: Read

        https://docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_GetLogRecord.html

        :stability: experimental
        '''
        return typing.cast("Logs", jsii.invoke(self, "toGetLogRecord", []))

    @jsii.member(jsii_name="toGetQueryResults")
    def to_get_query_results(self) -> "Logs":
        '''(experimental) Grants permission to return the results from the specified query.

        Access Level: Read

        https://docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_GetQueryResults.html

        :stability: experimental
        '''
        return typing.cast("Logs", jsii.invoke(self, "toGetQueryResults", []))

    @jsii.member(jsii_name="toLink")
    def to_link(self) -> "Logs":
        '''(experimental) Grants permission to share CloudWatch resources with a monitoring account.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/CloudWatch-Unified-Cross-Account-Setup.html#CloudWatch-Unified-Cross-Account-Setup-permissions

        :stability: experimental
        '''
        return typing.cast("Logs", jsii.invoke(self, "toLink", []))

    @jsii.member(jsii_name="toListLogDeliveries")
    def to_list_log_deliveries(self) -> "Logs":
        '''(experimental) Grants permission to list all the log deliveries for specified account and/or log source.

        Access Level: List

        https://docs.aws.amazon.com/AmazonCloudWatch/latest/logs/AWS-logs-and-resource-policy.html

        :stability: experimental
        '''
        return typing.cast("Logs", jsii.invoke(self, "toListLogDeliveries", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Logs":
        '''(experimental) Grants permission to list the tags for the specified resource.

        Access Level: List

        https://docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("Logs", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toListTagsLogGroup")
    def to_list_tags_log_group(self) -> "Logs":
        '''(experimental) Grants permission to list the tags for the specified log group.

        Access Level: List

        https://docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_ListTagsLogGroup.html

        :stability: experimental
        '''
        return typing.cast("Logs", jsii.invoke(self, "toListTagsLogGroup", []))

    @jsii.member(jsii_name="toPutDataProtectionPolicy")
    def to_put_data_protection_policy(self) -> "Logs":
        '''(experimental) Grants permission to attach a data protection policy to detect and redact sensitive information from log events.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_PutDataProtectionPolicy.html

        :stability: experimental
        '''
        return typing.cast("Logs", jsii.invoke(self, "toPutDataProtectionPolicy", []))

    @jsii.member(jsii_name="toPutDestination")
    def to_put_destination(self) -> "Logs":
        '''(experimental) Grants permission to create or update a Destination.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        Dependent actions:

        - iam:PassRole

        https://docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_PutDestination.html

        :stability: experimental
        '''
        return typing.cast("Logs", jsii.invoke(self, "toPutDestination", []))

    @jsii.member(jsii_name="toPutDestinationPolicy")
    def to_put_destination_policy(self) -> "Logs":
        '''(experimental) Grants permission to create or update an access policy associated with an existing Destination.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_PutDestinationPolicy.html

        :stability: experimental
        '''
        return typing.cast("Logs", jsii.invoke(self, "toPutDestinationPolicy", []))

    @jsii.member(jsii_name="toPutLogEvents")
    def to_put_log_events(self) -> "Logs":
        '''(experimental) Grants permission to upload a batch of log events to the specified log stream.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_PutLogEvents.html

        :stability: experimental
        '''
        return typing.cast("Logs", jsii.invoke(self, "toPutLogEvents", []))

    @jsii.member(jsii_name="toPutMetricFilter")
    def to_put_metric_filter(self) -> "Logs":
        '''(experimental) Grants permission to create or update a metric filter and associates it with the specified log group.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_PutMetricFilter.html

        :stability: experimental
        '''
        return typing.cast("Logs", jsii.invoke(self, "toPutMetricFilter", []))

    @jsii.member(jsii_name="toPutQueryDefinition")
    def to_put_query_definition(self) -> "Logs":
        '''(experimental) Grants permission to create or update a query definition.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_PutQueryDefinition.html

        :stability: experimental
        '''
        return typing.cast("Logs", jsii.invoke(self, "toPutQueryDefinition", []))

    @jsii.member(jsii_name="toPutResourcePolicy")
    def to_put_resource_policy(self) -> "Logs":
        '''(experimental) Grants permission to create or update a resource policy allowing other AWS services to put log events to this account.

        Access Level: Permissions management

        https://docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_PutResourcePolicy.html

        :stability: experimental
        '''
        return typing.cast("Logs", jsii.invoke(self, "toPutResourcePolicy", []))

    @jsii.member(jsii_name="toPutRetentionPolicy")
    def to_put_retention_policy(self) -> "Logs":
        '''(experimental) Grants permission to set the retention of the specified log group.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_PutRetentionPolicy.html

        :stability: experimental
        '''
        return typing.cast("Logs", jsii.invoke(self, "toPutRetentionPolicy", []))

    @jsii.member(jsii_name="toPutSubscriptionFilter")
    def to_put_subscription_filter(self) -> "Logs":
        '''(experimental) Grants permission to create or update a subscription filter and associates it with the specified log group.

        Access Level: Write

        Dependent actions:

        - iam:PassRole

        https://docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_PutSubscriptionFilter.html

        :stability: experimental
        '''
        return typing.cast("Logs", jsii.invoke(self, "toPutSubscriptionFilter", []))

    @jsii.member(jsii_name="toStartQuery")
    def to_start_query(self) -> "Logs":
        '''(experimental) Grants permission to schedule a query of a log group using CloudWatch Logs Insights.

        Access Level: Read

        https://docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_StartQuery.html

        :stability: experimental
        '''
        return typing.cast("Logs", jsii.invoke(self, "toStartQuery", []))

    @jsii.member(jsii_name="toStopQuery")
    def to_stop_query(self) -> "Logs":
        '''(experimental) Grants permission to stop a CloudWatch Logs Insights query that is in progress.

        Access Level: Read

        https://docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_StopQuery.html

        :stability: experimental
        '''
        return typing.cast("Logs", jsii.invoke(self, "toStopQuery", []))

    @jsii.member(jsii_name="toTagLogGroup")
    def to_tag_log_group(self) -> "Logs":
        '''(experimental) Grants permission to add or update the specified tags for the specified log group.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_TagLogGroup.html

        :stability: experimental
        '''
        return typing.cast("Logs", jsii.invoke(self, "toTagLogGroup", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Logs":
        '''(experimental) Grants permission to add or update the specified tags for the specified resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("Logs", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toTestMetricFilter")
    def to_test_metric_filter(self) -> "Logs":
        '''(experimental) Grants permission to test the filter pattern of a metric filter against a sample of log event messages.

        Access Level: Read

        https://docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_TestMetricFilter.html

        :stability: experimental
        '''
        return typing.cast("Logs", jsii.invoke(self, "toTestMetricFilter", []))

    @jsii.member(jsii_name="toUnmask")
    def to_unmask(self) -> "Logs":
        '''(experimental) Grants permission to fetch unmasked log events that have been redacted with a data protection policy.

        Access Level: Read

        https://docs.aws.amazon.com/AmazonCloudWatch/latest/logs/mask-sensitive-log-data.html

        :stability: experimental
        '''
        return typing.cast("Logs", jsii.invoke(self, "toUnmask", []))

    @jsii.member(jsii_name="toUntagLogGroup")
    def to_untag_log_group(self) -> "Logs":
        '''(experimental) Grants permission to remove the specified tags from the specified log group.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_UntagLogGroup.html

        :stability: experimental
        '''
        return typing.cast("Logs", jsii.invoke(self, "toUntagLogGroup", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Logs":
        '''(experimental) Grants permission to remove the specified tags from the specified resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("Logs", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateLogDelivery")
    def to_update_log_delivery(self) -> "Logs":
        '''(experimental) Grants permission to update the log delivery information for specified log delivery.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonCloudWatch/latest/logs/AWS-logs-and-resource-policy.html

        :stability: experimental
        '''
        return typing.cast("Logs", jsii.invoke(self, "toUpdateLogDelivery", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1ee0763d439e49ea3aff2a40efb9c10eb6a76b058c6d9a19309778561378b982)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e8f7da847e87e7f57b7a256613106d9be15565c32c7b9b4d014241ab8d6d02a9)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Lookoutequipment(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Lookoutequipment",
):
    '''(experimental) Statement provider for service `lookoutequipment <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonlookoutforequipment.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `lookoutequipment <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonlookoutforequipment.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onDataset")
    def on_dataset(
        self,
        dataset_name: builtins.str,
        dataset_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Lookoutequipment":
        '''(experimental) Adds a resource of type dataset to the statement.

        https://docs.aws.amazon.com/lookout-for-equipment/latest/ug/dataset.html

        :param dataset_name: - Identifier for the datasetName.
        :param dataset_id: - Identifier for the datasetId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4ecb4d5c78e00bc771edf596cae6f486b3150ec6440c2eab14f40951d8c6f9bf)
            check_type(argname="argument dataset_name", value=dataset_name, expected_type=type_hints["dataset_name"])
            check_type(argname="argument dataset_id", value=dataset_id, expected_type=type_hints["dataset_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Lookoutequipment", jsii.invoke(self, "onDataset", [dataset_name, dataset_id, account, region, partition]))

    @jsii.member(jsii_name="onInferenceScheduler")
    def on_inference_scheduler(
        self,
        inference_scheduler_name: builtins.str,
        inference_scheduler_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Lookoutequipment":
        '''(experimental) Adds a resource of type inference-scheduler to the statement.

        https://docs.aws.amazon.com/lookout-for-equipment/latest/ug/inference-scheduler.html

        :param inference_scheduler_name: - Identifier for the inferenceSchedulerName.
        :param inference_scheduler_id: - Identifier for the inferenceSchedulerId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__08f2987ff7cf6b971e96da8b81dacfa47e89b6ecca96af6ae612761b696afa7f)
            check_type(argname="argument inference_scheduler_name", value=inference_scheduler_name, expected_type=type_hints["inference_scheduler_name"])
            check_type(argname="argument inference_scheduler_id", value=inference_scheduler_id, expected_type=type_hints["inference_scheduler_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Lookoutequipment", jsii.invoke(self, "onInferenceScheduler", [inference_scheduler_name, inference_scheduler_id, account, region, partition]))

    @jsii.member(jsii_name="onLabelGroup")
    def on_label_group(
        self,
        label_group_name: builtins.str,
        label_group_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Lookoutequipment":
        '''(experimental) Adds a resource of type label-group to the statement.

        https://docs.aws.amazon.com/lookout-for-equipment/latest/ug/label-group.html

        :param label_group_name: - Identifier for the labelGroupName.
        :param label_group_id: - Identifier for the labelGroupId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3b2127147f22f67fdfec14359c3a8dd79b909ece89368077e4268750e38f0ba8)
            check_type(argname="argument label_group_name", value=label_group_name, expected_type=type_hints["label_group_name"])
            check_type(argname="argument label_group_id", value=label_group_id, expected_type=type_hints["label_group_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Lookoutequipment", jsii.invoke(self, "onLabelGroup", [label_group_name, label_group_id, account, region, partition]))

    @jsii.member(jsii_name="onModel")
    def on_model(
        self,
        model_name: builtins.str,
        model_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Lookoutequipment":
        '''(experimental) Adds a resource of type model to the statement.

        https://docs.aws.amazon.com/lookout-for-equipment/latest/ug/model.html

        :param model_name: - Identifier for the modelName.
        :param model_id: - Identifier for the modelId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ce208d666a2f7d88707bd0f7eaed24072ee5107e7e1e6055afb411029d8c2f3e)
            check_type(argname="argument model_name", value=model_name, expected_type=type_hints["model_name"])
            check_type(argname="argument model_id", value=model_id, expected_type=type_hints["model_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Lookoutequipment", jsii.invoke(self, "onModel", [model_name, model_id, account, region, partition]))

    @jsii.member(jsii_name="toCreateDataset")
    def to_create_dataset(self) -> "Lookoutequipment":
        '''(experimental) Grants permission to create a dataset.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/lookout-for-equipment/latest/ug/API_CreateDataset.html

        :stability: experimental
        '''
        return typing.cast("Lookoutequipment", jsii.invoke(self, "toCreateDataset", []))

    @jsii.member(jsii_name="toCreateInferenceScheduler")
    def to_create_inference_scheduler(self) -> "Lookoutequipment":
        '''(experimental) Grants permission to create an inference scheduler for a trained model.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/lookout-for-equipment/latest/ug/API_CreateInferenceScheduler.html

        :stability: experimental
        '''
        return typing.cast("Lookoutequipment", jsii.invoke(self, "toCreateInferenceScheduler", []))

    @jsii.member(jsii_name="toCreateLabel")
    def to_create_label(self) -> "Lookoutequipment":
        '''(experimental) Grants permission to create a label.

        Access Level: Write

        https://docs.aws.amazon.com/lookout-for-equipment/latest/ug/API_CreateLabel.html

        :stability: experimental
        '''
        return typing.cast("Lookoutequipment", jsii.invoke(self, "toCreateLabel", []))

    @jsii.member(jsii_name="toCreateLabelGroup")
    def to_create_label_group(self) -> "Lookoutequipment":
        '''(experimental) Grants permission to create a label group.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/lookout-for-equipment/latest/ug/API_CreateLabelGroup.html

        :stability: experimental
        '''
        return typing.cast("Lookoutequipment", jsii.invoke(self, "toCreateLabelGroup", []))

    @jsii.member(jsii_name="toCreateModel")
    def to_create_model(self) -> "Lookoutequipment":
        '''(experimental) Grants permission to create a model that is trained on a dataset.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/lookout-for-equipment/latest/ug/API_CreateModel.html

        :stability: experimental
        '''
        return typing.cast("Lookoutequipment", jsii.invoke(self, "toCreateModel", []))

    @jsii.member(jsii_name="toDeleteDataset")
    def to_delete_dataset(self) -> "Lookoutequipment":
        '''(experimental) Grants permission to delete a dataset.

        Access Level: Write

        https://docs.aws.amazon.com/lookout-for-equipment/latest/ug/API_DeleteDataset.html

        :stability: experimental
        '''
        return typing.cast("Lookoutequipment", jsii.invoke(self, "toDeleteDataset", []))

    @jsii.member(jsii_name="toDeleteInferenceScheduler")
    def to_delete_inference_scheduler(self) -> "Lookoutequipment":
        '''(experimental) Grants permission to delete an inference scheduler.

        Access Level: Write

        https://docs.aws.amazon.com/lookout-for-equipment/latest/ug/API_DeleteInferenceScheduler.html

        :stability: experimental
        '''
        return typing.cast("Lookoutequipment", jsii.invoke(self, "toDeleteInferenceScheduler", []))

    @jsii.member(jsii_name="toDeleteLabel")
    def to_delete_label(self) -> "Lookoutequipment":
        '''(experimental) Grants permission to delete a label.

        Access Level: Write

        https://docs.aws.amazon.com/lookout-for-equipment/latest/ug/API_DeleteLabel.html

        :stability: experimental
        '''
        return typing.cast("Lookoutequipment", jsii.invoke(self, "toDeleteLabel", []))

    @jsii.member(jsii_name="toDeleteLabelGroup")
    def to_delete_label_group(self) -> "Lookoutequipment":
        '''(experimental) Grants permission to delete a label group.

        Access Level: Write

        https://docs.aws.amazon.com/lookout-for-equipment/latest/ug/API_DeleteLabelGroup.html

        :stability: experimental
        '''
        return typing.cast("Lookoutequipment", jsii.invoke(self, "toDeleteLabelGroup", []))

    @jsii.member(jsii_name="toDeleteModel")
    def to_delete_model(self) -> "Lookoutequipment":
        '''(experimental) Grants permission to delete a model.

        Access Level: Write

        https://docs.aws.amazon.com/lookout-for-equipment/latest/ug/API_DeleteModel.html

        :stability: experimental
        '''
        return typing.cast("Lookoutequipment", jsii.invoke(self, "toDeleteModel", []))

    @jsii.member(jsii_name="toDescribeDataIngestionJob")
    def to_describe_data_ingestion_job(self) -> "Lookoutequipment":
        '''(experimental) Grants permission to describe a data ingestion job.

        Access Level: Read

        https://docs.aws.amazon.com/lookout-for-equipment/latest/ug/API_DescribeDataIngestionJob

        :stability: experimental
        '''
        return typing.cast("Lookoutequipment", jsii.invoke(self, "toDescribeDataIngestionJob", []))

    @jsii.member(jsii_name="toDescribeDataset")
    def to_describe_dataset(self) -> "Lookoutequipment":
        '''(experimental) Grants permission to describe a dataset.

        Access Level: Read

        https://docs.aws.amazon.com/lookout-for-equipment/latest/ug/API_DescribeDataset.html

        :stability: experimental
        '''
        return typing.cast("Lookoutequipment", jsii.invoke(self, "toDescribeDataset", []))

    @jsii.member(jsii_name="toDescribeInferenceScheduler")
    def to_describe_inference_scheduler(self) -> "Lookoutequipment":
        '''(experimental) Grants permission to describe an inference scheduler.

        Access Level: Read

        https://docs.aws.amazon.com/lookout-for-equipment/latest/ug/API_DescribeInferenceScheduler.html

        :stability: experimental
        '''
        return typing.cast("Lookoutequipment", jsii.invoke(self, "toDescribeInferenceScheduler", []))

    @jsii.member(jsii_name="toDescribelabel")
    def to_describelabel(self) -> "Lookoutequipment":
        '''(experimental) Grants permission to describe a label.

        Access Level: Read

        https://docs.aws.amazon.com/lookout-for-equipment/latest/ug/API_DescribeLabel.html

        :stability: experimental
        '''
        return typing.cast("Lookoutequipment", jsii.invoke(self, "toDescribelabel", []))

    @jsii.member(jsii_name="toDescribeLabelGroup")
    def to_describe_label_group(self) -> "Lookoutequipment":
        '''(experimental) Grants permission to describe a label group.

        Access Level: Read

        https://docs.aws.amazon.com/lookout-for-equipment/latest/ug/API_DescribeLabelGroup.html

        :stability: experimental
        '''
        return typing.cast("Lookoutequipment", jsii.invoke(self, "toDescribeLabelGroup", []))

    @jsii.member(jsii_name="toDescribeModel")
    def to_describe_model(self) -> "Lookoutequipment":
        '''(experimental) Grants permission to describe a model.

        Access Level: Read

        https://docs.aws.amazon.com/lookout-for-equipment/latest/ug/API_DescribeModel.html

        :stability: experimental
        '''
        return typing.cast("Lookoutequipment", jsii.invoke(self, "toDescribeModel", []))

    @jsii.member(jsii_name="toListDataIngestionJobs")
    def to_list_data_ingestion_jobs(self) -> "Lookoutequipment":
        '''(experimental) Grants permission to list the data ingestion jobs in your account or for a particular dataset.

        Access Level: List

        https://docs.aws.amazon.com/lookout-for-equipment/latest/ug/API_ListDataIngestionJobs.html

        :stability: experimental
        '''
        return typing.cast("Lookoutequipment", jsii.invoke(self, "toListDataIngestionJobs", []))

    @jsii.member(jsii_name="toListDatasets")
    def to_list_datasets(self) -> "Lookoutequipment":
        '''(experimental) Grants permission to list the datasets in your account.

        Access Level: List

        https://docs.aws.amazon.com/lookout-for-equipment/latest/ug/API_ListDatasets.html

        :stability: experimental
        '''
        return typing.cast("Lookoutequipment", jsii.invoke(self, "toListDatasets", []))

    @jsii.member(jsii_name="toListInferenceEvents")
    def to_list_inference_events(self) -> "Lookoutequipment":
        '''(experimental) Grants permission to list the inference events for an inference scheduler.

        Access Level: Read

        https://docs.aws.amazon.com/lookout-for-equipment/latest/ug/API_ListInferenceEvents.html

        :stability: experimental
        '''
        return typing.cast("Lookoutequipment", jsii.invoke(self, "toListInferenceEvents", []))

    @jsii.member(jsii_name="toListInferenceExecutions")
    def to_list_inference_executions(self) -> "Lookoutequipment":
        '''(experimental) Grants permission to list the inference executions for an inference scheduler.

        Access Level: Read

        https://docs.aws.amazon.com/lookout-for-equipment/latest/ug/API_ListInferenceExecutions.html

        :stability: experimental
        '''
        return typing.cast("Lookoutequipment", jsii.invoke(self, "toListInferenceExecutions", []))

    @jsii.member(jsii_name="toListInferenceSchedulers")
    def to_list_inference_schedulers(self) -> "Lookoutequipment":
        '''(experimental) Grants permission to list the inference schedulers in your account.

        Access Level: List

        https://docs.aws.amazon.com/lookout-for-equipment/latest/ug/API_ListInferenceSchedulers.html

        :stability: experimental
        '''
        return typing.cast("Lookoutequipment", jsii.invoke(self, "toListInferenceSchedulers", []))

    @jsii.member(jsii_name="toListLabelGroups")
    def to_list_label_groups(self) -> "Lookoutequipment":
        '''(experimental) Grants permission to list the label groups in your account.

        Access Level: List

        https://docs.aws.amazon.com/lookout-for-equipment/latest/ug/API_ListLabelGroups.html

        :stability: experimental
        '''
        return typing.cast("Lookoutequipment", jsii.invoke(self, "toListLabelGroups", []))

    @jsii.member(jsii_name="toListLabels")
    def to_list_labels(self) -> "Lookoutequipment":
        '''(experimental) Grants permission to list the labels in your account.

        Access Level: List

        https://docs.aws.amazon.com/lookout-for-equipment/latest/ug/API_ListLabels.html

        :stability: experimental
        '''
        return typing.cast("Lookoutequipment", jsii.invoke(self, "toListLabels", []))

    @jsii.member(jsii_name="toListModels")
    def to_list_models(self) -> "Lookoutequipment":
        '''(experimental) Grants permission to list the models in your account.

        Access Level: List

        https://docs.aws.amazon.com/lookout-for-equipment/latest/ug/API_ListModels.html

        :stability: experimental
        '''
        return typing.cast("Lookoutequipment", jsii.invoke(self, "toListModels", []))

    @jsii.member(jsii_name="toListSensorStatistics")
    def to_list_sensor_statistics(self) -> "Lookoutequipment":
        '''(experimental) Grants permission to list the sensor statistics for a particular dataset or an ingestion job.

        Access Level: List

        https://docs.aws.amazon.com/lookout-for-equipment/latest/ug/API_ListSensorStatistics.html

        :stability: experimental
        '''
        return typing.cast("Lookoutequipment", jsii.invoke(self, "toListSensorStatistics", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Lookoutequipment":
        '''(experimental) Grants permission to list the tags for a resource.

        Access Level: Read

        https://docs.aws.amazon.com/lookout-for-equipment/latest/ug/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("Lookoutequipment", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toStartDataIngestionJob")
    def to_start_data_ingestion_job(self) -> "Lookoutequipment":
        '''(experimental) Grants permission to start a data ingestion job for a dataset.

        Access Level: Write

        https://docs.aws.amazon.com/lookout-for-equipment/latest/ug/API_StartDataIngestionJob.html

        :stability: experimental
        '''
        return typing.cast("Lookoutequipment", jsii.invoke(self, "toStartDataIngestionJob", []))

    @jsii.member(jsii_name="toStartInferenceScheduler")
    def to_start_inference_scheduler(self) -> "Lookoutequipment":
        '''(experimental) Grants permission to start an inference scheduler.

        Access Level: Write

        https://docs.aws.amazon.com/lookout-for-equipment/latest/ug/API_StartInferenceScheduler.html

        :stability: experimental
        '''
        return typing.cast("Lookoutequipment", jsii.invoke(self, "toStartInferenceScheduler", []))

    @jsii.member(jsii_name="toStopInferenceScheduler")
    def to_stop_inference_scheduler(self) -> "Lookoutequipment":
        '''(experimental) Grants permission to stop an inference scheduler.

        Access Level: Write

        https://docs.aws.amazon.com/lookout-for-equipment/latest/ug/API_StopInferenceScheduler.html

        :stability: experimental
        '''
        return typing.cast("Lookoutequipment", jsii.invoke(self, "toStopInferenceScheduler", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Lookoutequipment":
        '''(experimental) Grants permission to tag a resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/lookout-for-equipment/latest/ug/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("Lookoutequipment", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Lookoutequipment":
        '''(experimental) Grants permission to untag a resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/lookout-for-equipment/latest/ug/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("Lookoutequipment", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateInferenceScheduler")
    def to_update_inference_scheduler(self) -> "Lookoutequipment":
        '''(experimental) Grants permission to update an inference scheduler.

        Access Level: Write

        https://docs.aws.amazon.com/lookout-for-equipment/latest/ug/API_UpdateInferenceScheduler.html

        :stability: experimental
        '''
        return typing.cast("Lookoutequipment", jsii.invoke(self, "toUpdateInferenceScheduler", []))

    @jsii.member(jsii_name="toUpdateLabelGroup")
    def to_update_label_group(self) -> "Lookoutequipment":
        '''(experimental) Grants permission to update a label group.

        Access Level: Write

        https://docs.aws.amazon.com/lookout-for-equipment/latest/ug/API_UpdateLabelGroup.html

        :stability: experimental
        '''
        return typing.cast("Lookoutequipment", jsii.invoke(self, "toUpdateLabelGroup", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__58bb1905a2ba1baa5d460b0b1141b564a0f7431031931ea798f546aacafedf68)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2fba1e27fa5a81dab702e9853d8380d294744d58112075b67920f82d23ca14e7)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Lookoutmetrics(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Lookoutmetrics",
):
    '''(experimental) Statement provider for service `lookoutmetrics <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonlookoutformetrics.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `lookoutmetrics <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonlookoutformetrics.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onAlert")
    def on_alert(
        self,
        alert_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Lookoutmetrics":
        '''(experimental) Adds a resource of type Alert to the statement.

        https://docs.aws.amazon.com/lookoutmetrics/latest/api/API_AlertSummary.html

        :param alert_name: - Identifier for the alertName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f76a6baf9ab34bfc8c785e18109e1b4f677eb1815e572fe6edd914a1272f0937)
            check_type(argname="argument alert_name", value=alert_name, expected_type=type_hints["alert_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Lookoutmetrics", jsii.invoke(self, "onAlert", [alert_name, account, region, partition]))

    @jsii.member(jsii_name="onAnomalyDetector")
    def on_anomaly_detector(
        self,
        anomaly_detector_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Lookoutmetrics":
        '''(experimental) Adds a resource of type AnomalyDetector to the statement.

        https://docs.aws.amazon.com/lookoutmetrics/latest/api/API_AnomalyDetectorSummary.html

        :param anomaly_detector_name: - Identifier for the anomalyDetectorName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c5d08a093e09858b4bc62c1a2cbe4dcd9baec2eb34a29c0824762152ec9b227a)
            check_type(argname="argument anomaly_detector_name", value=anomaly_detector_name, expected_type=type_hints["anomaly_detector_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Lookoutmetrics", jsii.invoke(self, "onAnomalyDetector", [anomaly_detector_name, account, region, partition]))

    @jsii.member(jsii_name="onMetricSet")
    def on_metric_set(
        self,
        anomaly_detector_name: builtins.str,
        metric_set_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Lookoutmetrics":
        '''(experimental) Adds a resource of type MetricSet to the statement.

        https://docs.aws.amazon.com/lookoutmetrics/latest/api/API_MetricSetSummary.html

        :param anomaly_detector_name: - Identifier for the anomalyDetectorName.
        :param metric_set_name: - Identifier for the metricSetName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e4eb4fb701a133a4dc3af717de4266efc288af4150eacdd115c8db8d431817c4)
            check_type(argname="argument anomaly_detector_name", value=anomaly_detector_name, expected_type=type_hints["anomaly_detector_name"])
            check_type(argname="argument metric_set_name", value=metric_set_name, expected_type=type_hints["metric_set_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Lookoutmetrics", jsii.invoke(self, "onMetricSet", [anomaly_detector_name, metric_set_name, account, region, partition]))

    @jsii.member(jsii_name="toActivateAnomalyDetector")
    def to_activate_anomaly_detector(self) -> "Lookoutmetrics":
        '''(experimental) Grants permission to activate an anomaly detector.

        Access Level: Write

        https://docs.aws.amazon.com/lookoutmetrics/latest/api/API_ActivateAnomalyDetector.html

        :stability: experimental
        '''
        return typing.cast("Lookoutmetrics", jsii.invoke(self, "toActivateAnomalyDetector", []))

    @jsii.member(jsii_name="toBackTestAnomalyDetector")
    def to_back_test_anomaly_detector(self) -> "Lookoutmetrics":
        '''(experimental) Grants permission to run a backtest with an anomaly detector.

        Access Level: Write

        https://docs.aws.amazon.com/lookoutmetrics/latest/api/API_BackTestAnomalyDetector.html

        :stability: experimental
        '''
        return typing.cast("Lookoutmetrics", jsii.invoke(self, "toBackTestAnomalyDetector", []))

    @jsii.member(jsii_name="toCreateAlert")
    def to_create_alert(self) -> "Lookoutmetrics":
        '''(experimental) Grants permission to create an alert for an anomaly detector.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/lookoutmetrics/latest/api/API_CreateAlert.html

        :stability: experimental
        '''
        return typing.cast("Lookoutmetrics", jsii.invoke(self, "toCreateAlert", []))

    @jsii.member(jsii_name="toCreateAnomalyDetector")
    def to_create_anomaly_detector(self) -> "Lookoutmetrics":
        '''(experimental) Grants permission to create an anomaly detector.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/lookoutmetrics/latest/api/API_CreateAnomalyDetector.html

        :stability: experimental
        '''
        return typing.cast("Lookoutmetrics", jsii.invoke(self, "toCreateAnomalyDetector", []))

    @jsii.member(jsii_name="toCreateMetricSet")
    def to_create_metric_set(self) -> "Lookoutmetrics":
        '''(experimental) Grants permission to create a dataset.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/lookoutmetrics/latest/api/API_CreateMetricSet.html

        :stability: experimental
        '''
        return typing.cast("Lookoutmetrics", jsii.invoke(self, "toCreateMetricSet", []))

    @jsii.member(jsii_name="toDeactivateAnomalyDetector")
    def to_deactivate_anomaly_detector(self) -> "Lookoutmetrics":
        '''(experimental) Grants permission to deactivate an anomaly detector.

        Access Level: Write

        https://docs.aws.amazon.com/lookoutmetrics/latest/api/API_DeactivateAnomalyDetector.html

        :stability: experimental
        '''
        return typing.cast("Lookoutmetrics", jsii.invoke(self, "toDeactivateAnomalyDetector", []))

    @jsii.member(jsii_name="toDeleteAlert")
    def to_delete_alert(self) -> "Lookoutmetrics":
        '''(experimental) Grants permission to delete an alert.

        Access Level: Write

        https://docs.aws.amazon.com/lookoutmetrics/latest/api/API_DeleteAlert.html

        :stability: experimental
        '''
        return typing.cast("Lookoutmetrics", jsii.invoke(self, "toDeleteAlert", []))

    @jsii.member(jsii_name="toDeleteAnomalyDetector")
    def to_delete_anomaly_detector(self) -> "Lookoutmetrics":
        '''(experimental) Grants permission to delete an anomaly detector.

        Access Level: Write

        https://docs.aws.amazon.com/lookoutmetrics/latest/api/API_DeleteAnomalyDetector.html

        :stability: experimental
        '''
        return typing.cast("Lookoutmetrics", jsii.invoke(self, "toDeleteAnomalyDetector", []))

    @jsii.member(jsii_name="toDescribeAlert")
    def to_describe_alert(self) -> "Lookoutmetrics":
        '''(experimental) Grants permission to get details about an alert.

        Access Level: Read

        https://docs.aws.amazon.com/lookoutmetrics/latest/api/API_DescribeAlert.html

        :stability: experimental
        '''
        return typing.cast("Lookoutmetrics", jsii.invoke(self, "toDescribeAlert", []))

    @jsii.member(jsii_name="toDescribeAnomalyDetectionExecutions")
    def to_describe_anomaly_detection_executions(self) -> "Lookoutmetrics":
        '''(experimental) Grants permission to get information about an anomaly detection job.

        Access Level: Read

        https://docs.aws.amazon.com/lookoutmetrics/latest/api/API_DescribeAnomalyDetectionExecutions.html

        :stability: experimental
        '''
        return typing.cast("Lookoutmetrics", jsii.invoke(self, "toDescribeAnomalyDetectionExecutions", []))

    @jsii.member(jsii_name="toDescribeAnomalyDetector")
    def to_describe_anomaly_detector(self) -> "Lookoutmetrics":
        '''(experimental) Grants permission to get details about an anomaly detector.

        Access Level: Read

        https://docs.aws.amazon.com/lookoutmetrics/latest/api/API_DescribeAnomalyDetector.html

        :stability: experimental
        '''
        return typing.cast("Lookoutmetrics", jsii.invoke(self, "toDescribeAnomalyDetector", []))

    @jsii.member(jsii_name="toDescribeMetricSet")
    def to_describe_metric_set(self) -> "Lookoutmetrics":
        '''(experimental) Grants permission to get details about a dataset.

        Access Level: Read

        https://docs.aws.amazon.com/lookoutmetrics/latest/api/API_DescribeMetricSet.html

        :stability: experimental
        '''
        return typing.cast("Lookoutmetrics", jsii.invoke(self, "toDescribeMetricSet", []))

    @jsii.member(jsii_name="toDetectMetricSetConfig")
    def to_detect_metric_set_config(self) -> "Lookoutmetrics":
        '''(experimental) Grants permission to detect metric set config from data source.

        Access Level: Write

        https://docs.aws.amazon.com/lookoutmetrics/latest/api/API_DetectMetricSetConfig.html

        :stability: experimental
        '''
        return typing.cast("Lookoutmetrics", jsii.invoke(self, "toDetectMetricSetConfig", []))

    @jsii.member(jsii_name="toGetAnomalyGroup")
    def to_get_anomaly_group(self) -> "Lookoutmetrics":
        '''(experimental) Grants permission to get details about a group of affected metrics.

        Access Level: Read

        https://docs.aws.amazon.com/lookoutmetrics/latest/api/API_GetAnomalyGroup.html

        :stability: experimental
        '''
        return typing.cast("Lookoutmetrics", jsii.invoke(self, "toGetAnomalyGroup", []))

    @jsii.member(jsii_name="toGetDataQualityMetrics")
    def to_get_data_quality_metrics(self) -> "Lookoutmetrics":
        '''(experimental) Grants permission to get data quality metrics for an anomaly detector.

        Access Level: Read

        https://docs.aws.amazon.com/lookoutmetrics/latest/api/API_GetDataQualityMetrics.html

        :stability: experimental
        '''
        return typing.cast("Lookoutmetrics", jsii.invoke(self, "toGetDataQualityMetrics", []))

    @jsii.member(jsii_name="toGetFeedback")
    def to_get_feedback(self) -> "Lookoutmetrics":
        '''(experimental) Grants permission to get feedback on affected metrics for an anomaly group.

        Access Level: Read

        https://docs.aws.amazon.com/lookoutmetrics/latest/api/API_GetFeedback.html

        :stability: experimental
        '''
        return typing.cast("Lookoutmetrics", jsii.invoke(self, "toGetFeedback", []))

    @jsii.member(jsii_name="toGetSampleData")
    def to_get_sample_data(self) -> "Lookoutmetrics":
        '''(experimental) Grants permission to get a selection of sample records from an Amazon S3 datasource.

        Access Level: Read

        https://docs.aws.amazon.com/lookoutmetrics/latest/api/API_GetSampleData.html

        :stability: experimental
        '''
        return typing.cast("Lookoutmetrics", jsii.invoke(self, "toGetSampleData", []))

    @jsii.member(jsii_name="toListAlerts")
    def to_list_alerts(self) -> "Lookoutmetrics":
        '''(experimental) Grants permission to get a list of alerts for a detector.

        Access Level: List

        https://docs.aws.amazon.com/lookoutmetrics/latest/api/API_ListAlerts.html

        :stability: experimental
        '''
        return typing.cast("Lookoutmetrics", jsii.invoke(self, "toListAlerts", []))

    @jsii.member(jsii_name="toListAnomalyDetectors")
    def to_list_anomaly_detectors(self) -> "Lookoutmetrics":
        '''(experimental) Grants permission to get a list of anomaly detectors.

        Access Level: List

        https://docs.aws.amazon.com/lookoutmetrics/latest/api/API_ListAnomalyDetectors.html

        :stability: experimental
        '''
        return typing.cast("Lookoutmetrics", jsii.invoke(self, "toListAnomalyDetectors", []))

    @jsii.member(jsii_name="toListAnomalyGroupRelatedMetrics")
    def to_list_anomaly_group_related_metrics(self) -> "Lookoutmetrics":
        '''(experimental) Grants permission to get a list of related measures in an anomaly group.

        Access Level: List

        https://docs.aws.amazon.com/lookoutmetrics/latest/api/API_ListAnomalyGroupRelatedMetrics.html

        :stability: experimental
        '''
        return typing.cast("Lookoutmetrics", jsii.invoke(self, "toListAnomalyGroupRelatedMetrics", []))

    @jsii.member(jsii_name="toListAnomalyGroupSummaries")
    def to_list_anomaly_group_summaries(self) -> "Lookoutmetrics":
        '''(experimental) Grants permission to get a list of anomaly groups.

        Access Level: List

        https://docs.aws.amazon.com/lookoutmetrics/latest/api/API_ListAnomalyGroupSummaries.html

        :stability: experimental
        '''
        return typing.cast("Lookoutmetrics", jsii.invoke(self, "toListAnomalyGroupSummaries", []))

    @jsii.member(jsii_name="toListAnomalyGroupTimeSeries")
    def to_list_anomaly_group_time_series(self) -> "Lookoutmetrics":
        '''(experimental) Grants permission to get a list of affected metrics for a measure in an anomaly group.

        Access Level: List

        https://docs.aws.amazon.com/lookoutmetrics/latest/api/API_ListAnomalyGroupTimeSeries.html

        :stability: experimental
        '''
        return typing.cast("Lookoutmetrics", jsii.invoke(self, "toListAnomalyGroupTimeSeries", []))

    @jsii.member(jsii_name="toListMetricSets")
    def to_list_metric_sets(self) -> "Lookoutmetrics":
        '''(experimental) Grants permission to get a list of datasets.

        Access Level: List

        https://docs.aws.amazon.com/lookoutmetrics/latest/api/API_ListMetricSets.html

        :stability: experimental
        '''
        return typing.cast("Lookoutmetrics", jsii.invoke(self, "toListMetricSets", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Lookoutmetrics":
        '''(experimental) Grants permission to get a list of tags for a detector, dataset, or alert.

        Access Level: Read

        https://docs.aws.amazon.com/lookoutmetrics/latest/api/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("Lookoutmetrics", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toPutFeedback")
    def to_put_feedback(self) -> "Lookoutmetrics":
        '''(experimental) Grants permission to add feedback for an affected metric in an anomaly group.

        Access Level: Write

        https://docs.aws.amazon.com/lookoutmetrics/latest/api/API_PutFeedback.html

        :stability: experimental
        '''
        return typing.cast("Lookoutmetrics", jsii.invoke(self, "toPutFeedback", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Lookoutmetrics":
        '''(experimental) Grants permission to add tags to a detector, dataset, or alert.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()
        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/lookoutmetrics/latest/api/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("Lookoutmetrics", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Lookoutmetrics":
        '''(experimental) Grants permission to remove tags from a detector, dataset, or alert.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/lookoutmetrics/latest/api/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("Lookoutmetrics", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateAlert")
    def to_update_alert(self) -> "Lookoutmetrics":
        '''(experimental) Grants permission to update an alert for an anomaly detector.

        Access Level: Write

        https://docs.aws.amazon.com/lookoutmetrics/latest/api/API_UpdateAlert.html

        :stability: experimental
        '''
        return typing.cast("Lookoutmetrics", jsii.invoke(self, "toUpdateAlert", []))

    @jsii.member(jsii_name="toUpdateAnomalyDetector")
    def to_update_anomaly_detector(self) -> "Lookoutmetrics":
        '''(experimental) Grants permission to update an anomaly detector.

        Access Level: Write

        https://docs.aws.amazon.com/lookoutmetrics/latest/api/API_UpdateAnomalyDetector.html

        :stability: experimental
        '''
        return typing.cast("Lookoutmetrics", jsii.invoke(self, "toUpdateAnomalyDetector", []))

    @jsii.member(jsii_name="toUpdateMetricSet")
    def to_update_metric_set(self) -> "Lookoutmetrics":
        '''(experimental) Grants permission to update a dataset.

        Access Level: Write

        https://docs.aws.amazon.com/lookoutmetrics/latest/api/API_UpdateMetricSet.html

        :stability: experimental
        '''
        return typing.cast("Lookoutmetrics", jsii.invoke(self, "toUpdateMetricSet", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2ab5d8367ae7ca23f3411852fed9b4a486325b2aa67081c2e4d29d9572149875)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b9ec995b9d5df6fad4beb69477da7fd1950462372c73e6d1246bf3808fada3dc)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Lookoutvision(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Lookoutvision",
):
    '''(experimental) Statement provider for service `lookoutvision <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonlookoutforvision.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `lookoutvision <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonlookoutforvision.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onModel")
    def on_model(
        self,
        project_name: builtins.str,
        model_version: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Lookoutvision":
        '''(experimental) Adds a resource of type model to the statement.

        https://docs.aws.amazon.com/lookout-for-vision/latest/developer-guide/model-create-project.html

        :param project_name: - Identifier for the projectName.
        :param model_version: - Identifier for the modelVersion.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__78806266bc91f68f4a4b8833e17797dd7e2499649ae861bddf5e0abe12e3daee)
            check_type(argname="argument project_name", value=project_name, expected_type=type_hints["project_name"])
            check_type(argname="argument model_version", value=model_version, expected_type=type_hints["model_version"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Lookoutvision", jsii.invoke(self, "onModel", [project_name, model_version, account, region, partition]))

    @jsii.member(jsii_name="onProject")
    def on_project(
        self,
        project_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Lookoutvision":
        '''(experimental) Adds a resource of type project to the statement.

        https://docs.aws.amazon.com/lookout-for-vision/latest/developer-guide/model-create-project.html

        :param project_name: - Identifier for the projectName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1edab672f98b5e60592fecf0a56c422ece4be6b369b243f9e42c76049c0a5f11)
            check_type(argname="argument project_name", value=project_name, expected_type=type_hints["project_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Lookoutvision", jsii.invoke(self, "onProject", [project_name, account, region, partition]))

    @jsii.member(jsii_name="toCreateDataset")
    def to_create_dataset(self) -> "Lookoutvision":
        '''(experimental) Grants permission to create a dataset manifest.

        Access Level: Write

        https://docs.aws.amazon.com/lookout-for-vision/latest/APIReference/API_CreateDataset.html

        :stability: experimental
        '''
        return typing.cast("Lookoutvision", jsii.invoke(self, "toCreateDataset", []))

    @jsii.member(jsii_name="toCreateModel")
    def to_create_model(self) -> "Lookoutvision":
        '''(experimental) Grants permission to create a new anomaly detection model.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/lookout-for-vision/latest/APIReference/API_CreateModel.html

        :stability: experimental
        '''
        return typing.cast("Lookoutvision", jsii.invoke(self, "toCreateModel", []))

    @jsii.member(jsii_name="toCreateProject")
    def to_create_project(self) -> "Lookoutvision":
        '''(experimental) Grants permission to create a new project.

        Access Level: Write

        https://docs.aws.amazon.com/lookout-for-vision/latest/APIReference/API_CreateProject.html

        :stability: experimental
        '''
        return typing.cast("Lookoutvision", jsii.invoke(self, "toCreateProject", []))

    @jsii.member(jsii_name="toDeleteDataset")
    def to_delete_dataset(self) -> "Lookoutvision":
        '''(experimental) Grants permission to delete a dataset.

        Access Level: Write

        https://docs.aws.amazon.com/lookout-for-vision/latest/APIReference/API_DeleteDataset.html

        :stability: experimental
        '''
        return typing.cast("Lookoutvision", jsii.invoke(self, "toDeleteDataset", []))

    @jsii.member(jsii_name="toDeleteModel")
    def to_delete_model(self) -> "Lookoutvision":
        '''(experimental) Grants permission to delete a model and all associated assets.

        Access Level: Write

        https://docs.aws.amazon.com/lookout-for-vision/latest/APIReference/API_DeleteModel.html

        :stability: experimental
        '''
        return typing.cast("Lookoutvision", jsii.invoke(self, "toDeleteModel", []))

    @jsii.member(jsii_name="toDeleteProject")
    def to_delete_project(self) -> "Lookoutvision":
        '''(experimental) Grants permission to permanently remove a project.

        Access Level: Write

        https://docs.aws.amazon.com/lookout-for-vision/latest/APIReference/API_DeleteProject.html

        :stability: experimental
        '''
        return typing.cast("Lookoutvision", jsii.invoke(self, "toDeleteProject", []))

    @jsii.member(jsii_name="toDescribeDataset")
    def to_describe_dataset(self) -> "Lookoutvision":
        '''(experimental) Grants permission to show detailed information about dataset manifest.

        Access Level: Read

        https://docs.aws.amazon.com/lookout-for-vision/latest/APIReference/API_DescribeDataset.html

        :stability: experimental
        '''
        return typing.cast("Lookoutvision", jsii.invoke(self, "toDescribeDataset", []))

    @jsii.member(jsii_name="toDescribeModel")
    def to_describe_model(self) -> "Lookoutvision":
        '''(experimental) Grants permission to show detailed information about a model.

        Access Level: Read

        https://docs.aws.amazon.com/lookout-for-vision/latest/APIReference/API_DescribeModel.html

        :stability: experimental
        '''
        return typing.cast("Lookoutvision", jsii.invoke(self, "toDescribeModel", []))

    @jsii.member(jsii_name="toDescribeModelPackagingJob")
    def to_describe_model_packaging_job(self) -> "Lookoutvision":
        '''(experimental) Grants permission to show detailed information about a model packaging job.

        Access Level: Read

        https://docs.aws.amazon.com/lookout-for-vision/latest/APIReference/API_DescribeModelPackagingJob.html

        :stability: experimental
        '''
        return typing.cast("Lookoutvision", jsii.invoke(self, "toDescribeModelPackagingJob", []))

    @jsii.member(jsii_name="toDescribeProject")
    def to_describe_project(self) -> "Lookoutvision":
        '''(experimental) Grants permission to show detailed information about a project.

        Access Level: Read

        https://docs.aws.amazon.com/lookout-for-vision/latest/APIReference/API_DescribeProject.html

        :stability: experimental
        '''
        return typing.cast("Lookoutvision", jsii.invoke(self, "toDescribeProject", []))

    @jsii.member(jsii_name="toDescribeTrialDetection")
    def to_describe_trial_detection(self) -> "Lookoutvision":
        '''(experimental) Grants permission to provides state information about a running anomaly detection job.

        Access Level: Read

        https://docs.aws.amazon.com/lookout-for-vision/latest/developer-guide/trial-detection.html

        :stability: experimental
        '''
        return typing.cast("Lookoutvision", jsii.invoke(self, "toDescribeTrialDetection", []))

    @jsii.member(jsii_name="toDetectAnomalies")
    def to_detect_anomalies(self) -> "Lookoutvision":
        '''(experimental) Grants permission to invoke detection of anomalies.

        Access Level: Write

        https://docs.aws.amazon.com/lookout-for-vision/latest/APIReference/API_DetectAnomalies.html

        :stability: experimental
        '''
        return typing.cast("Lookoutvision", jsii.invoke(self, "toDetectAnomalies", []))

    @jsii.member(jsii_name="toListDatasetEntries")
    def to_list_dataset_entries(self) -> "Lookoutvision":
        '''(experimental) Grants permission to list the contents of dataset manifest.

        Access Level: Read

        https://docs.aws.amazon.com/lookout-for-vision/latest/APIReference/API_ListDatasetEntries.html

        :stability: experimental
        '''
        return typing.cast("Lookoutvision", jsii.invoke(self, "toListDatasetEntries", []))

    @jsii.member(jsii_name="toListModelPackagingJobs")
    def to_list_model_packaging_jobs(self) -> "Lookoutvision":
        '''(experimental) Grants permission to list all model packaging jobs associated with a project.

        Access Level: List

        https://docs.aws.amazon.com/lookout-for-vision/latest/APIReference/API_ListModelPackagingJobs.html

        :stability: experimental
        '''
        return typing.cast("Lookoutvision", jsii.invoke(self, "toListModelPackagingJobs", []))

    @jsii.member(jsii_name="toListModels")
    def to_list_models(self) -> "Lookoutvision":
        '''(experimental) Grants permission to list all models associated with a project.

        Access Level: List

        https://docs.aws.amazon.com/lookout-for-vision/latest/APIReference/API_ListModels.html

        :stability: experimental
        '''
        return typing.cast("Lookoutvision", jsii.invoke(self, "toListModels", []))

    @jsii.member(jsii_name="toListProjects")
    def to_list_projects(self) -> "Lookoutvision":
        '''(experimental) Grants permission to list all projects.

        Access Level: List

        https://docs.aws.amazon.com/lookout-for-vision/latest/APIReference/API_ListProjects.html

        :stability: experimental
        '''
        return typing.cast("Lookoutvision", jsii.invoke(self, "toListProjects", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Lookoutvision":
        '''(experimental) Grants permission to list tags for a resource.

        Access Level: Read

        https://docs.aws.amazon.com/lookout-for-vision/latest/APIReference/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("Lookoutvision", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toListTrialDetections")
    def to_list_trial_detections(self) -> "Lookoutvision":
        '''(experimental) Grants permission to list all anomaly detection jobs.

        Access Level: List

        https://docs.aws.amazon.com/lookout-for-vision/latest/developer-guide/trial-detection.html

        :stability: experimental
        '''
        return typing.cast("Lookoutvision", jsii.invoke(self, "toListTrialDetections", []))

    @jsii.member(jsii_name="toStartModel")
    def to_start_model(self) -> "Lookoutvision":
        '''(experimental) Grants permission to start anomaly detection model.

        Access Level: Write

        https://docs.aws.amazon.com/lookout-for-vision/latest/APIReference/API_StartModel.html

        :stability: experimental
        '''
        return typing.cast("Lookoutvision", jsii.invoke(self, "toStartModel", []))

    @jsii.member(jsii_name="toStartModelPackagingJob")
    def to_start_model_packaging_job(self) -> "Lookoutvision":
        '''(experimental) Grants permission to start a model packaging job.

        Access Level: Write

        https://docs.aws.amazon.com/lookout-for-vision/latest/APIReference/API_StartModelPackagingJob.html

        :stability: experimental
        '''
        return typing.cast("Lookoutvision", jsii.invoke(self, "toStartModelPackagingJob", []))

    @jsii.member(jsii_name="toStartTrialDetection")
    def to_start_trial_detection(self) -> "Lookoutvision":
        '''(experimental) Grants permission to start bulk detection of anomalies for a set of images stored in an S3 bucket.

        Access Level: Write

        https://docs.aws.amazon.com/lookout-for-vision/latest/developer-guide/trial-detection.html

        :stability: experimental
        '''
        return typing.cast("Lookoutvision", jsii.invoke(self, "toStartTrialDetection", []))

    @jsii.member(jsii_name="toStopModel")
    def to_stop_model(self) -> "Lookoutvision":
        '''(experimental) Grants permission to stop anomaly detection model.

        Access Level: Write

        https://docs.aws.amazon.com/lookout-for-vision/latest/APIReference/API_StopModel.html

        :stability: experimental
        '''
        return typing.cast("Lookoutvision", jsii.invoke(self, "toStopModel", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Lookoutvision":
        '''(experimental) Grants permission to tag a resource with given key value pairs.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/lookout-for-vision/latest/APIReference/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("Lookoutvision", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Lookoutvision":
        '''(experimental) Grants permission to remove the tag with the given key from a resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/lookout-for-vision/latest/APIReference/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("Lookoutvision", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateDatasetEntries")
    def to_update_dataset_entries(self) -> "Lookoutvision":
        '''(experimental) Grants permission to update a training or test dataset manifest.

        Access Level: Write

        https://docs.aws.amazon.com/lookout-for-vision/latest/APIReference/API_UpdateDatasetEntries.html

        :stability: experimental
        '''
        return typing.cast("Lookoutvision", jsii.invoke(self, "toUpdateDatasetEntries", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c0c86f75b689da710afc8e3a1b79348728bf78b97048ffeb85c02f6eb6f4b88f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__54671bdee0d283baabf6b8f534f123e467d295e1e9bb1e192ac38020a8628d54)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class M2(PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.M2"):
    '''(experimental) Statement provider for service `m2 <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsmainframemodernizationservice.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `m2 <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsmainframemodernizationservice.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onApplication")
    def on_application(
        self,
        application_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "M2":
        '''(experimental) Adds a resource of type Application to the statement.

        https://docs.aws.amazon.com/m2/latest/userguide/concept-m2.html#application-concept

        :param application_id: - Identifier for the applicationId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f117c4e2c4bb07fe4dedaa1bd995cfbec8c7c7b01f55ba55470ff5e8c57a7c42)
            check_type(argname="argument application_id", value=application_id, expected_type=type_hints["application_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("M2", jsii.invoke(self, "onApplication", [application_id, account, region, partition]))

    @jsii.member(jsii_name="onEnvironment")
    def on_environment(
        self,
        environment_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "M2":
        '''(experimental) Adds a resource of type Environment to the statement.

        https://docs.aws.amazon.com/m2/latest/userguide/concept-m2.html#environment-concept

        :param environment_id: - Identifier for the environmentId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__dc288dc2cfb4a9bd1d61040703ed12588210da8514f83175bdd7965f22fadfdb)
            check_type(argname="argument environment_id", value=environment_id, expected_type=type_hints["environment_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("M2", jsii.invoke(self, "onEnvironment", [environment_id, account, region, partition]))

    @jsii.member(jsii_name="toCancelBatchJobExecution")
    def to_cancel_batch_job_execution(self) -> "M2":
        '''(experimental) Grants permission to cancel the execution of a batch job.

        Access Level: Write

        https://docs.aws.amazon.com/m2/latest/APIReference/API_CancelBatchJobExecution.html

        :stability: experimental
        '''
        return typing.cast("M2", jsii.invoke(self, "toCancelBatchJobExecution", []))

    @jsii.member(jsii_name="toCreateApplication")
    def to_create_application(self) -> "M2":
        '''(experimental) Grants permission to create an application.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - s3:GetObject
        - s3:ListBucket

        https://docs.aws.amazon.com/m2/latest/APIReference/API_CreateApplication.html

        :stability: experimental
        '''
        return typing.cast("M2", jsii.invoke(self, "toCreateApplication", []))

    @jsii.member(jsii_name="toCreateDataSetImportTask")
    def to_create_data_set_import_task(self) -> "M2":
        '''(experimental) Grants permission to create a data set import task.

        Access Level: Write

        Dependent actions:

        - s3:GetObject

        https://docs.aws.amazon.com/m2/latest/APIReference/API_CreateDataSetImportTask.html

        :stability: experimental
        '''
        return typing.cast("M2", jsii.invoke(self, "toCreateDataSetImportTask", []))

    @jsii.member(jsii_name="toCreateDeployment")
    def to_create_deployment(self) -> "M2":
        '''(experimental) Grants permission to create a deployment.

        Access Level: Write

        Dependent actions:

        - elasticloadbalancing:CreateListener
        - elasticloadbalancing:CreateTargetGroup
        - elasticloadbalancing:RegisterTargets

        https://docs.aws.amazon.com/m2/latest/APIReference/API_CreateDeployment.html

        :stability: experimental
        '''
        return typing.cast("M2", jsii.invoke(self, "toCreateDeployment", []))

    @jsii.member(jsii_name="toCreateEnvironment")
    def to_create_environment(self) -> "M2":
        '''(experimental) Grants permission to Create an environment.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - ec2:CreateNetworkInterface
        - ec2:CreateNetworkInterfacePermission
        - ec2:DescribeNetworkInterfaces
        - ec2:DescribeSecurityGroups
        - ec2:DescribeSubnets
        - ec2:DescribeVpcAttribute
        - ec2:DescribeVpcs
        - ec2:ModifyNetworkInterfaceAttribute
        - elasticfilesystem:DescribeMountTargets
        - elasticloadbalancing:CreateLoadBalancer
        - fsx:DescribeFileSystems
        - iam:CreateServiceLinkedRole

        https://docs.aws.amazon.com/m2/latest/APIReference/API_CreateEnvironment.html

        :stability: experimental
        '''
        return typing.cast("M2", jsii.invoke(self, "toCreateEnvironment", []))

    @jsii.member(jsii_name="toDeleteApplication")
    def to_delete_application(self) -> "M2":
        '''(experimental) Grants permission to delete an application.

        Access Level: Write

        Dependent actions:

        - elasticloadbalancing:DeleteListener
        - elasticloadbalancing:DeleteTargetGroup

        https://docs.aws.amazon.com/m2/latest/APIReference/API_DeleteApplication.html

        :stability: experimental
        '''
        return typing.cast("M2", jsii.invoke(self, "toDeleteApplication", []))

    @jsii.member(jsii_name="toDeleteApplicationFromEnvironment")
    def to_delete_application_from_environment(self) -> "M2":
        '''(experimental) Grants permission to delete an application from a runtime environment.

        Access Level: Write

        Dependent actions:

        - elasticloadbalancing:DeleteListener
        - elasticloadbalancing:DeleteTargetGroup

        https://docs.aws.amazon.com/m2/latest/APIReference/API_DeleteApplicationFromEnvironment.html

        :stability: experimental
        '''
        return typing.cast("M2", jsii.invoke(self, "toDeleteApplicationFromEnvironment", []))

    @jsii.member(jsii_name="toDeleteEnvironment")
    def to_delete_environment(self) -> "M2":
        '''(experimental) Grants permission to delete a runtime environment.

        Access Level: Write

        Dependent actions:

        - elasticloadbalancing:DeleteLoadBalancer

        https://docs.aws.amazon.com/m2/latest/APIReference/API_DeleteEnvironment.html

        :stability: experimental
        '''
        return typing.cast("M2", jsii.invoke(self, "toDeleteEnvironment", []))

    @jsii.member(jsii_name="toGetApplication")
    def to_get_application(self) -> "M2":
        '''(experimental) Grants permission to retrieve an application.

        Access Level: Read

        https://docs.aws.amazon.com/m2/latest/APIReference/API_GetApplication.html

        :stability: experimental
        '''
        return typing.cast("M2", jsii.invoke(self, "toGetApplication", []))

    @jsii.member(jsii_name="toGetApplicationVersion")
    def to_get_application_version(self) -> "M2":
        '''(experimental) Grants permission to retrieve an application version.

        Access Level: Read

        https://docs.aws.amazon.com/m2/latest/APIReference/API_GetApplicationVersion.html

        :stability: experimental
        '''
        return typing.cast("M2", jsii.invoke(self, "toGetApplicationVersion", []))

    @jsii.member(jsii_name="toGetBatchJobExecution")
    def to_get_batch_job_execution(self) -> "M2":
        '''(experimental) Grants permission to retrieve a batch job execution.

        Access Level: Read

        https://docs.aws.amazon.com/m2/latest/APIReference/API_GetBatchJobExecution.html

        :stability: experimental
        '''
        return typing.cast("M2", jsii.invoke(self, "toGetBatchJobExecution", []))

    @jsii.member(jsii_name="toGetDataSetDetails")
    def to_get_data_set_details(self) -> "M2":
        '''(experimental) Grants permission to retrieve data set details.

        Access Level: Read

        https://docs.aws.amazon.com/m2/latest/APIReference/API_GetDataSetDetails.html

        :stability: experimental
        '''
        return typing.cast("M2", jsii.invoke(self, "toGetDataSetDetails", []))

    @jsii.member(jsii_name="toGetDataSetImportTask")
    def to_get_data_set_import_task(self) -> "M2":
        '''(experimental) Grants permission to retrieve a data set import task.

        Access Level: Read

        https://docs.aws.amazon.com/m2/latest/APIReference/API_GetDataSetImportTask.html

        :stability: experimental
        '''
        return typing.cast("M2", jsii.invoke(self, "toGetDataSetImportTask", []))

    @jsii.member(jsii_name="toGetDeployment")
    def to_get_deployment(self) -> "M2":
        '''(experimental) Grants permission to retrieve a deployment.

        Access Level: Read

        https://docs.aws.amazon.com/m2/latest/APIReference/API_GetDeployment.html

        :stability: experimental
        '''
        return typing.cast("M2", jsii.invoke(self, "toGetDeployment", []))

    @jsii.member(jsii_name="toGetEnvironment")
    def to_get_environment(self) -> "M2":
        '''(experimental) Grants permission to retrieve a runtime environment.

        Access Level: Read

        https://docs.aws.amazon.com/m2/latest/APIReference/API_GetEnvironment.html

        :stability: experimental
        '''
        return typing.cast("M2", jsii.invoke(self, "toGetEnvironment", []))

    @jsii.member(jsii_name="toListApplications")
    def to_list_applications(self) -> "M2":
        '''(experimental) Grants permission to list applications.

        Access Level: List

        https://docs.aws.amazon.com/m2/latest/APIReference/API_ListApplications.html

        :stability: experimental
        '''
        return typing.cast("M2", jsii.invoke(self, "toListApplications", []))

    @jsii.member(jsii_name="toListApplicationVersions")
    def to_list_application_versions(self) -> "M2":
        '''(experimental) Grants permission to list the versions of an application.

        Access Level: Read

        https://docs.aws.amazon.com/m2/latest/APIReference/API_ListApplicationVersions.html

        :stability: experimental
        '''
        return typing.cast("M2", jsii.invoke(self, "toListApplicationVersions", []))

    @jsii.member(jsii_name="toListBatchJobDefinitions")
    def to_list_batch_job_definitions(self) -> "M2":
        '''(experimental) Grants permission to list batch job definitions.

        Access Level: Read

        https://docs.aws.amazon.com/m2/latest/APIReference/API_ListBatchJobDefinitions.html

        :stability: experimental
        '''
        return typing.cast("M2", jsii.invoke(self, "toListBatchJobDefinitions", []))

    @jsii.member(jsii_name="toListBatchJobExecutions")
    def to_list_batch_job_executions(self) -> "M2":
        '''(experimental) Grants permission to list executions for a batch job.

        Access Level: Read

        https://docs.aws.amazon.com/m2/latest/APIReference/API_ListBatchJobExecutions.html

        :stability: experimental
        '''
        return typing.cast("M2", jsii.invoke(self, "toListBatchJobExecutions", []))

    @jsii.member(jsii_name="toListDataSetImportHistory")
    def to_list_data_set_import_history(self) -> "M2":
        '''(experimental) Grants permission to list data set import history.

        Access Level: Read

        https://docs.aws.amazon.com/m2/latest/APIReference/API_ListDataSetImportHistory.html

        :stability: experimental
        '''
        return typing.cast("M2", jsii.invoke(self, "toListDataSetImportHistory", []))

    @jsii.member(jsii_name="toListDataSets")
    def to_list_data_sets(self) -> "M2":
        '''(experimental) Grants permission to list data sets.

        Access Level: Read

        https://docs.aws.amazon.com/m2/latest/APIReference/API_ListDataSets.html

        :stability: experimental
        '''
        return typing.cast("M2", jsii.invoke(self, "toListDataSets", []))

    @jsii.member(jsii_name="toListDeployments")
    def to_list_deployments(self) -> "M2":
        '''(experimental) Grants permission to list deployments.

        Access Level: Read

        https://docs.aws.amazon.com/m2/latest/APIReference/API_ListDeployments.html

        :stability: experimental
        '''
        return typing.cast("M2", jsii.invoke(self, "toListDeployments", []))

    @jsii.member(jsii_name="toListEngineVersions")
    def to_list_engine_versions(self) -> "M2":
        '''(experimental) Grants permission to list engine versions.

        Access Level: Read

        https://docs.aws.amazon.com/m2/latest/APIReference/API_ListEngineVersions.html

        :stability: experimental
        '''
        return typing.cast("M2", jsii.invoke(self, "toListEngineVersions", []))

    @jsii.member(jsii_name="toListEnvironments")
    def to_list_environments(self) -> "M2":
        '''(experimental) Grants permission to list runtime environments.

        Access Level: List

        https://docs.aws.amazon.com/m2/latest/APIReference/API_ListEnvironments.html

        :stability: experimental
        '''
        return typing.cast("M2", jsii.invoke(self, "toListEnvironments", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "M2":
        '''(experimental) Grants permission to list tags for a resource.

        Access Level: Read

        https://docs.aws.amazon.com/m2/latest/APIReference/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("M2", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toStartApplication")
    def to_start_application(self) -> "M2":
        '''(experimental) Grants permission to start an application.

        Access Level: Write

        https://docs.aws.amazon.com/m2/latest/APIReference/API_StartApplication.html

        :stability: experimental
        '''
        return typing.cast("M2", jsii.invoke(self, "toStartApplication", []))

    @jsii.member(jsii_name="toStartBatchJob")
    def to_start_batch_job(self) -> "M2":
        '''(experimental) Grants permission to start a batch job.

        Access Level: Write

        https://docs.aws.amazon.com/m2/latest/APIReference/API_StartBatchJob.html

        :stability: experimental
        '''
        return typing.cast("M2", jsii.invoke(self, "toStartBatchJob", []))

    @jsii.member(jsii_name="toStopApplication")
    def to_stop_application(self) -> "M2":
        '''(experimental) Grants permission to stop an application.

        Access Level: Write

        https://docs.aws.amazon.com/m2/latest/APIReference/API_StopApplication.html

        :stability: experimental
        '''
        return typing.cast("M2", jsii.invoke(self, "toStopApplication", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "M2":
        '''(experimental) Grants permission to tag a resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/m2/latest/APIReference/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("M2", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "M2":
        '''(experimental) Grants permission to untag a resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/m2/latest/APIReference/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("M2", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateApplication")
    def to_update_application(self) -> "M2":
        '''(experimental) Grants permission to update an application.

        Access Level: Write

        Dependent actions:

        - s3:GetObject
        - s3:ListBucket

        https://docs.aws.amazon.com/m2/latest/APIReference/API_UpdateApplication.html

        :stability: experimental
        '''
        return typing.cast("M2", jsii.invoke(self, "toUpdateApplication", []))

    @jsii.member(jsii_name="toUpdateEnvironment")
    def to_update_environment(self) -> "M2":
        '''(experimental) Grants permission to update a runtime environment.

        Access Level: Write

        https://docs.aws.amazon.com/m2/latest/APIReference/API_UpdateEnvironment.html

        :stability: experimental
        '''
        return typing.cast("M2", jsii.invoke(self, "toUpdateEnvironment", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__36dcfc1981ea6ee5733904f986992ac785d7860371601c22614ab8f3fa934311)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4fa5d81c7e569491212acdec572caae8d2a71752c3551f350808bb9a34423234)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Machinelearning(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Machinelearning",
):
    '''(experimental) Statement provider for service `machinelearning <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonmachinelearning.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `machinelearning <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonmachinelearning.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onBatchprediction")
    def on_batchprediction(
        self,
        batch_prediction_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Machinelearning":
        '''(experimental) Adds a resource of type batchprediction to the statement.

        https://docs.aws.amazon.com/machine-learning/latest/dg/amazon-machine-learning-key-concepts.html#batch-predictions

        :param batch_prediction_id: - Identifier for the batchPredictionId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__957a893f93c8eabb186e11aaff0edec2e2b9747346205cc030092b292ead3b57)
            check_type(argname="argument batch_prediction_id", value=batch_prediction_id, expected_type=type_hints["batch_prediction_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Machinelearning", jsii.invoke(self, "onBatchprediction", [batch_prediction_id, account, region, partition]))

    @jsii.member(jsii_name="onDatasource")
    def on_datasource(
        self,
        datasource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Machinelearning":
        '''(experimental) Adds a resource of type datasource to the statement.

        https://docs.aws.amazon.com/machine-learning/latest/dg/amazon-machine-learning-key-concepts.html#datasources

        :param datasource_id: - Identifier for the datasourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2c5b52a55a45d95264cec322f9ccb902621ee44b37012102dd6a9a7e30a08f75)
            check_type(argname="argument datasource_id", value=datasource_id, expected_type=type_hints["datasource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Machinelearning", jsii.invoke(self, "onDatasource", [datasource_id, account, region, partition]))

    @jsii.member(jsii_name="onEvaluation")
    def on_evaluation(
        self,
        evaluation_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Machinelearning":
        '''(experimental) Adds a resource of type evaluation to the statement.

        https://docs.aws.amazon.com/machine-learning/latest/dg/amazon-machine-learning-key-concepts.html#evaluations

        :param evaluation_id: - Identifier for the evaluationId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__305545a7adbb8338a538ebc2ed3ddf530bfa06c11d3b52ed2fcea2859a76d2ea)
            check_type(argname="argument evaluation_id", value=evaluation_id, expected_type=type_hints["evaluation_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Machinelearning", jsii.invoke(self, "onEvaluation", [evaluation_id, account, region, partition]))

    @jsii.member(jsii_name="onMlmodel")
    def on_mlmodel(
        self,
        ml_model_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Machinelearning":
        '''(experimental) Adds a resource of type mlmodel to the statement.

        https://docs.aws.amazon.com/machine-learning/latest/dg/amazon-machine-learning-key-concepts.html#ml-models

        :param ml_model_id: - Identifier for the mlModelId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2e4476c62663ca9c1b13a7d8e751e774570650941bbbe6b5a7eccf2cb29ae737)
            check_type(argname="argument ml_model_id", value=ml_model_id, expected_type=type_hints["ml_model_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Machinelearning", jsii.invoke(self, "onMlmodel", [ml_model_id, account, region, partition]))

    @jsii.member(jsii_name="toAddTags")
    def to_add_tags(self) -> "Machinelearning":
        '''(experimental) Adds one or more tags to an object, up to a limit of 10.

        Each tag consists of a key and an optional value

        Access Level: Tagging

        https://docs.aws.amazon.com/machine-learning/latest/APIReference/API_AddTags.html

        :stability: experimental
        '''
        return typing.cast("Machinelearning", jsii.invoke(self, "toAddTags", []))

    @jsii.member(jsii_name="toCreateBatchPrediction")
    def to_create_batch_prediction(self) -> "Machinelearning":
        '''(experimental) Generates predictions for a group of observations.

        Access Level: Write

        https://docs.aws.amazon.com/machine-learning/latest/APIReference/API_CreateBatchPrediction.html

        :stability: experimental
        '''
        return typing.cast("Machinelearning", jsii.invoke(self, "toCreateBatchPrediction", []))

    @jsii.member(jsii_name="toCreateDataSourceFromRDS")
    def to_create_data_source_from_rds(self) -> "Machinelearning":
        '''(experimental) Creates a DataSource object from an Amazon RDS.

        Access Level: Write

        https://docs.aws.amazon.com/machine-learning/latest/APIReference/API_CreateDataSourceFromRDS.html

        :stability: experimental
        '''
        return typing.cast("Machinelearning", jsii.invoke(self, "toCreateDataSourceFromRDS", []))

    @jsii.member(jsii_name="toCreateDataSourceFromRedshift")
    def to_create_data_source_from_redshift(self) -> "Machinelearning":
        '''(experimental) Creates a DataSource from a database hosted on an Amazon Redshift cluster.

        Access Level: Write

        https://docs.aws.amazon.com/machine-learning/latest/APIReference/API_CreateDataSourceFromRedshift.html

        :stability: experimental
        '''
        return typing.cast("Machinelearning", jsii.invoke(self, "toCreateDataSourceFromRedshift", []))

    @jsii.member(jsii_name="toCreateDataSourceFromS3")
    def to_create_data_source_from_s3(self) -> "Machinelearning":
        '''(experimental) Creates a DataSource object from S3.

        Access Level: Write

        https://docs.aws.amazon.com/machine-learning/latest/APIReference/API_CreateDataSourceFromS3.html

        :stability: experimental
        '''
        return typing.cast("Machinelearning", jsii.invoke(self, "toCreateDataSourceFromS3", []))

    @jsii.member(jsii_name="toCreateEvaluation")
    def to_create_evaluation(self) -> "Machinelearning":
        '''(experimental) Creates a new Evaluation of an MLModel.

        Access Level: Write

        https://docs.aws.amazon.com/machine-learning/latest/APIReference/API_CreateEvaluation.html

        :stability: experimental
        '''
        return typing.cast("Machinelearning", jsii.invoke(self, "toCreateEvaluation", []))

    @jsii.member(jsii_name="toCreateMLModel")
    def to_create_ml_model(self) -> "Machinelearning":
        '''(experimental) Creates a new MLModel.

        Access Level: Write

        https://docs.aws.amazon.com/machine-learning/latest/APIReference/API_CreateMLModel.html

        :stability: experimental
        '''
        return typing.cast("Machinelearning", jsii.invoke(self, "toCreateMLModel", []))

    @jsii.member(jsii_name="toCreateRealtimeEndpoint")
    def to_create_realtime_endpoint(self) -> "Machinelearning":
        '''(experimental) Creates a real-time endpoint for the MLModel.

        Access Level: Write

        https://docs.aws.amazon.com/machine-learning/latest/APIReference/API_CreateRealtimeEndpoint.html

        :stability: experimental
        '''
        return typing.cast("Machinelearning", jsii.invoke(self, "toCreateRealtimeEndpoint", []))

    @jsii.member(jsii_name="toDeleteBatchPrediction")
    def to_delete_batch_prediction(self) -> "Machinelearning":
        '''(experimental) Assigns the DELETED status to a BatchPrediction, rendering it unusable.

        Access Level: Write

        https://docs.aws.amazon.com/machine-learning/latest/APIReference/API_DeleteBatchPrediction.html

        :stability: experimental
        '''
        return typing.cast("Machinelearning", jsii.invoke(self, "toDeleteBatchPrediction", []))

    @jsii.member(jsii_name="toDeleteDataSource")
    def to_delete_data_source(self) -> "Machinelearning":
        '''(experimental) Assigns the DELETED status to a DataSource, rendering it unusable.

        Access Level: Write

        https://docs.aws.amazon.com/machine-learning/latest/APIReference/API_DeleteDataSource.html

        :stability: experimental
        '''
        return typing.cast("Machinelearning", jsii.invoke(self, "toDeleteDataSource", []))

    @jsii.member(jsii_name="toDeleteEvaluation")
    def to_delete_evaluation(self) -> "Machinelearning":
        '''(experimental) Assigns the DELETED status to an Evaluation, rendering it unusable.

        Access Level: Write

        https://docs.aws.amazon.com/machine-learning/latest/APIReference/API_DeleteEvaluation.html

        :stability: experimental
        '''
        return typing.cast("Machinelearning", jsii.invoke(self, "toDeleteEvaluation", []))

    @jsii.member(jsii_name="toDeleteMLModel")
    def to_delete_ml_model(self) -> "Machinelearning":
        '''(experimental) Assigns the DELETED status to an MLModel, rendering it unusable.

        Access Level: Write

        https://docs.aws.amazon.com/machine-learning/latest/APIReference/API_DeleteMLModel.html

        :stability: experimental
        '''
        return typing.cast("Machinelearning", jsii.invoke(self, "toDeleteMLModel", []))

    @jsii.member(jsii_name="toDeleteRealtimeEndpoint")
    def to_delete_realtime_endpoint(self) -> "Machinelearning":
        '''(experimental) Deletes a real time endpoint of an MLModel.

        Access Level: Write

        https://docs.aws.amazon.com/machine-learning/latest/APIReference/API_DeleteRealtimeEndpoint.html

        :stability: experimental
        '''
        return typing.cast("Machinelearning", jsii.invoke(self, "toDeleteRealtimeEndpoint", []))

    @jsii.member(jsii_name="toDeleteTags")
    def to_delete_tags(self) -> "Machinelearning":
        '''(experimental) Deletes the specified tags associated with an ML object. After this operation is complete, you can't recover deleted tags.

        Access Level: Tagging

        https://docs.aws.amazon.com/machine-learning/latest/APIReference/API_DeleteTags.html

        :stability: experimental
        '''
        return typing.cast("Machinelearning", jsii.invoke(self, "toDeleteTags", []))

    @jsii.member(jsii_name="toDescribeBatchPredictions")
    def to_describe_batch_predictions(self) -> "Machinelearning":
        '''(experimental) Returns a list of BatchPrediction operations that match the search criteria in the request.

        Access Level: List

        https://docs.aws.amazon.com/machine-learning/latest/APIReference/API_DescribeBatchPredictions.html

        :stability: experimental
        '''
        return typing.cast("Machinelearning", jsii.invoke(self, "toDescribeBatchPredictions", []))

    @jsii.member(jsii_name="toDescribeDataSources")
    def to_describe_data_sources(self) -> "Machinelearning":
        '''(experimental) Returns a list of DataSource that match the search criteria in the request.

        Access Level: List

        https://docs.aws.amazon.com/machine-learning/latest/APIReference/API_DescribeDataSources.html

        :stability: experimental
        '''
        return typing.cast("Machinelearning", jsii.invoke(self, "toDescribeDataSources", []))

    @jsii.member(jsii_name="toDescribeEvaluations")
    def to_describe_evaluations(self) -> "Machinelearning":
        '''(experimental) Returns a list of DescribeEvaluations that match the search criteria in the request.

        Access Level: List

        https://docs.aws.amazon.com/machine-learning/latest/APIReference/API_DescribeEvaluations.html

        :stability: experimental
        '''
        return typing.cast("Machinelearning", jsii.invoke(self, "toDescribeEvaluations", []))

    @jsii.member(jsii_name="toDescribeMLModels")
    def to_describe_ml_models(self) -> "Machinelearning":
        '''(experimental) Returns a list of MLModel that match the search criteria in the request.

        Access Level: List

        https://docs.aws.amazon.com/machine-learning/latest/APIReference/API_DescribeMLModels.html

        :stability: experimental
        '''
        return typing.cast("Machinelearning", jsii.invoke(self, "toDescribeMLModels", []))

    @jsii.member(jsii_name="toDescribeTags")
    def to_describe_tags(self) -> "Machinelearning":
        '''(experimental) Describes one or more of the tags for your Amazon ML object.

        Access Level: List

        https://docs.aws.amazon.com/machine-learning/latest/APIReference/API_DescribeTags.html

        :stability: experimental
        '''
        return typing.cast("Machinelearning", jsii.invoke(self, "toDescribeTags", []))

    @jsii.member(jsii_name="toGetBatchPrediction")
    def to_get_batch_prediction(self) -> "Machinelearning":
        '''(experimental) Returns a BatchPrediction that includes detailed metadata, status, and data file information.

        Access Level: Read

        https://docs.aws.amazon.com/machine-learning/latest/APIReference/API_GetBatchPrediction.html

        :stability: experimental
        '''
        return typing.cast("Machinelearning", jsii.invoke(self, "toGetBatchPrediction", []))

    @jsii.member(jsii_name="toGetDataSource")
    def to_get_data_source(self) -> "Machinelearning":
        '''(experimental) Returns a DataSource that includes metadata and data file information, as well as the current status of the DataSource.

        Access Level: Read

        https://docs.aws.amazon.com/machine-learning/latest/APIReference/API_GetDataSource.html

        :stability: experimental
        '''
        return typing.cast("Machinelearning", jsii.invoke(self, "toGetDataSource", []))

    @jsii.member(jsii_name="toGetEvaluation")
    def to_get_evaluation(self) -> "Machinelearning":
        '''(experimental) Returns an Evaluation that includes metadata as well as the current status of the Evaluation.

        Access Level: Read

        https://docs.aws.amazon.com/machine-learning/latest/APIReference/API_GetEvaluation.html

        :stability: experimental
        '''
        return typing.cast("Machinelearning", jsii.invoke(self, "toGetEvaluation", []))

    @jsii.member(jsii_name="toGetMLModel")
    def to_get_ml_model(self) -> "Machinelearning":
        '''(experimental) Returns an MLModel that includes detailed metadata, and data source information as well as the current status of the MLModel.

        Access Level: Read

        https://docs.aws.amazon.com/machine-learning/latest/APIReference/API_GetMLModel.html

        :stability: experimental
        '''
        return typing.cast("Machinelearning", jsii.invoke(self, "toGetMLModel", []))

    @jsii.member(jsii_name="toPredict")
    def to_predict(self) -> "Machinelearning":
        '''(experimental) Generates a prediction for the observation using the specified ML Model.

        Access Level: Write

        https://docs.aws.amazon.com/machine-learning/latest/APIReference/API_Predict.html

        :stability: experimental
        '''
        return typing.cast("Machinelearning", jsii.invoke(self, "toPredict", []))

    @jsii.member(jsii_name="toUpdateBatchPrediction")
    def to_update_batch_prediction(self) -> "Machinelearning":
        '''(experimental) Updates the BatchPredictionName of a BatchPrediction.

        Access Level: Write

        https://docs.aws.amazon.com/machine-learning/latest/APIReference/API_UpdateBatchPrediction.html

        :stability: experimental
        '''
        return typing.cast("Machinelearning", jsii.invoke(self, "toUpdateBatchPrediction", []))

    @jsii.member(jsii_name="toUpdateDataSource")
    def to_update_data_source(self) -> "Machinelearning":
        '''(experimental) Updates the DataSourceName of a DataSource.

        Access Level: Write

        https://docs.aws.amazon.com/machine-learning/latest/APIReference/API_UpdateDataSource.html

        :stability: experimental
        '''
        return typing.cast("Machinelearning", jsii.invoke(self, "toUpdateDataSource", []))

    @jsii.member(jsii_name="toUpdateEvaluation")
    def to_update_evaluation(self) -> "Machinelearning":
        '''(experimental) Updates the EvaluationName of an Evaluation.

        Access Level: Write

        https://docs.aws.amazon.com/machine-learning/latest/APIReference/API_UpdateEvaluation.html

        :stability: experimental
        '''
        return typing.cast("Machinelearning", jsii.invoke(self, "toUpdateEvaluation", []))

    @jsii.member(jsii_name="toUpdateMLModel")
    def to_update_ml_model(self) -> "Machinelearning":
        '''(experimental) Updates the MLModelName and the ScoreThreshold of an MLModel.

        Access Level: Write

        https://docs.aws.amazon.com/machine-learning/latest/APIReference/API_UpdateMLModel.html

        :stability: experimental
        '''
        return typing.cast("Machinelearning", jsii.invoke(self, "toUpdateMLModel", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a4aac8d9ce51b6f6f74ceafdfb0392e2846e25c3ea9944d95ba3b4e9e890c338)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__feff7c908d15f6637da11004962011ef7a34d5315e10e50d5b425bf8a4c628b2)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Macie2(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Macie2",
):
    '''(experimental) Statement provider for service `macie2 <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonmacie.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `macie2 <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonmacie.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onAllowList")
    def on_allow_list(
        self,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Macie2":
        '''(experimental) Adds a resource of type AllowList to the statement.

        https://docs.aws.amazon.com/macie/latest/user/what-is-macie.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7283452c44609ac06735ccc13b94d6de9bf2ab6971c50c8c97322345f7186bd3)
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Macie2", jsii.invoke(self, "onAllowList", [resource_id, account, region, partition]))

    @jsii.member(jsii_name="onClassificationJob")
    def on_classification_job(
        self,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Macie2":
        '''(experimental) Adds a resource of type ClassificationJob to the statement.

        https://docs.aws.amazon.com/macie/latest/user/what-is-macie.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__87bc6ccbc4cbcd99c7fa5046024251c18da491283bd712b2016d07c8a20aa392)
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Macie2", jsii.invoke(self, "onClassificationJob", [resource_id, account, region, partition]))

    @jsii.member(jsii_name="onCustomDataIdentifier")
    def on_custom_data_identifier(
        self,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Macie2":
        '''(experimental) Adds a resource of type CustomDataIdentifier to the statement.

        https://docs.aws.amazon.com/macie/latest/user/what-is-macie.html.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__27f92d5e618d64f09dd68a53c6df8f291c82a705a50265b3cb78ade64cc97d96)
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Macie2", jsii.invoke(self, "onCustomDataIdentifier", [resource_id, account, region, partition]))

    @jsii.member(jsii_name="onFindingsFilter")
    def on_findings_filter(
        self,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Macie2":
        '''(experimental) Adds a resource of type FindingsFilter to the statement.

        https://docs.aws.amazon.com/macie/latest/user/what-is-macie.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__af2667f951f61e9bf4185cd53966e9fbb8f6644f31293d14fe9f7928d16e9d9f)
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Macie2", jsii.invoke(self, "onFindingsFilter", [resource_id, account, region, partition]))

    @jsii.member(jsii_name="onMember")
    def on_member(
        self,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Macie2":
        '''(experimental) Adds a resource of type Member to the statement.

        https://docs.aws.amazon.com/macie/latest/user/what-is-macie.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c4d9b6101e4ef20a30a467301746fa8a773d46143d968a36f77c0e7a0df86261)
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Macie2", jsii.invoke(self, "onMember", [resource_id, account, region, partition]))

    @jsii.member(jsii_name="toAcceptInvitation")
    def to_accept_invitation(self) -> "Macie2":
        '''(experimental) Grants permission to accept an Amazon Macie membership invitation.

        Access Level: Write

        https://docs.aws.amazon.com/macie/latest/APIReference/invitations-accept.html

        :stability: experimental
        '''
        return typing.cast("Macie2", jsii.invoke(self, "toAcceptInvitation", []))

    @jsii.member(jsii_name="toBatchGetCustomDataIdentifiers")
    def to_batch_get_custom_data_identifiers(self) -> "Macie2":
        '''(experimental) Grants permission to retrieve information about one or more custom data identifiers.

        Access Level: Read

        https://docs.aws.amazon.com/macie/latest/APIReference/custom-data-identifiers-get.html

        :stability: experimental
        '''
        return typing.cast("Macie2", jsii.invoke(self, "toBatchGetCustomDataIdentifiers", []))

    @jsii.member(jsii_name="toCreateAllowList")
    def to_create_allow_list(self) -> "Macie2":
        '''(experimental) Grants permission to create and define the settings for an allow list.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/macie/latest/APIReference/allow-lists.html

        :stability: experimental
        '''
        return typing.cast("Macie2", jsii.invoke(self, "toCreateAllowList", []))

    @jsii.member(jsii_name="toCreateClassificationJob")
    def to_create_classification_job(self) -> "Macie2":
        '''(experimental) Grants permission to create and define the settings for a sensitive data discovery job.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/macie/latest/APIReference/jobs.html

        :stability: experimental
        '''
        return typing.cast("Macie2", jsii.invoke(self, "toCreateClassificationJob", []))

    @jsii.member(jsii_name="toCreateCustomDataIdentifier")
    def to_create_custom_data_identifier(self) -> "Macie2":
        '''(experimental) Grants permission to create and define the settings for a custom data identifier.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/macie/latest/APIReference/custom-data-identifiers.html

        :stability: experimental
        '''
        return typing.cast("Macie2", jsii.invoke(self, "toCreateCustomDataIdentifier", []))

    @jsii.member(jsii_name="toCreateFindingsFilter")
    def to_create_findings_filter(self) -> "Macie2":
        '''(experimental) Grants permission to create and define the settings for a findings filter.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/macie/latest/APIReference/findingsfilters.html

        :stability: experimental
        '''
        return typing.cast("Macie2", jsii.invoke(self, "toCreateFindingsFilter", []))

    @jsii.member(jsii_name="toCreateInvitations")
    def to_create_invitations(self) -> "Macie2":
        '''(experimental) Grants permission to send an Amazon Macie membership invitation.

        Access Level: Write

        https://docs.aws.amazon.com/macie/latest/APIReference/invitations.html

        :stability: experimental
        '''
        return typing.cast("Macie2", jsii.invoke(self, "toCreateInvitations", []))

    @jsii.member(jsii_name="toCreateMember")
    def to_create_member(self) -> "Macie2":
        '''(experimental) Grants permission to associate an account with an Amazon Macie administrator account.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/macie/latest/APIReference/members.html

        :stability: experimental
        '''
        return typing.cast("Macie2", jsii.invoke(self, "toCreateMember", []))

    @jsii.member(jsii_name="toCreateSampleFindings")
    def to_create_sample_findings(self) -> "Macie2":
        '''(experimental) Grants permission to create sample findings.

        Access Level: Write

        https://docs.aws.amazon.com/macie/latest/APIReference/findings-sample.html

        :stability: experimental
        '''
        return typing.cast("Macie2", jsii.invoke(self, "toCreateSampleFindings", []))

    @jsii.member(jsii_name="toDeclineInvitations")
    def to_decline_invitations(self) -> "Macie2":
        '''(experimental) Grants permission to decline Amazon Macie membership invitations.

        Access Level: Write

        https://docs.aws.amazon.com/macie/latest/APIReference/invitations-decline.html

        :stability: experimental
        '''
        return typing.cast("Macie2", jsii.invoke(self, "toDeclineInvitations", []))

    @jsii.member(jsii_name="toDeleteAllowList")
    def to_delete_allow_list(self) -> "Macie2":
        '''(experimental) Grants permission to delete an allow list.

        Access Level: Write

        https://docs.aws.amazon.com/macie/latest/APIReference/allow-lists-id.html

        :stability: experimental
        '''
        return typing.cast("Macie2", jsii.invoke(self, "toDeleteAllowList", []))

    @jsii.member(jsii_name="toDeleteCustomDataIdentifier")
    def to_delete_custom_data_identifier(self) -> "Macie2":
        '''(experimental) Grants permission to delete a custom data identifier.

        Access Level: Write

        https://docs.aws.amazon.com/macie/latest/APIReference/custom-data-identifiers-id.html

        :stability: experimental
        '''
        return typing.cast("Macie2", jsii.invoke(self, "toDeleteCustomDataIdentifier", []))

    @jsii.member(jsii_name="toDeleteFindingsFilter")
    def to_delete_findings_filter(self) -> "Macie2":
        '''(experimental) Grants permission to delete a findings filter.

        Access Level: Write

        https://docs.aws.amazon.com/macie/latest/APIReference/findingsfilters-id.html

        :stability: experimental
        '''
        return typing.cast("Macie2", jsii.invoke(self, "toDeleteFindingsFilter", []))

    @jsii.member(jsii_name="toDeleteInvitations")
    def to_delete_invitations(self) -> "Macie2":
        '''(experimental) Grants permission to delete Amazon Macie membership invitations.

        Access Level: Write

        https://docs.aws.amazon.com/macie/latest/APIReference/invitations-delete.html

        :stability: experimental
        '''
        return typing.cast("Macie2", jsii.invoke(self, "toDeleteInvitations", []))

    @jsii.member(jsii_name="toDeleteMember")
    def to_delete_member(self) -> "Macie2":
        '''(experimental) Grants permission to delete the association between an Amazon Macie administrator account and an account.

        Access Level: Write

        https://docs.aws.amazon.com/macie/latest/APIReference/members-id.html

        :stability: experimental
        '''
        return typing.cast("Macie2", jsii.invoke(self, "toDeleteMember", []))

    @jsii.member(jsii_name="toDescribeBuckets")
    def to_describe_buckets(self) -> "Macie2":
        '''(experimental) Grants permission to retrieve statistical data and other information about S3 buckets that Amazon Macie monitors and analyzes.

        Access Level: Read

        https://docs.aws.amazon.com/macie/latest/APIReference/datasources-s3.html

        :stability: experimental
        '''
        return typing.cast("Macie2", jsii.invoke(self, "toDescribeBuckets", []))

    @jsii.member(jsii_name="toDescribeClassificationJob")
    def to_describe_classification_job(self) -> "Macie2":
        '''(experimental) Grants permission to retrieve information about the status and settings for a sensitive data discovery job.

        Access Level: Read

        https://docs.aws.amazon.com/macie/latest/APIReference/jobs-jobid.html

        :stability: experimental
        '''
        return typing.cast("Macie2", jsii.invoke(self, "toDescribeClassificationJob", []))

    @jsii.member(jsii_name="toDescribeOrganizationConfiguration")
    def to_describe_organization_configuration(self) -> "Macie2":
        '''(experimental) Grants permission to retrieve information about the Amazon Macie configuration settings for an AWS organization.

        Access Level: Read

        https://docs.aws.amazon.com/macie/latest/APIReference/admin-configuration.html

        :stability: experimental
        '''
        return typing.cast("Macie2", jsii.invoke(self, "toDescribeOrganizationConfiguration", []))

    @jsii.member(jsii_name="toDisableMacie")
    def to_disable_macie(self) -> "Macie2":
        '''(experimental) Grants permission to disable an Amazon Macie account, which also deletes Macie resources for the account.

        Access Level: Write

        https://docs.aws.amazon.com/macie/latest/APIReference/macie.html

        :stability: experimental
        '''
        return typing.cast("Macie2", jsii.invoke(self, "toDisableMacie", []))

    @jsii.member(jsii_name="toDisableOrganizationAdminAccount")
    def to_disable_organization_admin_account(self) -> "Macie2":
        '''(experimental) Grants permission to disable an account as the delegated Amazon Macie administrator account for an AWS organization.

        Access Level: Write

        https://docs.aws.amazon.com/macie/latest/APIReference/admin.html

        :stability: experimental
        '''
        return typing.cast("Macie2", jsii.invoke(self, "toDisableOrganizationAdminAccount", []))

    @jsii.member(jsii_name="toDisassociateFromAdministratorAccount")
    def to_disassociate_from_administrator_account(self) -> "Macie2":
        '''(experimental) Grants permission to an Amazon Macie member account to disassociate from its Macie administrator account.

        Access Level: Write

        https://docs.aws.amazon.com/macie/latest/APIReference/administrator-disassociate.html

        :stability: experimental
        '''
        return typing.cast("Macie2", jsii.invoke(self, "toDisassociateFromAdministratorAccount", []))

    @jsii.member(jsii_name="toDisassociateFromMasterAccount")
    def to_disassociate_from_master_account(self) -> "Macie2":
        '''(experimental) Grants permission to an Amazon Macie member account to disassociate from its Macie administrator account.

        Access Level: Write

        https://docs.aws.amazon.com/macie/latest/APIReference/master-disassociate.html

        :stability: experimental
        '''
        return typing.cast("Macie2", jsii.invoke(self, "toDisassociateFromMasterAccount", []))

    @jsii.member(jsii_name="toDisassociateMember")
    def to_disassociate_member(self) -> "Macie2":
        '''(experimental) Grants permission to an Amazon Macie administrator account to disassociate from a Macie member account.

        Access Level: Write

        https://docs.aws.amazon.com/macie/latest/APIReference/members-disassociate-id.html

        :stability: experimental
        '''
        return typing.cast("Macie2", jsii.invoke(self, "toDisassociateMember", []))

    @jsii.member(jsii_name="toEnableMacie")
    def to_enable_macie(self) -> "Macie2":
        '''(experimental) Grants permission to enable and specify the configuration settings for a new Amazon Macie account.

        Access Level: Write

        https://docs.aws.amazon.com/macie/latest/APIReference/macie.html

        :stability: experimental
        '''
        return typing.cast("Macie2", jsii.invoke(self, "toEnableMacie", []))

    @jsii.member(jsii_name="toEnableOrganizationAdminAccount")
    def to_enable_organization_admin_account(self) -> "Macie2":
        '''(experimental) Grants permission to enable an account as the delegated Amazon Macie administrator account for an AWS organization.

        Access Level: Write

        https://docs.aws.amazon.com/macie/latest/APIReference/admin.html

        :stability: experimental
        '''
        return typing.cast("Macie2", jsii.invoke(self, "toEnableOrganizationAdminAccount", []))

    @jsii.member(jsii_name="toGetAdministratorAccount")
    def to_get_administrator_account(self) -> "Macie2":
        '''(experimental) Grants permission to retrieve information about the Amazon Macie administrator account for an account.

        Access Level: Read

        https://docs.aws.amazon.com/macie/latest/APIReference/administrator.html

        :stability: experimental
        '''
        return typing.cast("Macie2", jsii.invoke(self, "toGetAdministratorAccount", []))

    @jsii.member(jsii_name="toGetAllowList")
    def to_get_allow_list(self) -> "Macie2":
        '''(experimental) Grants permission to retrieve the settings and status of an allow list.

        Access Level: Read

        https://docs.aws.amazon.com/macie/latest/APIReference/allow-lists-id.html

        :stability: experimental
        '''
        return typing.cast("Macie2", jsii.invoke(self, "toGetAllowList", []))

    @jsii.member(jsii_name="toGetAutomatedDiscoveryConfiguration")
    def to_get_automated_discovery_configuration(self) -> "Macie2":
        '''(experimental) Grants permission to retrieve the configuration settings and status of automated sensitive data discovery for an account.

        Access Level: Read

        https://docs.aws.amazon.com/macie/latest/APIReference/automated-discovery-configuration.html

        :stability: experimental
        '''
        return typing.cast("Macie2", jsii.invoke(self, "toGetAutomatedDiscoveryConfiguration", []))

    @jsii.member(jsii_name="toGetBucketStatistics")
    def to_get_bucket_statistics(self) -> "Macie2":
        '''(experimental) Grants permission to retrieve aggregated statistical data for all the S3 buckets that Amazon Macie monitors and analyzes.

        Access Level: Read

        https://docs.aws.amazon.com/macie/latest/APIReference/datasources-s3-statistics.html

        :stability: experimental
        '''
        return typing.cast("Macie2", jsii.invoke(self, "toGetBucketStatistics", []))

    @jsii.member(jsii_name="toGetClassificationExportConfiguration")
    def to_get_classification_export_configuration(self) -> "Macie2":
        '''(experimental) Grants permission to retrieve the settings for exporting sensitive data discovery results.

        Access Level: Read

        https://docs.aws.amazon.com/macie/latest/APIReference/classification-export-configuration.html

        :stability: experimental
        '''
        return typing.cast("Macie2", jsii.invoke(self, "toGetClassificationExportConfiguration", []))

    @jsii.member(jsii_name="toGetClassificationScope")
    def to_get_classification_scope(self) -> "Macie2":
        '''(experimental) Grants permission to retrieve the classification scope settings for an account.

        Access Level: Read

        https://docs.aws.amazon.com/macie/latest/APIReference/classification-scopes-id.html

        :stability: experimental
        '''
        return typing.cast("Macie2", jsii.invoke(self, "toGetClassificationScope", []))

    @jsii.member(jsii_name="toGetCustomDataIdentifier")
    def to_get_custom_data_identifier(self) -> "Macie2":
        '''(experimental) Grants permission to retrieve information about the settings for a custom data identifier.

        Access Level: Read

        https://docs.aws.amazon.com/macie/latest/APIReference/custom-data-identifiers-id.html

        :stability: experimental
        '''
        return typing.cast("Macie2", jsii.invoke(self, "toGetCustomDataIdentifier", []))

    @jsii.member(jsii_name="toGetFindings")
    def to_get_findings(self) -> "Macie2":
        '''(experimental) Grants permission to retrieve the details of one or more findings.

        Access Level: Read

        https://docs.aws.amazon.com/macie/latest/APIReference/findings-describe.html

        :stability: experimental
        '''
        return typing.cast("Macie2", jsii.invoke(self, "toGetFindings", []))

    @jsii.member(jsii_name="toGetFindingsFilter")
    def to_get_findings_filter(self) -> "Macie2":
        '''(experimental) Grants permission to retrieve information about the settings for a findings filter.

        Access Level: Read

        https://docs.aws.amazon.com/macie/latest/APIReference/findingsfilters-id.html

        :stability: experimental
        '''
        return typing.cast("Macie2", jsii.invoke(self, "toGetFindingsFilter", []))

    @jsii.member(jsii_name="toGetFindingsPublicationConfiguration")
    def to_get_findings_publication_configuration(self) -> "Macie2":
        '''(experimental) Grants permission to retrieve the configuration settings for publishing findings to AWS Security Hub.

        Access Level: Read

        https://docs.aws.amazon.com/macie/latest/APIReference/findings-publication-configuration.html

        :stability: experimental
        '''
        return typing.cast("Macie2", jsii.invoke(self, "toGetFindingsPublicationConfiguration", []))

    @jsii.member(jsii_name="toGetFindingStatistics")
    def to_get_finding_statistics(self) -> "Macie2":
        '''(experimental) Grants permission to retrieve aggregated statistical data about findings.

        Access Level: Read

        https://docs.aws.amazon.com/macie/latest/APIReference/findings-statistics.html

        :stability: experimental
        '''
        return typing.cast("Macie2", jsii.invoke(self, "toGetFindingStatistics", []))

    @jsii.member(jsii_name="toGetInvitationsCount")
    def to_get_invitations_count(self) -> "Macie2":
        '''(experimental) Grants permission to retrieve the count of Amazon Macie membership invitations that were received by an account.

        Access Level: Read

        https://docs.aws.amazon.com/macie/latest/APIReference/invitations-count.html

        :stability: experimental
        '''
        return typing.cast("Macie2", jsii.invoke(self, "toGetInvitationsCount", []))

    @jsii.member(jsii_name="toGetMacieSession")
    def to_get_macie_session(self) -> "Macie2":
        '''(experimental) Grants permission to retrieve information about the status and configuration settings for an Amazon Macie account.

        Access Level: Read

        https://docs.aws.amazon.com/macie/latest/APIReference/macie.html

        :stability: experimental
        '''
        return typing.cast("Macie2", jsii.invoke(self, "toGetMacieSession", []))

    @jsii.member(jsii_name="toGetMasterAccount")
    def to_get_master_account(self) -> "Macie2":
        '''(experimental) Grants permission to retrieve information about the Amazon Macie administrator account for an account.

        Access Level: Read

        https://docs.aws.amazon.com/macie/latest/APIReference/master.html

        :stability: experimental
        '''
        return typing.cast("Macie2", jsii.invoke(self, "toGetMasterAccount", []))

    @jsii.member(jsii_name="toGetMember")
    def to_get_member(self) -> "Macie2":
        '''(experimental) Grants permission to retrieve information about an account that's associated with an Amazon Macie administrator account.

        Access Level: Read

        https://docs.aws.amazon.com/macie/latest/APIReference/members-id.html

        :stability: experimental
        '''
        return typing.cast("Macie2", jsii.invoke(self, "toGetMember", []))

    @jsii.member(jsii_name="toGetResourceProfile")
    def to_get_resource_profile(self) -> "Macie2":
        '''(experimental) Grants permission to retrieve sensitive data discovery statistics and the sensitivity score for an S3 bucket.

        Access Level: Read

        https://docs.aws.amazon.com/macie/latest/APIReference/resource-profiles.html

        :stability: experimental
        '''
        return typing.cast("Macie2", jsii.invoke(self, "toGetResourceProfile", []))

    @jsii.member(jsii_name="toGetRevealConfiguration")
    def to_get_reveal_configuration(self) -> "Macie2":
        '''(experimental) Grants permission to retrieve the status and configuration settings for retrieving occurrences of sensitive data reported by findings.

        Access Level: Read

        https://docs.aws.amazon.com/macie/latest/APIReference/reveal-configuration.html

        :stability: experimental
        '''
        return typing.cast("Macie2", jsii.invoke(self, "toGetRevealConfiguration", []))

    @jsii.member(jsii_name="toGetSensitiveDataOccurrences")
    def to_get_sensitive_data_occurrences(self) -> "Macie2":
        '''(experimental) Grants permission to retrieve occurrences of sensitive data reported by a finding.

        Access Level: Read

        https://docs.aws.amazon.com/macie/latest/APIReference/findings-findingid-reveal.html

        :stability: experimental
        '''
        return typing.cast("Macie2", jsii.invoke(self, "toGetSensitiveDataOccurrences", []))

    @jsii.member(jsii_name="toGetSensitiveDataOccurrencesAvailability")
    def to_get_sensitive_data_occurrences_availability(self) -> "Macie2":
        '''(experimental) Grants permission to check whether occurrences of sensitive data can be retrieved for a finding.

        Access Level: Read

        https://docs.aws.amazon.com/macie/latest/APIReference/findings-findingid-reveal-availability.html

        :stability: experimental
        '''
        return typing.cast("Macie2", jsii.invoke(self, "toGetSensitiveDataOccurrencesAvailability", []))

    @jsii.member(jsii_name="toGetSensitivityInspectionTemplate")
    def to_get_sensitivity_inspection_template(self) -> "Macie2":
        '''(experimental) Grants permission to retrieve the sensitivity inspection template settings for an account.

        Access Level: Read

        https://docs.aws.amazon.com/macie/latest/APIReference/templates-sensitivity-inspections-id.html

        :stability: experimental
        '''
        return typing.cast("Macie2", jsii.invoke(self, "toGetSensitivityInspectionTemplate", []))

    @jsii.member(jsii_name="toGetUsageStatistics")
    def to_get_usage_statistics(self) -> "Macie2":
        '''(experimental) Grants permission to retrieve quotas and aggregated usage data for one or more accounts.

        Access Level: Read

        https://docs.aws.amazon.com/macie/latest/APIReference/usage-statistics.html

        :stability: experimental
        '''
        return typing.cast("Macie2", jsii.invoke(self, "toGetUsageStatistics", []))

    @jsii.member(jsii_name="toGetUsageTotals")
    def to_get_usage_totals(self) -> "Macie2":
        '''(experimental) Grants permission to retrieve aggregated usage data for an account.

        Access Level: Read

        https://docs.aws.amazon.com/macie/latest/APIReference/usage.html

        :stability: experimental
        '''
        return typing.cast("Macie2", jsii.invoke(self, "toGetUsageTotals", []))

    @jsii.member(jsii_name="toListAllowLists")
    def to_list_allow_lists(self) -> "Macie2":
        '''(experimental) Grants permission to retrieve a subset of information about all the allow lists for an account.

        Access Level: List

        https://docs.aws.amazon.com/macie/latest/APIReference/allow-lists.html

        :stability: experimental
        '''
        return typing.cast("Macie2", jsii.invoke(self, "toListAllowLists", []))

    @jsii.member(jsii_name="toListClassificationJobs")
    def to_list_classification_jobs(self) -> "Macie2":
        '''(experimental) Grants permission to retrieve a subset of information about the status and settings for one or more sensitive data discovery jobs.

        Access Level: List

        https://docs.aws.amazon.com/macie/latest/APIReference/jobs-list.html

        :stability: experimental
        '''
        return typing.cast("Macie2", jsii.invoke(self, "toListClassificationJobs", []))

    @jsii.member(jsii_name="toListClassificationScopes")
    def to_list_classification_scopes(self) -> "Macie2":
        '''(experimental) Grants permission to retrieve a subset of information about the classification scope for an account.

        Access Level: List

        https://docs.aws.amazon.com/macie/latest/APIReference/classification-scopes.html

        :stability: experimental
        '''
        return typing.cast("Macie2", jsii.invoke(self, "toListClassificationScopes", []))

    @jsii.member(jsii_name="toListCustomDataIdentifiers")
    def to_list_custom_data_identifiers(self) -> "Macie2":
        '''(experimental) Grants permission to retrieve information about all custom data identifiers.

        Access Level: List

        https://docs.aws.amazon.com/macie/latest/APIReference/custom-data-identifiers-list.html

        :stability: experimental
        '''
        return typing.cast("Macie2", jsii.invoke(self, "toListCustomDataIdentifiers", []))

    @jsii.member(jsii_name="toListFindings")
    def to_list_findings(self) -> "Macie2":
        '''(experimental) Grants permission to retrieve a subset of information about one or more findings.

        Access Level: List

        https://docs.aws.amazon.com/macie/latest/APIReference/findings.html

        :stability: experimental
        '''
        return typing.cast("Macie2", jsii.invoke(self, "toListFindings", []))

    @jsii.member(jsii_name="toListFindingsFilters")
    def to_list_findings_filters(self) -> "Macie2":
        '''(experimental) Grants permission to retrieve information about all findings filters.

        Access Level: List

        https://docs.aws.amazon.com/macie/latest/APIReference/findingsfilters.html

        :stability: experimental
        '''
        return typing.cast("Macie2", jsii.invoke(self, "toListFindingsFilters", []))

    @jsii.member(jsii_name="toListInvitations")
    def to_list_invitations(self) -> "Macie2":
        '''(experimental) Grants permission to retrieve information about all the Amazon Macie membership invitations that were received by an account.

        Access Level: List

        https://docs.aws.amazon.com/macie/latest/APIReference/invitations.html

        :stability: experimental
        '''
        return typing.cast("Macie2", jsii.invoke(self, "toListInvitations", []))

    @jsii.member(jsii_name="toListManagedDataIdentifiers")
    def to_list_managed_data_identifiers(self) -> "Macie2":
        '''(experimental) Grants permission to retrieve information about managed data identifiers.

        Access Level: List

        https://docs.aws.amazon.com/macie/latest/APIReference/managed-data-identifiers-list.html

        :stability: experimental
        '''
        return typing.cast("Macie2", jsii.invoke(self, "toListManagedDataIdentifiers", []))

    @jsii.member(jsii_name="toListMembers")
    def to_list_members(self) -> "Macie2":
        '''(experimental) Grants permission to retrieve information about the Amazon Macie member accounts that are associated with a Macie administrator account.

        Access Level: List

        https://docs.aws.amazon.com/macie/latest/APIReference/members.html

        :stability: experimental
        '''
        return typing.cast("Macie2", jsii.invoke(self, "toListMembers", []))

    @jsii.member(jsii_name="toListOrganizationAdminAccounts")
    def to_list_organization_admin_accounts(self) -> "Macie2":
        '''(experimental) Grants permission to retrieve information about the delegated, Amazon Macie administrator account for an AWS organization.

        Access Level: List

        https://docs.aws.amazon.com/macie/latest/APIReference/admin.html

        :stability: experimental
        '''
        return typing.cast("Macie2", jsii.invoke(self, "toListOrganizationAdminAccounts", []))

    @jsii.member(jsii_name="toListResourceProfileArtifacts")
    def to_list_resource_profile_artifacts(self) -> "Macie2":
        '''(experimental) Grants permission to retrieve information about objects that were selected from an S3 bucket for automated sensitive data discovery.

        Access Level: List

        https://docs.aws.amazon.com/macie/latest/APIReference/resource-profiles-artifacts.html

        :stability: experimental
        '''
        return typing.cast("Macie2", jsii.invoke(self, "toListResourceProfileArtifacts", []))

    @jsii.member(jsii_name="toListResourceProfileDetections")
    def to_list_resource_profile_detections(self) -> "Macie2":
        '''(experimental) Grants permission to retrieve information about the types and amount of sensitive data that Amazon Macie found in an S3 bucket.

        Access Level: List

        https://docs.aws.amazon.com/macie/latest/APIReference/resource-profiles-detections.html

        :stability: experimental
        '''
        return typing.cast("Macie2", jsii.invoke(self, "toListResourceProfileDetections", []))

    @jsii.member(jsii_name="toListSensitivityInspectionTemplates")
    def to_list_sensitivity_inspection_templates(self) -> "Macie2":
        '''(experimental) Grants permission to retrieve a subset of information about the sensitivity inspection template for an account.

        Access Level: List

        https://docs.aws.amazon.com/macie/latest/APIReference/templates-sensitivity-inspections.html

        :stability: experimental
        '''
        return typing.cast("Macie2", jsii.invoke(self, "toListSensitivityInspectionTemplates", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Macie2":
        '''(experimental) Grants permission to retrieve the tags for an Amazon Macie resource.

        Access Level: Read

        https://docs.aws.amazon.com/macie/latest/APIReference/tags-resourcearn.html

        :stability: experimental
        '''
        return typing.cast("Macie2", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toPutClassificationExportConfiguration")
    def to_put_classification_export_configuration(self) -> "Macie2":
        '''(experimental) Grants permission to create or update the settings for storing sensitive data discovery results.

        Access Level: Write

        https://docs.aws.amazon.com/macie/latest/APIReference/classification-export-configuration.html

        :stability: experimental
        '''
        return typing.cast("Macie2", jsii.invoke(self, "toPutClassificationExportConfiguration", []))

    @jsii.member(jsii_name="toPutFindingsPublicationConfiguration")
    def to_put_findings_publication_configuration(self) -> "Macie2":
        '''(experimental) Grants permission to update the configuration settings for publishing findings to AWS Security Hub.

        Access Level: Write

        https://docs.aws.amazon.com/macie/latest/APIReference/findings-publication-configuration.html

        :stability: experimental
        '''
        return typing.cast("Macie2", jsii.invoke(self, "toPutFindingsPublicationConfiguration", []))

    @jsii.member(jsii_name="toSearchResources")
    def to_search_resources(self) -> "Macie2":
        '''(experimental) Grants permission to retrieve statistical data and other information about AWS resources that Amazon Macie monitors and analyzes.

        Access Level: Read

        https://docs.aws.amazon.com/macie/latest/APIReference/datasources-search-resources.html

        :stability: experimental
        '''
        return typing.cast("Macie2", jsii.invoke(self, "toSearchResources", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Macie2":
        '''(experimental) Grants permission to add or update the tags for an Amazon Macie resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/macie/latest/APIReference/tags-resourcearn.html

        :stability: experimental
        '''
        return typing.cast("Macie2", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toTestCustomDataIdentifier")
    def to_test_custom_data_identifier(self) -> "Macie2":
        '''(experimental) Grants permission to test a custom data identifier.

        Access Level: Write

        https://docs.aws.amazon.com/macie/latest/APIReference/custom-data-identifiers-test.html

        :stability: experimental
        '''
        return typing.cast("Macie2", jsii.invoke(self, "toTestCustomDataIdentifier", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Macie2":
        '''(experimental) Grants permission to remove tags from an Amazon Macie resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/macie/latest/APIReference/tags-resourcearn.html

        :stability: experimental
        '''
        return typing.cast("Macie2", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateAllowList")
    def to_update_allow_list(self) -> "Macie2":
        '''(experimental) Grants permission to update the settings for an allow list.

        Access Level: Write

        https://docs.aws.amazon.com/macie/latest/APIReference/allow-lists-id.html

        :stability: experimental
        '''
        return typing.cast("Macie2", jsii.invoke(self, "toUpdateAllowList", []))

    @jsii.member(jsii_name="toUpdateAutomatedDiscoveryConfiguration")
    def to_update_automated_discovery_configuration(self) -> "Macie2":
        '''(experimental) Grants permission to enable or disable automated sensitive data discovery for an account.

        Access Level: Write

        https://docs.aws.amazon.com/macie/latest/APIReference/automated-discovery-configuration.html

        :stability: experimental
        '''
        return typing.cast("Macie2", jsii.invoke(self, "toUpdateAutomatedDiscoveryConfiguration", []))

    @jsii.member(jsii_name="toUpdateClassificationJob")
    def to_update_classification_job(self) -> "Macie2":
        '''(experimental) Grants permission to change the status of a sensitive data discovery job.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/macie/latest/APIReference/jobs-jobid.html

        :stability: experimental
        '''
        return typing.cast("Macie2", jsii.invoke(self, "toUpdateClassificationJob", []))

    @jsii.member(jsii_name="toUpdateClassificationScope")
    def to_update_classification_scope(self) -> "Macie2":
        '''(experimental) Grants permission to update the classification scope settings for an account.

        Access Level: Write

        https://docs.aws.amazon.com/macie/latest/APIReference/classification-scopes-id.html

        :stability: experimental
        '''
        return typing.cast("Macie2", jsii.invoke(self, "toUpdateClassificationScope", []))

    @jsii.member(jsii_name="toUpdateFindingsFilter")
    def to_update_findings_filter(self) -> "Macie2":
        '''(experimental) Grants permission to update the settings for a findings filter.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/macie/latest/APIReference/findingsfilters-id.html

        :stability: experimental
        '''
        return typing.cast("Macie2", jsii.invoke(self, "toUpdateFindingsFilter", []))

    @jsii.member(jsii_name="toUpdateMacieSession")
    def to_update_macie_session(self) -> "Macie2":
        '''(experimental) Grants permission to suspend or re-enable an Amazon Macie account, or update the configuration settings for a Macie account.

        Access Level: Write

        https://docs.aws.amazon.com/macie/latest/APIReference/macie.html

        :stability: experimental
        '''
        return typing.cast("Macie2", jsii.invoke(self, "toUpdateMacieSession", []))

    @jsii.member(jsii_name="toUpdateMemberSession")
    def to_update_member_session(self) -> "Macie2":
        '''(experimental) Grants permission to an Amazon Macie administrator account to suspend or re-enable a Macie member account.

        Access Level: Write

        https://docs.aws.amazon.com/macie/latest/APIReference/macie-members-id.html

        :stability: experimental
        '''
        return typing.cast("Macie2", jsii.invoke(self, "toUpdateMemberSession", []))

    @jsii.member(jsii_name="toUpdateOrganizationConfiguration")
    def to_update_organization_configuration(self) -> "Macie2":
        '''(experimental) Grants permission to update Amazon Macie configuration settings for an AWS organization.

        Access Level: Write

        https://docs.aws.amazon.com/macie/latest/APIReference/admin-configuration.html

        :stability: experimental
        '''
        return typing.cast("Macie2", jsii.invoke(self, "toUpdateOrganizationConfiguration", []))

    @jsii.member(jsii_name="toUpdateResourceProfile")
    def to_update_resource_profile(self) -> "Macie2":
        '''(experimental) Grants permission to update the sensitivity score for an S3 bucket.

        Access Level: Write

        https://docs.aws.amazon.com/macie/latest/APIReference/resource-profiles.html

        :stability: experimental
        '''
        return typing.cast("Macie2", jsii.invoke(self, "toUpdateResourceProfile", []))

    @jsii.member(jsii_name="toUpdateResourceProfileDetections")
    def to_update_resource_profile_detections(self) -> "Macie2":
        '''(experimental) Grants permission to update the sensitivity scoring settings for an S3 bucket.

        Access Level: Write

        https://docs.aws.amazon.com/macie/latest/APIReference/resource-profiles-detections.html

        :stability: experimental
        '''
        return typing.cast("Macie2", jsii.invoke(self, "toUpdateResourceProfileDetections", []))

    @jsii.member(jsii_name="toUpdateRevealConfiguration")
    def to_update_reveal_configuration(self) -> "Macie2":
        '''(experimental) Grants permission to update the status and configuration settings for retrieving occurrences of sensitive data reported by findings.

        Access Level: Write

        https://docs.aws.amazon.com/macie/latest/APIReference/reveal-configuration.html

        :stability: experimental
        '''
        return typing.cast("Macie2", jsii.invoke(self, "toUpdateRevealConfiguration", []))

    @jsii.member(jsii_name="toUpdateSensitivityInspectionTemplate")
    def to_update_sensitivity_inspection_template(self) -> "Macie2":
        '''(experimental) Grants permission to update the sensitivity inspection template settings for an account.

        Access Level: Write

        https://docs.aws.amazon.com/macie/latest/APIReference/templates-sensitivity-inspections-id.html

        :stability: experimental
        '''
        return typing.cast("Macie2", jsii.invoke(self, "toUpdateSensitivityInspectionTemplate", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6e67a06038939b8c0b6f7ed9c8de782dd3027209653458fedaa0e7d20ade08b0)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__47710abcf11efb715eaf0ecf01716ffad520127b5a3298520a00a556f689ab46)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Managedblockchain(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Managedblockchain",
):
    '''(experimental) Statement provider for service `managedblockchain <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonmanagedblockchain.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `managedblockchain <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonmanagedblockchain.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onInvitation")
    def on_invitation(
        self,
        invitation_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Managedblockchain":
        '''(experimental) Adds a resource of type invitation to the statement.

        https://docs.aws.amazon.com/managed-blockchain/latest/APIReference/API_Invitation.html

        :param invitation_id: - Identifier for the invitationId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__923f246947c84342c1bd0e80fdd2736d6382c6ac6316d8205aa3b49d1abf6840)
            check_type(argname="argument invitation_id", value=invitation_id, expected_type=type_hints["invitation_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Managedblockchain", jsii.invoke(self, "onInvitation", [invitation_id, account, region, partition]))

    @jsii.member(jsii_name="onMember")
    def on_member(
        self,
        member_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Managedblockchain":
        '''(experimental) Adds a resource of type member to the statement.

        https://docs.aws.amazon.com/managed-blockchain/latest/APIReference/API_Member.html

        :param member_id: - Identifier for the memberId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6a5e9a110ce89918a90e16646a408f7b64b6603a18879a90b7da7b1adc9dfc91)
            check_type(argname="argument member_id", value=member_id, expected_type=type_hints["member_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Managedblockchain", jsii.invoke(self, "onMember", [member_id, account, region, partition]))

    @jsii.member(jsii_name="onNetwork")
    def on_network(
        self,
        network_id: builtins.str,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Managedblockchain":
        '''(experimental) Adds a resource of type network to the statement.

        https://docs.aws.amazon.com/managed-blockchain/latest/APIReference/API_Network.html

        :param network_id: - Identifier for the networkId.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b4acffb2e3d0ec4d4dbb84f11e85d9dc6d7baf4cd524a3fd0391dc4b585b0ae3)
            check_type(argname="argument network_id", value=network_id, expected_type=type_hints["network_id"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Managedblockchain", jsii.invoke(self, "onNetwork", [network_id, region, partition]))

    @jsii.member(jsii_name="onNode")
    def on_node(
        self,
        node_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Managedblockchain":
        '''(experimental) Adds a resource of type node to the statement.

        https://docs.aws.amazon.com/managed-blockchain/latest/APIReference/API_Node.html

        :param node_id: - Identifier for the nodeId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f1c08125b7a9feed91c28a4230acc24dea5eed904c2588cb5e9d45d11a73b5fe)
            check_type(argname="argument node_id", value=node_id, expected_type=type_hints["node_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Managedblockchain", jsii.invoke(self, "onNode", [node_id, account, region, partition]))

    @jsii.member(jsii_name="onProposal")
    def on_proposal(
        self,
        proposal_id: builtins.str,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Managedblockchain":
        '''(experimental) Adds a resource of type proposal to the statement.

        https://docs.aws.amazon.com/managed-blockchain/latest/APIReference/API_Proposal.html

        :param proposal_id: - Identifier for the proposalId.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d092be3c3e820f1e50612933f1e97bbe736ac767e4b5c33cbd0fcc68e1a9ef66)
            check_type(argname="argument proposal_id", value=proposal_id, expected_type=type_hints["proposal_id"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Managedblockchain", jsii.invoke(self, "onProposal", [proposal_id, region, partition]))

    @jsii.member(jsii_name="toCreateMember")
    def to_create_member(self) -> "Managedblockchain":
        '''(experimental) Grants permission to create a member of an Amazon Managed Blockchain network.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        Dependent actions:

        - iam:CreateServiceLinkedRole

        https://docs.aws.amazon.com/managed-blockchain/latest/APIReference/API_CreateMember.html

        :stability: experimental
        '''
        return typing.cast("Managedblockchain", jsii.invoke(self, "toCreateMember", []))

    @jsii.member(jsii_name="toCreateNetwork")
    def to_create_network(self) -> "Managedblockchain":
        '''(experimental) Grants permission to create an Amazon Managed Blockchain network.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        Dependent actions:

        - iam:CreateServiceLinkedRole

        https://docs.aws.amazon.com/managed-blockchain/latest/APIReference/API_CreateNetwork.html

        :stability: experimental
        '''
        return typing.cast("Managedblockchain", jsii.invoke(self, "toCreateNetwork", []))

    @jsii.member(jsii_name="toCreateNode")
    def to_create_node(self) -> "Managedblockchain":
        '''(experimental) Grants permission to create a node within a member of an Amazon Managed Blockchain network.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        Dependent actions:

        - iam:CreateServiceLinkedRole

        https://docs.aws.amazon.com/managed-blockchain/latest/APIReference/API_CreateNode.html

        :stability: experimental
        '''
        return typing.cast("Managedblockchain", jsii.invoke(self, "toCreateNode", []))

    @jsii.member(jsii_name="toCreateProposal")
    def to_create_proposal(self) -> "Managedblockchain":
        '''(experimental) Grants permission to create a proposal that other blockchain network members can vote on to add or remove a member in an Amazon Managed Blockchain network.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/managed-blockchain/latest/APIReference/API_CreateProposal.html

        :stability: experimental
        '''
        return typing.cast("Managedblockchain", jsii.invoke(self, "toCreateProposal", []))

    @jsii.member(jsii_name="toDeleteMember")
    def to_delete_member(self) -> "Managedblockchain":
        '''(experimental) Grants permission to delete a member and all associated resources from an Amazon Managed Blockchain network.

        Access Level: Write

        https://docs.aws.amazon.com/managed-blockchain/latest/APIReference/API_DeleteMember.html

        :stability: experimental
        '''
        return typing.cast("Managedblockchain", jsii.invoke(self, "toDeleteMember", []))

    @jsii.member(jsii_name="toDeleteNode")
    def to_delete_node(self) -> "Managedblockchain":
        '''(experimental) Grants permission to delete a node from a member of an Amazon Managed Blockchain network.

        Access Level: Write

        https://docs.aws.amazon.com/managed-blockchain/latest/APIReference/API_DeleteNode.html

        :stability: experimental
        '''
        return typing.cast("Managedblockchain", jsii.invoke(self, "toDeleteNode", []))

    @jsii.member(jsii_name="toGetMember")
    def to_get_member(self) -> "Managedblockchain":
        '''(experimental) Grants permission to return detailed information about a member of an Amazon Managed Blockchain network.

        Access Level: Read

        https://docs.aws.amazon.com/managed-blockchain/latest/APIReference/API_GetMember.html

        :stability: experimental
        '''
        return typing.cast("Managedblockchain", jsii.invoke(self, "toGetMember", []))

    @jsii.member(jsii_name="toGetNetwork")
    def to_get_network(self) -> "Managedblockchain":
        '''(experimental) Grants permission to return detailed information about an Amazon Managed Blockchain network.

        Access Level: Read

        https://docs.aws.amazon.com/managed-blockchain/latest/APIReference/API_GetNetwork.html

        :stability: experimental
        '''
        return typing.cast("Managedblockchain", jsii.invoke(self, "toGetNetwork", []))

    @jsii.member(jsii_name="toGetNode")
    def to_get_node(self) -> "Managedblockchain":
        '''(experimental) Grants permission to return detailed information about a node within a member of an Amazon Managed Blockchain network.

        Access Level: Read

        https://docs.aws.amazon.com/managed-blockchain/latest/APIReference/API_GetNode.html

        :stability: experimental
        '''
        return typing.cast("Managedblockchain", jsii.invoke(self, "toGetNode", []))

    @jsii.member(jsii_name="toGetProposal")
    def to_get_proposal(self) -> "Managedblockchain":
        '''(experimental) Grants permission to return detailed information about a proposal of an Amazon Managed Blockchain network.

        Access Level: Read

        https://docs.aws.amazon.com/managed-blockchain/latest/APIReference/API_GetProposal.html

        :stability: experimental
        '''
        return typing.cast("Managedblockchain", jsii.invoke(self, "toGetProposal", []))

    @jsii.member(jsii_name="toListInvitations")
    def to_list_invitations(self) -> "Managedblockchain":
        '''(experimental) Grants permission to list the invitations extended to the active AWS account from any Managed Blockchain network.

        Access Level: List

        https://docs.aws.amazon.com/managed-blockchain/latest/APIReference/API_ListInvitations.html

        :stability: experimental
        '''
        return typing.cast("Managedblockchain", jsii.invoke(self, "toListInvitations", []))

    @jsii.member(jsii_name="toListMembers")
    def to_list_members(self) -> "Managedblockchain":
        '''(experimental) Grants permission to list the members of an Amazon Managed Blockchain network and the properties of their memberships.

        Access Level: List

        https://docs.aws.amazon.com/managed-blockchain/latest/APIReference/API_ListMembers.html

        :stability: experimental
        '''
        return typing.cast("Managedblockchain", jsii.invoke(self, "toListMembers", []))

    @jsii.member(jsii_name="toListNetworks")
    def to_list_networks(self) -> "Managedblockchain":
        '''(experimental) Grants permission to list the Amazon Managed Blockchain networks in which the current AWS account participates.

        Access Level: List

        https://docs.aws.amazon.com/managed-blockchain/latest/APIReference/API_ListNetworks.html

        :stability: experimental
        '''
        return typing.cast("Managedblockchain", jsii.invoke(self, "toListNetworks", []))

    @jsii.member(jsii_name="toListNodes")
    def to_list_nodes(self) -> "Managedblockchain":
        '''(experimental) Grants permission to list the nodes within a member of an Amazon Managed Blockchain network.

        Access Level: List

        https://docs.aws.amazon.com/managed-blockchain/latest/APIReference/API_ListNodes.html

        :stability: experimental
        '''
        return typing.cast("Managedblockchain", jsii.invoke(self, "toListNodes", []))

    @jsii.member(jsii_name="toListProposals")
    def to_list_proposals(self) -> "Managedblockchain":
        '''(experimental) Grants permission to list proposals for the given Amazon Managed Blockchain network.

        Access Level: List

        https://docs.aws.amazon.com/managed-blockchain/latest/APIReference/API_ListProposals.html

        :stability: experimental
        '''
        return typing.cast("Managedblockchain", jsii.invoke(self, "toListProposals", []))

    @jsii.member(jsii_name="toListProposalVotes")
    def to_list_proposal_votes(self) -> "Managedblockchain":
        '''(experimental) Grants permission to list all votes for a proposal, including the value of the vote and the unique identifier of the member that cast the vote for the given Amazon Managed Blockchain network.

        Access Level: Read

        https://docs.aws.amazon.com/managed-blockchain/latest/APIReference/API_ListProposalVotes.html

        :stability: experimental
        '''
        return typing.cast("Managedblockchain", jsii.invoke(self, "toListProposalVotes", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Managedblockchain":
        '''(experimental) Grants permission to view tags associated with an Amazon Managed Blockchain resource.

        Access Level: Read

        https://docs.aws.amazon.com/managed-blockchain/latest/APIReference/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("Managedblockchain", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toRejectInvitation")
    def to_reject_invitation(self) -> "Managedblockchain":
        '''(experimental) Grants permission to reject the invitation to join the blockchain network.

        Access Level: Write

        https://docs.aws.amazon.com/managed-blockchain/latest/APIReference/API_RejectInvitation.html

        :stability: experimental
        '''
        return typing.cast("Managedblockchain", jsii.invoke(self, "toRejectInvitation", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Managedblockchain":
        '''(experimental) Grants permission to add tags to an Amazon Managed Blockchain resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/managed-blockchain/latest/APIReference/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("Managedblockchain", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Managedblockchain":
        '''(experimental) Grants permission to remove tags from an Amazon Managed Blockchain resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/managed-blockchain/latest/APIReference/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("Managedblockchain", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateMember")
    def to_update_member(self) -> "Managedblockchain":
        '''(experimental) Grants permission to update a member of an Amazon Managed Blockchain network.

        Access Level: Write

        Dependent actions:

        - iam:CreateServiceLinkedRole

        https://docs.aws.amazon.com/managed-blockchain/latest/APIReference/API_UpdateMember.html

        :stability: experimental
        '''
        return typing.cast("Managedblockchain", jsii.invoke(self, "toUpdateMember", []))

    @jsii.member(jsii_name="toUpdateNode")
    def to_update_node(self) -> "Managedblockchain":
        '''(experimental) Grants permission to update a node from a member of an Amazon Managed Blockchain network.

        Access Level: Write

        Dependent actions:

        - iam:CreateServiceLinkedRole

        https://docs.aws.amazon.com/managed-blockchain/latest/APIReference/API_UpdateNode.html

        :stability: experimental
        '''
        return typing.cast("Managedblockchain", jsii.invoke(self, "toUpdateNode", []))

    @jsii.member(jsii_name="toVoteOnProposal")
    def to_vote_on_proposal(self) -> "Managedblockchain":
        '''(experimental) Grants permission to cast a vote for a proposal on behalf of the blockchain network member specified.

        Access Level: Write

        https://docs.aws.amazon.com/managed-blockchain/latest/APIReference/API_VoteOnProposal.html

        :stability: experimental
        '''
        return typing.cast("Managedblockchain", jsii.invoke(self, "toVoteOnProposal", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bdbf45386a00576deb1e1311ffdb47bc11f76b04126e1d9cfc2d6932e2b554f2)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6a2b749653b361849cc97e16798a325dee9a8bae04bc7f9d9fabf7e880aba174)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Marketplacecommerceanalytics(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Marketplacecommerceanalytics",
):
    '''(experimental) Statement provider for service `marketplacecommerceanalytics <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsmarketplacecommerceanalyticsservice.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `marketplacecommerceanalytics <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsmarketplacecommerceanalyticsservice.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="toGenerateDataSet")
    def to_generate_data_set(self) -> "Marketplacecommerceanalytics":
        '''(experimental) Request a data set to be published to your Amazon S3 bucket.

        Access Level: Write

        :stability: experimental
        '''
        return typing.cast("Marketplacecommerceanalytics", jsii.invoke(self, "toGenerateDataSet", []))

    @jsii.member(jsii_name="toStartSupportDataExport")
    def to_start_support_data_export(self) -> "Marketplacecommerceanalytics":
        '''(experimental) Request a support data set to be published to your Amazon S3 bucket.

        Access Level: Write

        :stability: experimental
        '''
        return typing.cast("Marketplacecommerceanalytics", jsii.invoke(self, "toStartSupportDataExport", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0eb67dc6d0c87e5e8bd4f2cc1806f194bb95b7d0b86d9b1c926f7ce63a8e9bd9)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__55297913362d63f40f12d76fb393adb61926ea7d50837afbcef84fe542049e2c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Mechanicalturk(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Mechanicalturk",
):
    '''(experimental) Statement provider for service `mechanicalturk <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonmechanicalturk.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `mechanicalturk <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonmechanicalturk.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="toAcceptQualificationRequest")
    def to_accept_qualification_request(self) -> "Mechanicalturk":
        '''(experimental) The AcceptQualificationRequest operation grants a Worker's request for a Qualification.

        Access Level: Write

        https://docs.aws.amazon.com/AWSMechTurk/latest/AWSMturkAPI/ApiReference_AcceptQualificationRequestOperation.html

        :stability: experimental
        '''
        return typing.cast("Mechanicalturk", jsii.invoke(self, "toAcceptQualificationRequest", []))

    @jsii.member(jsii_name="toApproveAssignment")
    def to_approve_assignment(self) -> "Mechanicalturk":
        '''(experimental) The ApproveAssignment operation approves the results of a completed assignment.

        Access Level: Write

        https://docs.aws.amazon.com/AWSMechTurk/latest/AWSMturkAPI/ApiReference_ApproveAssignmentOperation.html

        :stability: experimental
        '''
        return typing.cast("Mechanicalturk", jsii.invoke(self, "toApproveAssignment", []))

    @jsii.member(jsii_name="toAssociateQualificationWithWorker")
    def to_associate_qualification_with_worker(self) -> "Mechanicalturk":
        '''(experimental) The AssociateQualificationWithWorker operation gives a Worker a Qualification.

        Access Level: Write

        https://docs.aws.amazon.com/AWSMechTurk/latest/AWSMturkAPI/ApiReference_AssociateQualificationWithWorkerOperation.html

        :stability: experimental
        '''
        return typing.cast("Mechanicalturk", jsii.invoke(self, "toAssociateQualificationWithWorker", []))

    @jsii.member(jsii_name="toCreateAdditionalAssignmentsForHIT")
    def to_create_additional_assignments_for_hit(self) -> "Mechanicalturk":
        '''(experimental) The CreateAdditionalAssignmentsForHIT operation increases the maximum number of assignments of an existing HIT.

        Access Level: Write

        https://docs.aws.amazon.com/AWSMechTurk/latest/AWSMturkAPI/ApiReference_CreateAdditionalAssignmentsForHITOperation.html

        :stability: experimental
        '''
        return typing.cast("Mechanicalturk", jsii.invoke(self, "toCreateAdditionalAssignmentsForHIT", []))

    @jsii.member(jsii_name="toCreateHIT")
    def to_create_hit(self) -> "Mechanicalturk":
        '''(experimental) The CreateHIT operation creates a new HIT (Human Intelligence Task).

        Access Level: Write

        https://docs.aws.amazon.com/AWSMechTurk/latest/AWSMturkAPI/ApiReference_CreateHITOperation.html

        :stability: experimental
        '''
        return typing.cast("Mechanicalturk", jsii.invoke(self, "toCreateHIT", []))

    @jsii.member(jsii_name="toCreateHITType")
    def to_create_hit_type(self) -> "Mechanicalturk":
        '''(experimental) The CreateHITType operation creates a new HIT type.

        Access Level: Write

        https://docs.aws.amazon.com/AWSMechTurk/latest/AWSMturkAPI/ApiReference_CreateHITTypeOperation.html

        :stability: experimental
        '''
        return typing.cast("Mechanicalturk", jsii.invoke(self, "toCreateHITType", []))

    @jsii.member(jsii_name="toCreateHITWithHITType")
    def to_create_hit_with_hit_type(self) -> "Mechanicalturk":
        '''(experimental) The CreateHITWithHITType operation creates a new Human Intelligence Task (HIT) using an existing HITTypeID generated by the CreateHITType operation.

        Access Level: Write

        https://docs.aws.amazon.com/AWSMechTurk/latest/AWSMturkAPI/ApiReference_CreateHITWithHITTypeOperation.html

        :stability: experimental
        '''
        return typing.cast("Mechanicalturk", jsii.invoke(self, "toCreateHITWithHITType", []))

    @jsii.member(jsii_name="toCreateQualificationType")
    def to_create_qualification_type(self) -> "Mechanicalturk":
        '''(experimental) The CreateQualificationType operation creates a new Qualification type, which is represented by a QualificationType data structure.

        Access Level: Write

        https://docs.aws.amazon.com/AWSMechTurk/latest/AWSMturkAPI/ApiReference_CreateQualificationTypeOperation.html

        :stability: experimental
        '''
        return typing.cast("Mechanicalturk", jsii.invoke(self, "toCreateQualificationType", []))

    @jsii.member(jsii_name="toCreateWorkerBlock")
    def to_create_worker_block(self) -> "Mechanicalturk":
        '''(experimental) The CreateWorkerBlock operation allows you to prevent a Worker from working on your HITs.

        Access Level: Write

        https://docs.aws.amazon.com/AWSMechTurk/latest/AWSMturkAPI/ApiReference_CreateWorkerBlockOperation.html

        :stability: experimental
        '''
        return typing.cast("Mechanicalturk", jsii.invoke(self, "toCreateWorkerBlock", []))

    @jsii.member(jsii_name="toDeleteHIT")
    def to_delete_hit(self) -> "Mechanicalturk":
        '''(experimental) The DeleteHIT operation disposes of a HIT that is no longer needed.

        Access Level: Write

        https://docs.aws.amazon.com/AWSMechTurk/latest/AWSMturkAPI/ApiReference_DeleteHITOperation.html

        :stability: experimental
        '''
        return typing.cast("Mechanicalturk", jsii.invoke(self, "toDeleteHIT", []))

    @jsii.member(jsii_name="toDeleteQualificationType")
    def to_delete_qualification_type(self) -> "Mechanicalturk":
        '''(experimental) The DeleteQualificationType disposes a Qualification type and disposes any HIT types that are associated with the Qualification type.

        Access Level: Write

        https://docs.aws.amazon.com/AWSMechTurk/latest/AWSMturkAPI/ApiReference_DeleteQualificationTypeOperation.html

        :stability: experimental
        '''
        return typing.cast("Mechanicalturk", jsii.invoke(self, "toDeleteQualificationType", []))

    @jsii.member(jsii_name="toDeleteWorkerBlock")
    def to_delete_worker_block(self) -> "Mechanicalturk":
        '''(experimental) The DeleteWorkerBlock operation allows you to reinstate a blocked Worker to work on your HITs.

        Access Level: Write

        https://docs.aws.amazon.com/AWSMechTurk/latest/AWSMturkAPI/ApiReference_DeleteWorkerBlockOperation.html

        :stability: experimental
        '''
        return typing.cast("Mechanicalturk", jsii.invoke(self, "toDeleteWorkerBlock", []))

    @jsii.member(jsii_name="toDisassociateQualificationFromWorker")
    def to_disassociate_qualification_from_worker(self) -> "Mechanicalturk":
        '''(experimental) The DisassociateQualificationFromWorker revokes a previously granted Qualification from a user.

        Access Level: Write

        https://docs.aws.amazon.com/AWSMechTurk/latest/AWSMturkAPI/ApiReference_DisassociateQualificationFromWorkerOperation.html

        :stability: experimental
        '''
        return typing.cast("Mechanicalturk", jsii.invoke(self, "toDisassociateQualificationFromWorker", []))

    @jsii.member(jsii_name="toGetAccountBalance")
    def to_get_account_balance(self) -> "Mechanicalturk":
        '''(experimental) The GetAccountBalance operation retrieves the amount of money in your Amazon Mechanical Turk account.

        Access Level: Read

        https://docs.aws.amazon.com/AWSMechTurk/latest/AWSMturkAPI/ApiReference_GetAccountBalanceOperation.html

        :stability: experimental
        '''
        return typing.cast("Mechanicalturk", jsii.invoke(self, "toGetAccountBalance", []))

    @jsii.member(jsii_name="toGetAssignment")
    def to_get_assignment(self) -> "Mechanicalturk":
        '''(experimental) The GetAssignment retrieves an assignment with an AssignmentStatus value of Submitted, Approved, or Rejected, using the assignment's ID.

        Access Level: Read

        https://docs.aws.amazon.com/AWSMechTurk/latest/AWSMturkAPI/ApiReference_GetAssignmentOperation.html

        :stability: experimental
        '''
        return typing.cast("Mechanicalturk", jsii.invoke(self, "toGetAssignment", []))

    @jsii.member(jsii_name="toGetFileUploadURL")
    def to_get_file_upload_url(self) -> "Mechanicalturk":
        '''(experimental) The GetFileUploadURL operation generates and returns a temporary URL.

        Access Level: Read

        https://docs.aws.amazon.com/AWSMechTurk/latest/AWSMturkAPI/ApiReference_GetFileUploadURLOperation.html

        :stability: experimental
        '''
        return typing.cast("Mechanicalturk", jsii.invoke(self, "toGetFileUploadURL", []))

    @jsii.member(jsii_name="toGetHIT")
    def to_get_hit(self) -> "Mechanicalturk":
        '''(experimental) The GetHIT operation retrieves the details of the specified HIT.

        Access Level: Read

        https://docs.aws.amazon.com/AWSMechTurk/latest/AWSMturkAPI/ApiReference_GetHITOperation.html

        :stability: experimental
        '''
        return typing.cast("Mechanicalturk", jsii.invoke(self, "toGetHIT", []))

    @jsii.member(jsii_name="toGetQualificationScore")
    def to_get_qualification_score(self) -> "Mechanicalturk":
        '''(experimental) The GetQualificationScore operation returns the value of a Worker's Qualification for a given Qualification type.

        Access Level: Read

        https://docs.aws.amazon.com/AWSMechTurk/latest/AWSMturkAPI/ApiReference_GetQualificationScoreOperation.html

        :stability: experimental
        '''
        return typing.cast("Mechanicalturk", jsii.invoke(self, "toGetQualificationScore", []))

    @jsii.member(jsii_name="toGetQualificationType")
    def to_get_qualification_type(self) -> "Mechanicalturk":
        '''(experimental) The GetQualificationType operation retrieves information about a Qualification type using its ID.

        Access Level: Read

        https://docs.aws.amazon.com/AWSMechTurk/latest/AWSMturkAPI/ApiReference_GetQualificationTypeOperation.html

        :stability: experimental
        '''
        return typing.cast("Mechanicalturk", jsii.invoke(self, "toGetQualificationType", []))

    @jsii.member(jsii_name="toListAssignmentsForHIT")
    def to_list_assignments_for_hit(self) -> "Mechanicalturk":
        '''(experimental) The ListAssignmentsForHIT operation retrieves completed assignments for a HIT.

        Access Level: List

        https://docs.aws.amazon.com/AWSMechTurk/latest/AWSMturkAPI/ApiReference_ListAssignmentsForHITOperation.html

        :stability: experimental
        '''
        return typing.cast("Mechanicalturk", jsii.invoke(self, "toListAssignmentsForHIT", []))

    @jsii.member(jsii_name="toListBonusPayments")
    def to_list_bonus_payments(self) -> "Mechanicalturk":
        '''(experimental) The ListBonusPayments operation retrieves the amounts of bonuses you have paid to Workers for a given HIT or assignment.

        Access Level: List

        https://docs.aws.amazon.com/AWSMechTurk/latest/AWSMturkAPI/ApiReference_ListBonusPaymentsOperation.html

        :stability: experimental
        '''
        return typing.cast("Mechanicalturk", jsii.invoke(self, "toListBonusPayments", []))

    @jsii.member(jsii_name="toListHITs")
    def to_list_hi_ts(self) -> "Mechanicalturk":
        '''(experimental) The ListHITs operation returns all of a Requester's HITs.

        Access Level: List

        https://docs.aws.amazon.com/AWSMechTurk/latest/AWSMturkAPI/ApiReference_ListHITsOperation.html

        :stability: experimental
        '''
        return typing.cast("Mechanicalturk", jsii.invoke(self, "toListHITs", []))

    @jsii.member(jsii_name="toListHITsForQualificationType")
    def to_list_hi_ts_for_qualification_type(self) -> "Mechanicalturk":
        '''(experimental) The ListHITsForQualificationType operation returns the HITs that use the given QualififcationType for a QualificationRequirement.

        Access Level: List

        https://docs.aws.amazon.com/AWSMechTurk/latest/AWSMturkAPI/ApiReference_ListHITsForQualificationTypeOperation.html

        :stability: experimental
        '''
        return typing.cast("Mechanicalturk", jsii.invoke(self, "toListHITsForQualificationType", []))

    @jsii.member(jsii_name="toListQualificationRequests")
    def to_list_qualification_requests(self) -> "Mechanicalturk":
        '''(experimental) The ListQualificationRequests operation retrieves requests for Qualifications of a particular Qualification type.

        Access Level: List

        https://docs.aws.amazon.com/AWSMechTurk/latest/AWSMturkAPI/ApiReference_ListQualificationRequestsOperation.html

        :stability: experimental
        '''
        return typing.cast("Mechanicalturk", jsii.invoke(self, "toListQualificationRequests", []))

    @jsii.member(jsii_name="toListQualificationTypes")
    def to_list_qualification_types(self) -> "Mechanicalturk":
        '''(experimental) The ListQualificationTypes operation searches for Qualification types using the specified search query, and returns a list of Qualification types.

        Access Level: List

        https://docs.aws.amazon.com/AWSMechTurk/latest/AWSMturkAPI/ApiReference_ListQualificationTypesOperation.html

        :stability: experimental
        '''
        return typing.cast("Mechanicalturk", jsii.invoke(self, "toListQualificationTypes", []))

    @jsii.member(jsii_name="toListReviewableHITs")
    def to_list_reviewable_hi_ts(self) -> "Mechanicalturk":
        '''(experimental) The ListReviewableHITs operation returns all of a Requester's HITs that have not been approved or rejected.

        Access Level: List

        https://docs.aws.amazon.com/AWSMechTurk/latest/AWSMturkAPI/ApiReference_ListReviewableHITsOperation.html

        :stability: experimental
        '''
        return typing.cast("Mechanicalturk", jsii.invoke(self, "toListReviewableHITs", []))

    @jsii.member(jsii_name="toListReviewPolicyResultsForHIT")
    def to_list_review_policy_results_for_hit(self) -> "Mechanicalturk":
        '''(experimental) The ListReviewPolicyResultsForHIT operation retrieves the computed results and the actions taken in the course of executing your Review Policies during a CreateHIT operation.

        Access Level: List

        https://docs.aws.amazon.com/AWSMechTurk/latest/AWSMturkAPI/ApiReference_ListReviewPolicyResultsForHITOperation.html

        :stability: experimental
        '''
        return typing.cast("Mechanicalturk", jsii.invoke(self, "toListReviewPolicyResultsForHIT", []))

    @jsii.member(jsii_name="toListWorkerBlocks")
    def to_list_worker_blocks(self) -> "Mechanicalturk":
        '''(experimental) The ListWorkersBlocks operation retrieves a list of Workers who are blocked from working on your HITs.

        Access Level: List

        https://docs.aws.amazon.com/AWSMechTurk/latest/AWSMturkAPI/ApiReference_ListWorkerBlocksOperation.html

        :stability: experimental
        '''
        return typing.cast("Mechanicalturk", jsii.invoke(self, "toListWorkerBlocks", []))

    @jsii.member(jsii_name="toListWorkersWithQualificationType")
    def to_list_workers_with_qualification_type(self) -> "Mechanicalturk":
        '''(experimental) The ListWorkersWithQualificationType operation returns all of the Workers with a given Qualification type.

        Access Level: List

        https://docs.aws.amazon.com/AWSMechTurk/latest/AWSMturkAPI/ApiReference_ListWorkersWithQualificationTypeOperation.html

        :stability: experimental
        '''
        return typing.cast("Mechanicalturk", jsii.invoke(self, "toListWorkersWithQualificationType", []))

    @jsii.member(jsii_name="toNotifyWorkers")
    def to_notify_workers(self) -> "Mechanicalturk":
        '''(experimental) The NotifyWorkers operation sends an email to one or more Workers that you specify with the Worker ID.

        Access Level: Write

        https://docs.aws.amazon.com/AWSMechTurk/latest/AWSMturkAPI/ApiReference_NotifyWorkersOperation.html

        :stability: experimental
        '''
        return typing.cast("Mechanicalturk", jsii.invoke(self, "toNotifyWorkers", []))

    @jsii.member(jsii_name="toRejectAssignment")
    def to_reject_assignment(self) -> "Mechanicalturk":
        '''(experimental) The RejectAssignment operation rejects the results of a completed assignment.

        Access Level: Write

        https://docs.aws.amazon.com/AWSMechTurk/latest/AWSMturkAPI/ApiReference_RejectAssignmentOperation.html

        :stability: experimental
        '''
        return typing.cast("Mechanicalturk", jsii.invoke(self, "toRejectAssignment", []))

    @jsii.member(jsii_name="toRejectQualificationRequest")
    def to_reject_qualification_request(self) -> "Mechanicalturk":
        '''(experimental) The RejectQualificationRequest operation rejects a user's request for a Qualification.

        Access Level: Write

        https://docs.aws.amazon.com/AWSMechTurk/latest/AWSMturkAPI/ApiReference_RejectQualificationRequestOperation.html

        :stability: experimental
        '''
        return typing.cast("Mechanicalturk", jsii.invoke(self, "toRejectQualificationRequest", []))

    @jsii.member(jsii_name="toSendBonus")
    def to_send_bonus(self) -> "Mechanicalturk":
        '''(experimental) The SendBonus operation issues a payment of money from your account to a Worker.

        Access Level: Write

        https://docs.aws.amazon.com/AWSMechTurk/latest/AWSMturkAPI/ApiReference_SendBonusOperation.html

        :stability: experimental
        '''
        return typing.cast("Mechanicalturk", jsii.invoke(self, "toSendBonus", []))

    @jsii.member(jsii_name="toSendTestEventNotification")
    def to_send_test_event_notification(self) -> "Mechanicalturk":
        '''(experimental) The SendTestEventNotification operation causes Amazon Mechanical Turk to send a notification message as if a HIT event occurred, according to the provided notification specification.

        Access Level: Write

        https://docs.aws.amazon.com/AWSMechTurk/latest/AWSMturkAPI/ApiReference_SendTestEventNotificationOperation.html

        :stability: experimental
        '''
        return typing.cast("Mechanicalturk", jsii.invoke(self, "toSendTestEventNotification", []))

    @jsii.member(jsii_name="toUpdateExpirationForHIT")
    def to_update_expiration_for_hit(self) -> "Mechanicalturk":
        '''(experimental) The UpdateExpirationForHIT operation allows you extend the expiration time of a HIT beyond is current expiration or expire a HIT immediately.

        Access Level: Write

        https://docs.aws.amazon.com/AWSMechTurk/latest/AWSMturkAPI/ApiReference_UpdateExpirationForHITOperation.html

        :stability: experimental
        '''
        return typing.cast("Mechanicalturk", jsii.invoke(self, "toUpdateExpirationForHIT", []))

    @jsii.member(jsii_name="toUpdateHITReviewStatus")
    def to_update_hit_review_status(self) -> "Mechanicalturk":
        '''(experimental) The UpdateHITReviewStatus operation toggles the status of a HIT.

        Access Level: Write

        https://docs.aws.amazon.com/AWSMechTurk/latest/AWSMturkAPI/ApiReference_UpdateHITReviewStatusOperation.html

        :stability: experimental
        '''
        return typing.cast("Mechanicalturk", jsii.invoke(self, "toUpdateHITReviewStatus", []))

    @jsii.member(jsii_name="toUpdateHITTypeOfHIT")
    def to_update_hit_type_of_hit(self) -> "Mechanicalturk":
        '''(experimental) The UpdateHITTypeOfHIT operation allows you to change the HITType properties of a HIT.

        Access Level: Write

        https://docs.aws.amazon.com/AWSMechTurk/latest/AWSMturkAPI/ApiReference_UpdateHITTypeOfHITOperation.html

        :stability: experimental
        '''
        return typing.cast("Mechanicalturk", jsii.invoke(self, "toUpdateHITTypeOfHIT", []))

    @jsii.member(jsii_name="toUpdateNotificationSettings")
    def to_update_notification_settings(self) -> "Mechanicalturk":
        '''(experimental) The UpdateNotificationSettings operation creates, updates, disables or re-enables notifications for a HIT type.

        Access Level: Write

        https://docs.aws.amazon.com/AWSMechTurk/latest/AWSMturkAPI/ApiReference_UpdateNotificationSettingsOperation.html

        :stability: experimental
        '''
        return typing.cast("Mechanicalturk", jsii.invoke(self, "toUpdateNotificationSettings", []))

    @jsii.member(jsii_name="toUpdateQualificationType")
    def to_update_qualification_type(self) -> "Mechanicalturk":
        '''(experimental) The UpdateQualificationType operation modifies the attributes of an existing Qualification type, which is represented by a QualificationType data structure.

        Access Level: Write

        https://docs.aws.amazon.com/AWSMechTurk/latest/AWSMturkAPI/ApiReference_UpdateQualificationTypeOperation.html

        :stability: experimental
        '''
        return typing.cast("Mechanicalturk", jsii.invoke(self, "toUpdateQualificationType", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b879b7fdbd3784434cba76c03982053e59912c9f0a27fb21f481ef9a3f4bfc8b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d3aa1627ed34d1dc0ffec4117b2807ffad18496bec0bde55d64375fe14f5745d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Mediaconnect(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Mediaconnect",
):
    '''(experimental) Statement provider for service `mediaconnect <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awselementalmediaconnect.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `mediaconnect <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awselementalmediaconnect.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onEntitlement")
    def on_entitlement(
        self,
        flow_id: builtins.str,
        entitlement_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Mediaconnect":
        '''(experimental) Adds a resource of type Entitlement to the statement.

        https://docs.aws.amazon.com/mediaconnect/latest/ug/entitlements.html

        :param flow_id: - Identifier for the flowId.
        :param entitlement_name: - Identifier for the entitlementName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__63c2afd7145d63433bbd8879254026428981a97828a86ccbe026f87d8310d3b6)
            check_type(argname="argument flow_id", value=flow_id, expected_type=type_hints["flow_id"])
            check_type(argname="argument entitlement_name", value=entitlement_name, expected_type=type_hints["entitlement_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Mediaconnect", jsii.invoke(self, "onEntitlement", [flow_id, entitlement_name, account, region, partition]))

    @jsii.member(jsii_name="onFlow")
    def on_flow(
        self,
        flow_id: builtins.str,
        flow_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Mediaconnect":
        '''(experimental) Adds a resource of type Flow to the statement.

        https://docs.aws.amazon.com/mediaconnect/latest/ug/flows.html

        :param flow_id: - Identifier for the flowId.
        :param flow_name: - Identifier for the flowName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a3b5c86c7ca5a4f20b1bbc83ff464b218ecff608fe351cb5e54ce0d2a74925d4)
            check_type(argname="argument flow_id", value=flow_id, expected_type=type_hints["flow_id"])
            check_type(argname="argument flow_name", value=flow_name, expected_type=type_hints["flow_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Mediaconnect", jsii.invoke(self, "onFlow", [flow_id, flow_name, account, region, partition]))

    @jsii.member(jsii_name="onOutput")
    def on_output(
        self,
        output_id: builtins.str,
        output_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Mediaconnect":
        '''(experimental) Adds a resource of type Output to the statement.

        https://docs.aws.amazon.com/mediaconnect/latest/ug/outputs.html

        :param output_id: - Identifier for the outputId.
        :param output_name: - Identifier for the outputName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a667a9cbfc8c4cb226d7597e31a74b945c48d330bdfe876ce4ce967907ad7a82)
            check_type(argname="argument output_id", value=output_id, expected_type=type_hints["output_id"])
            check_type(argname="argument output_name", value=output_name, expected_type=type_hints["output_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Mediaconnect", jsii.invoke(self, "onOutput", [output_id, output_name, account, region, partition]))

    @jsii.member(jsii_name="onSource")
    def on_source(
        self,
        source_id: builtins.str,
        source_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Mediaconnect":
        '''(experimental) Adds a resource of type Source to the statement.

        https://docs.aws.amazon.com/mediaconnect/latest/ug/sources.html

        :param source_id: - Identifier for the sourceId.
        :param source_name: - Identifier for the sourceName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2a49d8dbd627fd91e25204030caebb8aab20a0e5423300fbeb6b33eb2ceafaf1)
            check_type(argname="argument source_id", value=source_id, expected_type=type_hints["source_id"])
            check_type(argname="argument source_name", value=source_name, expected_type=type_hints["source_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Mediaconnect", jsii.invoke(self, "onSource", [source_id, source_name, account, region, partition]))

    @jsii.member(jsii_name="toAddFlowMediaStreams")
    def to_add_flow_media_streams(self) -> "Mediaconnect":
        '''(experimental) Grants permission to add media streams to any flow.

        Access Level: Write

        https://docs.aws.amazon.com/mediaconnect/latest/api/v1-flows-flowarn-mediastreams.html

        :stability: experimental
        '''
        return typing.cast("Mediaconnect", jsii.invoke(self, "toAddFlowMediaStreams", []))

    @jsii.member(jsii_name="toAddFlowOutputs")
    def to_add_flow_outputs(self) -> "Mediaconnect":
        '''(experimental) Grants permission to add outputs to any flow.

        Access Level: Write

        https://docs.aws.amazon.com/mediaconnect/latest/api/v1-flows-flowarn-outputs.html

        :stability: experimental
        '''
        return typing.cast("Mediaconnect", jsii.invoke(self, "toAddFlowOutputs", []))

    @jsii.member(jsii_name="toAddFlowSources")
    def to_add_flow_sources(self) -> "Mediaconnect":
        '''(experimental) Grants permission to add sources to any flow.

        Access Level: Write

        https://docs.aws.amazon.com/mediaconnect/latest/api/v1-flows-flowarn-source.html

        :stability: experimental
        '''
        return typing.cast("Mediaconnect", jsii.invoke(self, "toAddFlowSources", []))

    @jsii.member(jsii_name="toAddFlowVpcInterfaces")
    def to_add_flow_vpc_interfaces(self) -> "Mediaconnect":
        '''(experimental) Grants permission to add VPC interfaces to any flow.

        Access Level: Write

        https://docs.aws.amazon.com/mediaconnect/latest/api/v1-flows-flowarn-vpcinterfaces.html

        :stability: experimental
        '''
        return typing.cast("Mediaconnect", jsii.invoke(self, "toAddFlowVpcInterfaces", []))

    @jsii.member(jsii_name="toCreateFlow")
    def to_create_flow(self) -> "Mediaconnect":
        '''(experimental) Grants permission to create flows.

        Access Level: Write

        https://docs.aws.amazon.com/mediaconnect/latest/api/v1-flows.html

        :stability: experimental
        '''
        return typing.cast("Mediaconnect", jsii.invoke(self, "toCreateFlow", []))

    @jsii.member(jsii_name="toDeleteFlow")
    def to_delete_flow(self) -> "Mediaconnect":
        '''(experimental) Grants permission to delete flows.

        Access Level: Write

        https://docs.aws.amazon.com/mediaconnect/latest/api/v1-flows-flowarn.html

        :stability: experimental
        '''
        return typing.cast("Mediaconnect", jsii.invoke(self, "toDeleteFlow", []))

    @jsii.member(jsii_name="toDescribeFlow")
    def to_describe_flow(self) -> "Mediaconnect":
        '''(experimental) Grants permission to display the details of a flow including the flow ARN, name, and Availability Zone, as well as details about the source, outputs, and entitlements.

        Access Level: Read

        https://docs.aws.amazon.com/mediaconnect/latest/api/v1-flows-flowarn.html

        :stability: experimental
        '''
        return typing.cast("Mediaconnect", jsii.invoke(self, "toDescribeFlow", []))

    @jsii.member(jsii_name="toDescribeOffering")
    def to_describe_offering(self) -> "Mediaconnect":
        '''(experimental) Grants permission to display the details of an offering.

        Access Level: Read

        https://docs.aws.amazon.com/mediaconnect/latest/api/v1-offerings-offeringarn.html

        :stability: experimental
        '''
        return typing.cast("Mediaconnect", jsii.invoke(self, "toDescribeOffering", []))

    @jsii.member(jsii_name="toDescribeReservation")
    def to_describe_reservation(self) -> "Mediaconnect":
        '''(experimental) Grants permission to display the details of a reservation.

        Access Level: Read

        https://docs.aws.amazon.com/mediaconnect/latest/api/v1-reservations-reservationarn.html

        :stability: experimental
        '''
        return typing.cast("Mediaconnect", jsii.invoke(self, "toDescribeReservation", []))

    @jsii.member(jsii_name="toGrantFlowEntitlements")
    def to_grant_flow_entitlements(self) -> "Mediaconnect":
        '''(experimental) Grants permission to grant entitlements on any flow.

        Access Level: Write

        https://docs.aws.amazon.com/mediaconnect/latest/api/v1-flows-flowarn-entitlements.html

        :stability: experimental
        '''
        return typing.cast("Mediaconnect", jsii.invoke(self, "toGrantFlowEntitlements", []))

    @jsii.member(jsii_name="toListEntitlements")
    def to_list_entitlements(self) -> "Mediaconnect":
        '''(experimental) Grants permission to display a list of all entitlements that have been granted to the account.

        Access Level: List

        https://docs.aws.amazon.com/mediaconnect/latest/api/v1-entitlements.html

        :stability: experimental
        '''
        return typing.cast("Mediaconnect", jsii.invoke(self, "toListEntitlements", []))

    @jsii.member(jsii_name="toListFlows")
    def to_list_flows(self) -> "Mediaconnect":
        '''(experimental) Grants permission to display a list of flows that are associated with this account.

        Access Level: List

        https://docs.aws.amazon.com/mediaconnect/latest/api/v1-flows.html

        :stability: experimental
        '''
        return typing.cast("Mediaconnect", jsii.invoke(self, "toListFlows", []))

    @jsii.member(jsii_name="toListOfferings")
    def to_list_offerings(self) -> "Mediaconnect":
        '''(experimental) Grants permission to display a list of all offerings that are available to the account in the current AWS Region.

        Access Level: List

        https://docs.aws.amazon.com/mediaconnect/latest/api/v1-offerings.html

        :stability: experimental
        '''
        return typing.cast("Mediaconnect", jsii.invoke(self, "toListOfferings", []))

    @jsii.member(jsii_name="toListReservations")
    def to_list_reservations(self) -> "Mediaconnect":
        '''(experimental) Grants permission to display a list of all reservations that have been purchased by the account in the current AWS Region.

        Access Level: List

        https://docs.aws.amazon.com/mediaconnect/latest/api/v1-reservations.html

        :stability: experimental
        '''
        return typing.cast("Mediaconnect", jsii.invoke(self, "toListReservations", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Mediaconnect":
        '''(experimental) Grants permission to display a list of all tags associated with a resource.

        Access Level: Read

        https://docs.aws.amazon.com/mediaconnect/latest/api/tags-resourcearn.html

        :stability: experimental
        '''
        return typing.cast("Mediaconnect", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toPurchaseOffering")
    def to_purchase_offering(self) -> "Mediaconnect":
        '''(experimental) Grants permission to purchase an offering.

        Access Level: Write

        https://docs.aws.amazon.com/mediaconnect/latest/api/v1-offerings-offeringarn.html

        :stability: experimental
        '''
        return typing.cast("Mediaconnect", jsii.invoke(self, "toPurchaseOffering", []))

    @jsii.member(jsii_name="toRemoveFlowMediaStream")
    def to_remove_flow_media_stream(self) -> "Mediaconnect":
        '''(experimental) Grants permission to remove media streams from any flow.

        Access Level: Write

        https://docs.aws.amazon.com/mediaconnect/latest/api/v1-flows-flowarn-mediastreams-mediastreamname.html

        :stability: experimental
        '''
        return typing.cast("Mediaconnect", jsii.invoke(self, "toRemoveFlowMediaStream", []))

    @jsii.member(jsii_name="toRemoveFlowOutput")
    def to_remove_flow_output(self) -> "Mediaconnect":
        '''(experimental) Grants permission to remove outputs from any flow.

        Access Level: Write

        https://docs.aws.amazon.com/mediaconnect/latest/api/v1-flows-flowarn-outputs-outputarn.html

        :stability: experimental
        '''
        return typing.cast("Mediaconnect", jsii.invoke(self, "toRemoveFlowOutput", []))

    @jsii.member(jsii_name="toRemoveFlowSource")
    def to_remove_flow_source(self) -> "Mediaconnect":
        '''(experimental) Grants permission to remove sources from any flow.

        Access Level: Write

        https://docs.aws.amazon.com/mediaconnect/latest/api/v1-flows-flowarn-source-sourcearn.html

        :stability: experimental
        '''
        return typing.cast("Mediaconnect", jsii.invoke(self, "toRemoveFlowSource", []))

    @jsii.member(jsii_name="toRemoveFlowVpcInterface")
    def to_remove_flow_vpc_interface(self) -> "Mediaconnect":
        '''(experimental) Grants permission to remove VPC interfaces from any flow.

        Access Level: Write

        https://docs.aws.amazon.com/mediaconnect/latest/api/v1-flows-flowarn-vpcinterfaces-vpcinterfacename.html

        :stability: experimental
        '''
        return typing.cast("Mediaconnect", jsii.invoke(self, "toRemoveFlowVpcInterface", []))

    @jsii.member(jsii_name="toRevokeFlowEntitlement")
    def to_revoke_flow_entitlement(self) -> "Mediaconnect":
        '''(experimental) Grants permission to revoke entitlements on any flow.

        Access Level: Write

        https://docs.aws.amazon.com/mediaconnect/latest/api/v1-flows-flowarn-entitlements-entitlementarn.html

        :stability: experimental
        '''
        return typing.cast("Mediaconnect", jsii.invoke(self, "toRevokeFlowEntitlement", []))

    @jsii.member(jsii_name="toStartFlow")
    def to_start_flow(self) -> "Mediaconnect":
        '''(experimental) Grants permission to start flows.

        Access Level: Write

        https://docs.aws.amazon.com/mediaconnect/latest/api/v1-flows-start-flowarn.html

        :stability: experimental
        '''
        return typing.cast("Mediaconnect", jsii.invoke(self, "toStartFlow", []))

    @jsii.member(jsii_name="toStopFlow")
    def to_stop_flow(self) -> "Mediaconnect":
        '''(experimental) Grants permission to stop flows.

        Access Level: Write

        https://docs.aws.amazon.com/mediaconnect/latest/api/v1-flows-stop-flowarn.html

        :stability: experimental
        '''
        return typing.cast("Mediaconnect", jsii.invoke(self, "toStopFlow", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Mediaconnect":
        '''(experimental) Grants permission to associate tags with resources.

        Access Level: Tagging

        https://docs.aws.amazon.com/mediaconnect/latest/api/tags-resourcearn.html

        :stability: experimental
        '''
        return typing.cast("Mediaconnect", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Mediaconnect":
        '''(experimental) Grants permission to remove tags from resources.

        Access Level: Tagging

        https://docs.aws.amazon.com/mediaconnect/latest/api/tags-resourcearn.html

        :stability: experimental
        '''
        return typing.cast("Mediaconnect", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateFlow")
    def to_update_flow(self) -> "Mediaconnect":
        '''(experimental) Grants permission to update flows.

        Access Level: Write

        https://docs.aws.amazon.com/mediaconnect/latest/api/v1-flows-flowarn.html

        :stability: experimental
        '''
        return typing.cast("Mediaconnect", jsii.invoke(self, "toUpdateFlow", []))

    @jsii.member(jsii_name="toUpdateFlowEntitlement")
    def to_update_flow_entitlement(self) -> "Mediaconnect":
        '''(experimental) Grants permission to update entitlements on any flow.

        Access Level: Write

        https://docs.aws.amazon.com/mediaconnect/latest/api/v1-flows-flowarn-entitlements-entitlementarn.html

        :stability: experimental
        '''
        return typing.cast("Mediaconnect", jsii.invoke(self, "toUpdateFlowEntitlement", []))

    @jsii.member(jsii_name="toUpdateFlowMediaStream")
    def to_update_flow_media_stream(self) -> "Mediaconnect":
        '''(experimental) Grants permission to update media streams on any flow.

        Access Level: Write

        https://docs.aws.amazon.com/mediaconnect/latest/api/v1-flows-flowarn-mediastreams-mediastreamname.html

        :stability: experimental
        '''
        return typing.cast("Mediaconnect", jsii.invoke(self, "toUpdateFlowMediaStream", []))

    @jsii.member(jsii_name="toUpdateFlowOutput")
    def to_update_flow_output(self) -> "Mediaconnect":
        '''(experimental) Grants permission to update outputs on any flow.

        Access Level: Write

        https://docs.aws.amazon.com/mediaconnect/latest/api/v1-flows-flowarn-outputs-outputarn.html

        :stability: experimental
        '''
        return typing.cast("Mediaconnect", jsii.invoke(self, "toUpdateFlowOutput", []))

    @jsii.member(jsii_name="toUpdateFlowSource")
    def to_update_flow_source(self) -> "Mediaconnect":
        '''(experimental) Grants permission to update the source of any flow.

        Access Level: Write

        https://docs.aws.amazon.com/mediaconnect/latest/api/v1-flows-flowarn-source-sourcearn.html

        :stability: experimental
        '''
        return typing.cast("Mediaconnect", jsii.invoke(self, "toUpdateFlowSource", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d6670897044e7f903f6686bb9deac5f7fd376a8355ed53a0b78b26253b8a7101)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f0326fe1638967b232ad1536522fb2646dda0e4b6ff3c37240d9d9b98304509d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Mediaconvert(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Mediaconvert",
):
    '''(experimental) Statement provider for service `mediaconvert <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awselementalmediaconvert.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `mediaconvert <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awselementalmediaconvert.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onCertificateAssociation")
    def on_certificate_association(
        self,
        certificate_arn: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Mediaconvert":
        '''(experimental) Adds a resource of type CertificateAssociation to the statement.

        https://docs.aws.amazon.com/mediaconvert/latest/apireference/certificates.html

        :param certificate_arn: - Identifier for the certificateArn.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5d17fdd2dc6d2ad898dd906539ffb520699155302fce9bcd8a85db05ab5399b4)
            check_type(argname="argument certificate_arn", value=certificate_arn, expected_type=type_hints["certificate_arn"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Mediaconvert", jsii.invoke(self, "onCertificateAssociation", [certificate_arn, account, region, partition]))

    @jsii.member(jsii_name="onJob")
    def on_job(
        self,
        job_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Mediaconvert":
        '''(experimental) Adds a resource of type Job to the statement.

        https://docs.aws.amazon.com/mediaconvert/latest/apireference/jobs.html

        :param job_id: - Identifier for the jobId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__af8f3b256c1954c6de828c2f371fdfaddd5e452c1ed267613e6787973ea9cfa6)
            check_type(argname="argument job_id", value=job_id, expected_type=type_hints["job_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Mediaconvert", jsii.invoke(self, "onJob", [job_id, account, region, partition]))

    @jsii.member(jsii_name="onJobTemplate")
    def on_job_template(
        self,
        job_template_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Mediaconvert":
        '''(experimental) Adds a resource of type JobTemplate to the statement.

        https://docs.aws.amazon.com/mediaconvert/latest/apireference/jobtemplates.html

        :param job_template_name: - Identifier for the jobTemplateName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b3ce0b81b8ebf07e847cc82a44253041f9875083d96d264f8c62b12f2384a5e4)
            check_type(argname="argument job_template_name", value=job_template_name, expected_type=type_hints["job_template_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Mediaconvert", jsii.invoke(self, "onJobTemplate", [job_template_name, account, region, partition]))

    @jsii.member(jsii_name="onPreset")
    def on_preset(
        self,
        preset_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Mediaconvert":
        '''(experimental) Adds a resource of type Preset to the statement.

        https://docs.aws.amazon.com/mediaconvert/latest/apireference/presets.html

        :param preset_name: - Identifier for the presetName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5dd99f74fbe9bab9782dfb71d16b9e67b627f57ee2311a7d31cbf88371be6742)
            check_type(argname="argument preset_name", value=preset_name, expected_type=type_hints["preset_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Mediaconvert", jsii.invoke(self, "onPreset", [preset_name, account, region, partition]))

    @jsii.member(jsii_name="onQueue")
    def on_queue(
        self,
        queue_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Mediaconvert":
        '''(experimental) Adds a resource of type Queue to the statement.

        https://docs.aws.amazon.com/mediaconvert/latest/apireference/queues.html

        :param queue_name: - Identifier for the queueName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c1568d303dcb6712339900e1f58436cc66135b95f9d7905f2bbc3f59476f9911)
            check_type(argname="argument queue_name", value=queue_name, expected_type=type_hints["queue_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Mediaconvert", jsii.invoke(self, "onQueue", [queue_name, account, region, partition]))

    @jsii.member(jsii_name="toAssociateCertificate")
    def to_associate_certificate(self) -> "Mediaconvert":
        '''(experimental) Grants permission to associate an AWS Certificate Manager (ACM) Amazon Resource Name (ARN) with AWS Elemental MediaConvert.

        Access Level: Write

        https://docs.aws.amazon.com/mediaconvert/latest/apireference/certificates.html

        :stability: experimental
        '''
        return typing.cast("Mediaconvert", jsii.invoke(self, "toAssociateCertificate", []))

    @jsii.member(jsii_name="toCancelJob")
    def to_cancel_job(self) -> "Mediaconvert":
        '''(experimental) Grants permission to cancel an AWS Elemental MediaConvert job that is waiting in queue.

        Access Level: Write

        https://docs.aws.amazon.com/mediaconvert/latest/apireference/jobs-id.html

        :stability: experimental
        '''
        return typing.cast("Mediaconvert", jsii.invoke(self, "toCancelJob", []))

    @jsii.member(jsii_name="toCreateJob")
    def to_create_job(self) -> "Mediaconvert":
        '''(experimental) Grants permission to create and submit an AWS Elemental MediaConvert job.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/mediaconvert/latest/apireference/jobs.html

        :stability: experimental
        '''
        return typing.cast("Mediaconvert", jsii.invoke(self, "toCreateJob", []))

    @jsii.member(jsii_name="toCreateJobTemplate")
    def to_create_job_template(self) -> "Mediaconvert":
        '''(experimental) Grants permission to create an AWS Elemental MediaConvert custom job template.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/mediaconvert/latest/apireference/jobs-id.html

        :stability: experimental
        '''
        return typing.cast("Mediaconvert", jsii.invoke(self, "toCreateJobTemplate", []))

    @jsii.member(jsii_name="toCreatePreset")
    def to_create_preset(self) -> "Mediaconvert":
        '''(experimental) Grants permission to create an AWS Elemental MediaConvert custom output preset.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/mediaconvert/latest/apireference/presets.html

        :stability: experimental
        '''
        return typing.cast("Mediaconvert", jsii.invoke(self, "toCreatePreset", []))

    @jsii.member(jsii_name="toCreateQueue")
    def to_create_queue(self) -> "Mediaconvert":
        '''(experimental) Grants permission to create an AWS Elemental MediaConvert job queue.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/mediaconvert/latest/apireference/queues.html

        :stability: experimental
        '''
        return typing.cast("Mediaconvert", jsii.invoke(self, "toCreateQueue", []))

    @jsii.member(jsii_name="toDeleteJobTemplate")
    def to_delete_job_template(self) -> "Mediaconvert":
        '''(experimental) Grants permission to delete an AWS Elemental MediaConvert custom job template.

        Access Level: Write

        https://docs.aws.amazon.com/mediaconvert/latest/apireference/jobtemplates-name.html

        :stability: experimental
        '''
        return typing.cast("Mediaconvert", jsii.invoke(self, "toDeleteJobTemplate", []))

    @jsii.member(jsii_name="toDeletePolicy")
    def to_delete_policy(self) -> "Mediaconvert":
        '''(experimental) Grants permission to delete an AWS Elemental MediaConvert policy.

        Access Level: Write

        https://docs.aws.amazon.com/mediaconvert/latest/apireference/policy.html

        :stability: experimental
        '''
        return typing.cast("Mediaconvert", jsii.invoke(self, "toDeletePolicy", []))

    @jsii.member(jsii_name="toDeletePreset")
    def to_delete_preset(self) -> "Mediaconvert":
        '''(experimental) Grants permission to delete an AWS Elemental MediaConvert custom output preset.

        Access Level: Write

        https://docs.aws.amazon.com/mediaconvert/latest/apireference/presets-name.html

        :stability: experimental
        '''
        return typing.cast("Mediaconvert", jsii.invoke(self, "toDeletePreset", []))

    @jsii.member(jsii_name="toDeleteQueue")
    def to_delete_queue(self) -> "Mediaconvert":
        '''(experimental) Grants permission to delete an AWS Elemental MediaConvert job queue.

        Access Level: Write

        https://docs.aws.amazon.com/mediaconvert/latest/apireference/queues-name.html

        :stability: experimental
        '''
        return typing.cast("Mediaconvert", jsii.invoke(self, "toDeleteQueue", []))

    @jsii.member(jsii_name="toDescribeEndpoints")
    def to_describe_endpoints(self) -> "Mediaconvert":
        '''(experimental) Grants permission to subscribe to the AWS Elemental MediaConvert service, by sending a request for an account-specific endpoint.

        All transcoding requests must be sent to the endpoint that the service returns

        Access Level: List

        https://docs.aws.amazon.com/mediaconvert/latest/apireference/endpoints.html

        :stability: experimental
        '''
        return typing.cast("Mediaconvert", jsii.invoke(self, "toDescribeEndpoints", []))

    @jsii.member(jsii_name="toDisassociateCertificate")
    def to_disassociate_certificate(self) -> "Mediaconvert":
        '''(experimental) Grants permission to remove an association between the Amazon Resource Name (ARN) of an AWS Certificate Manager (ACM) certificate and an AWS Elemental MediaConvert resource.

        Access Level: Write

        https://docs.aws.amazon.com/mediaconvert/latest/apireference/certificates-arn.html

        :stability: experimental
        '''
        return typing.cast("Mediaconvert", jsii.invoke(self, "toDisassociateCertificate", []))

    @jsii.member(jsii_name="toGetJob")
    def to_get_job(self) -> "Mediaconvert":
        '''(experimental) Grants permission to get an AWS Elemental MediaConvert job.

        Access Level: Read

        https://docs.aws.amazon.com/mediaconvert/latest/apireference/jobs-id.html

        :stability: experimental
        '''
        return typing.cast("Mediaconvert", jsii.invoke(self, "toGetJob", []))

    @jsii.member(jsii_name="toGetJobTemplate")
    def to_get_job_template(self) -> "Mediaconvert":
        '''(experimental) Grants permission to get an AWS Elemental MediaConvert job template.

        Access Level: Read

        https://docs.aws.amazon.com/mediaconvert/latest/apireference/jobtemplates-name.html

        :stability: experimental
        '''
        return typing.cast("Mediaconvert", jsii.invoke(self, "toGetJobTemplate", []))

    @jsii.member(jsii_name="toGetPolicy")
    def to_get_policy(self) -> "Mediaconvert":
        '''(experimental) Grants permission to get an AWS Elemental MediaConvert policy.

        Access Level: Read

        https://docs.aws.amazon.com/mediaconvert/latest/apireference/policy.html

        :stability: experimental
        '''
        return typing.cast("Mediaconvert", jsii.invoke(self, "toGetPolicy", []))

    @jsii.member(jsii_name="toGetPreset")
    def to_get_preset(self) -> "Mediaconvert":
        '''(experimental) Grants permission to get an AWS Elemental MediaConvert output preset.

        Access Level: Read

        https://docs.aws.amazon.com/mediaconvert/latest/apireference/presets-name.html

        :stability: experimental
        '''
        return typing.cast("Mediaconvert", jsii.invoke(self, "toGetPreset", []))

    @jsii.member(jsii_name="toGetQueue")
    def to_get_queue(self) -> "Mediaconvert":
        '''(experimental) Grants permission to get an AWS Elemental MediaConvert job queue.

        Access Level: Read

        https://docs.aws.amazon.com/mediaconvert/latest/apireference/queues-name.html

        :stability: experimental
        '''
        return typing.cast("Mediaconvert", jsii.invoke(self, "toGetQueue", []))

    @jsii.member(jsii_name="toListJobs")
    def to_list_jobs(self) -> "Mediaconvert":
        '''(experimental) Grants permission to list AWS Elemental MediaConvert jobs.

        Access Level: List

        https://docs.aws.amazon.com/mediaconvert/latest/apireference/jobs.html

        :stability: experimental
        '''
        return typing.cast("Mediaconvert", jsii.invoke(self, "toListJobs", []))

    @jsii.member(jsii_name="toListJobTemplates")
    def to_list_job_templates(self) -> "Mediaconvert":
        '''(experimental) Grants permission to list AWS Elemental MediaConvert job templates.

        Access Level: List

        https://docs.aws.amazon.com/mediaconvert/latest/apireference/jobtemplates.html

        :stability: experimental
        '''
        return typing.cast("Mediaconvert", jsii.invoke(self, "toListJobTemplates", []))

    @jsii.member(jsii_name="toListPresets")
    def to_list_presets(self) -> "Mediaconvert":
        '''(experimental) Grants permission to list AWS Elemental MediaConvert output presets.

        Access Level: List

        https://docs.aws.amazon.com/mediaconvert/latest/apireference/presets.html

        :stability: experimental
        '''
        return typing.cast("Mediaconvert", jsii.invoke(self, "toListPresets", []))

    @jsii.member(jsii_name="toListQueues")
    def to_list_queues(self) -> "Mediaconvert":
        '''(experimental) Grants permission to list AWS Elemental MediaConvert job queues.

        Access Level: List

        https://docs.aws.amazon.com/mediaconvert/latest/apireference/queues.html

        :stability: experimental
        '''
        return typing.cast("Mediaconvert", jsii.invoke(self, "toListQueues", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Mediaconvert":
        '''(experimental) Grants permission to retrieve the tags for a MediaConvert queue, preset, or job template.

        Access Level: Read

        https://docs.aws.amazon.com/mediaconvert/latest/apireference/tags-arn.html

        :stability: experimental
        '''
        return typing.cast("Mediaconvert", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toPutPolicy")
    def to_put_policy(self) -> "Mediaconvert":
        '''(experimental) Grants permission to put an AWS Elemental MediaConvert policy.

        Access Level: Write

        https://docs.aws.amazon.com/mediaconvert/latest/apireference/policy.html

        :stability: experimental
        '''
        return typing.cast("Mediaconvert", jsii.invoke(self, "toPutPolicy", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Mediaconvert":
        '''(experimental) Grants permission to add tags to a MediaConvert queue, preset, or job template.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/mediaconvert/latest/apireference/tags.html

        :stability: experimental
        '''
        return typing.cast("Mediaconvert", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Mediaconvert":
        '''(experimental) Grants permission to remove tags from a MediaConvert queue, preset, or job template.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/mediaconvert/latest/apireference/tags-arn.html

        :stability: experimental
        '''
        return typing.cast("Mediaconvert", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateJobTemplate")
    def to_update_job_template(self) -> "Mediaconvert":
        '''(experimental) Grants permission to update an AWS Elemental MediaConvert custom job template.

        Access Level: Write

        https://docs.aws.amazon.com/mediaconvert/latest/apireference/jobtemplates-name.html

        :stability: experimental
        '''
        return typing.cast("Mediaconvert", jsii.invoke(self, "toUpdateJobTemplate", []))

    @jsii.member(jsii_name="toUpdatePreset")
    def to_update_preset(self) -> "Mediaconvert":
        '''(experimental) Grants permission to update an AWS Elemental MediaConvert custom output preset.

        Access Level: Write

        https://docs.aws.amazon.com/mediaconvert/latest/apireference/presets-name.html

        :stability: experimental
        '''
        return typing.cast("Mediaconvert", jsii.invoke(self, "toUpdatePreset", []))

    @jsii.member(jsii_name="toUpdateQueue")
    def to_update_queue(self) -> "Mediaconvert":
        '''(experimental) Grants permission to update an AWS Elemental MediaConvert job queue.

        Access Level: Write

        https://docs.aws.amazon.com/mediaconvert/latest/apireference/queues-name.html

        :stability: experimental
        '''
        return typing.cast("Mediaconvert", jsii.invoke(self, "toUpdateQueue", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__428b983398b0912c70bda8eadc955ffc3617d992e2fb4bc627bc6b15f93b6f77)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6679c2a932dcf1776c5d3acf09cf1bf797b37806a5e23febebf34fab5e8c9fcb)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Mediaimport(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Mediaimport",
):
    '''(experimental) Statement provider for service `mediaimport <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonmediaimport.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `mediaimport <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonmediaimport.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="toCreateDatabaseBinarySnapshot")
    def to_create_database_binary_snapshot(self) -> "Mediaimport":
        '''(experimental) Grants permission to create a database binary snapshot on the customer's aws account.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/custom-cev.html

        :stability: experimental
        '''
        return typing.cast("Mediaimport", jsii.invoke(self, "toCreateDatabaseBinarySnapshot", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8f1185730c470a978aa8851b2fc923f69030c48f75386ec0042397983a482b47)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2b8db10a456585422a098672e2eb81376eec50f87e8b913e5a2b42a3cbd4607b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Medialive(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Medialive",
):
    '''(experimental) Statement provider for service `medialive <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awselementalmedialive.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `medialive <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awselementalmedialive.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onChannel")
    def on_channel(
        self,
        channel_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Medialive":
        '''(experimental) Adds a resource of type channel to the statement.

        https://docs.aws.amazon.com/medialive/latest/ug/channels.html

        :param channel_id: - Identifier for the channelId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f2472d4a47f786364ea57eec053b829253e97ddba9242e48aafb61a9ac6bb76a)
            check_type(argname="argument channel_id", value=channel_id, expected_type=type_hints["channel_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Medialive", jsii.invoke(self, "onChannel", [channel_id, account, region, partition]))

    @jsii.member(jsii_name="onInput")
    def on_input(
        self,
        input_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Medialive":
        '''(experimental) Adds a resource of type input to the statement.

        https://docs.aws.amazon.com/medialive/latest/ug/inputs.html

        :param input_id: - Identifier for the inputId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__078baea5878cfcbc57c88fb033b5716a433605a79912b556a3608b95c943e4ec)
            check_type(argname="argument input_id", value=input_id, expected_type=type_hints["input_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Medialive", jsii.invoke(self, "onInput", [input_id, account, region, partition]))

    @jsii.member(jsii_name="onInputDevice")
    def on_input_device(
        self,
        device_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Medialive":
        '''(experimental) Adds a resource of type input-device to the statement.

        https://docs.aws.amazon.com/medialive/latest/ug/eml-devices.html

        :param device_id: - Identifier for the deviceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bda9546bcb38df22671cf1f4094aa107b14af8bc31232f57055d2eba75911e4d)
            check_type(argname="argument device_id", value=device_id, expected_type=type_hints["device_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Medialive", jsii.invoke(self, "onInputDevice", [device_id, account, region, partition]))

    @jsii.member(jsii_name="onInputSecurityGroup")
    def on_input_security_group(
        self,
        input_security_group_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Medialive":
        '''(experimental) Adds a resource of type input-security-group to the statement.

        https://docs.aws.amazon.com/medialive/latest/ug/inputsecuritygroups.html

        :param input_security_group_id: - Identifier for the inputSecurityGroupId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ae3b18f2e3818f3c4c82c64a056da25b1a89a607e66c9c183c5e0394b9468320)
            check_type(argname="argument input_security_group_id", value=input_security_group_id, expected_type=type_hints["input_security_group_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Medialive", jsii.invoke(self, "onInputSecurityGroup", [input_security_group_id, account, region, partition]))

    @jsii.member(jsii_name="onMultiplex")
    def on_multiplex(
        self,
        multiplex_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Medialive":
        '''(experimental) Adds a resource of type multiplex to the statement.

        https://docs.aws.amazon.com/medialive/latest/ug/eml-multiplex.html

        :param multiplex_id: - Identifier for the multiplexId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__71958a80b41e29b19d71daa3a80c757f7335795eeeda2e59f7d94e9dba3d21ed)
            check_type(argname="argument multiplex_id", value=multiplex_id, expected_type=type_hints["multiplex_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Medialive", jsii.invoke(self, "onMultiplex", [multiplex_id, account, region, partition]))

    @jsii.member(jsii_name="onOffering")
    def on_offering(
        self,
        offering_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Medialive":
        '''(experimental) Adds a resource of type offering to the statement.

        https://docs.aws.amazon.com/medialive/latest/ug/input-output-reservations.html

        :param offering_id: - Identifier for the offeringId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__89f475dafcf235986ec1895bffba7434fa7659691d09e5d59b7b6e36f9609e5c)
            check_type(argname="argument offering_id", value=offering_id, expected_type=type_hints["offering_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Medialive", jsii.invoke(self, "onOffering", [offering_id, account, region, partition]))

    @jsii.member(jsii_name="onReservation")
    def on_reservation(
        self,
        reservation_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Medialive":
        '''(experimental) Adds a resource of type reservation to the statement.

        https://docs.aws.amazon.com/medialive/latest/ug/reservations.html

        :param reservation_id: - Identifier for the reservationId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__37d5700330c48890072e5f9471a85677885720a28035685d3aef8077899ab410)
            check_type(argname="argument reservation_id", value=reservation_id, expected_type=type_hints["reservation_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Medialive", jsii.invoke(self, "onReservation", [reservation_id, account, region, partition]))

    @jsii.member(jsii_name="toAcceptInputDeviceTransfer")
    def to_accept_input_device_transfer(self) -> "Medialive":
        '''(experimental) Grants permission to accept an input device transfer.

        Access Level: Write

        https://docs.aws.amazon.com/medialive/latest/ug/eml-devices.html

        :stability: experimental
        '''
        return typing.cast("Medialive", jsii.invoke(self, "toAcceptInputDeviceTransfer", []))

    @jsii.member(jsii_name="toBatchDelete")
    def to_batch_delete(self) -> "Medialive":
        '''(experimental) Grants permission to delete channels, inputs, input security groups, and multiplexes.

        Access Level: Write

        https://docs.aws.amazon.com/medialive/latest/ug/editing-deleting-channel.html

        :stability: experimental
        '''
        return typing.cast("Medialive", jsii.invoke(self, "toBatchDelete", []))

    @jsii.member(jsii_name="toBatchStart")
    def to_batch_start(self) -> "Medialive":
        '''(experimental) Grants permission to start channels and multiplexes.

        Access Level: Write

        https://docs.aws.amazon.com/medialive/latest/ug/starting-stopping-deleting-a-channel.html

        :stability: experimental
        '''
        return typing.cast("Medialive", jsii.invoke(self, "toBatchStart", []))

    @jsii.member(jsii_name="toBatchStop")
    def to_batch_stop(self) -> "Medialive":
        '''(experimental) Grants permission to stop channels and multiplexes.

        Access Level: Write

        https://docs.aws.amazon.com/medialive/latest/ug/starting-stopping-deleting-a-channel.html

        :stability: experimental
        '''
        return typing.cast("Medialive", jsii.invoke(self, "toBatchStop", []))

    @jsii.member(jsii_name="toBatchUpdateSchedule")
    def to_batch_update_schedule(self) -> "Medialive":
        '''(experimental) Grants permission to add and remove actions from a channel's schedule.

        Access Level: Write

        https://docs.aws.amazon.com/medialive/latest/ug/submitting-batch-command.html

        :stability: experimental
        '''
        return typing.cast("Medialive", jsii.invoke(self, "toBatchUpdateSchedule", []))

    @jsii.member(jsii_name="toCancelInputDeviceTransfer")
    def to_cancel_input_device_transfer(self) -> "Medialive":
        '''(experimental) Grants permission to cancel an input device transfer.

        Access Level: Write

        https://docs.aws.amazon.com/medialive/latest/ug/eml-devices.html

        :stability: experimental
        '''
        return typing.cast("Medialive", jsii.invoke(self, "toCancelInputDeviceTransfer", []))

    @jsii.member(jsii_name="toClaimDevice")
    def to_claim_device(self) -> "Medialive":
        '''(experimental) Grants permission to claim an input device.

        Access Level: Write

        https://docs.aws.amazon.com/medialive/latest/ug/eml-devices.html

        :stability: experimental
        '''
        return typing.cast("Medialive", jsii.invoke(self, "toClaimDevice", []))

    @jsii.member(jsii_name="toCreateChannel")
    def to_create_channel(self) -> "Medialive":
        '''(experimental) Grants permission to create a channel.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/medialive/latest/ug/creating-channel-scratch.html

        :stability: experimental
        '''
        return typing.cast("Medialive", jsii.invoke(self, "toCreateChannel", []))

    @jsii.member(jsii_name="toCreateInput")
    def to_create_input(self) -> "Medialive":
        '''(experimental) Grants permission to create an input.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/medialive/latest/ug/creating-input.html

        :stability: experimental
        '''
        return typing.cast("Medialive", jsii.invoke(self, "toCreateInput", []))

    @jsii.member(jsii_name="toCreateInputSecurityGroup")
    def to_create_input_security_group(self) -> "Medialive":
        '''(experimental) Grants permission to create an input security group.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/medialive/latest/ug/working-with-input-security-groups.html

        :stability: experimental
        '''
        return typing.cast("Medialive", jsii.invoke(self, "toCreateInputSecurityGroup", []))

    @jsii.member(jsii_name="toCreateMultiplex")
    def to_create_multiplex(self) -> "Medialive":
        '''(experimental) Grants permission to create a multiplex.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/medialive/latest/ug/multiplex-create.html

        :stability: experimental
        '''
        return typing.cast("Medialive", jsii.invoke(self, "toCreateMultiplex", []))

    @jsii.member(jsii_name="toCreateMultiplexProgram")
    def to_create_multiplex_program(self) -> "Medialive":
        '''(experimental) Grants permission to create a multiplex program.

        Access Level: Write

        https://docs.aws.amazon.com/medialive/latest/ug/multiplex-create.html

        :stability: experimental
        '''
        return typing.cast("Medialive", jsii.invoke(self, "toCreateMultiplexProgram", []))

    @jsii.member(jsii_name="toCreatePartnerInput")
    def to_create_partner_input(self) -> "Medialive":
        '''(experimental) Grants permission to create a partner input.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/medialive/latest/ug/input-create-cdi-partners.html

        :stability: experimental
        '''
        return typing.cast("Medialive", jsii.invoke(self, "toCreatePartnerInput", []))

    @jsii.member(jsii_name="toCreateTags")
    def to_create_tags(self) -> "Medialive":
        '''(experimental) Grants permission to create tags for channels, inputs, input security groups, multiplexes, and reservations.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/medialive/latest/ug/tagging.html

        :stability: experimental
        '''
        return typing.cast("Medialive", jsii.invoke(self, "toCreateTags", []))

    @jsii.member(jsii_name="toDeleteChannel")
    def to_delete_channel(self) -> "Medialive":
        '''(experimental) Grants permission to delete a channel.

        Access Level: Write

        https://docs.aws.amazon.com/medialive/latest/ug/editing-deleting-channel.html

        :stability: experimental
        '''
        return typing.cast("Medialive", jsii.invoke(self, "toDeleteChannel", []))

    @jsii.member(jsii_name="toDeleteInput")
    def to_delete_input(self) -> "Medialive":
        '''(experimental) Grants permission to delete an input.

        Access Level: Write

        https://docs.aws.amazon.com/medialive/latest/ug/delete-input.html

        :stability: experimental
        '''
        return typing.cast("Medialive", jsii.invoke(self, "toDeleteInput", []))

    @jsii.member(jsii_name="toDeleteInputSecurityGroup")
    def to_delete_input_security_group(self) -> "Medialive":
        '''(experimental) Grants permission to delete an input security group.

        Access Level: Write

        https://docs.aws.amazon.com/medialive/latest/ug/delete-input-security-group.html

        :stability: experimental
        '''
        return typing.cast("Medialive", jsii.invoke(self, "toDeleteInputSecurityGroup", []))

    @jsii.member(jsii_name="toDeleteMultiplex")
    def to_delete_multiplex(self) -> "Medialive":
        '''(experimental) Grants permission to delete a multiplex.

        Access Level: Write

        https://docs.aws.amazon.com/medialive/latest/ug/delete-multiplex-program.html

        :stability: experimental
        '''
        return typing.cast("Medialive", jsii.invoke(self, "toDeleteMultiplex", []))

    @jsii.member(jsii_name="toDeleteMultiplexProgram")
    def to_delete_multiplex_program(self) -> "Medialive":
        '''(experimental) Grants permission to delete a multiplex program.

        Access Level: Write

        https://docs.aws.amazon.com/medialive/latest/ug/delete-multiplex-program.html

        :stability: experimental
        '''
        return typing.cast("Medialive", jsii.invoke(self, "toDeleteMultiplexProgram", []))

    @jsii.member(jsii_name="toDeleteReservation")
    def to_delete_reservation(self) -> "Medialive":
        '''(experimental) Grants permission to delete an expired reservation.

        Access Level: Write

        https://docs.aws.amazon.com/medialive/latest/ug/deleting-reservations.html

        :stability: experimental
        '''
        return typing.cast("Medialive", jsii.invoke(self, "toDeleteReservation", []))

    @jsii.member(jsii_name="toDeleteSchedule")
    def to_delete_schedule(self) -> "Medialive":
        '''(experimental) Grants permission to delete all schedule actions for a channel.

        Access Level: Write

        https://docs.aws.amazon.com/medialive/latest/ug/schedule-using-console-delete.html

        :stability: experimental
        '''
        return typing.cast("Medialive", jsii.invoke(self, "toDeleteSchedule", []))

    @jsii.member(jsii_name="toDeleteTags")
    def to_delete_tags(self) -> "Medialive":
        '''(experimental) Grants permission to delete tags from channels, inputs, input security groups, multiplexes, and reservations.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/medialive/latest/ug/tagging.html

        :stability: experimental
        '''
        return typing.cast("Medialive", jsii.invoke(self, "toDeleteTags", []))

    @jsii.member(jsii_name="toDescribeChannel")
    def to_describe_channel(self) -> "Medialive":
        '''(experimental) Grants permission to get details about a channel.

        Access Level: Read

        https://docs.aws.amazon.com/medialive/latest/ug/viewing-channel-configuration.html

        :stability: experimental
        '''
        return typing.cast("Medialive", jsii.invoke(self, "toDescribeChannel", []))

    @jsii.member(jsii_name="toDescribeInput")
    def to_describe_input(self) -> "Medialive":
        '''(experimental) Grants permission to describe an input.

        Access Level: Read

        https://docs.aws.amazon.com/medialive/latest/ug/edit-input.html

        :stability: experimental
        '''
        return typing.cast("Medialive", jsii.invoke(self, "toDescribeInput", []))

    @jsii.member(jsii_name="toDescribeInputDevice")
    def to_describe_input_device(self) -> "Medialive":
        '''(experimental) Grants permission to describe an input device.

        Access Level: Read

        https://docs.aws.amazon.com/medialive/latest/ug/device-edit.html

        :stability: experimental
        '''
        return typing.cast("Medialive", jsii.invoke(self, "toDescribeInputDevice", []))

    @jsii.member(jsii_name="toDescribeInputDeviceThumbnail")
    def to_describe_input_device_thumbnail(self) -> "Medialive":
        '''(experimental) Grants permission to describe an input device thumbnail.

        Access Level: Read

        https://docs.aws.amazon.com/medialive/latest/ug/device-edit.html

        :stability: experimental
        '''
        return typing.cast("Medialive", jsii.invoke(self, "toDescribeInputDeviceThumbnail", []))

    @jsii.member(jsii_name="toDescribeInputSecurityGroup")
    def to_describe_input_security_group(self) -> "Medialive":
        '''(experimental) Grants permission to describe an input security group.

        Access Level: Read

        https://docs.aws.amazon.com/medialive/latest/ug/edit-input-security-group.html

        :stability: experimental
        '''
        return typing.cast("Medialive", jsii.invoke(self, "toDescribeInputSecurityGroup", []))

    @jsii.member(jsii_name="toDescribeMultiplex")
    def to_describe_multiplex(self) -> "Medialive":
        '''(experimental) Grants permission to describe a multiplex.

        Access Level: Read

        https://docs.aws.amazon.com/medialive/latest/ug/edit-multiplex-program-channel.html

        :stability: experimental
        '''
        return typing.cast("Medialive", jsii.invoke(self, "toDescribeMultiplex", []))

    @jsii.member(jsii_name="toDescribeMultiplexProgram")
    def to_describe_multiplex_program(self) -> "Medialive":
        '''(experimental) Grants permission to describe a multiplex program.

        Access Level: Read

        https://docs.aws.amazon.com/medialive/latest/ug/monitoring-multiplex-console.html

        :stability: experimental
        '''
        return typing.cast("Medialive", jsii.invoke(self, "toDescribeMultiplexProgram", []))

    @jsii.member(jsii_name="toDescribeOffering")
    def to_describe_offering(self) -> "Medialive":
        '''(experimental) Grants permission to get details about a reservation offering.

        Access Level: Read

        https://docs.aws.amazon.com/medialive/latest/ug/purchasing-reservations.html

        :stability: experimental
        '''
        return typing.cast("Medialive", jsii.invoke(self, "toDescribeOffering", []))

    @jsii.member(jsii_name="toDescribeReservation")
    def to_describe_reservation(self) -> "Medialive":
        '''(experimental) Grants permission to get details about a reservation.

        Access Level: Read

        https://docs.aws.amazon.com/medialive/latest/ug/view-reservations.html

        :stability: experimental
        '''
        return typing.cast("Medialive", jsii.invoke(self, "toDescribeReservation", []))

    @jsii.member(jsii_name="toDescribeSchedule")
    def to_describe_schedule(self) -> "Medialive":
        '''(experimental) Grants permission to view a list of actions scheduled on a channel.

        Access Level: Read

        https://docs.aws.amazon.com/medialive/latest/ug/schedule-using-console-view.html

        :stability: experimental
        '''
        return typing.cast("Medialive", jsii.invoke(self, "toDescribeSchedule", []))

    @jsii.member(jsii_name="toListChannels")
    def to_list_channels(self) -> "Medialive":
        '''(experimental) Grants permission to list channels.

        Access Level: List

        https://docs.aws.amazon.com/medialive/latest/ug/viewing-channel-configuration.html

        :stability: experimental
        '''
        return typing.cast("Medialive", jsii.invoke(self, "toListChannels", []))

    @jsii.member(jsii_name="toListInputDevices")
    def to_list_input_devices(self) -> "Medialive":
        '''(experimental) Grants permission to list input devices.

        Access Level: List

        https://docs.aws.amazon.com/medialive/latest/ug/device-edit.html

        :stability: experimental
        '''
        return typing.cast("Medialive", jsii.invoke(self, "toListInputDevices", []))

    @jsii.member(jsii_name="toListInputDeviceTransfers")
    def to_list_input_device_transfers(self) -> "Medialive":
        '''(experimental) Grants permission to list input device transfers.

        Access Level: List

        https://docs.aws.amazon.com/medialive/latest/ug/eml-devices.html

        :stability: experimental
        '''
        return typing.cast("Medialive", jsii.invoke(self, "toListInputDeviceTransfers", []))

    @jsii.member(jsii_name="toListInputs")
    def to_list_inputs(self) -> "Medialive":
        '''(experimental) Grants permission to list inputs.

        Access Level: List

        https://docs.aws.amazon.com/medialive/latest/ug/edit-input.html

        :stability: experimental
        '''
        return typing.cast("Medialive", jsii.invoke(self, "toListInputs", []))

    @jsii.member(jsii_name="toListInputSecurityGroups")
    def to_list_input_security_groups(self) -> "Medialive":
        '''(experimental) Grants permission to list input security groups.

        Access Level: List

        https://docs.aws.amazon.com/medialive/latest/ug/edit-input-security-group.html

        :stability: experimental
        '''
        return typing.cast("Medialive", jsii.invoke(self, "toListInputSecurityGroups", []))

    @jsii.member(jsii_name="toListMultiplexes")
    def to_list_multiplexes(self) -> "Medialive":
        '''(experimental) Grants permission to list multiplexes.

        Access Level: List

        https://docs.aws.amazon.com/medialive/latest/ug/edit-multiplex-program-channel.html

        :stability: experimental
        '''
        return typing.cast("Medialive", jsii.invoke(self, "toListMultiplexes", []))

    @jsii.member(jsii_name="toListMultiplexPrograms")
    def to_list_multiplex_programs(self) -> "Medialive":
        '''(experimental) Grants permission to list multiplex programs.

        Access Level: List

        https://docs.aws.amazon.com/medialive/latest/ug/monitoring-multiplex-console.html

        :stability: experimental
        '''
        return typing.cast("Medialive", jsii.invoke(self, "toListMultiplexPrograms", []))

    @jsii.member(jsii_name="toListOfferings")
    def to_list_offerings(self) -> "Medialive":
        '''(experimental) Grants permission to list reservation offerings.

        Access Level: List

        https://docs.aws.amazon.com/medialive/latest/ug/purchasing-reservations.html

        :stability: experimental
        '''
        return typing.cast("Medialive", jsii.invoke(self, "toListOfferings", []))

    @jsii.member(jsii_name="toListReservations")
    def to_list_reservations(self) -> "Medialive":
        '''(experimental) Grants permission to list reservations.

        Access Level: List

        https://docs.aws.amazon.com/medialive/latest/ug/view-reservations.html

        :stability: experimental
        '''
        return typing.cast("Medialive", jsii.invoke(self, "toListReservations", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Medialive":
        '''(experimental) Grants permission to list tags for channels, inputs, input security groups, multiplexes, and reservations.

        Access Level: List

        https://docs.aws.amazon.com/medialive/latest/ug/tagging.html

        :stability: experimental
        '''
        return typing.cast("Medialive", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toPurchaseOffering")
    def to_purchase_offering(self) -> "Medialive":
        '''(experimental) Grants permission to purchase a reservation offering.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/medialive/latest/ug/purchasing-reservations.html

        :stability: experimental
        '''
        return typing.cast("Medialive", jsii.invoke(self, "toPurchaseOffering", []))

    @jsii.member(jsii_name="toRebootInputDevice")
    def to_reboot_input_device(self) -> "Medialive":
        '''(experimental) Grants permission to reboot an input device.

        Access Level: Write

        https://docs.aws.amazon.com/medialive/latest/ug/eml-devices.html

        :stability: experimental
        '''
        return typing.cast("Medialive", jsii.invoke(self, "toRebootInputDevice", []))

    @jsii.member(jsii_name="toRejectInputDeviceTransfer")
    def to_reject_input_device_transfer(self) -> "Medialive":
        '''(experimental) Grants permission to reject an input device transfer.

        Access Level: Write

        https://docs.aws.amazon.com/medialive/latest/ug/eml-devices.html

        :stability: experimental
        '''
        return typing.cast("Medialive", jsii.invoke(self, "toRejectInputDeviceTransfer", []))

    @jsii.member(jsii_name="toStartChannel")
    def to_start_channel(self) -> "Medialive":
        '''(experimental) Grants permission to start a channel.

        Access Level: Write

        https://docs.aws.amazon.com/medialive/latest/ug/starting-stopping-deleting-a-channel.html

        :stability: experimental
        '''
        return typing.cast("Medialive", jsii.invoke(self, "toStartChannel", []))

    @jsii.member(jsii_name="toStartInputDeviceMaintenanceWindow")
    def to_start_input_device_maintenance_window(self) -> "Medialive":
        '''(experimental) Grants permission to start a maintenance window for an input device.

        Access Level: Write

        https://docs.aws.amazon.com/medialive/latest/ug/eml-devices.html

        :stability: experimental
        '''
        return typing.cast("Medialive", jsii.invoke(self, "toStartInputDeviceMaintenanceWindow", []))

    @jsii.member(jsii_name="toStartMultiplex")
    def to_start_multiplex(self) -> "Medialive":
        '''(experimental) Grants permission to start a multiplex.

        Access Level: Write

        https://docs.aws.amazon.com/medialive/latest/ug/start-multiplex.html

        :stability: experimental
        '''
        return typing.cast("Medialive", jsii.invoke(self, "toStartMultiplex", []))

    @jsii.member(jsii_name="toStopChannel")
    def to_stop_channel(self) -> "Medialive":
        '''(experimental) Grants permission to stop a channel.

        Access Level: Write

        https://docs.aws.amazon.com/medialive/latest/ug/starting-stopping-deleting-a-channel.html

        :stability: experimental
        '''
        return typing.cast("Medialive", jsii.invoke(self, "toStopChannel", []))

    @jsii.member(jsii_name="toStopMultiplex")
    def to_stop_multiplex(self) -> "Medialive":
        '''(experimental) Grants permission to stop a multiplex.

        Access Level: Write

        https://docs.aws.amazon.com/medialive/latest/ug/stop-multiplex.title.html

        :stability: experimental
        '''
        return typing.cast("Medialive", jsii.invoke(self, "toStopMultiplex", []))

    @jsii.member(jsii_name="toTransferInputDevice")
    def to_transfer_input_device(self) -> "Medialive":
        '''(experimental) Grants permission to transfer an input device.

        Access Level: Write

        https://docs.aws.amazon.com/medialive/latest/ug/eml-devices.html

        :stability: experimental
        '''
        return typing.cast("Medialive", jsii.invoke(self, "toTransferInputDevice", []))

    @jsii.member(jsii_name="toUpdateChannel")
    def to_update_channel(self) -> "Medialive":
        '''(experimental) Grants permission to update a channel.

        Access Level: Write

        https://docs.aws.amazon.com/medialive/latest/ug/editing-deleting-channel.html

        :stability: experimental
        '''
        return typing.cast("Medialive", jsii.invoke(self, "toUpdateChannel", []))

    @jsii.member(jsii_name="toUpdateChannelClass")
    def to_update_channel_class(self) -> "Medialive":
        '''(experimental) Grants permission to update the class of a channel.

        Access Level: Write

        https://docs.aws.amazon.com/medialive/latest/ug/editing-deleting-channel.html

        :stability: experimental
        '''
        return typing.cast("Medialive", jsii.invoke(self, "toUpdateChannelClass", []))

    @jsii.member(jsii_name="toUpdateInput")
    def to_update_input(self) -> "Medialive":
        '''(experimental) Grants permission to update an input.

        Access Level: Write

        https://docs.aws.amazon.com/medialive/latest/ug/edit-input.html

        :stability: experimental
        '''
        return typing.cast("Medialive", jsii.invoke(self, "toUpdateInput", []))

    @jsii.member(jsii_name="toUpdateInputDevice")
    def to_update_input_device(self) -> "Medialive":
        '''(experimental) Grants permission to update an input device.

        Access Level: Write

        https://docs.aws.amazon.com/medialive/latest/ug/device-edit.html

        :stability: experimental
        '''
        return typing.cast("Medialive", jsii.invoke(self, "toUpdateInputDevice", []))

    @jsii.member(jsii_name="toUpdateInputSecurityGroup")
    def to_update_input_security_group(self) -> "Medialive":
        '''(experimental) Grants permission to update an input security group.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/medialive/latest/ug/edit-input-security-group.html

        :stability: experimental
        '''
        return typing.cast("Medialive", jsii.invoke(self, "toUpdateInputSecurityGroup", []))

    @jsii.member(jsii_name="toUpdateMultiplex")
    def to_update_multiplex(self) -> "Medialive":
        '''(experimental) Grants permission to update a multiplex.

        Access Level: Write

        https://docs.aws.amazon.com/medialive/latest/ug/edit-multiplex-program-channel.html

        :stability: experimental
        '''
        return typing.cast("Medialive", jsii.invoke(self, "toUpdateMultiplex", []))

    @jsii.member(jsii_name="toUpdateMultiplexProgram")
    def to_update_multiplex_program(self) -> "Medialive":
        '''(experimental) Grants permission to update a multiplex program.

        Access Level: Write

        https://docs.aws.amazon.com/medialive/latest/ug/edit-multiplex-program-channel.html

        :stability: experimental
        '''
        return typing.cast("Medialive", jsii.invoke(self, "toUpdateMultiplexProgram", []))

    @jsii.member(jsii_name="toUpdateReservation")
    def to_update_reservation(self) -> "Medialive":
        '''(experimental) Grants permission to update a reservation.

        Access Level: Write

        https://docs.aws.amazon.com/medialive/latest/ug/reservations.html

        :stability: experimental
        '''
        return typing.cast("Medialive", jsii.invoke(self, "toUpdateReservation", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9b7ed36330703b18adf8c98d07238012d4c886df115e3d37d9c7238be21481c8)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5f92a493b07a1b25f37f16e5290947b21078a9f876218fad03000bea87dbbf0f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Mediapackage(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Mediapackage",
):
    '''(experimental) Statement provider for service `mediapackage <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awselementalmediapackage.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `mediapackage <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awselementalmediapackage.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onChannels")
    def on_channels(
        self,
        channel_identifier: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Mediapackage":
        '''(experimental) Adds a resource of type channels to the statement.

        https://docs.aws.amazon.com/mediapackage/latest/ug/channels.html

        :param channel_identifier: - Identifier for the channelIdentifier.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d158aba54810950e818f7b7b5936ff0b5a8a7ad0907c4da7c07458eb08eb1afa)
            check_type(argname="argument channel_identifier", value=channel_identifier, expected_type=type_hints["channel_identifier"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Mediapackage", jsii.invoke(self, "onChannels", [channel_identifier, account, region, partition]))

    @jsii.member(jsii_name="onHarvestJobs")
    def on_harvest_jobs(
        self,
        harvest_job_identifier: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Mediapackage":
        '''(experimental) Adds a resource of type harvest_jobs to the statement.

        https://docs.aws.amazon.com/mediapackage/latest/ug/harvest-jobs.html

        :param harvest_job_identifier: - Identifier for the harvestJobIdentifier.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fb27212969c8aeb4cd29870d280423983e8403aa3dc0eaecde1c9ed75f74327e)
            check_type(argname="argument harvest_job_identifier", value=harvest_job_identifier, expected_type=type_hints["harvest_job_identifier"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Mediapackage", jsii.invoke(self, "onHarvestJobs", [harvest_job_identifier, account, region, partition]))

    @jsii.member(jsii_name="onOriginEndpoints")
    def on_origin_endpoints(
        self,
        origin_endpoint_identifier: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Mediapackage":
        '''(experimental) Adds a resource of type origin_endpoints to the statement.

        https://docs.aws.amazon.com/mediapackage/latest/ug/endpoints.html

        :param origin_endpoint_identifier: - Identifier for the originEndpointIdentifier.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fccda338622735e5c5cd396e665534f043cb4ad11a516bc66b3e4917e07dbc88)
            check_type(argname="argument origin_endpoint_identifier", value=origin_endpoint_identifier, expected_type=type_hints["origin_endpoint_identifier"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Mediapackage", jsii.invoke(self, "onOriginEndpoints", [origin_endpoint_identifier, account, region, partition]))

    @jsii.member(jsii_name="toConfigureLogs")
    def to_configure_logs(self) -> "Mediapackage":
        '''(experimental) Grants permission to configure access logs for a Channel.

        Access Level: Write

        Dependent actions:

        - iam:CreateServiceLinkedRole

        https://docs.aws.amazon.com/mediapackage/latest/apireference/channels-id-configure_logs.html#channels-id-configure_logsput

        :stability: experimental
        '''
        return typing.cast("Mediapackage", jsii.invoke(self, "toConfigureLogs", []))

    @jsii.member(jsii_name="toCreateChannel")
    def to_create_channel(self) -> "Mediapackage":
        '''(experimental) Grants permission to create a channel in AWS Elemental MediaPackage.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/mediapackage/latest/apireference/channels.html#channelspost

        :stability: experimental
        '''
        return typing.cast("Mediapackage", jsii.invoke(self, "toCreateChannel", []))

    @jsii.member(jsii_name="toCreateHarvestJob")
    def to_create_harvest_job(self) -> "Mediapackage":
        '''(experimental) Grants permission to create a harvest job in AWS Elemental MediaPackage.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/mediapackage/latest/apireference/harvest_jobs.html#harvest_jobspost

        :stability: experimental
        '''
        return typing.cast("Mediapackage", jsii.invoke(self, "toCreateHarvestJob", []))

    @jsii.member(jsii_name="toCreateOriginEndpoint")
    def to_create_origin_endpoint(self) -> "Mediapackage":
        '''(experimental) Grants permission to create an endpoint in AWS Elemental MediaPackage.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/mediapackage/latest/apireference/origin_endpoints.html#origin_endpointspost

        :stability: experimental
        '''
        return typing.cast("Mediapackage", jsii.invoke(self, "toCreateOriginEndpoint", []))

    @jsii.member(jsii_name="toDeleteChannel")
    def to_delete_channel(self) -> "Mediapackage":
        '''(experimental) Grants permission to delete a channel in AWS Elemental MediaPackage.

        Access Level: Write

        https://docs.aws.amazon.com/mediapackage/latest/apireference/channels-id.html#channels-iddelete

        :stability: experimental
        '''
        return typing.cast("Mediapackage", jsii.invoke(self, "toDeleteChannel", []))

    @jsii.member(jsii_name="toDeleteOriginEndpoint")
    def to_delete_origin_endpoint(self) -> "Mediapackage":
        '''(experimental) Grants permission to delete an endpoint in AWS Elemental MediaPackage.

        Access Level: Write

        https://docs.aws.amazon.com/mediapackage/latest/apireference/origin_endpoints-id.html#origin_endpoints-iddelete

        :stability: experimental
        '''
        return typing.cast("Mediapackage", jsii.invoke(self, "toDeleteOriginEndpoint", []))

    @jsii.member(jsii_name="toDescribeChannel")
    def to_describe_channel(self) -> "Mediapackage":
        '''(experimental) Grants permission to view the details of a channel in AWS Elemental MediaPackage.

        Access Level: Read

        https://docs.aws.amazon.com/mediapackage/latest/apireference/channels-id.html#channels-idget

        :stability: experimental
        '''
        return typing.cast("Mediapackage", jsii.invoke(self, "toDescribeChannel", []))

    @jsii.member(jsii_name="toDescribeHarvestJob")
    def to_describe_harvest_job(self) -> "Mediapackage":
        '''(experimental) Grants permission to view the details of a harvest job in AWS Elemental MediaPackage.

        Access Level: Read

        https://docs.aws.amazon.com/mediapackage/latest/apireference/harvest_jobs-id.html#harvest_jobs-idget

        :stability: experimental
        '''
        return typing.cast("Mediapackage", jsii.invoke(self, "toDescribeHarvestJob", []))

    @jsii.member(jsii_name="toDescribeOriginEndpoint")
    def to_describe_origin_endpoint(self) -> "Mediapackage":
        '''(experimental) Grants permission to view the details of an endpoint in AWS Elemental MediaPackage.

        Access Level: Read

        https://docs.aws.amazon.com/mediapackage/latest/apireference/origin_endpoints-id.html#origin_endpoints-idget

        :stability: experimental
        '''
        return typing.cast("Mediapackage", jsii.invoke(self, "toDescribeOriginEndpoint", []))

    @jsii.member(jsii_name="toListChannels")
    def to_list_channels(self) -> "Mediapackage":
        '''(experimental) Grants permission to view a list of channels in AWS Elemental MediaPackage.

        Access Level: Read

        https://docs.aws.amazon.com/mediapackage/latest/apireference/channels.html#channelsget

        :stability: experimental
        '''
        return typing.cast("Mediapackage", jsii.invoke(self, "toListChannels", []))

    @jsii.member(jsii_name="toListHarvestJobs")
    def to_list_harvest_jobs(self) -> "Mediapackage":
        '''(experimental) Grants permission to view a list of harvest jobs in AWS Elemental MediaPackage.

        Access Level: Read

        https://docs.aws.amazon.com/mediapackage/latest/apireference/harvest_jobs.html#harvest_jobsget

        :stability: experimental
        '''
        return typing.cast("Mediapackage", jsii.invoke(self, "toListHarvestJobs", []))

    @jsii.member(jsii_name="toListOriginEndpoints")
    def to_list_origin_endpoints(self) -> "Mediapackage":
        '''(experimental) Grants permission to view a list of endpoints in AWS Elemental MediaPackage.

        Access Level: Read

        https://docs.aws.amazon.com/mediapackage/latest/apireference/origin_endpoints.html#origin_endpointsget

        :stability: experimental
        '''
        return typing.cast("Mediapackage", jsii.invoke(self, "toListOriginEndpoints", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Mediapackage":
        '''(experimental) Grants permission to list the tags assigned to a Channel or OriginEndpoint.

        Access Level: Read

        https://docs.aws.amazon.com/mediapackage/latest/apireference/tags-resource-arn.html#tags-resource-arnget

        :stability: experimental
        '''
        return typing.cast("Mediapackage", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toRotateChannelCredentials")
    def to_rotate_channel_credentials(self) -> "Mediapackage":
        '''(experimental) Grants permission to rotate credentials for the first IngestEndpoint of a Channel in AWS Elemental MediaPackage.

        Access Level: Write

        https://docs.aws.amazon.com/mediapackage/latest/apireference/channels-id-credentials.html#channels-id-credentialsput

        :stability: experimental
        '''
        return typing.cast("Mediapackage", jsii.invoke(self, "toRotateChannelCredentials", []))

    @jsii.member(jsii_name="toRotateIngestEndpointCredentials")
    def to_rotate_ingest_endpoint_credentials(self) -> "Mediapackage":
        '''(experimental) Grants permission to rotate IngestEndpoint credentials for a Channel in AWS Elemental MediaPackage.

        Access Level: Write

        https://docs.aws.amazon.com/mediapackage/latest/apireference/channels-id-ingest_endpoints-ingest_endpoint_id-credentials.html#channels-id-ingest_endpoints-ingest_endpoint_id-credentialsput

        :stability: experimental
        '''
        return typing.cast("Mediapackage", jsii.invoke(self, "toRotateIngestEndpointCredentials", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Mediapackage":
        '''(experimental) Grants permission to tag a MediaPackage resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/mediapackage/latest/apireference/hj-create.html

        :stability: experimental
        '''
        return typing.cast("Mediapackage", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Mediapackage":
        '''(experimental) Grants permission to delete tags to a Channel or OriginEndpoint.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/mediapackage/latest/apireference/tags-resource-arn.html#tags-resource-arndelete

        :stability: experimental
        '''
        return typing.cast("Mediapackage", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateChannel")
    def to_update_channel(self) -> "Mediapackage":
        '''(experimental) Grants permission to make changes to a channel in AWS Elemental MediaPackage.

        Access Level: Write

        https://docs.aws.amazon.com/mediapackage/latest/apireference/channels-id.html#channels-idput

        :stability: experimental
        '''
        return typing.cast("Mediapackage", jsii.invoke(self, "toUpdateChannel", []))

    @jsii.member(jsii_name="toUpdateOriginEndpoint")
    def to_update_origin_endpoint(self) -> "Mediapackage":
        '''(experimental) Grants permission to make changes to an endpoint in AWS Elemental MediaPackage.

        Access Level: Write

        https://docs.aws.amazon.com/mediapackage/latest/apireference/origin_endpoints-id.html#origin_endpoints-idput

        :stability: experimental
        '''
        return typing.cast("Mediapackage", jsii.invoke(self, "toUpdateOriginEndpoint", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3eedcd23f21f979c7da52747b6a54aa7983204dd0f18763b16aff4e4efccccf8)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__58ca4e5bd2aafe72f8a8ab609124cda9601e66b63f226eba728f5d370b0a6748)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class MediapackageVod(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.MediapackageVod",
):
    '''(experimental) Statement provider for service `mediapackage-vod <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awselementalmediapackagevod.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `mediapackage-vod <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awselementalmediapackagevod.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onAssets")
    def on_assets(
        self,
        asset_identifier: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "MediapackageVod":
        '''(experimental) Adds a resource of type assets to the statement.

        https://docs.aws.amazon.com/mediapackage/latest/ug/asset.html

        :param asset_identifier: - Identifier for the assetIdentifier.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__297b72d08402ff53a0c815f87de8b5d8521d77f25d3baaa803ea812048adb917)
            check_type(argname="argument asset_identifier", value=asset_identifier, expected_type=type_hints["asset_identifier"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("MediapackageVod", jsii.invoke(self, "onAssets", [asset_identifier, account, region, partition]))

    @jsii.member(jsii_name="onPackagingConfigurations")
    def on_packaging_configurations(
        self,
        packaging_configuration_identifier: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "MediapackageVod":
        '''(experimental) Adds a resource of type packaging-configurations to the statement.

        https://docs.aws.amazon.com/mediapackage/latest/ug/pkg-cfig.html

        :param packaging_configuration_identifier: - Identifier for the packagingConfigurationIdentifier.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__59fcd98f0cdc7ac3c8ad3a1fa323030a778763d8c93aa042c80754c5ac3103fe)
            check_type(argname="argument packaging_configuration_identifier", value=packaging_configuration_identifier, expected_type=type_hints["packaging_configuration_identifier"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("MediapackageVod", jsii.invoke(self, "onPackagingConfigurations", [packaging_configuration_identifier, account, region, partition]))

    @jsii.member(jsii_name="onPackagingGroups")
    def on_packaging_groups(
        self,
        packaging_group_identifier: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "MediapackageVod":
        '''(experimental) Adds a resource of type packaging-groups to the statement.

        https://docs.aws.amazon.com/mediapackage/latest/ug/pkg-group.html

        :param packaging_group_identifier: - Identifier for the packagingGroupIdentifier.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b0d284dff34c8b057e854b9263acdd4da3fb46d9992d0d8d3e9c830352359f5b)
            check_type(argname="argument packaging_group_identifier", value=packaging_group_identifier, expected_type=type_hints["packaging_group_identifier"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("MediapackageVod", jsii.invoke(self, "onPackagingGroups", [packaging_group_identifier, account, region, partition]))

    @jsii.member(jsii_name="toConfigureLogs")
    def to_configure_logs(self) -> "MediapackageVod":
        '''(experimental) Grants permission to configure egress access logs for a PackagingGroup.

        Access Level: Write

        Dependent actions:

        - iam:CreateServiceLinkedRole

        https://docs.aws.amazon.com/mediapackage-vod/latest/apireference/packaging_groups-id-configure_logs.html#packaging_groups-id-configure_logsput

        :stability: experimental
        '''
        return typing.cast("MediapackageVod", jsii.invoke(self, "toConfigureLogs", []))

    @jsii.member(jsii_name="toCreateAsset")
    def to_create_asset(self) -> "MediapackageVod":
        '''(experimental) Grants permission to create an asset in AWS Elemental MediaPackage.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/mediapackage-vod/latest/apireference/assets.html#assetspost

        :stability: experimental
        '''
        return typing.cast("MediapackageVod", jsii.invoke(self, "toCreateAsset", []))

    @jsii.member(jsii_name="toCreatePackagingConfiguration")
    def to_create_packaging_configuration(self) -> "MediapackageVod":
        '''(experimental) Grants permission to create a packaging configuration in AWS Elemental MediaPackage.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/mediapackage-vod/latest/apireference/packaging_configurations.html#packaging_configurationspost

        :stability: experimental
        '''
        return typing.cast("MediapackageVod", jsii.invoke(self, "toCreatePackagingConfiguration", []))

    @jsii.member(jsii_name="toCreatePackagingGroup")
    def to_create_packaging_group(self) -> "MediapackageVod":
        '''(experimental) Grants permission to create a packaging group in AWS Elemental MediaPackage.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/mediapackage-vod/latest/apireference/packaging_groups.html#packaging_groupspost

        :stability: experimental
        '''
        return typing.cast("MediapackageVod", jsii.invoke(self, "toCreatePackagingGroup", []))

    @jsii.member(jsii_name="toDeleteAsset")
    def to_delete_asset(self) -> "MediapackageVod":
        '''(experimental) Grants permission to delete an asset in AWS Elemental MediaPackage.

        Access Level: Write

        https://docs.aws.amazon.com/mediapackage-vod/latest/apireference/assets-id.html#assets-iddelete

        :stability: experimental
        '''
        return typing.cast("MediapackageVod", jsii.invoke(self, "toDeleteAsset", []))

    @jsii.member(jsii_name="toDeletePackagingConfiguration")
    def to_delete_packaging_configuration(self) -> "MediapackageVod":
        '''(experimental) Grants permission to delete a packaging configuration in AWS Elemental MediaPackage.

        Access Level: Write

        https://docs.aws.amazon.com/mediapackage-vod/latest/apireference/packaging_configurations-id.html#packaging_configurations-iddelete

        :stability: experimental
        '''
        return typing.cast("MediapackageVod", jsii.invoke(self, "toDeletePackagingConfiguration", []))

    @jsii.member(jsii_name="toDeletePackagingGroup")
    def to_delete_packaging_group(self) -> "MediapackageVod":
        '''(experimental) Grants permission to delete a packaging group in AWS Elemental MediaPackage.

        Access Level: Write

        https://docs.aws.amazon.com/mediapackage-vod/latest/apireference/packaging_groups-id.html#packaging_groups-iddelete

        :stability: experimental
        '''
        return typing.cast("MediapackageVod", jsii.invoke(self, "toDeletePackagingGroup", []))

    @jsii.member(jsii_name="toDescribeAsset")
    def to_describe_asset(self) -> "MediapackageVod":
        '''(experimental) Grants permission to view the details of an asset in AWS Elemental MediaPackage.

        Access Level: Read

        https://docs.aws.amazon.com/mediapackage-vod/latest/apireference/assets-id.html#assets-idget

        :stability: experimental
        '''
        return typing.cast("MediapackageVod", jsii.invoke(self, "toDescribeAsset", []))

    @jsii.member(jsii_name="toDescribePackagingConfiguration")
    def to_describe_packaging_configuration(self) -> "MediapackageVod":
        '''(experimental) Grants permission to view the details of a packaging configuration in AWS Elemental MediaPackage.

        Access Level: Read

        https://docs.aws.amazon.com/mediapackage-vod/latest/apireference/packaging_configurations-id.html#packaging_configurations-idget

        :stability: experimental
        '''
        return typing.cast("MediapackageVod", jsii.invoke(self, "toDescribePackagingConfiguration", []))

    @jsii.member(jsii_name="toDescribePackagingGroup")
    def to_describe_packaging_group(self) -> "MediapackageVod":
        '''(experimental) Grants permission to view the details of a packaging group in AWS Elemental MediaPackage.

        Access Level: Read

        https://docs.aws.amazon.com/mediapackage-vod/latest/apireference/packaging_groups-id.html#packaging_groups-idget

        :stability: experimental
        '''
        return typing.cast("MediapackageVod", jsii.invoke(self, "toDescribePackagingGroup", []))

    @jsii.member(jsii_name="toListAssets")
    def to_list_assets(self) -> "MediapackageVod":
        '''(experimental) Grants permission to view a list of assets in AWS Elemental MediaPackage.

        Access Level: List

        https://docs.aws.amazon.com/mediapackage-vod/latest/apireference/assets.html#assetsget

        :stability: experimental
        '''
        return typing.cast("MediapackageVod", jsii.invoke(self, "toListAssets", []))

    @jsii.member(jsii_name="toListPackagingConfigurations")
    def to_list_packaging_configurations(self) -> "MediapackageVod":
        '''(experimental) Grants permission to view a list of packaging configurations in AWS Elemental MediaPackage.

        Access Level: List

        https://docs.aws.amazon.com/mediapackage-vod/latest/apireference/packaging_configurations.html#packaging_configurationsget

        :stability: experimental
        '''
        return typing.cast("MediapackageVod", jsii.invoke(self, "toListPackagingConfigurations", []))

    @jsii.member(jsii_name="toListPackagingGroups")
    def to_list_packaging_groups(self) -> "MediapackageVod":
        '''(experimental) Grants permission to view a list of packaging groups in AWS Elemental MediaPackage.

        Access Level: List

        https://docs.aws.amazon.com/mediapackage-vod/latest/apireference/packaging_groups.html#packaging_groupsget

        :stability: experimental
        '''
        return typing.cast("MediapackageVod", jsii.invoke(self, "toListPackagingGroups", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "MediapackageVod":
        '''(experimental) Grants permission to list the tags assigned to a PackagingGroup, PackagingConfiguration, or Asset.

        Access Level: Read

        https://docs.aws.amazon.com/mediapackage-vod/latest/apireference/tags-resource-arn.html#tags-resource-arnget

        :stability: experimental
        '''
        return typing.cast("MediapackageVod", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "MediapackageVod":
        '''(experimental) Grants permission to assign tags to a PackagingGroup, PackagingConfiguration, or Asset.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/mediapackage-vod/latest/apireference/tags-resource-arn.html#tags-resource-arnpost

        :stability: experimental
        '''
        return typing.cast("MediapackageVod", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "MediapackageVod":
        '''(experimental) Grants permission to delete tags from a PackagingGroup, PackagingConfiguration, or Asset.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/mediapackage-vod/latest/apireference/tags-resource-arn.html#tags-resource-arndelete

        :stability: experimental
        '''
        return typing.cast("MediapackageVod", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdatePackagingGroup")
    def to_update_packaging_group(self) -> "MediapackageVod":
        '''(experimental) Grants permission to update a packaging group in AWS Elemental MediaPackage.

        Access Level: Write

        https://docs.aws.amazon.com/mediapackage-vod/latest/apireference/packaging_groups-id.html#packaging_groups-idput

        :stability: experimental
        '''
        return typing.cast("MediapackageVod", jsii.invoke(self, "toUpdatePackagingGroup", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1ba91c3bd9e618bfe54e96af350c3966b08e0dfbe1b2c3f3b58f20ea3c9b40ad)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b6893d00a21e111ec0d00bfadc118de4dc4cda241991832b7cd72f9d7f66ff95)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Mediastore(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Mediastore",
):
    '''(experimental) Statement provider for service `mediastore <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awselementalmediastore.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `mediastore <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awselementalmediastore.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onContainer")
    def on_container(
        self,
        container_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Mediastore":
        '''(experimental) Adds a resource of type container to the statement.

        https://docs.aws.amazon.com/mediastore/latest/ug/containers.html

        :param container_name: - Identifier for the containerName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__31e4424a03b75ea8e6516ba7438ed003c23c5d7180095cdeb5ce4cb2819877ed)
            check_type(argname="argument container_name", value=container_name, expected_type=type_hints["container_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Mediastore", jsii.invoke(self, "onContainer", [container_name, account, region, partition]))

    @jsii.member(jsii_name="onFolder")
    def on_folder(
        self,
        container_name: builtins.str,
        folder_path: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Mediastore":
        '''(experimental) Adds a resource of type folder to the statement.

        https://docs.aws.amazon.com/mediastore/latest/ug/folders.html

        :param container_name: - Identifier for the containerName.
        :param folder_path: - Identifier for the folderPath.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9e202cf9b1b86d2e3a096209cfe0271ec5f283ed4d52b48aaff54d400bd5238b)
            check_type(argname="argument container_name", value=container_name, expected_type=type_hints["container_name"])
            check_type(argname="argument folder_path", value=folder_path, expected_type=type_hints["folder_path"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Mediastore", jsii.invoke(self, "onFolder", [container_name, folder_path, account, region, partition]))

    @jsii.member(jsii_name="onObject")
    def on_object(
        self,
        container_name: builtins.str,
        object_path: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Mediastore":
        '''(experimental) Adds a resource of type object to the statement.

        https://docs.aws.amazon.com/mediastore/latest/ug/objects.html

        :param container_name: - Identifier for the containerName.
        :param object_path: - Identifier for the objectPath.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__341b6bd918deed38d545388e261dbf4a3a43c1f982c71a3cace735d48ce38d90)
            check_type(argname="argument container_name", value=container_name, expected_type=type_hints["container_name"])
            check_type(argname="argument object_path", value=object_path, expected_type=type_hints["object_path"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Mediastore", jsii.invoke(self, "onObject", [container_name, object_path, account, region, partition]))

    @jsii.member(jsii_name="toCreateContainer")
    def to_create_container(self) -> "Mediastore":
        '''(experimental) Grants permission to create a container.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/mediastore/latest/apireference/API_CreateContainer.html

        :stability: experimental
        '''
        return typing.cast("Mediastore", jsii.invoke(self, "toCreateContainer", []))

    @jsii.member(jsii_name="toDeleteContainer")
    def to_delete_container(self) -> "Mediastore":
        '''(experimental) Grants permission to delete a container.

        Access Level: Write

        https://docs.aws.amazon.com/mediastore/latest/apireference/API_DeleteContainer.html

        :stability: experimental
        '''
        return typing.cast("Mediastore", jsii.invoke(self, "toDeleteContainer", []))

    @jsii.member(jsii_name="toDeleteContainerPolicy")
    def to_delete_container_policy(self) -> "Mediastore":
        '''(experimental) Grants permission to delete the access policy of a container.

        Access Level: Permissions management

        https://docs.aws.amazon.com/mediastore/latest/apireference/API_DeleteContainerPolicy.html

        :stability: experimental
        '''
        return typing.cast("Mediastore", jsii.invoke(self, "toDeleteContainerPolicy", []))

    @jsii.member(jsii_name="toDeleteCorsPolicy")
    def to_delete_cors_policy(self) -> "Mediastore":
        '''(experimental) Grants permission to delete the CORS policy from a container.

        Access Level: Write

        https://docs.aws.amazon.com/mediastore/latest/apireference/API_DeleteCorsPolicy.html

        :stability: experimental
        '''
        return typing.cast("Mediastore", jsii.invoke(self, "toDeleteCorsPolicy", []))

    @jsii.member(jsii_name="toDeleteLifecyclePolicy")
    def to_delete_lifecycle_policy(self) -> "Mediastore":
        '''(experimental) Grants permission to delete the lifecycle policy from a container.

        Access Level: Write

        https://docs.aws.amazon.com/mediastore/latest/apireference/API_DeleteLifecyclePolicy.html

        :stability: experimental
        '''
        return typing.cast("Mediastore", jsii.invoke(self, "toDeleteLifecyclePolicy", []))

    @jsii.member(jsii_name="toDeleteMetricPolicy")
    def to_delete_metric_policy(self) -> "Mediastore":
        '''(experimental) Grants permission to delete the metric policy from a container.

        Access Level: Write

        https://docs.aws.amazon.com/mediastore/latest/apireference/API_DeleteMetricPolicy.html

        :stability: experimental
        '''
        return typing.cast("Mediastore", jsii.invoke(self, "toDeleteMetricPolicy", []))

    @jsii.member(jsii_name="toDeleteObject")
    def to_delete_object(self) -> "Mediastore":
        '''(experimental) Grants permission to delete an object.

        Access Level: Write

        https://docs.aws.amazon.com/mediastore/latest/apireference/API_objstore_DeleteObject.html

        :stability: experimental
        '''
        return typing.cast("Mediastore", jsii.invoke(self, "toDeleteObject", []))

    @jsii.member(jsii_name="toDescribeContainer")
    def to_describe_container(self) -> "Mediastore":
        '''(experimental) Grants permission to retrieve details on a container.

        Access Level: List

        https://docs.aws.amazon.com/mediastore/latest/apireference/API_DescribeContainer.html

        :stability: experimental
        '''
        return typing.cast("Mediastore", jsii.invoke(self, "toDescribeContainer", []))

    @jsii.member(jsii_name="toDescribeObject")
    def to_describe_object(self) -> "Mediastore":
        '''(experimental) Grants permission to retrieve metadata for an object.

        Access Level: List

        https://docs.aws.amazon.com/mediastore/latest/apireference/API_objstore_DescribeObject.html

        :stability: experimental
        '''
        return typing.cast("Mediastore", jsii.invoke(self, "toDescribeObject", []))

    @jsii.member(jsii_name="toGetContainerPolicy")
    def to_get_container_policy(self) -> "Mediastore":
        '''(experimental) Grants permission to retrieve the access policy of a container.

        Access Level: Read

        https://docs.aws.amazon.com/mediastore/latest/apireference/API_GetContainerPolicy.html

        :stability: experimental
        '''
        return typing.cast("Mediastore", jsii.invoke(self, "toGetContainerPolicy", []))

    @jsii.member(jsii_name="toGetCorsPolicy")
    def to_get_cors_policy(self) -> "Mediastore":
        '''(experimental) Grants permission to retrieve the CORS policy of a container.

        Access Level: Read

        https://docs.aws.amazon.com/mediastore/latest/apireference/API_GetCorsPolicy.html

        :stability: experimental
        '''
        return typing.cast("Mediastore", jsii.invoke(self, "toGetCorsPolicy", []))

    @jsii.member(jsii_name="toGetLifecyclePolicy")
    def to_get_lifecycle_policy(self) -> "Mediastore":
        '''(experimental) Grants permission to retrieve the lifecycle policy that is assigned to a container.

        Access Level: Read

        https://docs.aws.amazon.com/mediastore/latest/apireference/API_GetLifecyclePolicy.html

        :stability: experimental
        '''
        return typing.cast("Mediastore", jsii.invoke(self, "toGetLifecyclePolicy", []))

    @jsii.member(jsii_name="toGetMetricPolicy")
    def to_get_metric_policy(self) -> "Mediastore":
        '''(experimental) Grants permission to retrieve the metric policy that is assigned to a container.

        Access Level: Read

        https://docs.aws.amazon.com/mediastore/latest/apireference/API_GetMetricPolicy.html

        :stability: experimental
        '''
        return typing.cast("Mediastore", jsii.invoke(self, "toGetMetricPolicy", []))

    @jsii.member(jsii_name="toGetObject")
    def to_get_object(self) -> "Mediastore":
        '''(experimental) Grants permission to retrieve an object.

        Access Level: Read

        https://docs.aws.amazon.com/mediastore/latest/apireference/API_objstore_GetObject.html

        :stability: experimental
        '''
        return typing.cast("Mediastore", jsii.invoke(self, "toGetObject", []))

    @jsii.member(jsii_name="toListContainers")
    def to_list_containers(self) -> "Mediastore":
        '''(experimental) Grants permission to retrieve a list of containers in the current account.

        Access Level: List

        https://docs.aws.amazon.com/mediastore/latest/apireference/API_ListContainers.html

        :stability: experimental
        '''
        return typing.cast("Mediastore", jsii.invoke(self, "toListContainers", []))

    @jsii.member(jsii_name="toListItems")
    def to_list_items(self) -> "Mediastore":
        '''(experimental) Grants permission to retrieve a list of objects and subfolders that are stored in a folder.

        Access Level: List

        https://docs.aws.amazon.com/mediastore/latest/apireference/API_objstore_ListItems.html

        :stability: experimental
        '''
        return typing.cast("Mediastore", jsii.invoke(self, "toListItems", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Mediastore":
        '''(experimental) Grants permission to list tags on a container.

        Access Level: Read

        https://docs.aws.amazon.com/mediastore/latest/apireference/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("Mediastore", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toPutContainerPolicy")
    def to_put_container_policy(self) -> "Mediastore":
        '''(experimental) Grants permission to create or replace the access policy of a container.

        Access Level: Permissions management

        https://docs.aws.amazon.com/mediastore/latest/apireference/API_PutContainerPolicy.html

        :stability: experimental
        '''
        return typing.cast("Mediastore", jsii.invoke(self, "toPutContainerPolicy", []))

    @jsii.member(jsii_name="toPutCorsPolicy")
    def to_put_cors_policy(self) -> "Mediastore":
        '''(experimental) Grants permission to add or modify the CORS policy of a container.

        Access Level: Write

        https://docs.aws.amazon.com/mediastore/latest/apireference/API_PutCorsPolicy.html

        :stability: experimental
        '''
        return typing.cast("Mediastore", jsii.invoke(self, "toPutCorsPolicy", []))

    @jsii.member(jsii_name="toPutLifecyclePolicy")
    def to_put_lifecycle_policy(self) -> "Mediastore":
        '''(experimental) Grants permission to add or modify the lifecycle policy that is assigned to a container.

        Access Level: Write

        https://docs.aws.amazon.com/mediastore/latest/apireference/API_PutLifecyclePolicy.html

        :stability: experimental
        '''
        return typing.cast("Mediastore", jsii.invoke(self, "toPutLifecyclePolicy", []))

    @jsii.member(jsii_name="toPutMetricPolicy")
    def to_put_metric_policy(self) -> "Mediastore":
        '''(experimental) Grants permission to add or modify the metric policy that is assigned to a container.

        Access Level: Write

        https://docs.aws.amazon.com/mediastore/latest/apireference/API_PutMetricPolicy.html

        :stability: experimental
        '''
        return typing.cast("Mediastore", jsii.invoke(self, "toPutMetricPolicy", []))

    @jsii.member(jsii_name="toPutObject")
    def to_put_object(self) -> "Mediastore":
        '''(experimental) Grants permission to upload an object.

        Access Level: Write

        https://docs.aws.amazon.com/mediastore/latest/apireference/API_objstore_PutObject.html

        :stability: experimental
        '''
        return typing.cast("Mediastore", jsii.invoke(self, "toPutObject", []))

    @jsii.member(jsii_name="toStartAccessLogging")
    def to_start_access_logging(self) -> "Mediastore":
        '''(experimental) Grants permission to start access logging on a container.

        Access Level: Write

        Dependent actions:

        - iam:PassRole

        https://docs.aws.amazon.com/mediastore/latest/apireference/API_StartAccessLogging.html

        :stability: experimental
        '''
        return typing.cast("Mediastore", jsii.invoke(self, "toStartAccessLogging", []))

    @jsii.member(jsii_name="toStopAccessLogging")
    def to_stop_access_logging(self) -> "Mediastore":
        '''(experimental) Grants permission to stop access logging on a container.

        Access Level: Write

        https://docs.aws.amazon.com/mediastore/latest/apireference/API_StopAccessLogging.html

        :stability: experimental
        '''
        return typing.cast("Mediastore", jsii.invoke(self, "toStopAccessLogging", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Mediastore":
        '''(experimental) Grants permission to add tags to a container.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/mediastore/latest/apireference/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("Mediastore", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Mediastore":
        '''(experimental) Grants permission to remove tags from a container.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/mediastore/latest/apireference/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("Mediastore", jsii.invoke(self, "toUntagResource", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c18e34ae347848d24b618eb871577a6247fd748bf885a683e07155482f908e7e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2580916c9a5259c74e97e222dd075ae67d52c07d7304a5b6ac24f61f742fb47a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Mediatailor(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Mediatailor",
):
    '''(experimental) Statement provider for service `mediatailor <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awselementalmediatailor.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `mediatailor <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awselementalmediatailor.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onChannel")
    def on_channel(
        self,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Mediatailor":
        '''(experimental) Adds a resource of type channel to the statement.

        https://docs.aws.amazon.com/mediatailor/latest/apireference/channel-channelname.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a5d0a97a3ee9d0dbccd596eddf442ff1c23e4111f954f392518db50a4ffc5571)
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Mediatailor", jsii.invoke(self, "onChannel", [resource_id, account, region, partition]))

    @jsii.member(jsii_name="onLiveSource")
    def on_live_source(
        self,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Mediatailor":
        '''(experimental) Adds a resource of type liveSource to the statement.

        https://docs.aws.amazon.com/mediatailor/latest/apireference/sourcelocation-sourcelocationname-livesource-livesourcename.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7f3819a6545fd51ad9af62e64e93dc8f70eca11a0c5dcb901e7b66e680530573)
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Mediatailor", jsii.invoke(self, "onLiveSource", [resource_id, account, region, partition]))

    @jsii.member(jsii_name="onPlaybackConfiguration")
    def on_playback_configuration(
        self,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Mediatailor":
        '''(experimental) Adds a resource of type playbackConfiguration to the statement.

        https://docs.aws.amazon.com/mediatailor/latest/apireference/playbackconfiguration.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__71523bfde26b383811344b4af13303e0b3a7213cb8ee9ab2e1bfc9f9d2796be4)
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Mediatailor", jsii.invoke(self, "onPlaybackConfiguration", [resource_id, account, region, partition]))

    @jsii.member(jsii_name="onPrefetchSchedule")
    def on_prefetch_schedule(
        self,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Mediatailor":
        '''(experimental) Adds a resource of type prefetchSchedule to the statement.

        https://docs.aws.amazon.com/mediatailor/latest/apireference/prefetchschedule-playbackconfigurationname-name.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5404e82b6abd754f88a8250eefe2313d75acb61d408bd071b4a72d33609c8eb7)
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Mediatailor", jsii.invoke(self, "onPrefetchSchedule", [resource_id, account, region, partition]))

    @jsii.member(jsii_name="onProgram")
    def on_program(
        self,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Mediatailor":
        '''(experimental) Adds a resource of type program to the statement.

        https://docs.aws.amazon.com/mediatailor/latest/apireference/channel-channelname-program-programname.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ade52afd83ae273ae5853034180fb67eabe0fc43c857edad4479bba962fb4f81)
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Mediatailor", jsii.invoke(self, "onProgram", [resource_id, account, region, partition]))

    @jsii.member(jsii_name="onSourceLocation")
    def on_source_location(
        self,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Mediatailor":
        '''(experimental) Adds a resource of type sourceLocation to the statement.

        https://docs.aws.amazon.com/mediatailor/latest/apireference/sourcelocation-sourcelocationname.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__67da46699391675c9052f719f54597a68cc005822b6fb0a346e10f0224c1d182)
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Mediatailor", jsii.invoke(self, "onSourceLocation", [resource_id, account, region, partition]))

    @jsii.member(jsii_name="onVodSource")
    def on_vod_source(
        self,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Mediatailor":
        '''(experimental) Adds a resource of type vodSource to the statement.

        https://docs.aws.amazon.com/mediatailor/latest/apireference/sourcelocation-sourcelocationname-vodsource-vodsourcename.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__44d3d4ea23760277d22f7d3c53e4423595f1a3c99484974eb803b32e24030200)
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Mediatailor", jsii.invoke(self, "onVodSource", [resource_id, account, region, partition]))

    @jsii.member(jsii_name="toConfigureLogsForPlaybackConfiguration")
    def to_configure_logs_for_playback_configuration(self) -> "Mediatailor":
        '''(experimental) Grants permission to configure logs for a playback configuration.

        Access Level: Write

        Dependent actions:

        - iam:CreateServiceLinkedRole

        https://docs.aws.amazon.com/mediatailor/latest/apireference/configurelogs-playbackconfiguration.html

        :stability: experimental
        '''
        return typing.cast("Mediatailor", jsii.invoke(self, "toConfigureLogsForPlaybackConfiguration", []))

    @jsii.member(jsii_name="toCreateChannel")
    def to_create_channel(self) -> "Mediatailor":
        '''(experimental) Grants permission to create a new channel.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/mediatailor/latest/apireference/channel-channelname.html

        :stability: experimental
        '''
        return typing.cast("Mediatailor", jsii.invoke(self, "toCreateChannel", []))

    @jsii.member(jsii_name="toCreateLiveSource")
    def to_create_live_source(self) -> "Mediatailor":
        '''(experimental) Grants permission to create a new live source on the source location with the specified source location name.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/mediatailor/latest/apireference/sourcelocation-sourcelocationname-livesource-livesourcename.html

        :stability: experimental
        '''
        return typing.cast("Mediatailor", jsii.invoke(self, "toCreateLiveSource", []))

    @jsii.member(jsii_name="toCreatePrefetchSchedule")
    def to_create_prefetch_schedule(self) -> "Mediatailor":
        '''(experimental) Grants permission to create a prefetch schedule for the playback configuration with the specified playback configuration name.

        Access Level: Write

        https://docs.aws.amazon.com/mediatailor/latest/apireference/prefetchschedule-playbackconfigurationname-name.html

        :stability: experimental
        '''
        return typing.cast("Mediatailor", jsii.invoke(self, "toCreatePrefetchSchedule", []))

    @jsii.member(jsii_name="toCreateProgram")
    def to_create_program(self) -> "Mediatailor":
        '''(experimental) Grants permission to create a new program on the channel with the specified channel name.

        Access Level: Write

        https://docs.aws.amazon.com/mediatailor/latest/apireference/channel-channelname-program-programname.html

        :stability: experimental
        '''
        return typing.cast("Mediatailor", jsii.invoke(self, "toCreateProgram", []))

    @jsii.member(jsii_name="toCreateSourceLocation")
    def to_create_source_location(self) -> "Mediatailor":
        '''(experimental) Grants permission to create a new source location.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/mediatailor/latest/apireference/sourcelocation-sourcelocationname.html

        :stability: experimental
        '''
        return typing.cast("Mediatailor", jsii.invoke(self, "toCreateSourceLocation", []))

    @jsii.member(jsii_name="toCreateVodSource")
    def to_create_vod_source(self) -> "Mediatailor":
        '''(experimental) Grants permission to create a new VOD source on the source location with the specified source location name.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/mediatailor/latest/apireference/sourcelocation-sourcelocationname-vodsource-vodsourcename.html

        :stability: experimental
        '''
        return typing.cast("Mediatailor", jsii.invoke(self, "toCreateVodSource", []))

    @jsii.member(jsii_name="toDeleteChannel")
    def to_delete_channel(self) -> "Mediatailor":
        '''(experimental) Grants permission to delete the channel with the specified channel name.

        Access Level: Write

        https://docs.aws.amazon.com/mediatailor/latest/apireference/channel-channelname.html

        :stability: experimental
        '''
        return typing.cast("Mediatailor", jsii.invoke(self, "toDeleteChannel", []))

    @jsii.member(jsii_name="toDeleteChannelPolicy")
    def to_delete_channel_policy(self) -> "Mediatailor":
        '''(experimental) Grants permission to delete the IAM policy on the channel with the specified channel name.

        Access Level: Permissions management

        https://docs.aws.amazon.com/mediatailor/latest/apireference/channel-channelname-policy.html

        :stability: experimental
        '''
        return typing.cast("Mediatailor", jsii.invoke(self, "toDeleteChannelPolicy", []))

    @jsii.member(jsii_name="toDeleteLiveSource")
    def to_delete_live_source(self) -> "Mediatailor":
        '''(experimental) Grants permission to delete the live source with the specified live source name on the source location with the specified source location name.

        Access Level: Write

        https://docs.aws.amazon.com/mediatailor/latest/apireference/sourcelocation-sourcelocationname-livesource-livesourcename.html

        :stability: experimental
        '''
        return typing.cast("Mediatailor", jsii.invoke(self, "toDeleteLiveSource", []))

    @jsii.member(jsii_name="toDeletePlaybackConfiguration")
    def to_delete_playback_configuration(self) -> "Mediatailor":
        '''(experimental) Grants permission to delete the specified playback configuration.

        Access Level: Write

        https://docs.aws.amazon.com/mediatailor/latest/apireference/playbackconfiguration-name.html

        :stability: experimental
        '''
        return typing.cast("Mediatailor", jsii.invoke(self, "toDeletePlaybackConfiguration", []))

    @jsii.member(jsii_name="toDeletePrefetchSchedule")
    def to_delete_prefetch_schedule(self) -> "Mediatailor":
        '''(experimental) Grants permission to delete a prefetch schedule for a playback configuration with the specified prefetch schedule name.

        Access Level: Write

        https://docs.aws.amazon.com/mediatailor/latest/apireference/prefetchschedule-playbackconfigurationname-name.html

        :stability: experimental
        '''
        return typing.cast("Mediatailor", jsii.invoke(self, "toDeletePrefetchSchedule", []))

    @jsii.member(jsii_name="toDeleteProgram")
    def to_delete_program(self) -> "Mediatailor":
        '''(experimental) Grants permission to delete the program with the specified program name on the channel with the specified channel name.

        Access Level: Write

        https://docs.aws.amazon.com/mediatailor/latest/apireference/channel-channelname-program-programname.html

        :stability: experimental
        '''
        return typing.cast("Mediatailor", jsii.invoke(self, "toDeleteProgram", []))

    @jsii.member(jsii_name="toDeleteSourceLocation")
    def to_delete_source_location(self) -> "Mediatailor":
        '''(experimental) Grants permission to delete the source location with the specified source location name.

        Access Level: Write

        https://docs.aws.amazon.com/mediatailor/latest/apireference/sourcelocation-sourcelocationname.html

        :stability: experimental
        '''
        return typing.cast("Mediatailor", jsii.invoke(self, "toDeleteSourceLocation", []))

    @jsii.member(jsii_name="toDeleteVodSource")
    def to_delete_vod_source(self) -> "Mediatailor":
        '''(experimental) Grants permission to delete the VOD source with the specified VOD source name on the source location with the specified source location name.

        Access Level: Write

        https://docs.aws.amazon.com/mediatailor/latest/apireference/sourcelocation-sourcelocationname-vodsource-vodsourcename.html

        :stability: experimental
        '''
        return typing.cast("Mediatailor", jsii.invoke(self, "toDeleteVodSource", []))

    @jsii.member(jsii_name="toDescribeChannel")
    def to_describe_channel(self) -> "Mediatailor":
        '''(experimental) Grants permission to retrieve the channel with the specified channel name.

        Access Level: Read

        https://docs.aws.amazon.com/mediatailor/latest/apireference/channel-channelname.html

        :stability: experimental
        '''
        return typing.cast("Mediatailor", jsii.invoke(self, "toDescribeChannel", []))

    @jsii.member(jsii_name="toDescribeLiveSource")
    def to_describe_live_source(self) -> "Mediatailor":
        '''(experimental) Grants permission to retrieve the live source with the specified live source name on the source location with the specified source location name.

        Access Level: Read

        https://docs.aws.amazon.com/mediatailor/latest/apireference/sourcelocation-sourcelocationname-livesource-livesourcename.html

        :stability: experimental
        '''
        return typing.cast("Mediatailor", jsii.invoke(self, "toDescribeLiveSource", []))

    @jsii.member(jsii_name="toDescribeProgram")
    def to_describe_program(self) -> "Mediatailor":
        '''(experimental) Grants permission to retrieve the program with the specified program name on the channel with the specified channel name.

        Access Level: Read

        https://docs.aws.amazon.com/mediatailor/latest/apireference/channel-channelname-program-programname.html

        :stability: experimental
        '''
        return typing.cast("Mediatailor", jsii.invoke(self, "toDescribeProgram", []))

    @jsii.member(jsii_name="toDescribeSourceLocation")
    def to_describe_source_location(self) -> "Mediatailor":
        '''(experimental) Grants permission to retrieve the source location with the specified source location name.

        Access Level: Read

        https://docs.aws.amazon.com/mediatailor/latest/apireference/sourcelocation-sourcelocationname.html

        :stability: experimental
        '''
        return typing.cast("Mediatailor", jsii.invoke(self, "toDescribeSourceLocation", []))

    @jsii.member(jsii_name="toDescribeVodSource")
    def to_describe_vod_source(self) -> "Mediatailor":
        '''(experimental) Grants permission to retrieve the VOD source with the specified VOD source name on the source location with the specified source location name.

        Access Level: Read

        https://docs.aws.amazon.com/mediatailor/latest/apireference/sourcelocation-sourcelocationname-vodsource-vodsourcename.html

        :stability: experimental
        '''
        return typing.cast("Mediatailor", jsii.invoke(self, "toDescribeVodSource", []))

    @jsii.member(jsii_name="toGetChannelPolicy")
    def to_get_channel_policy(self) -> "Mediatailor":
        '''(experimental) Grants permission to read the IAM policy on the channel with the specified channel name.

        Access Level: Read

        https://docs.aws.amazon.com/mediatailor/latest/apireference/channel-channelname-policy.html

        :stability: experimental
        '''
        return typing.cast("Mediatailor", jsii.invoke(self, "toGetChannelPolicy", []))

    @jsii.member(jsii_name="toGetChannelSchedule")
    def to_get_channel_schedule(self) -> "Mediatailor":
        '''(experimental) Grants permission to retrieve the schedule of programs on the channel with the specified channel name.

        Access Level: Read

        https://docs.aws.amazon.com/mediatailor/latest/apireference/channel-channelname-schedule.html

        :stability: experimental
        '''
        return typing.cast("Mediatailor", jsii.invoke(self, "toGetChannelSchedule", []))

    @jsii.member(jsii_name="toGetPlaybackConfiguration")
    def to_get_playback_configuration(self) -> "Mediatailor":
        '''(experimental) Grants permission to retrieve the configuration for the specified name.

        Access Level: Read

        https://docs.aws.amazon.com/mediatailor/latest/apireference/playbackconfiguration-name.html

        :stability: experimental
        '''
        return typing.cast("Mediatailor", jsii.invoke(self, "toGetPlaybackConfiguration", []))

    @jsii.member(jsii_name="toGetPrefetchSchedule")
    def to_get_prefetch_schedule(self) -> "Mediatailor":
        '''(experimental) Grants permission to retrieve prefetch schedule for a playback configuration with the specified prefetch schedule name.

        Access Level: Read

        https://docs.aws.amazon.com/mediatailor/latest/apireference/prefetchschedule-playbackconfigurationname-name.html

        :stability: experimental
        '''
        return typing.cast("Mediatailor", jsii.invoke(self, "toGetPrefetchSchedule", []))

    @jsii.member(jsii_name="toListAlerts")
    def to_list_alerts(self) -> "Mediatailor":
        '''(experimental) Grants permission to retrieve the list of alerts on a resource.

        Access Level: Read

        https://docs.aws.amazon.com/mediatailor/latest/apireference/alerts.html

        :stability: experimental
        '''
        return typing.cast("Mediatailor", jsii.invoke(self, "toListAlerts", []))

    @jsii.member(jsii_name="toListChannels")
    def to_list_channels(self) -> "Mediatailor":
        '''(experimental) Grants permission to retrieve the list of existing channels.

        Access Level: Read

        https://docs.aws.amazon.com/mediatailor/latest/apireference/channels.html

        :stability: experimental
        '''
        return typing.cast("Mediatailor", jsii.invoke(self, "toListChannels", []))

    @jsii.member(jsii_name="toListLiveSources")
    def to_list_live_sources(self) -> "Mediatailor":
        '''(experimental) Grants permission to retrieve the list of existing live sources on the source location with the specified source location name.

        Access Level: Read

        https://docs.aws.amazon.com/mediatailor/latest/apireference/sourcelocation-sourcelocationname-livesources.html

        :stability: experimental
        '''
        return typing.cast("Mediatailor", jsii.invoke(self, "toListLiveSources", []))

    @jsii.member(jsii_name="toListPlaybackConfigurations")
    def to_list_playback_configurations(self) -> "Mediatailor":
        '''(experimental) Grants permission to retrieve the list of available configurations.

        Access Level: List

        https://docs.aws.amazon.com/mediatailor/latest/apireference/playbackconfigurations.html

        :stability: experimental
        '''
        return typing.cast("Mediatailor", jsii.invoke(self, "toListPlaybackConfigurations", []))

    @jsii.member(jsii_name="toListPrefetchSchedules")
    def to_list_prefetch_schedules(self) -> "Mediatailor":
        '''(experimental) Grants permission to retrieve the list of prefetch schedules for a playback configuration.

        Access Level: List

        https://docs.aws.amazon.com/mediatailor/latest/apireference/prefetchschedule-playbackconfigurationname.html

        :stability: experimental
        '''
        return typing.cast("Mediatailor", jsii.invoke(self, "toListPrefetchSchedules", []))

    @jsii.member(jsii_name="toListSourceLocations")
    def to_list_source_locations(self) -> "Mediatailor":
        '''(experimental) Grants permission to retrieve the list of existing source locations.

        Access Level: Read

        https://docs.aws.amazon.com/mediatailor/latest/apireference/sourcelocations.html

        :stability: experimental
        '''
        return typing.cast("Mediatailor", jsii.invoke(self, "toListSourceLocations", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Mediatailor":
        '''(experimental) Grants permission to list the tags assigned to the specified playback configuration resource.

        Access Level: Read

        https://docs.aws.amazon.com/mediatailor/latest/apireference/tags-resourcearn.html

        :stability: experimental
        '''
        return typing.cast("Mediatailor", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toListVodSources")
    def to_list_vod_sources(self) -> "Mediatailor":
        '''(experimental) Grants permission to retrieve the list of existing VOD sources on the source location with the specified source location name.

        Access Level: Read

        https://docs.aws.amazon.com/mediatailor/latest/apireference/sourcelocation-sourcelocationname-vodsources.html

        :stability: experimental
        '''
        return typing.cast("Mediatailor", jsii.invoke(self, "toListVodSources", []))

    @jsii.member(jsii_name="toPutChannelPolicy")
    def to_put_channel_policy(self) -> "Mediatailor":
        '''(experimental) Grants permission to set the IAM policy on the channel with the specified channel name.

        Access Level: Permissions management

        https://docs.aws.amazon.com/mediatailor/latest/apireference/channel-channelname-policy.html

        :stability: experimental
        '''
        return typing.cast("Mediatailor", jsii.invoke(self, "toPutChannelPolicy", []))

    @jsii.member(jsii_name="toPutPlaybackConfiguration")
    def to_put_playback_configuration(self) -> "Mediatailor":
        '''(experimental) Grants permission to add a new configuration.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/mediatailor/latest/apireference/playbackconfiguration.html

        :stability: experimental
        '''
        return typing.cast("Mediatailor", jsii.invoke(self, "toPutPlaybackConfiguration", []))

    @jsii.member(jsii_name="toStartChannel")
    def to_start_channel(self) -> "Mediatailor":
        '''(experimental) Grants permission to start the channel with the specified channel name.

        Access Level: Write

        https://docs.aws.amazon.com/mediatailor/latest/apireference/channel-channelname-start.html

        :stability: experimental
        '''
        return typing.cast("Mediatailor", jsii.invoke(self, "toStartChannel", []))

    @jsii.member(jsii_name="toStopChannel")
    def to_stop_channel(self) -> "Mediatailor":
        '''(experimental) Grants permission to stop the channel with the specified channel name.

        Access Level: Write

        https://docs.aws.amazon.com/mediatailor/latest/apireference/channel-channelname-stop.html

        :stability: experimental
        '''
        return typing.cast("Mediatailor", jsii.invoke(self, "toStopChannel", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Mediatailor":
        '''(experimental) Grants permission to add tags to the specified playback configuration resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/mediatailor/latest/apireference/tags-resourcearn.html

        :stability: experimental
        '''
        return typing.cast("Mediatailor", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Mediatailor":
        '''(experimental) Grants permission to remove tags from the specified playback configuration resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/mediatailor/latest/apireference/tags-resourcearn.html

        :stability: experimental
        '''
        return typing.cast("Mediatailor", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateChannel")
    def to_update_channel(self) -> "Mediatailor":
        '''(experimental) Grants permission to update the channel with the specified channel name.

        Access Level: Write

        https://docs.aws.amazon.com/mediatailor/latest/apireference/channel-channelname.html

        :stability: experimental
        '''
        return typing.cast("Mediatailor", jsii.invoke(self, "toUpdateChannel", []))

    @jsii.member(jsii_name="toUpdateLiveSource")
    def to_update_live_source(self) -> "Mediatailor":
        '''(experimental) Grants permission to update the live source with the specified live source name on the source location with the specified source location name.

        Access Level: Write

        https://docs.aws.amazon.com/mediatailor/latest/apireference/sourcelocation-sourcelocationname-livesource-livesourcename.html

        :stability: experimental
        '''
        return typing.cast("Mediatailor", jsii.invoke(self, "toUpdateLiveSource", []))

    @jsii.member(jsii_name="toUpdateSourceLocation")
    def to_update_source_location(self) -> "Mediatailor":
        '''(experimental) Grants permission to update the source location with the specified source location name.

        Access Level: Write

        https://docs.aws.amazon.com/mediatailor/latest/apireference/sourcelocation-sourcelocationname.html

        :stability: experimental
        '''
        return typing.cast("Mediatailor", jsii.invoke(self, "toUpdateSourceLocation", []))

    @jsii.member(jsii_name="toUpdateVodSource")
    def to_update_vod_source(self) -> "Mediatailor":
        '''(experimental) Grants permission to update the VOD source with the specified VOD source name on the source location with the specified source location name.

        Access Level: Write

        https://docs.aws.amazon.com/mediatailor/latest/apireference/sourcelocation-sourcelocationname-vodsource-vodsourcename.html

        :stability: experimental
        '''
        return typing.cast("Mediatailor", jsii.invoke(self, "toUpdateVodSource", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b4887deb6b7dc1065feaf34712618580a7ec05aae7b2a79f40a1dda03babb1a0)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5c0452c7a0c70e5821dc61b0ccfc889919a4cebafdf0d62b13562f2ea5252c1a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Memorydb(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Memorydb",
):
    '''(experimental) Statement provider for service `memorydb <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonmemorydb.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `memorydb <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonmemorydb.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onAcl")
    def on_acl(
        self,
        acl_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Memorydb":
        '''(experimental) Adds a resource of type acl to the statement.

        https://docs.aws.amazon.com/memorydb/latest/devguide/WhatIs.Components.html

        :param acl_name: - Identifier for the aclName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__09f44752b36922d38ecf075355f4c9d03da85ba9e422edcba1392816339c26dd)
            check_type(argname="argument acl_name", value=acl_name, expected_type=type_hints["acl_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Memorydb", jsii.invoke(self, "onAcl", [acl_name, account, region, partition]))

    @jsii.member(jsii_name="onCluster")
    def on_cluster(
        self,
        cluster_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Memorydb":
        '''(experimental) Adds a resource of type cluster to the statement.

        https://docs.aws.amazon.com/memorydb/latest/devguide/WhatIs.Components.html

        :param cluster_name: - Identifier for the clusterName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1fb8b319a6154e1be0106eee55db2155b98ce61a20d82aadf0d017cd7a97f05a)
            check_type(argname="argument cluster_name", value=cluster_name, expected_type=type_hints["cluster_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Memorydb", jsii.invoke(self, "onCluster", [cluster_name, account, region, partition]))

    @jsii.member(jsii_name="onParametergroup")
    def on_parametergroup(
        self,
        parameter_group_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Memorydb":
        '''(experimental) Adds a resource of type parametergroup to the statement.

        https://docs.aws.amazon.com/memorydb/latest/devguide/WhatIs.Components.html

        :param parameter_group_name: - Identifier for the parameterGroupName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7d4d01a85fb04da799dd44211ebb6593460535184186be481f62c138816a6798)
            check_type(argname="argument parameter_group_name", value=parameter_group_name, expected_type=type_hints["parameter_group_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Memorydb", jsii.invoke(self, "onParametergroup", [parameter_group_name, account, region, partition]))

    @jsii.member(jsii_name="onSnapshot")
    def on_snapshot(
        self,
        snapshot_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Memorydb":
        '''(experimental) Adds a resource of type snapshot to the statement.

        https://docs.aws.amazon.com/memorydb/latest/devguide/WhatIs.Components.html

        :param snapshot_name: - Identifier for the snapshotName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9ed14ece7ad7f03cc48782bb03ca41881f1ba307aaadfa35ab115b7e8410dec7)
            check_type(argname="argument snapshot_name", value=snapshot_name, expected_type=type_hints["snapshot_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Memorydb", jsii.invoke(self, "onSnapshot", [snapshot_name, account, region, partition]))

    @jsii.member(jsii_name="onSubnetgroup")
    def on_subnetgroup(
        self,
        subnet_group_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Memorydb":
        '''(experimental) Adds a resource of type subnetgroup to the statement.

        https://docs.aws.amazon.com/memorydb/latest/devguide/WhatIs.Components.html

        :param subnet_group_name: - Identifier for the subnetGroupName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fc3dbad76ebbc00e8479a439f1ab86eb44084ed84d540b7315cb151f41e90edd)
            check_type(argname="argument subnet_group_name", value=subnet_group_name, expected_type=type_hints["subnet_group_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Memorydb", jsii.invoke(self, "onSubnetgroup", [subnet_group_name, account, region, partition]))

    @jsii.member(jsii_name="onUser")
    def on_user(
        self,
        user_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Memorydb":
        '''(experimental) Adds a resource of type user to the statement.

        https://docs.aws.amazon.com/memorydb/latest/devguide/WhatIs.Components.html

        :param user_name: - Identifier for the userName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1b8b3856e523c510a5f1fc9e2a8abb63bc9e8c8a93933430f4c3acad7c4eec58)
            check_type(argname="argument user_name", value=user_name, expected_type=type_hints["user_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Memorydb", jsii.invoke(self, "onUser", [user_name, account, region, partition]))

    @jsii.member(jsii_name="toBatchUpdateCluster")
    def to_batch_update_cluster(self) -> "Memorydb":
        '''(experimental) Grants permissions to apply service updates.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        Dependent actions:

        - ec2:CreateNetworkInterface
        - ec2:DeleteNetworkInterface
        - ec2:DescribeNetworkInterfaces
        - ec2:DescribeSubnets
        - ec2:DescribeVpcs
        - s3:GetObject

        https://docs.aws.amazon.com/memorydb/latest/APIReference/API_BatchUpdateCluster.html

        :stability: experimental
        '''
        return typing.cast("Memorydb", jsii.invoke(self, "toBatchUpdateCluster", []))

    @jsii.member(jsii_name="toCopySnapshot")
    def to_copy_snapshot(self) -> "Memorydb":
        '''(experimental) Grants permissions to make a copy of an existing snapshot.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()
        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - memorydb:TagResource
        - s3:DeleteObject
        - s3:GetBucketAcl
        - s3:PutObject

        https://docs.aws.amazon.com/memorydb/latest/APIReference/API_CopySnapshot.html

        :stability: experimental
        '''
        return typing.cast("Memorydb", jsii.invoke(self, "toCopySnapshot", []))

    @jsii.member(jsii_name="toCreateAcl")
    def to_create_acl(self) -> "Memorydb":
        '''(experimental) Grants permissions to create a new access control list.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()
        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - memorydb:TagResource

        https://docs.aws.amazon.com/memorydb/latest/APIReference/API_CreateAcl.html

        :stability: experimental
        '''
        return typing.cast("Memorydb", jsii.invoke(self, "toCreateAcl", []))

    @jsii.member(jsii_name="toCreateCluster")
    def to_create_cluster(self) -> "Memorydb":
        '''(experimental) Grants permissions to create a cluster.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()
        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - ec2:CreateNetworkInterface
        - ec2:DeleteNetworkInterface
        - ec2:DescribeNetworkInterfaces
        - ec2:DescribeSubnets
        - ec2:DescribeVpcs
        - memorydb:TagResource
        - s3:GetObject

        https://docs.aws.amazon.com/memorydb/latest/APIReference/API_CreateCluster.html

        :stability: experimental
        '''
        return typing.cast("Memorydb", jsii.invoke(self, "toCreateCluster", []))

    @jsii.member(jsii_name="toCreateParameterGroup")
    def to_create_parameter_group(self) -> "Memorydb":
        '''(experimental) Grants permissions to create a new parameter group.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - memorydb:TagResource

        https://docs.aws.amazon.com/memorydb/latest/APIReference/API_CreateParameterGroup.html

        :stability: experimental
        '''
        return typing.cast("Memorydb", jsii.invoke(self, "toCreateParameterGroup", []))

    @jsii.member(jsii_name="toCreateSnapshot")
    def to_create_snapshot(self) -> "Memorydb":
        '''(experimental) Grants permissions to create a backup of a cluster at the current point in time.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()
        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - memorydb:TagResource
        - s3:DeleteObject
        - s3:GetBucketAcl
        - s3:PutObject

        https://docs.aws.amazon.com/memorydb/latest/APIReference/API_CreateSnapshot.html

        :stability: experimental
        '''
        return typing.cast("Memorydb", jsii.invoke(self, "toCreateSnapshot", []))

    @jsii.member(jsii_name="toCreateSubnetGroup")
    def to_create_subnet_group(self) -> "Memorydb":
        '''(experimental) Grants permissions to create a new subnet group.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - memorydb:TagResource

        https://docs.aws.amazon.com/memorydb/latest/APIReference/API_CreateSubnetGroup.html

        :stability: experimental
        '''
        return typing.cast("Memorydb", jsii.invoke(self, "toCreateSubnetGroup", []))

    @jsii.member(jsii_name="toCreateUser")
    def to_create_user(self) -> "Memorydb":
        '''(experimental) Grants permissions to create a new user.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - memorydb:TagResource

        https://docs.aws.amazon.com/memorydb/latest/APIReference/API_CreateUser.html

        :stability: experimental
        '''
        return typing.cast("Memorydb", jsii.invoke(self, "toCreateUser", []))

    @jsii.member(jsii_name="toDeleteAcl")
    def to_delete_acl(self) -> "Memorydb":
        '''(experimental) Grants permissions to delete an access control list.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/memorydb/latest/APIReference/API_DeleteAcl.html

        :stability: experimental
        '''
        return typing.cast("Memorydb", jsii.invoke(self, "toDeleteAcl", []))

    @jsii.member(jsii_name="toDeleteCluster")
    def to_delete_cluster(self) -> "Memorydb":
        '''(experimental) Grants permissions to delete a previously provisioned cluster.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        Dependent actions:

        - ec2:CreateNetworkInterface
        - ec2:DeleteNetworkInterface
        - ec2:DescribeNetworkInterfaces
        - ec2:DescribeSubnets
        - ec2:DescribeVpcs

        https://docs.aws.amazon.com/memorydb/latest/APIReference/API_DeleteCluster.html

        :stability: experimental
        '''
        return typing.cast("Memorydb", jsii.invoke(self, "toDeleteCluster", []))

    @jsii.member(jsii_name="toDeleteParameterGroup")
    def to_delete_parameter_group(self) -> "Memorydb":
        '''(experimental) Grants permissions to delete a parameter group.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/memorydb/latest/APIReference/API_DeleteParameterGroup.html

        :stability: experimental
        '''
        return typing.cast("Memorydb", jsii.invoke(self, "toDeleteParameterGroup", []))

    @jsii.member(jsii_name="toDeleteSnapshot")
    def to_delete_snapshot(self) -> "Memorydb":
        '''(experimental) Grants permissions to delete a snapshot.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/memorydb/latest/APIReference/API_DeleteSnapshot.html

        :stability: experimental
        '''
        return typing.cast("Memorydb", jsii.invoke(self, "toDeleteSnapshot", []))

    @jsii.member(jsii_name="toDeleteSubnetGroup")
    def to_delete_subnet_group(self) -> "Memorydb":
        '''(experimental) Grants permissions to delete a subnet group.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        Dependent actions:

        - ec2:CreateNetworkInterface
        - ec2:DeleteNetworkInterface
        - ec2:DescribeNetworkInterfaces
        - ec2:DescribeSubnets
        - ec2:DescribeVpcs

        https://docs.aws.amazon.com/memorydb/latest/APIReference/API_DeleteSubnetGroup.html

        :stability: experimental
        '''
        return typing.cast("Memorydb", jsii.invoke(self, "toDeleteSubnetGroup", []))

    @jsii.member(jsii_name="toDeleteUser")
    def to_delete_user(self) -> "Memorydb":
        '''(experimental) Grants permissions to delete a user.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/memorydb/latest/APIReference/API_DeleteUser.html

        :stability: experimental
        '''
        return typing.cast("Memorydb", jsii.invoke(self, "toDeleteUser", []))

    @jsii.member(jsii_name="toDescribeAcls")
    def to_describe_acls(self) -> "Memorydb":
        '''(experimental) Grants permissions to retrieve information about access control lists.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/memorydb/latest/APIReference/API_DescribeAcls.html

        :stability: experimental
        '''
        return typing.cast("Memorydb", jsii.invoke(self, "toDescribeAcls", []))

    @jsii.member(jsii_name="toDescribeClusters")
    def to_describe_clusters(self) -> "Memorydb":
        '''(experimental) Grants permissions to retrieve information about all provisioned clusters if no cluster identifier is specified, or about a specific cluster if a cluster identifier is supplied.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/memorydb/latest/APIReference/API_DescribeClusters.html

        :stability: experimental
        '''
        return typing.cast("Memorydb", jsii.invoke(self, "toDescribeClusters", []))

    @jsii.member(jsii_name="toDescribeEngineVersions")
    def to_describe_engine_versions(self) -> "Memorydb":
        '''(experimental) Grants permissions to list of the available engines and their versions.

        Access Level: Read

        https://docs.aws.amazon.com/memorydb/latest/APIReference/API_DescribeEngineVersions.html

        :stability: experimental
        '''
        return typing.cast("Memorydb", jsii.invoke(self, "toDescribeEngineVersions", []))

    @jsii.member(jsii_name="toDescribeEvents")
    def to_describe_events(self) -> "Memorydb":
        '''(experimental) Grants permissions to retrieve events related to clusters, subnet groups, and parameter groups.

        Access Level: Read

        https://docs.aws.amazon.com/memorydb/latest/APIReference/API_DescribeEvents.html

        :stability: experimental
        '''
        return typing.cast("Memorydb", jsii.invoke(self, "toDescribeEvents", []))

    @jsii.member(jsii_name="toDescribeParameterGroups")
    def to_describe_parameter_groups(self) -> "Memorydb":
        '''(experimental) Grants permissions to retrieve information about parameter groups.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/memorydb/latest/APIReference/API_DescribeParameterGroups.html

        :stability: experimental
        '''
        return typing.cast("Memorydb", jsii.invoke(self, "toDescribeParameterGroups", []))

    @jsii.member(jsii_name="toDescribeParameters")
    def to_describe_parameters(self) -> "Memorydb":
        '''(experimental) Grants permissions to retrieve a detailed parameter list for a particular parameter group.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/memorydb/latest/APIReference/API_DescribeParameters.html

        :stability: experimental
        '''
        return typing.cast("Memorydb", jsii.invoke(self, "toDescribeParameters", []))

    @jsii.member(jsii_name="toDescribeServiceUpdates")
    def to_describe_service_updates(self) -> "Memorydb":
        '''(experimental) Grants permissions to retrieve details of the service updates.

        Access Level: Read

        https://docs.aws.amazon.com/memorydb/latest/APIReference/API_DescribeServiceUpdates.html

        :stability: experimental
        '''
        return typing.cast("Memorydb", jsii.invoke(self, "toDescribeServiceUpdates", []))

    @jsii.member(jsii_name="toDescribeSnapshots")
    def to_describe_snapshots(self) -> "Memorydb":
        '''(experimental) Grants permissions to retrieve information about cluster snapshots.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/memorydb/latest/APIReference/API_DescribeSnapshots.html

        :stability: experimental
        '''
        return typing.cast("Memorydb", jsii.invoke(self, "toDescribeSnapshots", []))

    @jsii.member(jsii_name="toDescribeSubnetGroups")
    def to_describe_subnet_groups(self) -> "Memorydb":
        '''(experimental) Grants permissions to retrieve a list of subnet group.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/memorydb/latest/APIReference/API_DescribeSubnetGroups.html

        :stability: experimental
        '''
        return typing.cast("Memorydb", jsii.invoke(self, "toDescribeSubnetGroups", []))

    @jsii.member(jsii_name="toDescribeUsers")
    def to_describe_users(self) -> "Memorydb":
        '''(experimental) Grants permissions to retrieve information about users.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/memorydb/latest/APIReference/API_DescribeUsers.html

        :stability: experimental
        '''
        return typing.cast("Memorydb", jsii.invoke(self, "toDescribeUsers", []))

    @jsii.member(jsii_name="toFailoverShard")
    def to_failover_shard(self) -> "Memorydb":
        '''(experimental) Grants permissions to test automatic failover on a specified shard in a cluster.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        Dependent actions:

        - ec2:CreateNetworkInterface
        - ec2:DeleteNetworkInterface
        - ec2:DescribeNetworkInterfaces
        - ec2:DescribeSubnets
        - ec2:DescribeVpcs

        https://docs.aws.amazon.com/memorydb/latest/APIReference/API_FailoverShard.html

        :stability: experimental
        '''
        return typing.cast("Memorydb", jsii.invoke(self, "toFailoverShard", []))

    @jsii.member(jsii_name="toListAllowedNodeTypeUpdates")
    def to_list_allowed_node_type_updates(self) -> "Memorydb":
        '''(experimental) Grants permissions to list available node type updates.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/memorydb/latest/APIReference/API_ListAllowedNodeTypeUpdates.html

        :stability: experimental
        '''
        return typing.cast("Memorydb", jsii.invoke(self, "toListAllowedNodeTypeUpdates", []))

    @jsii.member(jsii_name="toListTags")
    def to_list_tags(self) -> "Memorydb":
        '''(experimental) Grants permissions to list cost allocation tags.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/memorydb/latest/APIReference/API_ListTags.html

        :stability: experimental
        '''
        return typing.cast("Memorydb", jsii.invoke(self, "toListTags", []))

    @jsii.member(jsii_name="toResetParameterGroup")
    def to_reset_parameter_group(self) -> "Memorydb":
        '''(experimental) Grants permissions to modify the parameters of a parameter group to the engine or system default value.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/memorydb/latest/APIReference/API_ResetParameterGroup.html

        :stability: experimental
        '''
        return typing.cast("Memorydb", jsii.invoke(self, "toResetParameterGroup", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Memorydb":
        '''(experimental) Grants permissions to add up to 10 cost allocation tags to the named resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()
        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/memorydb/latest/APIReference/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("Memorydb", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Memorydb":
        '''(experimental) Grants permissions to remove the tags identified by the TagKeys list from a resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/memorydb/latest/APIReference/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("Memorydb", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateAcl")
    def to_update_acl(self) -> "Memorydb":
        '''(experimental) Grants permissions to update an access control list.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/memorydb/latest/APIReference/API_UpdateAcl.html

        :stability: experimental
        '''
        return typing.cast("Memorydb", jsii.invoke(self, "toUpdateAcl", []))

    @jsii.member(jsii_name="toUpdateCluster")
    def to_update_cluster(self) -> "Memorydb":
        '''(experimental) Grants permissions to update the settings for a cluster.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        Dependent actions:

        - ec2:CreateNetworkInterface
        - ec2:DeleteNetworkInterface
        - ec2:DescribeNetworkInterfaces
        - ec2:DescribeSubnets
        - ec2:DescribeVpcs

        https://docs.aws.amazon.com/memorydb/latest/APIReference/API_UpdateCluster.html

        :stability: experimental
        '''
        return typing.cast("Memorydb", jsii.invoke(self, "toUpdateCluster", []))

    @jsii.member(jsii_name="toUpdateParameterGroup")
    def to_update_parameter_group(self) -> "Memorydb":
        '''(experimental) Grants permissions to update parameters in a parameter group.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/memorydb/latest/APIReference/API_UpdateParameterGroup.html

        :stability: experimental
        '''
        return typing.cast("Memorydb", jsii.invoke(self, "toUpdateParameterGroup", []))

    @jsii.member(jsii_name="toUpdateSubnetGroup")
    def to_update_subnet_group(self) -> "Memorydb":
        '''(experimental) Grants permissions to update a subnet group.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/memorydb/latest/APIReference/API_UpdateSubnetGroup.html

        :stability: experimental
        '''
        return typing.cast("Memorydb", jsii.invoke(self, "toUpdateSubnetGroup", []))

    @jsii.member(jsii_name="toUpdateUser")
    def to_update_user(self) -> "Memorydb":
        '''(experimental) Grants permissions to update a user.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/memorydb/latest/APIReference/API_UpdateUser.html

        :stability: experimental
        '''
        return typing.cast("Memorydb", jsii.invoke(self, "toUpdateUser", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__64131d348b61ba0f507a4bdf4e009044a4202e4e8e531923cc5724c73cf6f465)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__dc587d1c0fd418c1f2a2ae2a4bb30a7ba0c7e1b4a362988677d0120ab7f0ea7e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Mgh(PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Mgh"):
    '''(experimental) Statement provider for service `mgh <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsmigrationhub.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `mgh <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsmigrationhub.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onMigrationTask")
    def on_migration_task(
        self,
        stream: builtins.str,
        task: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Mgh":
        '''(experimental) Adds a resource of type migrationTask to the statement.

        https://docs.aws.amazon.com/migrationhub/latest/ug/API_MigrationTask.html

        :param stream: - Identifier for the stream.
        :param task: - Identifier for the task.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__26da996bf45dcda78a26a0a71b1fda84ee701dd7fa0b0ff834745e80fdd213a3)
            check_type(argname="argument stream", value=stream, expected_type=type_hints["stream"])
            check_type(argname="argument task", value=task, expected_type=type_hints["task"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Mgh", jsii.invoke(self, "onMigrationTask", [stream, task, account, region, partition]))

    @jsii.member(jsii_name="onProgressUpdateStream")
    def on_progress_update_stream(
        self,
        stream: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Mgh":
        '''(experimental) Adds a resource of type progressUpdateStream to the statement.

        https://docs.aws.amazon.com/migrationhub/latest/ug/API_ProgressUpdateStreamSummary.html

        :param stream: - Identifier for the stream.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c417cc931f14cacd9454ed93c0a4f41c13536c16912ae32efb0e8df58bc1a825)
            check_type(argname="argument stream", value=stream, expected_type=type_hints["stream"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Mgh", jsii.invoke(self, "onProgressUpdateStream", [stream, account, region, partition]))

    @jsii.member(jsii_name="toAssociateCreatedArtifact")
    def to_associate_created_artifact(self) -> "Mgh":
        '''(experimental) Associate a given AWS artifact to a MigrationTask.

        Access Level: Write

        https://docs.aws.amazon.com/migrationhub/latest/ug/API_AssociateCreatedArtifact.html

        :stability: experimental
        '''
        return typing.cast("Mgh", jsii.invoke(self, "toAssociateCreatedArtifact", []))

    @jsii.member(jsii_name="toAssociateDiscoveredResource")
    def to_associate_discovered_resource(self) -> "Mgh":
        '''(experimental) Associate a given ADS resource to a MigrationTask.

        Access Level: Write

        https://docs.aws.amazon.com/migrationhub/latest/ug/API_AssociateDiscoveredResource.html

        :stability: experimental
        '''
        return typing.cast("Mgh", jsii.invoke(self, "toAssociateDiscoveredResource", []))

    @jsii.member(jsii_name="toCreateHomeRegionControl")
    def to_create_home_region_control(self) -> "Mgh":
        '''(experimental) Create a Migration Hub Home Region Control.

        Access Level: Write

        https://docs.aws.amazon.com/migrationhub/latest/ug/API_CreateHomeRegionControl.html

        :stability: experimental
        '''
        return typing.cast("Mgh", jsii.invoke(self, "toCreateHomeRegionControl", []))

    @jsii.member(jsii_name="toCreateProgressUpdateStream")
    def to_create_progress_update_stream(self) -> "Mgh":
        '''(experimental) Create a ProgressUpdateStream.

        Access Level: Write

        https://docs.aws.amazon.com/migrationhub/latest/ug/API_CreateProgressUpdateStream.html

        :stability: experimental
        '''
        return typing.cast("Mgh", jsii.invoke(self, "toCreateProgressUpdateStream", []))

    @jsii.member(jsii_name="toDeleteProgressUpdateStream")
    def to_delete_progress_update_stream(self) -> "Mgh":
        '''(experimental) Delete a ProgressUpdateStream.

        Access Level: Write

        https://docs.aws.amazon.com/migrationhub/latest/ug/API_DeleteProgressUpdateStream.html

        :stability: experimental
        '''
        return typing.cast("Mgh", jsii.invoke(self, "toDeleteProgressUpdateStream", []))

    @jsii.member(jsii_name="toDescribeApplicationState")
    def to_describe_application_state(self) -> "Mgh":
        '''(experimental) Get an Application Discovery Service Application's state.

        Access Level: Read

        https://docs.aws.amazon.com/migrationhub/latest/ug/API_DescribeApplicationState.html

        :stability: experimental
        '''
        return typing.cast("Mgh", jsii.invoke(self, "toDescribeApplicationState", []))

    @jsii.member(jsii_name="toDescribeHomeRegionControls")
    def to_describe_home_region_controls(self) -> "Mgh":
        '''(experimental) List Home Region Controls.

        Access Level: List

        https://docs.aws.amazon.com/migrationhub/latest/ug/API_DescribeHomeRegionControls.html

        :stability: experimental
        '''
        return typing.cast("Mgh", jsii.invoke(self, "toDescribeHomeRegionControls", []))

    @jsii.member(jsii_name="toDescribeMigrationTask")
    def to_describe_migration_task(self) -> "Mgh":
        '''(experimental) Describe a MigrationTask.

        Access Level: Read

        https://docs.aws.amazon.com/migrationhub/latest/ug/API_DescribeMigrationTask.html

        :stability: experimental
        '''
        return typing.cast("Mgh", jsii.invoke(self, "toDescribeMigrationTask", []))

    @jsii.member(jsii_name="toDisassociateCreatedArtifact")
    def to_disassociate_created_artifact(self) -> "Mgh":
        '''(experimental) Disassociate a given AWS artifact from a MigrationTask.

        Access Level: Write

        https://docs.aws.amazon.com/migrationhub/latest/ug/API_DisassociateCreatedArtifact.html

        :stability: experimental
        '''
        return typing.cast("Mgh", jsii.invoke(self, "toDisassociateCreatedArtifact", []))

    @jsii.member(jsii_name="toDisassociateDiscoveredResource")
    def to_disassociate_discovered_resource(self) -> "Mgh":
        '''(experimental) Disassociate a given ADS resource from a MigrationTask.

        Access Level: Write

        https://docs.aws.amazon.com/migrationhub/latest/ug/API_DisassociateDiscoveredResource.html

        :stability: experimental
        '''
        return typing.cast("Mgh", jsii.invoke(self, "toDisassociateDiscoveredResource", []))

    @jsii.member(jsii_name="toGetHomeRegion")
    def to_get_home_region(self) -> "Mgh":
        '''(experimental) Get the Migration Hub Home Region.

        Access Level: Read

        https://docs.aws.amazon.com/migrationhub/latest/ug/API_GetHomeRegion.html

        :stability: experimental
        '''
        return typing.cast("Mgh", jsii.invoke(self, "toGetHomeRegion", []))

    @jsii.member(jsii_name="toImportMigrationTask")
    def to_import_migration_task(self) -> "Mgh":
        '''(experimental) Import a MigrationTask.

        Access Level: Write

        https://docs.aws.amazon.com/migrationhub/latest/ug/API_ImportMigrationTask.html

        :stability: experimental
        '''
        return typing.cast("Mgh", jsii.invoke(self, "toImportMigrationTask", []))

    @jsii.member(jsii_name="toListApplicationStates")
    def to_list_application_states(self) -> "Mgh":
        '''(experimental) List Application statuses.

        Access Level: List

        https://docs.aws.amazon.com/migrationhub/latest/ug/API_ListApplicationStates.html

        :stability: experimental
        '''
        return typing.cast("Mgh", jsii.invoke(self, "toListApplicationStates", []))

    @jsii.member(jsii_name="toListCreatedArtifacts")
    def to_list_created_artifacts(self) -> "Mgh":
        '''(experimental) List associated created artifacts for a MigrationTask.

        Access Level: List

        https://docs.aws.amazon.com/migrationhub/latest/ug/API_ListCreatedArtifacts.html

        :stability: experimental
        '''
        return typing.cast("Mgh", jsii.invoke(self, "toListCreatedArtifacts", []))

    @jsii.member(jsii_name="toListDiscoveredResources")
    def to_list_discovered_resources(self) -> "Mgh":
        '''(experimental) List associated ADS resources from MigrationTask.

        Access Level: List

        https://docs.aws.amazon.com/migrationhub/latest/ug/API_ListDiscoveredResources.html

        :stability: experimental
        '''
        return typing.cast("Mgh", jsii.invoke(self, "toListDiscoveredResources", []))

    @jsii.member(jsii_name="toListMigrationTasks")
    def to_list_migration_tasks(self) -> "Mgh":
        '''(experimental) List MigrationTasks.

        Access Level: List

        https://docs.aws.amazon.com/migrationhub/latest/ug/API_ListMigrationTasks.html

        :stability: experimental
        '''
        return typing.cast("Mgh", jsii.invoke(self, "toListMigrationTasks", []))

    @jsii.member(jsii_name="toListProgressUpdateStreams")
    def to_list_progress_update_streams(self) -> "Mgh":
        '''(experimental) List ProgressUpdateStreams.

        Access Level: List

        https://docs.aws.amazon.com/migrationhub/latest/ug/API_ListProgressUpdateStreams.html

        :stability: experimental
        '''
        return typing.cast("Mgh", jsii.invoke(self, "toListProgressUpdateStreams", []))

    @jsii.member(jsii_name="toNotifyApplicationState")
    def to_notify_application_state(self) -> "Mgh":
        '''(experimental) Update an Application Discovery Service Application's state.

        Access Level: Write

        https://docs.aws.amazon.com/migrationhub/latest/ug/API_NotifyApplicationState.html

        :stability: experimental
        '''
        return typing.cast("Mgh", jsii.invoke(self, "toNotifyApplicationState", []))

    @jsii.member(jsii_name="toNotifyMigrationTaskState")
    def to_notify_migration_task_state(self) -> "Mgh":
        '''(experimental) Notify latest MigrationTask state.

        Access Level: Write

        https://docs.aws.amazon.com/migrationhub/latest/ug/API_NotifyMigrationTaskState.html

        :stability: experimental
        '''
        return typing.cast("Mgh", jsii.invoke(self, "toNotifyMigrationTaskState", []))

    @jsii.member(jsii_name="toPutResourceAttributes")
    def to_put_resource_attributes(self) -> "Mgh":
        '''(experimental) Put ResourceAttributes.

        Access Level: Write

        https://docs.aws.amazon.com/migrationhub/latest/ug/API_PutResourceAttributes.html

        :stability: experimental
        '''
        return typing.cast("Mgh", jsii.invoke(self, "toPutResourceAttributes", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b666b68b6eeed9a0acef055df6bb5bd890aae89f358fb0ff0cdc537837c3f7a3)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0692fb398de8e1f577174a4002b976553b6b46649ca97540386c71f96410d3e7)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Mgn(PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Mgn"):
    '''(experimental) Statement provider for service `mgn <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsapplicationmigrationservice.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `mgn <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsapplicationmigrationservice.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="ifCreateAction")
    def if_create_action(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Mgn":
        '''(experimental) Filters access by the name of a resource-creating API action.

        https://docs.aws.amazon.com/mgn/latest/ug/supported-iam-actions-tagging.html

        Applies to actions:

        - .toTagResource()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fb5a889bc25e4f69b82201906a5d504efeae80fdef670d00631e0d6807a77e07)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Mgn", jsii.invoke(self, "ifCreateAction", [value, operator]))

    @jsii.member(jsii_name="onApplicationResource")
    def on_application_resource(
        self,
        application_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Mgn":
        '''(experimental) Adds a resource of type ApplicationResource to the statement.

        https://docs.aws.amazon.com/mgn/latest/ug/applications.html

        :param application_id: - Identifier for the applicationID.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__93ccc011d34f96ddef68f428621b8f56f4370b5b97d87f9463efeb29ae65ae33)
            check_type(argname="argument application_id", value=application_id, expected_type=type_hints["application_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Mgn", jsii.invoke(self, "onApplicationResource", [application_id, account, region, partition]))

    @jsii.member(jsii_name="onJobResource")
    def on_job_resource(
        self,
        job_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Mgn":
        '''(experimental) Adds a resource of type JobResource to the statement.

        https://docs.aws.amazon.com/mgn/latest/ug/launching-target-servers.html

        :param job_id: - Identifier for the jobID.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d6e2742a7d5b3d86da9e919b79e4c93bd72559cdeecd4c8e44796b53327c45ea)
            check_type(argname="argument job_id", value=job_id, expected_type=type_hints["job_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Mgn", jsii.invoke(self, "onJobResource", [job_id, account, region, partition]))

    @jsii.member(jsii_name="onLaunchConfigurationTemplateResource")
    def on_launch_configuration_template_resource(
        self,
        launch_configuration_template_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Mgn":
        '''(experimental) Adds a resource of type LaunchConfigurationTemplateResource to the statement.

        https://docs.aws.amazon.com/mgn/latest/ug/post-launch-settings.html

        :param launch_configuration_template_id: - Identifier for the launchConfigurationTemplateID.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__77a14e90db57c6a58c450c23210fea942fda0865c7380e1a2e94fd3a8cce61a1)
            check_type(argname="argument launch_configuration_template_id", value=launch_configuration_template_id, expected_type=type_hints["launch_configuration_template_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Mgn", jsii.invoke(self, "onLaunchConfigurationTemplateResource", [launch_configuration_template_id, account, region, partition]))

    @jsii.member(jsii_name="onReplicationConfigurationTemplateResource")
    def on_replication_configuration_template_resource(
        self,
        replication_configuration_template_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Mgn":
        '''(experimental) Adds a resource of type ReplicationConfigurationTemplateResource to the statement.

        https://docs.aws.amazon.com/mgn/latest/ug/replication-settings-template.html

        :param replication_configuration_template_id: - Identifier for the replicationConfigurationTemplateID.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ca9faaf4dc56d3c40d43c17f95b8d1fc63418043c3d391645ad3b3ba9e610480)
            check_type(argname="argument replication_configuration_template_id", value=replication_configuration_template_id, expected_type=type_hints["replication_configuration_template_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Mgn", jsii.invoke(self, "onReplicationConfigurationTemplateResource", [replication_configuration_template_id, account, region, partition]))

    @jsii.member(jsii_name="onSourceServerResource")
    def on_source_server_resource(
        self,
        source_server_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Mgn":
        '''(experimental) Adds a resource of type SourceServerResource to the statement.

        https://docs.aws.amazon.com/mgn/latest/ug/source-servers.html

        :param source_server_id: - Identifier for the sourceServerID.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__67abdd4abb82882ca8229593d3ba93bf2b8dffca9d5cdcd7287debd795f41e23)
            check_type(argname="argument source_server_id", value=source_server_id, expected_type=type_hints["source_server_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Mgn", jsii.invoke(self, "onSourceServerResource", [source_server_id, account, region, partition]))

    @jsii.member(jsii_name="onVcenterClientResource")
    def on_vcenter_client_resource(
        self,
        vcenter_client_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Mgn":
        '''(experimental) Adds a resource of type VcenterClientResource to the statement.

        https://docs.aws.amazon.com/mgn/latest/ug/agentless-mgn.html

        :param vcenter_client_id: - Identifier for the vcenterClientID.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__cb6bc6e1e5a83b380bde820e1950201881b08b8f83f5b4d130f83036c4682dd9)
            check_type(argname="argument vcenter_client_id", value=vcenter_client_id, expected_type=type_hints["vcenter_client_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Mgn", jsii.invoke(self, "onVcenterClientResource", [vcenter_client_id, account, region, partition]))

    @jsii.member(jsii_name="onWaveResource")
    def on_wave_resource(
        self,
        wave_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Mgn":
        '''(experimental) Adds a resource of type WaveResource to the statement.

        https://docs.aws.amazon.com/mgn/latest/ug/waves.html

        :param wave_id: - Identifier for the waveID.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__121053f082880bac584795c6697f995f522c2cb08e4abec30263139592e8dd3b)
            check_type(argname="argument wave_id", value=wave_id, expected_type=type_hints["wave_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Mgn", jsii.invoke(self, "onWaveResource", [wave_id, account, region, partition]))

    @jsii.member(jsii_name="toArchiveApplication")
    def to_archive_application(self) -> "Mgn":
        '''(experimental) Grants permission to archive an application.

        Access Level: Write

        https://docs.aws.amazon.com/mgn/latest/APIReference/API_ArchiveApplication.html

        :stability: experimental
        '''
        return typing.cast("Mgn", jsii.invoke(self, "toArchiveApplication", []))

    @jsii.member(jsii_name="toArchiveWave")
    def to_archive_wave(self) -> "Mgn":
        '''(experimental) Grants permission to archive a wave.

        Access Level: Write

        https://docs.aws.amazon.com/mgn/latest/APIReference/API_ArchiveWave.html

        :stability: experimental
        '''
        return typing.cast("Mgn", jsii.invoke(self, "toArchiveWave", []))

    @jsii.member(jsii_name="toAssociateApplications")
    def to_associate_applications(self) -> "Mgn":
        '''(experimental) Grants permission to associate applications to a wave.

        Access Level: Write

        https://docs.aws.amazon.com/mgn/latest/APIReference/API_AssociateApplications.html

        :stability: experimental
        '''
        return typing.cast("Mgn", jsii.invoke(self, "toAssociateApplications", []))

    @jsii.member(jsii_name="toAssociateSourceServers")
    def to_associate_source_servers(self) -> "Mgn":
        '''(experimental) Grants permission to associate source servers to an application.

        Access Level: Write

        https://docs.aws.amazon.com/mgn/latest/APIReference/API_AssociateSourceServers.html

        :stability: experimental
        '''
        return typing.cast("Mgn", jsii.invoke(self, "toAssociateSourceServers", []))

    @jsii.member(jsii_name="toBatchCreateVolumeSnapshotGroupForMgn")
    def to_batch_create_volume_snapshot_group_for_mgn(self) -> "Mgn":
        '''(experimental) Grants permission to create volume snapshot group.

        Access Level: Write

        https://docs.aws.amazon.com/mgn/latest/ug/mgn-apis.html

        :stability: experimental
        '''
        return typing.cast("Mgn", jsii.invoke(self, "toBatchCreateVolumeSnapshotGroupForMgn", []))

    @jsii.member(jsii_name="toBatchDeleteSnapshotRequestForMgn")
    def to_batch_delete_snapshot_request_for_mgn(self) -> "Mgn":
        '''(experimental) Grants permission to batch delete snapshot request.

        Access Level: Write

        https://docs.aws.amazon.com/mgn/latest/ug/mgn-apis.html

        :stability: experimental
        '''
        return typing.cast("Mgn", jsii.invoke(self, "toBatchDeleteSnapshotRequestForMgn", []))

    @jsii.member(jsii_name="toChangeServerLifeCycleState")
    def to_change_server_life_cycle_state(self) -> "Mgn":
        '''(experimental) Grants permission to change source server life cycle state.

        Access Level: Write

        https://docs.aws.amazon.com/mgn/latest/APIReference/API_ChangeServerLifeCycleState.html

        :stability: experimental
        '''
        return typing.cast("Mgn", jsii.invoke(self, "toChangeServerLifeCycleState", []))

    @jsii.member(jsii_name="toCreateApplication")
    def to_create_application(self) -> "Mgn":
        '''(experimental) Grants permission to create an application.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/mgn/latest/APIReference/API_CreateApplication.html

        :stability: experimental
        '''
        return typing.cast("Mgn", jsii.invoke(self, "toCreateApplication", []))

    @jsii.member(jsii_name="toCreateLaunchConfigurationTemplate")
    def to_create_launch_configuration_template(self) -> "Mgn":
        '''(experimental) Grants permission to create launch configuration template.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/mgn/latest/APIReference/API_CreateLaunchConfigurationTemplate.html

        :stability: experimental
        '''
        return typing.cast("Mgn", jsii.invoke(self, "toCreateLaunchConfigurationTemplate", []))

    @jsii.member(jsii_name="toCreateReplicationConfigurationTemplate")
    def to_create_replication_configuration_template(self) -> "Mgn":
        '''(experimental) Grants permission to create replication configuration template.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/mgn/latest/APIReference/API_CreateReplicationConfigurationTemplate.html

        :stability: experimental
        '''
        return typing.cast("Mgn", jsii.invoke(self, "toCreateReplicationConfigurationTemplate", []))

    @jsii.member(jsii_name="toCreateVcenterClientForMgn")
    def to_create_vcenter_client_for_mgn(self) -> "Mgn":
        '''(experimental) Grants permission to create vcenter client.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/mgn/latest/ug/mgn-apis.html

        :stability: experimental
        '''
        return typing.cast("Mgn", jsii.invoke(self, "toCreateVcenterClientForMgn", []))

    @jsii.member(jsii_name="toCreateWave")
    def to_create_wave(self) -> "Mgn":
        '''(experimental) Grants permission to create a wave.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/mgn/latest/APIReference/API_CreateWave.html

        :stability: experimental
        '''
        return typing.cast("Mgn", jsii.invoke(self, "toCreateWave", []))

    @jsii.member(jsii_name="toDeleteApplication")
    def to_delete_application(self) -> "Mgn":
        '''(experimental) Grants permission to delete an application.

        Access Level: Write

        https://docs.aws.amazon.com/mgn/latest/APIReference/API_DeleteApplication.html

        :stability: experimental
        '''
        return typing.cast("Mgn", jsii.invoke(self, "toDeleteApplication", []))

    @jsii.member(jsii_name="toDeleteJob")
    def to_delete_job(self) -> "Mgn":
        '''(experimental) Grants permission to delete job.

        Access Level: Write

        https://docs.aws.amazon.com/mgn/latest/APIReference/API_DeleteJob.html

        :stability: experimental
        '''
        return typing.cast("Mgn", jsii.invoke(self, "toDeleteJob", []))

    @jsii.member(jsii_name="toDeleteLaunchConfigurationTemplate")
    def to_delete_launch_configuration_template(self) -> "Mgn":
        '''(experimental) Grants permission to delete launch configuration template.

        Access Level: Write

        https://docs.aws.amazon.com/mgn/latest/APIReference/API_DeleteLaunchConfigurationTemplate.html

        :stability: experimental
        '''
        return typing.cast("Mgn", jsii.invoke(self, "toDeleteLaunchConfigurationTemplate", []))

    @jsii.member(jsii_name="toDeleteReplicationConfigurationTemplate")
    def to_delete_replication_configuration_template(self) -> "Mgn":
        '''(experimental) Grants permission to delete replication configuration template.

        Access Level: Write

        https://docs.aws.amazon.com/mgn/latest/APIReference/API_DeleteReplicationConfigurationTemplate.html

        :stability: experimental
        '''
        return typing.cast("Mgn", jsii.invoke(self, "toDeleteReplicationConfigurationTemplate", []))

    @jsii.member(jsii_name="toDeleteSourceServer")
    def to_delete_source_server(self) -> "Mgn":
        '''(experimental) Grants permission to delete source server.

        Access Level: Write

        https://docs.aws.amazon.com/mgn/latest/APIReference/API_DeleteSourceServer.html

        :stability: experimental
        '''
        return typing.cast("Mgn", jsii.invoke(self, "toDeleteSourceServer", []))

    @jsii.member(jsii_name="toDeleteVcenterClient")
    def to_delete_vcenter_client(self) -> "Mgn":
        '''(experimental) Grants permission to delete vcenter client.

        Access Level: Write

        https://docs.aws.amazon.com/mgn/latest/APIReference/API_DeleteVcenterClient.html

        :stability: experimental
        '''
        return typing.cast("Mgn", jsii.invoke(self, "toDeleteVcenterClient", []))

    @jsii.member(jsii_name="toDeleteWave")
    def to_delete_wave(self) -> "Mgn":
        '''(experimental) Grants permission to delete a wave.

        Access Level: Write

        https://docs.aws.amazon.com/mgn/latest/APIReference/API_DeleteWave.html

        :stability: experimental
        '''
        return typing.cast("Mgn", jsii.invoke(self, "toDeleteWave", []))

    @jsii.member(jsii_name="toDescribeJobLogItems")
    def to_describe_job_log_items(self) -> "Mgn":
        '''(experimental) Grants permission to describe job log items.

        Access Level: Read

        https://docs.aws.amazon.com/mgn/latest/APIReference/API_DescribeJobLogItems.html

        :stability: experimental
        '''
        return typing.cast("Mgn", jsii.invoke(self, "toDescribeJobLogItems", []))

    @jsii.member(jsii_name="toDescribeJobs")
    def to_describe_jobs(self) -> "Mgn":
        '''(experimental) Grants permission to describe jobs.

        Access Level: List

        https://docs.aws.amazon.com/mgn/latest/APIReference/API_DescribeJobs.html

        :stability: experimental
        '''
        return typing.cast("Mgn", jsii.invoke(self, "toDescribeJobs", []))

    @jsii.member(jsii_name="toDescribeLaunchConfigurationTemplates")
    def to_describe_launch_configuration_templates(self) -> "Mgn":
        '''(experimental) Grants permission to describe launch configuration template.

        Access Level: List

        https://docs.aws.amazon.com/mgn/latest/APIReference/API_DescribeLaunchConfigurationTemplates.html

        :stability: experimental
        '''
        return typing.cast("Mgn", jsii.invoke(self, "toDescribeLaunchConfigurationTemplates", []))

    @jsii.member(jsii_name="toDescribeReplicationConfigurationTemplates")
    def to_describe_replication_configuration_templates(self) -> "Mgn":
        '''(experimental) Grants permission to describe replication configuration template.

        Access Level: List

        https://docs.aws.amazon.com/mgn/latest/APIReference/API_DescribeReplicationConfigurationTemplates.html

        :stability: experimental
        '''
        return typing.cast("Mgn", jsii.invoke(self, "toDescribeReplicationConfigurationTemplates", []))

    @jsii.member(jsii_name="toDescribeReplicationServerAssociationsForMgn")
    def to_describe_replication_server_associations_for_mgn(self) -> "Mgn":
        '''(experimental) Grants permission to describe replication server associations.

        Access Level: Read

        https://docs.aws.amazon.com/mgn/latest/ug/mgn-apis.html

        :stability: experimental
        '''
        return typing.cast("Mgn", jsii.invoke(self, "toDescribeReplicationServerAssociationsForMgn", []))

    @jsii.member(jsii_name="toDescribeSnapshotRequestsForMgn")
    def to_describe_snapshot_requests_for_mgn(self) -> "Mgn":
        '''(experimental) Grants permission to describe snapshots requests.

        Access Level: Read

        https://docs.aws.amazon.com/mgn/latest/ug/mgn-apis.html

        :stability: experimental
        '''
        return typing.cast("Mgn", jsii.invoke(self, "toDescribeSnapshotRequestsForMgn", []))

    @jsii.member(jsii_name="toDescribeSourceServers")
    def to_describe_source_servers(self) -> "Mgn":
        '''(experimental) Grants permission to describe source servers.

        Access Level: List

        https://docs.aws.amazon.com/mgn/latest/APIReference/API_DescribeSourceServers.html

        :stability: experimental
        '''
        return typing.cast("Mgn", jsii.invoke(self, "toDescribeSourceServers", []))

    @jsii.member(jsii_name="toDescribeVcenterClients")
    def to_describe_vcenter_clients(self) -> "Mgn":
        '''(experimental) Grants permission to describe vcenter clients.

        Access Level: List

        https://docs.aws.amazon.com/mgn/latest/APIReference/API_DescribeVcenterClients.html

        :stability: experimental
        '''
        return typing.cast("Mgn", jsii.invoke(self, "toDescribeVcenterClients", []))

    @jsii.member(jsii_name="toDisassociateApplications")
    def to_disassociate_applications(self) -> "Mgn":
        '''(experimental) Grants permission to disassociate applications from a wave.

        Access Level: Write

        https://docs.aws.amazon.com/mgn/latest/APIReference/API_DisassociateApplications.html

        :stability: experimental
        '''
        return typing.cast("Mgn", jsii.invoke(self, "toDisassociateApplications", []))

    @jsii.member(jsii_name="toDisassociateSourceServers")
    def to_disassociate_source_servers(self) -> "Mgn":
        '''(experimental) Grants permission to disassociate source servers from an application.

        Access Level: Write

        https://docs.aws.amazon.com/mgn/latest/APIReference/API_DisassociateSourceServers.html

        :stability: experimental
        '''
        return typing.cast("Mgn", jsii.invoke(self, "toDisassociateSourceServers", []))

    @jsii.member(jsii_name="toDisconnectFromService")
    def to_disconnect_from_service(self) -> "Mgn":
        '''(experimental) Grants permission to disconnect source server from service.

        Access Level: Write

        https://docs.aws.amazon.com/mgn/latest/APIReference/API_DisconnectFromService.html

        :stability: experimental
        '''
        return typing.cast("Mgn", jsii.invoke(self, "toDisconnectFromService", []))

    @jsii.member(jsii_name="toFinalizeCutover")
    def to_finalize_cutover(self) -> "Mgn":
        '''(experimental) Grants permission to finalize cutover.

        Access Level: Write

        https://docs.aws.amazon.com/mgn/latest/APIReference/API_FinalizeCutover.html

        :stability: experimental
        '''
        return typing.cast("Mgn", jsii.invoke(self, "toFinalizeCutover", []))

    @jsii.member(jsii_name="toGetAgentCommandForMgn")
    def to_get_agent_command_for_mgn(self) -> "Mgn":
        '''(experimental) Grants permission to get agent command.

        Access Level: Read

        https://docs.aws.amazon.com/mgn/latest/ug/mgn-apis.html

        :stability: experimental
        '''
        return typing.cast("Mgn", jsii.invoke(self, "toGetAgentCommandForMgn", []))

    @jsii.member(jsii_name="toGetAgentConfirmedResumeInfoForMgn")
    def to_get_agent_confirmed_resume_info_for_mgn(self) -> "Mgn":
        '''(experimental) Grants permission to get agent confirmed resume info.

        Access Level: Read

        https://docs.aws.amazon.com/mgn/latest/ug/mgn-apis.html

        :stability: experimental
        '''
        return typing.cast("Mgn", jsii.invoke(self, "toGetAgentConfirmedResumeInfoForMgn", []))

    @jsii.member(jsii_name="toGetAgentInstallationAssetsForMgn")
    def to_get_agent_installation_assets_for_mgn(self) -> "Mgn":
        '''(experimental) Grants permission to get agent installation assets.

        Access Level: Read

        https://docs.aws.amazon.com/mgn/latest/ug/mgn-apis.html

        :stability: experimental
        '''
        return typing.cast("Mgn", jsii.invoke(self, "toGetAgentInstallationAssetsForMgn", []))

    @jsii.member(jsii_name="toGetAgentReplicationInfoForMgn")
    def to_get_agent_replication_info_for_mgn(self) -> "Mgn":
        '''(experimental) Grants permission to get agent replication info.

        Access Level: Read

        https://docs.aws.amazon.com/mgn/latest/ug/mgn-apis.html

        :stability: experimental
        '''
        return typing.cast("Mgn", jsii.invoke(self, "toGetAgentReplicationInfoForMgn", []))

    @jsii.member(jsii_name="toGetAgentRuntimeConfigurationForMgn")
    def to_get_agent_runtime_configuration_for_mgn(self) -> "Mgn":
        '''(experimental) Grants permission to get agent runtime configuration.

        Access Level: Read

        https://docs.aws.amazon.com/mgn/latest/ug/mgn-apis.html

        :stability: experimental
        '''
        return typing.cast("Mgn", jsii.invoke(self, "toGetAgentRuntimeConfigurationForMgn", []))

    @jsii.member(jsii_name="toGetAgentSnapshotCreditsForMgn")
    def to_get_agent_snapshot_credits_for_mgn(self) -> "Mgn":
        '''(experimental) Grants permission to get agent snapshots credits.

        Access Level: Read

        https://docs.aws.amazon.com/mgn/latest/ug/mgn-apis.html

        :stability: experimental
        '''
        return typing.cast("Mgn", jsii.invoke(self, "toGetAgentSnapshotCreditsForMgn", []))

    @jsii.member(jsii_name="toGetChannelCommandsForMgn")
    def to_get_channel_commands_for_mgn(self) -> "Mgn":
        '''(experimental) Grants permission to get channel commands.

        Access Level: Read

        https://docs.aws.amazon.com/mgn/latest/ug/mgn-apis.html

        :stability: experimental
        '''
        return typing.cast("Mgn", jsii.invoke(self, "toGetChannelCommandsForMgn", []))

    @jsii.member(jsii_name="toGetLaunchConfiguration")
    def to_get_launch_configuration(self) -> "Mgn":
        '''(experimental) Grants permission to get launch configuration.

        Access Level: Read

        https://docs.aws.amazon.com/mgn/latest/APIReference/API_GetLaunchConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Mgn", jsii.invoke(self, "toGetLaunchConfiguration", []))

    @jsii.member(jsii_name="toGetReplicationConfiguration")
    def to_get_replication_configuration(self) -> "Mgn":
        '''(experimental) Grants permission to get replication configuration.

        Access Level: Read

        https://docs.aws.amazon.com/mgn/latest/APIReference/API_GetReplicationConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Mgn", jsii.invoke(self, "toGetReplicationConfiguration", []))

    @jsii.member(jsii_name="toGetVcenterClientCommandsForMgn")
    def to_get_vcenter_client_commands_for_mgn(self) -> "Mgn":
        '''(experimental) Grants permission to get vcenter client commands.

        Access Level: Read

        https://docs.aws.amazon.com/mgn/latest/ug/mgn-apis.html

        :stability: experimental
        '''
        return typing.cast("Mgn", jsii.invoke(self, "toGetVcenterClientCommandsForMgn", []))

    @jsii.member(jsii_name="toInitializeService")
    def to_initialize_service(self) -> "Mgn":
        '''(experimental) Grants permission to initialize service.

        Access Level: Write

        Dependent actions:

        - iam:AddRoleToInstanceProfile
        - iam:CreateInstanceProfile
        - iam:CreateServiceLinkedRole
        - iam:GetInstanceProfile

        https://docs.aws.amazon.com/mgn/latest/APIReference/API_InitializeService.html

        :stability: experimental
        '''
        return typing.cast("Mgn", jsii.invoke(self, "toInitializeService", []))

    @jsii.member(jsii_name="toIssueClientCertificateForMgn")
    def to_issue_client_certificate_for_mgn(self) -> "Mgn":
        '''(experimental) Grants permission to issue a client certificate.

        Access Level: Write

        https://docs.aws.amazon.com/mgn/latest/ug/mgn-apis.html

        :stability: experimental
        '''
        return typing.cast("Mgn", jsii.invoke(self, "toIssueClientCertificateForMgn", []))

    @jsii.member(jsii_name="toListApplications")
    def to_list_applications(self) -> "Mgn":
        '''(experimental) Grants permission to list application summaries.

        Access Level: List

        https://docs.aws.amazon.com/mgn/latest/APIReference/API_ListApplications.html

        :stability: experimental
        '''
        return typing.cast("Mgn", jsii.invoke(self, "toListApplications", []))

    @jsii.member(jsii_name="toListSourceServerActions")
    def to_list_source_server_actions(self) -> "Mgn":
        '''(experimental) Grants permission to list source server action documents.

        Access Level: List

        https://docs.aws.amazon.com/mgn/latest/APIReference/API_ListSourceServerActions.html

        :stability: experimental
        '''
        return typing.cast("Mgn", jsii.invoke(self, "toListSourceServerActions", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Mgn":
        '''(experimental) Grants permission to list tags for a resource.

        Access Level: Read

        https://docs.aws.amazon.com/mgn/latest/APIReference/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("Mgn", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toListTemplateActions")
    def to_list_template_actions(self) -> "Mgn":
        '''(experimental) Grants permission to list launch configuration template action documents.

        Access Level: List

        https://docs.aws.amazon.com/mgn/latest/APIReference/API_ListTemplateActions.html

        :stability: experimental
        '''
        return typing.cast("Mgn", jsii.invoke(self, "toListTemplateActions", []))

    @jsii.member(jsii_name="toListWaves")
    def to_list_waves(self) -> "Mgn":
        '''(experimental) Grants permission to list wave summaries.

        Access Level: List

        https://docs.aws.amazon.com/mgn/latest/APIReference/API_ListWaves.html

        :stability: experimental
        '''
        return typing.cast("Mgn", jsii.invoke(self, "toListWaves", []))

    @jsii.member(jsii_name="toMarkAsArchived")
    def to_mark_as_archived(self) -> "Mgn":
        '''(experimental) Grants permission to mark source server as archived.

        Access Level: Write

        https://docs.aws.amazon.com/mgn/latest/APIReference/API_MarkAsArchived.html

        :stability: experimental
        '''
        return typing.cast("Mgn", jsii.invoke(self, "toMarkAsArchived", []))

    @jsii.member(jsii_name="toNotifyAgentAuthenticationForMgn")
    def to_notify_agent_authentication_for_mgn(self) -> "Mgn":
        '''(experimental) Grants permission to notify agent authentication.

        Access Level: Write

        https://docs.aws.amazon.com/mgn/latest/ug/mgn-apis.html

        :stability: experimental
        '''
        return typing.cast("Mgn", jsii.invoke(self, "toNotifyAgentAuthenticationForMgn", []))

    @jsii.member(jsii_name="toNotifyAgentConnectedForMgn")
    def to_notify_agent_connected_for_mgn(self) -> "Mgn":
        '''(experimental) Grants permission to notify agent is connected.

        Access Level: Write

        https://docs.aws.amazon.com/mgn/latest/ug/mgn-apis.html

        :stability: experimental
        '''
        return typing.cast("Mgn", jsii.invoke(self, "toNotifyAgentConnectedForMgn", []))

    @jsii.member(jsii_name="toNotifyAgentDisconnectedForMgn")
    def to_notify_agent_disconnected_for_mgn(self) -> "Mgn":
        '''(experimental) Grants permission to notify agent is disconnected.

        Access Level: Write

        https://docs.aws.amazon.com/mgn/latest/ug/mgn-apis.html

        :stability: experimental
        '''
        return typing.cast("Mgn", jsii.invoke(self, "toNotifyAgentDisconnectedForMgn", []))

    @jsii.member(jsii_name="toNotifyAgentReplicationProgressForMgn")
    def to_notify_agent_replication_progress_for_mgn(self) -> "Mgn":
        '''(experimental) Grants permission to notify agent replication progress.

        Access Level: Write

        https://docs.aws.amazon.com/mgn/latest/ug/mgn-apis.html

        :stability: experimental
        '''
        return typing.cast("Mgn", jsii.invoke(self, "toNotifyAgentReplicationProgressForMgn", []))

    @jsii.member(jsii_name="toNotifyVcenterClientStartedForMgn")
    def to_notify_vcenter_client_started_for_mgn(self) -> "Mgn":
        '''(experimental) Grants permission to notify vcenter client started.

        Access Level: Write

        https://docs.aws.amazon.com/mgn/latest/ug/mgn-apis.html

        :stability: experimental
        '''
        return typing.cast("Mgn", jsii.invoke(self, "toNotifyVcenterClientStartedForMgn", []))

    @jsii.member(jsii_name="toPutSourceServerAction")
    def to_put_source_server_action(self) -> "Mgn":
        '''(experimental) Grants permission to put source server action document.

        Access Level: Write

        https://docs.aws.amazon.com/mgn/latest/APIReference/API_PutSourceServerAction.html

        :stability: experimental
        '''
        return typing.cast("Mgn", jsii.invoke(self, "toPutSourceServerAction", []))

    @jsii.member(jsii_name="toPutTemplateAction")
    def to_put_template_action(self) -> "Mgn":
        '''(experimental) Grants permission to put launch configuration template action document.

        Access Level: Write

        https://docs.aws.amazon.com/mgn/latest/APIReference/API_PutTemplateAction.html

        :stability: experimental
        '''
        return typing.cast("Mgn", jsii.invoke(self, "toPutTemplateAction", []))

    @jsii.member(jsii_name="toRegisterAgentForMgn")
    def to_register_agent_for_mgn(self) -> "Mgn":
        '''(experimental) Grants permission to register agent.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/mgn/latest/ug/mgn-apis.html

        :stability: experimental
        '''
        return typing.cast("Mgn", jsii.invoke(self, "toRegisterAgentForMgn", []))

    @jsii.member(jsii_name="toRemoveSourceServerAction")
    def to_remove_source_server_action(self) -> "Mgn":
        '''(experimental) Grants permission to remove source server action document.

        Access Level: Write

        https://docs.aws.amazon.com/mgn/latest/APIReference/API_RemoveSourceServerAction.html

        :stability: experimental
        '''
        return typing.cast("Mgn", jsii.invoke(self, "toRemoveSourceServerAction", []))

    @jsii.member(jsii_name="toRemoveTemplateAction")
    def to_remove_template_action(self) -> "Mgn":
        '''(experimental) Grants permission to remove launch configuration template action document.

        Access Level: Write

        https://docs.aws.amazon.com/mgn/latest/APIReference/API_RemoveTemplateAction.html

        :stability: experimental
        '''
        return typing.cast("Mgn", jsii.invoke(self, "toRemoveTemplateAction", []))

    @jsii.member(jsii_name="toRetryDataReplication")
    def to_retry_data_replication(self) -> "Mgn":
        '''(experimental) Grants permission to retry replication.

        Access Level: Write

        https://docs.aws.amazon.com/mgn/latest/APIReference/API_RetryDataReplication.html

        :stability: experimental
        '''
        return typing.cast("Mgn", jsii.invoke(self, "toRetryDataReplication", []))

    @jsii.member(jsii_name="toSendAgentLogsForMgn")
    def to_send_agent_logs_for_mgn(self) -> "Mgn":
        '''(experimental) Grants permission to send agent logs.

        Access Level: Write

        https://docs.aws.amazon.com/mgn/latest/ug/mgn-apis.html

        :stability: experimental
        '''
        return typing.cast("Mgn", jsii.invoke(self, "toSendAgentLogsForMgn", []))

    @jsii.member(jsii_name="toSendAgentMetricsForMgn")
    def to_send_agent_metrics_for_mgn(self) -> "Mgn":
        '''(experimental) Grants permission to send agent metrics.

        Access Level: Write

        https://docs.aws.amazon.com/mgn/latest/ug/mgn-apis.html

        :stability: experimental
        '''
        return typing.cast("Mgn", jsii.invoke(self, "toSendAgentMetricsForMgn", []))

    @jsii.member(jsii_name="toSendChannelCommandResultForMgn")
    def to_send_channel_command_result_for_mgn(self) -> "Mgn":
        '''(experimental) Grants permission to send channel command result.

        Access Level: Write

        https://docs.aws.amazon.com/mgn/latest/ug/mgn-apis.html

        :stability: experimental
        '''
        return typing.cast("Mgn", jsii.invoke(self, "toSendChannelCommandResultForMgn", []))

    @jsii.member(jsii_name="toSendClientLogsForMgn")
    def to_send_client_logs_for_mgn(self) -> "Mgn":
        '''(experimental) Grants permission to send client logs.

        Access Level: Write

        https://docs.aws.amazon.com/mgn/latest/ug/mgn-apis.html

        :stability: experimental
        '''
        return typing.cast("Mgn", jsii.invoke(self, "toSendClientLogsForMgn", []))

    @jsii.member(jsii_name="toSendClientMetricsForMgn")
    def to_send_client_metrics_for_mgn(self) -> "Mgn":
        '''(experimental) Grants permission to send client metrics.

        Access Level: Write

        https://docs.aws.amazon.com/mgn/latest/ug/mgn-apis.html

        :stability: experimental
        '''
        return typing.cast("Mgn", jsii.invoke(self, "toSendClientMetricsForMgn", []))

    @jsii.member(jsii_name="toSendVcenterClientCommandResultForMgn")
    def to_send_vcenter_client_command_result_for_mgn(self) -> "Mgn":
        '''(experimental) Grants permission to send vcenter client command result.

        Access Level: Write

        https://docs.aws.amazon.com/mgn/latest/ug/mgn-apis.html

        :stability: experimental
        '''
        return typing.cast("Mgn", jsii.invoke(self, "toSendVcenterClientCommandResultForMgn", []))

    @jsii.member(jsii_name="toSendVcenterClientLogsForMgn")
    def to_send_vcenter_client_logs_for_mgn(self) -> "Mgn":
        '''(experimental) Grants permission to send vcenter client logs.

        Access Level: Write

        https://docs.aws.amazon.com/mgn/latest/ug/mgn-apis.html

        :stability: experimental
        '''
        return typing.cast("Mgn", jsii.invoke(self, "toSendVcenterClientLogsForMgn", []))

    @jsii.member(jsii_name="toSendVcenterClientMetricsForMgn")
    def to_send_vcenter_client_metrics_for_mgn(self) -> "Mgn":
        '''(experimental) Grants permission to send vcenter client metrics.

        Access Level: Write

        https://docs.aws.amazon.com/mgn/latest/ug/mgn-apis.html

        :stability: experimental
        '''
        return typing.cast("Mgn", jsii.invoke(self, "toSendVcenterClientMetricsForMgn", []))

    @jsii.member(jsii_name="toStartCutover")
    def to_start_cutover(self) -> "Mgn":
        '''(experimental) Grants permission to start cutover.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - ec2:AttachVolume
        - ec2:AuthorizeSecurityGroupEgress
        - ec2:AuthorizeSecurityGroupIngress
        - ec2:CreateLaunchTemplate
        - ec2:CreateLaunchTemplateVersion
        - ec2:CreateSecurityGroup
        - ec2:CreateSnapshot
        - ec2:CreateTags
        - ec2:CreateVolume
        - ec2:DeleteLaunchTemplateVersions
        - ec2:DeleteSnapshot
        - ec2:DeleteVolume
        - ec2:DescribeAccountAttributes
        - ec2:DescribeAvailabilityZones
        - ec2:DescribeImages
        - ec2:DescribeInstanceAttribute
        - ec2:DescribeInstanceStatus
        - ec2:DescribeInstanceTypes
        - ec2:DescribeInstances
        - ec2:DescribeLaunchTemplateVersions
        - ec2:DescribeLaunchTemplates
        - ec2:DescribeSecurityGroups
        - ec2:DescribeSnapshots
        - ec2:DescribeSubnets
        - ec2:DescribeVolumes
        - ec2:DetachVolume
        - ec2:ModifyInstanceAttribute
        - ec2:ModifyLaunchTemplate
        - ec2:ReportInstanceStatus
        - ec2:RevokeSecurityGroupEgress
        - ec2:RunInstances
        - ec2:StartInstances
        - ec2:StopInstances
        - ec2:TerminateInstances
        - iam:PassRole
        - mgn:ListTagsForResource

        https://docs.aws.amazon.com/mgn/latest/APIReference/API_StartCutover.html

        :stability: experimental
        '''
        return typing.cast("Mgn", jsii.invoke(self, "toStartCutover", []))

    @jsii.member(jsii_name="toStartReplication")
    def to_start_replication(self) -> "Mgn":
        '''(experimental) Grants permission to start replication.

        Access Level: Write

        https://docs.aws.amazon.com/mgn/latest/APIReference/API_StartReplication.html

        :stability: experimental
        '''
        return typing.cast("Mgn", jsii.invoke(self, "toStartReplication", []))

    @jsii.member(jsii_name="toStartTest")
    def to_start_test(self) -> "Mgn":
        '''(experimental) Grants permission to start test.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - ec2:AttachVolume
        - ec2:AuthorizeSecurityGroupEgress
        - ec2:AuthorizeSecurityGroupIngress
        - ec2:CreateLaunchTemplate
        - ec2:CreateLaunchTemplateVersion
        - ec2:CreateSecurityGroup
        - ec2:CreateSnapshot
        - ec2:CreateTags
        - ec2:CreateVolume
        - ec2:DeleteLaunchTemplateVersions
        - ec2:DeleteSnapshot
        - ec2:DeleteVolume
        - ec2:DescribeAccountAttributes
        - ec2:DescribeAvailabilityZones
        - ec2:DescribeImages
        - ec2:DescribeInstanceAttribute
        - ec2:DescribeInstanceStatus
        - ec2:DescribeInstanceTypes
        - ec2:DescribeInstances
        - ec2:DescribeLaunchTemplateVersions
        - ec2:DescribeLaunchTemplates
        - ec2:DescribeSecurityGroups
        - ec2:DescribeSnapshots
        - ec2:DescribeSubnets
        - ec2:DescribeVolumes
        - ec2:DetachVolume
        - ec2:ModifyInstanceAttribute
        - ec2:ModifyLaunchTemplate
        - ec2:ReportInstanceStatus
        - ec2:RevokeSecurityGroupEgress
        - ec2:RunInstances
        - ec2:StartInstances
        - ec2:StopInstances
        - ec2:TerminateInstances
        - iam:PassRole
        - mgn:ListTagsForResource

        https://docs.aws.amazon.com/mgn/latest/APIReference/API_StartTest.html

        :stability: experimental
        '''
        return typing.cast("Mgn", jsii.invoke(self, "toStartTest", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Mgn":
        '''(experimental) Grants permission to assign a resource tag.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifCreateAction()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/mgn/latest/APIReference/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("Mgn", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toTerminateTargetInstances")
    def to_terminate_target_instances(self) -> "Mgn":
        '''(experimental) Grants permission to terminate target instances.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - ec2:DeleteVolume
        - ec2:DescribeInstances
        - ec2:DescribeVolumes
        - ec2:TerminateInstances

        https://docs.aws.amazon.com/mgn/latest/APIReference/API_TerminateTargetInstances.html

        :stability: experimental
        '''
        return typing.cast("Mgn", jsii.invoke(self, "toTerminateTargetInstances", []))

    @jsii.member(jsii_name="toUnarchiveApplication")
    def to_unarchive_application(self) -> "Mgn":
        '''(experimental) Grants permission to unarchive an application.

        Access Level: Write

        https://docs.aws.amazon.com/mgn/latest/APIReference/API_UnarchiveApplication.html

        :stability: experimental
        '''
        return typing.cast("Mgn", jsii.invoke(self, "toUnarchiveApplication", []))

    @jsii.member(jsii_name="toUnarchiveWave")
    def to_unarchive_wave(self) -> "Mgn":
        '''(experimental) Grants permission to unarchive a wave.

        Access Level: Write

        https://docs.aws.amazon.com/mgn/latest/APIReference/API_UnarchiveWave.html

        :stability: experimental
        '''
        return typing.cast("Mgn", jsii.invoke(self, "toUnarchiveWave", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Mgn":
        '''(experimental) Grants permission to untag a resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/mgn/latest/APIReference/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("Mgn", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateAgentBacklogForMgn")
    def to_update_agent_backlog_for_mgn(self) -> "Mgn":
        '''(experimental) Grants permission to update agent backlog.

        Access Level: Write

        https://docs.aws.amazon.com/mgn/latest/ug/mgn-apis.html

        :stability: experimental
        '''
        return typing.cast("Mgn", jsii.invoke(self, "toUpdateAgentBacklogForMgn", []))

    @jsii.member(jsii_name="toUpdateAgentConversionInfoForMgn")
    def to_update_agent_conversion_info_for_mgn(self) -> "Mgn":
        '''(experimental) Grants permission to update agent conversion info.

        Access Level: Write

        https://docs.aws.amazon.com/mgn/latest/ug/mgn-apis.html

        :stability: experimental
        '''
        return typing.cast("Mgn", jsii.invoke(self, "toUpdateAgentConversionInfoForMgn", []))

    @jsii.member(jsii_name="toUpdateAgentReplicationInfoForMgn")
    def to_update_agent_replication_info_for_mgn(self) -> "Mgn":
        '''(experimental) Grants permission to update agent replication info.

        Access Level: Write

        https://docs.aws.amazon.com/mgn/latest/ug/mgn-apis.html

        :stability: experimental
        '''
        return typing.cast("Mgn", jsii.invoke(self, "toUpdateAgentReplicationInfoForMgn", []))

    @jsii.member(jsii_name="toUpdateAgentReplicationProcessStateForMgn")
    def to_update_agent_replication_process_state_for_mgn(self) -> "Mgn":
        '''(experimental) Grants permission to update agent replication process state.

        Access Level: Write

        https://docs.aws.amazon.com/mgn/latest/ug/mgn-apis.html

        :stability: experimental
        '''
        return typing.cast("Mgn", jsii.invoke(self, "toUpdateAgentReplicationProcessStateForMgn", []))

    @jsii.member(jsii_name="toUpdateAgentSourcePropertiesForMgn")
    def to_update_agent_source_properties_for_mgn(self) -> "Mgn":
        '''(experimental) Grants permission to update agent source properties.

        Access Level: Write

        https://docs.aws.amazon.com/mgn/latest/ug/mgn-apis.html

        :stability: experimental
        '''
        return typing.cast("Mgn", jsii.invoke(self, "toUpdateAgentSourcePropertiesForMgn", []))

    @jsii.member(jsii_name="toUpdateApplication")
    def to_update_application(self) -> "Mgn":
        '''(experimental) Grants permission to update an application.

        Access Level: Write

        https://docs.aws.amazon.com/mgn/latest/APIReference/API_UpdateApplication.html

        :stability: experimental
        '''
        return typing.cast("Mgn", jsii.invoke(self, "toUpdateApplication", []))

    @jsii.member(jsii_name="toUpdateLaunchConfiguration")
    def to_update_launch_configuration(self) -> "Mgn":
        '''(experimental) Grants permission to update launch configuration.

        Access Level: Write

        https://docs.aws.amazon.com/mgn/latest/APIReference/API_UpdateLaunchConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Mgn", jsii.invoke(self, "toUpdateLaunchConfiguration", []))

    @jsii.member(jsii_name="toUpdateLaunchConfigurationTemplate")
    def to_update_launch_configuration_template(self) -> "Mgn":
        '''(experimental) Grants permission to update launch configuration.

        Access Level: Write

        https://docs.aws.amazon.com/mgn/latest/APIReference/API_UpdateLaunchConfigurationTemplate.html

        :stability: experimental
        '''
        return typing.cast("Mgn", jsii.invoke(self, "toUpdateLaunchConfigurationTemplate", []))

    @jsii.member(jsii_name="toUpdateReplicationConfiguration")
    def to_update_replication_configuration(self) -> "Mgn":
        '''(experimental) Grants permission to update replication configuration.

        Access Level: Write

        https://docs.aws.amazon.com/mgn/latest/APIReference/API_UpdateReplicationConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Mgn", jsii.invoke(self, "toUpdateReplicationConfiguration", []))

    @jsii.member(jsii_name="toUpdateReplicationConfigurationTemplate")
    def to_update_replication_configuration_template(self) -> "Mgn":
        '''(experimental) Grants permission to update replication configuration template.

        Access Level: Write

        https://docs.aws.amazon.com/mgn/latest/APIReference/API_UpdateReplicationConfigurationTemplate.html

        :stability: experimental
        '''
        return typing.cast("Mgn", jsii.invoke(self, "toUpdateReplicationConfigurationTemplate", []))

    @jsii.member(jsii_name="toUpdateSourceServerReplicationType")
    def to_update_source_server_replication_type(self) -> "Mgn":
        '''(experimental) Grants permission to update source server replication type.

        Access Level: Write

        https://docs.aws.amazon.com/mgn/latest/APIReference/API_UpdateSourceServerReplicationType.html

        :stability: experimental
        '''
        return typing.cast("Mgn", jsii.invoke(self, "toUpdateSourceServerReplicationType", []))

    @jsii.member(jsii_name="toUpdateWave")
    def to_update_wave(self) -> "Mgn":
        '''(experimental) Grants permission to update a wave.

        Access Level: Write

        https://docs.aws.amazon.com/mgn/latest/APIReference/API_UpdateWave.html

        :stability: experimental
        '''
        return typing.cast("Mgn", jsii.invoke(self, "toUpdateWave", []))

    @jsii.member(jsii_name="toVerifyClientRoleForMgn")
    def to_verify_client_role_for_mgn(self) -> "Mgn":
        '''(experimental) Grants permission to verify client role.

        Access Level: Read

        https://docs.aws.amazon.com/mgn/latest/ug/mgn-apis.html

        :stability: experimental
        '''
        return typing.cast("Mgn", jsii.invoke(self, "toVerifyClientRoleForMgn", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e387e57359b53f8308361df5bc4911dadb409d7e6913baecc0b20a355e9d28fd)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b863a562261f360799fceea77a87431d82a6cc5878adfe806c60eb3079821d7e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class MigrationhubOrchestrator(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.MigrationhubOrchestrator",
):
    '''(experimental) Statement provider for service `migrationhub-orchestrator <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsmigrationhuborchestrator.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `migrationhub-orchestrator <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsmigrationhuborchestrator.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onWorkflow")
    def on_workflow(
        self,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "MigrationhubOrchestrator":
        '''(experimental) Adds a resource of type workflow to the statement.

        https://docs.aws.amazon.com/migrationhub-orchestrator/latest/userguide/workflow.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__486fbc5677107e8afa89f4e88ef439c0b325d13434d32362d3c5ca6c8ab18367)
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("MigrationhubOrchestrator", jsii.invoke(self, "onWorkflow", [resource_id, account, region, partition]))

    @jsii.member(jsii_name="toCreateWorkflow")
    def to_create_workflow(self) -> "MigrationhubOrchestrator":
        '''(experimental) Grants permission to create a workflow based on the selected template.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/migrationhub-orchestrator/latest/APIReference/API_CreateWorkflow.html

        :stability: experimental
        '''
        return typing.cast("MigrationhubOrchestrator", jsii.invoke(self, "toCreateWorkflow", []))

    @jsii.member(jsii_name="toCreateWorkflowStep")
    def to_create_workflow_step(self) -> "MigrationhubOrchestrator":
        '''(experimental) Grants permission to create a step under a workflow and a specific step group.

        Access Level: Write

        https://docs.aws.amazon.com/migrationhub-orchestrator/latest/APIReference/API_CreateWorkflowStep.html

        :stability: experimental
        '''
        return typing.cast("MigrationhubOrchestrator", jsii.invoke(self, "toCreateWorkflowStep", []))

    @jsii.member(jsii_name="toCreateWorkflowStepGroup")
    def to_create_workflow_step_group(self) -> "MigrationhubOrchestrator":
        '''(experimental) Grants permission to to create a custom step group for a given workflow.

        Access Level: Write

        https://docs.aws.amazon.com/migrationhub-orchestrator/latest/APIReference/API_CreateWorkflowStepGroup.html

        :stability: experimental
        '''
        return typing.cast("MigrationhubOrchestrator", jsii.invoke(self, "toCreateWorkflowStepGroup", []))

    @jsii.member(jsii_name="toDeleteWorkflow")
    def to_delete_workflow(self) -> "MigrationhubOrchestrator":
        '''(experimental) Grants permission to a workflow.

        Access Level: Write

        https://docs.aws.amazon.com/migrationhub-orchestrator/latest/APIReference/API_DeleteWorkflow.html

        :stability: experimental
        '''
        return typing.cast("MigrationhubOrchestrator", jsii.invoke(self, "toDeleteWorkflow", []))

    @jsii.member(jsii_name="toDeleteWorkflowStep")
    def to_delete_workflow_step(self) -> "MigrationhubOrchestrator":
        '''(experimental) Grants permission to delete a step from a specific step group under a workflow.

        Access Level: Write

        https://docs.aws.amazon.com/migrationhub-orchestrator/latest/APIReference/API_DeleteWorkflowStep.html

        :stability: experimental
        '''
        return typing.cast("MigrationhubOrchestrator", jsii.invoke(self, "toDeleteWorkflowStep", []))

    @jsii.member(jsii_name="toDeleteWorkflowStepGroup")
    def to_delete_workflow_step_group(self) -> "MigrationhubOrchestrator":
        '''(experimental) Grants permission to delete a step group associated with a workflow.

        Access Level: Write

        https://docs.aws.amazon.com/migrationhub-orchestrator/latest/APIReference/API_DeleteWorkflowStepGroup.html

        :stability: experimental
        '''
        return typing.cast("MigrationhubOrchestrator", jsii.invoke(self, "toDeleteWorkflowStepGroup", []))

    @jsii.member(jsii_name="toGetMessage")
    def to_get_message(self) -> "MigrationhubOrchestrator":
        '''(experimental) Grants permission to the plugin to receive information from the service.

        Access Level: Read

        https://docs.aws.amazon.com/migrationhub-orchestrator/latest/APIReference/API_GetMessage.html

        :stability: experimental
        '''
        return typing.cast("MigrationhubOrchestrator", jsii.invoke(self, "toGetMessage", []))

    @jsii.member(jsii_name="toGetTemplate")
    def to_get_template(self) -> "MigrationhubOrchestrator":
        '''(experimental) Grants permission to get retrieve metadata for a Template.

        Access Level: Read

        https://docs.aws.amazon.com/migrationhub-orchestrator/latest/APIReference/API_GetTemplate.html

        :stability: experimental
        '''
        return typing.cast("MigrationhubOrchestrator", jsii.invoke(self, "toGetTemplate", []))

    @jsii.member(jsii_name="toGetTemplateStep")
    def to_get_template_step(self) -> "MigrationhubOrchestrator":
        '''(experimental) Grants permission to retrieve details of a step associated with a template and a step group.

        Access Level: Read

        https://docs.aws.amazon.com/migrationhub-orchestrator/latest/APIReference/API_GetTemplateStep.html

        :stability: experimental
        '''
        return typing.cast("MigrationhubOrchestrator", jsii.invoke(self, "toGetTemplateStep", []))

    @jsii.member(jsii_name="toGetTemplateStepGroup")
    def to_get_template_step_group(self) -> "MigrationhubOrchestrator":
        '''(experimental) Grants permission to retrieve metadata of a step group under a template.

        Access Level: Read

        https://docs.aws.amazon.com/migrationhub-orchestrator/latest/APIReference/API_GetTemplateStepGroup.html

        :stability: experimental
        '''
        return typing.cast("MigrationhubOrchestrator", jsii.invoke(self, "toGetTemplateStepGroup", []))

    @jsii.member(jsii_name="toGetWorkflow")
    def to_get_workflow(self) -> "MigrationhubOrchestrator":
        '''(experimental) Grants permission to retrieve metadata asscociated with a workflow.

        Access Level: Read

        https://docs.aws.amazon.com/migrationhub-orchestrator/latest/APIReference/API_GetWorkflow.html

        :stability: experimental
        '''
        return typing.cast("MigrationhubOrchestrator", jsii.invoke(self, "toGetWorkflow", []))

    @jsii.member(jsii_name="toGetWorkflowStep")
    def to_get_workflow_step(self) -> "MigrationhubOrchestrator":
        '''(experimental) Grants permission to get details of step associated with a workflow and a step group.

        Access Level: Read

        https://docs.aws.amazon.com/migrationhub-orchestrator/latest/APIReference/API_GetWorkflowStep.html

        :stability: experimental
        '''
        return typing.cast("MigrationhubOrchestrator", jsii.invoke(self, "toGetWorkflowStep", []))

    @jsii.member(jsii_name="toGetWorkflowStepGroup")
    def to_get_workflow_step_group(self) -> "MigrationhubOrchestrator":
        '''(experimental) Grants permission to get details of a step group associated with a workflow.

        Access Level: Read

        https://docs.aws.amazon.com/migrationhub-orchestrator/latest/APIReference/API_GetWorkflowStepGroup.html

        :stability: experimental
        '''
        return typing.cast("MigrationhubOrchestrator", jsii.invoke(self, "toGetWorkflowStepGroup", []))

    @jsii.member(jsii_name="toListPlugins")
    def to_list_plugins(self) -> "MigrationhubOrchestrator":
        '''(experimental) Grants permission to get a list all registered Plugins.

        Access Level: List

        https://docs.aws.amazon.com/migrationhub-orchestrator/latest/APIReference/API_ListPlugins.html

        :stability: experimental
        '''
        return typing.cast("MigrationhubOrchestrator", jsii.invoke(self, "toListPlugins", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "MigrationhubOrchestrator":
        '''(experimental) Grants permission to get a list of all the tags tied to a resource.

        Access Level: Read

        https://docs.aws.amazon.com/migrationhub-orchestrator/latest/APIReference/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("MigrationhubOrchestrator", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toListTemplates")
    def to_list_templates(self) -> "MigrationhubOrchestrator":
        '''(experimental) Grants permission to get a list of all Templates available to customer.

        Access Level: List

        https://docs.aws.amazon.com/migrationhub-orchestrator/latest/APIReference/API_ListTemplates.html

        :stability: experimental
        '''
        return typing.cast("MigrationhubOrchestrator", jsii.invoke(self, "toListTemplates", []))

    @jsii.member(jsii_name="toListTemplateStepGroups")
    def to_list_template_step_groups(self) -> "MigrationhubOrchestrator":
        '''(experimental) Grants permission to lists step groups of a template.

        Access Level: List

        https://docs.aws.amazon.com/migrationhub-orchestrator/latest/APIReference/API_ListTemplateStepGroups.html

        :stability: experimental
        '''
        return typing.cast("MigrationhubOrchestrator", jsii.invoke(self, "toListTemplateStepGroups", []))

    @jsii.member(jsii_name="toListTemplateSteps")
    def to_list_template_steps(self) -> "MigrationhubOrchestrator":
        '''(experimental) Grants permission to get a list of steps in a step group.

        Access Level: List

        https://docs.aws.amazon.com/migrationhub-orchestrator/latest/APIReference/API_ListServers.html

        :stability: experimental
        '''
        return typing.cast("MigrationhubOrchestrator", jsii.invoke(self, "toListTemplateSteps", []))

    @jsii.member(jsii_name="toListWorkflows")
    def to_list_workflows(self) -> "MigrationhubOrchestrator":
        '''(experimental) Grants permission to list all workflows.

        Access Level: List

        https://docs.aws.amazon.com/migrationhub-orchestrator/latest/APIReference/API_ListWorkflows.html

        :stability: experimental
        '''
        return typing.cast("MigrationhubOrchestrator", jsii.invoke(self, "toListWorkflows", []))

    @jsii.member(jsii_name="toListWorkflowStepGroups")
    def to_list_workflow_step_groups(self) -> "MigrationhubOrchestrator":
        '''(experimental) Grants permission to get list of step groups associated with a workflow.

        Access Level: List

        https://docs.aws.amazon.com/migrationhub-orchestrator/latest/APIReference/API_ListWorkflowStepGroups.html

        :stability: experimental
        '''
        return typing.cast("MigrationhubOrchestrator", jsii.invoke(self, "toListWorkflowStepGroups", []))

    @jsii.member(jsii_name="toListWorkflowSteps")
    def to_list_workflow_steps(self) -> "MigrationhubOrchestrator":
        '''(experimental) Grants permission to get a list of steps within step group associated with a workflow.

        Access Level: List

        https://docs.aws.amazon.com/migrationhub-orchestrator/latest/APIReference/API_ListAntiPatterns.html

        :stability: experimental
        '''
        return typing.cast("MigrationhubOrchestrator", jsii.invoke(self, "toListWorkflowSteps", []))

    @jsii.member(jsii_name="toRegisterPlugin")
    def to_register_plugin(self) -> "MigrationhubOrchestrator":
        '''(experimental) Grants permission to register the plugin to receive an ID and to start receiving messages from the service.

        Access Level: Write

        https://docs.aws.amazon.com/migrationhub-orchestrator/latest/APIReference/API_RegisterPlugin.html

        :stability: experimental
        '''
        return typing.cast("MigrationhubOrchestrator", jsii.invoke(self, "toRegisterPlugin", []))

    @jsii.member(jsii_name="toRetryWorkflowStep")
    def to_retry_workflow_step(self) -> "MigrationhubOrchestrator":
        '''(experimental) Grants permission to retry a failed step within a workflow.

        Access Level: Write

        https://docs.aws.amazon.com/migrationhub-orchestrator/latest/APIReference/API_RetryWorkflowStep.html

        :stability: experimental
        '''
        return typing.cast("MigrationhubOrchestrator", jsii.invoke(self, "toRetryWorkflowStep", []))

    @jsii.member(jsii_name="toSendMessage")
    def to_send_message(self) -> "MigrationhubOrchestrator":
        '''(experimental) Grants permission to the plugin to send information to the service.

        Access Level: Write

        https://docs.aws.amazon.com/migrationhub-orchestrator/latest/APIReference/API_SendMessage.html

        :stability: experimental
        '''
        return typing.cast("MigrationhubOrchestrator", jsii.invoke(self, "toSendMessage", []))

    @jsii.member(jsii_name="toStartWorkflow")
    def to_start_workflow(self) -> "MigrationhubOrchestrator":
        '''(experimental) Grants permission to start a workflow or resume a stopped workflow.

        Access Level: Write

        https://docs.aws.amazon.com/migrationhub-orchestrator/latest/APIReference/API_StartWorkflow.html

        :stability: experimental
        '''
        return typing.cast("MigrationhubOrchestrator", jsii.invoke(self, "toStartWorkflow", []))

    @jsii.member(jsii_name="toStopWorkflow")
    def to_stop_workflow(self) -> "MigrationhubOrchestrator":
        '''(experimental) Grants permission to stop a workflow.

        Access Level: Write

        https://docs.aws.amazon.com/migrationhub-orchestrator/latest/APIReference/API_StopWorkflow.html

        :stability: experimental
        '''
        return typing.cast("MigrationhubOrchestrator", jsii.invoke(self, "toStopWorkflow", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "MigrationhubOrchestrator":
        '''(experimental) Grants permission to add tags to a resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/migrationhub-orchestrator/latest/APIReference/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("MigrationhubOrchestrator", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "MigrationhubOrchestrator":
        '''(experimental) Grants permission to remove tags from a resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/migrationhub-orchestrator/latest/APIReference/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("MigrationhubOrchestrator", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateWorkflow")
    def to_update_workflow(self) -> "MigrationhubOrchestrator":
        '''(experimental) Grants permission to update the metadata associated with the workflow.

        Access Level: Write

        https://docs.aws.amazon.com/migrationhub-orchestrator/latest/APIReference/API_UpdateWorkflow.html

        :stability: experimental
        '''
        return typing.cast("MigrationhubOrchestrator", jsii.invoke(self, "toUpdateWorkflow", []))

    @jsii.member(jsii_name="toUpdateWorkflowStep")
    def to_update_workflow_step(self) -> "MigrationhubOrchestrator":
        '''(experimental) Grants permission to update metadata and status of a custom step within a workflow.

        Access Level: Write

        https://docs.aws.amazon.com/migrationhub-orchestrator/latest/APIReference/API_UpdateWorkflowStep.html

        :stability: experimental
        '''
        return typing.cast("MigrationhubOrchestrator", jsii.invoke(self, "toUpdateWorkflowStep", []))

    @jsii.member(jsii_name="toUpdateWorkflowStepGroup")
    def to_update_workflow_step_group(self) -> "MigrationhubOrchestrator":
        '''(experimental) Grants permission to update metadata associated with a step group in a given workflow.

        Access Level: Write

        https://docs.aws.amazon.com/migrationhub-orchestrator/latest/APIReference/API_UpdateWorkflowStepGroup.html

        :stability: experimental
        '''
        return typing.cast("MigrationhubOrchestrator", jsii.invoke(self, "toUpdateWorkflowStepGroup", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__443a783184c6428eac466574e5f9cd8f6fc876c3663f7577556a577934191453)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__80e901e6c6aaedb196755986b5f6a5a5743ead6c8144bdeba4359ca90659cd35)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class MigrationhubStrategy(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.MigrationhubStrategy",
):
    '''(experimental) Statement provider for service `migrationhub-strategy <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsmigrationhubstrategyrecommendations.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `migrationhub-strategy <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsmigrationhubstrategyrecommendations.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="toGetAntiPattern")
    def to_get_anti_pattern(self) -> "MigrationhubStrategy":
        '''(experimental) Grants permission to get details of each anti pattern that collector should look at in a customer's environment.

        Access Level: Read

        https://docs.aws.amazon.com/migrationhub-strategy/latest/APIReference/API_GetAntiPattern.html

        :stability: experimental
        '''
        return typing.cast("MigrationhubStrategy", jsii.invoke(self, "toGetAntiPattern", []))

    @jsii.member(jsii_name="toGetApplicationComponentDetails")
    def to_get_application_component_details(self) -> "MigrationhubStrategy":
        '''(experimental) Grants permission to get details of an application.

        Access Level: Read

        https://docs.aws.amazon.com/migrationhub-strategy/latest/APIReference/API_GetApplicationComponentDetails.html

        :stability: experimental
        '''
        return typing.cast("MigrationhubStrategy", jsii.invoke(self, "toGetApplicationComponentDetails", []))

    @jsii.member(jsii_name="toGetApplicationComponentStrategies")
    def to_get_application_component_strategies(self) -> "MigrationhubStrategy":
        '''(experimental) Grants permission to get a list of all recommended strategies and tools for an application running in a server.

        Access Level: Read

        https://docs.aws.amazon.com/migrationhub-strategy/latest/APIReference/API_GetApplicationComponentStrategies.html

        :stability: experimental
        '''
        return typing.cast("MigrationhubStrategy", jsii.invoke(self, "toGetApplicationComponentStrategies", []))

    @jsii.member(jsii_name="toGetAssessment")
    def to_get_assessment(self) -> "MigrationhubStrategy":
        '''(experimental) Grants permission to retrieve status of an on-going assessment.

        Access Level: Read

        https://docs.aws.amazon.com/migrationhub-strategy/latest/APIReference/API_GetAssessment.html

        :stability: experimental
        '''
        return typing.cast("MigrationhubStrategy", jsii.invoke(self, "toGetAssessment", []))

    @jsii.member(jsii_name="toGetImportFileTask")
    def to_get_import_file_task(self) -> "MigrationhubStrategy":
        '''(experimental) Grants permission to get details of a specific import task.

        Access Level: Read

        https://docs.aws.amazon.com/migrationhub-strategy/latest/APIReference/API_GetImportFileTask.html

        :stability: experimental
        '''
        return typing.cast("MigrationhubStrategy", jsii.invoke(self, "toGetImportFileTask", []))

    @jsii.member(jsii_name="toGetLatestAssessmentId")
    def to_get_latest_assessment_id(self) -> "MigrationhubStrategy":
        '''(experimental) Grants permission to retrieve the latest assessment id.

        Access Level: Read

        https://docs.aws.amazon.com/migrationhub-strategy/latest/APIReference/API_GetLatestAssessmentId.html

        :stability: experimental
        '''
        return typing.cast("MigrationhubStrategy", jsii.invoke(self, "toGetLatestAssessmentId", []))

    @jsii.member(jsii_name="toGetMessage")
    def to_get_message(self) -> "MigrationhubStrategy":
        '''(experimental) Grants permission to the collector to receive information from the service.

        Access Level: Read

        https://docs.aws.amazon.com/migrationhub-strategy/latest/APIReference/API_GetMessage.html

        :stability: experimental
        '''
        return typing.cast("MigrationhubStrategy", jsii.invoke(self, "toGetMessage", []))

    @jsii.member(jsii_name="toGetPortfolioPreferences")
    def to_get_portfolio_preferences(self) -> "MigrationhubStrategy":
        '''(experimental) Grants permission to retrieve customer migration/Modernization preferences.

        Access Level: Read

        https://docs.aws.amazon.com/migrationhub-strategy/latest/APIReference/API_GetPortfolioPreferences.html

        :stability: experimental
        '''
        return typing.cast("MigrationhubStrategy", jsii.invoke(self, "toGetPortfolioPreferences", []))

    @jsii.member(jsii_name="toGetPortfolioSummary")
    def to_get_portfolio_summary(self) -> "MigrationhubStrategy":
        '''(experimental) Grants permission to retrieve overall summary (number-of servers to rehost etc as well as overall number of anti patterns).

        Access Level: Read

        https://docs.aws.amazon.com/migrationhub-strategy/latest/APIReference/API_GetPortfolioSummary.html

        :stability: experimental
        '''
        return typing.cast("MigrationhubStrategy", jsii.invoke(self, "toGetPortfolioSummary", []))

    @jsii.member(jsii_name="toGetRecommendationReportDetails")
    def to_get_recommendation_report_details(self) -> "MigrationhubStrategy":
        '''(experimental) Grants permission to retrieve detailed information about a recommendation report.

        Access Level: Read

        https://docs.aws.amazon.com/migrationhub-strategy/latest/APIReference/API_GetRecommendationReportDetails.html

        :stability: experimental
        '''
        return typing.cast("MigrationhubStrategy", jsii.invoke(self, "toGetRecommendationReportDetails", []))

    @jsii.member(jsii_name="toGetServerDetails")
    def to_get_server_details(self) -> "MigrationhubStrategy":
        '''(experimental) Grants permission to get info about a specific server.

        Access Level: Read

        https://docs.aws.amazon.com/migrationhub-strategy/latest/APIReference/API_GetServerDetails.html

        :stability: experimental
        '''
        return typing.cast("MigrationhubStrategy", jsii.invoke(self, "toGetServerDetails", []))

    @jsii.member(jsii_name="toGetServerStrategies")
    def to_get_server_strategies(self) -> "MigrationhubStrategy":
        '''(experimental) Grants permission to get recommended strategies and tools for a specific server.

        Access Level: Read

        https://docs.aws.amazon.com/migrationhub-strategy/latest/APIReference/API_GetServerStrategies.html

        :stability: experimental
        '''
        return typing.cast("MigrationhubStrategy", jsii.invoke(self, "toGetServerStrategies", []))

    @jsii.member(jsii_name="toListAntiPatterns")
    def to_list_anti_patterns(self) -> "MigrationhubStrategy":
        '''(experimental) Grants permission to get a list of all anti patterns that collector should look for in a customer's environment.

        Access Level: List

        https://docs.aws.amazon.com/migrationhub-strategy/latest/APIReference/API_ListAntiPatterns.html

        :stability: experimental
        '''
        return typing.cast("MigrationhubStrategy", jsii.invoke(self, "toListAntiPatterns", []))

    @jsii.member(jsii_name="toListApplicationComponents")
    def to_list_application_components(self) -> "MigrationhubStrategy":
        '''(experimental) Grants permission to get a list of all applications running on servers on customer's servers.

        Access Level: List

        https://docs.aws.amazon.com/migrationhub-strategy/latest/APIReference/API_ListApplicationComponents.html

        :stability: experimental
        '''
        return typing.cast("MigrationhubStrategy", jsii.invoke(self, "toListApplicationComponents", []))

    @jsii.member(jsii_name="toListCollectors")
    def to_list_collectors(self) -> "MigrationhubStrategy":
        '''(experimental) Grants permission to get a list of all collectors installed by the customer.

        Access Level: List

        https://docs.aws.amazon.com/migrationhub-strategy/latest/APIReference/API_ListCollectors.html

        :stability: experimental
        '''
        return typing.cast("MigrationhubStrategy", jsii.invoke(self, "toListCollectors", []))

    @jsii.member(jsii_name="toListImportFileTask")
    def to_list_import_file_task(self) -> "MigrationhubStrategy":
        '''(experimental) Grants permission to get list of all imports performed by the customer.

        Access Level: List

        https://docs.aws.amazon.com/migrationhub-strategy/latest/APIReference/API_ListImportFileTask.html

        :stability: experimental
        '''
        return typing.cast("MigrationhubStrategy", jsii.invoke(self, "toListImportFileTask", []))

    @jsii.member(jsii_name="toListJarArtifacts")
    def to_list_jar_artifacts(self) -> "MigrationhubStrategy":
        '''(experimental) Grants permission to get a list of binaries that collector should assess.

        Access Level: List

        https://docs.aws.amazon.com/migrationhub-strategy/latest/APIReference/API_ListJarArtifacts.html

        :stability: experimental
        '''
        return typing.cast("MigrationhubStrategy", jsii.invoke(self, "toListJarArtifacts", []))

    @jsii.member(jsii_name="toListServers")
    def to_list_servers(self) -> "MigrationhubStrategy":
        '''(experimental) Grants permission to get a list of all servers in a customer's environment.

        Access Level: List

        https://docs.aws.amazon.com/migrationhub-strategy/latest/APIReference/API_ListServers.html

        :stability: experimental
        '''
        return typing.cast("MigrationhubStrategy", jsii.invoke(self, "toListServers", []))

    @jsii.member(jsii_name="toPutPortfolioPreferences")
    def to_put_portfolio_preferences(self) -> "MigrationhubStrategy":
        '''(experimental) Grants permission to save customer's Migration/Modernization preferences.

        Access Level: Write

        https://docs.aws.amazon.com/migrationhub-strategy/latest/APIReference/API_PutPortfolioPreferences.html

        :stability: experimental
        '''
        return typing.cast("MigrationhubStrategy", jsii.invoke(self, "toPutPortfolioPreferences", []))

    @jsii.member(jsii_name="toRegisterCollector")
    def to_register_collector(self) -> "MigrationhubStrategy":
        '''(experimental) Grants permission to register the collector to receive an ID and to start receiving messages from the service.

        Access Level: Write

        https://docs.aws.amazon.com/migrationhub-strategy/latest/APIReference/API_RegisterCollector.html

        :stability: experimental
        '''
        return typing.cast("MigrationhubStrategy", jsii.invoke(self, "toRegisterCollector", []))

    @jsii.member(jsii_name="toSendMessage")
    def to_send_message(self) -> "MigrationhubStrategy":
        '''(experimental) Grants permission to the collector to send information to the service.

        Access Level: Write

        https://docs.aws.amazon.com/migrationhub-strategy/latest/APIReference/API_SendMessage.html

        :stability: experimental
        '''
        return typing.cast("MigrationhubStrategy", jsii.invoke(self, "toSendMessage", []))

    @jsii.member(jsii_name="toStartAssessment")
    def to_start_assessment(self) -> "MigrationhubStrategy":
        '''(experimental) Grants permission to start assessment in a customer's environment (collect data from all servers and provide recommendations).

        Access Level: Write

        https://docs.aws.amazon.com/migrationhub-strategy/latest/APIReference/API_StartAssessment.html

        :stability: experimental
        '''
        return typing.cast("MigrationhubStrategy", jsii.invoke(self, "toStartAssessment", []))

    @jsii.member(jsii_name="toStartImportFileTask")
    def to_start_import_file_task(self) -> "MigrationhubStrategy":
        '''(experimental) Grants permission to start importing data from a file provided by customer.

        Access Level: Write

        https://docs.aws.amazon.com/migrationhub-strategy/latest/APIReference/API_StartImportFileTask.html

        :stability: experimental
        '''
        return typing.cast("MigrationhubStrategy", jsii.invoke(self, "toStartImportFileTask", []))

    @jsii.member(jsii_name="toStartRecommendationReportGeneration")
    def to_start_recommendation_report_generation(self) -> "MigrationhubStrategy":
        '''(experimental) Grants permission to start generating a recommendation report.

        Access Level: Write

        https://docs.aws.amazon.com/migrationhub-strategy/latest/APIReference/API_StartRecommendationReportGeneration.html

        :stability: experimental
        '''
        return typing.cast("MigrationhubStrategy", jsii.invoke(self, "toStartRecommendationReportGeneration", []))

    @jsii.member(jsii_name="toStopAssessment")
    def to_stop_assessment(self) -> "MigrationhubStrategy":
        '''(experimental) Grants permission to stop an on-going assessment.

        Access Level: Write

        https://docs.aws.amazon.com/migrationhub-strategy/latest/APIReference/API_StopAssessment.html

        :stability: experimental
        '''
        return typing.cast("MigrationhubStrategy", jsii.invoke(self, "toStopAssessment", []))

    @jsii.member(jsii_name="toUpdateApplicationComponentConfig")
    def to_update_application_component_config(self) -> "MigrationhubStrategy":
        '''(experimental) Grants permission to update details for an application.

        Access Level: Write

        https://docs.aws.amazon.com/migrationhub-strategy/latest/APIReference/API_UpdateApplicationComponentConfig.html

        :stability: experimental
        '''
        return typing.cast("MigrationhubStrategy", jsii.invoke(self, "toUpdateApplicationComponentConfig", []))

    @jsii.member(jsii_name="toUpdateCollectorConfiguration")
    def to_update_collector_configuration(self) -> "MigrationhubStrategy":
        '''(experimental) Grants permission to the collector to send configuration information to the service.

        Access Level: Write

        https://docs.aws.amazon.com/migrationhub-strategy/latest/APIReference/API_UpdateCollectorConfiguration.html

        :stability: experimental
        '''
        return typing.cast("MigrationhubStrategy", jsii.invoke(self, "toUpdateCollectorConfiguration", []))

    @jsii.member(jsii_name="toUpdateServerConfig")
    def to_update_server_config(self) -> "MigrationhubStrategy":
        '''(experimental) Grants permission to update info on a server along with the recommended strategy.

        Access Level: Write

        https://docs.aws.amazon.com/migrationhub-strategy/latest/APIReference/API_UpdateServerConfig.html

        :stability: experimental
        '''
        return typing.cast("MigrationhubStrategy", jsii.invoke(self, "toUpdateServerConfig", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__92104193c142cf9f3390ce560e60c91403a8e35ca19e4bbd081b1a2b71055645)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2d6a75c4af4011cef00e28877f214ba2f28bd862c672b1a8b6c4066ddf8adbae)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Mobileanalytics(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Mobileanalytics",
):
    '''(experimental) Statement provider for service `mobileanalytics <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonmobileanalytics.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `mobileanalytics <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonmobileanalytics.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="toGetFinancialReports")
    def to_get_financial_reports(self) -> "Mobileanalytics":
        '''(experimental) Grant access to financial metrics for an app.

        Access Level: Read

        :stability: experimental
        '''
        return typing.cast("Mobileanalytics", jsii.invoke(self, "toGetFinancialReports", []))

    @jsii.member(jsii_name="toGetReports")
    def to_get_reports(self) -> "Mobileanalytics":
        '''(experimental) Grant access to standard metrics for an app.

        Access Level: Read

        :stability: experimental
        '''
        return typing.cast("Mobileanalytics", jsii.invoke(self, "toGetReports", []))

    @jsii.member(jsii_name="toPutEvents")
    def to_put_events(self) -> "Mobileanalytics":
        '''(experimental) The PutEvents operation records one or more events.

        Access Level: Write

        https://docs.aws.amazon.com/mobileanalytics/latest/ug/PutEvents.html

        :stability: experimental
        '''
        return typing.cast("Mobileanalytics", jsii.invoke(self, "toPutEvents", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__867ae0795e3c36157075153530262d8a8e8fea0bc9bc3d13d34d7c3fce741e5d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f6892a4702d5a249e542fd71b4f89be9727e203c642bacd166280f7efcb0951f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Mobilehub(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Mobilehub",
):
    '''(experimental) Statement provider for service `mobilehub <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsmobilehub.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `mobilehub <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsmobilehub.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onProject")
    def on_project(
        self,
        project_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Mobilehub":
        '''(experimental) Adds a resource of type project to the statement.

        https://docs.aws.amazon.com/mobile-hub/latest/developerguide/reference-mobile-hub-iam-managed-policies.html

        :param project_id: - Identifier for the projectId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1562eed8196fa22c7ed36e4fdb0a766681b289e43458a57a2a504dfbfcd8c0c4)
            check_type(argname="argument project_id", value=project_id, expected_type=type_hints["project_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Mobilehub", jsii.invoke(self, "onProject", [project_id, account, region, partition]))

    @jsii.member(jsii_name="toCreateProject")
    def to_create_project(self) -> "Mobilehub":
        '''(experimental) Create a project.

        Access Level: Write

        https://docs.aws.amazon.com/mobile-hub/latest/developerguide/managed-policies.html

        :stability: experimental
        '''
        return typing.cast("Mobilehub", jsii.invoke(self, "toCreateProject", []))

    @jsii.member(jsii_name="toCreateServiceRole")
    def to_create_service_role(self) -> "Mobilehub":
        '''(experimental) Enable AWS Mobile Hub in the account by creating the required service role.

        Access Level: Write

        https://docs.aws.amazon.com/mobile-hub/latest/developerguide/managed-policies.html

        :stability: experimental
        '''
        return typing.cast("Mobilehub", jsii.invoke(self, "toCreateServiceRole", []))

    @jsii.member(jsii_name="toDeleteProject")
    def to_delete_project(self) -> "Mobilehub":
        '''(experimental) Delete the specified project.

        Access Level: Write

        https://docs.aws.amazon.com/mobile-hub/latest/developerguide/managed-policies.html

        :stability: experimental
        '''
        return typing.cast("Mobilehub", jsii.invoke(self, "toDeleteProject", []))

    @jsii.member(jsii_name="toDeleteProjectSnapshot")
    def to_delete_project_snapshot(self) -> "Mobilehub":
        '''(experimental) Delete a saved snapshot of project configuration.

        Access Level: Write

        https://docs.aws.amazon.com/mobile-hub/latest/developerguide/managed-policies.html

        :stability: experimental
        '''
        return typing.cast("Mobilehub", jsii.invoke(self, "toDeleteProjectSnapshot", []))

    @jsii.member(jsii_name="toDeployToStage")
    def to_deploy_to_stage(self) -> "Mobilehub":
        '''(experimental) Deploy changes to the specified stage.

        Access Level: Write

        https://docs.aws.amazon.com/mobile-hub/latest/developerguide/managed-policies.html

        :stability: experimental
        '''
        return typing.cast("Mobilehub", jsii.invoke(self, "toDeployToStage", []))

    @jsii.member(jsii_name="toDescribeBundle")
    def to_describe_bundle(self) -> "Mobilehub":
        '''(experimental) Describe the download bundle.

        Access Level: Read

        https://docs.aws.amazon.com/mobile-hub/latest/developerguide/managed-policies.html

        :stability: experimental
        '''
        return typing.cast("Mobilehub", jsii.invoke(self, "toDescribeBundle", []))

    @jsii.member(jsii_name="toExportBundle")
    def to_export_bundle(self) -> "Mobilehub":
        '''(experimental) Export the download bundle.

        Access Level: Read

        https://docs.aws.amazon.com/mobile-hub/latest/developerguide/managed-policies.html

        :stability: experimental
        '''
        return typing.cast("Mobilehub", jsii.invoke(self, "toExportBundle", []))

    @jsii.member(jsii_name="toExportProject")
    def to_export_project(self) -> "Mobilehub":
        '''(experimental) Export the project configuration.

        Access Level: Read

        https://docs.aws.amazon.com/mobile-hub/latest/developerguide/managed-policies.html

        :stability: experimental
        '''
        return typing.cast("Mobilehub", jsii.invoke(self, "toExportProject", []))

    @jsii.member(jsii_name="toGenerateProjectParameters")
    def to_generate_project_parameters(self) -> "Mobilehub":
        '''(experimental) Generate project parameters required for code generation.

        Access Level: Read

        https://docs.aws.amazon.com/mobile-hub/latest/developerguide/managed-policies.html

        :stability: experimental
        '''
        return typing.cast("Mobilehub", jsii.invoke(self, "toGenerateProjectParameters", []))

    @jsii.member(jsii_name="toGetProject")
    def to_get_project(self) -> "Mobilehub":
        '''(experimental) Get project configuration and resources.

        Access Level: Read

        https://docs.aws.amazon.com/mobile-hub/latest/developerguide/managed-policies.html

        :stability: experimental
        '''
        return typing.cast("Mobilehub", jsii.invoke(self, "toGetProject", []))

    @jsii.member(jsii_name="toGetProjectSnapshot")
    def to_get_project_snapshot(self) -> "Mobilehub":
        '''(experimental) Fetch the previously exported project configuration snapshot.

        Access Level: Read

        https://docs.aws.amazon.com/mobile-hub/latest/developerguide/managed-policies.html

        :stability: experimental
        '''
        return typing.cast("Mobilehub", jsii.invoke(self, "toGetProjectSnapshot", []))

    @jsii.member(jsii_name="toImportProject")
    def to_import_project(self) -> "Mobilehub":
        '''(experimental) Create a new project from the previously exported project configuration.

        Access Level: Write

        https://docs.aws.amazon.com/mobile-hub/latest/developerguide/managed-policies.html

        :stability: experimental
        '''
        return typing.cast("Mobilehub", jsii.invoke(self, "toImportProject", []))

    @jsii.member(jsii_name="toInstallBundle")
    def to_install_bundle(self) -> "Mobilehub":
        '''(experimental) Install a bundle in the project deployments S3 bucket.

        Access Level: Write

        https://docs.aws.amazon.com/mobile-hub/latest/developerguide/managed-policies.html

        :stability: experimental
        '''
        return typing.cast("Mobilehub", jsii.invoke(self, "toInstallBundle", []))

    @jsii.member(jsii_name="toListAvailableConnectors")
    def to_list_available_connectors(self) -> "Mobilehub":
        '''(experimental) List the available SaaS (Software as a Service) connectors.

        Access Level: List

        https://docs.aws.amazon.com/mobile-hub/latest/developerguide/managed-policies.html

        :stability: experimental
        '''
        return typing.cast("Mobilehub", jsii.invoke(self, "toListAvailableConnectors", []))

    @jsii.member(jsii_name="toListAvailableFeatures")
    def to_list_available_features(self) -> "Mobilehub":
        '''(experimental) List available features.

        Access Level: List

        https://docs.aws.amazon.com/mobile-hub/latest/developerguide/managed-policies.html

        :stability: experimental
        '''
        return typing.cast("Mobilehub", jsii.invoke(self, "toListAvailableFeatures", []))

    @jsii.member(jsii_name="toListAvailableRegions")
    def to_list_available_regions(self) -> "Mobilehub":
        '''(experimental) List available regions for projects.

        Access Level: List

        https://docs.aws.amazon.com/mobile-hub/latest/developerguide/managed-policies.html

        :stability: experimental
        '''
        return typing.cast("Mobilehub", jsii.invoke(self, "toListAvailableRegions", []))

    @jsii.member(jsii_name="toListBundles")
    def to_list_bundles(self) -> "Mobilehub":
        '''(experimental) List the available download bundles.

        Access Level: List

        https://docs.aws.amazon.com/mobile-hub/latest/developerguide/managed-policies.html

        :stability: experimental
        '''
        return typing.cast("Mobilehub", jsii.invoke(self, "toListBundles", []))

    @jsii.member(jsii_name="toListProjects")
    def to_list_projects(self) -> "Mobilehub":
        '''(experimental) List projects.

        Access Level: List

        https://docs.aws.amazon.com/mobile-hub/latest/developerguide/managed-policies.html

        :stability: experimental
        '''
        return typing.cast("Mobilehub", jsii.invoke(self, "toListProjects", []))

    @jsii.member(jsii_name="toListProjectSnapshots")
    def to_list_project_snapshots(self) -> "Mobilehub":
        '''(experimental) List saved snapshots of project configuration.

        Access Level: List

        https://docs.aws.amazon.com/mobile-hub/latest/developerguide/managed-policies.html

        :stability: experimental
        '''
        return typing.cast("Mobilehub", jsii.invoke(self, "toListProjectSnapshots", []))

    @jsii.member(jsii_name="toSynchronizeProject")
    def to_synchronize_project(self) -> "Mobilehub":
        '''(experimental) Synchronize state of resources into project.

        Access Level: Write

        https://docs.aws.amazon.com/mobile-hub/latest/developerguide/managed-policies.html

        :stability: experimental
        '''
        return typing.cast("Mobilehub", jsii.invoke(self, "toSynchronizeProject", []))

    @jsii.member(jsii_name="toUpdateProject")
    def to_update_project(self) -> "Mobilehub":
        '''(experimental) Update project.

        Access Level: Write

        https://docs.aws.amazon.com/mobile-hub/latest/developerguide/managed-policies.html

        :stability: experimental
        '''
        return typing.cast("Mobilehub", jsii.invoke(self, "toUpdateProject", []))

    @jsii.member(jsii_name="toValidateProject")
    def to_validate_project(self) -> "Mobilehub":
        '''(experimental) Validate a mobile hub project.

        Access Level: Read

        https://docs.aws.amazon.com/mobile-hub/latest/developerguide/managed-policies.html

        :stability: experimental
        '''
        return typing.cast("Mobilehub", jsii.invoke(self, "toValidateProject", []))

    @jsii.member(jsii_name="toVerifyServiceRole")
    def to_verify_service_role(self) -> "Mobilehub":
        '''(experimental) Verify AWS Mobile Hub is enabled in the account.

        Access Level: Read

        https://docs.aws.amazon.com/mobile-hub/latest/developerguide/managed-policies.html

        :stability: experimental
        '''
        return typing.cast("Mobilehub", jsii.invoke(self, "toVerifyServiceRole", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__adccc007844501768194d0d1c4f8b299ca64b1e7957cd0911ae7571d6f9b4ae0)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2e51f368356e73925c947be6e22b519fe4daaa0ad6faafc7b6757bbd0197de59)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Mobiletargeting(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Mobiletargeting",
):
    '''(experimental) Statement provider for service `mobiletargeting <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonpinpoint.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `mobiletargeting <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonpinpoint.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onApps")
    def on_apps(
        self,
        app_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Mobiletargeting":
        '''(experimental) Adds a resource of type apps to the statement.

        https://docs.aws.amazon.com/pinpoint/latest/developerguide/gettingstarted.html#gettingstarted-addapp

        :param app_id: - Identifier for the appId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d27d5e7c00f42fda568fdf398e4564a631537373354af8fd632b95788344e073)
            check_type(argname="argument app_id", value=app_id, expected_type=type_hints["app_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Mobiletargeting", jsii.invoke(self, "onApps", [app_id, account, region, partition]))

    @jsii.member(jsii_name="onCampaigns")
    def on_campaigns(
        self,
        app_id: builtins.str,
        campaign_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Mobiletargeting":
        '''(experimental) Adds a resource of type campaigns to the statement.

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-campaigns.html

        :param app_id: - Identifier for the appId.
        :param campaign_id: - Identifier for the campaignId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__cc8daaefe6d1622e9f3c3122525c23d5b64b3706d9bd7edaa997a5f1ef2ebc7a)
            check_type(argname="argument app_id", value=app_id, expected_type=type_hints["app_id"])
            check_type(argname="argument campaign_id", value=campaign_id, expected_type=type_hints["campaign_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Mobiletargeting", jsii.invoke(self, "onCampaigns", [app_id, campaign_id, account, region, partition]))

    @jsii.member(jsii_name="onJourneys")
    def on_journeys(
        self,
        app_id: builtins.str,
        journey_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Mobiletargeting":
        '''(experimental) Adds a resource of type journeys to the statement.

        https://docs.aws.amazon.com/pinpoint/latest/apireference/apps-application-id-journeys.html

        :param app_id: - Identifier for the appId.
        :param journey_id: - Identifier for the journeyId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9dd8cfd1363011d410f2b434ad22fb191d5195edb59dcd84ba3332320b23c19f)
            check_type(argname="argument app_id", value=app_id, expected_type=type_hints["app_id"])
            check_type(argname="argument journey_id", value=journey_id, expected_type=type_hints["journey_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Mobiletargeting", jsii.invoke(self, "onJourneys", [app_id, journey_id, account, region, partition]))

    @jsii.member(jsii_name="onPhoneNumberValidate")
    def on_phone_number_validate(
        self,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Mobiletargeting":
        '''(experimental) Adds a resource of type phone-number-validate to the statement.

        https://docs.aws.amazon.com/pinpoint/latest/apireference/phone-number-validate.html

        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e5929a266a84b14292bc81943fb70c358b666c6490b0227f6e6330e98044e001)
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Mobiletargeting", jsii.invoke(self, "onPhoneNumberValidate", [account, region, partition]))

    @jsii.member(jsii_name="onRecommenders")
    def on_recommenders(
        self,
        recommender_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Mobiletargeting":
        '''(experimental) Adds a resource of type recommenders to the statement.

        https://docs.aws.amazon.com/pinpoint/latest/apireference/recommenders.html

        :param recommender_id: - Identifier for the recommenderId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c27b46d4b928805471bbc14df4d11368da7963f40c0aeaceb8b8a9f446822828)
            check_type(argname="argument recommender_id", value=recommender_id, expected_type=type_hints["recommender_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Mobiletargeting", jsii.invoke(self, "onRecommenders", [recommender_id, account, region, partition]))

    @jsii.member(jsii_name="onSegments")
    def on_segments(
        self,
        app_id: builtins.str,
        segment_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Mobiletargeting":
        '''(experimental) Adds a resource of type segments to the statement.

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-segments.html

        :param app_id: - Identifier for the appId.
        :param segment_id: - Identifier for the segmentId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1fea37c9f424c4549ae29e247f832893b6117d27ffa39b0d12e8b9a3538cbb61)
            check_type(argname="argument app_id", value=app_id, expected_type=type_hints["app_id"])
            check_type(argname="argument segment_id", value=segment_id, expected_type=type_hints["segment_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Mobiletargeting", jsii.invoke(self, "onSegments", [app_id, segment_id, account, region, partition]))

    @jsii.member(jsii_name="onTemplates")
    def on_templates(
        self,
        template_name: builtins.str,
        channel_type: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Mobiletargeting":
        '''(experimental) Adds a resource of type templates to the statement.

        https://docs.aws.amazon.com/pinpoint/latest/apireference/templates.html

        :param template_name: - Identifier for the templateName.
        :param channel_type: - Identifier for the channelType.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__dc7f84eb12e8825eb5ca4de8bd614d34097172931a1800d6606f834f7143da19)
            check_type(argname="argument template_name", value=template_name, expected_type=type_hints["template_name"])
            check_type(argname="argument channel_type", value=channel_type, expected_type=type_hints["channel_type"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Mobiletargeting", jsii.invoke(self, "onTemplates", [template_name, channel_type, account, region, partition]))

    @jsii.member(jsii_name="toCreateApp")
    def to_create_app(self) -> "Mobiletargeting":
        '''(experimental) Grants permission to create an app.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-app.html#rest-api-app-methods

        :stability: experimental
        '''
        return typing.cast("Mobiletargeting", jsii.invoke(self, "toCreateApp", []))

    @jsii.member(jsii_name="toCreateCampaign")
    def to_create_campaign(self) -> "Mobiletargeting":
        '''(experimental) Grants permission to create a campaign for an app.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-campaigns.html#rest-api-campaigns-methods

        :stability: experimental
        '''
        return typing.cast("Mobiletargeting", jsii.invoke(self, "toCreateCampaign", []))

    @jsii.member(jsii_name="toCreateEmailTemplate")
    def to_create_email_template(self) -> "Mobiletargeting":
        '''(experimental) Grants permission to create an email template.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/pinpoint/latest/apireference/templates-template-name-email.html#templates-template-name-email-http-methods

        :stability: experimental
        '''
        return typing.cast("Mobiletargeting", jsii.invoke(self, "toCreateEmailTemplate", []))

    @jsii.member(jsii_name="toCreateExportJob")
    def to_create_export_job(self) -> "Mobiletargeting":
        '''(experimental) Grants permission to create an export job that exports endpoint definitions to Amazon S3.

        Access Level: Write

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-export-jobs.html#rest-api-export-jobs-methods

        :stability: experimental
        '''
        return typing.cast("Mobiletargeting", jsii.invoke(self, "toCreateExportJob", []))

    @jsii.member(jsii_name="toCreateImportJob")
    def to_create_import_job(self) -> "Mobiletargeting":
        '''(experimental) Grants permission to import endpoint definitions from to create a segment.

        Access Level: Write

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-import-jobs.html#rest-api-import-jobs-methods

        :stability: experimental
        '''
        return typing.cast("Mobiletargeting", jsii.invoke(self, "toCreateImportJob", []))

    @jsii.member(jsii_name="toCreateInAppTemplate")
    def to_create_in_app_template(self) -> "Mobiletargeting":
        '''(experimental) Grants permission to create an in-app message template.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/pinpoint/latest/apireference/templates-template-name-inapp.html#templates-template-name-inapp-http-methods

        :stability: experimental
        '''
        return typing.cast("Mobiletargeting", jsii.invoke(self, "toCreateInAppTemplate", []))

    @jsii.member(jsii_name="toCreateJourney")
    def to_create_journey(self) -> "Mobiletargeting":
        '''(experimental) Grants permission to create a Journey for an app.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/pinpoint/latest/apireference/apps-application-id-journeys-journey-id.html#apps-application-id-journeys-journey-id-http-methods

        :stability: experimental
        '''
        return typing.cast("Mobiletargeting", jsii.invoke(self, "toCreateJourney", []))

    @jsii.member(jsii_name="toCreatePushTemplate")
    def to_create_push_template(self) -> "Mobiletargeting":
        '''(experimental) Grants permission to create a push notification template.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/pinpoint/latest/apireference/templates-template-name-push.html#templates-template-name-push-http-methods

        :stability: experimental
        '''
        return typing.cast("Mobiletargeting", jsii.invoke(self, "toCreatePushTemplate", []))

    @jsii.member(jsii_name="toCreateRecommenderConfiguration")
    def to_create_recommender_configuration(self) -> "Mobiletargeting":
        '''(experimental) Grants permission to create an Amazon Pinpoint configuration for a recommender model.

        Access Level: Write

        https://docs.aws.amazon.com/pinpoint/latest/apireference/recommenders.html#CreateRecommenderConfiguration

        :stability: experimental
        '''
        return typing.cast("Mobiletargeting", jsii.invoke(self, "toCreateRecommenderConfiguration", []))

    @jsii.member(jsii_name="toCreateSegment")
    def to_create_segment(self) -> "Mobiletargeting":
        '''(experimental) Grants permission to create a segment that is based on endpoint data reported to Pinpoint by your app.

        To allow a user to create a segment by importing endpoint data from outside of Pinpoint, allow the mobiletargeting:CreateImportJob action

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-segments.html#rest-api-segments-methods

        :stability: experimental
        '''
        return typing.cast("Mobiletargeting", jsii.invoke(self, "toCreateSegment", []))

    @jsii.member(jsii_name="toCreateSmsTemplate")
    def to_create_sms_template(self) -> "Mobiletargeting":
        '''(experimental) Grants permission to create an sms message template.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/pinpoint/latest/apireference/templates-template-name-sms.html#templates-template-name-sms-http-methods

        :stability: experimental
        '''
        return typing.cast("Mobiletargeting", jsii.invoke(self, "toCreateSmsTemplate", []))

    @jsii.member(jsii_name="toCreateVoiceTemplate")
    def to_create_voice_template(self) -> "Mobiletargeting":
        '''(experimental) Grants permission to create a voice message template.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/pinpoint/latest/apireference/templates-template-name-voice.html#templates-template-name-voice-http-methods

        :stability: experimental
        '''
        return typing.cast("Mobiletargeting", jsii.invoke(self, "toCreateVoiceTemplate", []))

    @jsii.member(jsii_name="toDeleteAdmChannel")
    def to_delete_adm_channel(self) -> "Mobiletargeting":
        '''(experimental) Grants permission to delete the ADM channel for an app.

        Access Level: Write

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-adm-channel.html#rest-api-adm-channel-methods

        :stability: experimental
        '''
        return typing.cast("Mobiletargeting", jsii.invoke(self, "toDeleteAdmChannel", []))

    @jsii.member(jsii_name="toDeleteApnsChannel")
    def to_delete_apns_channel(self) -> "Mobiletargeting":
        '''(experimental) Grants permission to delete the APNs channel for an app.

        Access Level: Write

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-apns-channel.html#rest-api-apns-channel-methods

        :stability: experimental
        '''
        return typing.cast("Mobiletargeting", jsii.invoke(self, "toDeleteApnsChannel", []))

    @jsii.member(jsii_name="toDeleteApnsSandboxChannel")
    def to_delete_apns_sandbox_channel(self) -> "Mobiletargeting":
        '''(experimental) Grants permission to delete the APNs sandbox channel for an app.

        Access Level: Write

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-apns-sandbox-channel.html#rest-api-apns-sandbox-channel-methods

        :stability: experimental
        '''
        return typing.cast("Mobiletargeting", jsii.invoke(self, "toDeleteApnsSandboxChannel", []))

    @jsii.member(jsii_name="toDeleteApnsVoipChannel")
    def to_delete_apns_voip_channel(self) -> "Mobiletargeting":
        '''(experimental) Grants permission to delete the APNs VoIP channel for an app.

        Access Level: Write

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-apns-voip-channel.html#rest-api-apns-voip-channel-methods

        :stability: experimental
        '''
        return typing.cast("Mobiletargeting", jsii.invoke(self, "toDeleteApnsVoipChannel", []))

    @jsii.member(jsii_name="toDeleteApnsVoipSandboxChannel")
    def to_delete_apns_voip_sandbox_channel(self) -> "Mobiletargeting":
        '''(experimental) Grants permission to delete the APNs VoIP sandbox channel for an app.

        Access Level: Write

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-apns-voip-sandbox-channel.html#rest-api-apns-voip-sandbox-channel-methods

        :stability: experimental
        '''
        return typing.cast("Mobiletargeting", jsii.invoke(self, "toDeleteApnsVoipSandboxChannel", []))

    @jsii.member(jsii_name="toDeleteApp")
    def to_delete_app(self) -> "Mobiletargeting":
        '''(experimental) Grants permission to delete a specific campaign.

        Access Level: Write

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-app.html#rest-api-app-methods

        :stability: experimental
        '''
        return typing.cast("Mobiletargeting", jsii.invoke(self, "toDeleteApp", []))

    @jsii.member(jsii_name="toDeleteBaiduChannel")
    def to_delete_baidu_channel(self) -> "Mobiletargeting":
        '''(experimental) Grants permission to delete the Baidu channel for an app.

        Access Level: Write

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-baidu-channel.html#rest-api-baidu-channel-methods

        :stability: experimental
        '''
        return typing.cast("Mobiletargeting", jsii.invoke(self, "toDeleteBaiduChannel", []))

    @jsii.member(jsii_name="toDeleteCampaign")
    def to_delete_campaign(self) -> "Mobiletargeting":
        '''(experimental) Grants permission to delete a specific campaign.

        Access Level: Write

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-campaign.html#rest-api-campaign-methods

        :stability: experimental
        '''
        return typing.cast("Mobiletargeting", jsii.invoke(self, "toDeleteCampaign", []))

    @jsii.member(jsii_name="toDeleteEmailChannel")
    def to_delete_email_channel(self) -> "Mobiletargeting":
        '''(experimental) Grants permission to delete the email channel for an app.

        Access Level: Write

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-email-channel.html#rest-api-email-channel-methods

        :stability: experimental
        '''
        return typing.cast("Mobiletargeting", jsii.invoke(self, "toDeleteEmailChannel", []))

    @jsii.member(jsii_name="toDeleteEmailTemplate")
    def to_delete_email_template(self) -> "Mobiletargeting":
        '''(experimental) Grants permission to delete an email template or an email template version.

        Access Level: Write

        https://docs.aws.amazon.com/pinpoint/latest/apireference/templates-template-name-email.html#templates-template-name-email-http-methods

        :stability: experimental
        '''
        return typing.cast("Mobiletargeting", jsii.invoke(self, "toDeleteEmailTemplate", []))

    @jsii.member(jsii_name="toDeleteEndpoint")
    def to_delete_endpoint(self) -> "Mobiletargeting":
        '''(experimental) Grants permission to delete an endpoint.

        Access Level: Write

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-endpoint.html#rest-api-endpoint-methods

        :stability: experimental
        '''
        return typing.cast("Mobiletargeting", jsii.invoke(self, "toDeleteEndpoint", []))

    @jsii.member(jsii_name="toDeleteEventStream")
    def to_delete_event_stream(self) -> "Mobiletargeting":
        '''(experimental) Grants permission to delete the event stream for an app.

        Access Level: Write

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-event-stream.html#rest-api-event-stream-methods

        :stability: experimental
        '''
        return typing.cast("Mobiletargeting", jsii.invoke(self, "toDeleteEventStream", []))

    @jsii.member(jsii_name="toDeleteGcmChannel")
    def to_delete_gcm_channel(self) -> "Mobiletargeting":
        '''(experimental) Grants permission to delete the GCM channel for an app.

        Access Level: Write

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-gcm-channel.html#rest-api-gcm-channel-methods

        :stability: experimental
        '''
        return typing.cast("Mobiletargeting", jsii.invoke(self, "toDeleteGcmChannel", []))

    @jsii.member(jsii_name="toDeleteInAppTemplate")
    def to_delete_in_app_template(self) -> "Mobiletargeting":
        '''(experimental) Grants permission to delete an in-app message template or an in-app message template version.

        Access Level: Write

        https://docs.aws.amazon.com/pinpoint/latest/apireference/templates-template-name-inapp.html#templates-template-name-inapp-http-methods

        :stability: experimental
        '''
        return typing.cast("Mobiletargeting", jsii.invoke(self, "toDeleteInAppTemplate", []))

    @jsii.member(jsii_name="toDeleteJourney")
    def to_delete_journey(self) -> "Mobiletargeting":
        '''(experimental) Grants permission to delete a specific journey.

        Access Level: Write

        https://docs.aws.amazon.com/pinpoint/latest/apireference/apps-application-id-journeys-journey-id.html#apps-application-id-journeys-journey-id-http-methods

        :stability: experimental
        '''
        return typing.cast("Mobiletargeting", jsii.invoke(self, "toDeleteJourney", []))

    @jsii.member(jsii_name="toDeletePushTemplate")
    def to_delete_push_template(self) -> "Mobiletargeting":
        '''(experimental) Grants permission to delete a push notification template or a push notification template version.

        Access Level: Write

        https://docs.aws.amazon.com/pinpoint/latest/apireference/templates-template-name-push.html#templates-template-name-push-http-methods

        :stability: experimental
        '''
        return typing.cast("Mobiletargeting", jsii.invoke(self, "toDeletePushTemplate", []))

    @jsii.member(jsii_name="toDeleteRecommenderConfiguration")
    def to_delete_recommender_configuration(self) -> "Mobiletargeting":
        '''(experimental) Grants permission to delete an Amazon Pinpoint configuration for a recommender model.

        Access Level: Write

        https://docs.aws.amazon.com/pinpoint/latest/apireference/recommenders-recommender-id.html#DeleteRecommenderConfiguration

        :stability: experimental
        '''
        return typing.cast("Mobiletargeting", jsii.invoke(self, "toDeleteRecommenderConfiguration", []))

    @jsii.member(jsii_name="toDeleteSegment")
    def to_delete_segment(self) -> "Mobiletargeting":
        '''(experimental) Grants permission to delete a specific segment.

        Access Level: Write

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-segment.html#rest-api-segment-methods

        :stability: experimental
        '''
        return typing.cast("Mobiletargeting", jsii.invoke(self, "toDeleteSegment", []))

    @jsii.member(jsii_name="toDeleteSmsChannel")
    def to_delete_sms_channel(self) -> "Mobiletargeting":
        '''(experimental) Grants permission to delete the SMS channel for an app.

        Access Level: Write

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-sms-channel.html#rest-api-sms-channel-methods

        :stability: experimental
        '''
        return typing.cast("Mobiletargeting", jsii.invoke(self, "toDeleteSmsChannel", []))

    @jsii.member(jsii_name="toDeleteSmsTemplate")
    def to_delete_sms_template(self) -> "Mobiletargeting":
        '''(experimental) Grants permission to delete an sms message template or an sms message template version.

        Access Level: Write

        https://docs.aws.amazon.com/pinpoint/latest/apireference/templates-template-name-sms.html#templates-template-name-sms-http-methods

        :stability: experimental
        '''
        return typing.cast("Mobiletargeting", jsii.invoke(self, "toDeleteSmsTemplate", []))

    @jsii.member(jsii_name="toDeleteUserEndpoints")
    def to_delete_user_endpoints(self) -> "Mobiletargeting":
        '''(experimental) Grants permission to delete all of the endpoints that are associated with a user ID.

        Access Level: Write

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-user.html#rest-api-user-methods

        :stability: experimental
        '''
        return typing.cast("Mobiletargeting", jsii.invoke(self, "toDeleteUserEndpoints", []))

    @jsii.member(jsii_name="toDeleteVoiceChannel")
    def to_delete_voice_channel(self) -> "Mobiletargeting":
        '''(experimental) Grants permission to delete the Voice channel for an app.

        Access Level: Write

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-voice-channel.html#rest-api-voice-channel-methods

        :stability: experimental
        '''
        return typing.cast("Mobiletargeting", jsii.invoke(self, "toDeleteVoiceChannel", []))

    @jsii.member(jsii_name="toDeleteVoiceTemplate")
    def to_delete_voice_template(self) -> "Mobiletargeting":
        '''(experimental) Grants permission to delete a voice message template or a voice message template version.

        Access Level: Write

        https://docs.aws.amazon.com/pinpoint/latest/apireference/templates-template-name-voice.html#templates-template-name-voice-http-methods

        :stability: experimental
        '''
        return typing.cast("Mobiletargeting", jsii.invoke(self, "toDeleteVoiceTemplate", []))

    @jsii.member(jsii_name="toGetAdmChannel")
    def to_get_adm_channel(self) -> "Mobiletargeting":
        '''(experimental) Grants permission to retrieve information about the Amazon Device Messaging (ADM) channel for an app.

        Access Level: Read

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-adm-channel.html#rest-api-adm-channel-methods

        :stability: experimental
        '''
        return typing.cast("Mobiletargeting", jsii.invoke(self, "toGetAdmChannel", []))

    @jsii.member(jsii_name="toGetApnsChannel")
    def to_get_apns_channel(self) -> "Mobiletargeting":
        '''(experimental) Grants permission to retrieve information about the APNs channel for an app.

        Access Level: Read

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-apns-channel.html#rest-api-apns-channel-methods

        :stability: experimental
        '''
        return typing.cast("Mobiletargeting", jsii.invoke(self, "toGetApnsChannel", []))

    @jsii.member(jsii_name="toGetApnsSandboxChannel")
    def to_get_apns_sandbox_channel(self) -> "Mobiletargeting":
        '''(experimental) Grants permission to retrieve information about the APNs sandbox channel for an app.

        Access Level: Read

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-apns-sandbox-channel.html#rest-api-apns-sandbox-channel-methods

        :stability: experimental
        '''
        return typing.cast("Mobiletargeting", jsii.invoke(self, "toGetApnsSandboxChannel", []))

    @jsii.member(jsii_name="toGetApnsVoipChannel")
    def to_get_apns_voip_channel(self) -> "Mobiletargeting":
        '''(experimental) Grants permission to retrieve information about the APNs VoIP channel for an app.

        Access Level: Read

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-apns-voip-channel.html#rest-api-apns-voip-channel-methods

        :stability: experimental
        '''
        return typing.cast("Mobiletargeting", jsii.invoke(self, "toGetApnsVoipChannel", []))

    @jsii.member(jsii_name="toGetApnsVoipSandboxChannel")
    def to_get_apns_voip_sandbox_channel(self) -> "Mobiletargeting":
        '''(experimental) Grants permission to retrieve information about the APNs VoIP sandbox channel for an app.

        Access Level: Read

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-apns-voip-sandbox-channel.html#rest-api-apns-voip-sandbox-channel-methods

        :stability: experimental
        '''
        return typing.cast("Mobiletargeting", jsii.invoke(self, "toGetApnsVoipSandboxChannel", []))

    @jsii.member(jsii_name="toGetApp")
    def to_get_app(self) -> "Mobiletargeting":
        '''(experimental) Grants permission to retrieve information about a specific app in your Amazon Pinpoint account.

        Access Level: Read

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-app.html#rest-api-app-methods

        :stability: experimental
        '''
        return typing.cast("Mobiletargeting", jsii.invoke(self, "toGetApp", []))

    @jsii.member(jsii_name="toGetApplicationDateRangeKpi")
    def to_get_application_date_range_kpi(self) -> "Mobiletargeting":
        '''(experimental) Grants permission to retrieve (queries) pre-aggregated data for a standard metric that applies to an application.

        Access Level: Read

        https://docs.aws.amazon.com/pinpoint/latest/apireference/apps-application-id-kpis-daterange-kpi-name.html#GetApplicationDateRangeKpi

        :stability: experimental
        '''
        return typing.cast("Mobiletargeting", jsii.invoke(self, "toGetApplicationDateRangeKpi", []))

    @jsii.member(jsii_name="toGetApplicationSettings")
    def to_get_application_settings(self) -> "Mobiletargeting":
        '''(experimental) Grants permission to retrieve the default settings for an app.

        Access Level: List

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-settings.html#rest-api-settings-methods

        :stability: experimental
        '''
        return typing.cast("Mobiletargeting", jsii.invoke(self, "toGetApplicationSettings", []))

    @jsii.member(jsii_name="toGetApps")
    def to_get_apps(self) -> "Mobiletargeting":
        '''(experimental) Grants permission to retrieve a list of apps in your Amazon Pinpoint account.

        Access Level: Read

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-apps.html#rest-api-apps-methods

        :stability: experimental
        '''
        return typing.cast("Mobiletargeting", jsii.invoke(self, "toGetApps", []))

    @jsii.member(jsii_name="toGetBaiduChannel")
    def to_get_baidu_channel(self) -> "Mobiletargeting":
        '''(experimental) Grants permission to retrieve information about the Baidu channel for an app.

        Access Level: Read

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-baidu-channel.html#rest-api-baidu-channel-methods

        :stability: experimental
        '''
        return typing.cast("Mobiletargeting", jsii.invoke(self, "toGetBaiduChannel", []))

    @jsii.member(jsii_name="toGetCampaign")
    def to_get_campaign(self) -> "Mobiletargeting":
        '''(experimental) Grants permission to retrieve information about a specific campaign.

        Access Level: Read

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-campaign.html#rest-api-campaign-methods

        :stability: experimental
        '''
        return typing.cast("Mobiletargeting", jsii.invoke(self, "toGetCampaign", []))

    @jsii.member(jsii_name="toGetCampaignActivities")
    def to_get_campaign_activities(self) -> "Mobiletargeting":
        '''(experimental) Grants permission to retrieve information about the activities performed by a campaign.

        Access Level: List

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-campaign-activities.html#rest-api-campaign-activities-methods

        :stability: experimental
        '''
        return typing.cast("Mobiletargeting", jsii.invoke(self, "toGetCampaignActivities", []))

    @jsii.member(jsii_name="toGetCampaignDateRangeKpi")
    def to_get_campaign_date_range_kpi(self) -> "Mobiletargeting":
        '''(experimental) Grants permission to retrieve (queries) pre-aggregated data for a standard metric that applies to a campaign.

        Access Level: Read

        https://docs.aws.amazon.com/pinpoint/latest/apireference/apps-application-id-campaigns-campaign-id-kpis-daterange-kpi-name.html#GetCampaignDateRangeKpi

        :stability: experimental
        '''
        return typing.cast("Mobiletargeting", jsii.invoke(self, "toGetCampaignDateRangeKpi", []))

    @jsii.member(jsii_name="toGetCampaigns")
    def to_get_campaigns(self) -> "Mobiletargeting":
        '''(experimental) Grants permission to retrieve information about all campaigns for an app.

        Access Level: List

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-campaigns.html#rest-api-campaigns-methods

        :stability: experimental
        '''
        return typing.cast("Mobiletargeting", jsii.invoke(self, "toGetCampaigns", []))

    @jsii.member(jsii_name="toGetCampaignVersion")
    def to_get_campaign_version(self) -> "Mobiletargeting":
        '''(experimental) Grants permission to retrieve information about a specific campaign version.

        Access Level: Read

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-campaign-version.html#rest-api-campaign-version-methods

        :stability: experimental
        '''
        return typing.cast("Mobiletargeting", jsii.invoke(self, "toGetCampaignVersion", []))

    @jsii.member(jsii_name="toGetCampaignVersions")
    def to_get_campaign_versions(self) -> "Mobiletargeting":
        '''(experimental) Grants permission to retrieve information about the current and prior versions of a campaign.

        Access Level: List

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-campaign-versions.html#rest-api-campaign-versions-methods

        :stability: experimental
        '''
        return typing.cast("Mobiletargeting", jsii.invoke(self, "toGetCampaignVersions", []))

    @jsii.member(jsii_name="toGetChannels")
    def to_get_channels(self) -> "Mobiletargeting":
        '''(experimental) Grants permission to get all channels information for your app.

        Access Level: List

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-channels.html#rest-api-channels-methods

        :stability: experimental
        '''
        return typing.cast("Mobiletargeting", jsii.invoke(self, "toGetChannels", []))

    @jsii.member(jsii_name="toGetEmailChannel")
    def to_get_email_channel(self) -> "Mobiletargeting":
        '''(experimental) Grants permission to obtain information about the email channel in an app.

        Access Level: Read

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-email-channel.html#rest-api-email-channel-methods

        :stability: experimental
        '''
        return typing.cast("Mobiletargeting", jsii.invoke(self, "toGetEmailChannel", []))

    @jsii.member(jsii_name="toGetEmailTemplate")
    def to_get_email_template(self) -> "Mobiletargeting":
        '''(experimental) Grants permission to retrieve information about a specific or the active version of an email template.

        Access Level: Read

        https://docs.aws.amazon.com/pinpoint/latest/apireference/templates-template-name-email.html#templates-template-name-email-http-methods

        :stability: experimental
        '''
        return typing.cast("Mobiletargeting", jsii.invoke(self, "toGetEmailTemplate", []))

    @jsii.member(jsii_name="toGetEndpoint")
    def to_get_endpoint(self) -> "Mobiletargeting":
        '''(experimental) Grants permission to retrieve information about a specific endpoint.

        Access Level: Read

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-endpoint.html#rest-api-endpoint-methods

        :stability: experimental
        '''
        return typing.cast("Mobiletargeting", jsii.invoke(self, "toGetEndpoint", []))

    @jsii.member(jsii_name="toGetEventStream")
    def to_get_event_stream(self) -> "Mobiletargeting":
        '''(experimental) Grants permission to retrieve information about the event stream for an app.

        Access Level: Read

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-event-stream.html#rest-api-event-stream-methods

        :stability: experimental
        '''
        return typing.cast("Mobiletargeting", jsii.invoke(self, "toGetEventStream", []))

    @jsii.member(jsii_name="toGetExportJob")
    def to_get_export_job(self) -> "Mobiletargeting":
        '''(experimental) Grants permission to obtain information about a specific export job.

        Access Level: Read

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-export-jobs.html#rest-api-export-jobs-methods

        :stability: experimental
        '''
        return typing.cast("Mobiletargeting", jsii.invoke(self, "toGetExportJob", []))

    @jsii.member(jsii_name="toGetExportJobs")
    def to_get_export_jobs(self) -> "Mobiletargeting":
        '''(experimental) Grants permission to retrieve a list of all of the export jobs for an app.

        Access Level: List

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-export-jobs.html#rest-api-export-jobs-methods

        :stability: experimental
        '''
        return typing.cast("Mobiletargeting", jsii.invoke(self, "toGetExportJobs", []))

    @jsii.member(jsii_name="toGetGcmChannel")
    def to_get_gcm_channel(self) -> "Mobiletargeting":
        '''(experimental) Grants permission to retrieve information about the GCM channel for an app.

        Access Level: Read

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-gcm-channel.html#rest-api-gcm-channel-methods

        :stability: experimental
        '''
        return typing.cast("Mobiletargeting", jsii.invoke(self, "toGetGcmChannel", []))

    @jsii.member(jsii_name="toGetImportJob")
    def to_get_import_job(self) -> "Mobiletargeting":
        '''(experimental) Grants permission to retrieve information about a specific import job.

        Access Level: Read

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-import-job.html#rest-api-import-job-methods

        :stability: experimental
        '''
        return typing.cast("Mobiletargeting", jsii.invoke(self, "toGetImportJob", []))

    @jsii.member(jsii_name="toGetImportJobs")
    def to_get_import_jobs(self) -> "Mobiletargeting":
        '''(experimental) Grants permission to retrieve information about all import jobs for an app.

        Access Level: List

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-import-jobs.html#rest-api-import-jobs-methods

        :stability: experimental
        '''
        return typing.cast("Mobiletargeting", jsii.invoke(self, "toGetImportJobs", []))

    @jsii.member(jsii_name="toGetInAppMessages")
    def to_get_in_app_messages(self) -> "Mobiletargeting":
        '''(experimental) Grants permission to retrive in-app messages for the given endpoint id.

        Access Level: Read

        https://docs.aws.amazon.com/pinpoint/latest/apireference/apps-application-id-endpoints-endpoint-id-inappmessages.html

        :stability: experimental
        '''
        return typing.cast("Mobiletargeting", jsii.invoke(self, "toGetInAppMessages", []))

    @jsii.member(jsii_name="toGetInAppTemplate")
    def to_get_in_app_template(self) -> "Mobiletargeting":
        '''(experimental) Grants permission to retrieve information about a specific or the active version of an in-app message template.

        Access Level: Read

        https://docs.aws.amazon.com/pinpoint/latest/apireference/templates-template-name-inapp.html#templates-template-name-inapp-http-methods

        :stability: experimental
        '''
        return typing.cast("Mobiletargeting", jsii.invoke(self, "toGetInAppTemplate", []))

    @jsii.member(jsii_name="toGetJourney")
    def to_get_journey(self) -> "Mobiletargeting":
        '''(experimental) Grants permission to retrieve information about a specific journey.

        Access Level: Read

        https://docs.aws.amazon.com/pinpoint/latest/apireference/apps-application-id-journeys-journey-id.html#apps-application-id-journeys-journey-id-http-methods

        :stability: experimental
        '''
        return typing.cast("Mobiletargeting", jsii.invoke(self, "toGetJourney", []))

    @jsii.member(jsii_name="toGetJourneyDateRangeKpi")
    def to_get_journey_date_range_kpi(self) -> "Mobiletargeting":
        '''(experimental) Grants permission to retrieve (queries) pre-aggregated data for a standard engagement metric that applies to a journey.

        Access Level: Read

        https://docs.aws.amazon.com/pinpoint/latest/apireference/apps-application-id-journeys-journey-id-kpis-daterange-kpi-name.html#GetJourneyDateRangeKpi

        :stability: experimental
        '''
        return typing.cast("Mobiletargeting", jsii.invoke(self, "toGetJourneyDateRangeKpi", []))

    @jsii.member(jsii_name="toGetJourneyExecutionActivityMetrics")
    def to_get_journey_execution_activity_metrics(self) -> "Mobiletargeting":
        '''(experimental) Grants permission to retrieve (queries) pre-aggregated data for a standard execution metric that applies to a journey activity.

        Access Level: Read

        https://docs.aws.amazon.com/pinpoint/latest/apireference/apps-application-id-journeys-journey-id-activities-journey-activity-id-execution-metrics.html#GetJourneyExecutionActivityMetrics

        :stability: experimental
        '''
        return typing.cast("Mobiletargeting", jsii.invoke(self, "toGetJourneyExecutionActivityMetrics", []))

    @jsii.member(jsii_name="toGetJourneyExecutionMetrics")
    def to_get_journey_execution_metrics(self) -> "Mobiletargeting":
        '''(experimental) Grants permission to retrieve (queries) pre-aggregated data for a standard execution metric that applies to a journey.

        Access Level: Read

        https://docs.aws.amazon.com/pinpoint/latest/apireference/apps-application-id-journeys-journey-id-execution-metrics.html#GetJourneyExecutionMetrics

        :stability: experimental
        '''
        return typing.cast("Mobiletargeting", jsii.invoke(self, "toGetJourneyExecutionMetrics", []))

    @jsii.member(jsii_name="toGetPushTemplate")
    def to_get_push_template(self) -> "Mobiletargeting":
        '''(experimental) Grants permission to retrieve information about a specific or the active version of an push notification template.

        Access Level: Read

        https://docs.aws.amazon.com/pinpoint/latest/apireference/templates-template-name-push.html#templates-template-name-push-http-methods

        :stability: experimental
        '''
        return typing.cast("Mobiletargeting", jsii.invoke(self, "toGetPushTemplate", []))

    @jsii.member(jsii_name="toGetRecommenderConfiguration")
    def to_get_recommender_configuration(self) -> "Mobiletargeting":
        '''(experimental) Grants permission to retrieve information about an Amazon Pinpoint configuration for a recommender model.

        Access Level: Read

        https://docs.aws.amazon.com/pinpoint/latest/apireference/recommenders-recommender-id.html#GetRecommenderConfiguration

        :stability: experimental
        '''
        return typing.cast("Mobiletargeting", jsii.invoke(self, "toGetRecommenderConfiguration", []))

    @jsii.member(jsii_name="toGetRecommenderConfigurations")
    def to_get_recommender_configurations(self) -> "Mobiletargeting":
        '''(experimental) Grants permission to retrieve information about all the recommender model configurations that are associated with an Amazon Pinpoint account.

        Access Level: List

        https://docs.aws.amazon.com/pinpoint/latest/apireference/recommenders.html#GetRecommenderConfigurations

        :stability: experimental
        '''
        return typing.cast("Mobiletargeting", jsii.invoke(self, "toGetRecommenderConfigurations", []))

    @jsii.member(jsii_name="toGetReports")
    def to_get_reports(self) -> "Mobiletargeting":
        '''(experimental) Grants permission to mobiletargeting:GetReports.

        Access Level: Read

        :stability: experimental
        '''
        return typing.cast("Mobiletargeting", jsii.invoke(self, "toGetReports", []))

    @jsii.member(jsii_name="toGetSegment")
    def to_get_segment(self) -> "Mobiletargeting":
        '''(experimental) Grants permission to retrieve information about a specific segment.

        Access Level: Read

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-segment.html#rest-api-segment-methods

        :stability: experimental
        '''
        return typing.cast("Mobiletargeting", jsii.invoke(self, "toGetSegment", []))

    @jsii.member(jsii_name="toGetSegmentExportJobs")
    def to_get_segment_export_jobs(self) -> "Mobiletargeting":
        '''(experimental) Grants permission to retrieve information about jobs that export endpoint definitions from segments to Amazon S3.

        Access Level: List

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-export-jobs.html#rest-api-export-jobs-methods

        :stability: experimental
        '''
        return typing.cast("Mobiletargeting", jsii.invoke(self, "toGetSegmentExportJobs", []))

    @jsii.member(jsii_name="toGetSegmentImportJobs")
    def to_get_segment_import_jobs(self) -> "Mobiletargeting":
        '''(experimental) Grants permission to retrieve information about jobs that create segments by importing endpoint definitions from.

        Access Level: List

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-import-jobs.html#rest-api-import-jobs-methods

        :stability: experimental
        '''
        return typing.cast("Mobiletargeting", jsii.invoke(self, "toGetSegmentImportJobs", []))

    @jsii.member(jsii_name="toGetSegments")
    def to_get_segments(self) -> "Mobiletargeting":
        '''(experimental) Grants permission to retrieve information about the segments for an app.

        Access Level: List

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-segments.html#rest-api-segments-methods

        :stability: experimental
        '''
        return typing.cast("Mobiletargeting", jsii.invoke(self, "toGetSegments", []))

    @jsii.member(jsii_name="toGetSegmentVersion")
    def to_get_segment_version(self) -> "Mobiletargeting":
        '''(experimental) Grants permission to retrieve information about a specific segment version.

        Access Level: Read

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-segment-version.html#rest-api-segment-version-methods

        :stability: experimental
        '''
        return typing.cast("Mobiletargeting", jsii.invoke(self, "toGetSegmentVersion", []))

    @jsii.member(jsii_name="toGetSegmentVersions")
    def to_get_segment_versions(self) -> "Mobiletargeting":
        '''(experimental) Grants permission to retrieve information about the current and prior versions of a segment.

        Access Level: List

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-segment-versions.html#rest-api-segment-versions-methods

        :stability: experimental
        '''
        return typing.cast("Mobiletargeting", jsii.invoke(self, "toGetSegmentVersions", []))

    @jsii.member(jsii_name="toGetSmsChannel")
    def to_get_sms_channel(self) -> "Mobiletargeting":
        '''(experimental) Grants permission to obtain information about the SMS channel in an app.

        Access Level: Read

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-sms-channel.html#rest-api-sms-channel-methods

        :stability: experimental
        '''
        return typing.cast("Mobiletargeting", jsii.invoke(self, "toGetSmsChannel", []))

    @jsii.member(jsii_name="toGetSmsTemplate")
    def to_get_sms_template(self) -> "Mobiletargeting":
        '''(experimental) Grants permission to retrieve information about a specific or the active version of an sms message template.

        Access Level: Read

        https://docs.aws.amazon.com/pinpoint/latest/apireference/templates-template-name-sms.html#templates-template-name-sms-http-methods

        :stability: experimental
        '''
        return typing.cast("Mobiletargeting", jsii.invoke(self, "toGetSmsTemplate", []))

    @jsii.member(jsii_name="toGetUserEndpoints")
    def to_get_user_endpoints(self) -> "Mobiletargeting":
        '''(experimental) Grants permission to retrieve information about the endpoints that are associated with a user ID.

        Access Level: Read

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-user.html#rest-api-user-methods

        :stability: experimental
        '''
        return typing.cast("Mobiletargeting", jsii.invoke(self, "toGetUserEndpoints", []))

    @jsii.member(jsii_name="toGetVoiceChannel")
    def to_get_voice_channel(self) -> "Mobiletargeting":
        '''(experimental) Grants permission to obtain information about the Voice channel in an app.

        Access Level: Read

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-voice-channel.html#rest-api-voice-channel-methods

        :stability: experimental
        '''
        return typing.cast("Mobiletargeting", jsii.invoke(self, "toGetVoiceChannel", []))

    @jsii.member(jsii_name="toGetVoiceTemplate")
    def to_get_voice_template(self) -> "Mobiletargeting":
        '''(experimental) Grants permission to retrieve information about a specific or the active version of a voice message template.

        Access Level: Read

        https://docs.aws.amazon.com/pinpoint/latest/apireference/templates-template-name-voice.html#templates-template-name-voice-http-methods

        :stability: experimental
        '''
        return typing.cast("Mobiletargeting", jsii.invoke(self, "toGetVoiceTemplate", []))

    @jsii.member(jsii_name="toListJourneys")
    def to_list_journeys(self) -> "Mobiletargeting":
        '''(experimental) Grants permission to retrieve information about all journeys for an app.

        Access Level: List

        https://docs.aws.amazon.com/pinpoint/latest/apireference/apps-application-id-journeys.html#apps-application-id-journeys-http-methods

        :stability: experimental
        '''
        return typing.cast("Mobiletargeting", jsii.invoke(self, "toListJourneys", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Mobiletargeting":
        '''(experimental) Grants permission to list tags for a resource.

        Access Level: Read

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-tags.html#rest-api-tags-methods-get

        :stability: experimental
        '''
        return typing.cast("Mobiletargeting", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toListTemplates")
    def to_list_templates(self) -> "Mobiletargeting":
        '''(experimental) Grants permission to retrieve metadata about the queried templates.

        Access Level: List

        https://docs.aws.amazon.com/pinpoint/latest/apireference/templates.html#templates-http-methods

        :stability: experimental
        '''
        return typing.cast("Mobiletargeting", jsii.invoke(self, "toListTemplates", []))

    @jsii.member(jsii_name="toListTemplateVersions")
    def to_list_template_versions(self) -> "Mobiletargeting":
        '''(experimental) Grants permission to retrieve all versions about a specific template.

        Access Level: List

        https://docs.aws.amazon.com/pinpoint/latest/apireference/templates-template-name-template-type-versions.html#templates-template-name-template-type-versions-http-methods

        :stability: experimental
        '''
        return typing.cast("Mobiletargeting", jsii.invoke(self, "toListTemplateVersions", []))

    @jsii.member(jsii_name="toPhoneNumberValidate")
    def to_phone_number_validate(self) -> "Mobiletargeting":
        '''(experimental) Grants permission to obtain metadata for a phone number, such as the number type (mobile, landline, or VoIP), location, and provider.

        Access Level: Read

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-phone-number-validate.html#rest-api-phone-number-validate-methods

        :stability: experimental
        '''
        return typing.cast("Mobiletargeting", jsii.invoke(self, "toPhoneNumberValidate", []))

    @jsii.member(jsii_name="toPutEvents")
    def to_put_events(self) -> "Mobiletargeting":
        '''(experimental) Grants permission to create or update events for an app.

        Access Level: Write

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-events.html#rest-api-events-methods

        :stability: experimental
        '''
        return typing.cast("Mobiletargeting", jsii.invoke(self, "toPutEvents", []))

    @jsii.member(jsii_name="toPutEventStream")
    def to_put_event_stream(self) -> "Mobiletargeting":
        '''(experimental) Grants permission to create or update an event stream for an app.

        Access Level: Write

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-event-stream.html#rest-api-event-stream-methods

        :stability: experimental
        '''
        return typing.cast("Mobiletargeting", jsii.invoke(self, "toPutEventStream", []))

    @jsii.member(jsii_name="toRemoveAttributes")
    def to_remove_attributes(self) -> "Mobiletargeting":
        '''(experimental) Grants permission to remove the attributes for an app.

        Access Level: Write

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-app.html#rest-api-app-methods

        :stability: experimental
        '''
        return typing.cast("Mobiletargeting", jsii.invoke(self, "toRemoveAttributes", []))

    @jsii.member(jsii_name="toSendMessages")
    def to_send_messages(self) -> "Mobiletargeting":
        '''(experimental) Grants permission to send an SMS message or push notification to specific endpoints.

        Access Level: Write

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-messages.html#rest-api-messages-methods

        :stability: experimental
        '''
        return typing.cast("Mobiletargeting", jsii.invoke(self, "toSendMessages", []))

    @jsii.member(jsii_name="toSendOTPMessage")
    def to_send_otp_message(self) -> "Mobiletargeting":
        '''(experimental) Grants permission to send an OTP code to a user of your application.

        Access Level: Write

        https://docs.aws.amazon.com/pinpoint/latest/apireference/apps-application-id-otp.html

        :stability: experimental
        '''
        return typing.cast("Mobiletargeting", jsii.invoke(self, "toSendOTPMessage", []))

    @jsii.member(jsii_name="toSendUsersMessages")
    def to_send_users_messages(self) -> "Mobiletargeting":
        '''(experimental) Grants permission to send an SMS message or push notification to all endpoints that are associated with a specific user ID.

        Access Level: Write

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-users-messages.html#rest-api-users-messages-methods

        :stability: experimental
        '''
        return typing.cast("Mobiletargeting", jsii.invoke(self, "toSendUsersMessages", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Mobiletargeting":
        '''(experimental) Grants permission to add tags to a resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-tags.html#rest-api-tags-methods-post

        :stability: experimental
        '''
        return typing.cast("Mobiletargeting", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Mobiletargeting":
        '''(experimental) Grants permission to remove tags from a resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-tags.html#rest-api-tags-methods-delete

        :stability: experimental
        '''
        return typing.cast("Mobiletargeting", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateAdmChannel")
    def to_update_adm_channel(self) -> "Mobiletargeting":
        '''(experimental) Grants permission to update the Amazon Device Messaging (ADM) channel for an app.

        Access Level: Write

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-adm-channel.html#rest-api-adm-channel-methods

        :stability: experimental
        '''
        return typing.cast("Mobiletargeting", jsii.invoke(self, "toUpdateAdmChannel", []))

    @jsii.member(jsii_name="toUpdateApnsChannel")
    def to_update_apns_channel(self) -> "Mobiletargeting":
        '''(experimental) Grants permission to update the Apple Push Notification service (APNs) channel for an app.

        Access Level: Write

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-apns-channel.html#rest-api-apns-channel-methods

        :stability: experimental
        '''
        return typing.cast("Mobiletargeting", jsii.invoke(self, "toUpdateApnsChannel", []))

    @jsii.member(jsii_name="toUpdateApnsSandboxChannel")
    def to_update_apns_sandbox_channel(self) -> "Mobiletargeting":
        '''(experimental) Grants permission to update the Apple Push Notification service (APNs) sandbox channel for an app.

        Access Level: Write

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-apns-sandbox-channel.html#rest-api-apns-sandbox-channel-methods

        :stability: experimental
        '''
        return typing.cast("Mobiletargeting", jsii.invoke(self, "toUpdateApnsSandboxChannel", []))

    @jsii.member(jsii_name="toUpdateApnsVoipChannel")
    def to_update_apns_voip_channel(self) -> "Mobiletargeting":
        '''(experimental) Grants permission to update the Apple Push Notification service (APNs) VoIP channel for an app.

        Access Level: Write

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-apns-voip-channel.html#rest-api-apns-voip-channel-methods

        :stability: experimental
        '''
        return typing.cast("Mobiletargeting", jsii.invoke(self, "toUpdateApnsVoipChannel", []))

    @jsii.member(jsii_name="toUpdateApnsVoipSandboxChannel")
    def to_update_apns_voip_sandbox_channel(self) -> "Mobiletargeting":
        '''(experimental) Grants permission to update the Apple Push Notification service (APNs) VoIP sandbox channel for an app.

        Access Level: Write

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-apns-voip-sandbox-channel.html#rest-api-apns-voip-sandbox-channel-methods

        :stability: experimental
        '''
        return typing.cast("Mobiletargeting", jsii.invoke(self, "toUpdateApnsVoipSandboxChannel", []))

    @jsii.member(jsii_name="toUpdateApplicationSettings")
    def to_update_application_settings(self) -> "Mobiletargeting":
        '''(experimental) Grants permission to update the default settings for an app.

        Access Level: Write

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-settings.html#rest-api-settings-methods

        :stability: experimental
        '''
        return typing.cast("Mobiletargeting", jsii.invoke(self, "toUpdateApplicationSettings", []))

    @jsii.member(jsii_name="toUpdateBaiduChannel")
    def to_update_baidu_channel(self) -> "Mobiletargeting":
        '''(experimental) Grants permission to update the Baidu channel for an app.

        Access Level: Write

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-baidu-channel.html#rest-api-baidu-channel-methods

        :stability: experimental
        '''
        return typing.cast("Mobiletargeting", jsii.invoke(self, "toUpdateBaiduChannel", []))

    @jsii.member(jsii_name="toUpdateCampaign")
    def to_update_campaign(self) -> "Mobiletargeting":
        '''(experimental) Grants permission to update a specific campaign.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-campaign.html#rest-api-campaign-methods

        :stability: experimental
        '''
        return typing.cast("Mobiletargeting", jsii.invoke(self, "toUpdateCampaign", []))

    @jsii.member(jsii_name="toUpdateEmailChannel")
    def to_update_email_channel(self) -> "Mobiletargeting":
        '''(experimental) Grants permission to update the email channel for an app.

        Access Level: Write

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-email-channel.html#rest-api-email-channel-methods

        :stability: experimental
        '''
        return typing.cast("Mobiletargeting", jsii.invoke(self, "toUpdateEmailChannel", []))

    @jsii.member(jsii_name="toUpdateEmailTemplate")
    def to_update_email_template(self) -> "Mobiletargeting":
        '''(experimental) Grants permission to update a specific email template under the same version or generate a new version.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/pinpoint/latest/apireference/templates-template-name-email.html#templates-template-name-email-http-methods

        :stability: experimental
        '''
        return typing.cast("Mobiletargeting", jsii.invoke(self, "toUpdateEmailTemplate", []))

    @jsii.member(jsii_name="toUpdateEndpoint")
    def to_update_endpoint(self) -> "Mobiletargeting":
        '''(experimental) Grants permission to create an endpoint or update the information for an endpoint.

        Access Level: Write

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-endpoint.html#rest-api-endpoint-methods

        :stability: experimental
        '''
        return typing.cast("Mobiletargeting", jsii.invoke(self, "toUpdateEndpoint", []))

    @jsii.member(jsii_name="toUpdateEndpointsBatch")
    def to_update_endpoints_batch(self) -> "Mobiletargeting":
        '''(experimental) Grants permission to create or update endpoints as a batch operation.

        Access Level: Write

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-endpoints.html#rest-api-endpoints-methods

        :stability: experimental
        '''
        return typing.cast("Mobiletargeting", jsii.invoke(self, "toUpdateEndpointsBatch", []))

    @jsii.member(jsii_name="toUpdateGcmChannel")
    def to_update_gcm_channel(self) -> "Mobiletargeting":
        '''(experimental) Grants permission to update the Firebase Cloud Messaging (FCM) or Google Cloud Messaging (GCM) API key that allows to send push notifications to your Android app.

        Access Level: Write

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-gcm-channel.html#rest-api-gcm-channel-methods

        :stability: experimental
        '''
        return typing.cast("Mobiletargeting", jsii.invoke(self, "toUpdateGcmChannel", []))

    @jsii.member(jsii_name="toUpdateInAppTemplate")
    def to_update_in_app_template(self) -> "Mobiletargeting":
        '''(experimental) Grants permission to update a specific in-app message template under the same version or generate a new version.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/pinpoint/latest/apireference/templates-template-name-inapp.html#templates-template-name-inapp-http-methods

        :stability: experimental
        '''
        return typing.cast("Mobiletargeting", jsii.invoke(self, "toUpdateInAppTemplate", []))

    @jsii.member(jsii_name="toUpdateJourney")
    def to_update_journey(self) -> "Mobiletargeting":
        '''(experimental) Grants permission to update a specific journey.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/pinpoint/latest/apireference/apps-application-id-journeys-journey-id.html#apps-application-id-journeys-journey-id-http-methods

        :stability: experimental
        '''
        return typing.cast("Mobiletargeting", jsii.invoke(self, "toUpdateJourney", []))

    @jsii.member(jsii_name="toUpdateJourneyState")
    def to_update_journey_state(self) -> "Mobiletargeting":
        '''(experimental) Grants permission to update a specific journey state.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/pinpoint/latest/apireference/apps-application-id-journeys-journey-id-state.html#apps-application-id-journeys-journey-id-state-http-methods

        :stability: experimental
        '''
        return typing.cast("Mobiletargeting", jsii.invoke(self, "toUpdateJourneyState", []))

    @jsii.member(jsii_name="toUpdatePushTemplate")
    def to_update_push_template(self) -> "Mobiletargeting":
        '''(experimental) Grants permission to update a specific push notification template under the same version or generate a new version.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/pinpoint/latest/apireference/templates-template-name-push.html#templates-template-name-push-http-methods

        :stability: experimental
        '''
        return typing.cast("Mobiletargeting", jsii.invoke(self, "toUpdatePushTemplate", []))

    @jsii.member(jsii_name="toUpdateRecommenderConfiguration")
    def to_update_recommender_configuration(self) -> "Mobiletargeting":
        '''(experimental) Grants permission to update an Amazon Pinpoint configuration for a recommender model.

        Access Level: Write

        https://docs.aws.amazon.com/pinpoint/latest/apireference/recommenders-recommender-id.html#UpdateRecommenderConfiguration

        :stability: experimental
        '''
        return typing.cast("Mobiletargeting", jsii.invoke(self, "toUpdateRecommenderConfiguration", []))

    @jsii.member(jsii_name="toUpdateSegment")
    def to_update_segment(self) -> "Mobiletargeting":
        '''(experimental) Grants permission to update a specific segment.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-segment.html#rest-api-segment-methods

        :stability: experimental
        '''
        return typing.cast("Mobiletargeting", jsii.invoke(self, "toUpdateSegment", []))

    @jsii.member(jsii_name="toUpdateSmsChannel")
    def to_update_sms_channel(self) -> "Mobiletargeting":
        '''(experimental) Grants permission to update the SMS channel for an app.

        Access Level: Write

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-sms-channel.html#rest-api-sms-channel-methods

        :stability: experimental
        '''
        return typing.cast("Mobiletargeting", jsii.invoke(self, "toUpdateSmsChannel", []))

    @jsii.member(jsii_name="toUpdateSmsTemplate")
    def to_update_sms_template(self) -> "Mobiletargeting":
        '''(experimental) Grants permission to update a specific sms message template under the same version or generate a new version.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/pinpoint/latest/apireference/templates-template-name-sms.html#templates-template-name-sms-http-methods

        :stability: experimental
        '''
        return typing.cast("Mobiletargeting", jsii.invoke(self, "toUpdateSmsTemplate", []))

    @jsii.member(jsii_name="toUpdateTemplateActiveVersion")
    def to_update_template_active_version(self) -> "Mobiletargeting":
        '''(experimental) Grants permission to update the active version parameter of a specific template.

        Access Level: Write

        https://docs.aws.amazon.com/pinpoint/latest/apireference/templates-template-name-template-type-versions.html#templates-template-name-template-type-versions-http-methods

        :stability: experimental
        '''
        return typing.cast("Mobiletargeting", jsii.invoke(self, "toUpdateTemplateActiveVersion", []))

    @jsii.member(jsii_name="toUpdateVoiceChannel")
    def to_update_voice_channel(self) -> "Mobiletargeting":
        '''(experimental) Grants permission to update the Voice channel for an app.

        Access Level: Write

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-voice-channel.html#rest-api-voice-channel-methods

        :stability: experimental
        '''
        return typing.cast("Mobiletargeting", jsii.invoke(self, "toUpdateVoiceChannel", []))

    @jsii.member(jsii_name="toUpdateVoiceTemplate")
    def to_update_voice_template(self) -> "Mobiletargeting":
        '''(experimental) Grants permission to update a specific voice message template under the same version or generate a new version.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/pinpoint/latest/apireference/templates-template-name-voice.html#templates-template-name-voice-http-methods

        :stability: experimental
        '''
        return typing.cast("Mobiletargeting", jsii.invoke(self, "toUpdateVoiceTemplate", []))

    @jsii.member(jsii_name="toVerifyOTPMessage")
    def to_verify_otp_message(self) -> "Mobiletargeting":
        '''(experimental) Grants permission to check the validity of One-Time Passwords (OTPs).

        Access Level: Write

        https://docs.aws.amazon.com/pinpoint/latest/apireference/apps-application-id-verify-otp.html

        :stability: experimental
        '''
        return typing.cast("Mobiletargeting", jsii.invoke(self, "toVerifyOTPMessage", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5b9d71c7cdcdac19b13b5ffc626448208fc23a28e94165610e6e692919b121c8)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__21f637e77fa1893e8b6b6761f44139fcd2a15c1921bd9e611ffd3ddcbf66e6b0)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Monitron(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Monitron",
):
    '''(experimental) Statement provider for service `monitron <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonmonitron.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `monitron <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonmonitron.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onProject")
    def on_project(
        self,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Monitron":
        '''(experimental) Adds a resource of type project to the statement.

        https://docs.aws.amazon.com/Monitron/latest/admin-guide/projects-chapter.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a34a5aaeac052b20883afc38b614ba43c6b010e27424bfefe4462569e37cd148)
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Monitron", jsii.invoke(self, "onProject", [resource_id, account, region, partition]))

    @jsii.member(jsii_name="toAssociateProjectAdminUser")
    def to_associate_project_admin_user(self) -> "Monitron":
        '''(experimental) Grants permission to associate a user with the project as an administrator.

        Access Level: Permissions management

        Dependent actions:

        - sso-directory:DescribeUsers
        - sso:AssociateProfile
        - sso:GetManagedApplicationInstance
        - sso:GetProfile
        - sso:ListDirectoryAssociations
        - sso:ListProfileAssociations
        - sso:ListProfiles

        https://docs.aws.amazon.com/Monitron/latest/admin-guide/user-management-chapter.html

        :stability: experimental
        '''
        return typing.cast("Monitron", jsii.invoke(self, "toAssociateProjectAdminUser", []))

    @jsii.member(jsii_name="toCreateProject")
    def to_create_project(self) -> "Monitron":
        '''(experimental) Grants permission to create a project.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - iam:CreateServiceLinkedRole
        - kms:CreateGrant
        - sso:CreateManagedApplicationInstance
        - sso:DeleteManagedApplicationInstance

        https://docs.aws.amazon.com/Monitron/latest/admin-guide/mp-creating-project.html

        :stability: experimental
        '''
        return typing.cast("Monitron", jsii.invoke(self, "toCreateProject", []))

    @jsii.member(jsii_name="toDeleteProject")
    def to_delete_project(self) -> "Monitron":
        '''(experimental) Grants permission to delete a project.

        Access Level: Write

        Dependent actions:

        - sso:DeleteManagedApplicationInstance

        https://docs.aws.amazon.com/Monitron/latest/admin-guide/mp-delete-project.html

        :stability: experimental
        '''
        return typing.cast("Monitron", jsii.invoke(self, "toDeleteProject", []))

    @jsii.member(jsii_name="toDisassociateProjectAdminUser")
    def to_disassociate_project_admin_user(self) -> "Monitron":
        '''(experimental) Grants permission to disassociate an administrator from the project.

        Access Level: Permissions management

        Dependent actions:

        - sso-directory:DescribeUsers
        - sso:DisassociateProfile
        - sso:GetManagedApplicationInstance
        - sso:GetProfile
        - sso:ListDirectoryAssociations
        - sso:ListProfiles

        https://docs.aws.amazon.com/Monitron/latest/admin-guide/mu-remove-project-admin.html

        :stability: experimental
        '''
        return typing.cast("Monitron", jsii.invoke(self, "toDisassociateProjectAdminUser", []))

    @jsii.member(jsii_name="toGetProject")
    def to_get_project(self) -> "Monitron":
        '''(experimental) Grants permission to get information about a project.

        Access Level: Read

        https://docs.aws.amazon.com/Monitron/latest/admin-guide/mp-project-tasks.html

        :stability: experimental
        '''
        return typing.cast("Monitron", jsii.invoke(self, "toGetProject", []))

    @jsii.member(jsii_name="toGetProjectAdminUser")
    def to_get_project_admin_user(self) -> "Monitron":
        '''(experimental) Grants permission to describe an administrator who is associated with the project.

        Access Level: Read

        Dependent actions:

        - sso-directory:DescribeUsers
        - sso:GetManagedApplicationInstance
        - sso:ListProfileAssociations

        https://docs.aws.amazon.com/Monitron/latest/admin-guide/mp-project-tasks.html

        :stability: experimental
        '''
        return typing.cast("Monitron", jsii.invoke(self, "toGetProjectAdminUser", []))

    @jsii.member(jsii_name="toListProjectAdminUsers")
    def to_list_project_admin_users(self) -> "Monitron":
        '''(experimental) Grants permission to list all administrators associated with the project.

        Access Level: Permissions management

        Dependent actions:

        - sso-directory:DescribeUsers
        - sso:GetManagedApplicationInstance

        https://docs.aws.amazon.com/Monitron/latest/admin-guide/user-management-chapter.html

        :stability: experimental
        '''
        return typing.cast("Monitron", jsii.invoke(self, "toListProjectAdminUsers", []))

    @jsii.member(jsii_name="toListProjects")
    def to_list_projects(self) -> "Monitron":
        '''(experimental) Grants permission to list all projects.

        Access Level: List

        https://docs.aws.amazon.com/Monitron/latest/admin-guide/mp-project-tasks.html

        :stability: experimental
        '''
        return typing.cast("Monitron", jsii.invoke(self, "toListProjects", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Monitron":
        '''(experimental) Grants permission to list all tags for a resource.

        Access Level: Read

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/Monitron/latest/admin-guide/tagging.html

        :stability: experimental
        '''
        return typing.cast("Monitron", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Monitron":
        '''(experimental) Grants permission to tag a resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/Monitron/latest/admin-guide/tagging.html

        :stability: experimental
        '''
        return typing.cast("Monitron", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Monitron":
        '''(experimental) Grants permission to untag a resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/Monitron/latest/admin-guide/tagging.html#modify-tag-1

        :stability: experimental
        '''
        return typing.cast("Monitron", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateProject")
    def to_update_project(self) -> "Monitron":
        '''(experimental) Grants permission to update a project.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/Monitron/latest/admin-guide/mp-updating-project.html

        :stability: experimental
        '''
        return typing.cast("Monitron", jsii.invoke(self, "toUpdateProject", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b7a9a9c8d95dc4942bfc4476a247576189beb19029b0fb75403628b9d964d820)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__72a413440a264d53533c0c35bbc14652aa08d777d8e0c353febf63b8ce6a1b6e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Mq(PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Mq"):
    '''(experimental) Statement provider for service `mq <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonmq.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `mq <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonmq.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onBrokers")
    def on_brokers(
        self,
        broker_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Mq":
        '''(experimental) Adds a resource of type brokers to the statement.

        https://docs.aws.amazon.com/amazon-mq/latest/developer-guide/amazon-mq-how-it-works.html

        :param broker_id: - Identifier for the brokerId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5a49655c6915d9af3918ba9c7d3df204770f4b763c856b1204d54215650333bb)
            check_type(argname="argument broker_id", value=broker_id, expected_type=type_hints["broker_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Mq", jsii.invoke(self, "onBrokers", [broker_id, account, region, partition]))

    @jsii.member(jsii_name="onConfigurations")
    def on_configurations(
        self,
        configuration_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Mq":
        '''(experimental) Adds a resource of type configurations to the statement.

        https://docs.aws.amazon.com/amazon-mq/latest/developer-guide/amazon-mq-how-it-works.html

        :param configuration_id: - Identifier for the configurationId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0e5e4a03e42f6b792d927da48d12af3d4514162b329a28ebc44031601bb472ae)
            check_type(argname="argument configuration_id", value=configuration_id, expected_type=type_hints["configuration_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Mq", jsii.invoke(self, "onConfigurations", [configuration_id, account, region, partition]))

    @jsii.member(jsii_name="toCreateBroker")
    def to_create_broker(self) -> "Mq":
        '''(experimental) Grants permission to create a broker.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - ec2:CreateNetworkInterface
        - ec2:CreateNetworkInterfacePermission
        - ec2:CreateSecurityGroup
        - ec2:CreateVpcEndpoint
        - ec2:DescribeInternetGateways
        - ec2:DescribeNetworkInterfacePermissions
        - ec2:DescribeNetworkInterfaces
        - ec2:DescribeSecurityGroups
        - ec2:DescribeSubnets
        - ec2:DescribeVpcEndpoints
        - ec2:DescribeVpcs
        - ec2:ModifyNetworkInterfaceAttribute
        - iam:CreateServiceLinkedRole
        - route53:AssociateVPCWithHostedZone

        https://docs.aws.amazon.com/amazon-mq/latest/api-reference/rest-api-brokers.html#rest-api-brokers-methods-post

        :stability: experimental
        '''
        return typing.cast("Mq", jsii.invoke(self, "toCreateBroker", []))

    @jsii.member(jsii_name="toCreateConfiguration")
    def to_create_configuration(self) -> "Mq":
        '''(experimental) Grants permission to create a new configuration for the specified configuration name.

        Amazon MQ uses the default configuration (the engine type and engine version)

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/amazon-mq/latest/api-reference/rest-api-configurations.html#rest-api-configurations-methods-post

        :stability: experimental
        '''
        return typing.cast("Mq", jsii.invoke(self, "toCreateConfiguration", []))

    @jsii.member(jsii_name="toCreateTags")
    def to_create_tags(self) -> "Mq":
        '''(experimental) Grants permission to create tags.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/amazon-mq/latest/api-reference/rest-api-tags.html#rest-api-tags-methods-post

        :stability: experimental
        '''
        return typing.cast("Mq", jsii.invoke(self, "toCreateTags", []))

    @jsii.member(jsii_name="toCreateUser")
    def to_create_user(self) -> "Mq":
        '''(experimental) Grants permission to create an ActiveMQ user.

        Access Level: Write

        https://docs.aws.amazon.com/amazon-mq/latest/api-reference/rest-api-username.html#rest-api-username-methods-post

        :stability: experimental
        '''
        return typing.cast("Mq", jsii.invoke(self, "toCreateUser", []))

    @jsii.member(jsii_name="toDeleteBroker")
    def to_delete_broker(self) -> "Mq":
        '''(experimental) Grants permission to delete a broker.

        Access Level: Write

        Dependent actions:

        - ec2:DeleteNetworkInterface
        - ec2:DeleteNetworkInterfacePermission
        - ec2:DeleteVpcEndpoints
        - ec2:DetachNetworkInterface

        https://docs.aws.amazon.com/amazon-mq/latest/api-reference/rest-api-broker.html#rest-api-broker-methods-delete

        :stability: experimental
        '''
        return typing.cast("Mq", jsii.invoke(self, "toDeleteBroker", []))

    @jsii.member(jsii_name="toDeleteTags")
    def to_delete_tags(self) -> "Mq":
        '''(experimental) Grants permission to delete tags.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/amazon-mq/latest/api-reference/rest-api-tags.html#rest-api-tags-methods-delete

        :stability: experimental
        '''
        return typing.cast("Mq", jsii.invoke(self, "toDeleteTags", []))

    @jsii.member(jsii_name="toDeleteUser")
    def to_delete_user(self) -> "Mq":
        '''(experimental) Grants permission to delete an ActiveMQ user.

        Access Level: Write

        https://docs.aws.amazon.com/amazon-mq/latest/api-reference/rest-api-username.html#rest-api-username-methods-delete

        :stability: experimental
        '''
        return typing.cast("Mq", jsii.invoke(self, "toDeleteUser", []))

    @jsii.member(jsii_name="toDescribeBroker")
    def to_describe_broker(self) -> "Mq":
        '''(experimental) Grants permission to return information about the specified broker.

        Access Level: Read

        https://docs.aws.amazon.com/amazon-mq/latest/api-reference/rest-api-broker.html#rest-api-broker-methods-get

        :stability: experimental
        '''
        return typing.cast("Mq", jsii.invoke(self, "toDescribeBroker", []))

    @jsii.member(jsii_name="toDescribeBrokerEngineTypes")
    def to_describe_broker_engine_types(self) -> "Mq":
        '''(experimental) Grants permission to return information about broker engines.

        Access Level: Read

        https://docs.aws.amazon.com/amazon-mq/latest/api-reference/broker-engine-types.html#broker-engine-types-http-methods

        :stability: experimental
        '''
        return typing.cast("Mq", jsii.invoke(self, "toDescribeBrokerEngineTypes", []))

    @jsii.member(jsii_name="toDescribeBrokerInstanceOptions")
    def to_describe_broker_instance_options(self) -> "Mq":
        '''(experimental) Grants permission to return information about the broker instance options.

        Access Level: Read

        https://docs.aws.amazon.com/amazon-mq/latest/api-reference/broker-instance-options.html#broker-engine-types-http-methods

        :stability: experimental
        '''
        return typing.cast("Mq", jsii.invoke(self, "toDescribeBrokerInstanceOptions", []))

    @jsii.member(jsii_name="toDescribeConfiguration")
    def to_describe_configuration(self) -> "Mq":
        '''(experimental) Grants permission to return information about the specified configuration.

        Access Level: Read

        https://docs.aws.amazon.com/amazon-mq/latest/api-reference/rest-api-configuration.html#rest-api-configuration-methods-get

        :stability: experimental
        '''
        return typing.cast("Mq", jsii.invoke(self, "toDescribeConfiguration", []))

    @jsii.member(jsii_name="toDescribeConfigurationRevision")
    def to_describe_configuration_revision(self) -> "Mq":
        '''(experimental) Grants permission to return the specified configuration revision for the specified configuration.

        Access Level: Read

        https://docs.aws.amazon.com/amazon-mq/latest/api-reference/rest-api-configuration-revision.html#rest-api-configuration-revision-methods-get

        :stability: experimental
        '''
        return typing.cast("Mq", jsii.invoke(self, "toDescribeConfigurationRevision", []))

    @jsii.member(jsii_name="toDescribeUser")
    def to_describe_user(self) -> "Mq":
        '''(experimental) Grants permission to return information about an ActiveMQ user.

        Access Level: Read

        https://docs.aws.amazon.com/amazon-mq/latest/api-reference/rest-api-username.html#rest-api-username-methods-get

        :stability: experimental
        '''
        return typing.cast("Mq", jsii.invoke(self, "toDescribeUser", []))

    @jsii.member(jsii_name="toListBrokers")
    def to_list_brokers(self) -> "Mq":
        '''(experimental) Grants permission to return a list of all brokers.

        Access Level: List

        https://docs.aws.amazon.com/amazon-mq/latest/api-reference/rest-api-brokers.html#rest-api-brokers-methods-get

        :stability: experimental
        '''
        return typing.cast("Mq", jsii.invoke(self, "toListBrokers", []))

    @jsii.member(jsii_name="toListConfigurationRevisions")
    def to_list_configuration_revisions(self) -> "Mq":
        '''(experimental) Grants permission to return a list of all existing revisions for the specified configuration.

        Access Level: List

        https://docs.aws.amazon.com/amazon-mq/latest/api-reference/rest-api-revisions.html#rest-api-revisions-methods-get

        :stability: experimental
        '''
        return typing.cast("Mq", jsii.invoke(self, "toListConfigurationRevisions", []))

    @jsii.member(jsii_name="toListConfigurations")
    def to_list_configurations(self) -> "Mq":
        '''(experimental) Grants permission to return a list of all configurations.

        Access Level: List

        https://docs.aws.amazon.com/amazon-mq/latest/api-reference/rest-api-configurations.html#rest-api-configurations-methods-get

        :stability: experimental
        '''
        return typing.cast("Mq", jsii.invoke(self, "toListConfigurations", []))

    @jsii.member(jsii_name="toListTags")
    def to_list_tags(self) -> "Mq":
        '''(experimental) Grants permission to return a list of tags.

        Access Level: List

        https://docs.aws.amazon.com/amazon-mq/latest/api-reference/rest-api-tags.html#rest-api-tags-methods-get

        :stability: experimental
        '''
        return typing.cast("Mq", jsii.invoke(self, "toListTags", []))

    @jsii.member(jsii_name="toListUsers")
    def to_list_users(self) -> "Mq":
        '''(experimental) Grants permission to return a list of all ActiveMQ users.

        Access Level: List

        https://docs.aws.amazon.com/amazon-mq/latest/api-reference/rest-api-users.html#rest-api-users-methods-get

        :stability: experimental
        '''
        return typing.cast("Mq", jsii.invoke(self, "toListUsers", []))

    @jsii.member(jsii_name="toRebootBroker")
    def to_reboot_broker(self) -> "Mq":
        '''(experimental) Grants permission to reboot a broker.

        Access Level: Write

        https://docs.aws.amazon.com/amazon-mq/latest/api-reference/rest-api-restart.html#rest-api-reboot-methods-post

        :stability: experimental
        '''
        return typing.cast("Mq", jsii.invoke(self, "toRebootBroker", []))

    @jsii.member(jsii_name="toUpdateBroker")
    def to_update_broker(self) -> "Mq":
        '''(experimental) Grants permission to add a pending configuration change to a broker.

        Access Level: Write

        https://docs.aws.amazon.com/amazon-mq/latest/api-reference/rest-api-broker.html#rest-api-broker-methods-get

        :stability: experimental
        '''
        return typing.cast("Mq", jsii.invoke(self, "toUpdateBroker", []))

    @jsii.member(jsii_name="toUpdateConfiguration")
    def to_update_configuration(self) -> "Mq":
        '''(experimental) Grants permission to update the specified configuration.

        Access Level: Write

        https://docs.aws.amazon.com/amazon-mq/latest/api-reference/rest-api-configuration.html#rest-api-configuration-methods-put

        :stability: experimental
        '''
        return typing.cast("Mq", jsii.invoke(self, "toUpdateConfiguration", []))

    @jsii.member(jsii_name="toUpdateUser")
    def to_update_user(self) -> "Mq":
        '''(experimental) Grants permission to update the information for an ActiveMQ user.

        Access Level: Write

        https://docs.aws.amazon.com/amazon-mq/latest/api-reference/rest-api-username.html#rest-api-username-methods-put

        :stability: experimental
        '''
        return typing.cast("Mq", jsii.invoke(self, "toUpdateUser", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8334e1266391d10dae8c9710b7d05351292e02fc5d31471dd398ed38c9157d09)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__720e72e44079287d0c918b7b70ff593faf2919ade29629daa768651d672c23db)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class NeptuneDb(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.NeptuneDb",
):
    '''(experimental) Statement provider for service `neptune-db <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonneptune.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `neptune-db <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonneptune.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="ifQueryLanguage")
    def if_query_language(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "NeptuneDb":
        '''(experimental) Filters access by graph model.

        https://docs.aws.amazon.com/neptune/latest/userguide/iam-dp-context-keys.html#querylanguage

        Applies to actions:

        - .toDeleteDataViaQuery()
        - .toGetQueryStatus()
        - .toGetStreamRecords()
        - .toReadDataViaQuery()
        - .toWriteDataViaQuery()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8c8e43f91f6c1edb459ca7724ad630c74fc951f253bbd89798731a12c4d7946f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("NeptuneDb", jsii.invoke(self, "ifQueryLanguage", [value, operator]))

    @jsii.member(jsii_name="onDatabase")
    def on_database(
        self,
        cluster: builtins.str,
        database: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "NeptuneDb":
        '''(experimental) Adds a resource of type database to the statement.

        https://docs.aws.amazon.com/neptune/latest/userguide/iam-data-resources.html

        :param cluster: - Identifier for the cluster.
        :param database: - Identifier for the database.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5d04767d72dfcd1974fc48fb21ecb820d485e694ac2c7339650943536010c0a0)
            check_type(argname="argument cluster", value=cluster, expected_type=type_hints["cluster"])
            check_type(argname="argument database", value=database, expected_type=type_hints["database"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("NeptuneDb", jsii.invoke(self, "onDatabase", [cluster, database, account, region, partition]))

    @jsii.member(jsii_name="toCancelLoaderJob")
    def to_cancel_loader_job(self) -> "NeptuneDb":
        '''(experimental) Grants permission to cancel a loader job.

        Access Level: Write

        https://docs.aws.amazon.com/neptune/latest/userguide/iam-dp-actions.html#cancelloaderjob

        :stability: experimental
        '''
        return typing.cast("NeptuneDb", jsii.invoke(self, "toCancelLoaderJob", []))

    @jsii.member(jsii_name="toCancelMLDataProcessingJob")
    def to_cancel_ml_data_processing_job(self) -> "NeptuneDb":
        '''(experimental) Grants permission to cancel an ML data processing job.

        Access Level: Write

        https://docs.aws.amazon.com/neptune/latest/userguide/iam-dp-actions.html#cancelmldataprocessingjob

        :stability: experimental
        '''
        return typing.cast("NeptuneDb", jsii.invoke(self, "toCancelMLDataProcessingJob", []))

    @jsii.member(jsii_name="toCancelMLModelTrainingJob")
    def to_cancel_ml_model_training_job(self) -> "NeptuneDb":
        '''(experimental) Grants permission to cancel an ML model training job.

        Access Level: Write

        https://docs.aws.amazon.com/neptune/latest/userguide/iam-dp-actions.html#cancelmlmodeltrainingjob

        :stability: experimental
        '''
        return typing.cast("NeptuneDb", jsii.invoke(self, "toCancelMLModelTrainingJob", []))

    @jsii.member(jsii_name="toCancelMLModelTransformJob")
    def to_cancel_ml_model_transform_job(self) -> "NeptuneDb":
        '''(experimental) Grants permission to cancel an ML model transform job.

        Access Level: Write

        https://docs.aws.amazon.com/neptune/latest/userguide/iam-dp-actions.html#cancelmlmodeltransformjob

        :stability: experimental
        '''
        return typing.cast("NeptuneDb", jsii.invoke(self, "toCancelMLModelTransformJob", []))

    @jsii.member(jsii_name="toCancelQuery")
    def to_cancel_query(self) -> "NeptuneDb":
        '''(experimental) Grants permission to cancel a query.

        Access Level: Write

        https://docs.aws.amazon.com/neptune/latest/userguide/iam-dp-actions.html#cancelquery

        :stability: experimental
        '''
        return typing.cast("NeptuneDb", jsii.invoke(self, "toCancelQuery", []))

    @jsii.member(jsii_name="toConnect")
    def to_connect(self) -> "NeptuneDb":
        '''(experimental) Grants permission to all data-access actions in engine versions prior to 1.2.0.0.

        Access Level: Write

        https://docs.aws.amazon.com/neptune/latest/userguide/iam-dp-actions.html

        :stability: experimental
        '''
        return typing.cast("NeptuneDb", jsii.invoke(self, "toConnect", []))

    @jsii.member(jsii_name="toCreateMLEndpoint")
    def to_create_ml_endpoint(self) -> "NeptuneDb":
        '''(experimental) Grants permission to create an ML endpoint.

        Access Level: Write

        https://docs.aws.amazon.com/neptune/latest/userguide/iam-dp-actions.html#createmlendpoint

        :stability: experimental
        '''
        return typing.cast("NeptuneDb", jsii.invoke(self, "toCreateMLEndpoint", []))

    @jsii.member(jsii_name="toDeleteDataViaQuery")
    def to_delete_data_via_query(self) -> "NeptuneDb":
        '''(experimental) Grants permission to run delete data via query APIs on database.

        Access Level: Write

        Possible conditions:

        - .ifQueryLanguage()

        https://docs.aws.amazon.com/neptune/latest/userguide/iam-dp-actions.html#deletedataviaquery

        :stability: experimental
        '''
        return typing.cast("NeptuneDb", jsii.invoke(self, "toDeleteDataViaQuery", []))

    @jsii.member(jsii_name="toDeleteMLEndpoint")
    def to_delete_ml_endpoint(self) -> "NeptuneDb":
        '''(experimental) Grants permission to delete an ML endpoint.

        Access Level: Write

        https://docs.aws.amazon.com/neptune/latest/userguide/iam-dp-actions.html#deletemlendpoint

        :stability: experimental
        '''
        return typing.cast("NeptuneDb", jsii.invoke(self, "toDeleteMLEndpoint", []))

    @jsii.member(jsii_name="toDeleteStatistics")
    def to_delete_statistics(self) -> "NeptuneDb":
        '''(experimental) Grants permission to delete all the statistics in the database.

        Access Level: Write

        https://docs.aws.amazon.com/neptune/latest/userguide/iam-dp-actions.html#deletestatistics

        :stability: experimental
        '''
        return typing.cast("NeptuneDb", jsii.invoke(self, "toDeleteStatistics", []))

    @jsii.member(jsii_name="toGetEngineStatus")
    def to_get_engine_status(self) -> "NeptuneDb":
        '''(experimental) Grants permission to check the status of the Neptune engine.

        Access Level: Read

        https://docs.aws.amazon.com/neptune/latest/userguide/iam-dp-actions.html#getenginestatus

        :stability: experimental
        '''
        return typing.cast("NeptuneDb", jsii.invoke(self, "toGetEngineStatus", []))

    @jsii.member(jsii_name="toGetLoaderJobStatus")
    def to_get_loader_job_status(self) -> "NeptuneDb":
        '''(experimental) Grants permission to check the status of a loader job.

        Access Level: Read

        https://docs.aws.amazon.com/neptune/latest/userguide/iam-dp-actions.html#getloaderjobstatus

        :stability: experimental
        '''
        return typing.cast("NeptuneDb", jsii.invoke(self, "toGetLoaderJobStatus", []))

    @jsii.member(jsii_name="toGetMLDataProcessingJobStatus")
    def to_get_ml_data_processing_job_status(self) -> "NeptuneDb":
        '''(experimental) Grants permission to check the status of an ML data processing job.

        Access Level: Read

        https://docs.aws.amazon.com/neptune/latest/userguide/iam-dp-actions.html#getmldataprocessingjobstatus

        :stability: experimental
        '''
        return typing.cast("NeptuneDb", jsii.invoke(self, "toGetMLDataProcessingJobStatus", []))

    @jsii.member(jsii_name="toGetMLEndpointStatus")
    def to_get_ml_endpoint_status(self) -> "NeptuneDb":
        '''(experimental) Grants permission to check the status of an ML endpoint.

        Access Level: Read

        https://docs.aws.amazon.com/neptune/latest/userguide/iam-dp-actions.html#getmlendpointstatus

        :stability: experimental
        '''
        return typing.cast("NeptuneDb", jsii.invoke(self, "toGetMLEndpointStatus", []))

    @jsii.member(jsii_name="toGetMLModelTrainingJobStatus")
    def to_get_ml_model_training_job_status(self) -> "NeptuneDb":
        '''(experimental) Grants permission to check the status of an ML model training job.

        Access Level: Read

        https://docs.aws.amazon.com/neptune/latest/userguide/iam-dp-actions.html#getmlmodeltrainingjobstatus

        :stability: experimental
        '''
        return typing.cast("NeptuneDb", jsii.invoke(self, "toGetMLModelTrainingJobStatus", []))

    @jsii.member(jsii_name="toGetMLModelTransformJobStatus")
    def to_get_ml_model_transform_job_status(self) -> "NeptuneDb":
        '''(experimental) Grants permission to check the status of an ML model transform job.

        Access Level: Read

        https://docs.aws.amazon.com/neptune/latest/userguide/iam-dp-actions.html#getmlmodeltransformjobstatus

        :stability: experimental
        '''
        return typing.cast("NeptuneDb", jsii.invoke(self, "toGetMLModelTransformJobStatus", []))

    @jsii.member(jsii_name="toGetQueryStatus")
    def to_get_query_status(self) -> "NeptuneDb":
        '''(experimental) Grants permission to check the status of all active queries.

        Access Level: Read

        Possible conditions:

        - .ifQueryLanguage()

        https://docs.aws.amazon.com/neptune/latest/userguide/iam-dp-actions.html#getquerystatus

        :stability: experimental
        '''
        return typing.cast("NeptuneDb", jsii.invoke(self, "toGetQueryStatus", []))

    @jsii.member(jsii_name="toGetStatisticsStatus")
    def to_get_statistics_status(self) -> "NeptuneDb":
        '''(experimental) Grants permission to check the status of statistics of the database.

        Access Level: Read

        https://docs.aws.amazon.com/neptune/latest/userguide/iam-dp-actions.html#getstatisticsstatus

        :stability: experimental
        '''
        return typing.cast("NeptuneDb", jsii.invoke(self, "toGetStatisticsStatus", []))

    @jsii.member(jsii_name="toGetStreamRecords")
    def to_get_stream_records(self) -> "NeptuneDb":
        '''(experimental) Grants permission to fetch stream records from Neptune.

        Access Level: Read

        Possible conditions:

        - .ifQueryLanguage()

        https://docs.aws.amazon.com/neptune/latest/userguide/iam-dp-actions.html#getstreamrecords

        :stability: experimental
        '''
        return typing.cast("NeptuneDb", jsii.invoke(self, "toGetStreamRecords", []))

    @jsii.member(jsii_name="toListLoaderJobs")
    def to_list_loader_jobs(self) -> "NeptuneDb":
        '''(experimental) Grants permission to list all the loader jobs.

        Access Level: List

        https://docs.aws.amazon.com/neptune/latest/userguide/iam-dp-actions.html#listloaderjobs

        :stability: experimental
        '''
        return typing.cast("NeptuneDb", jsii.invoke(self, "toListLoaderJobs", []))

    @jsii.member(jsii_name="toListMLDataProcessingJobs")
    def to_list_ml_data_processing_jobs(self) -> "NeptuneDb":
        '''(experimental) Grants permission to list all the ML data processing jobs.

        Access Level: List

        https://docs.aws.amazon.com/neptune/latest/userguide/iam-dp-actions.html#listmldataprocessingjobs

        :stability: experimental
        '''
        return typing.cast("NeptuneDb", jsii.invoke(self, "toListMLDataProcessingJobs", []))

    @jsii.member(jsii_name="toListMLEndpoints")
    def to_list_ml_endpoints(self) -> "NeptuneDb":
        '''(experimental) Grants permission to list all the ML endpoints.

        Access Level: List

        https://docs.aws.amazon.com/neptune/latest/userguide/iam-dp-actions.html#listmlendpoints

        :stability: experimental
        '''
        return typing.cast("NeptuneDb", jsii.invoke(self, "toListMLEndpoints", []))

    @jsii.member(jsii_name="toListMLModelTrainingJobs")
    def to_list_ml_model_training_jobs(self) -> "NeptuneDb":
        '''(experimental) Grants permission to list all the ML model training jobs.

        Access Level: List

        https://docs.aws.amazon.com/neptune/latest/userguide/iam-dp-actions.html#listmlmodeltrainingjobs

        :stability: experimental
        '''
        return typing.cast("NeptuneDb", jsii.invoke(self, "toListMLModelTrainingJobs", []))

    @jsii.member(jsii_name="toListMLModelTransformJobs")
    def to_list_ml_model_transform_jobs(self) -> "NeptuneDb":
        '''(experimental) Grants permission to list all the ML model transform jobs.

        Access Level: List

        https://docs.aws.amazon.com/neptune/latest/userguide/iam-dp-actions.html#listmlmodeltransformjobs

        :stability: experimental
        '''
        return typing.cast("NeptuneDb", jsii.invoke(self, "toListMLModelTransformJobs", []))

    @jsii.member(jsii_name="toManageStatistics")
    def to_manage_statistics(self) -> "NeptuneDb":
        '''(experimental) Grants permission to manage statistics in the database.

        Access Level: Write

        https://docs.aws.amazon.com/neptune/latest/userguide/iam-dp-actions.html#managestatistics

        :stability: experimental
        '''
        return typing.cast("NeptuneDb", jsii.invoke(self, "toManageStatistics", []))

    @jsii.member(jsii_name="toReadDataViaQuery")
    def to_read_data_via_query(self) -> "NeptuneDb":
        '''(experimental) Grants permission to run read data via query APIs on database.

        Access Level: Read

        Possible conditions:

        - .ifQueryLanguage()

        https://docs.aws.amazon.com/neptune/latest/userguide/iam-dp-actions.html#readdataviaquery

        :stability: experimental
        '''
        return typing.cast("NeptuneDb", jsii.invoke(self, "toReadDataViaQuery", []))

    @jsii.member(jsii_name="toResetDatabase")
    def to_reset_database(self) -> "NeptuneDb":
        '''(experimental) Grants permission to get the token needed for reset and resets the Neptune database.

        Access Level: Write

        https://docs.aws.amazon.com/neptune/latest/userguide/iam-dp-actions.html#resetdatabase

        :stability: experimental
        '''
        return typing.cast("NeptuneDb", jsii.invoke(self, "toResetDatabase", []))

    @jsii.member(jsii_name="toStartLoaderJob")
    def to_start_loader_job(self) -> "NeptuneDb":
        '''(experimental) Grants permission to start a loader job.

        Access Level: Write

        https://docs.aws.amazon.com/neptune/latest/userguide/iam-dp-actions.html#startloaderjob

        :stability: experimental
        '''
        return typing.cast("NeptuneDb", jsii.invoke(self, "toStartLoaderJob", []))

    @jsii.member(jsii_name="toStartMLDataProcessingJob")
    def to_start_ml_data_processing_job(self) -> "NeptuneDb":
        '''(experimental) Grants permission to start an ML data processing job.

        Access Level: Write

        https://docs.aws.amazon.com/neptune/latest/userguide/iam-dp-actions.html#startmldataprocessingjob

        :stability: experimental
        '''
        return typing.cast("NeptuneDb", jsii.invoke(self, "toStartMLDataProcessingJob", []))

    @jsii.member(jsii_name="toStartMLModelTrainingJob")
    def to_start_ml_model_training_job(self) -> "NeptuneDb":
        '''(experimental) Grants permission to start an ML model training job.

        Access Level: Write

        https://docs.aws.amazon.com/neptune/latest/userguide/iam-dp-actions.html#startmlmodeltrainingjob

        :stability: experimental
        '''
        return typing.cast("NeptuneDb", jsii.invoke(self, "toStartMLModelTrainingJob", []))

    @jsii.member(jsii_name="toStartMLModelTransformJob")
    def to_start_ml_model_transform_job(self) -> "NeptuneDb":
        '''(experimental) Grants permission to start an ML model transform job.

        Access Level: Write

        https://docs.aws.amazon.com/neptune/latest/userguide/iam-dp-actions.html#startmlmodeltransformjob

        :stability: experimental
        '''
        return typing.cast("NeptuneDb", jsii.invoke(self, "toStartMLModelTransformJob", []))

    @jsii.member(jsii_name="toWriteDataViaQuery")
    def to_write_data_via_query(self) -> "NeptuneDb":
        '''(experimental) Grants permission to run write data via query APIs on database.

        Access Level: Write

        Possible conditions:

        - .ifQueryLanguage()

        https://docs.aws.amazon.com/neptune/latest/userguide/iam-dp-actions.html#writedataviaquery

        :stability: experimental
        '''
        return typing.cast("NeptuneDb", jsii.invoke(self, "toWriteDataViaQuery", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__61454920f63ab5cfd4836ffbfdbcc70128b015261aab86ee8f992c60edcca41a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__459a806786e48dac585f816aca0dce746b01b068faf4e5b9f0d6bd101d37b108)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class NetworkFirewall(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.NetworkFirewall",
):
    '''(experimental) Statement provider for service `network-firewall <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsnetworkfirewall.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `network-firewall <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsnetworkfirewall.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onFirewall")
    def on_firewall(
        self,
        name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "NetworkFirewall":
        '''(experimental) Adds a resource of type Firewall to the statement.

        https://docs.aws.amazon.com/network-firewall/latest/APIReference/API_Firewall.html

        :param name: - Identifier for the name.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6d80b14971c468c1e01cb3ce6153603f424933ea45be312a1ceeb65fc0c3dd0e)
            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("NetworkFirewall", jsii.invoke(self, "onFirewall", [name, account, region, partition]))

    @jsii.member(jsii_name="onFirewallPolicy")
    def on_firewall_policy(
        self,
        name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "NetworkFirewall":
        '''(experimental) Adds a resource of type FirewallPolicy to the statement.

        https://docs.aws.amazon.com/network-firewall/latest/APIReference/API_FirewallPolicyResponse.html

        :param name: - Identifier for the name.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5d196a5d2da2c0fd60c329ed895f13b3e3cc74e4ef9f2f9629412e204b899479)
            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("NetworkFirewall", jsii.invoke(self, "onFirewallPolicy", [name, account, region, partition]))

    @jsii.member(jsii_name="onStatefulRuleGroup")
    def on_stateful_rule_group(
        self,
        name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "NetworkFirewall":
        '''(experimental) Adds a resource of type StatefulRuleGroup to the statement.

        https://docs.aws.amazon.com/network-firewall/latest/APIReference/API_RuleGroupResponse.html

        :param name: - Identifier for the name.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__04d4dd426edf9e353cd9bc03f24ca4a8e0c3b52f4c3536a67a63aa4b7ec6d61f)
            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("NetworkFirewall", jsii.invoke(self, "onStatefulRuleGroup", [name, account, region, partition]))

    @jsii.member(jsii_name="onStatelessRuleGroup")
    def on_stateless_rule_group(
        self,
        name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "NetworkFirewall":
        '''(experimental) Adds a resource of type StatelessRuleGroup to the statement.

        https://docs.aws.amazon.com/network-firewall/latest/APIReference/API_RuleGroupResponse.html

        :param name: - Identifier for the name.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__038a7b578e08dabb9ebd2784c5347a63251c0be66b02017b30905768b50492ef)
            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("NetworkFirewall", jsii.invoke(self, "onStatelessRuleGroup", [name, account, region, partition]))

    @jsii.member(jsii_name="toAssociateFirewallPolicy")
    def to_associate_firewall_policy(self) -> "NetworkFirewall":
        '''(experimental) Grants permission to create an association between a firewall policy and a firewall.

        Access Level: Write

        https://docs.aws.amazon.com/network-firewall/latest/APIReference/API_AssociateFirewallPolicy.html

        :stability: experimental
        '''
        return typing.cast("NetworkFirewall", jsii.invoke(self, "toAssociateFirewallPolicy", []))

    @jsii.member(jsii_name="toAssociateSubnets")
    def to_associate_subnets(self) -> "NetworkFirewall":
        '''(experimental) Grants permission to associate VPC subnets to a firewall.

        Access Level: Write

        https://docs.aws.amazon.com/network-firewall/latest/APIReference/API_AssociateSubnets.html

        :stability: experimental
        '''
        return typing.cast("NetworkFirewall", jsii.invoke(self, "toAssociateSubnets", []))

    @jsii.member(jsii_name="toCreateFirewall")
    def to_create_firewall(self) -> "NetworkFirewall":
        '''(experimental) Grants permission to create an AWS Network Firewall firewall.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - iam:CreateServiceLinkedRole

        https://docs.aws.amazon.com/network-firewall/latest/APIReference/API_CreateFirewall.html

        :stability: experimental
        '''
        return typing.cast("NetworkFirewall", jsii.invoke(self, "toCreateFirewall", []))

    @jsii.member(jsii_name="toCreateFirewallPolicy")
    def to_create_firewall_policy(self) -> "NetworkFirewall":
        '''(experimental) Grants permission to create an AWS Network Firewall firewall policy.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/network-firewall/latest/APIReference/API_CreateFirewallPolicy.html

        :stability: experimental
        '''
        return typing.cast("NetworkFirewall", jsii.invoke(self, "toCreateFirewallPolicy", []))

    @jsii.member(jsii_name="toCreateRuleGroup")
    def to_create_rule_group(self) -> "NetworkFirewall":
        '''(experimental) Grants permission to create an AWS Network Firewall rule group.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/network-firewall/latest/APIReference/API_CreateRuleGroup.html

        :stability: experimental
        '''
        return typing.cast("NetworkFirewall", jsii.invoke(self, "toCreateRuleGroup", []))

    @jsii.member(jsii_name="toDeleteFirewall")
    def to_delete_firewall(self) -> "NetworkFirewall":
        '''(experimental) Grants permission to delete a firewall.

        Access Level: Write

        https://docs.aws.amazon.com/network-firewall/latest/APIReference/API_DeleteFirewall.html

        :stability: experimental
        '''
        return typing.cast("NetworkFirewall", jsii.invoke(self, "toDeleteFirewall", []))

    @jsii.member(jsii_name="toDeleteFirewallPolicy")
    def to_delete_firewall_policy(self) -> "NetworkFirewall":
        '''(experimental) Grants permission to delete a firewall policy.

        Access Level: Write

        https://docs.aws.amazon.com/network-firewall/latest/APIReference/API_DeleteFirewallPolicy.html

        :stability: experimental
        '''
        return typing.cast("NetworkFirewall", jsii.invoke(self, "toDeleteFirewallPolicy", []))

    @jsii.member(jsii_name="toDeleteResourcePolicy")
    def to_delete_resource_policy(self) -> "NetworkFirewall":
        '''(experimental) Grants permission to delete a resource policy for a firewall policy or rule group.

        Access Level: Write

        https://docs.aws.amazon.com/network-firewall/latest/APIReference/API_DeleteResourcePolicy.html

        :stability: experimental
        '''
        return typing.cast("NetworkFirewall", jsii.invoke(self, "toDeleteResourcePolicy", []))

    @jsii.member(jsii_name="toDeleteRuleGroup")
    def to_delete_rule_group(self) -> "NetworkFirewall":
        '''(experimental) Grants permission to delete a rule group.

        Access Level: Write

        https://docs.aws.amazon.com/network-firewall/latest/APIReference/API_DeleteRuleGroup.html

        :stability: experimental
        '''
        return typing.cast("NetworkFirewall", jsii.invoke(self, "toDeleteRuleGroup", []))

    @jsii.member(jsii_name="toDescribeFirewall")
    def to_describe_firewall(self) -> "NetworkFirewall":
        '''(experimental) Grants permission to retrieve the data objects that define a firewall.

        Access Level: Read

        https://docs.aws.amazon.com/network-firewall/latest/APIReference/API_DescribeFirewall.html

        :stability: experimental
        '''
        return typing.cast("NetworkFirewall", jsii.invoke(self, "toDescribeFirewall", []))

    @jsii.member(jsii_name="toDescribeFirewallPolicy")
    def to_describe_firewall_policy(self) -> "NetworkFirewall":
        '''(experimental) Grants permission to retrieve the data objects that define a firewall policy.

        Access Level: Read

        https://docs.aws.amazon.com/network-firewall/latest/APIReference/API_DescribeFirewallPolicy.html

        :stability: experimental
        '''
        return typing.cast("NetworkFirewall", jsii.invoke(self, "toDescribeFirewallPolicy", []))

    @jsii.member(jsii_name="toDescribeLoggingConfiguration")
    def to_describe_logging_configuration(self) -> "NetworkFirewall":
        '''(experimental) Grants permission to describe the logging configuration of a firewall.

        Access Level: Read

        https://docs.aws.amazon.com/network-firewall/latest/APIReference/API_DescribeLoggingConfiguration.html

        :stability: experimental
        '''
        return typing.cast("NetworkFirewall", jsii.invoke(self, "toDescribeLoggingConfiguration", []))

    @jsii.member(jsii_name="toDescribeResourcePolicy")
    def to_describe_resource_policy(self) -> "NetworkFirewall":
        '''(experimental) Grants permission to describe a resource policy for a firewall policy or rule group.

        Access Level: Read

        https://docs.aws.amazon.com/network-firewall/latest/APIReference/API_DescribeResourcePolicy.html

        :stability: experimental
        '''
        return typing.cast("NetworkFirewall", jsii.invoke(self, "toDescribeResourcePolicy", []))

    @jsii.member(jsii_name="toDescribeRuleGroup")
    def to_describe_rule_group(self) -> "NetworkFirewall":
        '''(experimental) Grants permission to retrieve the data objects that define a rule group.

        Access Level: Read

        https://docs.aws.amazon.com/network-firewall/latest/APIReference/API_DescribeRuleGroup.html

        :stability: experimental
        '''
        return typing.cast("NetworkFirewall", jsii.invoke(self, "toDescribeRuleGroup", []))

    @jsii.member(jsii_name="toDescribeRuleGroupMetadata")
    def to_describe_rule_group_metadata(self) -> "NetworkFirewall":
        '''(experimental) Grants permission to retrieve the high-level information about a rule group.

        Access Level: Read

        https://docs.aws.amazon.com/network-firewall/latest/APIReference/API_DescribeRuleGroupMetadata.html

        :stability: experimental
        '''
        return typing.cast("NetworkFirewall", jsii.invoke(self, "toDescribeRuleGroupMetadata", []))

    @jsii.member(jsii_name="toDisassociateSubnets")
    def to_disassociate_subnets(self) -> "NetworkFirewall":
        '''(experimental) Grants permission to disassociate VPC subnets from a firewall.

        Access Level: Write

        https://docs.aws.amazon.com/network-firewall/latest/APIReference/API_DisassociateSubnets.html

        :stability: experimental
        '''
        return typing.cast("NetworkFirewall", jsii.invoke(self, "toDisassociateSubnets", []))

    @jsii.member(jsii_name="toListFirewallPolicies")
    def to_list_firewall_policies(self) -> "NetworkFirewall":
        '''(experimental) Grants permission to retrieve the metadata for firewall policies.

        Access Level: List

        https://docs.aws.amazon.com/network-firewall/latest/APIReference/API_ListFirewallPolicies.html

        :stability: experimental
        '''
        return typing.cast("NetworkFirewall", jsii.invoke(self, "toListFirewallPolicies", []))

    @jsii.member(jsii_name="toListFirewalls")
    def to_list_firewalls(self) -> "NetworkFirewall":
        '''(experimental) Grants permission to retrieve the metadata for firewalls.

        Access Level: List

        https://docs.aws.amazon.com/network-firewall/latest/APIReference/API_ListFirewalls.html

        :stability: experimental
        '''
        return typing.cast("NetworkFirewall", jsii.invoke(self, "toListFirewalls", []))

    @jsii.member(jsii_name="toListRuleGroups")
    def to_list_rule_groups(self) -> "NetworkFirewall":
        '''(experimental) Grants permission to retrieve the metadata for rule groups.

        Access Level: List

        https://docs.aws.amazon.com/network-firewall/latest/APIReference/API_ListRuleGroups.html

        :stability: experimental
        '''
        return typing.cast("NetworkFirewall", jsii.invoke(self, "toListRuleGroups", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "NetworkFirewall":
        '''(experimental) Grants permission to retrieve the tags for a resource.

        Access Level: List

        https://docs.aws.amazon.com/network-firewall/latest/APIReference/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("NetworkFirewall", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toPutResourcePolicy")
    def to_put_resource_policy(self) -> "NetworkFirewall":
        '''(experimental) Grants permission to put a resource policy for a firewall policy or rule group.

        Access Level: Write

        https://docs.aws.amazon.com/network-firewall/latest/APIReference/API_PutResourcePolicy.html

        :stability: experimental
        '''
        return typing.cast("NetworkFirewall", jsii.invoke(self, "toPutResourcePolicy", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "NetworkFirewall":
        '''(experimental) Grants permission to attach tags to a resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/network-firewall/latest/APIReference/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("NetworkFirewall", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "NetworkFirewall":
        '''(experimental) Grants permission to remove tags from a resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/network-firewall/latest/APIReference/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("NetworkFirewall", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateFirewallDeleteProtection")
    def to_update_firewall_delete_protection(self) -> "NetworkFirewall":
        '''(experimental) Grants permission to add or remove delete protection for a firewall.

        Access Level: Write

        https://docs.aws.amazon.com/network-firewall/latest/APIReference/API_UpdateFirewallDeleteProtection.html

        :stability: experimental
        '''
        return typing.cast("NetworkFirewall", jsii.invoke(self, "toUpdateFirewallDeleteProtection", []))

    @jsii.member(jsii_name="toUpdateFirewallDescription")
    def to_update_firewall_description(self) -> "NetworkFirewall":
        '''(experimental) Grants permission to modify the description for a firewall.

        Access Level: Write

        https://docs.aws.amazon.com/network-firewall/latest/APIReference/API_UpdateFirewallDescription.html

        :stability: experimental
        '''
        return typing.cast("NetworkFirewall", jsii.invoke(self, "toUpdateFirewallDescription", []))

    @jsii.member(jsii_name="toUpdateFirewallEncryptionConfiguration")
    def to_update_firewall_encryption_configuration(self) -> "NetworkFirewall":
        '''(experimental) Grants permission to modify the encryption configuration of a firewall.

        Access Level: Write

        https://docs.aws.amazon.com/network-firewall/latest/APIReference/API_UpdateFirewallEncryptionConfiguration.html

        :stability: experimental
        '''
        return typing.cast("NetworkFirewall", jsii.invoke(self, "toUpdateFirewallEncryptionConfiguration", []))

    @jsii.member(jsii_name="toUpdateFirewallPolicy")
    def to_update_firewall_policy(self) -> "NetworkFirewall":
        '''(experimental) Grants permission to modify a firewall policy.

        Access Level: Write

        https://docs.aws.amazon.com/network-firewall/latest/APIReference/API_UpdateFirewallPolicy.html

        :stability: experimental
        '''
        return typing.cast("NetworkFirewall", jsii.invoke(self, "toUpdateFirewallPolicy", []))

    @jsii.member(jsii_name="toUpdateFirewallPolicyChangeProtection")
    def to_update_firewall_policy_change_protection(self) -> "NetworkFirewall":
        '''(experimental) Grants permission to add or remove firewall policy change protection for a firewall.

        Access Level: Write

        https://docs.aws.amazon.com/network-firewall/latest/APIReference/API_UpdateFirewallPolicyChangeProtection.html

        :stability: experimental
        '''
        return typing.cast("NetworkFirewall", jsii.invoke(self, "toUpdateFirewallPolicyChangeProtection", []))

    @jsii.member(jsii_name="toUpdateLoggingConfiguration")
    def to_update_logging_configuration(self) -> "NetworkFirewall":
        '''(experimental) Grants permission to modify the logging configuration of a firewall.

        Access Level: Write

        https://docs.aws.amazon.com/network-firewall/latest/APIReference/API_UpdateLoggingConfiguration.html

        :stability: experimental
        '''
        return typing.cast("NetworkFirewall", jsii.invoke(self, "toUpdateLoggingConfiguration", []))

    @jsii.member(jsii_name="toUpdateRuleGroup")
    def to_update_rule_group(self) -> "NetworkFirewall":
        '''(experimental) Grants permission to modify a rule group.

        Access Level: Write

        https://docs.aws.amazon.com/network-firewall/latest/APIReference/API_UpdateRuleGroup.html

        :stability: experimental
        '''
        return typing.cast("NetworkFirewall", jsii.invoke(self, "toUpdateRuleGroup", []))

    @jsii.member(jsii_name="toUpdateSubnetChangeProtection")
    def to_update_subnet_change_protection(self) -> "NetworkFirewall":
        '''(experimental) Grants permission to add or remove subnet change protection for a firewall.

        Access Level: Write

        https://docs.aws.amazon.com/network-firewall/latest/APIReference/API_UpdateSubnetChangeProtection.html

        :stability: experimental
        '''
        return typing.cast("NetworkFirewall", jsii.invoke(self, "toUpdateSubnetChangeProtection", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4c84281f2fb3851747d3089f871b53241143d19e0260213e27976e35b3d26ea2)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__987c811ac65f43f579e3235927f690070963b2e8fb98beecd0260fe335a0cd28)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Networkmanager(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Networkmanager",
):
    '''(experimental) Statement provider for service `networkmanager <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsnetworkmanager.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `networkmanager <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsnetworkmanager.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="ifCgwArn")
    def if_cgw_arn(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Networkmanager":
        '''(experimental) Filters access by which customer gateways can be associated or disassociated.

        https://docs.aws.amazon.com/vpc/latest/tgw/nm-security-iam.html

        Applies to actions:

        - .toAssociateCustomerGateway()
        - .toDisassociateCustomerGateway()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__708e31b0540a47b1c11a3f83a24b3a235b00206322b2bfbc8bdc82d63ff4dbae)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Networkmanager", jsii.invoke(self, "ifCgwArn", [value, operator]))

    @jsii.member(jsii_name="ifSubnetArns")
    def if_subnet_arns(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Networkmanager":
        '''(experimental) Filters access by which VPC subnets can be added or removed from a VPC attachment.

        https://docs.aws.amazon.com/vpc/latest/tgw/nm-security-iam.html

        Applies to actions:

        - .toCreateVpcAttachment()
        - .toUpdateVpcAttachment()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__073e67904272b2c0a769d324a8e2a54e7b9e2cad92e2fcea2c20e0e2ccc0ba77)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Networkmanager", jsii.invoke(self, "ifSubnetArns", [value, operator]))

    @jsii.member(jsii_name="ifTgwArn")
    def if_tgw_arn(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Networkmanager":
        '''(experimental) Filters access by which transit gateways can be registered, deregistered, or peered.

        https://docs.aws.amazon.com/vpc/latest/tgw/nm-security-iam.html

        Applies to actions:

        - .toCreateTransitGatewayPeering()
        - .toDeregisterTransitGateway()
        - .toRegisterTransitGateway()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e7a8ed033ea21c7622d86a323cf4818c955596830a2d5c06708f3dcef022b014)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Networkmanager", jsii.invoke(self, "ifTgwArn", [value, operator]))

    @jsii.member(jsii_name="ifTgwConnectPeerArn")
    def if_tgw_connect_peer_arn(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Networkmanager":
        '''(experimental) Filters access by which transit gateway connect peers can be associated or disassociated.

        https://docs.aws.amazon.com/vpc/latest/tgw/nm-security-iam.html

        Applies to actions:

        - .toAssociateTransitGatewayConnectPeer()
        - .toDisassociateTransitGatewayConnectPeer()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__44b03e62227e63913603c3a962f965828f2b858c2b984d725de7c2c6e59f90f8)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Networkmanager", jsii.invoke(self, "ifTgwConnectPeerArn", [value, operator]))

    @jsii.member(jsii_name="ifTgwRtbArn")
    def if_tgw_rtb_arn(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Networkmanager":
        '''(experimental) Filters access by which Transit Gateway Route Table can be used to create an attachment.

        https://docs.aws.amazon.com/vpc/latest/tgw/nm-security-iam.html

        Applies to actions:

        - .toCreateTransitGatewayRouteTableAttachment()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f4ba624855214f3f57bc89a536ad22528f93c2f5612674b37f767a90cf2524b2)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Networkmanager", jsii.invoke(self, "ifTgwRtbArn", [value, operator]))

    @jsii.member(jsii_name="ifVpcArn")
    def if_vpc_arn(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Networkmanager":
        '''(experimental) Filters access by which VPC can be used to a create/update attachment.

        https://docs.aws.amazon.com/vpc/latest/tgw/nm-security-iam.html

        Applies to actions:

        - .toCreateVpcAttachment()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__36d7b013d35ae83ffe348df9c48847fb5bd6ddf15df395516b843354c81b4b13)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Networkmanager", jsii.invoke(self, "ifVpcArn", [value, operator]))

    @jsii.member(jsii_name="ifVpnConnectionArn")
    def if_vpn_connection_arn(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Networkmanager":
        '''(experimental) Filters access by which Site-to-Site VPN can be used to a create/update attachment.

        https://docs.aws.amazon.com/vpc/latest/tgw/nm-security-iam.html

        Applies to actions:

        - .toCreateSiteToSiteVpnAttachment()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7021db8d765ca1c3e3e097829644f61e204c92c80414aa44300d91d9667027bc)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Networkmanager", jsii.invoke(self, "ifVpnConnectionArn", [value, operator]))

    @jsii.member(jsii_name="onAttachment")
    def on_attachment(
        self,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Networkmanager":
        '''(experimental) Adds a resource of type attachment to the statement.

        https://docs.aws.amazon.com/vpc/latest/tgw/what-is-network-manager.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a991a7f093e8829bbff23ef10e2170c56333f91b3715f7532c4a2445adf25ea7)
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Networkmanager", jsii.invoke(self, "onAttachment", [resource_id, account, partition]))

    @jsii.member(jsii_name="onConnection")
    def on_connection(
        self,
        global_network_id: builtins.str,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Networkmanager":
        '''(experimental) Adds a resource of type connection to the statement.

        https://docs.aws.amazon.com/vpc/latest/tgw/what-is-network-manager.html

        :param global_network_id: - Identifier for the globalNetworkId.
        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2db4aca01257970d14ab37d39b4ba7b6e1d41312d80948af918642e9068b04f1)
            check_type(argname="argument global_network_id", value=global_network_id, expected_type=type_hints["global_network_id"])
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Networkmanager", jsii.invoke(self, "onConnection", [global_network_id, resource_id, account, partition]))

    @jsii.member(jsii_name="onConnectPeer")
    def on_connect_peer(
        self,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Networkmanager":
        '''(experimental) Adds a resource of type connect-peer to the statement.

        https://docs.aws.amazon.com/vpc/latest/tgw/what-is-network-manager.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2cc8aef40cb67de663867261f8774ea673f6df43cfc45604974df3afb4c95142)
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Networkmanager", jsii.invoke(self, "onConnectPeer", [resource_id, account, partition]))

    @jsii.member(jsii_name="onCoreNetwork")
    def on_core_network(
        self,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Networkmanager":
        '''(experimental) Adds a resource of type core-network to the statement.

        https://docs.aws.amazon.com/vpc/latest/tgw/what-is-network-manager.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b237383bb09b2137338691ae2538133b5ba7a843bc259cfa02c33c17cd16cd4a)
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Networkmanager", jsii.invoke(self, "onCoreNetwork", [resource_id, account, partition]))

    @jsii.member(jsii_name="onDevice")
    def on_device(
        self,
        global_network_id: builtins.str,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Networkmanager":
        '''(experimental) Adds a resource of type device to the statement.

        https://docs.aws.amazon.com/vpc/latest/tgw/what-is-network-manager.html

        :param global_network_id: - Identifier for the globalNetworkId.
        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__461b6d83168b5cb4790b7379247e8607263ec99e2c086cd2549a73a0452702ff)
            check_type(argname="argument global_network_id", value=global_network_id, expected_type=type_hints["global_network_id"])
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Networkmanager", jsii.invoke(self, "onDevice", [global_network_id, resource_id, account, partition]))

    @jsii.member(jsii_name="onGlobalNetwork")
    def on_global_network(
        self,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Networkmanager":
        '''(experimental) Adds a resource of type global-network to the statement.

        https://docs.aws.amazon.com/vpc/latest/tgw/what-is-network-manager.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0feaf7ccfa789049cb83f50bfc2e4b224e039650aa7fc03f1c9793fd94695985)
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Networkmanager", jsii.invoke(self, "onGlobalNetwork", [resource_id, account, partition]))

    @jsii.member(jsii_name="onLink")
    def on_link(
        self,
        global_network_id: builtins.str,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Networkmanager":
        '''(experimental) Adds a resource of type link to the statement.

        https://docs.aws.amazon.com/vpc/latest/tgw/what-is-network-manager.html

        :param global_network_id: - Identifier for the globalNetworkId.
        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b7b83adcd3b53fd20e9eb98c08ce5e59cb07b8f789cd59d69706b0e21b486ebb)
            check_type(argname="argument global_network_id", value=global_network_id, expected_type=type_hints["global_network_id"])
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Networkmanager", jsii.invoke(self, "onLink", [global_network_id, resource_id, account, partition]))

    @jsii.member(jsii_name="onPeering")
    def on_peering(
        self,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Networkmanager":
        '''(experimental) Adds a resource of type peering to the statement.

        https://docs.aws.amazon.com/vpc/latest/tgw/what-is-network-manager.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6bfe30a627f44e0aab1066f37f22ab6e945400aaf03d83b46c2898aacba2cb09)
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Networkmanager", jsii.invoke(self, "onPeering", [resource_id, account, partition]))

    @jsii.member(jsii_name="onSite")
    def on_site(
        self,
        global_network_id: builtins.str,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Networkmanager":
        '''(experimental) Adds a resource of type site to the statement.

        https://docs.aws.amazon.com/vpc/latest/tgw/what-is-network-manager.html

        :param global_network_id: - Identifier for the globalNetworkId.
        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5af7be99280fa7b02ac98b39b0bb3afa7f941426a0305d5ae0db3596492604c0)
            check_type(argname="argument global_network_id", value=global_network_id, expected_type=type_hints["global_network_id"])
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Networkmanager", jsii.invoke(self, "onSite", [global_network_id, resource_id, account, partition]))

    @jsii.member(jsii_name="toAcceptAttachment")
    def to_accept_attachment(self) -> "Networkmanager":
        '''(experimental) Grants permission to accept creation of an attachment between a source and destination in a core network.

        Access Level: Write

        https://docs.aws.amazon.com/networkmanager/latest/APIReference/API_AcceptAttachment.html

        :stability: experimental
        '''
        return typing.cast("Networkmanager", jsii.invoke(self, "toAcceptAttachment", []))

    @jsii.member(jsii_name="toAssociateConnectPeer")
    def to_associate_connect_peer(self) -> "Networkmanager":
        '''(experimental) Grants permission to associate a Connect Peer.

        Access Level: Write

        https://docs.aws.amazon.com/networkmanager/latest/APIReference/API_AssociateConnectPeer.html

        :stability: experimental
        '''
        return typing.cast("Networkmanager", jsii.invoke(self, "toAssociateConnectPeer", []))

    @jsii.member(jsii_name="toAssociateCustomerGateway")
    def to_associate_customer_gateway(self) -> "Networkmanager":
        '''(experimental) Grants permission to associate a customer gateway to a device.

        Access Level: Write

        Possible conditions:

        - .ifCgwArn()

        https://docs.aws.amazon.com/networkmanager/latest/APIReference/API_AssociateCustomerGateway.html

        :stability: experimental
        '''
        return typing.cast("Networkmanager", jsii.invoke(self, "toAssociateCustomerGateway", []))

    @jsii.member(jsii_name="toAssociateLink")
    def to_associate_link(self) -> "Networkmanager":
        '''(experimental) Grants permission to associate a link to a device.

        Access Level: Write

        https://docs.aws.amazon.com/networkmanager/latest/APIReference/API_AssociateLink.html

        :stability: experimental
        '''
        return typing.cast("Networkmanager", jsii.invoke(self, "toAssociateLink", []))

    @jsii.member(jsii_name="toAssociateTransitGatewayConnectPeer")
    def to_associate_transit_gateway_connect_peer(self) -> "Networkmanager":
        '''(experimental) Grants permission to associate a transit gateway connect peer to a device.

        Access Level: Write

        Possible conditions:

        - .ifTgwConnectPeerArn()

        https://docs.aws.amazon.com/networkmanager/latest/APIReference/API_AssociateTransitGatewayConnectPeer.html

        :stability: experimental
        '''
        return typing.cast("Networkmanager", jsii.invoke(self, "toAssociateTransitGatewayConnectPeer", []))

    @jsii.member(jsii_name="toCreateConnectAttachment")
    def to_create_connect_attachment(self) -> "Networkmanager":
        '''(experimental) Grants permission to create a Connect attachment.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/networkmanager/latest/APIReference/API_CreateConnectAttachment.html

        :stability: experimental
        '''
        return typing.cast("Networkmanager", jsii.invoke(self, "toCreateConnectAttachment", []))

    @jsii.member(jsii_name="toCreateConnection")
    def to_create_connection(self) -> "Networkmanager":
        '''(experimental) Grants permission to create a new connection.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/networkmanager/latest/APIReference/API_CreateConnection.html

        :stability: experimental
        '''
        return typing.cast("Networkmanager", jsii.invoke(self, "toCreateConnection", []))

    @jsii.member(jsii_name="toCreateConnectPeer")
    def to_create_connect_peer(self) -> "Networkmanager":
        '''(experimental) Grants permission to create a Connect Peer connection.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/networkmanager/latest/APIReference/API_CreateConnectPeer.html

        :stability: experimental
        '''
        return typing.cast("Networkmanager", jsii.invoke(self, "toCreateConnectPeer", []))

    @jsii.member(jsii_name="toCreateCoreNetwork")
    def to_create_core_network(self) -> "Networkmanager":
        '''(experimental) Grants permission to create a new core network.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/networkmanager/latest/APIReference/API_CreateCoreNetwork.html

        :stability: experimental
        '''
        return typing.cast("Networkmanager", jsii.invoke(self, "toCreateCoreNetwork", []))

    @jsii.member(jsii_name="toCreateDevice")
    def to_create_device(self) -> "Networkmanager":
        '''(experimental) Grants permission to create a new device.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/networkmanager/latest/APIReference/API_CreateDevice.html

        :stability: experimental
        '''
        return typing.cast("Networkmanager", jsii.invoke(self, "toCreateDevice", []))

    @jsii.member(jsii_name="toCreateGlobalNetwork")
    def to_create_global_network(self) -> "Networkmanager":
        '''(experimental) Grants permission to create a new global network.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - iam:CreateServiceLinkedRole

        https://docs.aws.amazon.com/networkmanager/latest/APIReference/API_CreateGlobalNetwork.html

        :stability: experimental
        '''
        return typing.cast("Networkmanager", jsii.invoke(self, "toCreateGlobalNetwork", []))

    @jsii.member(jsii_name="toCreateLink")
    def to_create_link(self) -> "Networkmanager":
        '''(experimental) Grants permission to create a new link.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/networkmanager/latest/APIReference/API_CreateLink.html

        :stability: experimental
        '''
        return typing.cast("Networkmanager", jsii.invoke(self, "toCreateLink", []))

    @jsii.member(jsii_name="toCreateSite")
    def to_create_site(self) -> "Networkmanager":
        '''(experimental) Grants permission to create a new site.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/networkmanager/latest/APIReference/API_CreateSite.html

        :stability: experimental
        '''
        return typing.cast("Networkmanager", jsii.invoke(self, "toCreateSite", []))

    @jsii.member(jsii_name="toCreateSiteToSiteVpnAttachment")
    def to_create_site_to_site_vpn_attachment(self) -> "Networkmanager":
        '''(experimental) Grants permission to create a site-to-site VPN attachment.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifVpnConnectionArn()

        https://docs.aws.amazon.com/networkmanager/latest/APIReference/API_CreateSiteToSiteVpnAttachment.html

        :stability: experimental
        '''
        return typing.cast("Networkmanager", jsii.invoke(self, "toCreateSiteToSiteVpnAttachment", []))

    @jsii.member(jsii_name="toCreateTransitGatewayPeering")
    def to_create_transit_gateway_peering(self) -> "Networkmanager":
        '''(experimental) Grants permission to create a Transit Gateway peering.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifTgwArn()

        https://docs.aws.amazon.com/networkmanager/latest/APIReference/API_CreateTransitGatewayPeering.html

        :stability: experimental
        '''
        return typing.cast("Networkmanager", jsii.invoke(self, "toCreateTransitGatewayPeering", []))

    @jsii.member(jsii_name="toCreateTransitGatewayRouteTableAttachment")
    def to_create_transit_gateway_route_table_attachment(self) -> "Networkmanager":
        '''(experimental) Grants permission to create a TGW RTB attachment.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifTgwRtbArn()

        https://docs.aws.amazon.com/networkmanager/latest/APIReference/API_CreateTransitGatewayRouteTableAttachment.html

        :stability: experimental
        '''
        return typing.cast("Networkmanager", jsii.invoke(self, "toCreateTransitGatewayRouteTableAttachment", []))

    @jsii.member(jsii_name="toCreateVpcAttachment")
    def to_create_vpc_attachment(self) -> "Networkmanager":
        '''(experimental) Grants permission to create a VPC attachment.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifVpcArn()
        - .ifSubnetArns()

        https://docs.aws.amazon.com/networkmanager/latest/APIReference/API_CreateVpcAttachment.html

        :stability: experimental
        '''
        return typing.cast("Networkmanager", jsii.invoke(self, "toCreateVpcAttachment", []))

    @jsii.member(jsii_name="toDeleteAttachment")
    def to_delete_attachment(self) -> "Networkmanager":
        '''(experimental) Grants permission to delete an attachment.

        Access Level: Write

        https://docs.aws.amazon.com/networkmanager/latest/APIReference/API_DeleteAttachment.html

        :stability: experimental
        '''
        return typing.cast("Networkmanager", jsii.invoke(self, "toDeleteAttachment", []))

    @jsii.member(jsii_name="toDeleteConnection")
    def to_delete_connection(self) -> "Networkmanager":
        '''(experimental) Grants permission to delete a connection.

        Access Level: Write

        https://docs.aws.amazon.com/networkmanager/latest/APIReference/API_DeleteConnection.html

        :stability: experimental
        '''
        return typing.cast("Networkmanager", jsii.invoke(self, "toDeleteConnection", []))

    @jsii.member(jsii_name="toDeleteConnectPeer")
    def to_delete_connect_peer(self) -> "Networkmanager":
        '''(experimental) Grants permission to delete a Connect Peer.

        Access Level: Write

        https://docs.aws.amazon.com/networkmanager/latest/APIReference/API_DeleteConnectPeer.html

        :stability: experimental
        '''
        return typing.cast("Networkmanager", jsii.invoke(self, "toDeleteConnectPeer", []))

    @jsii.member(jsii_name="toDeleteCoreNetwork")
    def to_delete_core_network(self) -> "Networkmanager":
        '''(experimental) Grants permission to delete a core network.

        Access Level: Write

        https://docs.aws.amazon.com/networkmanager/latest/APIReference/API_DeleteCoreNetwork.html

        :stability: experimental
        '''
        return typing.cast("Networkmanager", jsii.invoke(self, "toDeleteCoreNetwork", []))

    @jsii.member(jsii_name="toDeleteCoreNetworkPolicyVersion")
    def to_delete_core_network_policy_version(self) -> "Networkmanager":
        '''(experimental) Grants permission to delete the core network policy version.

        Access Level: Write

        https://docs.aws.amazon.com/networkmanager/latest/APIReference/API_DeleteCoreNetworkPolicyVersion.html

        :stability: experimental
        '''
        return typing.cast("Networkmanager", jsii.invoke(self, "toDeleteCoreNetworkPolicyVersion", []))

    @jsii.member(jsii_name="toDeleteDevice")
    def to_delete_device(self) -> "Networkmanager":
        '''(experimental) Grants permission to delete a device.

        Access Level: Write

        https://docs.aws.amazon.com/networkmanager/latest/APIReference/API_DeleteDevice.html

        :stability: experimental
        '''
        return typing.cast("Networkmanager", jsii.invoke(self, "toDeleteDevice", []))

    @jsii.member(jsii_name="toDeleteGlobalNetwork")
    def to_delete_global_network(self) -> "Networkmanager":
        '''(experimental) Grants permission to delete a global network.

        Access Level: Write

        https://docs.aws.amazon.com/networkmanager/latest/APIReference/API_DeleteGlobalNetwork.html

        :stability: experimental
        '''
        return typing.cast("Networkmanager", jsii.invoke(self, "toDeleteGlobalNetwork", []))

    @jsii.member(jsii_name="toDeleteLink")
    def to_delete_link(self) -> "Networkmanager":
        '''(experimental) Grants permission to delete a link.

        Access Level: Write

        https://docs.aws.amazon.com/networkmanager/latest/APIReference/API_DeleteLink.html

        :stability: experimental
        '''
        return typing.cast("Networkmanager", jsii.invoke(self, "toDeleteLink", []))

    @jsii.member(jsii_name="toDeletePeering")
    def to_delete_peering(self) -> "Networkmanager":
        '''(experimental) Grants permission to delete a peering.

        Access Level: Write

        https://docs.aws.amazon.com/networkmanager/latest/APIReference/API_DeletePeering.html

        :stability: experimental
        '''
        return typing.cast("Networkmanager", jsii.invoke(self, "toDeletePeering", []))

    @jsii.member(jsii_name="toDeleteResourcePolicy")
    def to_delete_resource_policy(self) -> "Networkmanager":
        '''(experimental) Grants permission to delete a resource.

        Access Level: Write

        https://docs.aws.amazon.com/networkmanager/latest/APIReference/API_DeleteResourcePolicy.html

        :stability: experimental
        '''
        return typing.cast("Networkmanager", jsii.invoke(self, "toDeleteResourcePolicy", []))

    @jsii.member(jsii_name="toDeleteSite")
    def to_delete_site(self) -> "Networkmanager":
        '''(experimental) Grants permission to delete a site.

        Access Level: Write

        https://docs.aws.amazon.com/networkmanager/latest/APIReference/API_DeleteSite.html

        :stability: experimental
        '''
        return typing.cast("Networkmanager", jsii.invoke(self, "toDeleteSite", []))

    @jsii.member(jsii_name="toDeregisterTransitGateway")
    def to_deregister_transit_gateway(self) -> "Networkmanager":
        '''(experimental) Grants permission to deregister a transit gateway from a global network.

        Access Level: Write

        Possible conditions:

        - .ifTgwArn()

        https://docs.aws.amazon.com/networkmanager/latest/APIReference/API_DeregisterTransitGateway.html

        :stability: experimental
        '''
        return typing.cast("Networkmanager", jsii.invoke(self, "toDeregisterTransitGateway", []))

    @jsii.member(jsii_name="toDescribeGlobalNetworks")
    def to_describe_global_networks(self) -> "Networkmanager":
        '''(experimental) Grants permission to describe global networks.

        Access Level: List

        https://docs.aws.amazon.com/networkmanager/latest/APIReference/API_DescribeGlobalNetworks.html

        :stability: experimental
        '''
        return typing.cast("Networkmanager", jsii.invoke(self, "toDescribeGlobalNetworks", []))

    @jsii.member(jsii_name="toDisassociateConnectPeer")
    def to_disassociate_connect_peer(self) -> "Networkmanager":
        '''(experimental) Grants permission to disassociate a Connect Peer.

        Access Level: Write

        https://docs.aws.amazon.com/networkmanager/latest/APIReference/API_DisassociateConnectPeer.html

        :stability: experimental
        '''
        return typing.cast("Networkmanager", jsii.invoke(self, "toDisassociateConnectPeer", []))

    @jsii.member(jsii_name="toDisassociateCustomerGateway")
    def to_disassociate_customer_gateway(self) -> "Networkmanager":
        '''(experimental) Grants permission to disassociate a customer gateway from a device.

        Access Level: Write

        Possible conditions:

        - .ifCgwArn()

        https://docs.aws.amazon.com/networkmanager/latest/APIReference/API_DisassociateCustomerGateway.html

        :stability: experimental
        '''
        return typing.cast("Networkmanager", jsii.invoke(self, "toDisassociateCustomerGateway", []))

    @jsii.member(jsii_name="toDisassociateLink")
    def to_disassociate_link(self) -> "Networkmanager":
        '''(experimental) Grants permission to disassociate a link from a device.

        Access Level: Write

        https://docs.aws.amazon.com/networkmanager/latest/APIReference/API_DisassociateLink.html

        :stability: experimental
        '''
        return typing.cast("Networkmanager", jsii.invoke(self, "toDisassociateLink", []))

    @jsii.member(jsii_name="toDisassociateTransitGatewayConnectPeer")
    def to_disassociate_transit_gateway_connect_peer(self) -> "Networkmanager":
        '''(experimental) Grants permission to disassociate a transit gateway connect peer from a device.

        Access Level: Write

        Possible conditions:

        - .ifTgwConnectPeerArn()

        https://docs.aws.amazon.com/networkmanager/latest/APIReference/API_DisassociateTransitGatewayConnectPeer.html

        :stability: experimental
        '''
        return typing.cast("Networkmanager", jsii.invoke(self, "toDisassociateTransitGatewayConnectPeer", []))

    @jsii.member(jsii_name="toExecuteCoreNetworkChangeSet")
    def to_execute_core_network_change_set(self) -> "Networkmanager":
        '''(experimental) Grants permission to apply changes to the core network.

        Access Level: Write

        https://docs.aws.amazon.com/networkmanager/latest/APIReference/API_ExecuteCoreNetworkChangeSet.html

        :stability: experimental
        '''
        return typing.cast("Networkmanager", jsii.invoke(self, "toExecuteCoreNetworkChangeSet", []))

    @jsii.member(jsii_name="toGetConnectAttachment")
    def to_get_connect_attachment(self) -> "Networkmanager":
        '''(experimental) Grants permission to retrieve a Connect attachment.

        Access Level: Read

        https://docs.aws.amazon.com/networkmanager/latest/APIReference/API_GetConnectAttachment.html

        :stability: experimental
        '''
        return typing.cast("Networkmanager", jsii.invoke(self, "toGetConnectAttachment", []))

    @jsii.member(jsii_name="toGetConnections")
    def to_get_connections(self) -> "Networkmanager":
        '''(experimental) Grants permission to describe connections.

        Access Level: List

        https://docs.aws.amazon.com/networkmanager/latest/APIReference/API_GetConnections.html

        :stability: experimental
        '''
        return typing.cast("Networkmanager", jsii.invoke(self, "toGetConnections", []))

    @jsii.member(jsii_name="toGetConnectPeer")
    def to_get_connect_peer(self) -> "Networkmanager":
        '''(experimental) Grants permission to retrieve a Connect Peer.

        Access Level: Read

        https://docs.aws.amazon.com/networkmanager/latest/APIReference/API_GetConnectPeer.html

        :stability: experimental
        '''
        return typing.cast("Networkmanager", jsii.invoke(self, "toGetConnectPeer", []))

    @jsii.member(jsii_name="toGetConnectPeerAssociations")
    def to_get_connect_peer_associations(self) -> "Networkmanager":
        '''(experimental) Grants permission to describe Connect Peer associations.

        Access Level: Read

        https://docs.aws.amazon.com/networkmanager/latest/APIReference/API_GetConnectPeerAssociations.html

        :stability: experimental
        '''
        return typing.cast("Networkmanager", jsii.invoke(self, "toGetConnectPeerAssociations", []))

    @jsii.member(jsii_name="toGetCoreNetwork")
    def to_get_core_network(self) -> "Networkmanager":
        '''(experimental) Grants permission to retrieve a core network.

        Access Level: Read

        https://docs.aws.amazon.com/networkmanager/latest/APIReference/API_GetCoreNetwork.html

        :stability: experimental
        '''
        return typing.cast("Networkmanager", jsii.invoke(self, "toGetCoreNetwork", []))

    @jsii.member(jsii_name="toGetCoreNetworkChangeEvents")
    def to_get_core_network_change_events(self) -> "Networkmanager":
        '''(experimental) Grants permission to retrieve a list of core network change events.

        Access Level: Read

        https://docs.aws.amazon.com/networkmanager/latest/APIReference/API_GetCoreNetworkChangeEvents.html

        :stability: experimental
        '''
        return typing.cast("Networkmanager", jsii.invoke(self, "toGetCoreNetworkChangeEvents", []))

    @jsii.member(jsii_name="toGetCoreNetworkChangeSet")
    def to_get_core_network_change_set(self) -> "Networkmanager":
        '''(experimental) Grants permission to retrieve a list of core network change sets.

        Access Level: Read

        https://docs.aws.amazon.com/networkmanager/latest/APIReference/API_GetCoreNetworkChangeSet.html

        :stability: experimental
        '''
        return typing.cast("Networkmanager", jsii.invoke(self, "toGetCoreNetworkChangeSet", []))

    @jsii.member(jsii_name="toGetCoreNetworkPolicy")
    def to_get_core_network_policy(self) -> "Networkmanager":
        '''(experimental) Grants permission to retrieve core network policy.

        Access Level: Read

        https://docs.aws.amazon.com/networkmanager/latest/APIReference/API_GetCoreNetworkPolicy.html

        :stability: experimental
        '''
        return typing.cast("Networkmanager", jsii.invoke(self, "toGetCoreNetworkPolicy", []))

    @jsii.member(jsii_name="toGetCustomerGatewayAssociations")
    def to_get_customer_gateway_associations(self) -> "Networkmanager":
        '''(experimental) Grants permission to describe customer gateway associations.

        Access Level: List

        https://docs.aws.amazon.com/networkmanager/latest/APIReference/API_GetCustomerGatewayAssociations.html

        :stability: experimental
        '''
        return typing.cast("Networkmanager", jsii.invoke(self, "toGetCustomerGatewayAssociations", []))

    @jsii.member(jsii_name="toGetDevices")
    def to_get_devices(self) -> "Networkmanager":
        '''(experimental) Grants permission to describe devices.

        Access Level: List

        https://docs.aws.amazon.com/networkmanager/latest/APIReference/API_GetDevices.html

        :stability: experimental
        '''
        return typing.cast("Networkmanager", jsii.invoke(self, "toGetDevices", []))

    @jsii.member(jsii_name="toGetLinkAssociations")
    def to_get_link_associations(self) -> "Networkmanager":
        '''(experimental) Grants permission to describe link associations.

        Access Level: List

        https://docs.aws.amazon.com/networkmanager/latest/APIReference/API_GetLinkAssociations.html

        :stability: experimental
        '''
        return typing.cast("Networkmanager", jsii.invoke(self, "toGetLinkAssociations", []))

    @jsii.member(jsii_name="toGetLinks")
    def to_get_links(self) -> "Networkmanager":
        '''(experimental) Grants permission to describe links.

        Access Level: List

        https://docs.aws.amazon.com/networkmanager/latest/APIReference/API_GetLinks.html

        :stability: experimental
        '''
        return typing.cast("Networkmanager", jsii.invoke(self, "toGetLinks", []))

    @jsii.member(jsii_name="toGetNetworkResourceCounts")
    def to_get_network_resource_counts(self) -> "Networkmanager":
        '''(experimental) Grants permission to return the number of resources for a global network grouped by type.

        Access Level: Read

        https://docs.aws.amazon.com/networkmanager/latest/APIReference/API_GetNetworkResourceCounts.html

        :stability: experimental
        '''
        return typing.cast("Networkmanager", jsii.invoke(self, "toGetNetworkResourceCounts", []))

    @jsii.member(jsii_name="toGetNetworkResourceRelationships")
    def to_get_network_resource_relationships(self) -> "Networkmanager":
        '''(experimental) Grants permission to retrieve related resources for a resource within the global network.

        Access Level: Read

        https://docs.aws.amazon.com/networkmanager/latest/APIReference/API_GetNetworkResourceRelationships.html

        :stability: experimental
        '''
        return typing.cast("Networkmanager", jsii.invoke(self, "toGetNetworkResourceRelationships", []))

    @jsii.member(jsii_name="toGetNetworkResources")
    def to_get_network_resources(self) -> "Networkmanager":
        '''(experimental) Grants permission to retrieve a global network resource.

        Access Level: Read

        https://docs.aws.amazon.com/networkmanager/latest/APIReference/API_GetNetworkResources.html

        :stability: experimental
        '''
        return typing.cast("Networkmanager", jsii.invoke(self, "toGetNetworkResources", []))

    @jsii.member(jsii_name="toGetNetworkRoutes")
    def to_get_network_routes(self) -> "Networkmanager":
        '''(experimental) Grants permission to retrieve routes for a route table within the global network.

        Access Level: Read

        https://docs.aws.amazon.com/networkmanager/latest/APIReference/API_GetNetworkRoutes.html

        :stability: experimental
        '''
        return typing.cast("Networkmanager", jsii.invoke(self, "toGetNetworkRoutes", []))

    @jsii.member(jsii_name="toGetNetworkTelemetry")
    def to_get_network_telemetry(self) -> "Networkmanager":
        '''(experimental) Grants permission to retrieve network telemetry objects for the global network.

        Access Level: Read

        https://docs.aws.amazon.com/networkmanager/latest/APIReference/API_GetNetworkTelemetry.html

        :stability: experimental
        '''
        return typing.cast("Networkmanager", jsii.invoke(self, "toGetNetworkTelemetry", []))

    @jsii.member(jsii_name="toGetResourcePolicy")
    def to_get_resource_policy(self) -> "Networkmanager":
        '''(experimental) Grants permission to retrieve a resource policy.

        Access Level: Read

        https://docs.aws.amazon.com/networkmanager/latest/APIReference/API_GetResourcePolicy.html

        :stability: experimental
        '''
        return typing.cast("Networkmanager", jsii.invoke(self, "toGetResourcePolicy", []))

    @jsii.member(jsii_name="toGetRouteAnalysis")
    def to_get_route_analysis(self) -> "Networkmanager":
        '''(experimental) Grants permission to retrieve a route analysis configuration and result.

        Access Level: Read

        https://docs.aws.amazon.com/networkmanager/latest/APIReference/API_GetRouteAnalysis.html

        :stability: experimental
        '''
        return typing.cast("Networkmanager", jsii.invoke(self, "toGetRouteAnalysis", []))

    @jsii.member(jsii_name="toGetSites")
    def to_get_sites(self) -> "Networkmanager":
        '''(experimental) Grants permission to describe global networks.

        Access Level: List

        https://docs.aws.amazon.com/networkmanager/latest/APIReference/API_GetSites.html

        :stability: experimental
        '''
        return typing.cast("Networkmanager", jsii.invoke(self, "toGetSites", []))

    @jsii.member(jsii_name="toGetSiteToSiteVpnAttachment")
    def to_get_site_to_site_vpn_attachment(self) -> "Networkmanager":
        '''(experimental) Grants permission to retrieve a site-to-site VPN attachment.

        Access Level: Read

        https://docs.aws.amazon.com/networkmanager/latest/APIReference/API_GetSiteToSiteVpnAttachment.html

        :stability: experimental
        '''
        return typing.cast("Networkmanager", jsii.invoke(self, "toGetSiteToSiteVpnAttachment", []))

    @jsii.member(jsii_name="toGetTransitGatewayConnectPeerAssociations")
    def to_get_transit_gateway_connect_peer_associations(self) -> "Networkmanager":
        '''(experimental) Grants permission to describe transit gateway connect peer associations.

        Access Level: List

        https://docs.aws.amazon.com/networkmanager/latest/APIReference/API_GetTransitGatewayConnectPeerAssociations.html

        :stability: experimental
        '''
        return typing.cast("Networkmanager", jsii.invoke(self, "toGetTransitGatewayConnectPeerAssociations", []))

    @jsii.member(jsii_name="toGetTransitGatewayPeering")
    def to_get_transit_gateway_peering(self) -> "Networkmanager":
        '''(experimental) Grants permission to retrieve a Transit Gateway peering.

        Access Level: Read

        https://docs.aws.amazon.com/networkmanager/latest/APIReference/API_GetTransitGatewayPeering.html

        :stability: experimental
        '''
        return typing.cast("Networkmanager", jsii.invoke(self, "toGetTransitGatewayPeering", []))

    @jsii.member(jsii_name="toGetTransitGatewayRegistrations")
    def to_get_transit_gateway_registrations(self) -> "Networkmanager":
        '''(experimental) Grants permission to describe transit gateway registrations.

        Access Level: List

        https://docs.aws.amazon.com/networkmanager/latest/APIReference/API_GetTransitGatewayRegistrations.html

        :stability: experimental
        '''
        return typing.cast("Networkmanager", jsii.invoke(self, "toGetTransitGatewayRegistrations", []))

    @jsii.member(jsii_name="toGetTransitGatewayRouteTableAttachment")
    def to_get_transit_gateway_route_table_attachment(self) -> "Networkmanager":
        '''(experimental) Grants permission to retrieve a TGW RTB attachment.

        Access Level: Read

        https://docs.aws.amazon.com/networkmanager/latest/APIReference/API_GetTransitGatewayRouteTableAttachment.html

        :stability: experimental
        '''
        return typing.cast("Networkmanager", jsii.invoke(self, "toGetTransitGatewayRouteTableAttachment", []))

    @jsii.member(jsii_name="toGetVpcAttachment")
    def to_get_vpc_attachment(self) -> "Networkmanager":
        '''(experimental) Grants permission to retrieve a VPC attachment.

        Access Level: Read

        https://docs.aws.amazon.com/networkmanager/latest/APIReference/API_GetVpcAttachment.html

        :stability: experimental
        '''
        return typing.cast("Networkmanager", jsii.invoke(self, "toGetVpcAttachment", []))

    @jsii.member(jsii_name="toListAttachments")
    def to_list_attachments(self) -> "Networkmanager":
        '''(experimental) Grants permission to describe attachments.

        Access Level: List

        https://docs.aws.amazon.com/networkmanager/latest/APIReference/API_ListAttachments.html

        :stability: experimental
        '''
        return typing.cast("Networkmanager", jsii.invoke(self, "toListAttachments", []))

    @jsii.member(jsii_name="toListConnectPeers")
    def to_list_connect_peers(self) -> "Networkmanager":
        '''(experimental) Grants permission to describe Connect Peers.

        Access Level: List

        https://docs.aws.amazon.com/networkmanager/latest/APIReference/API_ListConnectPeers.html

        :stability: experimental
        '''
        return typing.cast("Networkmanager", jsii.invoke(self, "toListConnectPeers", []))

    @jsii.member(jsii_name="toListCoreNetworkPolicyVersions")
    def to_list_core_network_policy_versions(self) -> "Networkmanager":
        '''(experimental) Grants permission to list core network policy versions.

        Access Level: List

        https://docs.aws.amazon.com/networkmanager/latest/APIReference/API_ListCoreNetworkPolicyVersions.html

        :stability: experimental
        '''
        return typing.cast("Networkmanager", jsii.invoke(self, "toListCoreNetworkPolicyVersions", []))

    @jsii.member(jsii_name="toListCoreNetworks")
    def to_list_core_networks(self) -> "Networkmanager":
        '''(experimental) Grants permission to list core networks.

        Access Level: List

        https://docs.aws.amazon.com/networkmanager/latest/APIReference/API_ListCoreNetworks.html

        :stability: experimental
        '''
        return typing.cast("Networkmanager", jsii.invoke(self, "toListCoreNetworks", []))

    @jsii.member(jsii_name="toListOrganizationServiceAccessStatus")
    def to_list_organization_service_access_status(self) -> "Networkmanager":
        '''(experimental) Grants permission to list organization service access status.

        Access Level: List

        https://docs.aws.amazon.com/networkmanager/latest/APIReference/API_ListOrganizationServiceAccessStatus.html

        :stability: experimental
        '''
        return typing.cast("Networkmanager", jsii.invoke(self, "toListOrganizationServiceAccessStatus", []))

    @jsii.member(jsii_name="toListPeerings")
    def to_list_peerings(self) -> "Networkmanager":
        '''(experimental) Grants permission to describe peerings.

        Access Level: List

        https://docs.aws.amazon.com/networkmanager/latest/APIReference/API_ListPeerings.html

        :stability: experimental
        '''
        return typing.cast("Networkmanager", jsii.invoke(self, "toListPeerings", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Networkmanager":
        '''(experimental) Grants permission to list tags for a Network Manager resource.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/networkmanager/latest/APIReference/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("Networkmanager", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toPutCoreNetworkPolicy")
    def to_put_core_network_policy(self) -> "Networkmanager":
        '''(experimental) Grants permission to create a core network policy.

        Access Level: Write

        https://docs.aws.amazon.com/networkmanager/latest/APIReference/API_PutCoreNetworkPolicy.html

        :stability: experimental
        '''
        return typing.cast("Networkmanager", jsii.invoke(self, "toPutCoreNetworkPolicy", []))

    @jsii.member(jsii_name="toPutResourcePolicy")
    def to_put_resource_policy(self) -> "Networkmanager":
        '''(experimental) Grants permission to create or update a resource policy.

        Access Level: Write

        https://docs.aws.amazon.com/networkmanager/latest/APIReference/API_PutResourcePolicy.html

        :stability: experimental
        '''
        return typing.cast("Networkmanager", jsii.invoke(self, "toPutResourcePolicy", []))

    @jsii.member(jsii_name="toRegisterTransitGateway")
    def to_register_transit_gateway(self) -> "Networkmanager":
        '''(experimental) Grants permission to register a transit gateway to a global network.

        Access Level: Write

        Possible conditions:

        - .ifTgwArn()

        https://docs.aws.amazon.com/networkmanager/latest/APIReference/API_RegisterTransitGateway.html

        :stability: experimental
        '''
        return typing.cast("Networkmanager", jsii.invoke(self, "toRegisterTransitGateway", []))

    @jsii.member(jsii_name="toRejectAttachment")
    def to_reject_attachment(self) -> "Networkmanager":
        '''(experimental) Grants permission to reject attachment request.

        Access Level: Write

        https://docs.aws.amazon.com/networkmanager/latest/APIReference/API_RejectAttachment.html

        :stability: experimental
        '''
        return typing.cast("Networkmanager", jsii.invoke(self, "toRejectAttachment", []))

    @jsii.member(jsii_name="toRestoreCoreNetworkPolicyVersion")
    def to_restore_core_network_policy_version(self) -> "Networkmanager":
        '''(experimental) Grants permission to restore the core network policy to a previous version.

        Access Level: Write

        https://docs.aws.amazon.com/networkmanager/latest/APIReference/API_RestoreCoreNetworkPolicyVersion.html

        :stability: experimental
        '''
        return typing.cast("Networkmanager", jsii.invoke(self, "toRestoreCoreNetworkPolicyVersion", []))

    @jsii.member(jsii_name="toStartOrganizationServiceAccessUpdate")
    def to_start_organization_service_access_update(self) -> "Networkmanager":
        '''(experimental) Grants permission to start organization service access update.

        Access Level: Write

        https://docs.aws.amazon.com/networkmanager/latest/APIReference/API_StartOrganizationServiceAccessUpdate.html

        :stability: experimental
        '''
        return typing.cast("Networkmanager", jsii.invoke(self, "toStartOrganizationServiceAccessUpdate", []))

    @jsii.member(jsii_name="toStartRouteAnalysis")
    def to_start_route_analysis(self) -> "Networkmanager":
        '''(experimental) Grants permission to start a route analysis and stores analysis configuration.

        Access Level: Write

        https://docs.aws.amazon.com/networkmanager/latest/APIReference/API_StartRouteAnalysis.html

        :stability: experimental
        '''
        return typing.cast("Networkmanager", jsii.invoke(self, "toStartRouteAnalysis", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Networkmanager":
        '''(experimental) Grants permission to tag a Network Manager resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()
        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/networkmanager/latest/APIReference/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("Networkmanager", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Networkmanager":
        '''(experimental) Grants permission to untag a Network Manager resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/networkmanager/latest/APIReference/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("Networkmanager", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateConnection")
    def to_update_connection(self) -> "Networkmanager":
        '''(experimental) Grants permission to update a connection.

        Access Level: Write

        https://docs.aws.amazon.com/networkmanager/latest/APIReference/API_UpdateConnection.html

        :stability: experimental
        '''
        return typing.cast("Networkmanager", jsii.invoke(self, "toUpdateConnection", []))

    @jsii.member(jsii_name="toUpdateCoreNetwork")
    def to_update_core_network(self) -> "Networkmanager":
        '''(experimental) Grants permission to update a core network.

        Access Level: Write

        https://docs.aws.amazon.com/networkmanager/latest/APIReference/API_UpdateCoreNetwork.html

        :stability: experimental
        '''
        return typing.cast("Networkmanager", jsii.invoke(self, "toUpdateCoreNetwork", []))

    @jsii.member(jsii_name="toUpdateDevice")
    def to_update_device(self) -> "Networkmanager":
        '''(experimental) Grants permission to update a device.

        Access Level: Write

        https://docs.aws.amazon.com/networkmanager/latest/APIReference/API_UpdateDevice.html

        :stability: experimental
        '''
        return typing.cast("Networkmanager", jsii.invoke(self, "toUpdateDevice", []))

    @jsii.member(jsii_name="toUpdateGlobalNetwork")
    def to_update_global_network(self) -> "Networkmanager":
        '''(experimental) Grants permission to update a global network.

        Access Level: Write

        https://docs.aws.amazon.com/networkmanager/latest/APIReference/API_UpdateGlobalNetwork.html

        :stability: experimental
        '''
        return typing.cast("Networkmanager", jsii.invoke(self, "toUpdateGlobalNetwork", []))

    @jsii.member(jsii_name="toUpdateLink")
    def to_update_link(self) -> "Networkmanager":
        '''(experimental) Grants permission to update a link.

        Access Level: Write

        https://docs.aws.amazon.com/networkmanager/latest/APIReference/API_UpdateLink.html

        :stability: experimental
        '''
        return typing.cast("Networkmanager", jsii.invoke(self, "toUpdateLink", []))

    @jsii.member(jsii_name="toUpdateNetworkResourceMetadata")
    def to_update_network_resource_metadata(self) -> "Networkmanager":
        '''(experimental) Grants permission to add or update metadata key/value pairs on network resource.

        Access Level: Write

        https://docs.aws.amazon.com/networkmanager/latest/APIReference/API_UpdateNetworkResourceMetadata.html

        :stability: experimental
        '''
        return typing.cast("Networkmanager", jsii.invoke(self, "toUpdateNetworkResourceMetadata", []))

    @jsii.member(jsii_name="toUpdateSite")
    def to_update_site(self) -> "Networkmanager":
        '''(experimental) Grants permission to update a site.

        Access Level: Write

        https://docs.aws.amazon.com/networkmanager/latest/APIReference/API_UpdateSite.html

        :stability: experimental
        '''
        return typing.cast("Networkmanager", jsii.invoke(self, "toUpdateSite", []))

    @jsii.member(jsii_name="toUpdateVpcAttachment")
    def to_update_vpc_attachment(self) -> "Networkmanager":
        '''(experimental) Grants permission to update a VPC attachment.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifSubnetArns()

        https://docs.aws.amazon.com/networkmanager/latest/APIReference/API_UpdateVpcAttachment.html

        :stability: experimental
        '''
        return typing.cast("Networkmanager", jsii.invoke(self, "toUpdateVpcAttachment", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7c48a09c1572cd5e715dd51d609e7c05a22bc251f375d75e5afd2567f93a3426)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f5a14e0864bcd0a942b06c9fb17e8d240dc446446fef9776d15ba185bce6ff6c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Nimble(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Nimble",
):
    '''(experimental) Statement provider for service `nimble <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonnimblestudio.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `nimble <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonnimblestudio.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="ifCreatedBy")
    def if_created_by(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Nimble":
        '''(experimental) Filters access by the createdBy request parameter or the ID of the creator of the resource.

        https://docs.aws.amazon.com/nimble-studio/latest/userguide/security-iam-service-with-iam.html

        Applies to actions:

        - .toListStreamingSessions()

        Applies to resource types:

        - streaming-session

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5ec32263543cd03d40d8de7ff12f4e02aff35dc470bb4e4ebee8c0139c5c42df)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Nimble", jsii.invoke(self, "ifCreatedBy", [value, operator]))

    @jsii.member(jsii_name="ifOwnedBy")
    def if_owned_by(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Nimble":
        '''(experimental) Filters access by the ownedBy request parameter or the ID of the owner of the resource.

        https://docs.aws.amazon.com/nimble-studio/latest/userguide/security-iam-service-with-iam.html

        Applies to actions:

        - .toListStreamingSessions()

        Applies to resource types:

        - streaming-session
        - streaming-session-backup

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fbbc769e09ef4ba45f3cb6e65fc7d0d40e942d6d4fac13b071951246d0525ef3)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Nimble", jsii.invoke(self, "ifOwnedBy", [value, operator]))

    @jsii.member(jsii_name="ifPrincipalId")
    def if_principal_id(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Nimble":
        '''(experimental) Filters access by the principalId request parameter.

        https://docs.aws.amazon.com/nimble-studio/latest/userguide/security-iam-service-with-iam.html

        Applies to actions:

        - .toListLaunchProfiles()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1543989927cb50deb5d069abad08aec471408f6a03986ad15e7781d5cc87180a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Nimble", jsii.invoke(self, "ifPrincipalId", [value, operator]))

    @jsii.member(jsii_name="ifRequesterPrincipalId")
    def if_requester_principal_id(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Nimble":
        '''(experimental) Filters access by the ID of the logged in user.

        https://docs.aws.amazon.com/nimble-studio/latest/userguide/security-iam-service-with-iam.html

        Applies to actions:

        - .toCreateStreamingSessionStream()
        - .toDeleteStreamingSession()
        - .toGetStreamingSession()
        - .toGetStreamingSessionBackup()
        - .toGetStreamingSessionStream()
        - .toListLaunchProfiles()
        - .toListStreamingSessionBackups()
        - .toListStreamingSessions()
        - .toStartStreamingSession()
        - .toStopStreamingSession()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b8fb97a1e40d34c288df1bc75c7e210b37750fadbe3fe3669afa1bf5b1c0278a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Nimble", jsii.invoke(self, "ifRequesterPrincipalId", [value, operator]))

    @jsii.member(jsii_name="ifStudioId")
    def if_studio_id(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Nimble":
        '''(experimental) Filters access by a specific studio.

        https://docs.aws.amazon.com/nimble-studio/latest/userguide/security-iam-service-with-iam.html

        Applies to resource types:

        - studio
        - streaming-image
        - studio-component
        - launch-profile
        - eula-acceptance

        :param value: The value(s) to check.
        :param operator: Works with `arn operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_ARN>`_. **Default:** ``ArnLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9ff2353bb5858730584cfb3f590079731c8a32ad2303272c5052abe9d145abf6)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Nimble", jsii.invoke(self, "ifStudioId", [value, operator]))

    @jsii.member(jsii_name="onEula")
    def on_eula(
        self,
        eula_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Nimble":
        '''(experimental) Adds a resource of type eula to the statement.

        https://docs.aws.amazon.com/nimble-studio/latest/APIReference/API_Eula.html

        :param eula_id: - Identifier for the eulaId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__41080f76c6bcc6ed61337f6fe51253b4e5777240c9d1b05dde6f627dc1eebe0a)
            check_type(argname="argument eula_id", value=eula_id, expected_type=type_hints["eula_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Nimble", jsii.invoke(self, "onEula", [eula_id, account, region, partition]))

    @jsii.member(jsii_name="onEulaAcceptance")
    def on_eula_acceptance(
        self,
        eula_acceptance_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Nimble":
        '''(experimental) Adds a resource of type eula-acceptance to the statement.

        https://docs.aws.amazon.com/nimble-studio/latest/APIReference/API_EulaAcceptance.html

        :param eula_acceptance_id: - Identifier for the eulaAcceptanceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifStudioId()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6154ec0c2a46eeb21be81cd47ce9e9449eefc1bfef339bf84f5453f32bc17e91)
            check_type(argname="argument eula_acceptance_id", value=eula_acceptance_id, expected_type=type_hints["eula_acceptance_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Nimble", jsii.invoke(self, "onEulaAcceptance", [eula_acceptance_id, account, region, partition]))

    @jsii.member(jsii_name="onLaunchProfile")
    def on_launch_profile(
        self,
        launch_profile_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Nimble":
        '''(experimental) Adds a resource of type launch-profile to the statement.

        https://docs.aws.amazon.com/nimble-studio/latest/APIReference/API_LaunchProfile.html

        :param launch_profile_id: - Identifier for the launchProfileId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsRequestTag() - .ifAwsResourceTag() - .ifAwsTagKeys() - .ifStudioId()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5b8e8f22fa24ab9030ff008d0182a1fc97b7539e4787168453b31112bfb82e19)
            check_type(argname="argument launch_profile_id", value=launch_profile_id, expected_type=type_hints["launch_profile_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Nimble", jsii.invoke(self, "onLaunchProfile", [launch_profile_id, account, region, partition]))

    @jsii.member(jsii_name="onStreamingImage")
    def on_streaming_image(
        self,
        streaming_image_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Nimble":
        '''(experimental) Adds a resource of type streaming-image to the statement.

        https://docs.aws.amazon.com/nimble-studio/latest/APIReference/API_StreamingImage.html

        :param streaming_image_id: - Identifier for the streamingImageId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsRequestTag() - .ifAwsResourceTag() - .ifAwsTagKeys() - .ifStudioId()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8cc70e0b65ff97effbea4d691fad14ceda535bb476b288c431fd156c95c02cf7)
            check_type(argname="argument streaming_image_id", value=streaming_image_id, expected_type=type_hints["streaming_image_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Nimble", jsii.invoke(self, "onStreamingImage", [streaming_image_id, account, region, partition]))

    @jsii.member(jsii_name="onStreamingSession")
    def on_streaming_session(
        self,
        streaming_session_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Nimble":
        '''(experimental) Adds a resource of type streaming-session to the statement.

        https://docs.aws.amazon.com/nimble-studio/latest/APIReference/API_StreamingSession.html

        :param streaming_session_id: - Identifier for the streamingSessionId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsRequestTag() - .ifAwsResourceTag() - .ifAwsTagKeys() - .ifCreatedBy() - .ifOwnedBy()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a1b63e6fcbbb2a4f44da8b19dd9d745f12cee254ee1137182e036121227562f9)
            check_type(argname="argument streaming_session_id", value=streaming_session_id, expected_type=type_hints["streaming_session_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Nimble", jsii.invoke(self, "onStreamingSession", [streaming_session_id, account, region, partition]))

    @jsii.member(jsii_name="onStreamingSessionBackup")
    def on_streaming_session_backup(
        self,
        streaming_session_backup_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Nimble":
        '''(experimental) Adds a resource of type streaming-session-backup to the statement.

        https://docs.aws.amazon.com/nimble-studio/latest/APIReference/API_StreamingSessionBackup.html

        :param streaming_session_backup_id: - Identifier for the streamingSessionBackupId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsRequestTag() - .ifAwsResourceTag() - .ifAwsTagKeys() - .ifOwnedBy()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ac49ec6708975e2b69e55dba9d0f43c5b19bc2be2f12a9eb4ecafc32497231b9)
            check_type(argname="argument streaming_session_backup_id", value=streaming_session_backup_id, expected_type=type_hints["streaming_session_backup_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Nimble", jsii.invoke(self, "onStreamingSessionBackup", [streaming_session_backup_id, account, region, partition]))

    @jsii.member(jsii_name="onStudio")
    def on_studio(
        self,
        studio_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Nimble":
        '''(experimental) Adds a resource of type studio to the statement.

        https://docs.aws.amazon.com/nimble-studio/latest/APIReference/API_Studio.html

        :param studio_id: - Identifier for the studioId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsRequestTag() - .ifAwsResourceTag() - .ifAwsTagKeys() - .ifStudioId()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__03579e7d62838832324a61fa9cf5d4476b122e51fa033f88e8a8d550b4820ae3)
            check_type(argname="argument studio_id", value=studio_id, expected_type=type_hints["studio_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Nimble", jsii.invoke(self, "onStudio", [studio_id, account, region, partition]))

    @jsii.member(jsii_name="onStudioComponent")
    def on_studio_component(
        self,
        studio_component_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Nimble":
        '''(experimental) Adds a resource of type studio-component to the statement.

        https://docs.aws.amazon.com/nimble-studio/latest/APIReference/API_StudioComponent.html

        :param studio_component_id: - Identifier for the studioComponentId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsRequestTag() - .ifAwsResourceTag() - .ifAwsTagKeys() - .ifStudioId()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1f82fd3a36e627efb1c2c5752a53dff7c398b1bb9d6115dc6db0768ccd4d5fef)
            check_type(argname="argument studio_component_id", value=studio_component_id, expected_type=type_hints["studio_component_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Nimble", jsii.invoke(self, "onStudioComponent", [studio_component_id, account, region, partition]))

    @jsii.member(jsii_name="toAcceptEulas")
    def to_accept_eulas(self) -> "Nimble":
        '''(experimental) Grants permission to accept EULAs.

        Access Level: Write

        https://docs.aws.amazon.com/nimble-studio/latest/APIReference/API_AcceptEulas.html

        :stability: experimental
        '''
        return typing.cast("Nimble", jsii.invoke(self, "toAcceptEulas", []))

    @jsii.member(jsii_name="toCreateLaunchProfile")
    def to_create_launch_profile(self) -> "Nimble":
        '''(experimental) Grants permission to create a launch profile.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        Dependent actions:

        - ec2:CreateNetworkInterface
        - ec2:DescribeNatGateways
        - ec2:DescribeNetworkAcls
        - ec2:DescribeRouteTables
        - ec2:DescribeSubnets
        - ec2:DescribeVpcEndpoints
        - ec2:RunInstances

        https://docs.aws.amazon.com/nimble-studio/latest/APIReference/API_CreateLaunchProfile.html

        :stability: experimental
        '''
        return typing.cast("Nimble", jsii.invoke(self, "toCreateLaunchProfile", []))

    @jsii.member(jsii_name="toCreateStreamingImage")
    def to_create_streaming_image(self) -> "Nimble":
        '''(experimental) Grants permission to create a streaming image.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        Dependent actions:

        - ec2:DescribeImages
        - ec2:DescribeSnapshots
        - ec2:ModifyInstanceAttribute
        - ec2:ModifySnapshotAttribute
        - ec2:RegisterImage

        https://docs.aws.amazon.com/nimble-studio/latest/APIReference/API_CreateStreamingImage.html

        :stability: experimental
        '''
        return typing.cast("Nimble", jsii.invoke(self, "toCreateStreamingImage", []))

    @jsii.member(jsii_name="toCreateStreamingSession")
    def to_create_streaming_session(self) -> "Nimble":
        '''(experimental) Grants permission to create a streaming session.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        Dependent actions:

        - ec2:CreateNetworkInterface
        - ec2:CreateNetworkInterfacePermission
        - nimble:GetLaunchProfile
        - nimble:GetLaunchProfileInitialization
        - nimble:ListEulaAcceptances

        https://docs.aws.amazon.com/nimble-studio/latest/APIReference/API_CreateStreamingSession.html

        :stability: experimental
        '''
        return typing.cast("Nimble", jsii.invoke(self, "toCreateStreamingSession", []))

    @jsii.member(jsii_name="toCreateStreamingSessionStream")
    def to_create_streaming_session_stream(self) -> "Nimble":
        '''(experimental) Grants permission to create a StreamingSessionStream.

        Access Level: Write

        Possible conditions:

        - .ifRequesterPrincipalId()

        https://docs.aws.amazon.com/nimble-studio/latest/APIReference/API_CreateStreamingSessionStream.html

        :stability: experimental
        '''
        return typing.cast("Nimble", jsii.invoke(self, "toCreateStreamingSessionStream", []))

    @jsii.member(jsii_name="toCreateStudio")
    def to_create_studio(self) -> "Nimble":
        '''(experimental) Grants permission to create a studio.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        Dependent actions:

        - iam:PassRole
        - sso:CreateManagedApplicationInstance

        https://docs.aws.amazon.com/nimble-studio/latest/APIReference/API_CreateStudio.html

        :stability: experimental
        '''
        return typing.cast("Nimble", jsii.invoke(self, "toCreateStudio", []))

    @jsii.member(jsii_name="toCreateStudioComponent")
    def to_create_studio_component(self) -> "Nimble":
        '''(experimental) Grants permission to create a studio component.

        A studio component designates a network resource to which a launch profile will provide access

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        Dependent actions:

        - ds:AuthorizeApplication
        - ds:DescribeDirectories
        - ec2:DescribeSecurityGroups
        - fsx:DescribeFileSystems
        - iam:PassRole

        https://docs.aws.amazon.com/nimble-studio/latest/APIReference/API_CreateStudioComponent.html

        :stability: experimental
        '''
        return typing.cast("Nimble", jsii.invoke(self, "toCreateStudioComponent", []))

    @jsii.member(jsii_name="toDeleteLaunchProfile")
    def to_delete_launch_profile(self) -> "Nimble":
        '''(experimental) Grants permission to delete a launch profile.

        Access Level: Write

        https://docs.aws.amazon.com/nimble-studio/latest/APIReference/API_DeleteLaunchProfile.html

        :stability: experimental
        '''
        return typing.cast("Nimble", jsii.invoke(self, "toDeleteLaunchProfile", []))

    @jsii.member(jsii_name="toDeleteLaunchProfileMember")
    def to_delete_launch_profile_member(self) -> "Nimble":
        '''(experimental) Grants permission to delete a launch profile member.

        Access Level: Write

        https://docs.aws.amazon.com/nimble-studio/latest/APIReference/API_DeleteLaunchProfileMember.html

        :stability: experimental
        '''
        return typing.cast("Nimble", jsii.invoke(self, "toDeleteLaunchProfileMember", []))

    @jsii.member(jsii_name="toDeleteStreamingImage")
    def to_delete_streaming_image(self) -> "Nimble":
        '''(experimental) Grants permission to delete a streaming image.

        Access Level: Write

        Dependent actions:

        - ec2:DeleteSnapshot
        - ec2:DeregisterImage
        - ec2:ModifyInstanceAttribute
        - ec2:ModifySnapshotAttribute

        https://docs.aws.amazon.com/nimble-studio/latest/APIReference/API_DeleteStreamingImage.html

        :stability: experimental
        '''
        return typing.cast("Nimble", jsii.invoke(self, "toDeleteStreamingImage", []))

    @jsii.member(jsii_name="toDeleteStreamingSession")
    def to_delete_streaming_session(self) -> "Nimble":
        '''(experimental) Grants permission to delete a streaming session.

        Access Level: Write

        Possible conditions:

        - .ifRequesterPrincipalId()

        Dependent actions:

        - ec2:DeleteNetworkInterface

        https://docs.aws.amazon.com/nimble-studio/latest/APIReference/API_DeleteStreamingSession.html

        :stability: experimental
        '''
        return typing.cast("Nimble", jsii.invoke(self, "toDeleteStreamingSession", []))

    @jsii.member(jsii_name="toDeleteStudio")
    def to_delete_studio(self) -> "Nimble":
        '''(experimental) Grants permission to delete a studio.

        Access Level: Write

        Dependent actions:

        - sso:DeleteManagedApplicationInstance

        https://docs.aws.amazon.com/nimble-studio/latest/APIReference/API_DeleteStudio.html

        :stability: experimental
        '''
        return typing.cast("Nimble", jsii.invoke(self, "toDeleteStudio", []))

    @jsii.member(jsii_name="toDeleteStudioComponent")
    def to_delete_studio_component(self) -> "Nimble":
        '''(experimental) Grants permission to delete a studio component.

        Access Level: Write

        Dependent actions:

        - ds:UnauthorizeApplication

        https://docs.aws.amazon.com/nimble-studio/latest/APIReference/API_DeleteStudioComponent.html

        :stability: experimental
        '''
        return typing.cast("Nimble", jsii.invoke(self, "toDeleteStudioComponent", []))

    @jsii.member(jsii_name="toDeleteStudioMember")
    def to_delete_studio_member(self) -> "Nimble":
        '''(experimental) Grants permission to delete a studio member.

        Access Level: Write

        https://docs.aws.amazon.com/nimble-studio/latest/APIReference/API_DeleteStudioMember.html

        :stability: experimental
        '''
        return typing.cast("Nimble", jsii.invoke(self, "toDeleteStudioMember", []))

    @jsii.member(jsii_name="toGetEula")
    def to_get_eula(self) -> "Nimble":
        '''(experimental) Grants permission to get a EULA.

        Access Level: Read

        https://docs.aws.amazon.com/nimble-studio/latest/APIReference/API_GetEula.html

        :stability: experimental
        '''
        return typing.cast("Nimble", jsii.invoke(self, "toGetEula", []))

    @jsii.member(jsii_name="toGetFeatureMap")
    def to_get_feature_map(self) -> "Nimble":
        '''(experimental) Grants permission to allow Nimble Studio portal to show the appropriate features for this account.

        Access Level: Read

        https://docs.aws.amazon.com/nimble-studio/latest/userguide/security-iam-service-with-iam.html

        :stability: experimental
        '''
        return typing.cast("Nimble", jsii.invoke(self, "toGetFeatureMap", []))

    @jsii.member(jsii_name="toGetLaunchProfile")
    def to_get_launch_profile(self) -> "Nimble":
        '''(experimental) Grants permission to get a launch profile.

        Access Level: Read

        https://docs.aws.amazon.com/nimble-studio/latest/APIReference/API_GetLaunchProfile.html

        :stability: experimental
        '''
        return typing.cast("Nimble", jsii.invoke(self, "toGetLaunchProfile", []))

    @jsii.member(jsii_name="toGetLaunchProfileDetails")
    def to_get_launch_profile_details(self) -> "Nimble":
        '''(experimental) Grants permission to get a launch profile's details, which includes the summary of studio components and streaming images used by the launch profile.

        Access Level: Read

        https://docs.aws.amazon.com/nimble-studio/latest/APIReference/API_GetLaunchProfileDetails.html

        :stability: experimental
        '''
        return typing.cast("Nimble", jsii.invoke(self, "toGetLaunchProfileDetails", []))

    @jsii.member(jsii_name="toGetLaunchProfileInitialization")
    def to_get_launch_profile_initialization(self) -> "Nimble":
        '''(experimental) Grants permission to get a launch profile initialization.

        A launch profile initialization is a dereferenced version of a launch profile, including attached studio component connection information

        Access Level: Read

        Dependent actions:

        - ds:DescribeDirectories
        - ec2:DescribeSecurityGroups
        - fsx:DescribeFileSystems

        https://docs.aws.amazon.com/nimble-studio/latest/APIReference/API_GetLaunchProfileInitialization.html

        :stability: experimental
        '''
        return typing.cast("Nimble", jsii.invoke(self, "toGetLaunchProfileInitialization", []))

    @jsii.member(jsii_name="toGetLaunchProfileMember")
    def to_get_launch_profile_member(self) -> "Nimble":
        '''(experimental) Grants permission to get a launch profile member.

        Access Level: Read

        https://docs.aws.amazon.com/nimble-studio/latest/APIReference/API_GetLaunchProfileMember.html

        :stability: experimental
        '''
        return typing.cast("Nimble", jsii.invoke(self, "toGetLaunchProfileMember", []))

    @jsii.member(jsii_name="toGetStreamingImage")
    def to_get_streaming_image(self) -> "Nimble":
        '''(experimental) Grants permission to get a streaming image.

        Access Level: Read

        https://docs.aws.amazon.com/nimble-studio/latest/APIReference/API_GetStreamingImage.html

        :stability: experimental
        '''
        return typing.cast("Nimble", jsii.invoke(self, "toGetStreamingImage", []))

    @jsii.member(jsii_name="toGetStreamingSession")
    def to_get_streaming_session(self) -> "Nimble":
        '''(experimental) Grants permission to get a streaming session.

        Access Level: Read

        Possible conditions:

        - .ifRequesterPrincipalId()

        https://docs.aws.amazon.com/nimble-studio/latest/APIReference/API_GetStreamingSession.html

        :stability: experimental
        '''
        return typing.cast("Nimble", jsii.invoke(self, "toGetStreamingSession", []))

    @jsii.member(jsii_name="toGetStreamingSessionBackup")
    def to_get_streaming_session_backup(self) -> "Nimble":
        '''(experimental) Grants permission to get a streaming session backup.

        Access Level: Read

        Possible conditions:

        - .ifRequesterPrincipalId()

        https://docs.aws.amazon.com/nimble-studio/latest/APIReference/API_GetStreamingSessionBackup.html

        :stability: experimental
        '''
        return typing.cast("Nimble", jsii.invoke(self, "toGetStreamingSessionBackup", []))

    @jsii.member(jsii_name="toGetStreamingSessionStream")
    def to_get_streaming_session_stream(self) -> "Nimble":
        '''(experimental) Grants permission to get a streaming session stream.

        Access Level: Read

        Possible conditions:

        - .ifRequesterPrincipalId()

        https://docs.aws.amazon.com/nimble-studio/latest/APIReference/API_GetStreamingSessionStream.html

        :stability: experimental
        '''
        return typing.cast("Nimble", jsii.invoke(self, "toGetStreamingSessionStream", []))

    @jsii.member(jsii_name="toGetStudio")
    def to_get_studio(self) -> "Nimble":
        '''(experimental) Grants permission to get a studio.

        Access Level: Read

        https://docs.aws.amazon.com/nimble-studio/latest/APIReference/API_GetStudio.html

        :stability: experimental
        '''
        return typing.cast("Nimble", jsii.invoke(self, "toGetStudio", []))

    @jsii.member(jsii_name="toGetStudioComponent")
    def to_get_studio_component(self) -> "Nimble":
        '''(experimental) Grants permission to get a studio component.

        Access Level: Read

        https://docs.aws.amazon.com/nimble-studio/latest/APIReference/API_GetStudioComponent.html

        :stability: experimental
        '''
        return typing.cast("Nimble", jsii.invoke(self, "toGetStudioComponent", []))

    @jsii.member(jsii_name="toGetStudioMember")
    def to_get_studio_member(self) -> "Nimble":
        '''(experimental) Grants permission to get a studio member.

        Access Level: Read

        https://docs.aws.amazon.com/nimble-studio/latest/APIReference/API_GetStudioMember.html

        :stability: experimental
        '''
        return typing.cast("Nimble", jsii.invoke(self, "toGetStudioMember", []))

    @jsii.member(jsii_name="toListEulaAcceptances")
    def to_list_eula_acceptances(self) -> "Nimble":
        '''(experimental) Grants permission to list EULA acceptances.

        Access Level: Read

        https://docs.aws.amazon.com/nimble-studio/latest/APIReference/API_ListEulaAcceptances.html

        :stability: experimental
        '''
        return typing.cast("Nimble", jsii.invoke(self, "toListEulaAcceptances", []))

    @jsii.member(jsii_name="toListEulas")
    def to_list_eulas(self) -> "Nimble":
        '''(experimental) Grants permission to list EULAs.

        Access Level: Read

        https://docs.aws.amazon.com/nimble-studio/latest/APIReference/API_ListEulas.html

        :stability: experimental
        '''
        return typing.cast("Nimble", jsii.invoke(self, "toListEulas", []))

    @jsii.member(jsii_name="toListLaunchProfileMembers")
    def to_list_launch_profile_members(self) -> "Nimble":
        '''(experimental) Grants permission to list launch profile members.

        Access Level: Read

        https://docs.aws.amazon.com/nimble-studio/latest/APIReference/API_ListLaunchProfileMembers.html

        :stability: experimental
        '''
        return typing.cast("Nimble", jsii.invoke(self, "toListLaunchProfileMembers", []))

    @jsii.member(jsii_name="toListLaunchProfiles")
    def to_list_launch_profiles(self) -> "Nimble":
        '''(experimental) Grants permission to list launch profiles.

        Access Level: Read

        Possible conditions:

        - .ifPrincipalId()
        - .ifRequesterPrincipalId()

        https://docs.aws.amazon.com/nimble-studio/latest/APIReference/API_ListLaunchProfiles.html

        :stability: experimental
        '''
        return typing.cast("Nimble", jsii.invoke(self, "toListLaunchProfiles", []))

    @jsii.member(jsii_name="toListStreamingImages")
    def to_list_streaming_images(self) -> "Nimble":
        '''(experimental) Grants permission to list streaming images.

        Access Level: Read

        https://docs.aws.amazon.com/nimble-studio/latest/APIReference/API_ListStreamingImages.html

        :stability: experimental
        '''
        return typing.cast("Nimble", jsii.invoke(self, "toListStreamingImages", []))

    @jsii.member(jsii_name="toListStreamingSessionBackups")
    def to_list_streaming_session_backups(self) -> "Nimble":
        '''(experimental) Grants permission to list streaming session backups.

        Access Level: Read

        Possible conditions:

        - .ifRequesterPrincipalId()

        https://docs.aws.amazon.com/nimble-studio/latest/APIReference/API_ListStreamingSessionBackups.html

        :stability: experimental
        '''
        return typing.cast("Nimble", jsii.invoke(self, "toListStreamingSessionBackups", []))

    @jsii.member(jsii_name="toListStreamingSessions")
    def to_list_streaming_sessions(self) -> "Nimble":
        '''(experimental) Grants permission to list streaming sessions.

        Access Level: Read

        Possible conditions:

        - .ifCreatedBy()
        - .ifOwnedBy()
        - .ifRequesterPrincipalId()

        https://docs.aws.amazon.com/nimble-studio/latest/APIReference/API_ListStreamingSessions.html

        :stability: experimental
        '''
        return typing.cast("Nimble", jsii.invoke(self, "toListStreamingSessions", []))

    @jsii.member(jsii_name="toListStudioComponents")
    def to_list_studio_components(self) -> "Nimble":
        '''(experimental) Grants permission to list studio components.

        Access Level: Read

        https://docs.aws.amazon.com/nimble-studio/latest/APIReference/API_ListStudioComponents.html

        :stability: experimental
        '''
        return typing.cast("Nimble", jsii.invoke(self, "toListStudioComponents", []))

    @jsii.member(jsii_name="toListStudioMembers")
    def to_list_studio_members(self) -> "Nimble":
        '''(experimental) Grants permission to list studio members.

        Access Level: Read

        https://docs.aws.amazon.com/nimble-studio/latest/APIReference/API_ListStudioMembers.html

        :stability: experimental
        '''
        return typing.cast("Nimble", jsii.invoke(self, "toListStudioMembers", []))

    @jsii.member(jsii_name="toListStudios")
    def to_list_studios(self) -> "Nimble":
        '''(experimental) Grants permission to list all studios.

        Access Level: Read

        https://docs.aws.amazon.com/nimble-studio/latest/APIReference/API_ListStudios.html

        :stability: experimental
        '''
        return typing.cast("Nimble", jsii.invoke(self, "toListStudios", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Nimble":
        '''(experimental) Grants permission to list all tags on a Nimble Studio resource.

        Access Level: Read

        https://docs.aws.amazon.com/nimble-studio/latest/APIReference/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("Nimble", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toPutLaunchProfileMembers")
    def to_put_launch_profile_members(self) -> "Nimble":
        '''(experimental) Grants permission to add/update launch profile members.

        Access Level: Write

        Dependent actions:

        - sso-directory:DescribeUsers

        https://docs.aws.amazon.com/nimble-studio/latest/APIReference/API_PutLaunchProfileMembers.html

        :stability: experimental
        '''
        return typing.cast("Nimble", jsii.invoke(self, "toPutLaunchProfileMembers", []))

    @jsii.member(jsii_name="toPutStudioLogEvents")
    def to_put_studio_log_events(self) -> "Nimble":
        '''(experimental) Grants permission to report metrics and logs for the Nimble Studio portal to monitor application health.

        Access Level: Write

        https://docs.aws.amazon.com/nimble-studio/latest/userguide/security-iam-service-with-iam.html

        :stability: experimental
        '''
        return typing.cast("Nimble", jsii.invoke(self, "toPutStudioLogEvents", []))

    @jsii.member(jsii_name="toPutStudioMembers")
    def to_put_studio_members(self) -> "Nimble":
        '''(experimental) Grants permission to add/update studio members.

        Access Level: Write

        Dependent actions:

        - sso-directory:DescribeUsers

        https://docs.aws.amazon.com/nimble-studio/latest/APIReference/API_PutStudioMembers.html

        :stability: experimental
        '''
        return typing.cast("Nimble", jsii.invoke(self, "toPutStudioMembers", []))

    @jsii.member(jsii_name="toStartStreamingSession")
    def to_start_streaming_session(self) -> "Nimble":
        '''(experimental) Grants permission to start a streaming session.

        Access Level: Write

        Possible conditions:

        - .ifRequesterPrincipalId()

        Dependent actions:

        - nimble:GetLaunchProfile
        - nimble:GetLaunchProfileMember

        https://docs.aws.amazon.com/nimble-studio/latest/APIReference/API_StartStreamingSession.html

        :stability: experimental
        '''
        return typing.cast("Nimble", jsii.invoke(self, "toStartStreamingSession", []))

    @jsii.member(jsii_name="toStartStudioSSOConfigurationRepair")
    def to_start_studio_sso_configuration_repair(self) -> "Nimble":
        '''(experimental) Grants permission to repair the studio's AWS IAM Identity Center configuration.

        Access Level: Write

        Dependent actions:

        - sso:CreateManagedApplicationInstance
        - sso:GetManagedApplicationInstance

        https://docs.aws.amazon.com/nimble-studio/latest/APIReference/API_StartStudioSSOConfigurationRepair.html

        :stability: experimental
        '''
        return typing.cast("Nimble", jsii.invoke(self, "toStartStudioSSOConfigurationRepair", []))

    @jsii.member(jsii_name="toStopStreamingSession")
    def to_stop_streaming_session(self) -> "Nimble":
        '''(experimental) Grants permission to stop a streaming session.

        Access Level: Write

        Possible conditions:

        - .ifRequesterPrincipalId()

        Dependent actions:

        - nimble:GetLaunchProfile

        https://docs.aws.amazon.com/nimble-studio/latest/APIReference/API_StopStreamingSession.html

        :stability: experimental
        '''
        return typing.cast("Nimble", jsii.invoke(self, "toStopStreamingSession", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Nimble":
        '''(experimental) Grants permission to add or overwrite one or more tags for the specified Nimble Studio resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/nimble-studio/latest/APIReference/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("Nimble", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Nimble":
        '''(experimental) Grants permission to disassociate one or more tags from the specified Nimble Studio resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/nimble-studio/latest/APIReference/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("Nimble", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateLaunchProfile")
    def to_update_launch_profile(self) -> "Nimble":
        '''(experimental) Grants permission to update a launch profile.

        Access Level: Write

        Dependent actions:

        - ec2:DescribeNatGateways
        - ec2:DescribeNetworkAcls
        - ec2:DescribeRouteTables
        - ec2:DescribeSubnets
        - ec2:DescribeVpcEndpoints

        https://docs.aws.amazon.com/nimble-studio/latest/APIReference/API_UpdateLaunchProfile.html

        :stability: experimental
        '''
        return typing.cast("Nimble", jsii.invoke(self, "toUpdateLaunchProfile", []))

    @jsii.member(jsii_name="toUpdateLaunchProfileMember")
    def to_update_launch_profile_member(self) -> "Nimble":
        '''(experimental) Grants permission to update a launch profile member.

        Access Level: Write

        https://docs.aws.amazon.com/nimble-studio/latest/APIReference/API_UpdateLaunchProfileMember.html

        :stability: experimental
        '''
        return typing.cast("Nimble", jsii.invoke(self, "toUpdateLaunchProfileMember", []))

    @jsii.member(jsii_name="toUpdateStreamingImage")
    def to_update_streaming_image(self) -> "Nimble":
        '''(experimental) Grants permission to update a streaming image.

        Access Level: Write

        https://docs.aws.amazon.com/nimble-studio/latest/APIReference/API_UpdateStreamingImage.html

        :stability: experimental
        '''
        return typing.cast("Nimble", jsii.invoke(self, "toUpdateStreamingImage", []))

    @jsii.member(jsii_name="toUpdateStudio")
    def to_update_studio(self) -> "Nimble":
        '''(experimental) Grants permission to update a studio.

        Access Level: Write

        Dependent actions:

        - iam:PassRole

        https://docs.aws.amazon.com/nimble-studio/latest/APIReference/API_UpdateStudio.html

        :stability: experimental
        '''
        return typing.cast("Nimble", jsii.invoke(self, "toUpdateStudio", []))

    @jsii.member(jsii_name="toUpdateStudioComponent")
    def to_update_studio_component(self) -> "Nimble":
        '''(experimental) Grants permission to update a studio component.

        Access Level: Write

        Dependent actions:

        - ds:AuthorizeApplication
        - ds:DescribeDirectories
        - ec2:DescribeSecurityGroups
        - fsx:DescribeFileSystems
        - iam:PassRole

        https://docs.aws.amazon.com/nimble-studio/latest/APIReference/API_UpdateStudioComponent.html

        :stability: experimental
        '''
        return typing.cast("Nimble", jsii.invoke(self, "toUpdateStudioComponent", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e2f8335a78e6724fbdd630d2a1865d69aaf89082e69319c3c7b919db2e6b6d10)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__afe5fb5653d4c5b7b51444881261b4495c768da4de45316ea1ab47d07c9bd439)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Oam(PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Oam"):
    '''(experimental) Statement provider for service `oam <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazoncloudwatchobservabilityaccessmanager.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `oam <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazoncloudwatchobservabilityaccessmanager.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="ifResourceTypes")
    def if_resource_types(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Oam":
        '''(experimental) Filters access by the presence of resource types in the request.

        https://docs.aws.amazon.com/oam/latest/apireference/api_createlink.html#api_createlink_requestsyntax

        Applies to actions:

        - .toCreateLink()
        - .toUpdateLink()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ae2e0dddd9a16bb321cfb663c33149b98b4def79d361f3cb32cb2c187456f441)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Oam", jsii.invoke(self, "ifResourceTypes", [value, operator]))

    @jsii.member(jsii_name="onLink")
    def on_link(
        self,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Oam":
        '''(experimental) Adds a resource of type Link to the statement.

        https://docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/CloudWatch-Unified-Cross-Account.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9d603be22aa35eb779f66e6f9d877ea828422aafc1419c295403723c703b9589)
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Oam", jsii.invoke(self, "onLink", [resource_id, account, region, partition]))

    @jsii.member(jsii_name="onSink")
    def on_sink(
        self,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Oam":
        '''(experimental) Adds a resource of type Sink to the statement.

        https://docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/CloudWatch-Unified-Cross-Account.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e7d95af87e1e56c97c24e968001da96203216f4d5a6e561bfd4684b26d141f2d)
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Oam", jsii.invoke(self, "onSink", [resource_id, account, region, partition]))

    @jsii.member(jsii_name="toCreateLink")
    def to_create_link(self) -> "Oam":
        '''(experimental) Grants permission to create a link between a monitoring account and a source account for cross-account monitoring.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifResourceTypes()

        Dependent actions:

        - oam:TagResource

        https://docs.aws.amazon.com/oam/latest/APIReference/API_CreateLink.html

        :stability: experimental
        '''
        return typing.cast("Oam", jsii.invoke(self, "toCreateLink", []))

    @jsii.member(jsii_name="toCreateSink")
    def to_create_sink(self) -> "Oam":
        '''(experimental) Grants permission to create a sink in an account so that it can be used as a monitoring account for cross-account monitoring.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - oam:TagResource

        https://docs.aws.amazon.com/oam/latest/APIReference/API_CreateSink.html

        :stability: experimental
        '''
        return typing.cast("Oam", jsii.invoke(self, "toCreateSink", []))

    @jsii.member(jsii_name="toDeleteLink")
    def to_delete_link(self) -> "Oam":
        '''(experimental) Grants permission to delete a link between a monitoring account and a source account for cross-account monitoring.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/oam/latest/APIReference/API_DeleteLink.html

        :stability: experimental
        '''
        return typing.cast("Oam", jsii.invoke(self, "toDeleteLink", []))

    @jsii.member(jsii_name="toDeleteSink")
    def to_delete_sink(self) -> "Oam":
        '''(experimental) Grants permission to delete a cross-account monitoring sink in a monitoring account.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/oam/latest/APIReference/API_DeleteSink.html

        :stability: experimental
        '''
        return typing.cast("Oam", jsii.invoke(self, "toDeleteSink", []))

    @jsii.member(jsii_name="toGetLink")
    def to_get_link(self) -> "Oam":
        '''(experimental) Grants permission to retrieve complete information about one cross-account monitoring link.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/oam/latest/APIReference/API_GetLink.html

        :stability: experimental
        '''
        return typing.cast("Oam", jsii.invoke(self, "toGetLink", []))

    @jsii.member(jsii_name="toGetSink")
    def to_get_sink(self) -> "Oam":
        '''(experimental) Grants permission to retrieve complete information about one cross-account monitoring sink.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/oam/latest/APIReference/API_GetSink.html

        :stability: experimental
        '''
        return typing.cast("Oam", jsii.invoke(self, "toGetSink", []))

    @jsii.member(jsii_name="toGetSinkPolicy")
    def to_get_sink_policy(self) -> "Oam":
        '''(experimental) Grants permission to retrieve information for the IAM policy for a cross-account monitoring sink.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/oam/latest/APIReference/API_GetSinkPolicy.html

        :stability: experimental
        '''
        return typing.cast("Oam", jsii.invoke(self, "toGetSinkPolicy", []))

    @jsii.member(jsii_name="toListAttachedLinks")
    def to_list_attached_links(self) -> "Oam":
        '''(experimental) Grants permission to retrieve a list of links that are linked for a cross-account monitoring sink.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/oam/latest/APIReference/API_ListAttachedLinks.html

        :stability: experimental
        '''
        return typing.cast("Oam", jsii.invoke(self, "toListAttachedLinks", []))

    @jsii.member(jsii_name="toListLinks")
    def to_list_links(self) -> "Oam":
        '''(experimental) Grants permission to retrieve the ARNs of cross-account monitoring links in this account.

        Access Level: Read

        https://docs.aws.amazon.com/oam/latest/APIReference/API_ListLinks.html

        :stability: experimental
        '''
        return typing.cast("Oam", jsii.invoke(self, "toListLinks", []))

    @jsii.member(jsii_name="toListSinks")
    def to_list_sinks(self) -> "Oam":
        '''(experimental) Grants permission to retrieve the ARNs of cross-account monitoring sinks in this account.

        Access Level: Read

        https://docs.aws.amazon.com/oam/latest/APIReference/API_ListSinks.html

        :stability: experimental
        '''
        return typing.cast("Oam", jsii.invoke(self, "toListSinks", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Oam":
        '''(experimental) Grants permission to list the tags for a resource.

        Access Level: Read

        https://docs.aws.amazon.com/oam/latest/APIReference/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("Oam", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toPutSinkPolicy")
    def to_put_sink_policy(self) -> "Oam":
        '''(experimental) Grants permission to create or update the IAM policy for a cross-account monitoring sink.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/oam/latest/APIReference/API_PutSinkPolicy.html

        :stability: experimental
        '''
        return typing.cast("Oam", jsii.invoke(self, "toPutSinkPolicy", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Oam":
        '''(experimental) Grants permission to tag a resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/oam/latest/APIReference/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("Oam", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Oam":
        '''(experimental) Grants permission to untag a resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/oam/latest/APIReference/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("Oam", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateLink")
    def to_update_link(self) -> "Oam":
        '''(experimental) Grants permission to update an existing link between a monitoring account and a source account.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()
        - .ifResourceTypes()

        https://docs.aws.amazon.com/oam/latest/APIReference/API_UpdateLink.html

        :stability: experimental
        '''
        return typing.cast("Oam", jsii.invoke(self, "toUpdateLink", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__aa2e31c4040f1ffdc3eee408a471f8878bb7450922e1e86abc9973d22a705c87)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0c23cb8abde0efae00b897084139b42b092eec6dee7872f3affe9528aa3b9256)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Omics(PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Omics"):
    '''(experimental) Statement provider for service `omics <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonomics.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `omics <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonomics.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="ifAnnotationImportJobJobId")
    def if_annotation_import_job_job_id(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Omics":
        '''(experimental) Filters access by a unique resource identifier.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_condition-keys.html#condition-annotation-import-job-id

        Applies to resource types:

        - AnnotationImportJob

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a170ec6c1f9c944cc602f8fe5eda851c6ba4a2f48665b97b05ca6d13a3419787)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Omics", jsii.invoke(self, "ifAnnotationImportJobJobId", [value, operator]))

    @jsii.member(jsii_name="ifAnnotationStoreName")
    def if_annotation_store_name(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Omics":
        '''(experimental) Filters access by the name of the store.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_condition-keys.html#condition-annotation-store-name

        Applies to resource types:

        - AnnotationStore

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fa364cd5d9e3ca1303e3ccf9630682925f45e4834ce3fe48d4bdecdaf083fd4e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Omics", jsii.invoke(self, "ifAnnotationStoreName", [value, operator]))

    @jsii.member(jsii_name="ifVariantImportJobJobId")
    def if_variant_import_job_job_id(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Omics":
        '''(experimental) Filters access by a unique resource identifier.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_condition-keys.html#condition-variant-import-job-id

        Applies to resource types:

        - VariantImportJob

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__aa120c12fb321ec0876747349f2e3b215c30391618bebb79a8c797851984b439)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Omics", jsii.invoke(self, "ifVariantImportJobJobId", [value, operator]))

    @jsii.member(jsii_name="ifVariantStoreName")
    def if_variant_store_name(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Omics":
        '''(experimental) Filters access by the name of the store.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_condition-keys.html#condition-variant-store-name

        Applies to resource types:

        - VariantStore

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c45bcb30e99c995cddebef374991ed14b40711d1b217419f3331ce297f73238f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Omics", jsii.invoke(self, "ifVariantStoreName", [value, operator]))

    @jsii.member(jsii_name="onAnnotationImportJob")
    def on_annotation_import_job(
        self,
        annotation_import_job_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Omics":
        '''(experimental) Adds a resource of type AnnotationImportJob to the statement.

        https://docs.aws.amazon.com/omics/latest/api/API_AnnotationImportJobItem.html

        :param annotation_import_job_id: - Identifier for the annotationImportJobId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAnnotationImportJobJobId()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__65246fe7a71174190d5eab61cb9cff283f4ceb33e956414bdf8321c5fa90a931)
            check_type(argname="argument annotation_import_job_id", value=annotation_import_job_id, expected_type=type_hints["annotation_import_job_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Omics", jsii.invoke(self, "onAnnotationImportJob", [annotation_import_job_id, account, region, partition]))

    @jsii.member(jsii_name="onAnnotationStore")
    def on_annotation_store(
        self,
        annotation_store_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Omics":
        '''(experimental) Adds a resource of type AnnotationStore to the statement.

        https://docs.aws.amazon.com/omics/latest/api/API_AnnotationStoreItem.html

        :param annotation_store_id: - Identifier for the annotationStoreId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAnnotationStoreName()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__41a935a7d63fd4a543ee2fa5bc07cbbb4e183024625dd12257519516c7129778)
            check_type(argname="argument annotation_store_id", value=annotation_store_id, expected_type=type_hints["annotation_store_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Omics", jsii.invoke(self, "onAnnotationStore", [annotation_store_id, account, region, partition]))

    @jsii.member(jsii_name="onReadSet")
    def on_read_set(
        self,
        sequence_store_id: builtins.str,
        read_set_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Omics":
        '''(experimental) Adds a resource of type readSet to the statement.

        https://docs.aws.amazon.com/omics/latest/api/API_ReadSetFiles.html

        :param sequence_store_id: - Identifier for the sequenceStoreId.
        :param read_set_id: - Identifier for the readSetId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3868f1756f2102422cf996a00801d854dd8712b6bc319c41cc296689a1c0b2a5)
            check_type(argname="argument sequence_store_id", value=sequence_store_id, expected_type=type_hints["sequence_store_id"])
            check_type(argname="argument read_set_id", value=read_set_id, expected_type=type_hints["read_set_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Omics", jsii.invoke(self, "onReadSet", [sequence_store_id, read_set_id, account, region, partition]))

    @jsii.member(jsii_name="onReference")
    def on_reference(
        self,
        reference_store_id: builtins.str,
        reference_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Omics":
        '''(experimental) Adds a resource of type reference to the statement.

        https://docs.aws.amazon.com/omics/latest/api/API_ReferenceFiles.html

        :param reference_store_id: - Identifier for the referenceStoreId.
        :param reference_id: - Identifier for the referenceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__09dd6fe55fe718c1bce160cc941c10bfcf8d51d4ed353adb1b73a95952ba2be9)
            check_type(argname="argument reference_store_id", value=reference_store_id, expected_type=type_hints["reference_store_id"])
            check_type(argname="argument reference_id", value=reference_id, expected_type=type_hints["reference_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Omics", jsii.invoke(self, "onReference", [reference_store_id, reference_id, account, region, partition]))

    @jsii.member(jsii_name="onReferenceStore")
    def on_reference_store(
        self,
        reference_store_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Omics":
        '''(experimental) Adds a resource of type referenceStore to the statement.

        https://docs.aws.amazon.com/omics/latest/api/API_ReferenceStoreDetail.html

        :param reference_store_id: - Identifier for the referenceStoreId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e46263e25212ed3803a2c8862ff13e90dca485454dbd2e7b45504b66853e3d1a)
            check_type(argname="argument reference_store_id", value=reference_store_id, expected_type=type_hints["reference_store_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Omics", jsii.invoke(self, "onReferenceStore", [reference_store_id, account, region, partition]))

    @jsii.member(jsii_name="onRun")
    def on_run(
        self,
        id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Omics":
        '''(experimental) Adds a resource of type run to the statement.

        https://docs.aws.amazon.com/omics/latest/api/API_RunListItem.html

        :param id: - Identifier for the id.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6dd97422812522dfdd93d6cf7ec25b27c051dc62addb75cf75094bbb311d0cdd)
            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Omics", jsii.invoke(self, "onRun", [id, account, region, partition]))

    @jsii.member(jsii_name="onRunGroup")
    def on_run_group(
        self,
        id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Omics":
        '''(experimental) Adds a resource of type runGroup to the statement.

        https://docs.aws.amazon.com/omics/latest/api/API_RunGroupListItem.html

        :param id: - Identifier for the id.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__09c8c2d17cc3999b90b346baef6a4456eba7aa6c7174c8559370cd5b189b559b)
            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Omics", jsii.invoke(self, "onRunGroup", [id, account, region, partition]))

    @jsii.member(jsii_name="onSequenceStore")
    def on_sequence_store(
        self,
        sequence_store_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Omics":
        '''(experimental) Adds a resource of type sequenceStore to the statement.

        https://docs.aws.amazon.com/omics/latest/api/API_SequenceStoreDetail.html

        :param sequence_store_id: - Identifier for the sequenceStoreId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__eda25d32fce215b50769b873dd601c2d29b433ebc9365617cca6875ef8d5c415)
            check_type(argname="argument sequence_store_id", value=sequence_store_id, expected_type=type_hints["sequence_store_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Omics", jsii.invoke(self, "onSequenceStore", [sequence_store_id, account, region, partition]))

    @jsii.member(jsii_name="onTaggingResource")
    def on_tagging_resource(
        self,
        tag_key: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Omics":
        '''(experimental) Adds a resource of type TaggingResource to the statement.

        https://docs.aws.amazon.com/omics/latest/api/API_TagResource.html

        :param tag_key: - Identifier for the tagKey.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__81f178a648e6c18053651e75c16b6939a892c8d13530166326b9b4131ec640de)
            check_type(argname="argument tag_key", value=tag_key, expected_type=type_hints["tag_key"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Omics", jsii.invoke(self, "onTaggingResource", [tag_key, account, region, partition]))

    @jsii.member(jsii_name="onTaskResource")
    def on_task_resource(
        self,
        id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Omics":
        '''(experimental) Adds a resource of type TaskResource to the statement.

        https://docs.aws.amazon.com/omics/latest/api/API_TaskListItem.html

        :param id: - Identifier for the id.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4e682ccbcd4d65c7cf66d813e8a42d960c54cf29fb71721f801b508394bbf4a8)
            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Omics", jsii.invoke(self, "onTaskResource", [id, account, region, partition]))

    @jsii.member(jsii_name="onVariantImportJob")
    def on_variant_import_job(
        self,
        variant_import_job_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Omics":
        '''(experimental) Adds a resource of type VariantImportJob to the statement.

        https://docs.aws.amazon.com/omics/latest/api/API_VariantImportJobItem.html

        :param variant_import_job_id: - Identifier for the variantImportJobId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifVariantImportJobJobId()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0612040a3ab9d20cc0e27e4f1a10cf881d16d6f2e09d5d5a8375a8cbfcf44da3)
            check_type(argname="argument variant_import_job_id", value=variant_import_job_id, expected_type=type_hints["variant_import_job_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Omics", jsii.invoke(self, "onVariantImportJob", [variant_import_job_id, account, region, partition]))

    @jsii.member(jsii_name="onVariantStore")
    def on_variant_store(
        self,
        variant_store_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Omics":
        '''(experimental) Adds a resource of type VariantStore to the statement.

        https://docs.aws.amazon.com/omics/latest/api/API_VariantStoreItem.html

        :param variant_store_id: - Identifier for the variantStoreId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifVariantStoreName()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c2d4f11815171ea601817f63eabe384d1092405096c7867e2ec7e8f0befe1a13)
            check_type(argname="argument variant_store_id", value=variant_store_id, expected_type=type_hints["variant_store_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Omics", jsii.invoke(self, "onVariantStore", [variant_store_id, account, region, partition]))

    @jsii.member(jsii_name="onWorkflow")
    def on_workflow(
        self,
        id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Omics":
        '''(experimental) Adds a resource of type workflow to the statement.

        https://docs.aws.amazon.com/omics/latest/api/API_WorkflowListItem.html

        :param id: - Identifier for the id.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7346a1e199cf1c9883390a53cd81c1e9c9018c15376c9461decb689d7b0b28b4)
            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Omics", jsii.invoke(self, "onWorkflow", [id, account, region, partition]))

    @jsii.member(jsii_name="toBatchDeleteReadSet")
    def to_batch_delete_read_set(self) -> "Omics":
        '''(experimental) Grants permission to batch delete Read Sets in the given Sequence Store.

        Access Level: Write

        https://docs.aws.amazon.com/omics/latest/api/API_BatchDeleteReadSet.html

        :stability: experimental
        '''
        return typing.cast("Omics", jsii.invoke(self, "toBatchDeleteReadSet", []))

    @jsii.member(jsii_name="toCancelAnnotationImportJob")
    def to_cancel_annotation_import_job(self) -> "Omics":
        '''(experimental) Grants permission to cancel an Annotation Import Job.

        Access Level: Write

        https://docs.aws.amazon.com/omics/latest/api/API_CancelAnnotationImportJob.html

        :stability: experimental
        '''
        return typing.cast("Omics", jsii.invoke(self, "toCancelAnnotationImportJob", []))

    @jsii.member(jsii_name="toCancelRun")
    def to_cancel_run(self) -> "Omics":
        '''(experimental) Grants permission to cancel a workflow run and stop all workflow tasks.

        Access Level: Write

        https://docs.aws.amazon.com/omics/latest/api/API_CancelRun.html

        :stability: experimental
        '''
        return typing.cast("Omics", jsii.invoke(self, "toCancelRun", []))

    @jsii.member(jsii_name="toCancelVariantImportJob")
    def to_cancel_variant_import_job(self) -> "Omics":
        '''(experimental) Grants permission to cancel a Variant Import Job.

        Access Level: Write

        https://docs.aws.amazon.com/omics/latest/api/API_CancelVariantImportJob.html

        :stability: experimental
        '''
        return typing.cast("Omics", jsii.invoke(self, "toCancelVariantImportJob", []))

    @jsii.member(jsii_name="toCreateAnnotationStore")
    def to_create_annotation_store(self) -> "Omics":
        '''(experimental) Grants permission to create an Annotation Store.

        Access Level: Write

        https://docs.aws.amazon.com/omics/latest/api/API_CreateAnnotationStore.html

        :stability: experimental
        '''
        return typing.cast("Omics", jsii.invoke(self, "toCreateAnnotationStore", []))

    @jsii.member(jsii_name="toCreateReferenceStore")
    def to_create_reference_store(self) -> "Omics":
        '''(experimental) Grants permission to create a Reference Store.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/omics/latest/api/API_CreateReferenceStore.html

        :stability: experimental
        '''
        return typing.cast("Omics", jsii.invoke(self, "toCreateReferenceStore", []))

    @jsii.member(jsii_name="toCreateRunGroup")
    def to_create_run_group(self) -> "Omics":
        '''(experimental) Grants permission to create a new workflow run group.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/omics/latest/api/API_CreateRunGroup.html

        :stability: experimental
        '''
        return typing.cast("Omics", jsii.invoke(self, "toCreateRunGroup", []))

    @jsii.member(jsii_name="toCreateSequenceStore")
    def to_create_sequence_store(self) -> "Omics":
        '''(experimental) Grants permission to create a Sequence Store.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/omics/latest/api/API_CreateSequenceStore.html

        :stability: experimental
        '''
        return typing.cast("Omics", jsii.invoke(self, "toCreateSequenceStore", []))

    @jsii.member(jsii_name="toCreateVariantStore")
    def to_create_variant_store(self) -> "Omics":
        '''(experimental) Grants permission to create a Variant Store.

        Access Level: Write

        https://docs.aws.amazon.com/omics/latest/api/API_CreateVariantStore.html

        :stability: experimental
        '''
        return typing.cast("Omics", jsii.invoke(self, "toCreateVariantStore", []))

    @jsii.member(jsii_name="toCreateWorkflow")
    def to_create_workflow(self) -> "Omics":
        '''(experimental) Grants permission to create a new workflow with a workflow definition and template of workflow parameters.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/omics/latest/api/API_CreateWorkflow.html

        :stability: experimental
        '''
        return typing.cast("Omics", jsii.invoke(self, "toCreateWorkflow", []))

    @jsii.member(jsii_name="toDeleteAnnotationStore")
    def to_delete_annotation_store(self) -> "Omics":
        '''(experimental) Grants permission to delete an Annotation Store.

        Access Level: Write

        https://docs.aws.amazon.com/omics/latest/api/API_DeleteAnnotationStore.html

        :stability: experimental
        '''
        return typing.cast("Omics", jsii.invoke(self, "toDeleteAnnotationStore", []))

    @jsii.member(jsii_name="toDeleteReference")
    def to_delete_reference(self) -> "Omics":
        '''(experimental) Grants permission to delete a Reference in the given Reference Store.

        Access Level: Write

        https://docs.aws.amazon.com/omics/latest/api/API_DeleteReference.html

        :stability: experimental
        '''
        return typing.cast("Omics", jsii.invoke(self, "toDeleteReference", []))

    @jsii.member(jsii_name="toDeleteReferenceStore")
    def to_delete_reference_store(self) -> "Omics":
        '''(experimental) Grants permission to delete a Reference Store.

        Access Level: Write

        https://docs.aws.amazon.com/omics/latest/api/API_DeleteReferenceStore.html

        :stability: experimental
        '''
        return typing.cast("Omics", jsii.invoke(self, "toDeleteReferenceStore", []))

    @jsii.member(jsii_name="toDeleteRun")
    def to_delete_run(self) -> "Omics":
        '''(experimental) Grants permission to delete a workflow run.

        Access Level: Write

        https://docs.aws.amazon.com/omics/latest/api/API_DeleteRun.html

        :stability: experimental
        '''
        return typing.cast("Omics", jsii.invoke(self, "toDeleteRun", []))

    @jsii.member(jsii_name="toDeleteRunGroup")
    def to_delete_run_group(self) -> "Omics":
        '''(experimental) Grants permission to delete a workflow run group.

        Access Level: Write

        https://docs.aws.amazon.com/omics/latest/api/API_DeleteRunGroup.html

        :stability: experimental
        '''
        return typing.cast("Omics", jsii.invoke(self, "toDeleteRunGroup", []))

    @jsii.member(jsii_name="toDeleteSequenceStore")
    def to_delete_sequence_store(self) -> "Omics":
        '''(experimental) Grants permission to delete a Sequence Store.

        Access Level: Write

        https://docs.aws.amazon.com/omics/latest/api/API_DeleteSequenceStore.html

        :stability: experimental
        '''
        return typing.cast("Omics", jsii.invoke(self, "toDeleteSequenceStore", []))

    @jsii.member(jsii_name="toDeleteVariantStore")
    def to_delete_variant_store(self) -> "Omics":
        '''(experimental) Grants permission to delete a Variant Store.

        Access Level: Write

        https://docs.aws.amazon.com/omics/latest/api/API_DeleteVariantStore.html

        :stability: experimental
        '''
        return typing.cast("Omics", jsii.invoke(self, "toDeleteVariantStore", []))

    @jsii.member(jsii_name="toDeleteWorkflow")
    def to_delete_workflow(self) -> "Omics":
        '''(experimental) Grants permission to delete a workflow.

        Access Level: Write

        https://docs.aws.amazon.com/omics/latest/api/API_DeleteWorkflow.html

        :stability: experimental
        '''
        return typing.cast("Omics", jsii.invoke(self, "toDeleteWorkflow", []))

    @jsii.member(jsii_name="toGetAnnotationImportJob")
    def to_get_annotation_import_job(self) -> "Omics":
        '''(experimental) Grants permission to get the status of an Annotation Import Job.

        Access Level: Read

        https://docs.aws.amazon.com/omics/latest/api/API_GetAnnotationImportJob.html

        :stability: experimental
        '''
        return typing.cast("Omics", jsii.invoke(self, "toGetAnnotationImportJob", []))

    @jsii.member(jsii_name="toGetAnnotationStore")
    def to_get_annotation_store(self) -> "Omics":
        '''(experimental) Grants permission to get detailed information about an Annotation Store.

        Access Level: Read

        https://docs.aws.amazon.com/omics/latest/api/API_GetAnnotationStore.html

        :stability: experimental
        '''
        return typing.cast("Omics", jsii.invoke(self, "toGetAnnotationStore", []))

    @jsii.member(jsii_name="toGetReadSet")
    def to_get_read_set(self) -> "Omics":
        '''(experimental) Grants permission to get a Read Set in the given Sequence Store.

        Access Level: Read

        https://docs.aws.amazon.com/omics/latest/api/API_GetReadSet.html

        :stability: experimental
        '''
        return typing.cast("Omics", jsii.invoke(self, "toGetReadSet", []))

    @jsii.member(jsii_name="toGetReadSetActivationJob")
    def to_get_read_set_activation_job(self) -> "Omics":
        '''(experimental) Grants permission to get details about a Read Set activation job for the given Sequence Store.

        Access Level: Read

        https://docs.aws.amazon.com/omics/latest/api/API_GetReadSetActivationJob.html

        :stability: experimental
        '''
        return typing.cast("Omics", jsii.invoke(self, "toGetReadSetActivationJob", []))

    @jsii.member(jsii_name="toGetReadSetExportJob")
    def to_get_read_set_export_job(self) -> "Omics":
        '''(experimental) Grants permission to get details about a Read Set export job for the given Sequence Store.

        Access Level: Read

        https://docs.aws.amazon.com/omics/latest/api/API_GetReadSetExportJob.html

        :stability: experimental
        '''
        return typing.cast("Omics", jsii.invoke(self, "toGetReadSetExportJob", []))

    @jsii.member(jsii_name="toGetReadSetImportJob")
    def to_get_read_set_import_job(self) -> "Omics":
        '''(experimental) Grants permission to get details about a Read Set import job for the given Sequence Store.

        Access Level: Read

        https://docs.aws.amazon.com/omics/latest/api/API_GetReadSetImportJob.html

        :stability: experimental
        '''
        return typing.cast("Omics", jsii.invoke(self, "toGetReadSetImportJob", []))

    @jsii.member(jsii_name="toGetReadSetMetadata")
    def to_get_read_set_metadata(self) -> "Omics":
        '''(experimental) Grants permission to get details about a Read Set in the given Sequence Store.

        Access Level: Read

        https://docs.aws.amazon.com/omics/latest/api/API_GetReadSetMetadata.html

        :stability: experimental
        '''
        return typing.cast("Omics", jsii.invoke(self, "toGetReadSetMetadata", []))

    @jsii.member(jsii_name="toGetReference")
    def to_get_reference(self) -> "Omics":
        '''(experimental) Grants permission to get a Reference in the given Reference Store.

        Access Level: Read

        https://docs.aws.amazon.com/omics/latest/api/API_GetReference.html

        :stability: experimental
        '''
        return typing.cast("Omics", jsii.invoke(self, "toGetReference", []))

    @jsii.member(jsii_name="toGetReferenceImportJob")
    def to_get_reference_import_job(self) -> "Omics":
        '''(experimental) Grants permission to get details about a Reference import job for the given Reference Store.

        Access Level: Read

        https://docs.aws.amazon.com/omics/latest/api/API_GetReferenceImportJob.html

        :stability: experimental
        '''
        return typing.cast("Omics", jsii.invoke(self, "toGetReferenceImportJob", []))

    @jsii.member(jsii_name="toGetReferenceMetadata")
    def to_get_reference_metadata(self) -> "Omics":
        '''(experimental) Grants permission to get details about a Reference in the given Reference Store.

        Access Level: Read

        https://docs.aws.amazon.com/omics/latest/api/API_GetReferenceMetadata.html

        :stability: experimental
        '''
        return typing.cast("Omics", jsii.invoke(self, "toGetReferenceMetadata", []))

    @jsii.member(jsii_name="toGetReferenceStore")
    def to_get_reference_store(self) -> "Omics":
        '''(experimental) Grants permission to get details about a Reference Store.

        Access Level: Read

        https://docs.aws.amazon.com/omics/latest/api/API_GetReferenceStore.html

        :stability: experimental
        '''
        return typing.cast("Omics", jsii.invoke(self, "toGetReferenceStore", []))

    @jsii.member(jsii_name="toGetRun")
    def to_get_run(self) -> "Omics":
        '''(experimental) Grants permission to retrieve workflow run details.

        Access Level: Read

        https://docs.aws.amazon.com/omics/latest/api/API_GetRun.html

        :stability: experimental
        '''
        return typing.cast("Omics", jsii.invoke(self, "toGetRun", []))

    @jsii.member(jsii_name="toGetRunGroup")
    def to_get_run_group(self) -> "Omics":
        '''(experimental) Grants permission to retrieve workflow run group details.

        Access Level: Read

        https://docs.aws.amazon.com/omics/latest/api/API_GetRunGroup.html

        :stability: experimental
        '''
        return typing.cast("Omics", jsii.invoke(self, "toGetRunGroup", []))

    @jsii.member(jsii_name="toGetRunTask")
    def to_get_run_task(self) -> "Omics":
        '''(experimental) Grants permission to retrieve workflow task details.

        Access Level: Read

        https://docs.aws.amazon.com/omics/latest/api/API_GetRunTask.html

        :stability: experimental
        '''
        return typing.cast("Omics", jsii.invoke(self, "toGetRunTask", []))

    @jsii.member(jsii_name="toGetSequenceStore")
    def to_get_sequence_store(self) -> "Omics":
        '''(experimental) Grants permission to get details about a Sequence Store.

        Access Level: Read

        https://docs.aws.amazon.com/omics/latest/api/API_GetSequenceStore.html

        :stability: experimental
        '''
        return typing.cast("Omics", jsii.invoke(self, "toGetSequenceStore", []))

    @jsii.member(jsii_name="toGetVariantImportJob")
    def to_get_variant_import_job(self) -> "Omics":
        '''(experimental) Grants permission to get the status of a Variant Import Job.

        Access Level: Read

        https://docs.aws.amazon.com/omics/latest/api/API_GetVariantImportJob.html

        :stability: experimental
        '''
        return typing.cast("Omics", jsii.invoke(self, "toGetVariantImportJob", []))

    @jsii.member(jsii_name="toGetVariantStore")
    def to_get_variant_store(self) -> "Omics":
        '''(experimental) Grants permission to get detailed information about a Variant Store.

        Access Level: Read

        https://docs.aws.amazon.com/omics/latest/api/API_GetVariantStore.html

        :stability: experimental
        '''
        return typing.cast("Omics", jsii.invoke(self, "toGetVariantStore", []))

    @jsii.member(jsii_name="toGetWorkflow")
    def to_get_workflow(self) -> "Omics":
        '''(experimental) Grants permission to retrieve workflow details.

        Access Level: Read

        https://docs.aws.amazon.com/omics/latest/api/API_GetWorkflow.html

        :stability: experimental
        '''
        return typing.cast("Omics", jsii.invoke(self, "toGetWorkflow", []))

    @jsii.member(jsii_name="toListAnnotationImportJobs")
    def to_list_annotation_import_jobs(self) -> "Omics":
        '''(experimental) Grants permission to get a list of Annotation Import Jobs.

        Access Level: List

        https://docs.aws.amazon.com/omics/latest/api/API_ListAnnotationImportJobs.html

        :stability: experimental
        '''
        return typing.cast("Omics", jsii.invoke(self, "toListAnnotationImportJobs", []))

    @jsii.member(jsii_name="toListAnnotationStores")
    def to_list_annotation_stores(self) -> "Omics":
        '''(experimental) Grants permission to retrieve a list of information about Annotation Stores.

        Access Level: List

        https://docs.aws.amazon.com/omics/latest/api/API_ListAnnotationStores.html

        :stability: experimental
        '''
        return typing.cast("Omics", jsii.invoke(self, "toListAnnotationStores", []))

    @jsii.member(jsii_name="toListReadSetActivationJobs")
    def to_list_read_set_activation_jobs(self) -> "Omics":
        '''(experimental) Grants permission to list Read Set activation jobs for the given Sequence Store.

        Access Level: List

        https://docs.aws.amazon.com/omics/latest/api/API_ListReadSetActivationJobs.html

        :stability: experimental
        '''
        return typing.cast("Omics", jsii.invoke(self, "toListReadSetActivationJobs", []))

    @jsii.member(jsii_name="toListReadSetExportJobs")
    def to_list_read_set_export_jobs(self) -> "Omics":
        '''(experimental) Grants permission to list Read Set export jobs for the given Sequence Store.

        Access Level: List

        https://docs.aws.amazon.com/omics/latest/api/API_ListReadSetExportJobs.html

        :stability: experimental
        '''
        return typing.cast("Omics", jsii.invoke(self, "toListReadSetExportJobs", []))

    @jsii.member(jsii_name="toListReadSetImportJobs")
    def to_list_read_set_import_jobs(self) -> "Omics":
        '''(experimental) Grants permission to list Read Set import jobs for the given Sequence Store.

        Access Level: List

        https://docs.aws.amazon.com/omics/latest/api/API_ListReadSetImportJobs.html

        :stability: experimental
        '''
        return typing.cast("Omics", jsii.invoke(self, "toListReadSetImportJobs", []))

    @jsii.member(jsii_name="toListReadSets")
    def to_list_read_sets(self) -> "Omics":
        '''(experimental) Grants permission to list Read Sets in the given Sequence Store.

        Access Level: List

        https://docs.aws.amazon.com/omics/latest/api/API_ListReadSets.html

        :stability: experimental
        '''
        return typing.cast("Omics", jsii.invoke(self, "toListReadSets", []))

    @jsii.member(jsii_name="toListReferenceImportJobs")
    def to_list_reference_import_jobs(self) -> "Omics":
        '''(experimental) Grants permission to list Reference import jobs for the given Reference Store.

        Access Level: List

        https://docs.aws.amazon.com/omics/latest/api/API_ListReferenceImportJobs.html

        :stability: experimental
        '''
        return typing.cast("Omics", jsii.invoke(self, "toListReferenceImportJobs", []))

    @jsii.member(jsii_name="toListReferences")
    def to_list_references(self) -> "Omics":
        '''(experimental) Grants permission to list References in the given Reference Store.

        Access Level: List

        https://docs.aws.amazon.com/omics/latest/api/API_ListReferences.html

        :stability: experimental
        '''
        return typing.cast("Omics", jsii.invoke(self, "toListReferences", []))

    @jsii.member(jsii_name="toListReferenceStores")
    def to_list_reference_stores(self) -> "Omics":
        '''(experimental) Grants permission to list Reference Stores.

        Access Level: List

        https://docs.aws.amazon.com/omics/latest/api/API_ListReferenceStores.html

        :stability: experimental
        '''
        return typing.cast("Omics", jsii.invoke(self, "toListReferenceStores", []))

    @jsii.member(jsii_name="toListRunGroups")
    def to_list_run_groups(self) -> "Omics":
        '''(experimental) Grants permission to retrieve a list of workflow run groups.

        Access Level: List

        https://docs.aws.amazon.com/omics/latest/api/API_ListRunGroups.html

        :stability: experimental
        '''
        return typing.cast("Omics", jsii.invoke(self, "toListRunGroups", []))

    @jsii.member(jsii_name="toListRuns")
    def to_list_runs(self) -> "Omics":
        '''(experimental) Grants permission to retrieve a list of workflow runs.

        Access Level: List

        https://docs.aws.amazon.com/omics/latest/api/API_ListRuns.html

        :stability: experimental
        '''
        return typing.cast("Omics", jsii.invoke(self, "toListRuns", []))

    @jsii.member(jsii_name="toListRunTasks")
    def to_list_run_tasks(self) -> "Omics":
        '''(experimental) Grants permission to retrieve a list of tasks for a workflow run.

        Access Level: List

        https://docs.aws.amazon.com/omics/latest/api/API_ListRunTasks.html

        :stability: experimental
        '''
        return typing.cast("Omics", jsii.invoke(self, "toListRunTasks", []))

    @jsii.member(jsii_name="toListSequenceStores")
    def to_list_sequence_stores(self) -> "Omics":
        '''(experimental) Grants permission to list Sequence Stores.

        Access Level: List

        https://docs.aws.amazon.com/omics/latest/api/API_ListSequenceStores.html

        :stability: experimental
        '''
        return typing.cast("Omics", jsii.invoke(self, "toListSequenceStores", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Omics":
        '''(experimental) Grants permission to retrieve a list of resource AWS tags.

        Access Level: List

        https://docs.aws.amazon.com/omics/latest/api/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("Omics", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toListVariantImportJobs")
    def to_list_variant_import_jobs(self) -> "Omics":
        '''(experimental) Grants permission to get a list of Variant Import Jobs.

        Access Level: List

        https://docs.aws.amazon.com/omics/latest/api/API_ListVariantImportJobs.html

        :stability: experimental
        '''
        return typing.cast("Omics", jsii.invoke(self, "toListVariantImportJobs", []))

    @jsii.member(jsii_name="toListVariantStores")
    def to_list_variant_stores(self) -> "Omics":
        '''(experimental) Grants permission to retrieve a list of metadata for Variant Stores.

        Access Level: List

        https://docs.aws.amazon.com/omics/latest/api/API_ListVariantStores.html

        :stability: experimental
        '''
        return typing.cast("Omics", jsii.invoke(self, "toListVariantStores", []))

    @jsii.member(jsii_name="toListWorkflows")
    def to_list_workflows(self) -> "Omics":
        '''(experimental) Grants permission to retrieve a list of available workflows.

        Access Level: List

        https://docs.aws.amazon.com/omics/latest/api/API_ListWorkflows.html

        :stability: experimental
        '''
        return typing.cast("Omics", jsii.invoke(self, "toListWorkflows", []))

    @jsii.member(jsii_name="toStartAnnotationImportJob")
    def to_start_annotation_import_job(self) -> "Omics":
        '''(experimental) Grants permission to import a list of Annotation files to an Annotation Store.

        Access Level: Write

        https://docs.aws.amazon.com/omics/latest/api/API_StartAnnotationImportJob.html

        :stability: experimental
        '''
        return typing.cast("Omics", jsii.invoke(self, "toStartAnnotationImportJob", []))

    @jsii.member(jsii_name="toStartReadSetActivationJob")
    def to_start_read_set_activation_job(self) -> "Omics":
        '''(experimental) Grants permission to start a Read Set activation job from the given Sequence Store.

        Access Level: Write

        https://docs.aws.amazon.com/omics/latest/api/API_StartReadSetActivationJob.html

        :stability: experimental
        '''
        return typing.cast("Omics", jsii.invoke(self, "toStartReadSetActivationJob", []))

    @jsii.member(jsii_name="toStartReadSetExportJob")
    def to_start_read_set_export_job(self) -> "Omics":
        '''(experimental) Grants permission to start a Read Set export job from the given Sequence Store.

        Access Level: Write

        https://docs.aws.amazon.com/omics/latest/api/API_StartReadSetExportJob.html

        :stability: experimental
        '''
        return typing.cast("Omics", jsii.invoke(self, "toStartReadSetExportJob", []))

    @jsii.member(jsii_name="toStartReadSetImportJob")
    def to_start_read_set_import_job(self) -> "Omics":
        '''(experimental) Grants permission to start a Read Set import job into the given Sequence Store.

        Access Level: Write

        https://docs.aws.amazon.com/omics/latest/api/API_StartReadSetImportJob.html

        :stability: experimental
        '''
        return typing.cast("Omics", jsii.invoke(self, "toStartReadSetImportJob", []))

    @jsii.member(jsii_name="toStartReferenceImportJob")
    def to_start_reference_import_job(self) -> "Omics":
        '''(experimental) Grants permission to start a Reference import job into the given Reference Store.

        Access Level: Write

        https://docs.aws.amazon.com/omics/latest/api/API_StartReferenceImportJob.html

        :stability: experimental
        '''
        return typing.cast("Omics", jsii.invoke(self, "toStartReferenceImportJob", []))

    @jsii.member(jsii_name="toStartRun")
    def to_start_run(self) -> "Omics":
        '''(experimental) Grants permission to start a workflow run.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/omics/latest/api/API_StartRun.html

        :stability: experimental
        '''
        return typing.cast("Omics", jsii.invoke(self, "toStartRun", []))

    @jsii.member(jsii_name="toStartVariantImportJob")
    def to_start_variant_import_job(self) -> "Omics":
        '''(experimental) Grants permission to import a list of variant files to an Variant Store.

        Access Level: Write

        https://docs.aws.amazon.com/omics/latest/api/API_StartVariantImportJob.html

        :stability: experimental
        '''
        return typing.cast("Omics", jsii.invoke(self, "toStartVariantImportJob", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Omics":
        '''(experimental) Grants permission to add AWS tags to a resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/omics/latest/api/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("Omics", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Omics":
        '''(experimental) Grants permission to remove resource AWS tags.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/omics/latest/api/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("Omics", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateAnnotationStore")
    def to_update_annotation_store(self) -> "Omics":
        '''(experimental) Grants permission to update information about the Annotation Store.

        Access Level: Write

        https://docs.aws.amazon.com/omics/latest/api/API_UpdateAnnotationStore.html

        :stability: experimental
        '''
        return typing.cast("Omics", jsii.invoke(self, "toUpdateAnnotationStore", []))

    @jsii.member(jsii_name="toUpdateRunGroup")
    def to_update_run_group(self) -> "Omics":
        '''(experimental) Grants permission to update a workflow run group.

        Access Level: Write

        https://docs.aws.amazon.com/omics/latest/api/API_UpdateRunGroup.html

        :stability: experimental
        '''
        return typing.cast("Omics", jsii.invoke(self, "toUpdateRunGroup", []))

    @jsii.member(jsii_name="toUpdateVariantStore")
    def to_update_variant_store(self) -> "Omics":
        '''(experimental) Grants permission to update metadata about the Variant Store.

        Access Level: Write

        https://docs.aws.amazon.com/omics/latest/api/API_UpdateVariantStore.html

        :stability: experimental
        '''
        return typing.cast("Omics", jsii.invoke(self, "toUpdateVariantStore", []))

    @jsii.member(jsii_name="toUpdateWorkflow")
    def to_update_workflow(self) -> "Omics":
        '''(experimental) Grants permission to update workflow details.

        Access Level: Write

        https://docs.aws.amazon.com/omics/latest/api/API_UpdateWorkflow.html

        :stability: experimental
        '''
        return typing.cast("Omics", jsii.invoke(self, "toUpdateWorkflow", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__231e33fd3e3b78b8790bfc581709868e948091840bc2a2edb180c0c167ed1918)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1bf6c46117504b1f769bd2d865dbac001954b2df207392844a299823176fca2e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Opsworks(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Opsworks",
):
    '''(experimental) Statement provider for service `opsworks <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsopsworks.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `opsworks <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsopsworks.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onStack")
    def on_stack(
        self,
        stack_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Opsworks":
        '''(experimental) Adds a resource of type stack to the statement.

        https://docs.aws.amazon.com/opsworks/latest/userguide/workingstacks.html

        :param stack_id: - Identifier for the stackId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__398466ef3c5449392d8d5c33d2d8c0ada36bd308e02a7d336c68e68efe273c1c)
            check_type(argname="argument stack_id", value=stack_id, expected_type=type_hints["stack_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Opsworks", jsii.invoke(self, "onStack", [stack_id, account, region, partition]))

    @jsii.member(jsii_name="toAssignInstance")
    def to_assign_instance(self) -> "Opsworks":
        '''(experimental) Grants permission to assign a registered instance to a layer.

        Access Level: Write

        https://docs.aws.amazon.com/opsworks/latest/APIReference/API_AssignInstance.html

        :stability: experimental
        '''
        return typing.cast("Opsworks", jsii.invoke(self, "toAssignInstance", []))

    @jsii.member(jsii_name="toAssignVolume")
    def to_assign_volume(self) -> "Opsworks":
        '''(experimental) Grants permission to assign one of the stack's registered Amazon EBS volumes to a specified instance.

        Access Level: Write

        https://docs.aws.amazon.com/opsworks/latest/APIReference/API_AssignVolume.html

        :stability: experimental
        '''
        return typing.cast("Opsworks", jsii.invoke(self, "toAssignVolume", []))

    @jsii.member(jsii_name="toAssociateElasticIp")
    def to_associate_elastic_ip(self) -> "Opsworks":
        '''(experimental) Grants permission to associate one of the stack's registered Elastic IP addresses with a specified instance.

        Access Level: Write

        https://docs.aws.amazon.com/opsworks/latest/APIReference/API_AssociateElasticIp.html

        :stability: experimental
        '''
        return typing.cast("Opsworks", jsii.invoke(self, "toAssociateElasticIp", []))

    @jsii.member(jsii_name="toAttachElasticLoadBalancer")
    def to_attach_elastic_load_balancer(self) -> "Opsworks":
        '''(experimental) Grants permission to attach an Elastic Load Balancing load balancer to a specified layer.

        Access Level: Write

        https://docs.aws.amazon.com/opsworks/latest/APIReference/API_AttachElasticLoadBalancer.html

        :stability: experimental
        '''
        return typing.cast("Opsworks", jsii.invoke(self, "toAttachElasticLoadBalancer", []))

    @jsii.member(jsii_name="toCloneStack")
    def to_clone_stack(self) -> "Opsworks":
        '''(experimental) Grants permission to create a clone of a specified stack.

        Access Level: Write

        https://docs.aws.amazon.com/opsworks/latest/APIReference/API_CloneStack.html

        :stability: experimental
        '''
        return typing.cast("Opsworks", jsii.invoke(self, "toCloneStack", []))

    @jsii.member(jsii_name="toCreateApp")
    def to_create_app(self) -> "Opsworks":
        '''(experimental) Grants permission to create an app for a specified stack.

        Access Level: Write

        https://docs.aws.amazon.com/opsworks/latest/APIReference/API_CreateApp.html

        :stability: experimental
        '''
        return typing.cast("Opsworks", jsii.invoke(self, "toCreateApp", []))

    @jsii.member(jsii_name="toCreateDeployment")
    def to_create_deployment(self) -> "Opsworks":
        '''(experimental) Grants permission to run deployment or stack commands.

        Access Level: Write

        https://docs.aws.amazon.com/opsworks/latest/APIReference/API_CreateDeployment.html

        :stability: experimental
        '''
        return typing.cast("Opsworks", jsii.invoke(self, "toCreateDeployment", []))

    @jsii.member(jsii_name="toCreateInstance")
    def to_create_instance(self) -> "Opsworks":
        '''(experimental) Grants permission to create an instance in a specified stack.

        Access Level: Write

        https://docs.aws.amazon.com/opsworks/latest/APIReference/API_CreateInstance.html

        :stability: experimental
        '''
        return typing.cast("Opsworks", jsii.invoke(self, "toCreateInstance", []))

    @jsii.member(jsii_name="toCreateLayer")
    def to_create_layer(self) -> "Opsworks":
        '''(experimental) Grants permission to create a layer.

        Access Level: Write

        https://docs.aws.amazon.com/opsworks/latest/APIReference/API_CreateLayer.html

        :stability: experimental
        '''
        return typing.cast("Opsworks", jsii.invoke(self, "toCreateLayer", []))

    @jsii.member(jsii_name="toCreateStack")
    def to_create_stack(self) -> "Opsworks":
        '''(experimental) Grants permission to create a new stack.

        Access Level: Write

        https://docs.aws.amazon.com/opsworks/latest/APIReference/API_CreateStack.html

        :stability: experimental
        '''
        return typing.cast("Opsworks", jsii.invoke(self, "toCreateStack", []))

    @jsii.member(jsii_name="toCreateUserProfile")
    def to_create_user_profile(self) -> "Opsworks":
        '''(experimental) Grants permission to create a new user profile.

        Access Level: Write

        https://docs.aws.amazon.com/opsworks/latest/APIReference/API_CreateUserProfile.html

        :stability: experimental
        '''
        return typing.cast("Opsworks", jsii.invoke(self, "toCreateUserProfile", []))

    @jsii.member(jsii_name="toDeleteApp")
    def to_delete_app(self) -> "Opsworks":
        '''(experimental) Grants permission to delete a specified app.

        Access Level: Write

        https://docs.aws.amazon.com/opsworks/latest/APIReference/API_DeleteApp.html

        :stability: experimental
        '''
        return typing.cast("Opsworks", jsii.invoke(self, "toDeleteApp", []))

    @jsii.member(jsii_name="toDeleteInstance")
    def to_delete_instance(self) -> "Opsworks":
        '''(experimental) Grants permission to delete a specified instance, which terminates the associated Amazon EC2 instance.

        Access Level: Write

        https://docs.aws.amazon.com/opsworks/latest/APIReference/API_DeleteInstance.html

        :stability: experimental
        '''
        return typing.cast("Opsworks", jsii.invoke(self, "toDeleteInstance", []))

    @jsii.member(jsii_name="toDeleteLayer")
    def to_delete_layer(self) -> "Opsworks":
        '''(experimental) Grants permission to delete a specified layer.

        Access Level: Write

        https://docs.aws.amazon.com/opsworks/latest/APIReference/API_DeleteLayer.html

        :stability: experimental
        '''
        return typing.cast("Opsworks", jsii.invoke(self, "toDeleteLayer", []))

    @jsii.member(jsii_name="toDeleteStack")
    def to_delete_stack(self) -> "Opsworks":
        '''(experimental) Grants permission to delete a specified stack.

        Access Level: Write

        https://docs.aws.amazon.com/opsworks/latest/APIReference/API_DeleteStack.html

        :stability: experimental
        '''
        return typing.cast("Opsworks", jsii.invoke(self, "toDeleteStack", []))

    @jsii.member(jsii_name="toDeleteUserProfile")
    def to_delete_user_profile(self) -> "Opsworks":
        '''(experimental) Grants permission to delete a user profile.

        Access Level: Write

        https://docs.aws.amazon.com/opsworks/latest/APIReference/API_DeleteUserProfile.html

        :stability: experimental
        '''
        return typing.cast("Opsworks", jsii.invoke(self, "toDeleteUserProfile", []))

    @jsii.member(jsii_name="toDeregisterEcsCluster")
    def to_deregister_ecs_cluster(self) -> "Opsworks":
        '''(experimental) Grants permission to delete a user profile.

        Access Level: Write

        https://docs.aws.amazon.com/opsworks/latest/APIReference/API_DeregisterEcsCluster.html

        :stability: experimental
        '''
        return typing.cast("Opsworks", jsii.invoke(self, "toDeregisterEcsCluster", []))

    @jsii.member(jsii_name="toDeregisterElasticIp")
    def to_deregister_elastic_ip(self) -> "Opsworks":
        '''(experimental) Grants permission to deregister a specified Elastic IP address.

        Access Level: Write

        https://docs.aws.amazon.com/opsworks/latest/APIReference/API_DeregisterElasticIp.html

        :stability: experimental
        '''
        return typing.cast("Opsworks", jsii.invoke(self, "toDeregisterElasticIp", []))

    @jsii.member(jsii_name="toDeregisterInstance")
    def to_deregister_instance(self) -> "Opsworks":
        '''(experimental) Grants permission to deregister a registered Amazon EC2 or on-premises instance.

        Access Level: Write

        https://docs.aws.amazon.com/opsworks/latest/APIReference/API_DeregisterInstance.html

        :stability: experimental
        '''
        return typing.cast("Opsworks", jsii.invoke(self, "toDeregisterInstance", []))

    @jsii.member(jsii_name="toDeregisterRdsDbInstance")
    def to_deregister_rds_db_instance(self) -> "Opsworks":
        '''(experimental) Grants permission to deregister an Amazon RDS instance.

        Access Level: Write

        https://docs.aws.amazon.com/opsworks/latest/APIReference/API_DeregisterRdsDbInstance.html

        :stability: experimental
        '''
        return typing.cast("Opsworks", jsii.invoke(self, "toDeregisterRdsDbInstance", []))

    @jsii.member(jsii_name="toDeregisterVolume")
    def to_deregister_volume(self) -> "Opsworks":
        '''(experimental) Grants permission to deregister an Amazon EBS volume.

        Access Level: Write

        https://docs.aws.amazon.com/opsworks/latest/APIReference/API_DeregisterVolume.html

        :stability: experimental
        '''
        return typing.cast("Opsworks", jsii.invoke(self, "toDeregisterVolume", []))

    @jsii.member(jsii_name="toDescribeAgentVersions")
    def to_describe_agent_versions(self) -> "Opsworks":
        '''(experimental) Grants permission to describe the available AWS OpsWorks agent versions.

        Access Level: List

        https://docs.aws.amazon.com/opsworks/latest/APIReference/API_DescribeAgentVersions.html

        :stability: experimental
        '''
        return typing.cast("Opsworks", jsii.invoke(self, "toDescribeAgentVersions", []))

    @jsii.member(jsii_name="toDescribeApps")
    def to_describe_apps(self) -> "Opsworks":
        '''(experimental) Grants permission to request a description of a specified set of apps.

        Access Level: List

        https://docs.aws.amazon.com/opsworks/latest/APIReference/API_DescribeApps.html

        :stability: experimental
        '''
        return typing.cast("Opsworks", jsii.invoke(self, "toDescribeApps", []))

    @jsii.member(jsii_name="toDescribeCommands")
    def to_describe_commands(self) -> "Opsworks":
        '''(experimental) Grants permission to describe the results of specified commands.

        Access Level: List

        https://docs.aws.amazon.com/opsworks/latest/APIReference/API_DescribeCommands.html

        :stability: experimental
        '''
        return typing.cast("Opsworks", jsii.invoke(self, "toDescribeCommands", []))

    @jsii.member(jsii_name="toDescribeDeployments")
    def to_describe_deployments(self) -> "Opsworks":
        '''(experimental) Grants permission to request a description of a specified set of deployments.

        Access Level: List

        https://docs.aws.amazon.com/opsworks/latest/APIReference/API_DescribeDeployments.html

        :stability: experimental
        '''
        return typing.cast("Opsworks", jsii.invoke(self, "toDescribeDeployments", []))

    @jsii.member(jsii_name="toDescribeEcsClusters")
    def to_describe_ecs_clusters(self) -> "Opsworks":
        '''(experimental) Grants permission to describe Amazon ECS clusters that are registered with a stack.

        Access Level: List

        https://docs.aws.amazon.com/opsworks/latest/APIReference/API_DescribeEcsClusters.html

        :stability: experimental
        '''
        return typing.cast("Opsworks", jsii.invoke(self, "toDescribeEcsClusters", []))

    @jsii.member(jsii_name="toDescribeElasticIps")
    def to_describe_elastic_ips(self) -> "Opsworks":
        '''(experimental) Grants permission to describe Elastic IP addresses.

        Access Level: List

        https://docs.aws.amazon.com/opsworks/latest/APIReference/API_DescribeElasticIps.html

        :stability: experimental
        '''
        return typing.cast("Opsworks", jsii.invoke(self, "toDescribeElasticIps", []))

    @jsii.member(jsii_name="toDescribeElasticLoadBalancers")
    def to_describe_elastic_load_balancers(self) -> "Opsworks":
        '''(experimental) Grants permission to describe a stack's Elastic Load Balancing instances.

        Access Level: List

        https://docs.aws.amazon.com/opsworks/latest/APIReference/API_DescribeElasticLoadBalancers.html

        :stability: experimental
        '''
        return typing.cast("Opsworks", jsii.invoke(self, "toDescribeElasticLoadBalancers", []))

    @jsii.member(jsii_name="toDescribeInstances")
    def to_describe_instances(self) -> "Opsworks":
        '''(experimental) Grants permission to request a description of a set of instances.

        Access Level: List

        https://docs.aws.amazon.com/opsworks/latest/APIReference/API_DescribeInstances.html

        :stability: experimental
        '''
        return typing.cast("Opsworks", jsii.invoke(self, "toDescribeInstances", []))

    @jsii.member(jsii_name="toDescribeLayers")
    def to_describe_layers(self) -> "Opsworks":
        '''(experimental) Grants permission to request a description of one or more layers in a specified stack.

        Access Level: List

        https://docs.aws.amazon.com/opsworks/latest/APIReference/API_DescribeLayers.html

        :stability: experimental
        '''
        return typing.cast("Opsworks", jsii.invoke(self, "toDescribeLayers", []))

    @jsii.member(jsii_name="toDescribeLoadBasedAutoScaling")
    def to_describe_load_based_auto_scaling(self) -> "Opsworks":
        '''(experimental) Grants permission to describe load-based auto scaling configurations for specified layers.

        Access Level: List

        https://docs.aws.amazon.com/opsworks/latest/APIReference/API_DescribeLoadBasedAutoScaling.html

        :stability: experimental
        '''
        return typing.cast("Opsworks", jsii.invoke(self, "toDescribeLoadBasedAutoScaling", []))

    @jsii.member(jsii_name="toDescribeMyUserProfile")
    def to_describe_my_user_profile(self) -> "Opsworks":
        '''(experimental) Grants permission to describe a user's SSH information.

        Access Level: List

        https://docs.aws.amazon.com/opsworks/latest/APIReference/API_DescribeMyUserProfile.html

        :stability: experimental
        '''
        return typing.cast("Opsworks", jsii.invoke(self, "toDescribeMyUserProfile", []))

    @jsii.member(jsii_name="toDescribeOperatingSystems")
    def to_describe_operating_systems(self) -> "Opsworks":
        '''(experimental) Grants permission to describe the operating systems that are supported by AWS OpsWorks Stacks.

        Access Level: List

        https://docs.aws.amazon.com/opsworks/latest/APIReference/API_DescribeOperatingSystems.html

        :stability: experimental
        '''
        return typing.cast("Opsworks", jsii.invoke(self, "toDescribeOperatingSystems", []))

    @jsii.member(jsii_name="toDescribePermissions")
    def to_describe_permissions(self) -> "Opsworks":
        '''(experimental) Grants permission to describe the permissions for a specified stack.

        Access Level: List

        https://docs.aws.amazon.com/opsworks/latest/APIReference/API_DescribePermissions.html

        :stability: experimental
        '''
        return typing.cast("Opsworks", jsii.invoke(self, "toDescribePermissions", []))

    @jsii.member(jsii_name="toDescribeRaidArrays")
    def to_describe_raid_arrays(self) -> "Opsworks":
        '''(experimental) Grants permission to describe an instance's RAID arrays.

        Access Level: List

        https://docs.aws.amazon.com/opsworks/latest/APIReference/API_DescribeRaidArrays.html

        :stability: experimental
        '''
        return typing.cast("Opsworks", jsii.invoke(self, "toDescribeRaidArrays", []))

    @jsii.member(jsii_name="toDescribeRdsDbInstances")
    def to_describe_rds_db_instances(self) -> "Opsworks":
        '''(experimental) Grants permission to describe Amazon RDS instances.

        Access Level: List

        https://docs.aws.amazon.com/opsworks/latest/APIReference/API_DescribeRdsDbInstances.html

        :stability: experimental
        '''
        return typing.cast("Opsworks", jsii.invoke(self, "toDescribeRdsDbInstances", []))

    @jsii.member(jsii_name="toDescribeServiceErrors")
    def to_describe_service_errors(self) -> "Opsworks":
        '''(experimental) Grants permission to describe AWS OpsWorks service errors.

        Access Level: List

        https://docs.aws.amazon.com/opsworks/latest/APIReference/API_DescribeServiceErrors.html

        :stability: experimental
        '''
        return typing.cast("Opsworks", jsii.invoke(self, "toDescribeServiceErrors", []))

    @jsii.member(jsii_name="toDescribeStackProvisioningParameters")
    def to_describe_stack_provisioning_parameters(self) -> "Opsworks":
        '''(experimental) Grants permission to request a description of a stack's provisioning parameters.

        Access Level: List

        https://docs.aws.amazon.com/opsworks/latest/APIReference/API_DescribeStackProvisioningParameters.html

        :stability: experimental
        '''
        return typing.cast("Opsworks", jsii.invoke(self, "toDescribeStackProvisioningParameters", []))

    @jsii.member(jsii_name="toDescribeStacks")
    def to_describe_stacks(self) -> "Opsworks":
        '''(experimental) Grants permission to request a description of one or more stacks.

        Access Level: List

        https://docs.aws.amazon.com/opsworks/latest/APIReference/API_DescribeStacks.html

        :stability: experimental
        '''
        return typing.cast("Opsworks", jsii.invoke(self, "toDescribeStacks", []))

    @jsii.member(jsii_name="toDescribeStackSummary")
    def to_describe_stack_summary(self) -> "Opsworks":
        '''(experimental) Grants permission to describe the number of layers and apps in a specified stack, and the number of instances in each state, such as running_setup or online.

        Access Level: List

        https://docs.aws.amazon.com/opsworks/latest/APIReference/API_DescribeStackSummary.html

        :stability: experimental
        '''
        return typing.cast("Opsworks", jsii.invoke(self, "toDescribeStackSummary", []))

    @jsii.member(jsii_name="toDescribeTimeBasedAutoScaling")
    def to_describe_time_based_auto_scaling(self) -> "Opsworks":
        '''(experimental) Grants permission to describe time-based auto scaling configurations for specified instances.

        Access Level: List

        https://docs.aws.amazon.com/opsworks/latest/APIReference/API_DescribeTimeBasedAutoScaling.html

        :stability: experimental
        '''
        return typing.cast("Opsworks", jsii.invoke(self, "toDescribeTimeBasedAutoScaling", []))

    @jsii.member(jsii_name="toDescribeUserProfiles")
    def to_describe_user_profiles(self) -> "Opsworks":
        '''(experimental) Grants permission to describe specified users.

        Access Level: List

        https://docs.aws.amazon.com/opsworks/latest/APIReference/API_DescribeUserProfiles.html

        :stability: experimental
        '''
        return typing.cast("Opsworks", jsii.invoke(self, "toDescribeUserProfiles", []))

    @jsii.member(jsii_name="toDescribeVolumes")
    def to_describe_volumes(self) -> "Opsworks":
        '''(experimental) Grants permission to describe an instance's Amazon EBS volumes.

        Access Level: List

        https://docs.aws.amazon.com/opsworks/latest/APIReference/API_DescribeVolumes.html

        :stability: experimental
        '''
        return typing.cast("Opsworks", jsii.invoke(self, "toDescribeVolumes", []))

    @jsii.member(jsii_name="toDetachElasticLoadBalancer")
    def to_detach_elastic_load_balancer(self) -> "Opsworks":
        '''(experimental) Grants permission to detache a specified Elastic Load Balancing instance from its layer.

        Access Level: Write

        https://docs.aws.amazon.com/opsworks/latest/APIReference/API_DetachElasticLoadBalancer.html

        :stability: experimental
        '''
        return typing.cast("Opsworks", jsii.invoke(self, "toDetachElasticLoadBalancer", []))

    @jsii.member(jsii_name="toDisassociateElasticIp")
    def to_disassociate_elastic_ip(self) -> "Opsworks":
        '''(experimental) Grants permission to disassociate an Elastic IP address from its instance.

        Access Level: Write

        https://docs.aws.amazon.com/opsworks/latest/APIReference/API_DisassociateElasticIp.html

        :stability: experimental
        '''
        return typing.cast("Opsworks", jsii.invoke(self, "toDisassociateElasticIp", []))

    @jsii.member(jsii_name="toGetHostnameSuggestion")
    def to_get_hostname_suggestion(self) -> "Opsworks":
        '''(experimental) Grants permission to get a generated host name for the specified layer, based on the current host name theme.

        Access Level: Read

        https://docs.aws.amazon.com/opsworks/latest/APIReference/API_GetHostnameSuggestion.html

        :stability: experimental
        '''
        return typing.cast("Opsworks", jsii.invoke(self, "toGetHostnameSuggestion", []))

    @jsii.member(jsii_name="toGrantAccess")
    def to_grant_access(self) -> "Opsworks":
        '''(experimental) Grants permission to grant RDP access to a Windows instance for a specified time period.

        Access Level: Write

        https://docs.aws.amazon.com/opsworks/latest/APIReference/API_RebootInstance.html

        :stability: experimental
        '''
        return typing.cast("Opsworks", jsii.invoke(self, "toGrantAccess", []))

    @jsii.member(jsii_name="toListTags")
    def to_list_tags(self) -> "Opsworks":
        '''(experimental) Grants permission to return a list of tags that are applied to the specified stack or layer.

        Access Level: List

        https://docs.aws.amazon.com/opsworks/latest/APIReference/API_ListTags.html

        :stability: experimental
        '''
        return typing.cast("Opsworks", jsii.invoke(self, "toListTags", []))

    @jsii.member(jsii_name="toRebootInstance")
    def to_reboot_instance(self) -> "Opsworks":
        '''(experimental) Grants permission to reboot a specified instance.

        Access Level: Write

        https://docs.aws.amazon.com/opsworks/latest/APIReference/API_RebootInstance.html

        :stability: experimental
        '''
        return typing.cast("Opsworks", jsii.invoke(self, "toRebootInstance", []))

    @jsii.member(jsii_name="toRegisterEcsCluster")
    def to_register_ecs_cluster(self) -> "Opsworks":
        '''(experimental) Grants permission to register a specified Amazon ECS cluster with a stack.

        Access Level: Write

        https://docs.aws.amazon.com/opsworks/latest/APIReference/API_RegisterEcsCluster.html

        :stability: experimental
        '''
        return typing.cast("Opsworks", jsii.invoke(self, "toRegisterEcsCluster", []))

    @jsii.member(jsii_name="toRegisterElasticIp")
    def to_register_elastic_ip(self) -> "Opsworks":
        '''(experimental) Grants permission to register an Elastic IP address with a specified stack.

        Access Level: Write

        https://docs.aws.amazon.com/opsworks/latest/APIReference/API_RegisterElasticIp.html

        :stability: experimental
        '''
        return typing.cast("Opsworks", jsii.invoke(self, "toRegisterElasticIp", []))

    @jsii.member(jsii_name="toRegisterInstance")
    def to_register_instance(self) -> "Opsworks":
        '''(experimental) Grants permission to register instances with a specified stack that were created outside of AWS OpsWorks.

        Access Level: Write

        https://docs.aws.amazon.com/opsworks/latest/APIReference/API_RegisterInstance.html

        :stability: experimental
        '''
        return typing.cast("Opsworks", jsii.invoke(self, "toRegisterInstance", []))

    @jsii.member(jsii_name="toRegisterRdsDbInstance")
    def to_register_rds_db_instance(self) -> "Opsworks":
        '''(experimental) Grants permission to register an Amazon RDS instance with a stack.

        Access Level: Write

        https://docs.aws.amazon.com/opsworks/latest/APIReference/API_RegisterRdsDbInstance.html

        :stability: experimental
        '''
        return typing.cast("Opsworks", jsii.invoke(self, "toRegisterRdsDbInstance", []))

    @jsii.member(jsii_name="toRegisterVolume")
    def to_register_volume(self) -> "Opsworks":
        '''(experimental) Grants permission to register an Amazon EBS volume with a specified stack.

        Access Level: Write

        https://docs.aws.amazon.com/opsworks/latest/APIReference/API_RegisterVolume.html

        :stability: experimental
        '''
        return typing.cast("Opsworks", jsii.invoke(self, "toRegisterVolume", []))

    @jsii.member(jsii_name="toSetLoadBasedAutoScaling")
    def to_set_load_based_auto_scaling(self) -> "Opsworks":
        '''(experimental) Grants permission to specify the load-based auto scaling configuration for a specified layer.

        Access Level: Write

        https://docs.aws.amazon.com/opsworks/latest/APIReference/API_SetLoadBasedAutoScaling.html

        :stability: experimental
        '''
        return typing.cast("Opsworks", jsii.invoke(self, "toSetLoadBasedAutoScaling", []))

    @jsii.member(jsii_name="toSetPermission")
    def to_set_permission(self) -> "Opsworks":
        '''(experimental) Grants permission to specify a user's permissions.

        Access Level: Permissions management

        https://docs.aws.amazon.com/opsworks/latest/APIReference/API_SetPermission.html

        :stability: experimental
        '''
        return typing.cast("Opsworks", jsii.invoke(self, "toSetPermission", []))

    @jsii.member(jsii_name="toSetTimeBasedAutoScaling")
    def to_set_time_based_auto_scaling(self) -> "Opsworks":
        '''(experimental) Grants permission to specify the time-based auto scaling configuration for a specified instance.

        Access Level: Write

        https://docs.aws.amazon.com/opsworks/latest/APIReference/API_SetTimeBasedAutoScaling.html

        :stability: experimental
        '''
        return typing.cast("Opsworks", jsii.invoke(self, "toSetTimeBasedAutoScaling", []))

    @jsii.member(jsii_name="toStartInstance")
    def to_start_instance(self) -> "Opsworks":
        '''(experimental) Grants permission to start a specified instance.

        Access Level: Write

        https://docs.aws.amazon.com/opsworks/latest/APIReference/API_StartInstance.html

        :stability: experimental
        '''
        return typing.cast("Opsworks", jsii.invoke(self, "toStartInstance", []))

    @jsii.member(jsii_name="toStartStack")
    def to_start_stack(self) -> "Opsworks":
        '''(experimental) Grants permission to start a stack's instances.

        Access Level: Write

        https://docs.aws.amazon.com/opsworks/latest/APIReference/API_StartStack.html

        :stability: experimental
        '''
        return typing.cast("Opsworks", jsii.invoke(self, "toStartStack", []))

    @jsii.member(jsii_name="toStopInstance")
    def to_stop_instance(self) -> "Opsworks":
        '''(experimental) Grants permission to stop a specified instance.

        Access Level: Write

        https://docs.aws.amazon.com/opsworks/latest/APIReference/API_StopInstance.html

        :stability: experimental
        '''
        return typing.cast("Opsworks", jsii.invoke(self, "toStopInstance", []))

    @jsii.member(jsii_name="toStopStack")
    def to_stop_stack(self) -> "Opsworks":
        '''(experimental) Grants permission to stop a specified stack.

        Access Level: Write

        https://docs.aws.amazon.com/opsworks/latest/APIReference/API_StopStack.html

        :stability: experimental
        '''
        return typing.cast("Opsworks", jsii.invoke(self, "toStopStack", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Opsworks":
        '''(experimental) Grants permission to apply tags to a specified stack or layer.

        Access Level: Tagging

        https://docs.aws.amazon.com/opsworks/latest/APIReference/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("Opsworks", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUnassignInstance")
    def to_unassign_instance(self) -> "Opsworks":
        '''(experimental) Grants permission to unassign a registered instance from all of it's layers.

        Access Level: Write

        https://docs.aws.amazon.com/opsworks/latest/APIReference/API_UnassignInstance.html

        :stability: experimental
        '''
        return typing.cast("Opsworks", jsii.invoke(self, "toUnassignInstance", []))

    @jsii.member(jsii_name="toUnassignVolume")
    def to_unassign_volume(self) -> "Opsworks":
        '''(experimental) Grants permission to unassign an assigned Amazon EBS volume.

        Access Level: Write

        https://docs.aws.amazon.com/opsworks/latest/APIReference/API_UnassignVolume.html

        :stability: experimental
        '''
        return typing.cast("Opsworks", jsii.invoke(self, "toUnassignVolume", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Opsworks":
        '''(experimental) Grants permission to remove tags from a specified stack or layer.

        Access Level: Tagging

        https://docs.aws.amazon.com/opsworks/latest/APIReference/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("Opsworks", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateApp")
    def to_update_app(self) -> "Opsworks":
        '''(experimental) Grants permission to update a specified app.

        Access Level: Write

        https://docs.aws.amazon.com/opsworks/latest/APIReference/API_UpdateApp.html

        :stability: experimental
        '''
        return typing.cast("Opsworks", jsii.invoke(self, "toUpdateApp", []))

    @jsii.member(jsii_name="toUpdateElasticIp")
    def to_update_elastic_ip(self) -> "Opsworks":
        '''(experimental) Grants permission to update a registered Elastic IP address's name.

        Access Level: Write

        https://docs.aws.amazon.com/opsworks/latest/APIReference/API_UpdateElasticIp.html

        :stability: experimental
        '''
        return typing.cast("Opsworks", jsii.invoke(self, "toUpdateElasticIp", []))

    @jsii.member(jsii_name="toUpdateInstance")
    def to_update_instance(self) -> "Opsworks":
        '''(experimental) Grants permission to update a specified instance.

        Access Level: Write

        https://docs.aws.amazon.com/opsworks/latest/APIReference/API_UpdateInstance.html

        :stability: experimental
        '''
        return typing.cast("Opsworks", jsii.invoke(self, "toUpdateInstance", []))

    @jsii.member(jsii_name="toUpdateLayer")
    def to_update_layer(self) -> "Opsworks":
        '''(experimental) Grants permission to update a specified layer.

        Access Level: Write

        https://docs.aws.amazon.com/opsworks/latest/APIReference/API_UpdateLayer.html

        :stability: experimental
        '''
        return typing.cast("Opsworks", jsii.invoke(self, "toUpdateLayer", []))

    @jsii.member(jsii_name="toUpdateMyUserProfile")
    def to_update_my_user_profile(self) -> "Opsworks":
        '''(experimental) Grants permission to update a user's SSH public key.

        Access Level: Write

        https://docs.aws.amazon.com/opsworks/latest/APIReference/API_UpdateMyUserProfile.html

        :stability: experimental
        '''
        return typing.cast("Opsworks", jsii.invoke(self, "toUpdateMyUserProfile", []))

    @jsii.member(jsii_name="toUpdateRdsDbInstance")
    def to_update_rds_db_instance(self) -> "Opsworks":
        '''(experimental) Grants permission to update an Amazon RDS instance.

        Access Level: Write

        https://docs.aws.amazon.com/opsworks/latest/APIReference/API_UpdateRdsDbInstance.html

        :stability: experimental
        '''
        return typing.cast("Opsworks", jsii.invoke(self, "toUpdateRdsDbInstance", []))

    @jsii.member(jsii_name="toUpdateStack")
    def to_update_stack(self) -> "Opsworks":
        '''(experimental) Grants permission to update a specified stack.

        Access Level: Write

        https://docs.aws.amazon.com/opsworks/latest/APIReference/API_UpdateStack.html

        :stability: experimental
        '''
        return typing.cast("Opsworks", jsii.invoke(self, "toUpdateStack", []))

    @jsii.member(jsii_name="toUpdateUserProfile")
    def to_update_user_profile(self) -> "Opsworks":
        '''(experimental) Grants permission to update a specified user profile.

        Access Level: Permissions management

        https://docs.aws.amazon.com/opsworks/latest/APIReference/API_UpdateUserProfile.html

        :stability: experimental
        '''
        return typing.cast("Opsworks", jsii.invoke(self, "toUpdateUserProfile", []))

    @jsii.member(jsii_name="toUpdateVolume")
    def to_update_volume(self) -> "Opsworks":
        '''(experimental) Grants permission to update an Amazon EBS volume's name or mount point.

        Access Level: Write

        https://docs.aws.amazon.com/opsworks/latest/APIReference/API_UpdateVolume.html

        :stability: experimental
        '''
        return typing.cast("Opsworks", jsii.invoke(self, "toUpdateVolume", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bcb119369e16f6599061934a6e24beed02cf589f1e1e2e12b3d037f8b72a02bc)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e99d489d658082c79138770e252842ec637a73cc7c6432c72eaf687d549a5371)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class OpsworksCm(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.OpsworksCm",
):
    '''(experimental) Statement provider for service `opsworks-cm <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsopsworksconfigurationmanagement.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `opsworks-cm <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsopsworksconfigurationmanagement.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onBackup")
    def on_backup(
        self,
        server_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "OpsworksCm":
        '''(experimental) Adds a resource of type backup to the statement.

        :param server_name: - Identifier for the serverName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4c5482fcba25094285576d26f5c1efe4b62b9ef47f19640010c39a3c23ea8c86)
            check_type(argname="argument server_name", value=server_name, expected_type=type_hints["server_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("OpsworksCm", jsii.invoke(self, "onBackup", [server_name, account, partition]))

    @jsii.member(jsii_name="onServer")
    def on_server(
        self,
        server_name: builtins.str,
        unique_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "OpsworksCm":
        '''(experimental) Adds a resource of type server to the statement.

        :param server_name: - Identifier for the serverName.
        :param unique_id: - Identifier for the uniqueId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9795735ee99f2de5c5e24119b5cd71abe25248bd99897b2202bb67948be18a6e)
            check_type(argname="argument server_name", value=server_name, expected_type=type_hints["server_name"])
            check_type(argname="argument unique_id", value=unique_id, expected_type=type_hints["unique_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("OpsworksCm", jsii.invoke(self, "onServer", [server_name, unique_id, account, partition]))

    @jsii.member(jsii_name="toAssociateNode")
    def to_associate_node(self) -> "OpsworksCm":
        '''(experimental) Grants permission to associate a node to a configuration management server.

        Access Level: Write

        https://docs.aws.amazon.com/opsworks-cm/latest/APIReference/API_AssociateNode.html

        :stability: experimental
        '''
        return typing.cast("OpsworksCm", jsii.invoke(self, "toAssociateNode", []))

    @jsii.member(jsii_name="toCreateBackup")
    def to_create_backup(self) -> "OpsworksCm":
        '''(experimental) Grants permission to create a backup for the specified server.

        Access Level: Write

        https://docs.aws.amazon.com/opsworks-cm/latest/APIReference/API_CreateBackup.html

        :stability: experimental
        '''
        return typing.cast("OpsworksCm", jsii.invoke(self, "toCreateBackup", []))

    @jsii.member(jsii_name="toCreateServer")
    def to_create_server(self) -> "OpsworksCm":
        '''(experimental) Grants permission to create a new server.

        Access Level: Write

        https://docs.aws.amazon.com/opsworks-cm/latest/APIReference/API_CreateServer.html

        :stability: experimental
        '''
        return typing.cast("OpsworksCm", jsii.invoke(self, "toCreateServer", []))

    @jsii.member(jsii_name="toDeleteBackup")
    def to_delete_backup(self) -> "OpsworksCm":
        '''(experimental) Grants permission to delete the specified backup and possibly its S3 bucket.

        Access Level: Write

        https://docs.aws.amazon.com/opsworks-cm/latest/APIReference/API_DeleteBackup.html

        :stability: experimental
        '''
        return typing.cast("OpsworksCm", jsii.invoke(self, "toDeleteBackup", []))

    @jsii.member(jsii_name="toDeleteServer")
    def to_delete_server(self) -> "OpsworksCm":
        '''(experimental) Grants permission to delete the specified server with its corresponding CloudFormation stack and possibly the S3 bucket.

        Access Level: Write

        https://docs.aws.amazon.com/opsworks-cm/latest/APIReference/API_DeleteServer.html

        :stability: experimental
        '''
        return typing.cast("OpsworksCm", jsii.invoke(self, "toDeleteServer", []))

    @jsii.member(jsii_name="toDescribeAccountAttributes")
    def to_describe_account_attributes(self) -> "OpsworksCm":
        '''(experimental) Grants permission to describe the service limits for the user's account.

        Access Level: List

        https://docs.aws.amazon.com/opsworks-cm/latest/APIReference/API_DescribeAccountAttributes.html

        :stability: experimental
        '''
        return typing.cast("OpsworksCm", jsii.invoke(self, "toDescribeAccountAttributes", []))

    @jsii.member(jsii_name="toDescribeBackups")
    def to_describe_backups(self) -> "OpsworksCm":
        '''(experimental) Grants permission to describe a single backup, all backups of a specified server or all backups of the user's account.

        Access Level: List

        https://docs.aws.amazon.com/opsworks-cm/latest/APIReference/API_DescribeBackups.html

        :stability: experimental
        '''
        return typing.cast("OpsworksCm", jsii.invoke(self, "toDescribeBackups", []))

    @jsii.member(jsii_name="toDescribeEvents")
    def to_describe_events(self) -> "OpsworksCm":
        '''(experimental) Grants permission to describe all events of the specified server.

        Access Level: List

        https://docs.aws.amazon.com/opsworks-cm/latest/APIReference/API_DescribeEvents.html

        :stability: experimental
        '''
        return typing.cast("OpsworksCm", jsii.invoke(self, "toDescribeEvents", []))

    @jsii.member(jsii_name="toDescribeNodeAssociationStatus")
    def to_describe_node_association_status(self) -> "OpsworksCm":
        '''(experimental) Grants permission to describe the association status for the specified node token and the specified server.

        Access Level: List

        https://docs.aws.amazon.com/opsworks-cm/latest/APIReference/API_DescribeNodeAssociationStatus.html

        :stability: experimental
        '''
        return typing.cast("OpsworksCm", jsii.invoke(self, "toDescribeNodeAssociationStatus", []))

    @jsii.member(jsii_name="toDescribeServers")
    def to_describe_servers(self) -> "OpsworksCm":
        '''(experimental) Grants permission to describe the specified server or all servers of the user's account.

        Access Level: List

        https://docs.aws.amazon.com/opsworks-cm/latest/APIReference/API_DescribeServers.html

        :stability: experimental
        '''
        return typing.cast("OpsworksCm", jsii.invoke(self, "toDescribeServers", []))

    @jsii.member(jsii_name="toDisassociateNode")
    def to_disassociate_node(self) -> "OpsworksCm":
        '''(experimental) Grants permission to disassociate a specified node from a server.

        Access Level: Write

        https://docs.aws.amazon.com/opsworks-cm/latest/APIReference/API_DisassociateNode.html

        :stability: experimental
        '''
        return typing.cast("OpsworksCm", jsii.invoke(self, "toDisassociateNode", []))

    @jsii.member(jsii_name="toExportServerEngineAttribute")
    def to_export_server_engine_attribute(self) -> "OpsworksCm":
        '''(experimental) Grants permission to export an engine attribute from a server.

        Access Level: Read

        https://docs.aws.amazon.com/opsworks-cm/latest/APIReference/API_ExportServerEngineAttribute.html

        :stability: experimental
        '''
        return typing.cast("OpsworksCm", jsii.invoke(self, "toExportServerEngineAttribute", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "OpsworksCm":
        '''(experimental) Grants permission to list the tags that are applied to the specified server or backup.

        Access Level: Read

        https://docs.aws.amazon.com/opsworks-cm/latest/APIReference/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("OpsworksCm", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toRestoreServer")
    def to_restore_server(self) -> "OpsworksCm":
        '''(experimental) Grants permission to apply a backup to specified server. Possibly swaps out the ec2-instance if specified.

        Access Level: Write

        https://docs.aws.amazon.com/opsworks-cm/latest/APIReference/API_RestoreServer.html

        :stability: experimental
        '''
        return typing.cast("OpsworksCm", jsii.invoke(self, "toRestoreServer", []))

    @jsii.member(jsii_name="toStartMaintenance")
    def to_start_maintenance(self) -> "OpsworksCm":
        '''(experimental) Grants permission to start the server maintenance immediately.

        Access Level: Write

        https://docs.aws.amazon.com/opsworks-cm/latest/APIReference/API_StartMaintenance.html

        :stability: experimental
        '''
        return typing.cast("OpsworksCm", jsii.invoke(self, "toStartMaintenance", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "OpsworksCm":
        '''(experimental) Grants permission to apply tags to the specified server or backup.

        Access Level: Tagging

        https://docs.aws.amazon.com/opsworks-cm/latest/APIReference/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("OpsworksCm", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "OpsworksCm":
        '''(experimental) Grants permission to remove tags from the specified server or backup.

        Access Level: Tagging

        https://docs.aws.amazon.com/opsworks-cm/latest/APIReference/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("OpsworksCm", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateServer")
    def to_update_server(self) -> "OpsworksCm":
        '''(experimental) Grants permission to update general server settings.

        Access Level: Write

        https://docs.aws.amazon.com/opsworks-cm/latest/APIReference/API_UpdateServer.html

        :stability: experimental
        '''
        return typing.cast("OpsworksCm", jsii.invoke(self, "toUpdateServer", []))

    @jsii.member(jsii_name="toUpdateServerEngineAttributes")
    def to_update_server_engine_attributes(self) -> "OpsworksCm":
        '''(experimental) Grants permission to update server settings specific to the configuration management type.

        Access Level: Write

        https://docs.aws.amazon.com/opsworks-cm/latest/APIReference/API_UpdateServerEngineAttributes.html

        :stability: experimental
        '''
        return typing.cast("OpsworksCm", jsii.invoke(self, "toUpdateServerEngineAttributes", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f90c3ea53d411f50a84481e0d78cf484828c6bbd6489c9694362ea3890d4fc18)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8cc148f34ce3c4ecc4044d1618450c4279df4ca209c44e9e43a1df1f01df969f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Organizations(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Organizations",
):
    '''(experimental) Statement provider for service `organizations <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsorganizations.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `organizations <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsorganizations.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="ifPolicyType")
    def if_policy_type(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Organizations":
        '''(experimental) Filters access by the specified policy type names.

        https://docs.aws.amazon.com/organizations/latest/userguide/orgs_permissions_overview.html#orgs_permissions_conditionkeys

        Applies to actions:

        - .toAttachPolicy()
        - .toCreatePolicy()
        - .toDeletePolicy()
        - .toDescribeEffectivePolicy()
        - .toDescribePolicy()
        - .toDetachPolicy()
        - .toDisablePolicyType()
        - .toEnablePolicyType()
        - .toListPolicies()
        - .toListPoliciesForTarget()
        - .toListTargetsForPolicy()
        - .toUpdatePolicy()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f139b6b23e2f72992d29a5903293300caffc7d75229e710744e2e0bfc789a934)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Organizations", jsii.invoke(self, "ifPolicyType", [value, operator]))

    @jsii.member(jsii_name="ifServicePrincipal")
    def if_service_principal(
        self,
        value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
        operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
    ) -> "Organizations":
        '''(experimental) Filters access by the specified service principal names.

        https://docs.aws.amazon.com/organizations/latest/userguide/orgs_permissions_overview.html#orgs_permissions_conditionkeys

        Applies to actions:

        - .toDeregisterDelegatedAdministrator()
        - .toDisableAWSServiceAccess()
        - .toEnableAWSServiceAccess()
        - .toListDelegatedAdministrators()
        - .toRegisterDelegatedAdministrator()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5ef11a89f902d89cbc3c55bf7b986da5ede2b0b6afe41306aa1e04afb1f8831c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            check_type(argname="argument operator", value=operator, expected_type=type_hints["operator"])
        return typing.cast("Organizations", jsii.invoke(self, "ifServicePrincipal", [value, operator]))

    @jsii.member(jsii_name="onAccount")
    def on_account(
        self,
        organization_id: builtins.str,
        account_id: typing.Optional[builtins.str] = None,
        account: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Organizations":
        '''(experimental) Adds a resource of type account to the statement.

        https://docs.aws.amazon.com/organizations/latest/userguide/orgs_reference_arn-formats.html

        :param organization_id: - Identifier for the organizationId.
        :param account_id: - Account of the resource; defaults to empty string: all accounts.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bf8ff1c2ea2bb919452739f595275d484cc06683b37b6c82164d1570c96fd346)
            check_type(argname="argument organization_id", value=organization_id, expected_type=type_hints["organization_id"])
            check_type(argname="argument account_id", value=account_id, expected_type=type_hints["account_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Organizations", jsii.invoke(self, "onAccount", [organization_id, account_id, account, partition]))

    @jsii.member(jsii_name="onAwspolicy")
    def on_awspolicy(
        self,
        policy_type: builtins.str,
        policy_id: builtins.str,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Organizations":
        '''(experimental) Adds a resource of type awspolicy to the statement.

        https://docs.aws.amazon.com/organizations/latest/userguide/orgs_reference_arn-formats.html

        :param policy_type: - Identifier for the policyType.
        :param policy_id: - Identifier for the policyId.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__33cc02b27c7dc5f4c7fcb6807b0fece39d932e77902973dea0a7d02a55953cbf)
            check_type(argname="argument policy_type", value=policy_type, expected_type=type_hints["policy_type"])
            check_type(argname="argument policy_id", value=policy_id, expected_type=type_hints["policy_id"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Organizations", jsii.invoke(self, "onAwspolicy", [policy_type, policy_id, partition]))

    @jsii.member(jsii_name="onHandshake")
    def on_handshake(
        self,
        organization_id: builtins.str,
        handshake_type: builtins.str,
        handshake_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Organizations":
        '''(experimental) Adds a resource of type handshake to the statement.

        https://docs.aws.amazon.com/organizations/latest/userguide/orgs_reference_arn-formats.html

        :param organization_id: - Identifier for the organizationId.
        :param handshake_type: - Identifier for the handshakeType.
        :param handshake_id: - Identifier for the handshakeId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d84c799e38e824fc49ddf611acacaea459e82c5eb45f5e3a2f07eb2db777f698)
            check_type(argname="argument organization_id", value=organization_id, expected_type=type_hints["organization_id"])
            check_type(argname="argument handshake_type", value=handshake_type, expected_type=type_hints["handshake_type"])
            check_type(argname="argument handshake_id", value=handshake_id, expected_type=type_hints["handshake_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Organizations", jsii.invoke(self, "onHandshake", [organization_id, handshake_type, handshake_id, account, partition]))

    @jsii.member(jsii_name="onOrganization")
    def on_organization(
        self,
        organization_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Organizations":
        '''(experimental) Adds a resource of type organization to the statement.

        https://docs.aws.amazon.com/organizations/latest/userguide/orgs_reference_arn-formats.html

        :param organization_id: - Identifier for the organizationId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f289aca29353bb42722682f394f4c6c886bc103f8bbe22cb96a495255c595a77)
            check_type(argname="argument organization_id", value=organization_id, expected_type=type_hints["organization_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Organizations", jsii.invoke(self, "onOrganization", [organization_id, account, partition]))

    @jsii.member(jsii_name="onOrganizationalunit")
    def on_organizationalunit(
        self,
        organization_id: builtins.str,
        organizational_unit_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Organizations":
        '''(experimental) Adds a resource of type organizationalunit to the statement.

        https://docs.aws.amazon.com/organizations/latest/userguide/orgs_reference_arn-formats.html

        :param organization_id: - Identifier for the organizationId.
        :param organizational_unit_id: - Identifier for the organizationalUnitId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__14704a64edfaa9cfa0cc0576c120d3c75e73db8f70f03f01104b9f2f6e773c11)
            check_type(argname="argument organization_id", value=organization_id, expected_type=type_hints["organization_id"])
            check_type(argname="argument organizational_unit_id", value=organizational_unit_id, expected_type=type_hints["organizational_unit_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Organizations", jsii.invoke(self, "onOrganizationalunit", [organization_id, organizational_unit_id, account, partition]))

    @jsii.member(jsii_name="onPolicy")
    def on_policy(
        self,
        organization_id: builtins.str,
        policy_type: builtins.str,
        policy_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Organizations":
        '''(experimental) Adds a resource of type policy to the statement.

        https://docs.aws.amazon.com/organizations/latest/userguide/orgs_reference_arn-formats.html

        :param organization_id: - Identifier for the organizationId.
        :param policy_type: - Identifier for the policyType.
        :param policy_id: - Identifier for the policyId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9b9fc2c0eb73f3a63ddf6e53e4d39ac4a7cc685c75c8e00235e53df2a3486496)
            check_type(argname="argument organization_id", value=organization_id, expected_type=type_hints["organization_id"])
            check_type(argname="argument policy_type", value=policy_type, expected_type=type_hints["policy_type"])
            check_type(argname="argument policy_id", value=policy_id, expected_type=type_hints["policy_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Organizations", jsii.invoke(self, "onPolicy", [organization_id, policy_type, policy_id, account, partition]))

    @jsii.member(jsii_name="onRoot")
    def on_root(
        self,
        organization_id: builtins.str,
        root_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Organizations":
        '''(experimental) Adds a resource of type root to the statement.

        https://docs.aws.amazon.com/organizations/latest/userguide/orgs_reference_arn-formats.html

        :param organization_id: - Identifier for the organizationId.
        :param root_id: - Identifier for the rootId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8c1b19fe28c427856d6c1120feeb3a07a3b0e93f3696fea33a2a59082b94bb9f)
            check_type(argname="argument organization_id", value=organization_id, expected_type=type_hints["organization_id"])
            check_type(argname="argument root_id", value=root_id, expected_type=type_hints["root_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Organizations", jsii.invoke(self, "onRoot", [organization_id, root_id, account, partition]))

    @jsii.member(jsii_name="toAcceptHandshake")
    def to_accept_handshake(self) -> "Organizations":
        '''(experimental) Grants permission to send a response to the originator of a handshake agreeing to the action proposed by the handshake request.

        Access Level: Write

        Dependent actions:

        - iam:CreateServiceLinkedRole

        https://docs.aws.amazon.com/organizations/latest/APIReference/API_AcceptHandshake.html

        :stability: experimental
        '''
        return typing.cast("Organizations", jsii.invoke(self, "toAcceptHandshake", []))

    @jsii.member(jsii_name="toAttachPolicy")
    def to_attach_policy(self) -> "Organizations":
        '''(experimental) Grants permission to attach a policy to a root, an organizational unit, or an individual account.

        Access Level: Write

        Possible conditions:

        - .ifPolicyType()

        https://docs.aws.amazon.com/organizations/latest/APIReference/API_AttachPolicy.html

        :stability: experimental
        '''
        return typing.cast("Organizations", jsii.invoke(self, "toAttachPolicy", []))

    @jsii.member(jsii_name="toCancelHandshake")
    def to_cancel_handshake(self) -> "Organizations":
        '''(experimental) Grants permission to cancel a handshake.

        Access Level: Write

        https://docs.aws.amazon.com/organizations/latest/APIReference/API_CancelHandshake.html

        :stability: experimental
        '''
        return typing.cast("Organizations", jsii.invoke(self, "toCancelHandshake", []))

    @jsii.member(jsii_name="toCloseAccount")
    def to_close_account(self) -> "Organizations":
        '''(experimental) Grants permission to close an AWS account that is now a part of an Organizations, either created within the organization, or invited to join the organization.

        Access Level: Write

        https://docs.aws.amazon.com/organizations/latest/APIReference/API_CloseAccount.html

        :stability: experimental
        '''
        return typing.cast("Organizations", jsii.invoke(self, "toCloseAccount", []))

    @jsii.member(jsii_name="toCreateAccount")
    def to_create_account(self) -> "Organizations":
        '''(experimental) Grants permission to create an AWS account that is automatically a member of the organization with the credentials that made the request.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/organizations/latest/APIReference/API_CreateAccount.html

        :stability: experimental
        '''
        return typing.cast("Organizations", jsii.invoke(self, "toCreateAccount", []))

    @jsii.member(jsii_name="toCreateGovCloudAccount")
    def to_create_gov_cloud_account(self) -> "Organizations":
        '''(experimental) Grants permission to create an AWS GovCloud (US) account.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/organizations/latest/APIReference/API_CreateGovCloudAccount.html

        :stability: experimental
        '''
        return typing.cast("Organizations", jsii.invoke(self, "toCreateGovCloudAccount", []))

    @jsii.member(jsii_name="toCreateOrganization")
    def to_create_organization(self) -> "Organizations":
        '''(experimental) Grants permission to create an organization.

        The account with the credentials that calls the CreateOrganization operation automatically becomes the management account of the new organization

        Access Level: Write

        Dependent actions:

        - iam:CreateServiceLinkedRole

        https://docs.aws.amazon.com/organizations/latest/APIReference/API_CreateOrganization.html

        :stability: experimental
        '''
        return typing.cast("Organizations", jsii.invoke(self, "toCreateOrganization", []))

    @jsii.member(jsii_name="toCreateOrganizationalUnit")
    def to_create_organizational_unit(self) -> "Organizations":
        '''(experimental) Grants permission to create an organizational unit (OU) within a root or parent OU.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/organizations/latest/APIReference/API_CreateOrganizationalUnit.html

        :stability: experimental
        '''
        return typing.cast("Organizations", jsii.invoke(self, "toCreateOrganizationalUnit", []))

    @jsii.member(jsii_name="toCreatePolicy")
    def to_create_policy(self) -> "Organizations":
        '''(experimental) Grants permission to create a policy that you can attach to a root, an organizational unit (OU), or an individual AWS account.

        Access Level: Write

        Possible conditions:

        - .ifPolicyType()
        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/organizations/latest/APIReference/API_CreatePolicy.html

        :stability: experimental
        '''
        return typing.cast("Organizations", jsii.invoke(self, "toCreatePolicy", []))

    @jsii.member(jsii_name="toDeclineHandshake")
    def to_decline_handshake(self) -> "Organizations":
        '''(experimental) Grants permission to decline a handshake request. This sets the handshake state to DECLINED and effectively deactivates the request.

        Access Level: Write

        https://docs.aws.amazon.com/organizations/latest/APIReference/API_DeclineHandshake.html

        :stability: experimental
        '''
        return typing.cast("Organizations", jsii.invoke(self, "toDeclineHandshake", []))

    @jsii.member(jsii_name="toDeleteOrganization")
    def to_delete_organization(self) -> "Organizations":
        '''(experimental) Grants permission to delete the organization.

        Access Level: Write

        https://docs.aws.amazon.com/organizations/latest/APIReference/API_DeleteOrganization.html

        :stability: experimental
        '''
        return typing.cast("Organizations", jsii.invoke(self, "toDeleteOrganization", []))

    @jsii.member(jsii_name="toDeleteOrganizationalUnit")
    def to_delete_organizational_unit(self) -> "Organizations":
        '''(experimental) Grants permission to delete an organizational unit from a root or another OU.

        Access Level: Write

        https://docs.aws.amazon.com/organizations/latest/APIReference/API_DeleteOrganizationalUnit.html

        :stability: experimental
        '''
        return typing.cast("Organizations", jsii.invoke(self, "toDeleteOrganizationalUnit", []))

    @jsii.member(jsii_name="toDeletePolicy")
    def to_delete_policy(self) -> "Organizations":
        '''(experimental) Grants permission to delete a policy from your organization.

        Access Level: Write

        Possible conditions:

        - .ifPolicyType()

        https://docs.aws.amazon.com/organizations/latest/APIReference/API_DeletePolicy.html

        :stability: experimental
        '''
        return typing.cast("Organizations", jsii.invoke(self, "toDeletePolicy", []))

    @jsii.member(jsii_name="toDeregisterDelegatedAdministrator")
    def to_deregister_delegated_administrator(self) -> "Organizations":
        '''(experimental) Grants permission to deregister the specified member AWS account as a delegated administrator for the AWS service that is specified by ServicePrincipal.

        Access Level: Write

        Possible conditions:

        - .ifServicePrincipal()

        https://docs.aws.amazon.com/organizations/latest/APIReference/API_DeregisterDelegatedAdministrator.html

        :stability: experimental
        '''
        return typing.cast("Organizations", jsii.invoke(self, "toDeregisterDelegatedAdministrator", []))

    @jsii.member(jsii_name="toDescribeAccount")
    def to_describe_account(self) -> "Organizations":
        '''(experimental) Grants permission to retrieve Organizations-related details about the specified account.

        Access Level: Read

        https://docs.aws.amazon.com/organizations/latest/APIReference/API_DescribeAccount.html

        :stability: experimental
        '''
        return typing.cast("Organizations", jsii.invoke(self, "toDescribeAccount", []))

    @jsii.member(jsii_name="toDescribeCreateAccountStatus")
    def to_describe_create_account_status(self) -> "Organizations":
        '''(experimental) Grants permission to retrieve the current status of an asynchronous request to create an account.

        Access Level: Read

        https://docs.aws.amazon.com/organizations/latest/APIReference/API_DescribeCreateAccountStatus.html

        :stability: experimental
        '''
        return typing.cast("Organizations", jsii.invoke(self, "toDescribeCreateAccountStatus", []))

    @jsii.member(jsii_name="toDescribeEffectivePolicy")
    def to_describe_effective_policy(self) -> "Organizations":
        '''(experimental) Grants permission to retrieve the effective policy for an account.

        Access Level: Read

        Possible conditions:

        - .ifPolicyType()

        https://docs.aws.amazon.com/organizations/latest/APIReference/API_DescribeEffectivePolicy.html

        :stability: experimental
        '''
        return typing.cast("Organizations", jsii.invoke(self, "toDescribeEffectivePolicy", []))

    @jsii.member(jsii_name="toDescribeHandshake")
    def to_describe_handshake(self) -> "Organizations":
        '''(experimental) Grants permission to retrieve details about a previously requested handshake.

        Access Level: Read

        https://docs.aws.amazon.com/organizations/latest/APIReference/API_DescribeHandshake.html

        :stability: experimental
        '''
        return typing.cast("Organizations", jsii.invoke(self, "toDescribeHandshake", []))

    @jsii.member(jsii_name="toDescribeOrganization")
    def to_describe_organization(self) -> "Organizations":
        '''(experimental) Grants permission to retrieves details about the organization that the calling credentials belong to.

        Access Level: Read

        https://docs.aws.amazon.com/organizations/latest/APIReference/API_DescribeOrganization.html

        :stability: experimental
        '''
        return typing.cast("Organizations", jsii.invoke(self, "toDescribeOrganization", []))

    @jsii.member(jsii_name="toDescribeOrganizationalUnit")
    def to_describe_organizational_unit(self) -> "Organizations":
        '''(experimental) Grants permission to retrieve details about an organizational unit (OU).

        Access Level: Read

        https://docs.aws.amazon.com/organizations/latest/APIReference/API_DescribeOrganizationalUnit.html

        :stability: experimental
        '''
        return typing.cast("Organizations", jsii.invoke(self, "toDescribeOrganizationalUnit", []))

    @jsii.member(jsii_name="toDescribePolicy")
    def to_describe_policy(self) -> "Organizations":
        '''(experimental) Grants permission to retrieves details about a policy.

        Access Level: Read

        Possible conditions:

        - .ifPolicyType()

        https://docs.aws.amazon.com/organizations/latest/APIReference/API_DescribePolicy.html

        :stability: experimental
        '''
        return typing.cast("Organizations", jsii.invoke(self, "toDescribePolicy", []))

    @jsii.member(jsii_name="toDetachPolicy")
    def to_detach_policy(self) -> "Organizations":
        '''(experimental) Grants permission to detach a policy from a target root, organizational unit, or account.

        Access Level: Write

        Possible conditions:

        - .ifPolicyType()

        https://docs.aws.amazon.com/organizations/latest/APIReference/API_DetachPolicy.html

        :stability: experimental
        '''
        return typing.cast("Organizations", jsii.invoke(self, "toDetachPolicy", []))

    @jsii.member(jsii_name="toDisableAWSServiceAccess")
    def to_disable_aws_service_access(self) -> "Organizations":
        '''(experimental) Grants permission to disable integration of an AWS service (the service that is specified by ServicePrincipal) with AWS Organizations.

        Access Level: Write

        Possible conditions:

        - .ifServicePrincipal()

        https://docs.aws.amazon.com/organizations/latest/APIReference/API_DisableAWSServiceAccess.html

        :stability: experimental
        '''
        return typing.cast("Organizations", jsii.invoke(self, "toDisableAWSServiceAccess", []))

    @jsii.member(jsii_name="toDisablePolicyType")
    def to_disable_policy_type(self) -> "Organizations":
        '''(experimental) Grants permission to disable an organization policy type in a root.

        Access Level: Write

        Possible conditions:

        - .ifPolicyType()

        https://docs.aws.amazon.com/organizations/latest/APIReference/API_DisablePolicyType.html

        :stability: experimental
        '''
        return typing.cast("Organizations", jsii.invoke(self, "toDisablePolicyType", []))

    @jsii.member(jsii_name="toEnableAllFeatures")
    def to_enable_all_features(self) -> "Organizations":
        '''(experimental) Grants permission to start the process to enable all features in an organization, upgrading it from supporting only Consolidated Billing features.

        Access Level: Write

        https://docs.aws.amazon.com/organizations/latest/APIReference/API_EnableAllFeatures.html

        :stability: experimental
        '''
        return typing.cast("Organizations", jsii.invoke(self, "toEnableAllFeatures", []))

    @jsii.member(jsii_name="toEnableAWSServiceAccess")
    def to_enable_aws_service_access(self) -> "Organizations":
        '''(experimental) Grants permission to enable integration of an AWS service (the service that is specified by ServicePrincipal) with AWS Organizations.

        Access Level: Write

        Possible conditions:

        - .ifServicePrincipal()

        https://docs.aws.amazon.com/organizations/latest/APIReference/API_EnableAWSServiceAccess.html

        :stability: experimental
        '''
        return typing.cast("Organizations", jsii.invoke(self, "toEnableAWSServiceAccess", []))

    @jsii.member(jsii_name="toEnablePolicyType")
    def to_enable_policy_type(self) -> "Organizations":
        '''(experimental) Grants permission to enable a policy type in a root.

        Access Level: Write

        Possible conditions:

        - .ifPolicyType()

        https://docs.aws.amazon.com/organizations/latest/APIReference/API_EnablePolicyType.html

        :stability: experimental
        '''
        return typing.cast("Organizations", jsii.invoke(self, "toEnablePolicyType", []))

    @jsii.member(jsii_name="toInviteAccountToOrganization")
    def to_invite_account_to_organization(self) -> "Organizations":
        '''(experimental) Grants permission to send an invitation to another AWS account, asking it to join your organization as a member account.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/organizations/latest/APIReference/API_InviteAccountToOrganization.html

        :stability: experimental
        '''
        return typing.cast("Organizations", jsii.invoke(self, "toInviteAccountToOrganization", []))

    @jsii.member(jsii_name="toLeaveOrganization")
    def to_leave_organization(self) -> "Organizations":
        '''(experimental) Grants permission to remove a member account from its parent organization.

        Access Level: Write

        https://docs.aws.amazon.com/organizations/latest/APIReference/API_LeaveOrganization.html

        :stability: experimental
        '''
        return typing.cast("Organizations", jsii.invoke(self, "toLeaveOrganization", []))

    @jsii.member(jsii_name="toListAccounts")
    def to_list_accounts(self) -> "Organizations":
        '''(experimental) Grants permission to list all of the the accounts in the organization.

        Access Level: List

        https://docs.aws.amazon.com/organizations/latest/APIReference/API_ListAccounts.html

        :stability: experimental
        '''
        return typing.cast("Organizations", jsii.invoke(self, "toListAccounts", []))

    @jsii.member(jsii_name="toListAccountsForParent")
    def to_list_accounts_for_parent(self) -> "Organizations":
        '''(experimental) Grants permission to list the accounts in an organization that are contained by a root or organizational unit (OU).

        Access Level: List

        https://docs.aws.amazon.com/organizations/latest/APIReference/API_ListAccountsForParent.html

        :stability: experimental
        '''
        return typing.cast("Organizations", jsii.invoke(self, "toListAccountsForParent", []))

    @jsii.member(jsii_name="toListAWSServiceAccessForOrganization")
    def to_list_aws_service_access_for_organization(self) -> "Organizations":
        '''(experimental) Grants permission to retrieve the list of the AWS services for which you enabled integration with your organization.

        Access Level: List

        https://docs.aws.amazon.com/organizations/latest/APIReference/API_ListAWSServiceAccessForOrganization.html

        :stability: experimental
        '''
        return typing.cast("Organizations", jsii.invoke(self, "toListAWSServiceAccessForOrganization", []))

    @jsii.member(jsii_name="toListChildren")
    def to_list_children(self) -> "Organizations":
        '''(experimental) Grants permission to list all of the OUs or accounts that are contained in a parent OU or root.

        Access Level: List

        https://docs.aws.amazon.com/organizations/latest/APIReference/API_ListChildren.html

        :stability: experimental
        '''
        return typing.cast("Organizations", jsii.invoke(self, "toListChildren", []))

    @jsii.member(jsii_name="toListCreateAccountStatus")
    def to_list_create_account_status(self) -> "Organizations":
        '''(experimental) Grants permission to list the asynchronous account creation requests that are currently being tracked for the organization.

        Access Level: List

        https://docs.aws.amazon.com/organizations/latest/APIReference/API_ListCreateAccountStatus.html

        :stability: experimental
        '''
        return typing.cast("Organizations", jsii.invoke(self, "toListCreateAccountStatus", []))

    @jsii.member(jsii_name="toListDelegatedAdministrators")
    def to_list_delegated_administrators(self) -> "Organizations":
        '''(experimental) Grants permission to list the AWS accounts that are designated as delegated administrators in this organization.

        Access Level: List

        Possible conditions:

        - .ifServicePrincipal()

        https://docs.aws.amazon.com/organizations/latest/APIReference/API_ListDelegatedAdministrators.html

        :stability: experimental
        '''
        return typing.cast("Organizations", jsii.invoke(self, "toListDelegatedAdministrators", []))

    @jsii.member(jsii_name="toListDelegatedServicesForAccount")
    def to_list_delegated_services_for_account(self) -> "Organizations":
        '''(experimental) Grants permission to list the AWS services for which the specified account is a delegated administrator in this organization.

        Access Level: List

        https://docs.aws.amazon.com/organizations/latest/APIReference/API_ListDelegatedServicesForAccount.html

        :stability: experimental
        '''
        return typing.cast("Organizations", jsii.invoke(self, "toListDelegatedServicesForAccount", []))

    @jsii.member(jsii_name="toListHandshakesForAccount")
    def to_list_handshakes_for_account(self) -> "Organizations":
        '''(experimental) Grants permission to list all of the handshakes that are associated with an account.

        Access Level: List

        https://docs.aws.amazon.com/organizations/latest/APIReference/API_ListHandshakesForAccount.html

        :stability: experimental
        '''
        return typing.cast("Organizations", jsii.invoke(self, "toListHandshakesForAccount", []))

    @jsii.member(jsii_name="toListHandshakesForOrganization")
    def to_list_handshakes_for_organization(self) -> "Organizations":
        '''(experimental) Grants permission to list the handshakes that are associated with the organization.

        Access Level: List

        https://docs.aws.amazon.com/organizations/latest/APIReference/API_ListHandshakesForOrganization.html

        :stability: experimental
        '''
        return typing.cast("Organizations", jsii.invoke(self, "toListHandshakesForOrganization", []))

    @jsii.member(jsii_name="toListOrganizationalUnitsForParent")
    def to_list_organizational_units_for_parent(self) -> "Organizations":
        '''(experimental) Grants permission to lists all of the organizational units (OUs) in a parent organizational unit or root.

        Access Level: List

        https://docs.aws.amazon.com/organizations/latest/APIReference/API_ListOrganizationalUnitsForParent.html

        :stability: experimental
        '''
        return typing.cast("Organizations", jsii.invoke(self, "toListOrganizationalUnitsForParent", []))

    @jsii.member(jsii_name="toListParents")
    def to_list_parents(self) -> "Organizations":
        '''(experimental) Grants permission to list the root or organizational units (OUs) that serve as the immediate parent of a child OU or account.

        Access Level: List

        https://docs.aws.amazon.com/organizations/latest/APIReference/API_ListParents.html

        :stability: experimental
        '''
        return typing.cast("Organizations", jsii.invoke(self, "toListParents", []))

    @jsii.member(jsii_name="toListPolicies")
    def to_list_policies(self) -> "Organizations":
        '''(experimental) Grants permission to list all of the policies in an organization.

        Access Level: List

        Possible conditions:

        - .ifPolicyType()

        https://docs.aws.amazon.com/organizations/latest/APIReference/API_ListPolicies.html

        :stability: experimental
        '''
        return typing.cast("Organizations", jsii.invoke(self, "toListPolicies", []))

    @jsii.member(jsii_name="toListPoliciesForTarget")
    def to_list_policies_for_target(self) -> "Organizations":
        '''(experimental) Grants permission to list all of the policies that are directly attached to a root, organizational unit (OU), or account.

        Access Level: List

        Possible conditions:

        - .ifPolicyType()

        https://docs.aws.amazon.com/organizations/latest/APIReference/API_ListPoliciesForTarget.html

        :stability: experimental
        '''
        return typing.cast("Organizations", jsii.invoke(self, "toListPoliciesForTarget", []))

    @jsii.member(jsii_name="toListRoots")
    def to_list_roots(self) -> "Organizations":
        '''(experimental) Grants permission to list all of the roots that are defined in the organization.

        Access Level: List

        https://docs.aws.amazon.com/organizations/latest/APIReference/API_ListRoots.html

        :stability: experimental
        '''
        return typing.cast("Organizations", jsii.invoke(self, "toListRoots", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Organizations":
        '''(experimental) Grants permission to list all tags for the specified resource.

        Access Level: List

        https://docs.aws.amazon.com/organizations/latest/APIReference/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("Organizations", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toListTargetsForPolicy")
    def to_list_targets_for_policy(self) -> "Organizations":
        '''(experimental) Grants permission to list all the roots, OUs, and accounts to which a policy is attached.

        Access Level: List

        Possible conditions:

        - .ifPolicyType()

        https://docs.aws.amazon.com/organizations/latest/APIReference/API_ListTargetsForPolicy.html

        :stability: experimental
        '''
        return typing.cast("Organizations", jsii.invoke(self, "toListTargetsForPolicy", []))

    @jsii.member(jsii_name="toMoveAccount")
    def to_move_account(self) -> "Organizations":
        '''(experimental) Grants permission to move an account from its current root or OU to another parent root or OU.

        Access Level: Write

        https://docs.aws.amazon.com/organizations/latest/APIReference/API_MoveAccount.html

        :stability: experimental
        '''
        return typing.cast("Organizations", jsii.invoke(self, "toMoveAccount", []))

    @jsii.member(jsii_name="toRegisterDelegatedAdministrator")
    def to_register_delegated_administrator(self) -> "Organizations":
        '''(experimental) Grants permission to register the specified member account to administer the Organizations features of the AWS service that is specified by ServicePrincipal.

        Access Level: Write

        Possible conditions:

        - .ifServicePrincipal()

        https://docs.aws.amazon.com/organizations/latest/APIReference/API_RegisterDelegatedAdministrator.html

        :stability: experimental
        '''
        return typing.cast("Organizations", jsii.invoke(self, "toRegisterDelegatedAdministrator", []))

    @jsii.member(jsii_name="toRemoveAccountFromOrganization")
    def to_remove_account_from_organization(self) -> "Organizations":
        '''(experimental) Grants permission to removes the specified account from the organization.

        Access Level: Write

        https://docs.aws.amazon.com/organizations/latest/APIReference/API_RemoveAccountFromOrganization.html

        :stability: experimental
        '''
        return typing.cast("Organizations", jsii.invoke(self, "toRemoveAccountFromOrganization", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Organizations":
        '''(experimental) Grants permission to add one or more tags to the specified resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/organizations/latest/APIReference/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("Organizations", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Organizations":
        '''(experimental) Grants permission to remove one or more tags from the specified resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/organizations/latest/APIReference/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("Organizations", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateOrganizationalUnit")
    def to_update_organizational_unit(self) -> "Organizations":
        '''(experimental) Grants permission to rename an organizational unit (OU).

        Access Level: Write

        https://docs.aws.amazon.com/organizations/latest/APIReference/API_UpdateOrganizationalUnit.html

        :stability: experimental
        '''
        return typing.cast("Organizations", jsii.invoke(self, "toUpdateOrganizationalUnit", []))

    @jsii.member(jsii_name="toUpdatePolicy")
    def to_update_policy(self) -> "Organizations":
        '''(experimental) Grants permission to update an existing policy with a new name, description, or content.

        Access Level: Write

        Possible conditions:

        - .ifPolicyType()

        https://docs.aws.amazon.com/organizations/latest/APIReference/API_UpdatePolicy.html

        :stability: experimental
        '''
        return typing.cast("Organizations", jsii.invoke(self, "toUpdatePolicy", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__af29ce63d26cb84905105e8c1a6a045a2f14f4cf54c616d960b9059008567e10)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__339eefc6adbd36ef47e75c34585cdd169c0bf99934a9fc56c087ee98a954be5b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Outposts(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Outposts",
):
    '''(experimental) Statement provider for service `outposts <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsoutposts.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `outposts <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsoutposts.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onOutpost")
    def on_outpost(
        self,
        outpost_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Outposts":
        '''(experimental) Adds a resource of type outpost to the statement.

        https://docs.aws.amazon.com/outposts/latest/userguide/work-with-outposts.html

        :param outpost_id: - Identifier for the outpostId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f1d7de9820473779681e97d774c0e7ada086babbdef4cb1516d5f344b0069bad)
            check_type(argname="argument outpost_id", value=outpost_id, expected_type=type_hints["outpost_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Outposts", jsii.invoke(self, "onOutpost", [outpost_id, account, region, partition]))

    @jsii.member(jsii_name="onSite")
    def on_site(
        self,
        site_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Outposts":
        '''(experimental) Adds a resource of type site to the statement.

        https://docs.aws.amazon.com/outposts/latest/userguide/work-with-outposts.html

        :param site_id: - Identifier for the siteId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6309048e59bb653498a09619bd256bfd5fdbe2e42d6c525eff4fb5594deddb18)
            check_type(argname="argument site_id", value=site_id, expected_type=type_hints["site_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Outposts", jsii.invoke(self, "onSite", [site_id, account, region, partition]))

    @jsii.member(jsii_name="toCancelOrder")
    def to_cancel_order(self) -> "Outposts":
        '''(experimental) Grants permission to cancel an order.

        Access Level: Write

        https://docs.aws.amazon.com/outposts/latest/APIReference/API_CancelOrder.html

        :stability: experimental
        '''
        return typing.cast("Outposts", jsii.invoke(self, "toCancelOrder", []))

    @jsii.member(jsii_name="toCreateOrder")
    def to_create_order(self) -> "Outposts":
        '''(experimental) Grants permission to create an order.

        Access Level: Write

        https://docs.aws.amazon.com/outposts/latest/APIReference/API_CreateOrder.html

        :stability: experimental
        '''
        return typing.cast("Outposts", jsii.invoke(self, "toCreateOrder", []))

    @jsii.member(jsii_name="toCreateOutpost")
    def to_create_outpost(self) -> "Outposts":
        '''(experimental) Grants permission to create an Outpost.

        Access Level: Write

        https://docs.aws.amazon.com/outposts/latest/APIReference/API_CreateOutpost.html

        :stability: experimental
        '''
        return typing.cast("Outposts", jsii.invoke(self, "toCreateOutpost", []))

    @jsii.member(jsii_name="toCreatePrivateConnectivityConfig")
    def to_create_private_connectivity_config(self) -> "Outposts":
        '''(experimental) Grants permission to create a private connectivity configuration.

        Access Level: Write

        https://docs.aws.amazon.com/outposts/latest/userguide/how-outposts-works.html#private-connectivity

        :stability: experimental
        '''
        return typing.cast("Outposts", jsii.invoke(self, "toCreatePrivateConnectivityConfig", []))

    @jsii.member(jsii_name="toCreateSite")
    def to_create_site(self) -> "Outposts":
        '''(experimental) Grants permission to create a site.

        Access Level: Write

        https://docs.aws.amazon.com/outposts/latest/APIReference/API_CreateSite.html

        :stability: experimental
        '''
        return typing.cast("Outposts", jsii.invoke(self, "toCreateSite", []))

    @jsii.member(jsii_name="toDeleteOutpost")
    def to_delete_outpost(self) -> "Outposts":
        '''(experimental) Grants permission to delete an Outpost.

        Access Level: Write

        https://docs.aws.amazon.com/outposts/latest/APIReference/API_DeleteOutpost.html

        :stability: experimental
        '''
        return typing.cast("Outposts", jsii.invoke(self, "toDeleteOutpost", []))

    @jsii.member(jsii_name="toDeleteSite")
    def to_delete_site(self) -> "Outposts":
        '''(experimental) Grants permission to delete a site.

        Access Level: Write

        https://docs.aws.amazon.com/outposts/latest/APIReference/API_DeleteSite.html

        :stability: experimental
        '''
        return typing.cast("Outposts", jsii.invoke(self, "toDeleteSite", []))

    @jsii.member(jsii_name="toGetCatalogItem")
    def to_get_catalog_item(self) -> "Outposts":
        '''(experimental) Grants permission to get a catalog item.

        Access Level: Read

        https://docs.aws.amazon.com/outposts/latest/APIReference/API_GetCatalogItem.html

        :stability: experimental
        '''
        return typing.cast("Outposts", jsii.invoke(self, "toGetCatalogItem", []))

    @jsii.member(jsii_name="toGetConnection")
    def to_get_connection(self) -> "Outposts":
        '''(experimental) Grants permission to get information about the connection for your Outpost server.

        Access Level: Read

        https://docs.aws.amazon.com/outposts/latest/APIReference/API_GetConnection.html

        :stability: experimental
        '''
        return typing.cast("Outposts", jsii.invoke(self, "toGetConnection", []))

    @jsii.member(jsii_name="toGetOrder")
    def to_get_order(self) -> "Outposts":
        '''(experimental) Grants permission to get information about an order.

        Access Level: Read

        https://docs.aws.amazon.com/outposts/latest/APIReference/API_GetOrder.html

        :stability: experimental
        '''
        return typing.cast("Outposts", jsii.invoke(self, "toGetOrder", []))

    @jsii.member(jsii_name="toGetOutpost")
    def to_get_outpost(self) -> "Outposts":
        '''(experimental) Grants permission to get information about the specified Outpost.

        Access Level: Read

        https://docs.aws.amazon.com/outposts/latest/APIReference/API_GetOutpost.html

        :stability: experimental
        '''
        return typing.cast("Outposts", jsii.invoke(self, "toGetOutpost", []))

    @jsii.member(jsii_name="toGetOutpostInstanceTypes")
    def to_get_outpost_instance_types(self) -> "Outposts":
        '''(experimental) Grants permission to get the instance types for the specified Outpost.

        Access Level: Read

        https://docs.aws.amazon.com/outposts/latest/APIReference/API_GetOutpostInstanceTypes.html

        :stability: experimental
        '''
        return typing.cast("Outposts", jsii.invoke(self, "toGetOutpostInstanceTypes", []))

    @jsii.member(jsii_name="toGetPrivateConnectivityConfig")
    def to_get_private_connectivity_config(self) -> "Outposts":
        '''(experimental) Grants permission to get a private connectivity configuration.

        Access Level: Read

        https://docs.aws.amazon.com/outposts/latest/userguide/how-outposts-works.html#private-connectivity

        :stability: experimental
        '''
        return typing.cast("Outposts", jsii.invoke(self, "toGetPrivateConnectivityConfig", []))

    @jsii.member(jsii_name="toGetSite")
    def to_get_site(self) -> "Outposts":
        '''(experimental) Grants permission to get a site.

        Access Level: Read

        https://docs.aws.amazon.com/outposts/latest/APIReference/API_GetSite.html

        :stability: experimental
        '''
        return typing.cast("Outposts", jsii.invoke(self, "toGetSite", []))

    @jsii.member(jsii_name="toGetSiteAddress")
    def to_get_site_address(self) -> "Outposts":
        '''(experimental) Grants permission to get a site address.

        Access Level: Read

        https://docs.aws.amazon.com/outposts/latest/APIReference/API_GetSiteAddress.html

        :stability: experimental
        '''
        return typing.cast("Outposts", jsii.invoke(self, "toGetSiteAddress", []))

    @jsii.member(jsii_name="toListAssets")
    def to_list_assets(self) -> "Outposts":
        '''(experimental) Grants permission to list the assets for your Outpost.

        Access Level: List

        https://docs.aws.amazon.com/outposts/latest/APIReference/API_ListAssets.html

        :stability: experimental
        '''
        return typing.cast("Outposts", jsii.invoke(self, "toListAssets", []))

    @jsii.member(jsii_name="toListCatalogItems")
    def to_list_catalog_items(self) -> "Outposts":
        '''(experimental) Grants permission to list all catalog items.

        Access Level: List

        https://docs.aws.amazon.com/outposts/latest/APIReference/API_ListCatalogItems.html

        :stability: experimental
        '''
        return typing.cast("Outposts", jsii.invoke(self, "toListCatalogItems", []))

    @jsii.member(jsii_name="toListOrders")
    def to_list_orders(self) -> "Outposts":
        '''(experimental) Grants permission to list the orders for your AWS account.

        Access Level: List

        https://docs.aws.amazon.com/outposts/latest/APIReference/API_ListOrders.html

        :stability: experimental
        '''
        return typing.cast("Outposts", jsii.invoke(self, "toListOrders", []))

    @jsii.member(jsii_name="toListOutposts")
    def to_list_outposts(self) -> "Outposts":
        '''(experimental) Grants permission to list the Outposts for your AWS account.

        Access Level: List

        https://docs.aws.amazon.com/outposts/latest/APIReference/API_ListOutposts.html

        :stability: experimental
        '''
        return typing.cast("Outposts", jsii.invoke(self, "toListOutposts", []))

    @jsii.member(jsii_name="toListSites")
    def to_list_sites(self) -> "Outposts":
        '''(experimental) Grants permission to list the sites for your AWS account.

        Access Level: List

        https://docs.aws.amazon.com/outposts/latest/APIReference/API_ListSites.html

        :stability: experimental
        '''
        return typing.cast("Outposts", jsii.invoke(self, "toListSites", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Outposts":
        '''(experimental) Grants permission to list tags for a resource.

        Access Level: Read

        https://docs.aws.amazon.com/outposts/latest/APIReference/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("Outposts", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toStartConnection")
    def to_start_connection(self) -> "Outposts":
        '''(experimental) Grants permission to start a connection for your Outpost server.

        Access Level: Write

        https://docs.aws.amazon.com/outposts/latest/APIReference/API_StartConnection.html

        :stability: experimental
        '''
        return typing.cast("Outposts", jsii.invoke(self, "toStartConnection", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Outposts":
        '''(experimental) Grants permission to tag a resource.

        Access Level: Tagging

        https://docs.aws.amazon.com/outposts/latest/APIReference/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("Outposts", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Outposts":
        '''(experimental) Grants permission to untag a resource.

        Access Level: Tagging

        https://docs.aws.amazon.com/outposts/latest/APIReference/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("Outposts", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateOutpost")
    def to_update_outpost(self) -> "Outposts":
        '''(experimental) Grants permission to update an Outpost.

        Access Level: Write

        https://docs.aws.amazon.com/outposts/latest/APIReference/API_UpdateOutpost.html

        :stability: experimental
        '''
        return typing.cast("Outposts", jsii.invoke(self, "toUpdateOutpost", []))

    @jsii.member(jsii_name="toUpdateSite")
    def to_update_site(self) -> "Outposts":
        '''(experimental) Grants permission to update a site.

        Access Level: Write

        https://docs.aws.amazon.com/outposts/latest/APIReference/API_UpdateSite.html

        :stability: experimental
        '''
        return typing.cast("Outposts", jsii.invoke(self, "toUpdateSite", []))

    @jsii.member(jsii_name="toUpdateSiteAddress")
    def to_update_site_address(self) -> "Outposts":
        '''(experimental) Grants permission to update the site address.

        Access Level: Write

        https://docs.aws.amazon.com/outposts/latest/APIReference/API_UpdateSiteAddress.html

        :stability: experimental
        '''
        return typing.cast("Outposts", jsii.invoke(self, "toUpdateSiteAddress", []))

    @jsii.member(jsii_name="toUpdateSiteRackPhysicalProperties")
    def to_update_site_rack_physical_properties(self) -> "Outposts":
        '''(experimental) Grants permission to update the physical properties of a rack at a site.

        Access Level: Write

        https://docs.aws.amazon.com/outposts/latest/APIReference/API_UpdateSiteRackPhysicalProperties.html

        :stability: experimental
        '''
        return typing.cast("Outposts", jsii.invoke(self, "toUpdateSiteRackPhysicalProperties", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0fefc6610c93fb836b61bb19bf4d63b7e3505391527bca543bbe33f69f6de159)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4b2aa2a6eeaecf9112477132de856fe5c151024f2af0445073d602acccc7b9c5)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Panorama(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Panorama",
):
    '''(experimental) Statement provider for service `panorama <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awspanorama.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `panorama <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awspanorama.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onApp")
    def on_app(
        self,
        app_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Panorama":
        '''(experimental) Adds a resource of type app to the statement.

        https://docs.aws.amazon.com/panorama/latest/dev/

        :param app_name: - Identifier for the appName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1e53f4b78dfae7a174cd105b4308efb7fa6b1558186511f8d466a6ce16f4359d)
            check_type(argname="argument app_name", value=app_name, expected_type=type_hints["app_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Panorama", jsii.invoke(self, "onApp", [app_name, account, region, partition]))

    @jsii.member(jsii_name="onApplicationInstance")
    def on_application_instance(
        self,
        application_instance_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Panorama":
        '''(experimental) Adds a resource of type applicationInstance to the statement.

        https://docs.aws.amazon.com/panorama/latest/dev/

        :param application_instance_id: - Identifier for the applicationInstanceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4ed00a07e1290990fdf3127020fdb6da6fe39cc9c37220a81837fe6f1dea5234)
            check_type(argname="argument application_instance_id", value=application_instance_id, expected_type=type_hints["application_instance_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Panorama", jsii.invoke(self, "onApplicationInstance", [application_instance_id, account, region, partition]))

    @jsii.member(jsii_name="onAppVersion")
    def on_app_version(
        self,
        app_name: builtins.str,
        app_version: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Panorama":
        '''(experimental) Adds a resource of type appVersion to the statement.

        https://docs.aws.amazon.com/panorama/latest/dev/

        :param app_name: - Identifier for the appName.
        :param app_version: - Identifier for the appVersion.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__cca02018c785ee4d05ac4528f609af39dc5d237257c7ee3b7b5dfd15d9a0ab92)
            check_type(argname="argument app_name", value=app_name, expected_type=type_hints["app_name"])
            check_type(argname="argument app_version", value=app_version, expected_type=type_hints["app_version"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Panorama", jsii.invoke(self, "onAppVersion", [app_name, app_version, account, region, partition]))

    @jsii.member(jsii_name="onDataSource")
    def on_data_source(
        self,
        device_id: builtins.str,
        data_source_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Panorama":
        '''(experimental) Adds a resource of type dataSource to the statement.

        https://docs.aws.amazon.com/panorama/latest/dev/

        :param device_id: - Identifier for the deviceId.
        :param data_source_name: - Identifier for the dataSourceName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__60d7dd56c280aadce8fa09f50f3b8de899ef572dc72b470ca5a98b18de53ee0f)
            check_type(argname="argument device_id", value=device_id, expected_type=type_hints["device_id"])
            check_type(argname="argument data_source_name", value=data_source_name, expected_type=type_hints["data_source_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Panorama", jsii.invoke(self, "onDataSource", [device_id, data_source_name, account, region, partition]))

    @jsii.member(jsii_name="onDevice")
    def on_device(
        self,
        device_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Panorama":
        '''(experimental) Adds a resource of type device to the statement.

        https://docs.aws.amazon.com/panorama/latest/dev/

        :param device_id: - Identifier for the deviceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4e26d2ea02f9300348865fd97d99244264e501ac5ec2af34128a05cea86ee72a)
            check_type(argname="argument device_id", value=device_id, expected_type=type_hints["device_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Panorama", jsii.invoke(self, "onDevice", [device_id, account, region, partition]))

    @jsii.member(jsii_name="onModel")
    def on_model(
        self,
        model_name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Panorama":
        '''(experimental) Adds a resource of type model to the statement.

        https://docs.aws.amazon.com/panorama/latest/dev/

        :param model_name: - Identifier for the modelName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1071b4af180838840eae427fb0d18e78e8bdc994ac1f8caed14806617c7d9776)
            check_type(argname="argument model_name", value=model_name, expected_type=type_hints["model_name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Panorama", jsii.invoke(self, "onModel", [model_name, account, region, partition]))

    @jsii.member(jsii_name="onPackage")
    def on_package(
        self,
        package_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Panorama":
        '''(experimental) Adds a resource of type package to the statement.

        https://docs.aws.amazon.com/panorama/latest/dev/

        :param package_id: - Identifier for the packageId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__99672c6195181e6d0c384bc826b4ef8e3cf2c77833f6fe82fc80d8c2e4382115)
            check_type(argname="argument package_id", value=package_id, expected_type=type_hints["package_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Panorama", jsii.invoke(self, "onPackage", [package_id, account, region, partition]))

    @jsii.member(jsii_name="toCreateApp")
    def to_create_app(self) -> "Panorama":
        '''(experimental) Grants permission to create an AWS Panorama application.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/panorama/latest/dev/API_CreateApp.html

        :stability: experimental
        '''
        return typing.cast("Panorama", jsii.invoke(self, "toCreateApp", []))

    @jsii.member(jsii_name="toCreateAppDeployment")
    def to_create_app_deployment(self) -> "Panorama":
        '''(experimental) Grants permission to deploy an AWS Panorama application.

        Access Level: Write

        https://docs.aws.amazon.com/panorama/latest/dev/API_CreateAppDeployment.html

        :stability: experimental
        '''
        return typing.cast("Panorama", jsii.invoke(self, "toCreateAppDeployment", []))

    @jsii.member(jsii_name="toCreateApplicationInstance")
    def to_create_application_instance(self) -> "Panorama":
        '''(experimental) Grants permission to create an AWS Panorama Application Instance.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/panorama/latest/dev/API_CreateApplicationInstance.html

        :stability: experimental
        '''
        return typing.cast("Panorama", jsii.invoke(self, "toCreateApplicationInstance", []))

    @jsii.member(jsii_name="toCreateAppVersion")
    def to_create_app_version(self) -> "Panorama":
        '''(experimental) Grants permission to create a version of an AWS Panorama application.

        Access Level: Write

        https://docs.aws.amazon.com/panorama/latest/dev/API_CreateAppVersion.html

        :stability: experimental
        '''
        return typing.cast("Panorama", jsii.invoke(self, "toCreateAppVersion", []))

    @jsii.member(jsii_name="toCreateDataSource")
    def to_create_data_source(self) -> "Panorama":
        '''(experimental) Grants permission to create an AWS Panorama datasource.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/panorama/latest/dev/API_CreateDataSource.html

        :stability: experimental
        '''
        return typing.cast("Panorama", jsii.invoke(self, "toCreateDataSource", []))

    @jsii.member(jsii_name="toCreateDeploymentConfiguration")
    def to_create_deployment_configuration(self) -> "Panorama":
        '''(experimental) Grants permission to configure a deployment for an AWS Panorama application.

        Access Level: Write

        https://docs.aws.amazon.com/panorama/latest/dev/API_CreateDeploymentConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Panorama", jsii.invoke(self, "toCreateDeploymentConfiguration", []))

    @jsii.member(jsii_name="toCreateInputs")
    def to_create_inputs(self) -> "Panorama":
        '''(experimental) Grants permission to generate a list of cameras on the same network as an AWS Panorama Appliance.

        Access Level: Write

        https://docs.aws.amazon.com/panorama/latest/dev/API_CreateInputList.html

        :stability: experimental
        '''
        return typing.cast("Panorama", jsii.invoke(self, "toCreateInputs", []))

    @jsii.member(jsii_name="toCreateJobForDevices")
    def to_create_job_for_devices(self) -> "Panorama":
        '''(experimental) Grants permission to create a job for an AWS Panorama Appliance.

        Access Level: Write

        https://docs.aws.amazon.com/panorama/latest/dev/API_CreateJobForDevices.html

        :stability: experimental
        '''
        return typing.cast("Panorama", jsii.invoke(self, "toCreateJobForDevices", []))

    @jsii.member(jsii_name="toCreateModel")
    def to_create_model(self) -> "Panorama":
        '''(experimental) Grants permission to import a machine learning model into AWS Panorama.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/panorama/latest/dev/API_CreateModel.html

        :stability: experimental
        '''
        return typing.cast("Panorama", jsii.invoke(self, "toCreateModel", []))

    @jsii.member(jsii_name="toCreateNodeFromTemplateJob")
    def to_create_node_from_template_job(self) -> "Panorama":
        '''(experimental) Grants permission to create an AWS Panorama Node.

        Access Level: Write

        https://docs.aws.amazon.com/panorama/latest/dev/API_CreateNodeFromTemplateJob.html

        :stability: experimental
        '''
        return typing.cast("Panorama", jsii.invoke(self, "toCreateNodeFromTemplateJob", []))

    @jsii.member(jsii_name="toCreatePackage")
    def to_create_package(self) -> "Panorama":
        '''(experimental) Grants permission to create an AWS Panorama Package.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/panorama/latest/dev/API_CreatePackage.html

        :stability: experimental
        '''
        return typing.cast("Panorama", jsii.invoke(self, "toCreatePackage", []))

    @jsii.member(jsii_name="toCreatePackageImportJob")
    def to_create_package_import_job(self) -> "Panorama":
        '''(experimental) Grants permission to create an AWS Panorama Package.

        Access Level: Write

        https://docs.aws.amazon.com/panorama/latest/dev/API_CreatePackageImportJob.html

        :stability: experimental
        '''
        return typing.cast("Panorama", jsii.invoke(self, "toCreatePackageImportJob", []))

    @jsii.member(jsii_name="toCreateStreams")
    def to_create_streams(self) -> "Panorama":
        '''(experimental) Grants permission to generate a list of streams available to an AWS Panorama Appliance.

        Access Level: Write

        https://docs.aws.amazon.com/panorama/latest/dev/API_CreateStreamsList.html

        :stability: experimental
        '''
        return typing.cast("Panorama", jsii.invoke(self, "toCreateStreams", []))

    @jsii.member(jsii_name="toDeleteApp")
    def to_delete_app(self) -> "Panorama":
        '''(experimental) Grants permission to delete an AWS Panorama application.

        Access Level: Write

        https://docs.aws.amazon.com/panorama/latest/dev/API_DeleteApp.html

        :stability: experimental
        '''
        return typing.cast("Panorama", jsii.invoke(self, "toDeleteApp", []))

    @jsii.member(jsii_name="toDeleteAppVersion")
    def to_delete_app_version(self) -> "Panorama":
        '''(experimental) Grants permission to delete a version of an AWS Panorama application.

        Access Level: Write

        https://docs.aws.amazon.com/panorama/latest/dev/API_DeleteAppVersion.html

        :stability: experimental
        '''
        return typing.cast("Panorama", jsii.invoke(self, "toDeleteAppVersion", []))

    @jsii.member(jsii_name="toDeleteDataSource")
    def to_delete_data_source(self) -> "Panorama":
        '''(experimental) Grants permission to delete an AWS Panorama datasource.

        Access Level: Write

        https://docs.aws.amazon.com/panorama/latest/dev/API_DeleteDataSource.html

        :stability: experimental
        '''
        return typing.cast("Panorama", jsii.invoke(self, "toDeleteDataSource", []))

    @jsii.member(jsii_name="toDeleteDevice")
    def to_delete_device(self) -> "Panorama":
        '''(experimental) Grants permission to deregister an AWS Panorama Appliance.

        Access Level: Write

        https://docs.aws.amazon.com/panorama/latest/dev/API_DeleteDevice.html

        :stability: experimental
        '''
        return typing.cast("Panorama", jsii.invoke(self, "toDeleteDevice", []))

    @jsii.member(jsii_name="toDeleteModel")
    def to_delete_model(self) -> "Panorama":
        '''(experimental) Grants permission to delete a machine learning model from AWS Panorama.

        Access Level: Write

        https://docs.aws.amazon.com/panorama/latest/dev/API_DeleteModel.html

        :stability: experimental
        '''
        return typing.cast("Panorama", jsii.invoke(self, "toDeleteModel", []))

    @jsii.member(jsii_name="toDeletePackage")
    def to_delete_package(self) -> "Panorama":
        '''(experimental) Grants permission to delete an AWS Panorama Package.

        Access Level: Write

        https://docs.aws.amazon.com/panorama/latest/dev/API_DeletePackage.html

        :stability: experimental
        '''
        return typing.cast("Panorama", jsii.invoke(self, "toDeletePackage", []))

    @jsii.member(jsii_name="toDeregisterPackageVersion")
    def to_deregister_package_version(self) -> "Panorama":
        '''(experimental) Grants permission to deregister an AWS Panorama Package Version.

        Access Level: Write

        https://docs.aws.amazon.com/panorama/latest/dev/API_DeregisterPackageVersion.html

        :stability: experimental
        '''
        return typing.cast("Panorama", jsii.invoke(self, "toDeregisterPackageVersion", []))

    @jsii.member(jsii_name="toDescribeApp")
    def to_describe_app(self) -> "Panorama":
        '''(experimental) Grants permission to view details about an AWS Panorama application.

        Access Level: Read

        https://docs.aws.amazon.com/panorama/latest/dev/API_DescribeApp.html

        :stability: experimental
        '''
        return typing.cast("Panorama", jsii.invoke(self, "toDescribeApp", []))

    @jsii.member(jsii_name="toDescribeAppDeployment")
    def to_describe_app_deployment(self) -> "Panorama":
        '''(experimental) Grants permission to view details about a deployment for an AWS Panorama application.

        Access Level: Read

        https://docs.aws.amazon.com/panorama/latest/dev/API_DescribeAppDeployment.html

        :stability: experimental
        '''
        return typing.cast("Panorama", jsii.invoke(self, "toDescribeAppDeployment", []))

    @jsii.member(jsii_name="toDescribeApplicationInstance")
    def to_describe_application_instance(self) -> "Panorama":
        '''(experimental) Grants permission to view details about an AWS Panorama Application Instance.

        Access Level: Read

        https://docs.aws.amazon.com/panorama/latest/dev/API_DescribeApplicationInstance.html

        :stability: experimental
        '''
        return typing.cast("Panorama", jsii.invoke(self, "toDescribeApplicationInstance", []))

    @jsii.member(jsii_name="toDescribeApplicationInstanceDetails")
    def to_describe_application_instance_details(self) -> "Panorama":
        '''(experimental) Grants permission to view details about an AWS Panorama Application Instance.

        Access Level: Read

        https://docs.aws.amazon.com/panorama/latest/dev/API_DescribeApplicationInstanceDetails.html

        :stability: experimental
        '''
        return typing.cast("Panorama", jsii.invoke(self, "toDescribeApplicationInstanceDetails", []))

    @jsii.member(jsii_name="toDescribeAppVersion")
    def to_describe_app_version(self) -> "Panorama":
        '''(experimental) Grants permission to view details about a version of an AWS Panorama application.

        Access Level: Read

        https://docs.aws.amazon.com/panorama/latest/dev/API_DescribeAppVersion.html

        :stability: experimental
        '''
        return typing.cast("Panorama", jsii.invoke(self, "toDescribeAppVersion", []))

    @jsii.member(jsii_name="toDescribeDataSource")
    def to_describe_data_source(self) -> "Panorama":
        '''(experimental) Grants permission to view details about a datasource in AWS Panorama.

        Access Level: Read

        https://docs.aws.amazon.com/panorama/latest/dev/API_DescribeDataSource.html

        :stability: experimental
        '''
        return typing.cast("Panorama", jsii.invoke(self, "toDescribeDataSource", []))

    @jsii.member(jsii_name="toDescribeDevice")
    def to_describe_device(self) -> "Panorama":
        '''(experimental) Grants permission to view details about an AWS Panorama Appliance.

        Access Level: Read

        https://docs.aws.amazon.com/panorama/latest/dev/API_DescribeDevice.html

        :stability: experimental
        '''
        return typing.cast("Panorama", jsii.invoke(self, "toDescribeDevice", []))

    @jsii.member(jsii_name="toDescribeDeviceJob")
    def to_describe_device_job(self) -> "Panorama":
        '''(experimental) Grants permission to view job details for an AWS Panorama Appliance.

        Access Level: Read

        https://docs.aws.amazon.com/panorama/latest/dev/API_DescribeDeviceJob.html

        :stability: experimental
        '''
        return typing.cast("Panorama", jsii.invoke(self, "toDescribeDeviceJob", []))

    @jsii.member(jsii_name="toDescribeModel")
    def to_describe_model(self) -> "Panorama":
        '''(experimental) Grants permission to view details about a machine learning model in AWS Panorama.

        Access Level: Read

        https://docs.aws.amazon.com/panorama/latest/dev/API_DescribeModel.html

        :stability: experimental
        '''
        return typing.cast("Panorama", jsii.invoke(self, "toDescribeModel", []))

    @jsii.member(jsii_name="toDescribeNode")
    def to_describe_node(self) -> "Panorama":
        '''(experimental) Grants permission to view details about an AWS Panorama Node.

        Access Level: Read

        https://docs.aws.amazon.com/panorama/latest/dev/API_DescribeNode.html

        :stability: experimental
        '''
        return typing.cast("Panorama", jsii.invoke(self, "toDescribeNode", []))

    @jsii.member(jsii_name="toDescribeNodeFromTemplateJob")
    def to_describe_node_from_template_job(self) -> "Panorama":
        '''(experimental) Grants permission to view details about AWS Panorama Node.

        Access Level: Read

        https://docs.aws.amazon.com/panorama/latest/dev/API_DescribeNodeFromTemplateJob.html

        :stability: experimental
        '''
        return typing.cast("Panorama", jsii.invoke(self, "toDescribeNodeFromTemplateJob", []))

    @jsii.member(jsii_name="toDescribePackage")
    def to_describe_package(self) -> "Panorama":
        '''(experimental) Grants permission to view details about an AWS Panorama Package.

        Access Level: Read

        https://docs.aws.amazon.com/panorama/latest/dev/API_DescribePackage.html

        :stability: experimental
        '''
        return typing.cast("Panorama", jsii.invoke(self, "toDescribePackage", []))

    @jsii.member(jsii_name="toDescribePackageImportJob")
    def to_describe_package_import_job(self) -> "Panorama":
        '''(experimental) Grants permission to view details about an AWS Panorama Package.

        Access Level: Read

        https://docs.aws.amazon.com/panorama/latest/dev/API_DescribePackageImportJob.html

        :stability: experimental
        '''
        return typing.cast("Panorama", jsii.invoke(self, "toDescribePackageImportJob", []))

    @jsii.member(jsii_name="toDescribePackageVersion")
    def to_describe_package_version(self) -> "Panorama":
        '''(experimental) Grants permission to view details about an AWS Panorama Package Version.

        Access Level: Read

        https://docs.aws.amazon.com/panorama/latest/dev/API_DescribePackageVersion.html

        :stability: experimental
        '''
        return typing.cast("Panorama", jsii.invoke(self, "toDescribePackageVersion", []))

    @jsii.member(jsii_name="toDescribeSoftware")
    def to_describe_software(self) -> "Panorama":
        '''(experimental) Grants permission to view details about a software version for the AWS Panorama Appliance.

        Access Level: Read

        https://docs.aws.amazon.com/panorama/latest/dev/API_DescribeSoftware.html

        :stability: experimental
        '''
        return typing.cast("Panorama", jsii.invoke(self, "toDescribeSoftware", []))

    @jsii.member(jsii_name="toGetDeploymentConfiguration")
    def to_get_deployment_configuration(self) -> "Panorama":
        '''(experimental) Grants permission to view details about a deployment configuration for an AWS Panorama application.

        Access Level: Read

        https://docs.aws.amazon.com/panorama/latest/dev/API_GetDeploymentConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Panorama", jsii.invoke(self, "toGetDeploymentConfiguration", []))

    @jsii.member(jsii_name="toGetInputs")
    def to_get_inputs(self) -> "Panorama":
        '''(experimental) Grants permission to retrieve a list of cameras generated with CreateInputs.

        Access Level: Read

        https://docs.aws.amazon.com/panorama/latest/dev/API_GetInputList.html

        :stability: experimental
        '''
        return typing.cast("Panorama", jsii.invoke(self, "toGetInputs", []))

    @jsii.member(jsii_name="toGetStreams")
    def to_get_streams(self) -> "Panorama":
        '''(experimental) Grants permission to retrieve a list of streams generated with CreateStreams.

        Access Level: Read

        https://docs.aws.amazon.com/panorama/latest/dev/API_GetStreamsList.html

        :stability: experimental
        '''
        return typing.cast("Panorama", jsii.invoke(self, "toGetStreams", []))

    @jsii.member(jsii_name="toGetWebSocketURL")
    def to_get_web_socket_url(self) -> "Panorama":
        '''(experimental) Grants permission to generate a WebSocket endpoint for communication with AWS Panorama.

        Access Level: Read

        https://docs.aws.amazon.com/panorama/latest/dev/API_GetWebSocketURL.html

        :stability: experimental
        '''
        return typing.cast("Panorama", jsii.invoke(self, "toGetWebSocketURL", []))

    @jsii.member(jsii_name="toListAppDeploymentOperations")
    def to_list_app_deployment_operations(self) -> "Panorama":
        '''(experimental) Grants permission to retrieve a list of deployments for an AWS Panorama application.

        Access Level: List

        https://docs.aws.amazon.com/panorama/latest/dev/API_ListAppDeploymentOperations.html

        :stability: experimental
        '''
        return typing.cast("Panorama", jsii.invoke(self, "toListAppDeploymentOperations", []))

    @jsii.member(jsii_name="toListApplicationInstanceDependencies")
    def to_list_application_instance_dependencies(self) -> "Panorama":
        '''(experimental) Grants permission to retrieve a list of application instance dependencies in AWS Panorama.

        Access Level: List

        https://docs.aws.amazon.com/panorama/latest/dev/API_ListApplicationInstanceDependencies.html

        :stability: experimental
        '''
        return typing.cast("Panorama", jsii.invoke(self, "toListApplicationInstanceDependencies", []))

    @jsii.member(jsii_name="toListApplicationInstanceNodeInstances")
    def to_list_application_instance_node_instances(self) -> "Panorama":
        '''(experimental) Grants permission to retrieve a list of node instances of application instances in AWS Panorama.

        Access Level: List

        https://docs.aws.amazon.com/panorama/latest/dev/API_ListApplicationInstanceNodeInstances.html

        :stability: experimental
        '''
        return typing.cast("Panorama", jsii.invoke(self, "toListApplicationInstanceNodeInstances", []))

    @jsii.member(jsii_name="toListApplicationInstances")
    def to_list_application_instances(self) -> "Panorama":
        '''(experimental) Grants permission to retrieve a list of application instances in AWS Panorama.

        Access Level: List

        https://docs.aws.amazon.com/panorama/latest/dev/API_ListApplicationInstances.html

        :stability: experimental
        '''
        return typing.cast("Panorama", jsii.invoke(self, "toListApplicationInstances", []))

    @jsii.member(jsii_name="toListApps")
    def to_list_apps(self) -> "Panorama":
        '''(experimental) Grants permission to retrieve a list of applications in AWS Panorama.

        Access Level: List

        https://docs.aws.amazon.com/panorama/latest/dev/API_ListApps.html

        :stability: experimental
        '''
        return typing.cast("Panorama", jsii.invoke(self, "toListApps", []))

    @jsii.member(jsii_name="toListAppVersions")
    def to_list_app_versions(self) -> "Panorama":
        '''(experimental) Grants permission to retrieve a list of application versions in AWS Panorama.

        Access Level: List

        https://docs.aws.amazon.com/panorama/latest/dev/API_ListAppVersions.html

        :stability: experimental
        '''
        return typing.cast("Panorama", jsii.invoke(self, "toListAppVersions", []))

    @jsii.member(jsii_name="toListDataSources")
    def to_list_data_sources(self) -> "Panorama":
        '''(experimental) Grants permission to retrieve a list of datasources in AWS Panorama.

        Access Level: List

        https://docs.aws.amazon.com/panorama/latest/dev/API_ListDataSources.html

        :stability: experimental
        '''
        return typing.cast("Panorama", jsii.invoke(self, "toListDataSources", []))

    @jsii.member(jsii_name="toListDeploymentConfigurations")
    def to_list_deployment_configurations(self) -> "Panorama":
        '''(experimental) Grants permission to retrieve a list of deployment configurations in AWS Panorama.

        Access Level: List

        https://docs.aws.amazon.com/panorama/latest/dev/API_ListDeploymentConfigurations.html

        :stability: experimental
        '''
        return typing.cast("Panorama", jsii.invoke(self, "toListDeploymentConfigurations", []))

    @jsii.member(jsii_name="toListDevices")
    def to_list_devices(self) -> "Panorama":
        '''(experimental) Grants permission to retrieve a list of appliances in AWS Panorama.

        Access Level: List

        https://docs.aws.amazon.com/panorama/latest/dev/API_ListDevices.html

        :stability: experimental
        '''
        return typing.cast("Panorama", jsii.invoke(self, "toListDevices", []))

    @jsii.member(jsii_name="toListDevicesJobs")
    def to_list_devices_jobs(self) -> "Panorama":
        '''(experimental) Grants permission to retrieve a list of jobs for an AWS Panorama Appliance.

        Access Level: List

        https://docs.aws.amazon.com/panorama/latest/dev/API_ListDevicesJobs.html

        :stability: experimental
        '''
        return typing.cast("Panorama", jsii.invoke(self, "toListDevicesJobs", []))

    @jsii.member(jsii_name="toListModels")
    def to_list_models(self) -> "Panorama":
        '''(experimental) Grants permission to retrieve a list of models in AWS Panorama.

        Access Level: List

        https://docs.aws.amazon.com/panorama/latest/dev/API_ListModels.html

        :stability: experimental
        '''
        return typing.cast("Panorama", jsii.invoke(self, "toListModels", []))

    @jsii.member(jsii_name="toListNodeFromTemplateJobs")
    def to_list_node_from_template_jobs(self) -> "Panorama":
        '''(experimental) Grants permission to retrieve a list of Nodes for an AWS Panorama Appliance.

        Access Level: List

        https://docs.aws.amazon.com/panorama/latest/dev/API_ListNodeFromTemplateJobs.html

        :stability: experimental
        '''
        return typing.cast("Panorama", jsii.invoke(self, "toListNodeFromTemplateJobs", []))

    @jsii.member(jsii_name="toListNodes")
    def to_list_nodes(self) -> "Panorama":
        '''(experimental) Grants permission to retrieve a list of nodes in AWS Panorama.

        Access Level: List

        https://docs.aws.amazon.com/panorama/latest/dev/API_ListNodes.html

        :stability: experimental
        '''
        return typing.cast("Panorama", jsii.invoke(self, "toListNodes", []))

    @jsii.member(jsii_name="toListPackageImportJobs")
    def to_list_package_import_jobs(self) -> "Panorama":
        '''(experimental) Grants permission to retrieve a list of packages in AWS Panorama.

        Access Level: List

        https://docs.aws.amazon.com/panorama/latest/dev/API_ListPackageImportJobs.html

        :stability: experimental
        '''
        return typing.cast("Panorama", jsii.invoke(self, "toListPackageImportJobs", []))

    @jsii.member(jsii_name="toListPackages")
    def to_list_packages(self) -> "Panorama":
        '''(experimental) Grants permission to retrieve a list of packages in AWS Panorama.

        Access Level: List

        https://docs.aws.amazon.com/panorama/latest/dev/API_ListPackages.html

        :stability: experimental
        '''
        return typing.cast("Panorama", jsii.invoke(self, "toListPackages", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Panorama":
        '''(experimental) Grants permission to retrieve a list of tags for a resource in AWS Panorama.

        Access Level: Read

        https://docs.aws.amazon.com/panorama/latest/dev/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("Panorama", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toProvisionDevice")
    def to_provision_device(self) -> "Panorama":
        '''(experimental) Grants permission to register an AWS Panorama Appliance.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/panorama/latest/dev/API_ProvisionDevice.html

        :stability: experimental
        '''
        return typing.cast("Panorama", jsii.invoke(self, "toProvisionDevice", []))

    @jsii.member(jsii_name="toRegisterPackageVersion")
    def to_register_package_version(self) -> "Panorama":
        '''(experimental) Grants permission to register an AWS Panorama Package Version.

        Access Level: Write

        https://docs.aws.amazon.com/panorama/latest/dev/API_RegisterPackageVersion.html

        :stability: experimental
        '''
        return typing.cast("Panorama", jsii.invoke(self, "toRegisterPackageVersion", []))

    @jsii.member(jsii_name="toRemoveApplicationInstance")
    def to_remove_application_instance(self) -> "Panorama":
        '''(experimental) Grants permission to remove an AWS Panorama Application Instance.

        Access Level: Write

        https://docs.aws.amazon.com/panorama/latest/dev/API_RemoveApplicationInstance.html

        :stability: experimental
        '''
        return typing.cast("Panorama", jsii.invoke(self, "toRemoveApplicationInstance", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Panorama":
        '''(experimental) Grants permission to add tags to a resource in AWS Panorama.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/panorama/latest/dev/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("Panorama", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Panorama":
        '''(experimental) Grants permission to remove tags from a resource in AWS Panorama.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/panorama/latest/dev/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("Panorama", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateApp")
    def to_update_app(self) -> "Panorama":
        '''(experimental) Grants permission to modify an AWS Panorama application.

        Access Level: Write

        https://docs.aws.amazon.com/panorama/latest/dev/API_UpdateApp.html

        :stability: experimental
        '''
        return typing.cast("Panorama", jsii.invoke(self, "toUpdateApp", []))

    @jsii.member(jsii_name="toUpdateAppConfiguration")
    def to_update_app_configuration(self) -> "Panorama":
        '''(experimental) Grants permission to modify the version-specific configuration of an AWS Panorama application.

        Access Level: Write

        https://docs.aws.amazon.com/panorama/latest/dev/API_UpdateAppConfiguration.html

        :stability: experimental
        '''
        return typing.cast("Panorama", jsii.invoke(self, "toUpdateAppConfiguration", []))

    @jsii.member(jsii_name="toUpdateDataSource")
    def to_update_data_source(self) -> "Panorama":
        '''(experimental) Grants permission to modify an AWS Panorama datasource.

        Access Level: Write

        https://docs.aws.amazon.com/panorama/latest/dev/API_UpdateDataSource.html

        :stability: experimental
        '''
        return typing.cast("Panorama", jsii.invoke(self, "toUpdateDataSource", []))

    @jsii.member(jsii_name="toUpdateDeviceMetadata")
    def to_update_device_metadata(self) -> "Panorama":
        '''(experimental) Grants permission to modify basic settings for an AWS Panorama Appliance.

        Access Level: Write

        https://docs.aws.amazon.com/panorama/latest/dev/API_UpdateDeviceMetadata.html

        :stability: experimental
        '''
        return typing.cast("Panorama", jsii.invoke(self, "toUpdateDeviceMetadata", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4522c891183f320c41c27dfdde01a81aa0333822c16e23dd9ce5b38d0eb43bcf)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4a87e75b02dcb8c04e172e22e854e507f92bdf3aa46dd0ea6112e6dd15dc6d44)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Personalize(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Personalize",
):
    '''(experimental) Statement provider for service `personalize <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonpersonalize.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `personalize <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonpersonalize.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onAlgorithm")
    def on_algorithm(
        self,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Personalize":
        '''(experimental) Adds a resource of type algorithm to the statement.

        https://docs.aws.amazon.com/personalize/latest/dg/API_Algorithm.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__abca39c02caa0db7ae8194d407c6250195ee4e3ed8835b94af0e98c7eb4b93ce)
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Personalize", jsii.invoke(self, "onAlgorithm", [resource_id, account, region, partition]))

    @jsii.member(jsii_name="onBatchInferenceJob")
    def on_batch_inference_job(
        self,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Personalize":
        '''(experimental) Adds a resource of type batchInferenceJob to the statement.

        https://docs.aws.amazon.com/personalize/latest/dg/API_BatchInferenceJob.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c238a5dc24ba9bf93b27d14d8b4b0dcb249c295c1fee6f9acac2e631c20e1de8)
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Personalize", jsii.invoke(self, "onBatchInferenceJob", [resource_id, account, region, partition]))

    @jsii.member(jsii_name="onBatchSegmentJob")
    def on_batch_segment_job(
        self,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Personalize":
        '''(experimental) Adds a resource of type batchSegmentJob to the statement.

        https://docs.aws.amazon.com/personalize/latest/dg/API_BatchSegmentJob.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__44657f6979da485a29001eadb2c31012e21a2cd3120fbd467fda195b26b2abb9)
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Personalize", jsii.invoke(self, "onBatchSegmentJob", [resource_id, account, region, partition]))

    @jsii.member(jsii_name="onCampaign")
    def on_campaign(
        self,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Personalize":
        '''(experimental) Adds a resource of type campaign to the statement.

        https://docs.aws.amazon.com/personalize/latest/dg/API_Campaign.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0f15307ac719216a36b8e4b8a0b74f21584c52402a505f2604fe5236dfc9c50c)
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Personalize", jsii.invoke(self, "onCampaign", [resource_id, account, region, partition]))

    @jsii.member(jsii_name="onDataset")
    def on_dataset(
        self,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Personalize":
        '''(experimental) Adds a resource of type dataset to the statement.

        https://docs.aws.amazon.com/personalize/latest/dg/API_Dataset.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__aba684460debdcd292f1ffe56e2dbf49adbf5373b3f64dbf6527ccc8b7848fae)
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Personalize", jsii.invoke(self, "onDataset", [resource_id, account, region, partition]))

    @jsii.member(jsii_name="onDatasetExportJob")
    def on_dataset_export_job(
        self,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Personalize":
        '''(experimental) Adds a resource of type datasetExportJob to the statement.

        https://docs.aws.amazon.com/personalize/latest/dg/API_DatasetExportJob.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d6eb24957ac99942e113a117c92ea2ecd9c29c2aa838a375671e94e428bf43cf)
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Personalize", jsii.invoke(self, "onDatasetExportJob", [resource_id, account, region, partition]))

    @jsii.member(jsii_name="onDatasetGroup")
    def on_dataset_group(
        self,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Personalize":
        '''(experimental) Adds a resource of type datasetGroup to the statement.

        https://docs.aws.amazon.com/personalize/latest/dg/API_DatasetGroup.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6266421a88ba941ddc8bc21844cc0e75469c1fc640d9bcd60587e049c1194174)
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Personalize", jsii.invoke(self, "onDatasetGroup", [resource_id, account, region, partition]))

    @jsii.member(jsii_name="onDatasetImportJob")
    def on_dataset_import_job(
        self,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Personalize":
        '''(experimental) Adds a resource of type datasetImportJob to the statement.

        https://docs.aws.amazon.com/personalize/latest/dg/API_DatasetImportJob.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d63971716964c0adfe94bd375bc5ae7415b2f66b4b3a12567b59220bbd6e967e)
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Personalize", jsii.invoke(self, "onDatasetImportJob", [resource_id, account, region, partition]))

    @jsii.member(jsii_name="onEventTracker")
    def on_event_tracker(
        self,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Personalize":
        '''(experimental) Adds a resource of type eventTracker to the statement.

        https://docs.aws.amazon.com/personalize/latest/dg/API_EventTracker.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b2a688515b7fc285d7d899dbb648ebc763e01c3d13f35b70347e515b6c745718)
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Personalize", jsii.invoke(self, "onEventTracker", [resource_id, account, region, partition]))

    @jsii.member(jsii_name="onFeatureTransformation")
    def on_feature_transformation(
        self,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Personalize":
        '''(experimental) Adds a resource of type featureTransformation to the statement.

        https://docs.aws.amazon.com/personalize/latest/dg/API_FeatureTransformation.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fbe51e274d7c67d719a70f08bc95048fac6be4a1368b45a7d7abaa9e5338e19a)
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Personalize", jsii.invoke(self, "onFeatureTransformation", [resource_id, account, region, partition]))

    @jsii.member(jsii_name="onFilter")
    def on_filter(
        self,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Personalize":
        '''(experimental) Adds a resource of type filter to the statement.

        https://docs.aws.amazon.com/personalize/latest/dg/API_Filter.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4b07aeca62c1e485072a8a09ef428a5521a85d8c1ec4a790afd11647c3745704)
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Personalize", jsii.invoke(self, "onFilter", [resource_id, account, region, partition]))

    @jsii.member(jsii_name="onRecipe")
    def on_recipe(
        self,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Personalize":
        '''(experimental) Adds a resource of type recipe to the statement.

        https://docs.aws.amazon.com/personalize/latest/dg/API_Recipe.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2ee3261bec7e446341fa6e3f4969f2b89747c845e75fc918e36a31fb802bdf70)
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Personalize", jsii.invoke(self, "onRecipe", [resource_id, account, region, partition]))

    @jsii.member(jsii_name="onRecommender")
    def on_recommender(
        self,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Personalize":
        '''(experimental) Adds a resource of type recommender to the statement.

        https://docs.aws.amazon.com/personalize/latest/dg/API_Recommender.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6beb104cf919cb798a1274ee7da3b3bcec35ea4774070cd208e985dfd265c934)
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Personalize", jsii.invoke(self, "onRecommender", [resource_id, account, region, partition]))

    @jsii.member(jsii_name="onSchema")
    def on_schema(
        self,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Personalize":
        '''(experimental) Adds a resource of type schema to the statement.

        https://docs.aws.amazon.com/personalize/latest/dg/how-it-works-dataset-schema.html#schema-examples

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__153e363485e98f40274512fa8781e2660dfdf1badad9c3d14068f1fbb3e0d360)
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Personalize", jsii.invoke(self, "onSchema", [resource_id, account, region, partition]))

    @jsii.member(jsii_name="onSolution")
    def on_solution(
        self,
        resource_id: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Personalize":
        '''(experimental) Adds a resource of type solution to the statement.

        https://docs.aws.amazon.com/personalize/latest/dg/API_Solution.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__06dd8623f9a78e85340c614815369ef184e798a31e070b028335c0d9b34e6712)
            check_type(argname="argument resource_id", value=resource_id, expected_type=type_hints["resource_id"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Personalize", jsii.invoke(self, "onSolution", [resource_id, account, region, partition]))

    @jsii.member(jsii_name="toCreateBatchInferenceJob")
    def to_create_batch_inference_job(self) -> "Personalize":
        '''(experimental) Grants permission to create a batch inference job.

        Access Level: Write

        https://docs.aws.amazon.com/personalize/latest/dg/API_CreateBatchInferenceJob.html

        :stability: experimental
        '''
        return typing.cast("Personalize", jsii.invoke(self, "toCreateBatchInferenceJob", []))

    @jsii.member(jsii_name="toCreateBatchSegmentJob")
    def to_create_batch_segment_job(self) -> "Personalize":
        '''(experimental) Grants permission to create a batch segment job.

        Access Level: Write

        https://docs.aws.amazon.com/personalize/latest/dg/API_CreateBatchSegmentJob.html

        :stability: experimental
        '''
        return typing.cast("Personalize", jsii.invoke(self, "toCreateBatchSegmentJob", []))

    @jsii.member(jsii_name="toCreateCampaign")
    def to_create_campaign(self) -> "Personalize":
        '''(experimental) Grants permission to create a campaign.

        Access Level: Write

        https://docs.aws.amazon.com/personalize/latest/dg/API_CreateCampaign.html

        :stability: experimental
        '''
        return typing.cast("Personalize", jsii.invoke(self, "toCreateCampaign", []))

    @jsii.member(jsii_name="toCreateDataset")
    def to_create_dataset(self) -> "Personalize":
        '''(experimental) Grants permission to create a dataset.

        Access Level: Write

        https://docs.aws.amazon.com/personalize/latest/dg/API_CreateDataset.html

        :stability: experimental
        '''
        return typing.cast("Personalize", jsii.invoke(self, "toCreateDataset", []))

    @jsii.member(jsii_name="toCreateDatasetExportJob")
    def to_create_dataset_export_job(self) -> "Personalize":
        '''(experimental) Grants permission to create a dataset export job.

        Access Level: Write

        https://docs.aws.amazon.com/personalize/latest/dg/API_CreateDatasetExportJob.html

        :stability: experimental
        '''
        return typing.cast("Personalize", jsii.invoke(self, "toCreateDatasetExportJob", []))

    @jsii.member(jsii_name="toCreateDatasetGroup")
    def to_create_dataset_group(self) -> "Personalize":
        '''(experimental) Grants permission to create a dataset group.

        Access Level: Write

        https://docs.aws.amazon.com/personalize/latest/dg/API_CreateDatasetGroup.html

        :stability: experimental
        '''
        return typing.cast("Personalize", jsii.invoke(self, "toCreateDatasetGroup", []))

    @jsii.member(jsii_name="toCreateDatasetImportJob")
    def to_create_dataset_import_job(self) -> "Personalize":
        '''(experimental) Grants permission to create a dataset import job.

        Access Level: Write

        https://docs.aws.amazon.com/personalize/latest/dg/API_CreateDatasetImportJob.html

        :stability: experimental
        '''
        return typing.cast("Personalize", jsii.invoke(self, "toCreateDatasetImportJob", []))

    @jsii.member(jsii_name="toCreateEventTracker")
    def to_create_event_tracker(self) -> "Personalize":
        '''(experimental) Grants permission to create an event tracker.

        Access Level: Write

        https://docs.aws.amazon.com/personalize/latest/dg/API_CreateEventTracker.html

        :stability: experimental
        '''
        return typing.cast("Personalize", jsii.invoke(self, "toCreateEventTracker", []))

    @jsii.member(jsii_name="toCreateFilter")
    def to_create_filter(self) -> "Personalize":
        '''(experimental) Grants permission to create a filter.

        Access Level: Write

        https://docs.aws.amazon.com/personalize/latest/dg/API_CreateFilter.html

        :stability: experimental
        '''
        return typing.cast("Personalize", jsii.invoke(self, "toCreateFilter", []))

    @jsii.member(jsii_name="toCreateRecommender")
    def to_create_recommender(self) -> "Personalize":
        '''(experimental) Grants permission to create a recommender.

        Access Level: Write

        https://docs.aws.amazon.com/personalize/latest/dg/API_CreateRecommender.html

        :stability: experimental
        '''
        return typing.cast("Personalize", jsii.invoke(self, "toCreateRecommender", []))

    @jsii.member(jsii_name="toCreateSchema")
    def to_create_schema(self) -> "Personalize":
        '''(experimental) Grants permission to create a schema.

        Access Level: Write

        https://docs.aws.amazon.com/personalize/latest/dg/API_CreateSchema.html

        :stability: experimental
        '''
        return typing.cast("Personalize", jsii.invoke(self, "toCreateSchema", []))

    @jsii.member(jsii_name="toCreateSolution")
    def to_create_solution(self) -> "Personalize":
        '''(experimental) Grants permission to create a solution.

        Access Level: Write

        https://docs.aws.amazon.com/personalize/latest/dg/API_CreateSolution.html

        :stability: experimental
        '''
        return typing.cast("Personalize", jsii.invoke(self, "toCreateSolution", []))

    @jsii.member(jsii_name="toCreateSolutionVersion")
    def to_create_solution_version(self) -> "Personalize":
        '''(experimental) Grants permission to create a solution version.

        Access Level: Write

        https://docs.aws.amazon.com/personalize/latest/dg/API_CreateSolutionVersion.html

        :stability: experimental
        '''
        return typing.cast("Personalize", jsii.invoke(self, "toCreateSolutionVersion", []))

    @jsii.member(jsii_name="toDeleteCampaign")
    def to_delete_campaign(self) -> "Personalize":
        '''(experimental) Grants permission to delete a campaign.

        Access Level: Write

        https://docs.aws.amazon.com/personalize/latest/dg/API_DeleteCampaign.html

        :stability: experimental
        '''
        return typing.cast("Personalize", jsii.invoke(self, "toDeleteCampaign", []))

    @jsii.member(jsii_name="toDeleteDataset")
    def to_delete_dataset(self) -> "Personalize":
        '''(experimental) Grants permission to delete a dataset.

        Access Level: Write

        https://docs.aws.amazon.com/personalize/latest/dg/API_DeleteDataset.html

        :stability: experimental
        '''
        return typing.cast("Personalize", jsii.invoke(self, "toDeleteDataset", []))

    @jsii.member(jsii_name="toDeleteDatasetGroup")
    def to_delete_dataset_group(self) -> "Personalize":
        '''(experimental) Grants permission to delete a dataset group.

        Access Level: Write

        https://docs.aws.amazon.com/personalize/latest/dg/API_DeleteDatasetGroup.html

        :stability: experimental
        '''
        return typing.cast("Personalize", jsii.invoke(self, "toDeleteDatasetGroup", []))

    @jsii.member(jsii_name="toDeleteEventTracker")
    def to_delete_event_tracker(self) -> "Personalize":
        '''(experimental) Grants permission to delete an event tracker.

        Access Level: Write

        https://docs.aws.amazon.com/personalize/latest/dg/API_DeleteEventTracker.html

        :stability: experimental
        '''
        return typing.cast("Personalize", jsii.invoke(self, "toDeleteEventTracker", []))

    @jsii.member(jsii_name="toDeleteFilter")
    def to_delete_filter(self) -> "Personalize":
        '''(experimental) Grants permission to delete a filter.

        Access Level: Write

        https://docs.aws.amazon.com/personalize/latest/dg/API_DeleteFilter.html

        :stability: experimental
        '''
        return typing.cast("Personalize", jsii.invoke(self, "toDeleteFilter", []))

    @jsii.member(jsii_name="toDeleteRecommender")
    def to_delete_recommender(self) -> "Personalize":
        '''(experimental) Grants permission to delete a recommender.

        Access Level: Write

        https://docs.aws.amazon.com/personalize/latest/dg/API_DeleteRecommender.html

        :stability: experimental
        '''
        return typing.cast("Personalize", jsii.invoke(self, "toDeleteRecommender", []))

    @jsii.member(jsii_name="toDeleteSchema")
    def to_delete_schema(self) -> "Personalize":
        '''(experimental) Grants permission to delete a schema.

        Access Level: Write

        https://docs.aws.amazon.com/personalize/latest/dg/API_DeleteSchema.html

        :stability: experimental
        '''
        return typing.cast("Personalize", jsii.invoke(self, "toDeleteSchema", []))

    @jsii.member(jsii_name="toDeleteSolution")
    def to_delete_solution(self) -> "Personalize":
        '''(experimental) Grants permission to delete a solution including all versions of the solution.

        Access Level: Write

        https://docs.aws.amazon.com/personalize/latest/dg/API_DeleteSolution.html

        :stability: experimental
        '''
        return typing.cast("Personalize", jsii.invoke(self, "toDeleteSolution", []))

    @jsii.member(jsii_name="toDescribeAlgorithm")
    def to_describe_algorithm(self) -> "Personalize":
        '''(experimental) Grants permission to describe an algorithm.

        Access Level: Read

        https://docs.aws.amazon.com/personalize/latest/dg/API_DescribeAlgorithm.html

        :stability: experimental
        '''
        return typing.cast("Personalize", jsii.invoke(self, "toDescribeAlgorithm", []))

    @jsii.member(jsii_name="toDescribeBatchInferenceJob")
    def to_describe_batch_inference_job(self) -> "Personalize":
        '''(experimental) Grants permission to describe a batch inference job.

        Access Level: Read

        https://docs.aws.amazon.com/personalize/latest/dg/API_DescribeBatchInferenceJob.html

        :stability: experimental
        '''
        return typing.cast("Personalize", jsii.invoke(self, "toDescribeBatchInferenceJob", []))

    @jsii.member(jsii_name="toDescribeBatchSegmentJob")
    def to_describe_batch_segment_job(self) -> "Personalize":
        '''(experimental) Grants permission to describe a batch segment job.

        Access Level: Read

        https://docs.aws.amazon.com/personalize/latest/dg/API_DescribeBatchSegmentJob.html

        :stability: experimental
        '''
        return typing.cast("Personalize", jsii.invoke(self, "toDescribeBatchSegmentJob", []))

    @jsii.member(jsii_name="toDescribeCampaign")
    def to_describe_campaign(self) -> "Personalize":
        '''(experimental) Grants permission to describe a campaign.

        Access Level: Read

        https://docs.aws.amazon.com/personalize/latest/dg/API_DescribeCampaign.html

        :stability: experimental
        '''
        return typing.cast("Personalize", jsii.invoke(self, "toDescribeCampaign", []))

    @jsii.member(jsii_name="toDescribeDataset")
    def to_describe_dataset(self) -> "Personalize":
        '''(experimental) Grants permission to describe a dataset.

        Access Level: Read

        https://docs.aws.amazon.com/personalize/latest/dg/API_DescribeDataset.html

        :stability: experimental
        '''
        return typing.cast("Personalize", jsii.invoke(self, "toDescribeDataset", []))

    @jsii.member(jsii_name="toDescribeDatasetExportJob")
    def to_describe_dataset_export_job(self) -> "Personalize":
        '''(experimental) Grants permission to describe a dataset export job.

        Access Level: Read

        https://docs.aws.amazon.com/personalize/latest/dg/API_DescribeDatasetExportJob.html

        :stability: experimental
        '''
        return typing.cast("Personalize", jsii.invoke(self, "toDescribeDatasetExportJob", []))

    @jsii.member(jsii_name="toDescribeDatasetGroup")
    def to_describe_dataset_group(self) -> "Personalize":
        '''(experimental) Grants permission to describe a dataset group.

        Access Level: Read

        https://docs.aws.amazon.com/personalize/latest/dg/API_DescribeDatasetGroup.html

        :stability: experimental
        '''
        return typing.cast("Personalize", jsii.invoke(self, "toDescribeDatasetGroup", []))

    @jsii.member(jsii_name="toDescribeDatasetImportJob")
    def to_describe_dataset_import_job(self) -> "Personalize":
        '''(experimental) Grants permission to describe a dataset import job.

        Access Level: Read

        https://docs.aws.amazon.com/personalize/latest/dg/API_DescribeDatasetImportJob.html

        :stability: experimental
        '''
        return typing.cast("Personalize", jsii.invoke(self, "toDescribeDatasetImportJob", []))

    @jsii.member(jsii_name="toDescribeEventTracker")
    def to_describe_event_tracker(self) -> "Personalize":
        '''(experimental) Grants permission to describe an event tracker.

        Access Level: Read

        https://docs.aws.amazon.com/personalize/latest/dg/API_DescribeEventTracker.html

        :stability: experimental
        '''
        return typing.cast("Personalize", jsii.invoke(self, "toDescribeEventTracker", []))

    @jsii.member(jsii_name="toDescribeFeatureTransformation")
    def to_describe_feature_transformation(self) -> "Personalize":
        '''(experimental) Grants permission to describe a feature transformation.

        Access Level: Read

        https://docs.aws.amazon.com/personalize/latest/dg/API_DescribeFeatureTransformation.html

        :stability: experimental
        '''
        return typing.cast("Personalize", jsii.invoke(self, "toDescribeFeatureTransformation", []))

    @jsii.member(jsii_name="toDescribeFilter")
    def to_describe_filter(self) -> "Personalize":
        '''(experimental) Grants permission to describe a filter.

        Access Level: Read

        https://docs.aws.amazon.com/personalize/latest/dg/API_DescribeFilter.html

        :stability: experimental
        '''
        return typing.cast("Personalize", jsii.invoke(self, "toDescribeFilter", []))

    @jsii.member(jsii_name="toDescribeRecipe")
    def to_describe_recipe(self) -> "Personalize":
        '''(experimental) Grants permission to describe a recipe.

        Access Level: Read

        https://docs.aws.amazon.com/personalize/latest/dg/API_DescribeRecipe.html

        :stability: experimental
        '''
        return typing.cast("Personalize", jsii.invoke(self, "toDescribeRecipe", []))

    @jsii.member(jsii_name="toDescribeRecommender")
    def to_describe_recommender(self) -> "Personalize":
        '''(experimental) Grants permission to describe a recommender.

        Access Level: Read

        https://docs.aws.amazon.com/personalize/latest/dg/API_DescribeRecommender.html

        :stability: experimental
        '''
        return typing.cast("Personalize", jsii.invoke(self, "toDescribeRecommender", []))

    @jsii.member(jsii_name="toDescribeSchema")
    def to_describe_schema(self) -> "Personalize":
        '''(experimental) Grants permission to describe a schema.

        Access Level: Read

        https://docs.aws.amazon.com/personalize/latest/dg/API_DescribeSchema.html

        :stability: experimental
        '''
        return typing.cast("Personalize", jsii.invoke(self, "toDescribeSchema", []))

    @jsii.member(jsii_name="toDescribeSolution")
    def to_describe_solution(self) -> "Personalize":
        '''(experimental) Grants permission to describe a solution.

        Access Level: Read

        https://docs.aws.amazon.com/personalize/latest/dg/API_DescribeSolution.html

        :stability: experimental
        '''
        return typing.cast("Personalize", jsii.invoke(self, "toDescribeSolution", []))

    @jsii.member(jsii_name="toDescribeSolutionVersion")
    def to_describe_solution_version(self) -> "Personalize":
        '''(experimental) Grants permission to describe a version of a solution.

        Access Level: Read

        https://docs.aws.amazon.com/personalize/latest/dg/API_DescribeSolutionVersion.html

        :stability: experimental
        '''
        return typing.cast("Personalize", jsii.invoke(self, "toDescribeSolutionVersion", []))

    @jsii.member(jsii_name="toGetPersonalizedRanking")
    def to_get_personalized_ranking(self) -> "Personalize":
        '''(experimental) Grants permission to get a re-ranked list of recommendations.

        Access Level: Read

        https://docs.aws.amazon.com/personalize/latest/dg/API_RS_GetPersonalizedRanking.html

        :stability: experimental
        '''
        return typing.cast("Personalize", jsii.invoke(self, "toGetPersonalizedRanking", []))

    @jsii.member(jsii_name="toGetRecommendations")
    def to_get_recommendations(self) -> "Personalize":
        '''(experimental) Grants permission to get a list of recommendations from a campaign.

        Access Level: Read

        https://docs.aws.amazon.com/personalize/latest/dg/API_RS_GetRecommendations.html

        :stability: experimental
        '''
        return typing.cast("Personalize", jsii.invoke(self, "toGetRecommendations", []))

    @jsii.member(jsii_name="toGetSolutionMetrics")
    def to_get_solution_metrics(self) -> "Personalize":
        '''(experimental) Grants permission to get metrics for a solution version.

        Access Level: Read

        https://docs.aws.amazon.com/personalize/latest/dg/API_GetSolutionMetrics.html

        :stability: experimental
        '''
        return typing.cast("Personalize", jsii.invoke(self, "toGetSolutionMetrics", []))

    @jsii.member(jsii_name="toListBatchInferenceJobs")
    def to_list_batch_inference_jobs(self) -> "Personalize":
        '''(experimental) Grants permission to list batch inference jobs.

        Access Level: List

        https://docs.aws.amazon.com/personalize/latest/dg/API_ListBatchInferenceJobs.html

        :stability: experimental
        '''
        return typing.cast("Personalize", jsii.invoke(self, "toListBatchInferenceJobs", []))

    @jsii.member(jsii_name="toListBatchSegmentJobs")
    def to_list_batch_segment_jobs(self) -> "Personalize":
        '''(experimental) Grants permission to list batch segment jobs.

        Access Level: List

        https://docs.aws.amazon.com/personalize/latest/dg/API_ListBatchSegmentJobs.html

        :stability: experimental
        '''
        return typing.cast("Personalize", jsii.invoke(self, "toListBatchSegmentJobs", []))

    @jsii.member(jsii_name="toListCampaigns")
    def to_list_campaigns(self) -> "Personalize":
        '''(experimental) Grants permission to list campaigns.

        Access Level: List

        https://docs.aws.amazon.com/personalize/latest/dg/API_ListCampaigns.html

        :stability: experimental
        '''
        return typing.cast("Personalize", jsii.invoke(self, "toListCampaigns", []))

    @jsii.member(jsii_name="toListDatasetExportJobs")
    def to_list_dataset_export_jobs(self) -> "Personalize":
        '''(experimental) Grants permission to list dataset export jobs.

        Access Level: List

        https://docs.aws.amazon.com/personalize/latest/dg/API_ListDatasetExportJobs.html

        :stability: experimental
        '''
        return typing.cast("Personalize", jsii.invoke(self, "toListDatasetExportJobs", []))

    @jsii.member(jsii_name="toListDatasetGroups")
    def to_list_dataset_groups(self) -> "Personalize":
        '''(experimental) Grants permission to list dataset groups.

        Access Level: List

        https://docs.aws.amazon.com/personalize/latest/dg/API_ListDatasetGroups.html

        :stability: experimental
        '''
        return typing.cast("Personalize", jsii.invoke(self, "toListDatasetGroups", []))

    @jsii.member(jsii_name="toListDatasetImportJobs")
    def to_list_dataset_import_jobs(self) -> "Personalize":
        '''(experimental) Grants permission to list dataset import jobs.

        Access Level: List

        https://docs.aws.amazon.com/personalize/latest/dg/API_ListDatasetImportJobs.html

        :stability: experimental
        '''
        return typing.cast("Personalize", jsii.invoke(self, "toListDatasetImportJobs", []))

    @jsii.member(jsii_name="toListDatasets")
    def to_list_datasets(self) -> "Personalize":
        '''(experimental) Grants permission to list datasets.

        Access Level: List

        https://docs.aws.amazon.com/personalize/latest/dg/API_ListDatasets.html

        :stability: experimental
        '''
        return typing.cast("Personalize", jsii.invoke(self, "toListDatasets", []))

    @jsii.member(jsii_name="toListEventTrackers")
    def to_list_event_trackers(self) -> "Personalize":
        '''(experimental) Grants permission to list event trackers.

        Access Level: List

        https://docs.aws.amazon.com/personalize/latest/dg/API_ListEventTrackers.html

        :stability: experimental
        '''
        return typing.cast("Personalize", jsii.invoke(self, "toListEventTrackers", []))

    @jsii.member(jsii_name="toListFilters")
    def to_list_filters(self) -> "Personalize":
        '''(experimental) Grants permission to list filters.

        Access Level: List

        https://docs.aws.amazon.com/personalize/latest/dg/API_ListFilters.html

        :stability: experimental
        '''
        return typing.cast("Personalize", jsii.invoke(self, "toListFilters", []))

    @jsii.member(jsii_name="toListRecipes")
    def to_list_recipes(self) -> "Personalize":
        '''(experimental) Grants permission to list recipes.

        Access Level: List

        https://docs.aws.amazon.com/personalize/latest/dg/API_ListRecipes.html

        :stability: experimental
        '''
        return typing.cast("Personalize", jsii.invoke(self, "toListRecipes", []))

    @jsii.member(jsii_name="toListRecommenders")
    def to_list_recommenders(self) -> "Personalize":
        '''(experimental) Grants permission to list recommenders.

        Access Level: List

        https://docs.aws.amazon.com/personalize/latest/dg/API_ListRecommenders.html

        :stability: experimental
        '''
        return typing.cast("Personalize", jsii.invoke(self, "toListRecommenders", []))

    @jsii.member(jsii_name="toListSchemas")
    def to_list_schemas(self) -> "Personalize":
        '''(experimental) Grants permission to list schemas.

        Access Level: List

        https://docs.aws.amazon.com/personalize/latest/dg/API_ListSchemas.html

        :stability: experimental
        '''
        return typing.cast("Personalize", jsii.invoke(self, "toListSchemas", []))

    @jsii.member(jsii_name="toListSolutions")
    def to_list_solutions(self) -> "Personalize":
        '''(experimental) Grants permission to list solutions.

        Access Level: List

        https://docs.aws.amazon.com/personalize/latest/dg/API_ListSolutions.html

        :stability: experimental
        '''
        return typing.cast("Personalize", jsii.invoke(self, "toListSolutions", []))

    @jsii.member(jsii_name="toListSolutionVersions")
    def to_list_solution_versions(self) -> "Personalize":
        '''(experimental) Grants permission to list versions of a solution.

        Access Level: List

        https://docs.aws.amazon.com/personalize/latest/dg/API_ListSolutionVersions.html

        :stability: experimental
        '''
        return typing.cast("Personalize", jsii.invoke(self, "toListSolutionVersions", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Personalize":
        '''(experimental) Grants permission to list tags for a resource.

        Access Level: List

        https://docs.aws.amazon.com/personalize/latest/dg/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("Personalize", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toPutEvents")
    def to_put_events(self) -> "Personalize":
        '''(experimental) Grants permission to put real time event data.

        Access Level: Write

        https://docs.aws.amazon.com/personalize/latest/dg/API_UBS_PutEvents.html

        :stability: experimental
        '''
        return typing.cast("Personalize", jsii.invoke(self, "toPutEvents", []))

    @jsii.member(jsii_name="toPutItems")
    def to_put_items(self) -> "Personalize":
        '''(experimental) Grants permission to ingest Items data.

        Access Level: Write

        https://docs.aws.amazon.com/personalize/latest/dg/API_UBS_PutItems.html

        :stability: experimental
        '''
        return typing.cast("Personalize", jsii.invoke(self, "toPutItems", []))

    @jsii.member(jsii_name="toPutUsers")
    def to_put_users(self) -> "Personalize":
        '''(experimental) Grants permission to ingest Users data.

        Access Level: Write

        https://docs.aws.amazon.com/personalize/latest/dg/API_UBS_PutUsers.html

        :stability: experimental
        '''
        return typing.cast("Personalize", jsii.invoke(self, "toPutUsers", []))

    @jsii.member(jsii_name="toStartRecommender")
    def to_start_recommender(self) -> "Personalize":
        '''(experimental) Grants permission to start a recommender.

        Access Level: Write

        https://docs.aws.amazon.com/personalize/latest/dg/API_StartRecommender.html

        :stability: experimental
        '''
        return typing.cast("Personalize", jsii.invoke(self, "toStartRecommender", []))

    @jsii.member(jsii_name="toStopRecommender")
    def to_stop_recommender(self) -> "Personalize":
        '''(experimental) Grants permission to stop a recommender.

        Access Level: Write

        https://docs.aws.amazon.com/personalize/latest/dg/API_StopRecommender.html

        :stability: experimental
        '''
        return typing.cast("Personalize", jsii.invoke(self, "toStopRecommender", []))

    @jsii.member(jsii_name="toStopSolutionVersionCreation")
    def to_stop_solution_version_creation(self) -> "Personalize":
        '''(experimental) Grants permission to stop a solution version creation.

        Access Level: Write

        https://docs.aws.amazon.com/personalize/latest/dg/API_StopSolutionVersionCreation.html

        :stability: experimental
        '''
        return typing.cast("Personalize", jsii.invoke(self, "toStopSolutionVersionCreation", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Personalize":
        '''(experimental) Grants permission to tag a resource.

        Access Level: Tagging

        https://docs.aws.amazon.com/personalize/latest/dg/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("Personalize", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Personalize":
        '''(experimental) Grants permission to untag a resource.

        Access Level: Tagging

        https://docs.aws.amazon.com/personalize/latest/dg/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("Personalize", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdateCampaign")
    def to_update_campaign(self) -> "Personalize":
        '''(experimental) Grants permission to update a campaign.

        Access Level: Write

        https://docs.aws.amazon.com/personalize/latest/dg/API_UpdateCampaign.html

        :stability: experimental
        '''
        return typing.cast("Personalize", jsii.invoke(self, "toUpdateCampaign", []))

    @jsii.member(jsii_name="toUpdateRecommender")
    def to_update_recommender(self) -> "Personalize":
        '''(experimental) Grants permission to update a recommender.

        Access Level: Write

        https://docs.aws.amazon.com/personalize/latest/dg/API_UpdateRecommender.html

        :stability: experimental
        '''
        return typing.cast("Personalize", jsii.invoke(self, "toUpdateRecommender", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3d8c5e88f78402e13b3fba4533ff03f36329bd353802005dafee1ea4048359f8)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e11ca457d912b8ff90407d6cbc53adb549aa21eda542c70df4dc8fc6ce86cdd8)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Pi(PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Pi"):
    '''(experimental) Statement provider for service `pi <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsperformanceinsights.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `pi <https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsperformanceinsights.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onMetricResource")
    def on_metric_resource(
        self,
        service_type: builtins.str,
        identifier: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Pi":
        '''(experimental) Adds a resource of type metric-resource to the statement.

        https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/USER_PerfInsights.access-control.html

        :param service_type: - Identifier for the serviceType.
        :param identifier: - Identifier for the identifier.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition.

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4766e6a4578c95570f67448f46037ff0ec67d6fdf3e198e74aab6f96add2f4e5)
            check_type(argname="argument service_type", value=service_type, expected_type=type_hints["service_type"])
            check_type(argname="argument identifier", value=identifier, expected_type=type_hints["identifier"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Pi", jsii.invoke(self, "onMetricResource", [service_type, identifier, account, region, partition]))

    @jsii.member(jsii_name="toDescribeDimensionKeys")
    def to_describe_dimension_keys(self) -> "Pi":
        '''(experimental) Grants permission to call DescribeDimensionKeys API to retrieve the top N dimension keys for a metric for a specific time period.

        Access Level: Read

        https://docs.aws.amazon.com/performance-insights/latest/APIReference/API_DescribeDimensionKeys.html

        :stability: experimental
        '''
        return typing.cast("Pi", jsii.invoke(self, "toDescribeDimensionKeys", []))

    @jsii.member(jsii_name="toGetDimensionKeyDetails")
    def to_get_dimension_key_details(self) -> "Pi":
        '''(experimental) Grants permission to call GetDimensionKeyDetails API to retrieve the attributes of the specified dimension group.

        Access Level: Read

        https://docs.aws.amazon.com/performance-insights/latest/APIReference/API_GetDimensionKeyDetails.html

        :stability: experimental
        '''
        return typing.cast("Pi", jsii.invoke(self, "toGetDimensionKeyDetails", []))

    @jsii.member(jsii_name="toGetResourceMetadata")
    def to_get_resource_metadata(self) -> "Pi":
        '''(experimental) Grants permission to call GetResourceMetadata API to retrieve the metadata for different features.

        Access Level: Read

        https://docs.aws.amazon.com/performance-insights/latest/APIReference/API_GetResourceMetadata.html

        :stability: experimental
        '''
        return typing.cast("Pi", jsii.invoke(self, "toGetResourceMetadata", []))

    @jsii.member(jsii_name="toGetResourceMetrics")
    def to_get_resource_metrics(self) -> "Pi":
        '''(experimental) Grants permission to call GetResourceMetrics API to retrieve PI metrics for a set of data sources, over a time period.

        Access Level: Read

        https://docs.aws.amazon.com/performance-insights/latest/APIReference/API_GetResourceMetrics.html

        :stability: experimental
        '''
        return typing.cast("Pi", jsii.invoke(self, "toGetResourceMetrics", []))

    @jsii.member(jsii_name="toListAvailableResourceDimensions")
    def to_list_available_resource_dimensions(self) -> "Pi":
        '''(experimental) Grants permission to call ListAvailableResourceDimensions API to retrieve the dimensions that can be queried for each specified metric type on a specified DB instance.

        Access Level: Read

        https://docs.aws.amazon.com/performance-insights/latest/APIReference/API_ListAvailableResourceDimensions.html

        :stability: experimental
        '''
        return typing.cast("Pi", jsii.invoke(self, "toListAvailableResourceDimensions", []))

    @jsii.member(jsii_name="toListAvailableResourceMetrics")
    def to_list_available_resource_metrics(self) -> "Pi":
        '''(experimental) Grants permission to call ListAvailableResourceMetrics API to retrieve metrics of the specified types that can be queried for a specified DB instance.

        Access Level: Read

        https://docs.aws.amazon.com/performance-insights/latest/APIReference/API_ListAvailableResourceMetrics.html

        :stability: experimental
        '''
        return typing.cast("Pi", jsii.invoke(self, "toListAvailableResourceMetrics", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e43a2b9fb79db8178ef8146c220f665ee6ac0e14c613d8a765bb4b218fa33acb)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__189f9659caef6ade76ef3bd363313ee1eead3d42f9d7b2c3038599708bb391ee)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


class Pipes(PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Pipes"):
    '''(experimental) Statement provider for service `pipes <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazoneventbridgepipes.html>`_.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        conditions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        effect: typing.Optional[_aws_cdk_aws_iam_ceddda9d.Effect] = None,
        not_actions: typing.Optional[typing.Sequence[builtins.str]] = None,
        not_principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        not_resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        principals: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IPrincipal]] = None,
        resources: typing.Optional[typing.Sequence[builtins.str]] = None,
        sid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Statement provider for service `pipes <https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazoneventbridgepipes.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        :stability: experimental
        '''
        props = _aws_cdk_aws_iam_ceddda9d.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="onPipe")
    def on_pipe(
        self,
        name: builtins.str,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        partition: typing.Optional[builtins.str] = None,
    ) -> "Pipes":
        '''(experimental) Adds a resource of type pipe to the statement.

        https://docs.aws.amazon.com/eventbridge/latest/userguide/eb-pipes.html

        :param name: - Identifier for the name.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``, unless using the CDK, where the default is the current Stack's partition. Possible conditions: - .ifAwsResourceTag()

        :stability: experimental
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__dc08115323eb54c655be417618607833e168711de671fb7c8607ee7e72f77ff6)
            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
            check_type(argname="argument partition", value=partition, expected_type=type_hints["partition"])
        return typing.cast("Pipes", jsii.invoke(self, "onPipe", [name, account, region, partition]))

    @jsii.member(jsii_name="toCreatePipe")
    def to_create_pipe(self) -> "Pipes":
        '''(experimental) Grants permission to create a pipe.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsResourceTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - iam:PassRole

        https://docs.aws.amazon.com/eventbridge/latest/pipes-reference/API_CreatePipe.html

        :stability: experimental
        '''
        return typing.cast("Pipes", jsii.invoke(self, "toCreatePipe", []))

    @jsii.member(jsii_name="toDeletePipe")
    def to_delete_pipe(self) -> "Pipes":
        '''(experimental) Grants permission to delete a pipe.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/eventbridge/latest/pipes-reference/API_DeletePipe.html

        :stability: experimental
        '''
        return typing.cast("Pipes", jsii.invoke(self, "toDeletePipe", []))

    @jsii.member(jsii_name="toDescribePipe")
    def to_describe_pipe(self) -> "Pipes":
        '''(experimental) Grants permission to describe a pipe.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/eventbridge/latest/pipes-reference/API_DescribePipe.html

        :stability: experimental
        '''
        return typing.cast("Pipes", jsii.invoke(self, "toDescribePipe", []))

    @jsii.member(jsii_name="toListPipes")
    def to_list_pipes(self) -> "Pipes":
        '''(experimental) Grants permission to list all pipes in your account.

        Access Level: List

        https://docs.aws.amazon.com/eventbridge/latest/pipes-reference/API_ListPipes.html

        :stability: experimental
        '''
        return typing.cast("Pipes", jsii.invoke(self, "toListPipes", []))

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Pipes":
        '''(experimental) Grants permission to list the tags for a resource.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/eventbridge/latest/pipes-reference/API_ListTagsForResource.html

        :stability: experimental
        '''
        return typing.cast("Pipes", jsii.invoke(self, "toListTagsForResource", []))

    @jsii.member(jsii_name="toStartPipe")
    def to_start_pipe(self) -> "Pipes":
        '''(experimental) Grants permission to start a pipe.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/eventbridge/latest/pipes-reference/API_StartPipe.html

        :stability: experimental
        '''
        return typing.cast("Pipes", jsii.invoke(self, "toStartPipe", []))

    @jsii.member(jsii_name="toStopPipe")
    def to_stop_pipe(self) -> "Pipes":
        '''(experimental) Grants permission to stop a pipe.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/eventbridge/latest/pipes-reference/API_StopPipe.html

        :stability: experimental
        '''
        return typing.cast("Pipes", jsii.invoke(self, "toStopPipe", []))

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Pipes":
        '''(experimental) Grants permission to add tags to a resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsResourceTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/eventbridge/latest/pipes-reference/API_TagResource.html

        :stability: experimental
        '''
        return typing.cast("Pipes", jsii.invoke(self, "toTagResource", []))

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Pipes":
        '''(experimental) Grants permission to remove tags from a resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsResourceTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/eventbridge/latest/pipes-reference/API_UntagResource.html

        :stability: experimental
        '''
        return typing.cast("Pipes", jsii.invoke(self, "toUntagResource", []))

    @jsii.member(jsii_name="toUpdatePipe")
    def to_update_pipe(self) -> "Pipes":
        '''(experimental) Grants permission to update a pipe.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        Dependent actions:

        - iam:PassRole

        https://docs.aws.amazon.com/eventbridge/latest/pipes-reference/API_UpdatePipe.html

        :stability: experimental
        '''
        return typing.cast("Pipes", jsii.invoke(self, "toUpdatePipe", []))

    @builtins.property
    @jsii.member(jsii_name="accessLevelList")
    def _access_level_list(self) -> AccessLevelList:
        '''
        :stability: experimental
        '''
        return typing.cast(AccessLevelList, jsii.get(self, "accessLevelList"))

    @_access_level_list.setter
    def _access_level_list(self, value: AccessLevelList) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ed3b08734e0d4273778155f5fbdf9772dd9358fe864e420bdbbd7ace33c0a29a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "accessLevelList", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> builtins.str:
        '''(experimental) Holds the prefix of the service actions, e.g. ``ec2``.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "servicePrefix"))

    @service_prefix.setter
    def service_prefix(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ffa892c746d7d95e11c74491c2a20fce98d2da3c8444887af17af74466015986)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "servicePrefix", value)


__all__ = [
    "A2c",
    "A4b",
    "AccessAnalyzer",
    "AccessLevelList",
    "Account",
    "Acm",
    "AcmPca",
    "Activate",
    "Airflow",
    "All",
    "Amplify",
    "Amplifybackend",
    "Amplifyuibuilder",
    "Aoss",
    "Apigateway",
    "ApigatewayV2",
    "AppIntegrations",
    "Appconfig",
    "Appflow",
    "ApplicationAutoscaling",
    "ApplicationCostProfiler",
    "Applicationinsights",
    "Appmesh",
    "AppmeshPreview",
    "Apprunner",
    "Appstream",
    "Appsync",
    "Aps",
    "ArcZonalShift",
    "Arsenal",
    "Artifact",
    "Athena",
    "Auditmanager",
    "Autoscaling",
    "AutoscalingPlans",
    "AwsCloudControlApi",
    "AwsMarketplace",
    "AwsMarketplaceCatalog",
    "AwsMarketplaceEntitlementService",
    "AwsMarketplaceImageBuildingService",
    "AwsMarketplaceManagement",
    "AwsMarketplaceMeteringService",
    "AwsMarketplacePrivate",
    "AwsMarketplaceProcurementSystemsIntegration",
    "AwsMarketplaceSellerReporting",
    "AwsPortal",
    "Awsconnector",
    "Backup",
    "BackupGateway",
    "BackupStorage",
    "Batch",
    "Billing",
    "Billingconductor",
    "Braket",
    "Budgets",
    "Bugbust",
    "Cases",
    "Cassandra",
    "Ce",
    "Chatbot",
    "Chime",
    "Cloud9",
    "Clouddirectory",
    "Cloudformation",
    "Cloudfront",
    "Cloudhsm",
    "Cloudsearch",
    "Cloudshell",
    "Cloudtrail",
    "Cloudwatch",
    "Codeartifact",
    "Codebuild",
    "Codecommit",
    "Codedeploy",
    "CodedeployCommandsSecure",
    "Codeguru",
    "CodeguruProfiler",
    "CodeguruReviewer",
    "Codepipeline",
    "Codestar",
    "CodestarConnections",
    "CodestarNotifications",
    "Codewhisperer",
    "CognitoIdentity",
    "CognitoIdp",
    "CognitoSync",
    "Collection",
    "Comprehend",
    "Comprehendmedical",
    "ComputeOptimizer",
    "Conditions",
    "Config",
    "Connect",
    "ConnectCampaigns",
    "Controltower",
    "Cur",
    "Databrew",
    "Dataexchange",
    "Datapipeline",
    "Datasync",
    "Dax",
    "Dbqms",
    "Deepcomposer",
    "Deeplens",
    "Deepracer",
    "Detective",
    "Devicefarm",
    "DevopsGuru",
    "Directconnect",
    "Discovery",
    "Dlm",
    "Dms",
    "DocdbElastic",
    "Drs",
    "Ds",
    "Dynamodb",
    "Ebs",
    "Ec2",
    "Ec2InstanceConnect",
    "Ec2messages",
    "Ecr",
    "EcrPublic",
    "Ecs",
    "Eks",
    "ElasticInference",
    "Elasticache",
    "Elasticbeanstalk",
    "Elasticfilesystem",
    "Elasticloadbalancing",
    "ElasticloadbalancingV2",
    "Elasticmapreduce",
    "Elastictranscoder",
    "ElementalActivations",
    "ElementalAppliancesSoftware",
    "ElementalSupportCases",
    "ElementalSupportContent",
    "EmrContainers",
    "EmrServerless",
    "Es",
    "Events",
    "Evidently",
    "ExecuteApi",
    "Finspace",
    "Firehose",
    "Fis",
    "Fms",
    "Forecast",
    "Frauddetector",
    "Freertos",
    "Fsx",
    "Gamelift",
    "Gamesparks",
    "Geo",
    "Glacier",
    "Globalaccelerator",
    "Glue",
    "Grafana",
    "Greengrass",
    "GreengrassV2",
    "Groundstation",
    "Groundtruthlabeling",
    "Guardduty",
    "Health",
    "Healthlake",
    "Honeycode",
    "Iam",
    "IdentitySync",
    "Identitystore",
    "IdentitystoreAuth",
    "Imagebuilder",
    "Importexport",
    "Inspector",
    "Inspector2",
    "Internetmonitor",
    "Iot",
    "Iot1click",
    "IotDeviceTester",
    "Iotanalytics",
    "Iotdeviceadvisor",
    "Iotevents",
    "Iotfleethub",
    "Iotfleetwise",
    "Iotjobsdata",
    "Iotroborunner",
    "Iotsitewise",
    "Iottwinmaker",
    "Iotwireless",
    "Iq",
    "IqPermission",
    "Ivs",
    "Ivschat",
    "Kafka",
    "KafkaCluster",
    "Kafkaconnect",
    "Kendra",
    "Kinesis",
    "Kinesisanalytics",
    "KinesisanalyticsV2",
    "Kinesisvideo",
    "Kms",
    "Lakeformation",
    "Lambda",
    "Launchwizard",
    "Lex",
    "LexV2",
    "LicenseManager",
    "LicenseManagerLinuxSubscriptions",
    "LicenseManagerUserSubscriptions",
    "Lightsail",
    "Logs",
    "Lookoutequipment",
    "Lookoutmetrics",
    "Lookoutvision",
    "M2",
    "Machinelearning",
    "Macie2",
    "Managedblockchain",
    "Marketplacecommerceanalytics",
    "Mechanicalturk",
    "Mediaconnect",
    "Mediaconvert",
    "Mediaimport",
    "Medialive",
    "Mediapackage",
    "MediapackageVod",
    "Mediastore",
    "Mediatailor",
    "Memorydb",
    "Mgh",
    "Mgn",
    "MigrationhubOrchestrator",
    "MigrationhubStrategy",
    "Mobileanalytics",
    "Mobilehub",
    "Mobiletargeting",
    "Monitron",
    "Mq",
    "NeptuneDb",
    "NetworkFirewall",
    "Networkmanager",
    "Nimble",
    "Oam",
    "Omics",
    "Operator",
    "Opsworks",
    "OpsworksCm",
    "Organizations",
    "Outposts",
    "Panorama",
    "Personalize",
    "Pi",
    "Pipes",
    "PolicyStatement",
    "PolicyStatementBase",
    "PolicyStatementWithActions",
    "PolicyStatementWithCDKPrincipal",
    "PolicyStatementWithCondition",
    "PolicyStatementWithEffect",
    "PolicyStatementWithPrincipal",
    "PolicyStatementWithResources",
    "Polly",
    "Pricing",
    "Principals",
    "PrivateNetworks",
    "Profile",
    "Proton",
    "PurchaseOrders",
    "Qldb",
    "Quicksight",
    "Ram",
    "Rbin",
    "Rds",
    "RdsData",
    "RdsDb",
    "Redshift",
    "RedshiftData",
    "RedshiftServerless",
    "RefactorSpaces",
    "Rekognition",
    "Resiliencehub",
    "ResourceExplorer",
    "ResourceExplorer2",
    "ResourceGroups",
    "ResourceTypes",
    "Rhelkb",
    "Robomaker",
    "Rolesanywhere",
    "Route53",
    "Route53RecoveryCluster",
    "Route53RecoveryControlConfig",
    "Route53RecoveryReadiness",
    "Route53domains",
    "Route53resolver",
    "Rum",
    "S3",
    "S3ObjectLambda",
    "S3Outposts",
    "Sagemaker",
    "SagemakerGeospatial",
    "SagemakerGroundtruthSynthetic",
    "Savingsplans",
    "Scheduler",
    "Schemas",
    "Sdb",
    "Secretsmanager",
    "Securityhub",
    "Securitylake",
    "Serverlessrepo",
    "Servicecatalog",
    "Servicediscovery",
    "Serviceextract",
    "Servicequotas",
    "Ses",
    "SesPinpoint",
    "SesV2",
    "Shield",
    "Signer",
    "Simspaceweaver",
    "Sms",
    "SmsVoice",
    "SmsVoiceV2",
    "SnowDeviceManagement",
    "Snowball",
    "Sns",
    "Sqlworkbench",
    "Sqs",
    "Ssm",
    "SsmContacts",
    "SsmGuiconnect",
    "SsmIncidents",
    "SsmSap",
    "Ssmmessages",
    "Sso",
    "SsoDirectory",
    "States",
    "Storagegateway",
    "Sts",
    "Sumerian",
    "Support",
    "Supportapp",
    "Supportplans",
    "Sustainability",
    "Swf",
    "Synthetics",
    "Tag",
    "Tax",
    "Textract",
    "Timestream",
    "Tiros",
    "Transcribe",
    "Transfer",
    "Translate",
    "Trustedadvisor",
    "VendorInsights",
    "Voiceid",
    "VpcLattice",
    "VpcLatticeSvcs",
    "Waf",
    "WafRegional",
    "Wafv2",
    "Wam",
    "Wellarchitected",
    "Wickr",
    "Wisdom",
    "Workdocs",
    "Worklink",
    "Workmail",
    "Workmailmessageflow",
    "Workspaces",
    "WorkspacesWeb",
    "Xray",
]

publication.publish()

def _typecheckingstub__579949f48c7b4f1c10967e9f3b640d8e6ca1a9fd1e941f1920563b132e0996b6(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4acac607a06bf55f5c43e877cfca00295ffcc1e9945c156974d01171dcb2db3d(
    key: builtins.str,
    value: typing.Any,
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e10b52e16dcfac79efc9ea923d674c81ffd2dabec0e7822c586ca8f8f9de7896(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__77a3d31809a5ad76d6f10fc028393f2e65dc80e4c2be672bf46f7f7e9dd7a674(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__91893d077bf626c48feb45612371bcb5407e81ef25b37d109f8ce87e79e95d7c(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6938b62e6c8390e9ada92580158b4619670cd8f303c244d8887ad623658f5646(
    value: typing.Union[builtins.str, datetime.datetime, typing.Sequence[typing.Union[builtins.str, datetime.datetime]]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5e336602a5b626c2dfa6e0b085d1e72345a583c6a8b2164c968a014a9511da50(
    value: typing.Union[builtins.str, jsii.Number, datetime.datetime, typing.Sequence[typing.Union[builtins.str, jsii.Number, datetime.datetime]]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__71739ebf855c9fadf72a940b00213ac4581e5309b2045f79cda3f40a4fa80df0(
    value: typing.Union[jsii.Number, typing.Sequence[jsii.Number]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__abda858b8dd2b0e6c9adf876576eed0b720a4c9c2f6dea69727206b80396936a(
    value: typing.Optional[builtins.bool] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e4de3fd3e2a1957285db40def17a862d61d311316e98a72c4ef86192b5488b51(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__545ee3520b072cf7617ddaece58cf66cf06cd058b5cd7f63ed950d865bccf21f(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f2a13889bc1e8659e6e30524bfcba2b883970377bf5c420d76fd0856c03d2fd3(
    value: typing.Optional[builtins.bool] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bbcb97bb3d386c1d9e1d5557052e4f49372985dd0397c74431d35d706bf57668(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7a1a3d666a5661c5fa9395378496d8c3b6d977982e97fd2c935e2ef07eacc814(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c7b8f923048816d47ebceb8d4338ca96d7a82661eff87edc6e8963e6f28bda7c(
    value: builtins.str,
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5119b5010474e05d588b96102c39a318ca8515112eec50b3cd9906d9807e2a02(
    value: typing.Sequence[builtins.str],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a3dd9dfa4ff3b13e2ad35f4eb3ab4ec96b2ba8e5256e9ec5df9b0ddb6b8e2200(
    key: builtins.str,
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c6adf16796fa9edee7366bce0c01aa700f2b3e1847204e40f074fdf651a1fb1f(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c252618b1d8c3ba69e31759bc4792eec37911a633871e1d2370c0d757afba984(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fd80f1e59171cdaef4e7a050252718eeaf45802d248593d168b4013f07fd1baa(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4ce7be33b6db69996ee0536555f56937e600dcef3d37890a1c9dc331155f098e(
    key: builtins.str,
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__77574925161ac75d69e4783281751d06ead48182e52515e21c934b117a2ce4c3(
    key: builtins.str,
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__26c2d255a4532cdf69c90e71a07b59e34532a6499449e90b967406350ff36709(
    value: typing.Optional[builtins.bool] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f405148df33289680f21ae809ea41cb3d1af04fa48caf4ff026f1d07353af40f(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__da13e0098396083cf25f2bf190ea6f5f5f9c8f7ce3e1a89069b0e95c7fd186c9(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__19e1f1ea56b9049f0c9d51b8b2abec0dc02e9c124237b27f5b83631e481bc21c(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__149e746a4a92c4008590bf34380ff8846e67bfde3493e9aabdd14607cd2c778f(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2813df0980c3415210198c2b2c6ed7e075b4b4314165d7d618eb0711433a752b(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__935566b2d494943945611d0a7eb7d62f40ef4638d78e4a63029abb0e0934e500(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b6b5b81ccf9fc0cc775c13aa86d12a487c6115ad2c1c8d05ce07d17ed125027f(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f3df45da6adf87ea8cab5f09ed2fa144df7e42fabaaab2da35db5d4ee665bf2c(
    value: typing.Union[builtins.str, datetime.datetime],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5325d219d3e0d2b37eb851625320a8e810a9acf8d01a892beba99c9dfa3bcefe(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dee3b7f069b307fc3df14ca752871945fdf57dbba451be0238d9560a10ba6fca(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__34f8d87031b10108d53094ddbe0c4b69bf79a3960b0a2d847ba1175a4bb6e52e(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__51e9c642e90e85a28ee4c84d88d46808c309d9c0f81d52921cfe3fece838f2f9(
    value: typing.Optional[builtins.bool] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f7123410883271971ad6aa7d7444820711a6ec350c757f2676a9bda361623dc5(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bd17871dd5791c2ddfc16aed89364d3cd00a3b40b5bc8f1d1622bea99c46c1ef(
    value: Conditions,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1cf6892a5b291a682363a39fda717f045e02342ae3e6d11a6e8db52747e40eb8(
    *expressions: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b285e0c40b17308307de63582a74aa529a455e1abee436409cd8cf824a35cfdd(
    action: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2e49c83c92d9689b52d2f1c44053ab77a2a7c5db7494e866d4758bbd8954bb86(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__deaf43b85fb80cc5908ce05c802c528383e9410b7d5b836be0bf73b3177014e4(
    value: typing.List[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0d2a094e0565cff64c6bc666f411d297277df95721cab1ad6d9d3d3b3878ff1f(
    *arns: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a7b6f6b41926dae8edb1e42a14801d7dfd79995f20e0390d82ad0d37ca96a4ee(
    value: typing.List[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3aa2cab3468e7acbf0579765ddbb7e70f0c36ee6ac053982c0c5471e125d7cc8(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f07540633ebc00771025b4ccdaa1d1f2a71623c7328202ed91842e3d49650dd6(
    prefix: builtins.str,
    principal: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2d34e335619e76f101d439fe9e03e55873ed39985dfc982abd84c2cb508dccf5(
    arn: builtins.str,
    prefix: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__45021adb9aba562bfefdec8af51014b59ad66b5d9d2ea65d5ad8e46359ff2cd3(
    *accounts: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a35284fda156068cc6bc491abd471ea5fba7e5ca17e747622a5631b526d00c4f(
    account: builtins.str,
    role_name: builtins.str,
    *session_names: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__940296438549c30700e0baa1596d21c76e9d72291ccd4f12d8a055f2ce91487b(
    *user_i_ds: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__07ac586aa94a2f6759cc8628a4311b4ccaf53e4f2d761612edc82da58758ecb0(
    *providers: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a3af9f5cf3ca7932bf24eedcbaa45512468b6cbb659afa8ad3a1b1ff3123c191(
    account: builtins.str,
    *roles: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2ab734231ff0665034afd1112a3d4873c6a222b9be4f552b8fb3d1361546b4ad(
    account: builtins.str,
    *provider_names: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__46df73c4fb1b40827b40b23ef188546ea0f42ae4a945c4aa12b5e2e62d854876(
    *services: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b6ddff4cbd8aa1d1bd88c62e23b8671eda3733f0ce372dd3a758d8e88a62e169(
    account: builtins.str,
    *users: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__58c30ebc2e9971817b228909d84ebb56798115985acb807e216605b8c4951a6c(
    value: Principals,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__648b2dfe516763983ec490a8d19d34a236e6606570ad2647f35ae64bd40bc2e8(
    value: builtins.bool,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__90f4f9111d9a2e9f78495bd2be4f9ac3204df45cb40f6eb6d821a21162ee0483(
    *principals: _aws_cdk_aws_iam_ceddda9d.IPrincipal,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3b0d59f37f904814af1adedf568162488cb245bdf6b646df1f95bb25074366c8(
    value: typing.List[_aws_cdk_aws_iam_ceddda9d.IPrincipal],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2b0819564f88353b107e8e38ff4a9097def3907ac2b649507cad8e7ad2b0ec53(
    lexicon_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9b0754818c413e5991f91abbf5876f668bdda0fe78a3434ab79005824dd1c322(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8ebc8e7db5b232faa2f9578339525878a162cb37e687d6bd67813c55cc827bb8(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__579219d1f1d7d3c04df3616f51b8a737dd785e2d387227384042694192969225(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1b8d8acc144f5df3506445322472a5b983c289e3c8fc01a6252ac76866b16c3e(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c78495541eba8ce3f162863520d8556ea6297727ed59a9165602e310e6f3996d(
    network_name: builtins.str,
    device_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b8988d6e372bf98d5f59f13149c9d73f7c2a1f378c25780175d7a2ac11c557e6(
    network_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c601c443fde2b826ef47e6e42b92bf978ff4cc6b09e354731b177d3562afc1b8(
    network_name: builtins.str,
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bd74a71f107e2bdb9c47322903123b40009621685b5e5e9218eaa814f1c9f6c9(
    network_name: builtins.str,
    network_site_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__87f423fa11d621ef5e282c21fb22e43f063ed9f7450e1b0270299bdfceb11567(
    network_name: builtins.str,
    order_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c2d0cf42c184a7600601eb968b7bef294c9c217f4a73e70c4c39ee21679a38f1(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3db20039c24b1fca0e617652c99a59363725ec80f33c416d68061f47a77e2e30(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a2b1f199d6547ed3dafa4f7705c841822ccec77c8adb17fc93e8295e4e0ead02(
    domain_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1913581cf99ed8d12e80c4fba16ba6e642a456e3601b0b5d1d2669e62091cf2a(
    domain_name: builtins.str,
    uri: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6df7788c5fe51db7a446c135e4d724112636a7017669bd996e3e6f493d1deb7f(
    domain_name: builtins.str,
    object_type_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2dd1139bc8aad0fb1281254d9465dbc85c428d2c7b9dd8e5d7b47b4c0733ab22(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e0e8f7cded78b5fbc9a2dd172d00c9aeab9e06ba28a4d4846aab0148395a789f(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2bc9285af8b9aa13d6fdf1c34fdf665b54005c730da65437334b7a1b843bd20e(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ea8a40ac549e481caf71d50c7fe20129aa38492f3340750665b44188e8003c94(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ac48f004ce74c4e213acb5b8c1aa544f6dc1bc0b47ec33e4a45cc761f1329699(
    id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c747f08251a7fa27085e31386122e7934a07c09c714495732d1e0cf076f8d232(
    name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__70a9b8ec9135fd0b5caca910079cad0e13419770b4bb0be274078fb0be575319(
    id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dbd0c2b60e79fc1ca75d46486fdd12e2994b79ef7cc05748820b764db0637c83(
    name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6545ec5b0ee2859985a7c9469635b72041924871a04bcce4b782fc253b6ce27c(
    template_name: builtins.str,
    major_version_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__37d6a6285ef1c28c32c98c087d2c5caafd0459b60ca6d7b6ccf4dae2d55ddee4(
    template_name: builtins.str,
    major_version_id: builtins.str,
    minor_version_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e73ce180fb6471ed013317b8402491634d48a378167b9ee45651ca6f340865da(
    template_name: builtins.str,
    major_version: builtins.str,
    minor_version: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2c7f37bbef0c789ca7218f6b5979db3c6151e853f853a076b35b7e2d433efa10(
    provider: builtins.str,
    name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f24eb7d5d6d9b2df44ca8f9e7fd7a837ad383c93e3019f3a344377deb41f6240(
    name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fe741a27570e60fb05460171f7696967e4925abbf3a29b46ef9b8a0b8dd80ab0(
    service_name: builtins.str,
    name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ffd69e8ba1e5acdbf19cd5ee4454845bb48c9fbdbab24c854019e5e8ada9a5c8(
    name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__68e56a77582bf90c342b558e1f4bd7084abd407d41bf6289be5066daab3bcb7a(
    template_name: builtins.str,
    major_version_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7645969471d50d60fade3029686d2f7475352b37b21faef8890d885614ffd691(
    template_name: builtins.str,
    major_version_id: builtins.str,
    minor_version_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__445ca55f3243cde309fee2aad41b5fcdae53b340c6cc0ed496667bfbca4b0925(
    template_name: builtins.str,
    major_version: builtins.str,
    minor_version: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cee18e641232e7242cd266c124c69a563052934095d9d502db588c2b0e028536(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__47a6aaa6185f89c9e9cb0bb6459b12bafa5974a90396d074394c3d40581a094f(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3e3d436024cfbd35405a5a8df265a65629876a0414e29d6d27540b97fcf3cd74(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5b41b89765dd8d0efa87eb8aaa217d06dc70601dadd5e37000420d9dbfd00acb(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__25fc78ee73c9b42f748c66e1e161a9637861df2dc4aa4c3ab949f0d42e33b240(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__131223977953c8d9e91e0ef0a4d361c675ed0322fb616c8df32835ac536595de(
    ledger_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7f63c4c848438da1f9887d2d1805f43bd2b43c74b433b269e4c5492f159b125b(
    ledger_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a8acc269f9427058d34add18281ce78396044b76b37a40877580898a1b448468(
    ledger_name: builtins.str,
    stream_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5259b62eba77b89955d9ce76169264bc8b8c1e4e6c21850e6e09d9d2ce18d476(
    ledger_name: builtins.str,
    table_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1ccef00513824a3c4df9fee296ec0531a8913d4672e252f393b64f84ecccad05(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__69240f7fd8d6b079163a836df6b28f9efd9ddec0305e06ac9a20171e28f33627(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5e0c710756e3bf2b1ca44eb6d7d80ab03299bba6f18270f82772f384da601f80(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__db2661f7c772db4be984fe4284e72b8b89556cc45e0c1083fdc07daeca27d853(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0f4a621f11bb21179e60b6b64885b190ac70d799bc8185d8d6cf87e0fcf3ffcd(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__44159aa408ec26a402a18c7c525859af9dbc6aa81c94547c093f92000ea9de96(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__14795a604d3b0ccb927167a36b61a3c81156be1ee754bd5be23e3694dbd0a8c9(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e9709dcc769a166fd093a1b255c8963a5fc195c702cc40ec3ba9ad88c1d21864(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bb41b4f8581e81474d7e2daadfac4f50b65fad3dd12f80b41c8d25a54d0d3b7e(
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__957d75e003b4b5bf3829c2d0c82275863b15387ac179ac2df753414e26430f0d(
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1350e0ebc15b8fc9495bee2deef13f5fd8b2e7344833b17161cbdaa5d85939ba(
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__33c08c2da8209e9d8a9504cd2ea593bf28c3c5aa15bea88b79758ead38680184(
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__84ec0a9917d324ea3cd842f28fd5dd04a75a189fd0d56909f5ba169194c0626d(
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8db0720b3b947dcd3e602e18d0def15b54422b06586ba77ca9046724f29f93fb(
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__43e087be1e1589de610a19aa12ef6378ce302d49d22caa94b6feb33294a4a826(
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9ed14425ec6b1ee8dc4b901398ba6663ffc67b46d3ca8e6ecf8b70e344b28c29(
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__306701a65ed65af18d94fbf36932eaa53fe003890d20a5027842a45617f51f08(
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3d1c0a94e524114e63a705f01751d70c7f60c6f7b621d1557c84e2572af05282(
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1fff74d1d768b23282f9c12b3fac57d207c1d10b5afd42b8a19a950da3719b93(
    dataset_id: builtins.str,
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__904a18163bac938bf761856c867da18d24e4122954a4f9a3c90cc0dd307d3b55(
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0088b86f4f1e5e3d72affd4e3d67f9eeb53768221c2cff1995e2cb0f2f4be06c(
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2fe9c5527c78ca4ce91627feee176bb0c7201290dfc851a6e669ab913db9595e(
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e8f56174fa358b7046ea8c6fcfdc0732aff78792e2764d8ffd9e886713aef7ee(
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__463cb80b4449529b6638609f1e062d3eafb546a22c023ad53816e88ea5cf4b93(
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7c6b53eae3e980b95782f51583e413a110978b74d56aaf9955cb3df60c3edfca(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__29ae795573d8061836506865c7777c84ab73159ae5bf3a261ff3c962f251a119(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2235097db0b8de509a76389fee5cccd2d209350d2ac98a87cad6b0454d77acc1(
    value: typing.Optional[builtins.bool] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ea06878a24bf9053a0c82945a480387de98267b00bb5fb8fb908884e3cffecb3(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6c3fea5cab82466098458b3ef9bc60397edb4874ba9e61f12b8478ec154b25a6(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6a05a661b149132501e2399d31db71b9bc0968063300855e6c7f9bb6ff621766(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c2a717933926c33ba0a1c2bb90dcde7259449533a4a40b0a31d2408d32db6122(
    value: typing.Optional[builtins.bool] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3f5ef853a00b84e8a1d7efb184efb32ec712a6bacf5b4313842abd95c9a6f980(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0e5426f7987fbc1a5fc5fc196b1ed6651c93ff5e72abc8148162652b52a1b349(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__08ccf3fc32e275bc7ff3d79939850909de2c0dfb4108dee5f6cb2692fa60e948(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b507beec83babaed0298d691e322d03df4d80ac27c19a1d9122aaeb9d48b7b4f(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b750445fd2d890d8843c02442e2b69d24f9278df5635f50cdf7312a651d76948(
    resource_path: builtins.str,
    account: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__28815fc5b6aab3f2f30193b6663fce1d62e2290c2eb8cbadac2d423cad3d1d12(
    resource_path: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dfbd4feaefffb4c3e50215633880d25e59fa8eee3c3d97da425a49dd573ea707(
    resource_path: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dd344d8ec5d188cbb36ce51cddcdcf36677c8cc3b3170ad595e80c9e58940247(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9abd48b42c44ddf1bcb569b04c64c103260012d41f02dcec00c2f1b1769987bf(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__69ce5c5a3135a847b9dba239ca50da4afd4c05900f81ceed15cff1c072cc9f85(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__61c6c30244287bbf027f37c0af88b7a82e9f4b56d9069208b30dcd1553a117db(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__30f27a713e27953f8518c81b09396e2482a3921067e82ade307880599ffb8761(
    resource_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bc1fc9bb2930a30bf8a8a50117479b43e3821f08e4a7a98a84b5ade81372163f(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cead1dc1359ec6a8366db8df6ce43b1a23e1b7dcceafa2de1570f50c4cfcfc7d(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c0b50b72c1d9e4e5c71ef35145d24c127985b7a00281b1af97fb79a10cbe8fc9(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__34d37ece1f2b0f4ac7e049332eb2506a53d642699f2eb2bac91093360ce1c22b(
    tag_key: builtins.str,
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d9255ba1cc21498aed371cde6de81bd1e5f13f566eab0499a9e512d6dab7541f(
    tag_key: builtins.str,
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fc09882fdfd30f9785938a4ccbd078db4bc6d48610c5e6588e05f875e15b6075(
    tag_key: builtins.str,
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cc39c9249f6ce1ba49bfe2b6e258f2fe72383b7866fc0287ec5a74e63189098d(
    value: typing.Optional[builtins.bool] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7af7de060fd56a6d7f529190380a150ca173a38942b85dd71ac9e47c4b921e91(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5ef1efc5211d55ac4ea39e1c436bce80b61f644d3882cbed29d836da9f4cf31b(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0c069beef1c2a1138f1f452545c247e3ae23a2a9839226850f41968e35188b6f(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d269806a49d38fd536660597afbe6afd855e028109395979fa592dba10c9e4f8(
    tag_key: builtins.str,
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__604392b59c0fe00b129013b85b2aae371f5eba9df4f122ab6d74ade09683330d(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b191d148e2333642d134ce4445f0113701ff6031d1e647aec56d19afa8c80ff6(
    tag_key: builtins.str,
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c2a2e0850d7c9106659ac2dd9cb9657eac6aa216e90ef475bb4c34dbc6a35942(
    value: typing.Optional[builtins.bool] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__64e682e005b538a2d09a32d1d154336093f87e4fdb8859871848cc074bb5f746(
    tag_key: builtins.str,
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ba436c05ff735a353f8bc0b928ce8bcc0c24ae30aa277d09ff35de3dd0fac7f5(
    tag_key: builtins.str,
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c06d26d78e96da093c39360f6e094958f025d74770216e06af19583adbf773eb(
    value: typing.Union[jsii.Number, typing.Sequence[jsii.Number]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5cc0630b61826fdf5e064bbc02a57d096875ebbf8fd1191f95b57c010f3aacea(
    tag_key: builtins.str,
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__57b72fd033672f6aaba0a77b05166340e45a80d6ee8b01b45a024908181ce049(
    tag_key: builtins.str,
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9c43c6dfb8bb5d1f50a4352c5c7c78c443cc4e673654a339b6f3a68f7f48903e(
    tag_key: builtins.str,
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1fbc0d4606f29b96e451d8819f5ced25b4e57f7cf35cfc64b47541c11518159a(
    tag_key: builtins.str,
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8d64202ebdb619a9d171ba83fd1e504c537a154b479f02045622f2403721938c(
    value: typing.Optional[builtins.bool] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9901df7bbf23a27a15df6e411bb81b7aa2e718d49b931ef79f2dbe7328f3a554(
    value: typing.Union[jsii.Number, typing.Sequence[jsii.Number]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ac1b019df3ffcdd7d7c7d9f37b3faf54375dd88b86e0c3403c3e6e628485dcc1(
    tag_key: builtins.str,
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__debc0b3aa64b7b962f2989f9f7c58606e8f72c4a5722069eb381aebe10b7c467(
    value: typing.Optional[builtins.bool] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9fc267c6d78a122ed15919bce7f1a5c8c0344f71c24836cca398486a89d02169(
    engine: builtins.str,
    engine_version: builtins.str,
    custom_db_engine_version_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__944a6b99d179514045fad46759703a8d820f102f3577c62ac0fe758436b4b287(
    db_cluster_instance_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e43064940b3da8a4ffea65adf2c8462909a33e7ce2c41954b71d35582b81c82a(
    db_cluster_endpoint: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c4d6ff2653c5596c61c2495505d446fcb77b84204be8fc8de80890599926b3ac(
    cluster_parameter_group_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__afe9603a235c9154ab146abaada6f7057a88ef4f46bb174dd81bf15e532762e7(
    cluster_snapshot_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__45859d47716715a15f970e88b36e35f0992d087c41bdddcdcab136ec35ca1789(
    db_instance_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b0dda477f85080d12861f660ad999af5fd818e9c0e4f3f1710b548423161271c(
    blue_green_deployment_identifier: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7adc22584ea62303c693ca661f37a654689a818d603261488c2b740227e93456(
    subscription_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b7afacc989ab6ecd9eef72828755a71a190de07a518fed34135ed4fa35a5f7a0(
    global_cluster: builtins.str,
    account: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e3e645a2e2981b9724a1e21112e33dfc5d90d25d87d1d0cd16b4f5443c310b07(
    option_group_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__07e4ad63f2cd24812d1b4657541f0d78aa8921e5fec85971c5873701d40889db(
    parameter_group_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ca3fa0b80c5d33fc67f3c46944a111b65605bb0f187ab5dd29a2eb2a77eb5d97(
    db_proxy_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1c1f65db78636309776e8ca086804675e55b2f585cad49a8e48b31d9396a2949(
    db_proxy_endpoint_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__24532d4209f76c86a28d3e4ef027dd6fa60f5a6a16eebd84191e6b746e5104bd(
    reserved_db_instance_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__619642916d135fda15fa1f05a511ff579e26e63665f66ba5d2edc1220accfeee(
    security_group_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__578aac8fc1d33ef9d3ab9a50053f913cbd0bd5944e14bf481a4d69f6e6ba8c61(
    snapshot_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__24f8117a1e8630e3f0a89eb775d3f05378543d573ba39b2add42cf95778d25b1(
    subnet_group_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9af5c45f17edf1e6762e9c021bbf116d5c1f9cd0d903e60c339d96abb3decb01(
    target_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2eed1e77192e80c3f804f6141259b68754e8db103e1387632806561f83e2a063(
    target_group_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__630578f0f6bb1016c481a41130264ae16aa9fdae569db1e736ad582fe7079050(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__668f84ce2ffda25343ef83454063ca754b6761b34cee2eb966241db6a4bcb3ad(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__09a5ce552e9c695f972c5fb23a736931b8e91614cbf7e9db665970ff3893b882(
    db_cluster_instance_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__648be6c21385f2a48fb24913b13bcc7828d03ff40a464a07aa51175db3881ca1(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__17882f42f2108cad985e7fbdfb5f20da7f7af81870f73f05491fa76ee8a9ead5(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d6034507aca07f9084ae13802530395eff0e73ec0ea99acc8127ab207e1c4714(
    dbi_resource_id: builtins.str,
    db_user_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b611253fcc150803064b88ff04239c0fe3a7a227c63970580e1cfcdaf5c982f1(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bd665cd142ebdf49b5627f109dcc34d783b11d22845b7ef1863a5566a06ac914(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d227fb8b8acc6e58c170c4a730daf83b45177bb27d4f211587c578b7d6da0215(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3ed690be7a02aa7464be32b7c0ad704fba78477e7f53fba53cb6c8f047dfa6f1(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3ad838f848ca9184a9ae53f3e9c5ef213068fcd84c333a75ec4c70625cb6ab95(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9a1a0ed532c12d54870adc50bf91082c6084713b8d785c1b9214b66d9303932a(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2f2681ad39edacdaf1fb98cfb36f0ff7aebd740992de162acf5de0c2ee8ce17f(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__223fa46b1223d700239fbed8b2142119c84106b88db05a3dff938aad34dd6df3(
    cluster_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1a3e2be2b8142f8032eb9eadb9df46a559736d32cc7e80f001efe63bb1a7ae69(
    producer_cluster_namespace: builtins.str,
    data_share_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__465ab44400c65dc223c349361ad99c659a3a6907b51c0366139c1394dede7128(
    cluster_name: builtins.str,
    db_group: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b312774e1a7091380cd891927593603dc5594408171a108ac28092e4ea47fbcc(
    cluster_name: builtins.str,
    db_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d6620cd5d4726779ba54b980cae22c649f910b27c1a4837665f298f90a20d26a(
    cluster_name: builtins.str,
    db_user: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__80766c5cfa0f1a62e1cc1713d13f9cfdb8be09907dd25003375dcd051584e17d(
    event_subscription_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c23595481dda13fa4cfbd40d551a24e7697158c02ae04b5deef17d1aee50419b(
    h_sm_client_certificate_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0edffb50023b9ee9f77560babf7d0dae7120b3f6f344e24d8975ec45534c7167(
    h_sm_configuration_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7a9335f02c066e99218b06ffdfe78c4ad84102cfdacb8970d73e11a5e667e165(
    producer_cluster_namespace: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b72d8a714f1dd5e3a653fc24ee0fd2a1f2882e083a89fc2280b2c25bdd8f71a5(
    parameter_group_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bfd969edcb4d19e3c25b1a77f664558bc15879c37845d53b226791119934bc3a(
    security_group_name: builtins.str,
    owner: builtins.str,
    ec2_security_group_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__394a4c7f6af9f13d5172d96aeebad1f543a5c07b1c8ae4b3403f8a504161cffe(
    security_group_name: builtins.str,
    ip_range: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f6d2fe84f89a65ddc027ad50637cb2816ebae84c1b10a9a569179348fb90b447(
    security_group_name: builtins.str,
    owner: builtins.str,
    ece2_securitygroup_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__eee273e6de69f74d1e1a5a2129988153943b6d8e06f65bc43463e56f0bdb3ec7(
    cluster_name: builtins.str,
    snapshot_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ea9f346c7ea2efdbabf17387903e38b2b966836a762f83d89d02e7efd053605b(
    snapshot_copy_grant_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__551e07c48ccd9beb84351fbb671b5c85215e80ae262b0f62d3ac1812029829cb(
    parameter_group_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0060693348413f0186d827f778ce0408443316475ed32ba5f57ee0e92682e45b(
    subnet_group_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3477896d8d15e08e0d916c70b462f4393aa3ea7eb37e9818bf5c5f536306b6e3(
    usage_limit_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__27a3783acef7fc0edd4d41af61709ce4884c380d97d49404bb1b4668a801434a(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__26f8fe0f17b8f2aab016793718e12bd0665be7bb46c1a02bed72c1dd32a1aa66(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f0bdc2ec501837e62f0a169f110ddff63a15c3e522f83607c22c4b242b28794c(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9760aa5e7590453f83ffd7c92c202a39f1fa565a94a3d056250d66820c163716(
    cluster_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b25d020bc47e677a27c12f7e89bc0671c2757532036da378d09f856aeba6cbdd(
    workgroup_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c9bcaf7e78efb7a26d198755edd4bd8d4988fdc51d3d58951d0d42d10014f48b(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__961d688957f974f942ebc0acfe0de7f5f6d3db09d2f7e1a0e6355756f57f7aa3(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5f70805c90b3ed2f5766473e78d4b136dc10dd32e96597ecad45c09d52de069c(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2c64fd462106c9cf44ec86636da6b98ad072ca935b1dde8abc4587a7e2d8a2ff(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2b46922be7ca33b011c823b4a336893d8d9641458850fbeae3746d0d3bf4a8dd(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f76aee1acad2752c1a61c35c7bfcaf21fc5ab044ecbdbcedcaae95855627d6fe(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__08036020ddd194d8f3941761586cc22fc4f511d39899b44c895e3fd6aad4f91e(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__facc4b3fab0879e9a5a8ef9f3fe7182992abf386d1df8501ea23acae7f46dba6(
    endpoint_access_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__27832be3785047cecded20ffc374a27ba2885e762112e5812f757257b9b237e7(
    namespace_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c2494e33673557550abe8b81af9fcad0911e3a9e170731ddc324d42a83f7de50(
    recovery_point_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__512d1b4bbece9e20bce96451aba9dc48d4222a533272edb225721e18b77057f9(
    snapshot_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__71c17ebfd86c4b4bcf164d4e41e028cd62010dee072b860bff61ae6d180e1127(
    workgroup_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__712e031176b21b2ad13d58e1cc12f7ffd97e71f30c8abc1fede153c27f52129b(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3daca9081e22196517fb6bb34b60c97dca09a53e19cbc0fa3e15570c07554e54(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__74695e9de25a599223d50004511871229f14123c08c8bf82a0bee7ab0f9b2f27(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6ac3b9e32c15f4303d052f7497e622936924d253cd71f01f876d62af616372dd(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b37f93e0fc7499b832ac828193261c4e4ffa7851f903f510761df8f02e6bf4be(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3549224f7022f0024c90df002675c7f2218584e04d8b0cc386d1dd938f004d48(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ff8baf630ff7fecd2a755577fe8d8ac7c6aed07baba8c1e997cb31edf596b635(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7a3e678bafb3c9cd784042a8d0626a9d85a0553da5c97c40b09227404aac6d2b(
    environment_id: builtins.str,
    application_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3de92234f0725efdd42fd5d3a55a5e53c1b02159bc8ca5f14d812f929e761c4c(
    environment_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__26f21f32707684567451b14871bbcbb234bf16fbd09d04d076f0f20a41ccd4ac(
    environment_id: builtins.str,
    application_id: builtins.str,
    route_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c585d0bb4a7b6c4999d6ee0133954e96a491c562aae85b01b8b923bd029a8d6d(
    environment_id: builtins.str,
    application_id: builtins.str,
    service_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__36d39356952edeed025fca47732a7c1f5422f197cd53d19226336a5fa13f158d(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__832fa86560a5353e715104e64a422a616e4a7bdf55b6fa2d7fd5d9d29639a90b(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ef769c33497a939f85ed8a7dc1cfd6438a208c29dc37ddb2d3f8065d2aefa152(
    collection_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a4894838fa19e276fe2ccd9ec114333a631d62a526eb682de56147fab5b722c0(
    project_name: builtins.str,
    dataset_type: builtins.str,
    creation_timestamp: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7b4e65681ce26c427368cf1925efccf503abd623e67803683304726200cc489a(
    project_name: builtins.str,
    creation_timestamp: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__95283f7d4e4ca230169e60a2dc3b6c4598437f4455ae7f4978d8deab46598311(
    project_name: builtins.str,
    version_name: builtins.str,
    creation_timestamp: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ab3c82b5425bedc1f9bc98e845d21b6d403dec270f51f56701c0d90335f1c7c7(
    streamprocessor_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5fc0f3ad25de8e78fc435d352366875c95e11b0197d96bb23f52d8deff98b95d(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__24ed3ca8616ab85fa4c8076868b27211696f377cbce1c1154617789049c2ceb3(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4af5f1c4978d29fb42e30a628a42f96a3adf73e9d1a576cc3542e1ee43d26db1(
    app_assessment_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2507c0f8259f9e637ab7b91ddecba0dc270a7cc01ded05cac3749d0bc57ea98f(
    app_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ebed51e06a3f306609dea6ebc5b3b292eef87eecc1d78f8815b1da349ab0dbb0(
    recommendation_template_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f3987905f09b92c5b8082a52e25d37871b18df9a6ef0042d5595c62166d2f0ec(
    resiliency_policy_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c8e2d530e9fa96ac267eed4008de04d0fca70b0975dccf545d23b65ea21561b5(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5c3b282518a68378d69fdec19657225216cecfd9628d8fa926bddc00c216af58(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e47fbb229c299184c96be535f84b79afcf2f5ad9ba1dedfbb506113b40f5180a(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__10bb712cca8229fd5858e076dd5e65285772ce589ac25cc5b9a3188ddcd28925(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4213a8426de1b41302bd960b8da70f1e740119e5faf2252fa5094b735c56c976(
    index_uuid: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__879db4830398e7a5514de0651c1549ff470f7039b978624bcbf8eba1818648ba(
    view_name: builtins.str,
    view_uuid: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ade4f809cb3eef1bcda39b45592cb78eaf43276b78a7b3f709437544198d8b41(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a1232ea42aa80ef5501688834b78f4b09688d2e822ba45d5f96336804bae3937(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__aa59430d7bb61b88283331af3708fdbe9ac5e71e93c94114b5ad34370d643a77(
    group_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__425eba4a1ab5a25c7dad6a1878fc9f9b797fd9999fb4d3e10251effdfcebd9e1(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ef7e1077c7c84ea8572ff88cc97e49b4fb0e4d2c91b7a33c9a6e7a7e0c559642(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9fc4e1b052c082e221a8d5c6cdfe1d69c2990973fb295487a2b60a5b81b31dd2(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__270790c46f352b784864b35ba6a10fe9a1b4a4a360ec66b949814d4ae3dd1546(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__78abb5eb41a1a0b8de716c4b734e256ddf7d1dd1a7f14a7be95b7b6d4a5ed1eb(
    fleet_name: builtins.str,
    created_on_epoch: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1d3bb75e851d6ddae89ebfdede638d91514e374303a02041c95bcd87e5d61358(
    deployment_job_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6c2f317fb38f4c089d9a7f860679a583bf670d701386b92ad46ca4cde8514033(
    robot_name: builtins.str,
    created_on_epoch: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__49c32ba9644dbe87a047afc807db52a9388b7cfc80c4410d30178ec2fe1795cb(
    application_name: builtins.str,
    created_on_epoch: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e04f377d30da5cbb0c4bb9db3fd0e777f29250fb3f16d6200c121810f99238e4(
    application_name: builtins.str,
    created_on_epoch: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2f7a30dbcde8bf58ecf0c9cc50f90878c911beb3f30bf96fc5d17a8d15b34729(
    simulation_job_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d8daf776ce5493875ecf5dbefbd7012ebb3cdfe84c324f01b109d5e218aa4158(
    simulation_job_batch_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__89132bb9ae90bb3ae9e2993c248a8df5ba4ad2aeb16add4ad2ab99492ed91324(
    world_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__70333703090476bb7782b3e6e0f40d16407452217b4f60319e669b1a9abdcd1e(
    world_export_job_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__484162b90033478439224904ab221329b7be51c50423b90e114f540f6f1457d8(
    world_generation_job_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__15c1e3d36862890f400e53021cc0f87f0332d9ea00f3ea84ea4bdd8b67333e12(
    world_template_job_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4d164ef4da774e68a7dfd3b9be6a45773f498e73c5aedcbe286d037ad57d584f(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__480be3032854a8be7f8df07494bebf11fb2179cb18ef55904723deb07ebe466d(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fd275ff83c3f72a094457418d37ded5de6982a8d6955844b5e9b26493f5de5e5(
    crl_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dbc3d5cff8ab209703aa2f0beb8f32013a83c0ef10dd876229369c172e19ac2c(
    profile_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8d9010a61bf26573df767b9038644f2642078b10ffbf0537200d77dfcc0834d0(
    subject_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4afec003b3da3110b8d8efac47e6b16d1f924aefc7926e54b29e2a41c24a1cea(
    trust_anchor_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7df879e792cb3f935ea491d4d99ad37f64dd989533a3a7113af4f3c6c7f3e0d1(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__83c28f57ac9cb7aad301b2c754841a6a765aace6cb34bb2980dbecd15108da2c(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3c6c06f44d412f758508fe7b57ccac1666dd04d847184a07f39fefa2f2a43491(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1101beae23a2c5c4ff1a16a0acc6e006d4b765be6d43f213c0358445824fc66d(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2515e99005bafabc35e9b3052e363ff3f64750701d4902660e145bbc328afe21(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bdb18224b02f0e8c4c1ebb99814ce1ea11d3a391ee83114cfa5145ea5f965143(
    id: builtins.str,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__887d27ad7b837249c4c1bce13c1c46dd899476331ff895db959d4756ad79a191(
    id: builtins.str,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2d64514aaa0693ab2dd843176b53b5b878de7c0cc038b39f70d78c601a8eb168(
    id: builtins.str,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dcd437068428482df5cd142903902d51fb9952dde257b1d4b43031e142fcb1e4(
    id: builtins.str,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dd6107a38d2d927566d1d1e00f803206ea25fb352c24e0b8562db4f63c66ee2a(
    id: builtins.str,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c6fb3c4677e0ffe6f7f9110d770fa7598cfadef4116e6629d6962c6d32ff3b83(
    id: builtins.str,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c1db32c399ddbe5f8476083a209bf6a3a760c69b9a26573be4bb0922badb5b0d(
    id: builtins.str,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__eccc3087b649bedada26c339f113cffa849ee3b19ad6ee4b70ec9209b8e63e81(
    id: builtins.str,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fba2ec8d5b8b221ca2ef50f5ec375ab0cc2a63d51fdd9a3b6da1353ca778aba2(
    vpc_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5d200a66d5c3218c329658de13ed0f0d2a3fb4480d65e530683c8fcbc7a41bb2(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__565c9d4f740b94fbd07c18befff8625b2e877773c83c5d8855524efaa2313073(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2e0519f7e7dbd84421297c1da3d7794d5470796b59a788d62a4b1596c6c77dbc(
    value: typing.Optional[builtins.bool] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d252a2e09a7dafa165edfe9315f57509d8e4a2e632bd58e926337018b14899ee(
    control_panel_id: builtins.str,
    routing_control_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__529fc8dcb43a0f21d60ec62c47f22af465776e94fc88a4545496be77f0bbf727(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__06e16804e38778fd44644453b433f9bae8bc9f3fb566072e6e0d2673709dcfc7(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7a183c98d4596bc6b834842512840eb4736c366439238b489bf2bdddeb60cd03(
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__aaf720a5d33905dbfc4f3d858cfb9b61f97657bba8d55a8e499445004d23cd54(
    control_panel_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f49338e59cbf4d74bba3184c425a7c6be83a3f1c26c6a2e38c235e00a15e623e(
    control_panel_id: builtins.str,
    routing_control_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__24f5a890ec032ce91b17d8147649be626c3d761d1a0a6fc1ec2169c552d23576(
    control_panel_id: builtins.str,
    safety_rule_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1caa508660f442029f84e0dedfb663a558232622ea6897079144f8cae4b95049(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7c937712f4d5a60797925925340dfe6230a734ea29868b4ecc47587c4ff0b2c8(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__83ebcc6262c74f89f9c6073bb7eb1a538a95f8273e95b14a5de6f9888a9a4b2b(
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1850c7041a58e49989ea80ead9e8968d78f42513fef32194546853ba6317b9a7(
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6dd88841858aeccfbb8188488fe236ccfab5a5f9f9c4e4d5c73f9e5284deb40b(
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__93382760b057c4bbcdb06776a242e2e0ad947fe1c936e65755aec039e29ff7c1(
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__851264da398030aae8e5c4d97122a2e6b6786cca79ef7d0c7e65d06bcc1c4a2f(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4d674a5f2847270ad8c7f17406a75c8432a58ca3ffa462b994206cd79f41cb2b(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__34b7b527223f8d195bbe1ab4facd589532e0b67b94f0ce88a1079e96c37c4dde(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7f9cd78ee3b9d7d812c75644db68c31e593b1e1f93ffe6307ba9cf15a5d69dfb(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__13456c4cfd31e7847c56bf6f529c6c7a696629713b105e5b160d485d88b9dd1b(
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4bfd4a9d4bea29482c7da173bd53fe9fca32e7235d973d37f62840f085ecf163(
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b8981f61ec5a6df4897310f433edf425264b3013d71a88023da7ba281d6b9b0c(
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__040e970cd0f473815b811ea9fbd0723eac54cd55a90b11bf4c9b4cc8bf204d49(
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5408b696f5def45878278a2f28cbab5cd2ada4ebbc30b8e178f3d243290c2ee2(
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bc9c1a5f17972d40f38b82a8f6f38568c9aca53afa4970b10610dbb746c1a674(
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4967bd93a4ebdf6920cdb67e5ef192779f92e05ff23302037d6a7867ad3bf04c(
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d63a0dc09a41177e8534bc0158f070d0e786b79f64b1d346012893219e459af8(
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c3ad3a6c9c8754824504a0ce8fd4d269ddbea963e3992ad8735cf5bdeb1dde86(
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6ec65403b3b0199da57088dda2e62a2efc00029738edee74e866fa64e1efb3c8(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fede4e4d0d46d4bfc3add549098f0cee165be729ad698af32eeb0afe92221eb1(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__eb8ec129d76c83242d20950112c2e42fa7630cfd88b2cef2abd5fc9f1f563021(
    name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__336939fc6223992984d7cdd9dd05593470fce9b17ebc44f662b198ad4654b99b(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__38e42be3be4fefb83b9093e5e6b37dae78e919b3bb64ad56f2e3ada3a517d113(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a031360ab57e1a655a950ed834c827dade58f3fdcc6b23fca876373a2545686f(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4d0ba00c484092bff16ab56a08fc98d95cf74e62c6e1bef21cd40cb8479d6fe1(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f86531121a99aaaa83ce23b07e579df5e383ce660045f68b3a05317db89985cf(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8f9b56cd502a3294c0bbc1e3dee2aaa540f65f0f3512247d43e7590a6ddded9d(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ad27c5e372b0e3a7713fdf29d285eae3da395e921ddb4864db638d54a1735550(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__659c06ff0153ebbf19804e7860e35e095e41eacc2cc8a28691dd785f7106dbf5(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7d7932dbf0bdf54ca842c00ebc82bb76b2a3be5bc7be44643c6b43b9e660b780(
    value: typing.Union[jsii.Number, typing.Sequence[jsii.Number]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__123783c94b4c79cc49430460ad819b913d037c5d2f4226600908190f4d7592c8(
    key: builtins.str,
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ae9ece27d57ffbe72314b4e8439337cffc202e1124b77d4e10c8c4e6913208eb(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__76635c54a493d35e44291950c8f0e8d630ebf3c58377a7322f6140f7185294e9(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__69ed959861794d188d782f7dea3562d1772ddb0f38896ec72e72e60200ae2e30(
    value: typing.Union[jsii.Number, typing.Sequence[jsii.Number]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5a4c8304aaadeb89b314cc64a9654f01a019eea84ae751ba2a5fc2c5c932e1c5(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e614a9278eeef28b51fce29c94eb3cdfe9b2613374897202ab49998076fbb500(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__795dedc3ed8f3816ab3f91c2e8ce18063e52632174fa3a4e8305d8ca6c00720d(
    value: typing.Union[jsii.Number, typing.Sequence[jsii.Number]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3aaa12a078045c7df277cb8795cfac7d22d535c2e22925a7d6b49e156967eca8(
    value: typing.Union[builtins.str, datetime.datetime, typing.Sequence[typing.Union[builtins.str, datetime.datetime]]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5c43924b9d2f7b929deed573955814c3d7a80c8677eab131a55a7118c3a709f4(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a8eeb8671e1b4728a6618c27949ff8243c9608452e44cdaff50c23a515e5f86e(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ee338eb188f3182e3b6eb5dc6322a79e1a0849198ca16ff3c965cc28f2c737bb(
    value: typing.Union[jsii.Number, typing.Sequence[jsii.Number]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d47c6ba0245d7c0fa6f357249c6098e7223835965e9607d8ef23a16dacc859c8(
    key: builtins.str,
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fce925b88dc774333aef6fda80d089fef1986d1a0f6f8a995b1b36481f53e09e(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__eb4b9c72daa48dc85cc2402845b2556af9268f5a90e01b0a37c13456b259f17f(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ddb5f320f6889be62bed3ba8e37b04b08c92257778c5b1da265ff11fded61289(
    value: typing.Union[jsii.Number, typing.Sequence[jsii.Number]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9080e3bb07a0ed978e653601d056a466086ca766bcb24749660ba94e5aadfd8e(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7d350876dc5c7c748406f5b63cdc5e0485c51e53b2f57207d7524f46d8b7f230(
    value: typing.Union[jsii.Number, typing.Sequence[jsii.Number]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__512a9d405f0c5c1d797ecb77932895b09861e4958604b8651edf6e9d76013a17(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fa38a050de556694389aaa33c2cade0a314a3dd99145b678c60f2dbfdbbccc39(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__75fb62365449f33f96b6333e4ec8015dcf9e5dd2b6cfa32bdd0243a651721ff4(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__471b778cb8dfb1630c189ff2bfef07e9a4bafb2cd281608ca193be3760516ca1(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3d75bd63ac5dc5a6675b05625b96953a0b60184dc14b838b2815f28e757ebd0a(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d5c6ba8fb2bdf0b8c1908e1bb0564162e5a070c10880a64fa04a7f8cf75f4fdf(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__29b344cde8ffd903fe0d7d7706564e3fafb3fb6e0a00c9e539e9bff9fcf97328(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__52d47d7d051d24cc4049c8f239a9a8544b4b72318181470f1e66a96c48ab486d(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4386c5706ce10bfc4c1048895825866d9d04ce9ca2316a04584a25ed4ae1a8e8(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__19e7cbff2565c2f144287b6f3ecd9fea288e0914bbf72d0554dc4b2da9e7bd2a(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__81b38af40b4f48b24b058f45f1b925bd4d70ab7c84bebc819afd1684909d17b4(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7f4bafa7c18d5bc088ccfba07ad4411096c95e0eab981eeef032c57c7ff4178e(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__56ee5055f3d0cc39bc8bb6561621da287b692c0cdd80d01d70f93a824384c0af(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__da2b270fd7629da79a39cb8b1403a8c2422e913b663252202303dd0fa618453d(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4bce75ee0a9a42a26e4ebebea1a3d814f826631a079e6b7d88d5aab87bc05043(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c85aeec6a1606844ea932e06abb1a8ca4495a11c9f6dba4329fbfaa3ffb914dc(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f564934fdf99d145f9a329a86c8e853af4d2d133bb1f1ab4b2f5a44cfe283a58(
    access_point_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f281a89b6325c5b7b018cdb23e5c8b431e78c0a7e5ede0c1199cad614fbd83d0(
    bucket_name: builtins.str,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__96d21e59ccb5e2c04fc4df87b290c82ba03f3247f388081c61c33de3c11226fe(
    job_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dec02f2ad0c84e852220edeb9d3657cb13788a34002776fca150819ef606c97c(
    access_point_alias: builtins.str,
    account: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e9ff06335a3553e005a50d6e53df9cc92f36f29916d173ad6442170fe47bbafd(
    operation: builtins.str,
    token: builtins.str,
    account: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__11668d1c44ca2dd438b580dffeef9ef3be5ad56a25453e2f986bf3012cf56333(
    bucket_name: builtins.str,
    object_name: builtins.str,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0b6fecba176f6107827d730cbe0120917bdf80dcbcc3c24388dfbf351be8aed4(
    access_point_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__eaa17ac4f73d13edb54fa4e2ac78840074c603bd1525705cc63164df86be63f6(
    config_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__93c22689bc79bd73fe955052ba4b7519f9db4ac4437f74e343b3dcddd3b775f5(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f7675e73b6f87417455f03cb49e6f265dc29638a200f313f3f158f8d9edde866(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fc4bfc82c002341d1c6d28df2c2274f07e3fb5e2439b0f597f320ea52378dadb(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__64c15ce1da97771f2346ed922e3b2aa8335e7b3af768bc9dde2686e1112a30ef(
    value: typing.Union[jsii.Number, typing.Sequence[jsii.Number]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3429a624626fc0b23ee50578d3e344056bb351b279f3c96177e2f584f7890b42(
    value: typing.Union[jsii.Number, typing.Sequence[jsii.Number]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0f9ef23751b9e87b204b00662c4891cc3500146b83276987f27b1872c6e63302(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__210f9edc4f4ccbd7a736c825c40c61986b15e2b69728637d1ae433d1ab6eca72(
    access_point_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9f170af3efd3de732bcfab9aa143ae085e81928189113ecf125675a55b21e7cf(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__934ae304210982986473e0b1f0fdc42e86906c0e9001b2786740481b3016ad90(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__93686141254b0a2c349b505e200a54b5eced356bbf968886120575dd14acaa73(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f583acbc6918c2e6dee967cb3d1ed9ec25cc61c9efc32e4ac327d86177e1ecd0(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__36dd511a62d924eda926815fa3594e635396ab02ecc77c8ec9377930a187909b(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__63cecf77d2041c132d0aeca564a35c0f6026f2d038fdccecc175a2b1d5e0e0e9(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__69ba293463666d62d9d03ccce0bb4c4b5fb3ed9d35f9d29f354640e993b42f9b(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__52f8a41a17c14dc94216332f21c95954bcc35f1b57a6c29107b8659bf5075bcf(
    key: builtins.str,
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__13c4de129f5daa061cd125e0e5a5a020d02b1cca1316189a24b7be442a346a1a(
    value: typing.Union[jsii.Number, typing.Sequence[jsii.Number]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d6a2793b77a0e2bd96751710c7afaa913cc4bbda0156cc8a2a6470f521f49767(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__464dba3ed700e89b8f59d4c9a4449be0adfee44b5ca4c46cfae3196e405af531(
    key: builtins.str,
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b52647c7c0f6268c58d4f12e818ed4e3ff4200a84d4de77436fd01735fc4ada0(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bc97fdf40af742f5cff495dd2c0a33c1a6a270261ce48cfca72ba3e813b2c4e5(
    value: typing.Union[jsii.Number, typing.Sequence[jsii.Number]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b29dbbae12af8aa1ec98fbc5ab67d0ed7e13349c7ee580681bc780994019bbe6(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ea478b88c81709213dcfd6553a402827ab03e8ffcb80fa3e07f3b14388b55568(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2f5c6711b0b6e4b5d6a60a173a2d7d4e5dfdb609a0bbc0bd555861389bed3533(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__01c157cfbe3faf93da3e3072ad0ab290954c746b12cbab5bd8133055e03f960e(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b408a6c1ac0296fb25adf830e45af4150dd94a9654d1b0d22055d451e4fe6cbe(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d2704a0fb3fa6f84cf83863cab390f40729f15dfd0ff1d2ff3071df833aa8737(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2c3f34a2edcf103eb7a0ea9a13fc045c906ec838a3fbe2f1ec4f9d9009fb2baf(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d068a8490b61895ffbd42b872b0aeb928a92e184ed6f5e15baf35463b56772b5(
    outpost_id: builtins.str,
    access_point_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f5564d15edabe49604432795a6e15147e7f8076eb18c41d4341993f9ee502f17(
    outpost_id: builtins.str,
    bucket_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ecdb383be31b74e5522569275a6984e1d11effb21bc6a252ddd5df11922ed8ec(
    outpost_id: builtins.str,
    endpoint_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8a116574eff0a232884dc3870d489ceea2606501d599f2b76e4c53b009acf8d8(
    outpost_id: builtins.str,
    bucket_name: builtins.str,
    object_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a9692b569d968c1d12d66cc382d52d6ee82e7e7b6dd5618f0627606ed4d2e445(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__204906efa745ebd378c59ad7adb5fd2da0771f6146bf1a347c1631488490536c(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__38442d1a6d6c7e52c43a73917755a3341b8c4ba3c2e793f866711c792e9b9121(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6e178a7841665c729c9af77cb86feadd7ab7790303f88c9d18998b3b660741d4(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e73770ff74847d6713adbf5ea8be8381a7f5a9bb9356c31919b05ba04fc0e6f3(
    metadata_key: builtins.str,
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b478cbf468f61eee782796e994d95681128551993fd2cea18cf6f6fed24f41e2(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__22bfaee4059f5dbde5c3376b3fbb8710717aaf53a796c3a7f4df259fdcb1bbae(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1ce5dcae17ab5242c97a9f336ae001ec26b7c58b2aee590007b1f41a4fc355f0(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ec93c95f5886280131ae4e083ff85011b62bf91df30d2dc00ad3f5ee47d02913(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d417f0730f40888f6b6e26cbc04396b37bd8b775bc6e8804c23226320cac53e3(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cc555a7806b59b6c9e5a08765f547e428df7bd04f3efd9e0b2f693d0e59039af(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__02c0541f77fcee7c8c8247104048d999016b7172d3a1d9a276d22d751847a1d9(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__eb0f3980eca82453002f4144aef627bcea189b8fc761f3427d71ab2a8f819e3a(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dc3f1efb6906d435916b330eb0d22ecdd6c1f2a3c8d734e02498db245d558249(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7959f00860b5ce96dea05c640b0173b03998d68acae69b7234df9e9eec397f5e(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f79ec987df8d491782b6c2e1e115c76d66c13121a915d466dc38d50ecac5bfb5(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4f028e966b200987aa2945baaaefbe79ced1347d21a5213790bd72ccbe2f1e43(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fd008b1ee4800adca5601cd8486462f5d8f18bfc5b30860e10872ed1dac72423(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e0bf054dbacac533323522362b9799e36e96fd68d89bbe7ec2188038904a3cb6(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f5ac2ee25f1c07354ff383e68b97943bedaf29901f62a852a8c3dd44b3a8cfcd(
    value: typing.Optional[builtins.bool] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4f6991a1a3f8ed71bdf190b82a6375191c81a6a77a0524688f6b774833659a00(
    value: typing.Union[jsii.Number, typing.Sequence[jsii.Number]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9ad29451faa0f4098c25fab8e1b27133b219419b4836ad4975e8b8d3875c871d(
    value: typing.Union[jsii.Number, typing.Sequence[jsii.Number]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e9d0b9fb8b7e64e20027503afada4bd2a66742ffa974f3e17b19634fee5768d2(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c4219ac8af4dd0aa8eed6e464578909eca54ea694632b5d5d40914fd1093fccb(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cbae8ce63a545d32b833adc0dd8e548a206cdf367739583149033905f0b45594(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3b7706117e12b163e3ae349db620ec398de74ca2656a5482640c982bad4f142a(
    value: typing.Optional[builtins.bool] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dc8b746cc89a7b0947acc332498e735fddf926bdb3b899a6e2e504200252990b(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__20d0b5123e397f952b65fe02d7ba41ea832a19bc48b3f274b8e5b4de3865db41(
    tag_key: builtins.str,
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2cc9f187cd0a492901f3ab1999d0b1ced14f93b699fce07c5e26e285101ae768(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cbe9eb03133bf853570ac6cec05ed685bdce857b54735bba729c66dcac2872f2(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__985c6e8cc6e203d6ddafe187730de781acece6645a25cdf677e0f43b59892f8d(
    value: typing.Union[jsii.Number, typing.Sequence[jsii.Number]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a8a9b2274f94c5f53e2d37db868f3e6386a24ad9f2704f18ecd7b7ba49ecd42e(
    value: typing.Union[jsii.Number, typing.Sequence[jsii.Number]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bdbe0d36f01970e880fcd04940e108b2ad46140a5b8a3663564c6077adfc0fdf(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3a687d31c8a76cd879d30ba8a8e6ac2744293962d1abc3e020b21b895a8cda10(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__587c0f08ce78efec0b38074ca3e5dbc932f349a2d7703e439812fe72f9dd1b39(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e64a673a6e270f3cbadfbb68bbef3bf9a88bc5932a7b177ff7cf09d42c8a399c(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ade846b14df3be5e2ed6949d4b7e605a20105c02326e75a45b51f96e8d259497(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f5caeae42c0c2ead37a124f568d89e2a25345c77de1fc471994227a97d1202df(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a7aab60ec42df713912aee9360fba75ce11b1b0353b033b41b8c001cd9e93854(
    action_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0b12275505ca308216b9b429c3399b27951d469a77128651059ee70e8738f4ed(
    algorithm_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__353aa603fede9286da7509dd378389bdad9fe822310edde0d1ee80996969db9c(
    domain_id: builtins.str,
    user_profile_name: builtins.str,
    app_type: builtins.str,
    app_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8884be6a26cbe784c53f398bab4c57ccb8caa557a2ea5f0711af9e261334f4af(
    app_image_config_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__19633f4b4aca83438e9c4604432e3b382e7f83eebead4ced33f9ffa0402f1507(
    hash_of_artifact_source: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__79dfc4c403279b53a29afc3b551bc318e2ff7e57c3e13035dd02bed0b7c0b9ee(
    auto_ml_job_job_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2d8b0473b8e66364fb34223242d4fba3a69066bdbc2c1d04ab8dec3e968f8cfe(
    code_repository_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7d57f33572ad2444a5989fac2a91453d10e9b5e9a4438229372f6091b9cbe889(
    compilation_job_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1455215de395f9291d77a6687a6ca049b7cb46c512cc7222eae6e1fb0eceb92e(
    context_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e16868aa9fc74334f9f299ec7e8bb8d587319db4df9c654d5b1bad88c398f139(
    data_quality_job_definition_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7a24f4335929e2d939dda92e46a9a2eba9f2f6e4ea1dde9287ea5c100a23b085(
    device_fleet_name: builtins.str,
    device_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__685613e04bc7f6cf0f23bc8f9af6b3261de5e5f7a33aa6945190f5c2c8f6a68e(
    device_fleet_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2f3a611c667e246d4e4fa0a1872d8c8b289cea470d6597dca3cc360d4f5ac3ee(
    domain_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e7afc6630f09c5c6433ca122217763c497fbe455fe579e746401edbe3b6807b1(
    edge_deployment_plan_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3a6163c6135d98c962fe1e1a2cc0b14ba29a537c3674d79eddb5e1f35f317e2c(
    edge_packaging_job_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d4ca62d4741c19e7c08d9eb5881c3d14d53d29c653a18911ad08dfde71052100(
    endpoint_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__edb365410421c8946c855d864cf21ca573e6f2969afb09752f1ca0da8a69b85d(
    endpoint_config_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__839867f2c56946613c931ad194a7da1956d271b775de2d4e26b6db62a0b58621(
    experiment_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bfe37173776404a06c92319ee8ad50d17efae667412fe85089f6ab8d6befbdd1(
    trial_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__014e25625cb0cbc5d32aa1a26824107fe0f8225aaff92f097b9663f41dc6650e(
    trial_component_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dac2a6fda8c7ed1b70b10c8cb6a3d1604845c221cb4be5811f42f9797b7d0645(
    feature_group_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6fca58ab0598b78bcb8c1217912eec48644f304b7eb8c466b3f206a629bc9ffd(
    flow_definition_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d4049e90aaaba0ac841381867d1d5bd67df764ee340f98a9505d86dc8752a26e(
    hub_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f665e3d6ddc37c6471c58be9111eea6f3bdf8aa98aa5d96579d12c8caa8b2edd(
    hub_name: builtins.str,
    hub_content_type: builtins.str,
    hub_content_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__05dc84c9e5cfce7996ec1280e873a71469a2e5e2a21af8d9fbf52c85059fe1c6(
    human_loop_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b82d84fea15aa98f21b852784b21d244097f61939cb44847aae504a25f0559dc(
    human_task_ui_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f9aafc652dbbf2e80ff9e564632eb0f2fc6d6440459bfff8290c34622bfd05e7(
    hyper_parameter_tuning_job_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7ef50af25cfd2284cb51fcf30be31368ff7a893d89d7d082934f306e51e40c48(
    image_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cc4fccc24cda556a8ddf83c8a16c65406192e5d2a08ca48c5b5d75583330f27d(
    image_name: builtins.str,
    version: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2e4ded14314cd98f7bc0306694a72048730681ff1dc54050463dfb214d875210(
    inference_experiment_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__85948f497099f7ce80d20236cf19b14d05a8dd223e18666f7e1384349d8a4b6f(
    inference_recommendations_job_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__76d14d22d27420bde257323f3e2b9904bb18dee186a3acce61fb892a9a6dd70e(
    labeling_job_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cea28ff7be98a6fcebb30f7cf3107b12ea192e0160cf0f49b188cde664268478(
    lineage_group_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bfc49dfac080ba84a7ba0ed9d8152cf44257243226611be993d9882f39d75872(
    model_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__556fd84c3d3395693b741e02ad0206e08d3d88dabad2cd427c5daa4190427aa3(
    model_bias_job_definition_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3a9269ff594d15c0935592199959468c997ef97f9af47e057bc0891a9500b1c1(
    model_card_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__80649090a00407975f1f101c82a2850ab92511d9b3132538ce0665d9e7742a07(
    model_card_name: builtins.str,
    export_job_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ed3798fa62affc96fa0002a9a2275d56e4da2780f5d4f3dde4e8fb56c234d29d(
    model_explainability_job_definition_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__de2016b103077574b1cd95cb553ea47fb8b2bcc8a42298e9bd1c78c3786fcde8(
    model_package_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e0a2f7f86a89fe8c60cd09d8abeaaebab0b97208a9a6278cf8c389dd9032acfa(
    model_package_group_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b3632ca3d02f7909d3a81aa5600b49233f186e7d710e1a50117924b705a18ee1(
    model_quality_job_definition_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e943bed4a854253997875ad6f9dbf45abc06a1b6ce3477e3984947b71fc6f1b3(
    monitoring_schedule_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__aa34d57f41a927eaa92c58e19aefbf2f4ac13d9006958391b896e2bc1f31fcf9(
    monitoring_schedule_name: builtins.str,
    monitoring_schedule_alert_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ec69bda11cda913062b108d33dc55d49e1f76ae1dd487b397123a740514f615a(
    notebook_instance_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__95c194612c1327c4ecdcb4c1f164ca6d955a7ac6e71b7e8f75bdbff6ce1954dd(
    notebook_instance_lifecycle_config_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b2487df702567b5f0e8aacf082827fff2e8024c65265e707f02b3f45ea98d8ee(
    pipeline_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c7e3169aa68238b33011a64a56deba8c9233c34a39ccc6fbe587167acaf410a5(
    pipeline_name: builtins.str,
    random_string: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__60ee48f3e3045cf4525620cc68ca7e4184a595efc7f17bc5309a1a45931ec12e(
    processing_job_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__adbedaf36894c033414ad1b2d4c1a45ce68e75f22b2e45fc785b5b0080a13265(
    project_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f25f0fc2f890c78bbaf438ba48f178bc04b6a80360579b1f74d60161eaa356c6(
    shared_model_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bb608fda52499da50f6a815b51fd439ec7cb44268ca420e4fb986f23b921172a(
    event_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__84d2273273fac3b64a0dd9d52ebe4a8cc2b33869323e927a35489fa72c273f16(
    domain_id: builtins.str,
    space_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__095e42117b98848739706263dbd6cb2f2fd80355d575e210f835f0498162dc62(
    studio_lifecycle_config_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e26da0fb41851559f474add901a5f91a9763033817813f080d2184cc0577dc52(
    training_job_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__13022b85510d2c8884103a1f086398a6d3ab1e5564be61466475f840f1d5a592(
    transform_job_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d6edd0de7b5d4d7c3f31dbba3d9f5ec660873a1b09dc2c0c478442fca135df6b(
    domain_id: builtins.str,
    user_profile_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f492a4730007908193f98bae0fff97931a1e44ba475d7f1e8ea19e83da3ce7c0(
    workforce_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fa8c5fccb9a6bc228438083cbaa8964107aba597e81a8f79c4ca00dc2689947d(
    workteam_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2e9cc9da2a9f159dad2fb982fe34b44e3a44224595f78a65f910456f64d1ea10(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d97a437b504b9125885c18e92a91c15be1434082afbcf19472df51280ce2a5b8(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__90c3d0b7f40cedfcfc946371be29a5acd76a8136552d1dfd22121b507d7c75bf(
    job_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9f2d0c6720945c0fcf7ec6fa7d0eb30384b7e5f6829922c162cbcd931d806e2a(
    collection_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7d4e91a3260ea46965e622c9a89ec6aed3ff4d37babb0f5cfd73c33072346a3a(
    job_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8e88e33748f469864d57bbbf1d773433f81fa9f5be5678b68aa4c70496d83421(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__89e8d149a11211d58597069623e6e3187bfd89347e7fe46cc61bef3c7e99c9e0(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1593ac861b22cbfa5de34152b29f0f9e706e62191aa652c0c2739526ac5ecfb8(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6d80e5d93ffb82a3ac423a35218777a91cf5364e7310083e710f13802e7427b5(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__69083fc4469a16a09602943aacfd365eeb8cf2eaa571812f037257dfdec929b4(
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__aba649df8592e3f4bef0ea3f7dbee1c5213e644dff4924c853b1048f20c974a9(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__67b1e3526e8b5d84d784dbe52bbda2fc0c830c21fa1d8f94d5cd578ebcee5140(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__64907ad737043d425b8023f44b4e7a777098ca9cf0154c7d063089b59320187c(
    group_name: builtins.str,
    schedule_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e81efaf946cc5df0932cac7305e44d89af63f9769690c382cf32b956c9e99baf(
    group_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__21c40e3265f8fea4ea846c87b1e6175b75495a3d2f8e526f40073ff6f66d4190(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d82a6ab5e16b218facda89b56cd693d246c97685b58afada3ceba8d0e3ec27c3(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4c718f5f142a7d801122c3248d74697689f523a19231898c312f8d49a8473756(
    discoverer_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2da95b0a92e58d70c7cf60ad603767002a9a371cb6db38e369da65a277391354(
    registry_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fa4597e43ec19df1890a80c0beeadc707742cd9ec7eeddbf1dfd98843917d86b(
    registry_name: builtins.str,
    schema_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__18711c6bdd99c38894e9c5d110da9562fe9a01786fe1110ba270e94b36568217(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e135b90d5871613bfb1a49953ada496a331f6def3f8ad9af21faa6f1f9aa1a9e(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0dd550b13559912c13433babd82b82410210a4f5b89607faebb5353f5274895a(
    domain_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2cf935a898270a9a7352554668a8a33b1faa62d4256020e67b9c3419be79c8d9(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8099f41c9e5ef9d00ebc028ffe2bc677a3aa26c641c531cc1f47519658e8d283(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9b4ac6f97c75ddba2953248c19d9de3e1e7a5fa3728baada4c601e1b77fba326(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0914d7c607c346e92f2fd378b041fdd2d50a9e8b9dd1a1480e1eeea68e31387e(
    value: typing.Optional[builtins.bool] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c71c101aa8fddb1f6a622a7ba972aa9e53dbff764a597bf7b2aacb39021369ed(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__94cd71da810f09b383b4674d6f4e5e4ed224756557c957712a48cfed48dae440(
    value: typing.Optional[builtins.bool] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fa819c51cc11e6401971a2ef1eeef1c957175a5e399d7b4c82d394b05cb27967(
    value: typing.Optional[builtins.bool] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b5270a52f93ded95eaa337ff52025b09799efc53f4ea96f5c383f5c87d1583c3(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cc3e9c39a652e9d01d9f3aaeb6896d4494d7fd9df82911ae017f0ec1cda41e86(
    value: typing.Optional[builtins.bool] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8a25bcc56747feb046dadfe90f5da7cf39ab793f893b41c4af6396e33da53a8e(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ccb65ce9400d39c537d5382a872d890e57120c13a484829825caf6b08a8bc9e4(
    value: typing.Union[jsii.Number, typing.Sequence[jsii.Number]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d888b28cd2be9348a41260a0cf619ad47b342bd302ad97e08df83191463a5987(
    allow_rotation_lambda_arn: builtins.str,
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__37062ddf3e738e0c075d9465b9a99e7bf6bd5829ac1666c894ba4333d406602e(
    tag_key: builtins.str,
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__48819556e2df068c0b4b1244c62a1abb47e2b764529ab1f43cfe83da2d131264(
    value: typing.Optional[builtins.bool] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a72f77f5c4e698215b854b1037d6fc5eb409bed04fc556a28332b491eb70a4f3(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a3b2c6e2253681a63f93e3538503c8786688d35f19fbdfb828a0427ba01bd5f4(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f02f08c895bbc512d4a48015a06e8270d5e2ca749c46edd1057c7bb3ebfd3269(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__844789d0d3d95d6b0954c2bc4c76198cd70532a70525a7a0ff54faf456bb4fb4(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6ea64f516c930cd9b197edf5159f8c9ccb13691fc544d5527d3fc870afc14bbe(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__20c4ecc2e2a7979c9c4281000f8094d33861a5be5574e912bab16cfdbf62e319(
    secret_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bd53234c88169a2295c6c50172b864db8821a5eb8a4b02854c6a4cad3afd1de4(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__251461be4888ef9fafd03a48e982ff44f76466881e7ad5347972f0c17707fb0e(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9581d42c5ddb777a806fa306a3e4bb507d95bdf1918bbe9e3c91f2fff0cb4be7(
    a_sff_syntax_path: builtins.str,
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9c7beb28ad0df83c7115ca6c81189a740b3221ec810013b844d0db75dd5588c5(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3d8b1fdd6a0a79ffeca538fd7186bce6e6a256b2aaca0cb5cbdbe507668157c7(
    finding_aggregator_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__be5a4028eabf59e2c9c2904c26500c06823776900c49ecfbdf180b54505b922f(
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4471b496be7b78baf316559dd037a638837e05d544d0e5ae076fee918160fa63(
    company: builtins.str,
    product_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__17d76b9029b0e9d26357846b0126a7fd192e65b3a4d23aa3543bd05749af9e7c(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ae238d4560f4fcebb8d75143c0003a9347443bca96b608e55bdaad0b9e1576e8(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2b1bb07fcae906438d3480effc1a4c094620b712ebcede5debb22d88992e55b3(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e43512d29e8b537e8ce70472b52eb3c387c2d0d0b5969a29b9e52a87d0be1835(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5639be045bb5eea1b99a8f94aa18115e33a59db228dbe35235011b7163b8bfc9(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c794e7465c36846c57f58d96a8b6c939b67842c805d3a029ec7a464a63639bec(
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4831d491d7d99bf9d21f528475ef1980bacbca21e0bed9dbe509d521022d05e4(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__88de6abcfb38ad5ebad0b0171e88a299bbcb6038e05d5798aba678e831a542f6(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__64447ba0a500d0df654609f6fd96f854e457c35e99001ba6d966fec0900f6518(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ad1511cb011570be27c66d4008b3a98fc5d5c8f069db0c84ae9f2d635c81b025(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2ea66071cb4e7459edf6bc4a2f5fd2b8f37334a3bd3255b56e305ad821ae357a(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9749ecce11faf85a7f017060fb1187b73cfcf148d73d3ca17ae5a54f88715e1d(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1de14c25fd96f8b204651e123efed34970ef9527747659cc764e1e04c64c085a(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__49e4a5dff0740ed9008de08db0327806af00c3a21e8feb193beb066d46963917(
    application_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bef6448a08daebed0033ab86ad4072ae48296923aed9bea12a5e9b519a31f7e1(
    attribute_group_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fffbc868179a360fdd6c51ae788dc2d24c3e92275d3e5005fc7766d12e3b976f(
    portfolio_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__550a2c1ac44ab2fd362abf7fc9ae928380ec80c988eaaa66cb73267564554333(
    product_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b9de06cbd0e4fc99b58fd55d12da6bcd9c6370d9b0ec93607e6feac49285481f(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f7d8260b5ac347917a615787db21dab68b86b138b72879789b8ee7dbc1e08063(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__80f39cfcc77165c0522806ed5d31196e54d7badbdf9a7915848897c174606c3a(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__35846e4557b60a659093adb8b753847181b1e11854578de985d34a3385e7ffd3(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__85154aa6d52c39b16007ac6d327562ab63154cc50d82d6cd17dddd28dad5550c(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3c76c851b7c52b045ed759af1b6444a134f7bc5e9ae081ee982a7d67c4c7784d(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a98259f9400bd267d1c4390ac2f844dd4b5e99c44e2c7b3fa975a18d8833aee9(
    namespace_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2cdc586eacac80798e6f7893437e628fd5d10c28353e02ef076208a00df05b52(
    service_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__591c405c2d795e6fb8cc77d7d755382ca979fef249fe63ec429dda6b992a9910(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2f604f3e3261da2bceb6055a30d30616d4e9f0515f34701878b2f68de8f373bf(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1c70f36014709d0be141498db9437ae2ad61980eab76fc4ba8284f2ace00caab(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5130a0754262bdefe53dfe3a5127bead93f3744059f44c6297d637246caa8715(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0831bbea28a3f4619d310da1c0a503191f4901b3f485791f7499a7f556f9a99d(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6da2f3b6810b0f888b887460664ce0a54d05a18d8043fba813eb51f70f20f0a3(
    service_code: builtins.str,
    quota_code: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4d9f11db186615b61196cb1f0b89f5adf215e8984f66dd91fa2eb953438a8d76(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3e6671f37c226b1cdcf6a270064a9263d00e8d5a14830601d9a8941612e12bc9(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__387dcdfe1152f12c74ae4e803b657af5f03f2978f223c3db721ceb9e80fbf5d3(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__aa566fe7aca358c6dba44988af8918e3d9fb99ef6024ed9235b6dd2d781a6787(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3ce3d524d24d32914d042e254eadbe452c43c5b7b07bfa7a8e95ef258b131668(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b82c8483127cde30d526f2d2fa202fdabda52a045fcee658eb0c358cf4152466(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b1b2421dec5b96e466cfc9355730190aa7a0dea92548ac5a15379e1a54197e5f(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a87353c6ae5002b669c24e05a4200d53c4d8f099da89d23b13bf6aecd7ab1238(
    configuration_set_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2d6b19a9f311d3eb1a98ccfa8833c026c683a4386918edc705cce2699e85524c(
    template_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c60ed7f119383c8e428444dd3b090e38b231ba2bfadfa55ffcbc2ef3c576e0f8(
    identity_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__36a7c9eb1ae5b3442bb9f2c5cfb39c797a0bf2835fcb483e6e0d24e46d1167ac(
    template_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f6c136e3e508cadbb9c4d3d86806a19a78b73be951fd6f8588b61719fd08bf78(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bac1a84f1b61b531f687d8707ddc6d48588f011549368c5f700f83d47d336874(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c37e725fed529ef1f6eb6475400976d0c46acd383039848f37a109129cf6e980(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__52e7d7fd7abbcd7506f612406a2568d2573bf641f1855752cb035083acf6902c(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ecedaa9797e97e1b0ec885fc7a972544ca46c651ea4f3afdf7c1977ff33b521f(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__aec92d60b942fe65b9671baf6ab9ecebb951c2d27acfa9d5680a0e4f594b1e01(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__72849d5183391a7ed0be6a2e0e1d5dd878fbf8129c09d73544ec1262af55f594(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ad193f3301d05331fc1f0c2c30ced9f53f17af816fd37a75677ad92f2d0f28bc(
    configuration_set_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d888ddb1c3480311a90a3b259f3ca714a034b6425b75d298e9ab9b0863ba9b85(
    dedicated_ip_pool: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7e2eb35be2a4fc79954f592621610f0fc4e3d639ce7f0d80aadb8448596ae7fa(
    report_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__91ce7a1baac649a0d9b201a9048995cdce68a49b2b26fd2e01433d17665ceb59(
    identity_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d45a0ffc8cbdd92bdf9ecd89e96481a0c1ee5dded143c812cd65c5bc95f6d8ad(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e4cdd72b5fb356d57aff7120b554ba0c519c81ec1470d6ab4eda5316a0b04a18(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9794e60c997ad9fe168b5c813d1efe64ef9bafdf1dbc537bcf856d4086e7d23c(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__11cf809edb5a37df366f6d96015d905947cab0ce74d1b8c3c2da8b3f694149e4(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c079d6ad9c321d29d4aae24a2533dd2728d1caa168c2721bad2557938a9be119(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__84fa8a79500e3ffc77004cfe905459cefc27d072449f12bb613209af9b44fbb1(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__19f1362af5312456066e833ee0376735daee6ba9cdf1eaf8682c5ec4ebb72b7f(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__09b63806c58657a643b63126a31541b81757c8956ae12723e6afc48f0d66d019(
    configuration_set_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__86ce927f15d151eef94a0a21767e58c2316b2e2123c9618a96f6db000120ef62(
    contact_list_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ec6c82430254cd660f6391d8e8fd1466ef9fc33524ca0c2b2828910d5ab3d894(
    template_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3210d7bdef7e60a2db77f5ab26881ba2f9205ca5b492ec0fc5d6f108a4d969bb(
    dedicated_ip_pool: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__abff695540da218f6dd2df6a6d79eb304250057c47ebea3f3bc83feb0c272729(
    report_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0891ead7383be1bc68eaaa31ba2124f2801c17d398d5d690e85c38ba1f6e5eb9(
    identity_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__484284e04322d5950d2efa1486a15948ec9f4787fe6d41c7e8aee059d2383c43(
    import_job_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a248572a1f7c7f4bda1a58c8285a6d43c1462c6db80e6096bc78b826bdf091db(
    template_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4c2e74f688bf29a96ac18f93a327154033c572e971d8334a8275d457faac1422(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__39de02d1c99a24e67672726fc0a1d9ec3032411fe9aa2083ec2cdb28b5f6fb59(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fab4eff93c1fb643f1ff6d99e34d8aaa8ec9d04f349541829381469e55541691(
    id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9ca97cdc46bc44d75f8b323115c9b75468a488d501ebfbb400ac24c9fae036b5(
    id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__93ca1abfa21b347149804d46b850ad9ebe59e46d8e2fa35be0b87aa20400f424(
    id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e739906e6af43b93419095f90b8782d57566756de466265d781cff78337dcb28(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__87233394db63df39c1b459f95aca4ca734e40f14e6ab5ea46c0bfc26600e41ec(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f598e02c845bb35f35a9a0e4966cff902846dd9ce502e495babddc40c54d93b2(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7964e93ebf4bd5a2aae91eaed4023207822ce36c3e1896bc2e41e3f6bb96c35b(
    job_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__883ac2e4b711d7e11d4d69f1f8558d0e715c656d8e27411f9d16fd2033886374(
    profile_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__16fc0b464404da25b3bd2620a1c7dd28235e927306c4bb1210fe63addc95af77(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3660c5813f5e7e11b630e3f2847c16a246fdb013ed4d9b0cd8d0a79f6e8e2759(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7693ce77c3124dd1c729f1d0cc86d0454d17fef5958a4c1b63baac2a4fc36691(
    simulation_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7dbe10466146751b9795f869e4a37afcbf92259e1e5496c9b53d365bc8ac1a34(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__60a958dc74a926de483ae84207dcc6f6b9465fa48a8036788f668bce1b0a805e(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2a90d2fda4ecf4cf2c3c00bd33b3f904dd96e83e2bb82c1d51a9ec828966a7b6(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3bfa4364b8d635a823abe6d4a3d175263dafa4b1ab273125365ec40c60f2261a(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__14e640f700219f83fb0e04d1deca576bae84cbefa81235e458c74c9cc7378587(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__65af6936c0af90237e5d5b44067d94ede2cf578012d2ed895eb77856d896fc93(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__86eed1cd175f6e3abc623e56d59f89e89f723af1b3e6968cb27861eb41da3f6e(
    configuration_set_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0a3305f72aedec0dd7848f39222777623c2f0b34feb2cf6f214419d4eaa65b13(
    opt_out_list_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6edf3a2c0771a224e9399709307488ea656f9f53186a0735df50b5aa2b466ca5(
    phone_number_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__859a92bfb5e70c384fa038eab8dfa9d4b249184f13a2cac8a338175e2a23cd27(
    pool_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__de6e6e77656508d83f7f68b5944309ebd58915b0a72d4499c6bf9b91be64f04f(
    sender_id: builtins.str,
    iso_country_code: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__63d7a1cda54aeba2922782e1360c4486fc833ddbf0a8c742733af7c080ca3408(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__22049c913363b17c9a0bf6a7767e4080d6482dc40b7983fb78466e6f8e6429c0(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__df1ea6aa2e4f5dba3b1b5adeecd243d003e81209ddd095aac86cde5d2ce78ba2(
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__415b46c4108b03c48d4bbeec789712de0f52e99a4ea51d12e5ede27e3274f994(
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__84225be3dd2592028e1d0d7b399d79d6e610b9f9abf2dbffdb74318533678652(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4cbc6a0e2db3b6627f588349344eb95a8d2ef7daf88f111cf56239c1ce7d0f2a(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e9afe3583a13b4b86ded194ee791d672fa675fe01a3de17b1bf7c08e1fadffb8(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8c0be3a9aa08734664b4fc64c1051b797792265c2a6fadeb0c9820d2577cc1f9(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__153699a4d5b49cc6fb524caa1ad31ae0e4d21f42eae05b5b36ab19ceaec8627b(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__73bdc44533e63550d9e78985f09dfa664906aa7dce47a7335edd7463d09b9c72(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__372dddbfc823b08373295d671ab1c9c74e7f19e54eb9ab3ecdb773af8e272d85(
    topic_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cf1e89385bfae51ecccb35308d61d17e1f52bab24f8acdf273adfb8b4175550b(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b3a9e8c49c4319f045770e135ca4890c031ca584371289a624e76900264a7783(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__307bedf56a508d015807ea5592309cc0048629a2f16412887b62e94e416dc870(
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__17eb2ba9fea790b7f15d0ea82ef40da0bf0a003d80e8fdf1b5d5ed4886a4f293(
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__386930d738d50856cb0e4eaf306064046b178ae3f48c1b1882a20e148f26e317(
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e671b20ed0a690b4a05021fa68616fd6e21623e251d3494b6c2c9105f91145c2(
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__80daabbbd77d1e438b1e8155ba1a5fe88e4d56a630d39766636dd3a029bcb922(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__100ec1b9b86b7870842b4650a09c919f47d533b31d42b7086d222883ad8dce0f(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__20996415c184829a62620e5aeeb881375bd12ffbf3f3181e367098ae1f35361e(
    queue_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5952b77f830ca1cf438ecdda0bb5965d129e42e7d01c4cfc6fb22ade605e3c5b(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4c2287fd3a2092de8e73aa8188fdc927ecdac9bd038ff92f58f34edd123d5f68(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8a288b787f43e6dfcdf79d96ea0c04383caaadfb5729aa80a49e92ced648b0d5(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9c11b836938d9d11bf9b922a4eba778e4602e9fb849c7e7d7f6878d10f6363a8(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__79c288869eeb4c08e939f30a8c19fc6bb6030a98984e4ba3fff5cf12b820ce52(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__61169003391da8022d8e921c7ca689e400e5b46e1428c1a6ffe46e5c7a423512(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__63557b374d81fc214bb519b5a2dd60f61af373eea45dd46bc9891d626c2c38c3(
    tag_key: builtins.str,
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b59047424aae669ff7b2ca74cfaf2861ab28fc1090c417f1d6d9765e98d9c7c1(
    value: typing.Optional[builtins.bool] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ee78a5e5214d8168436be934338d4909c57ee2a982395cb780411fa033a0c788(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8858b3ed0ab05baed507da4f2b655d85a2ddc3b99467932bc40af0ba0d8617c9(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__63d34726cae3bf54acc7e53bbbd498a179c96290697813f9ac23b6263692da64(
    association_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__015311cd3855957d4f19eaac253a7c3ec4bebbfe7bc78e933c4bcefe50182f87(
    automation_definition_name: builtins.str,
    version_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e1f8b2c1be534afdfcbeb97eb308f8e98fd9aff1979994af3e8d3262bf0f3929(
    automation_execution_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__631c4c22026eea95b376d4e5922cd8ede02f46ef397009d304fa7b19fd4c3193(
    bucket_name: builtins.str,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__02352e33d632779acccf7f60960b5e0029289374168c3a0cc625000423816a6f(
    document_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3c94e9249304fbc327295b43cd5e88762044bf9759ce94ac91101d414e2b9e51(
    instance_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b4c7f3ba39e5b850a0804e229bc268488b00cc54b0145d60e2ba51eb703ab111(
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__60de7a0f4023f4179cdb1e33e9ca9fcf8bdf89d2ed1c29655400289d7b58f41e(
    instance_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d955ebbc774a7f4ba6068417fc678679d434b425f467dab454295eaf1688a301(
    instance_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8b32a0d9df7c215ef6cecfb7160a45caf3979d10a21b7b2bdb51e2066274b4af(
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b2404499ef69fe959b97333d4e3da566ee9caa5c3ae10320160f2501e96a91de(
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c88d724605124d1a43b3a0e7f4c4193a66d0df620f6a9b86eb65d8d174cf5606(
    parameter_name_without_leading_slash: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__08f1336bbbab533a52e781c5b3e70f3f4c66ed2e645884399757ac6895332021(
    patch_baseline_id_resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__04b8161381bc5c675e122c8bd3bad4d822f1a34d5f865dbb441259cc7cdbc010(
    sync_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a46715388b50704574e1283dd31bc550bfb8e68b31b1a278fbf8e27fd11125cd(
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2aa9ec9450a711f810483308b6c4182411911a265a0a1c0ae6f83fbd153336b7(
    session_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c45b854687dc6bda37b19b4b26a8609f6bc36733d6621cf92a163f563c4aebd1(
    task_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9aaed0026187eb78db95f9ac612000370f5f4164bb6234cf127f4e5a7484454d(
    window_target_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c8699d90f5743aa421378b5ec2966471694fffc27ca9918786f8efedd58c7f0a(
    window_task_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__83421e85744b060ab8bed456149ea385890368217b8670be522e3f72f30867cb(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__06312c7329b85d34e7013833ff47570ff02b88739c97cc9a5248b34a6529ba39(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bd2802743740474fb76e530e28b76773948261293aff3db2ff60c295689160ef(
    contact_alias: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__19c5731637c76cc73ab88745aed38e6196d7c9b649ba10cc9edeaca904c3f9c8(
    contact_alias: builtins.str,
    contact_channel_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8a7f6a55ffe26e86182ea73d3b82a9c79d3b832c15a9f8cdf8f63ac137017480(
    contact_alias: builtins.str,
    engagement_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__aeebb11b41fcd9df199886c765cc58722b6bcc7c715c6d1c7ebe073bb4ec8a44(
    contact_alias: builtins.str,
    page_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f2873c6ade2c61abf0e648122d2de66101819dd0ee8fd92ce63a254bf6ca71d1(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4fb80cf00c667e83b1b3a1d72eb38b388fb3884c941c838ff9236314836273aa(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4317ae7277acb2ad08b668bec0ee9102106561bfdca1ca3645aa366a5bb5eb38(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8b998051aba785635b700b8d6f014fe82b5ad138d2acb63bf302824224e0e4a1(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fe39e9dcd3e3d12b46232a2dc0358f47b8c629a9ff1eb1440879eca4bddd8c0a(
    response_plan: builtins.str,
    incident_record: builtins.str,
    account: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3f241253dd8dee01ba72f41a8f5bdbfd65b0887199ce734990a9d3dae65425ef(
    replication_set: builtins.str,
    account: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8c7c1357f884f2a2e3da57e2f6ae71f56cc28ec2002604b3dffa2746b02589be(
    response_plan: builtins.str,
    account: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fd2137d103bc955eb8909b4720debcb23c7349b8bd0a30157ab532216c95bf32(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f59307be424033966fa85d57196d811c873f021c60fd4c657f148840c6f08d41(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6d327abfa8709efc8395b37a01f81d1a31adb69cf97b851e5d24995a7c3fbdc6(
    application_type: builtins.str,
    application_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__31a92d4d321aac370a0b24d3728971aeaf7e98f75b57be48c443d8482531858c(
    application_type: builtins.str,
    application_id: builtins.str,
    database_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d38fb1ecb5165a9ce5246a40957b8d46ab8fecbf6d31d4026da75a0f5b75cb12(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__208d6613cd947b37b66c83c7bbb4dd250d68d7b0eb5239864182dfb418a46494(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__36bcc948cc631efce07c90c39fd3297cbee20805c5778e25c9454e5623270362(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9c7bb119b02a550f1b56110137ee6931cae32fa24b38fc540ac84896fce94439(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1702d2754e5720ec485210bd006e3ff463833c6b80b405cc2269fd70422bb1bb(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a77f0ee5f1935a71160bccd4f8dfe7152202b4145113237c5cbb8035d8154b81(
    account_id: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ec5434820943d0c10203eb7aba808e00457ec135b330893e1da80000a9c22e94(
    instance_id: builtins.str,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e85cdffa870429a96d8114bdecf697e3a5cdd88ca647f5a3dbaa1cf3f000bd48(
    instance_id: builtins.str,
    permission_set_id: builtins.str,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__807830123c5f8135f1ed4edd98f8aa80c854f534ef4aab7162bdc9b2038a5a07(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ecad6b02c3dc93ab8f1c1a2f97b8282fc434bca64ea4b0b20517bded46579045(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f64a7a006d765c18949b5f7a79044e57cef0e6ed79463989427f08321374be2c(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__787c5d11a86646b6b27970042356df605cc6fe5c8f70541d00377a6aae80ab97(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__558ba3042ff4b7351291ebd20a1b767e9f199d6b57d15473ecee13ab80a93d00(
    activity_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dcc5706baa3ec6bbc34ee8287099c5d058630ea300a8199d30663733b0bfbd06(
    state_machine_name: builtins.str,
    execution_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0d08cf01154de0c11537593158b6927755ab95989e86807f2b7de4c5641877c8(
    state_machine_name: builtins.str,
    execution_id: builtins.str,
    express_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0b8604faaed45dad40dec1c686583ffcb385b125f321f0a7f5de732bc9f00070(
    state_machine_name: builtins.str,
    map_run_label: builtins.str,
    map_run_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__371cdc5cf9d6feae5473d04659722a31f0bc75847446c19f06b25685c5d98239(
    state_machine_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5e1117abb17bbbcde1b74f5e12995845b21c4adbe94a606d8ebe0d1f023e67d8(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__18ba367d14016da9f9c8368572c4f06c230189fd9db5659134123d92c9a28793(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4fb192b6785fa11b7d9e641be419a29f7a6f39cc9ba47d66e037918983039438(
    gateway_id: builtins.str,
    vtldevice: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a077a391756bb466ce8bdb6e922f29c9145e7422b6a5ecfaeef1d6a23e710176(
    fsa_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__af6d28bfee531ff5c157dae0e63e6ee8e2e421f080ce1fdc9325c4b0340bc617(
    gateway_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__754341200f2aa040d02b5786e71846d9e73e45015da100ad54a24e375bc35306(
    share_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__90706ff6e78cb2419b55d1f33749338586611630676fa6f58e363dcc2c10cebb(
    tape_barcode: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cc253ecd33a0941efee24c35c9f89306c75108027568e7c78f5e53510fb972a1(
    pool_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f9373ae1594af2143e0ed9397758480e68c2eab5f307b257e0b881d4f499f92f(
    gateway_id: builtins.str,
    iscsi_target: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e7df4aae276d6f8fa82ea0d8ba45035d48913bcac8c185595fca043f0f37318e(
    gateway_id: builtins.str,
    volume_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__747483c0586efaa80b3694c0ceff65a12eb42d7cbc7ea75e061082899522fb52(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5477a0cf3c58a98765b4b40e4250451f457b6b4df6abd5e006def792744b7fe8(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a2c759614d4b8558b83546afc917963ac19bfc78c4e9447804e544079855e928(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d6b6f0853e6b91f7fc9e02a4a655c45ee8bf3205be180fcff36a79be715569b3(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b4aec1e3c4663aa6a614b9300304c2776d349b05b5ae8efc8cfa83f448f329ad(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__853ecce3f5e6fab97ca602c2c4e99d6f16a45dc522bf15cab7b68ec0e5a94636(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__17d8e6c76055631872289c3e8d24ee38c76de1bea57a410d4e63ea09b177523b(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4680cd004bbd979042cb5b1a7873a0490fd808b2df4b4930a5cd1490de11d04f(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a6de4f465dcd0a738efddef4345c614a6649b56ff4008aa4765c9ebb252d1bcf(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0e9fb7b7a13eb830676b0fa1b406edb452b1484483304760ac97cb7bcb4731af(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2adfb871892ec25568d5b621486e89858e6e62ce22496918bfd17c71cd83f675(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__22a4bbff581ecbd94281f7b424c1126c5a25ad71b44a5e7b40bd17c55aacbc91(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__37f450a86b7620e753b650379122b9f79cdc27a5f98706e9044df75bf99a0ded(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__31619025761030601899ebf15e6a13ccb0e6dff972f7ad5830e43945651185c5(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8e63fdd93df0f3041b3eb73b3fa8df52304766b7e66271235141c5364d31da18(
    tag_key: builtins.str,
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__13ddd99b0b5fb19ad0cce179867ca83dfa14ef04cdb02ceb3bc45daa370e398e(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1c22c1e619c27f5ca8a285af071766a4376fc7d6ed5765d3bb096afdb3249c1f(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__38ace441d93b8f9675cc5d145fd8f49953736c17356c7955e43a9777e7bbb499(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f6d5f0eca6e2e795dd32d996ecf0f565a41da6eb4f54ebd59acd741ac0a22d37(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b0bc5716e60092c110295a67ee61c6421c3bc47069be90eda527fab94f3419cd(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8ab353333c06e64c212b62f95ab2479c5e7b411b8fe8e4484df68aec3cf35ee7(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dbd69e3fe3bef0b207655dadc1800e9e1a81636f8f29df9babb8a72d2295fd07(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0cb95cea91f1d8e4323fd1f047bda86ac7aeaf3b991f69854d2833f8b2d4960f(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4c9fa3c199fc49e13c7ad97d846a16862cfdd76f5e47f2d6a32a599313235ba8(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e8c7d21cc9aadfd734a05b50430aa0ba7ea696e2332e28c98a735dfd8153c322(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__28f5cb644596480ee0d1a7a132053e5c38b85335ac8eef0ca32b78b30b5206b5(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c1ec37f70d5a2f89ff45e6a41d7a41450bd399913dd713705437feb621920846(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ca0b120523c02c29f32bfaf5b0efc41c3b5a78f28efb6255e97669c58f3e0f1f(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9fac7695ab648f98d096b20905a91ff604219d1d216fc0832c664939d14a2dc4(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bff1f2ab4c405d8b56e32aa50e2a7a36bc591aee6ec013e0d6926b36d55c1010(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1eb2fa344123238c8d768035f77a5509bfebea97901df258b6427a77604ae767(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__31ab88dc3f3558239214e9f09f7a1ea9846cfcb8eef36df9e63e239013d4bb80(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0582edd00d3146615474a71987788e6108be2724a658cd232435502aa491bfdc(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__980458e9cc0c922a14ca3acd39a5576a2b38aa066358ea5e88b8255085ff4773(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0d66e72a60981a320f631af33471bd7bc660203ae27f62b9bff8d2465056cbb8(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a6b2ddd7c77cf94437187b3c51aac6a406834e15163d08920e3b8e8947d8319a(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1ac44d3a357285e61cb7134822787cfeb8c227aa7a0aef525ecefb3c92259e74(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9ea542fd9dba04c3af6c2a0fb22faa22ec72c4ca712ccecf17ab5a1af13760b9(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__349ed7060f7c2a2adf5ff1780c88fd8304013f13ec8333ed86d5a1c3964a4ad9(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4c92a122166c8bfd0c3b5436860fde46f6c97cc5775e60de8b9e89e2d2129a40(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__23cabc67567b28be9a78e0e4a97c110f03acb4fd482ee4ab2d7eef94c5e26e34(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d1963e4b6c07c81c8d7430592ce068fc9aa292a4dbb15b4ed0bdabdf64ad911f(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3ebbeed7d33f67ea228122d7e1e1404ae1d70275acf5d49c25583d7dc7cc262b(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bcc34ee9092bbc3bbf003bfa5c9714221cafdd9f1e360f8da353a165fecc6ea3(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ebc82d1f1d091f6d14b50f4e447c1f1b8be7220f25920abf894577e54d9e392b(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c4b5c80181d99df02d745cc02250e5bbcbffbb47a4fae221566371e09c894535(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d95fe063b18cd7832e24c3572cf4c55a0dc574112a62e96dcc2bafcccac6897c(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c842a861611e7cb50c42c24a59ac8d51c767b2fb754b09be15fb8268e6c7cf2f(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f8ad5b561e7121f6125c2ad3c6ac38c7397fa0a1f53cd89838fc4cb087274285(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e2b9a791c100a13f4c152bf25037aca8ed60327a16a918fe83e417ff161ded30(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__255588f314993aa0395ed9cc4dff555c9bb105c2c7609fb9bbda37b3ad9de942(
    role_name_with_path: builtins.str,
    account: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__87e8a81a902fa204ac69e7302cad47a6591b537684963fa42682125dccca7418(
    user_name_with_path: builtins.str,
    account: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4b6c6eec28c374d8e0b586dd75317d97345bd1bf6c4843cb305cd8534cecb9f4(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__76089d1a7ba35752ae871b0ddc92f97a675b232e62c38e94c24ccf410b5e021f(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b48f8362b3fdfc10981b0d9353fd4d7d8813b1be32444b04010cb73be0579fb1(
    project_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5d87dd2d37b900f7e37c6168d484d40acaa3d87cdb1cfd0a2259479e40a3ed17(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9ac7636a6ba72a4c6be1a0e49735c522fec46f34921a32fc445110314eeb33a1(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a8b7b0facb832175244fdf7f51b86efd18b15d27ca3a4df3cfe2f519821fe5ed(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e316dd5144c78a5ab4f8c8765c8f0964d7be1e4596d1e76b0a11ffb6766f3152(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ed2e3949482eb35a32d1f371184808468884f390d9e47af7efdfcd7a9b2b1809(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cd0dd774facf188b1879cdf6e3447d16099bb77d04999b97ed8a097e05638fff(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f22475b090ba78776837ac81457caf95deb3a2e7a61746131ff0035bc95836bd(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__db2c88ccfdff90c496368fc990e48e68d9ea86e557ec23954a124d0127b6f3f1(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f3c99cbeb61fd1b21060fd022c83316ebbb3cf1eec25d41e53322192b543b3de(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__08ce2c16b36699c5ca34e20771a88bfe4f4565741076aefd08c1fed1c7cb8857(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__78b14464800348270c89eed751af8ba77e3f6dfddde7b590cb609b0bc7aa25a8(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fbf8bdddfa348fc627795a4eb23d47f4b7669b8c17af1078948f3f4ec6c62937(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__807d6841bee2f334aee465ec147717c78a5e767154f480ac77cb30c2be412a0a(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ef9323f7cdeec14af84ab064a797f71d767b42df4255865b33c38709ad06da22(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e44fe08b340b977d1855e3db942ddeae2ff78b379545463a9654be82d39a89d1(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8421840701470efe4795b9284cbf7031f94f74aafc60e6da9d26110107d870ff(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5bdf0f8ba5be833636f4ea8c09dc45891382f09da6d32c04d0b56b823eab4de5(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d0c9b2543b617e07bc386b6e63aba860650d8d4d30824305ae49e04a7b3f83f0(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5ca3c9b2424fbae567168f702aef0e9b8640969104252bb907e2e3a861a695a7(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1324643c42370ca7ff06848bf02b212d311d5ccc24a108eb99e406c6a3b3afd2(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0441306ade2662caa1d5574c896a7af1d458f33eb6961173b824824cd3a666a0(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8842c5b9360baafcb9cc0c2f2a04c5a79fba20fa68e23efe9c3c672241adf456(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__30cddb9a39dd3ea007166d1cb541ec81b4cd961e3018ffdf7b317c64f5909588(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8cf5bec312273a2937868ff3fd8b3a17a2f64285cddcb7dbdb7fd42de26296c9(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b451b965b43cdd7273fa4ad1bafa39327bafdc7b5614be9fb483ba3d64faec3e(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a2d908aa5bba9c6d72f72b9740638391ca2ef94e814093383b857b2691d43633(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__df6d984885c4061a58d1e242ed0a1aabe7f592ee839a6d95920492f8baf50530(
    domain_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fac13df42dd78b67a2ac1ef0cf8e1c6cbeb0422ff05bc1405d636aacce2fca0a(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6f797cb9c81efead3438322b3513ee4158bb5d7dcf867561007c2f713185ddb6(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e6bed424e387b92d6d6f2ecabb8e8636d8dfb1c377535c163db13bbcd5b8ceaa(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7c5efb03621519fa048cec5b0f49f3cc7672ee831ce20e9c6286784cada6d05a(
    canary_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c95bf38e90991f47bda738e728b5781a6882e904de5f7bf416ad62269dbaad4b(
    group_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5f90d6ace9854dc9266a7df7d59bd90c932ca2875c6d7c3556a0fa28fe6edf55(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0d52604abca1c9bf404fec2f3d4ef66ab8f89e9e94b26fe1c8512fd6641333f0(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__097310013a9d4c32e004950302c7cc8c0f03c7d901ea568f21b9cd570b4104e0(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8188cff1ad06909687b3171519c3d7d600dc270836a541bfd07125cedb023e90(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4a8794039d9f5cbd3ecbc991bd258909d243c498c66e050c916cb50ed993da8c(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5c1145fbbf21b9258d486c7ef6945cc77602d36464f702f1ff343d171685ed63(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__281226ca7d3eedb9fb426148f0e404c2f64d7e16ff1211106ec4e03bfc130ec2(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1e463d01b2abbf6df4415827351569054d191c22fd771d42d44016d3ccac1d12(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bd6de4b01f2f405e38564c05eb2cf3fbbda04ee654cde1c51a3d1f7210e59983(
    database_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__08cd2bf44308e100381ec3d1d48f803278f18f60eda7a28f027b351fc05fa76f(
    scheduled_query_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__88e67abef72635298aa107de332c404aa4e0f45bf750e4b3ff5b24b3be454f29(
    database_name: builtins.str,
    table_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7cd784726e2e4bee6ddb98b9c640ac0ef8a1a10a95e3fbd48b7d1407661c1a1a(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fb967273513b19347b3b9038a5d9787f818d66067e319b59fc887b90a6c0b7e4(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__526d91622ccaa78ffd22e10d149f43b781918e61b02e94a8fd1a50e3268a13dc(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cb99ea2b44d37b314d7038aa201e2c078ef7ce25781358208cf162b1174c6a70(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3fc61e29a026e3641c460043d79e8ca9621f5e59aa4cba6823f629d68b74a810(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__283d530f340124ace9020096f553f3d66c3524de24112d74a5174dc9d6ddd2d7(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__97b238bfa538feb503808c891ae95ae690c44ba8eee239f002ac705694b4a415(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__372d9c16a061517a537b0017740c5397824c639166d71f9424ca4a93629e864b(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fd65af44c4ac29bd3d663c01c2273bb2ea0894bb46ff020f2152d53c1e209e9a(
    category_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__10879745cb2d4050d8b79f544bc3538071e4e7f30bfdb477bee39920769d16df(
    job_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5c500bbb3d7b4186eeb032c344fd463a0ffbeddbbf6eeda2d8a6bc46269374c5(
    model_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fe9db20a4cc2cd5b23eb2559e16f1b5272009c598af0b09b643073b847085135(
    job_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0b30fec53aaee1fb040b5684caeb65126c8089f67807ad64274ef1855e1f94bd(
    vocabulary_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4084182fb6e01dd19be61cea182c62137dfed2d63cc8e23f5f4e05124c846828(
    job_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__463d7297a037423180e4da381cd677a6ec337d93a13e93e8afb4b5e4ebfe089e(
    vocabulary_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7426913f354b5fd3aab9b67fb03b80fda07def73c97480e51ccc56eebce2af61(
    vocabulary_filter_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__84eb638ee40cde49671575ccbcc91a9e64362ac21d04d541f117f1e17d2a1ec7(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__709db907f71c80ac562e129fb5704d33518e395e0b8427682bba4fa2ac61cb3c(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__96a9d7fd11f2dee7e8ea1618e2df515f8d017637d79e132db55a9651c8433f67(
    agreement_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__eb11aff7be7b7ec558c563265af8990d3855b050e2ee660bd94fed2d12bde152(
    certificate_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__99c3ced0774a6875f445ba98338f7d52b9e661904bf31844a80dc35bfb3342ad(
    connector_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ed443b0e45e9ce61e0762a7a0710ae04a3b7915b7d8ec6a0d7f7910c6f7599f5(
    server_id: builtins.str,
    host_key_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__31cdd5cc17e6057239bb020ad87fb87610385a365f920da117d50b79dedb5d3b(
    profile_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e2635540b3dad95ab39a8b879bdb89b2656156fe2dd53af81e22f6b5d3e1cb90(
    server_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9312edb8ea9468ac5eb32784664cad6277b223596dd800a2dba55b714f61b30c(
    server_id: builtins.str,
    user_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__458e6e915d489fb8842c99b696b67ae1dfe0b6c57fb0a890a77415bfc18cc6a8(
    workflow_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__256b17bedf4ba63110c6b554496d16e89c6edc47da10bff85e730d2dc424ff30(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c336443460b9597a021bf56f3383d44c3069449a33ccc3fe38bd67f416556245(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__748f0ab86af4b1bc8e0746b5befd1437a9ed6172d319137877bf3bb5ef8ba4ae(
    resource_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f1853b33f97957a242a1e8499fd88a9e200f6ad2417c3ee26ce57b356d2b6200(
    resource_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__00eda8adb2172f26899164662c772299818c0a27e70848866f8fe286979fe137(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0b8c31fff7b6e2541c1562ca6bba79af2bbb98bedd72e4b47647dd1a6d3c584d(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1128f062d3b22c35c367c1c2c1a640fdd6dbd7a690615ddca297afcdfc7eab19(
    category_code: builtins.str,
    check_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b991861e2a98e906c8ce6a3a7ac981b34a65b7289b184cd784956fa7351190ff(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__99e7c39111cc6b742526c0bd19666e37c293c393384430fc937426266b5d3bc6(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c39bfff3803114bae6272bac32ecb7d29c61f5251adfdb547ced9f0e2cb8dfda(
    resource_id: builtins.str,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__492d27e727822754c2779a1861c19f041432a6fac813493d48956870f59d3292(
    resource_id: builtins.str,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5c237feaca7017a5693cffb96556b9fd0677b846387614e6e81f72f642f08df5(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__70c54418264771a9c2ba0242520ef5a4ba727699d616a54f467261264954851a(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b329a589724c8e883145f9ff4e75c575731605586f87c0b1cb9cdba81b34a597(
    domain_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fe98334824eb17a1ae4d848cbf91ab37e9ad13623e5b643f2f9cca305e625eda(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8946f78a08190edfedc5fc7022154a8d88e1965381b5a5ecf6d447e97de5b70a(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4d4cb29766035c6785047e49a48a81b0eb1c104b39eef688bc9283390a85e8f0(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__06dc83cee1a57f4b63a244030a489faf44ffb6c23bd71b170b89f77499e850aa(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__02a6b596dcda22f265a44c0d14c6e255c39f19de5c588ae7cf0902a15825b04e(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3baffb97f90768ee2e7862b9293b2f08151693e7e02bb51d3dacba6c6b20a7c0(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6dc87d9125c6b2a75ed823c2f414e8a259b808591ef71bf511459d53559c75f9(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__82e250decd8353c559de8c68362b873476685f132e2be49fac4f6e6c9b4766c2(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5af25b014132e006accae90abe7d2f44fd4cf65fbe8f2cf19754e1c3d7972085(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__922f100acb4371c6666b1ced0e6ca008b4f7d23c66d5a165f937bd854483b296(
    access_log_subscription_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9d62e4739e3c45e96f9a00e10b693cc6f34b45c1af1a50a6c6cc94cc7f707cd1(
    service_id: builtins.str,
    listener_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1957959de0609820c66db597e44e46eda2919dc1e9f94838206ded02648ab031(
    service_id: builtins.str,
    listener_id: builtins.str,
    rule_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7b4062886ab0915c0ddfc465b8415875687cb896c5be651e554262df2b615ecd(
    service_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fd8ef85439caad5d64ff053af93f824a950e1618c24ecc5c32fc0d2cb32e1ab1(
    service_network_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6246f08febb437b74665795b16bf99b84f65afd824422b4348786f7e585f1348(
    service_network_service_association_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7258ac89ebd894b17ed4ce723e2e6f218a9be00c5cb7e8e32a3baaf0833ccac5(
    service_network_vpc_association_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2affbf42ea3184d2ca4f084740013a862b0ebb115067ba41da8cd74cd0191f32(
    target_group_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4c242774037627b043402bb4bde53f102f0de7edf586de9cf1725b92b17da00c(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dfe0638de1707024543363fc28a20415e82bd32c70a770a0c287d4d9f40067fd(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3b88b41a34b7d16296ba6d311a3197c8e98634885d063f79c95599eebb5a4cae(
    value: typing.Union[jsii.Number, typing.Sequence[jsii.Number]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__24b9b5e982036271f8dc8fffd756cfa3d9953bc1d8b4a8880e838074c532507c(
    header_name: builtins.str,
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b9c02a57ef2c1ff8a1cac279f0da0f59558494bbda2a3e83eebed3004906fe95(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0faa5050134d67a26d24e7c578fcbf03e2caac45d5dd6f9d2da10d52d73a3b20(
    query_string_key: builtins.str,
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e4b9e3d7a1f4fefea3a1d9171d204da29e17a105290007b557860de4a28f6bf3(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5b74664e4c0623e0669f39ca3ec5fe17b1c4de5987c0929dd5e218576497c468(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d62660d41119635ed50dc335e38a850823d2054da6c12f54da255d4eaadbe57d(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__416135916283557e4b223098c7be2ace8467dc5c6e22fd74eca67247c4c65ba0(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__af27088006a148cc200fa41c7d5b43d6d4c044c4c719cfe9297b12b97a5c3d18(
    service_id: builtins.str,
    request_path: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fb9507a0c13718f1f477998405e2fc7a6893ebd17b835a9c91ced7f735e94fcc(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6a1653b55be2e6c6a443e0bd2661d91f962249fd746fa8acbd5d8da48d312165(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__76779c1a4bc34aa4e430b156d43dd79891bebaf965806363738636544c593b7f(
    id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__acc2fa5d84be641300b75cfa40fdc39b032209f46f3a6021adbcc11b31783924(
    id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8453b0d114ad750e981a1e76c9caac2ab014736ddb9d19d9a5f7baff5aff056b(
    id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__de63cdf126c9dc98918fbcc4b3d3ebf18eb00ff88d8c18ac93a3eafa26a54b41(
    id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__430640b363592b50cc79808bea096ac4863032072026b422d713ddea8d589cf1(
    id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__af2e2edd65f47160fbc1f7488e0d16c9174c22a56be6daaf8ea0741d84ffcd88(
    id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__93a27015a79034577e4375acd25824cd697c471bb0f113820ffaf8b65a220ec7(
    id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__981e99a2022b9905b90ef37e238ca7a1287072c81b9670b68b8665a954dc3842(
    id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a4c243c7188fd23cb4fcc3defd22dd01bc8b1eff4ee1326a9a2b5062c61c0c66(
    id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9d8ab5d328169849691838a4a4e03a9a8b104060cc6432b289509b1ad9a859f7(
    id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c09781db5e19fae2a2d35425f7734d80e8ebc99ca0da87288b10f73eea706b0d(
    id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9362e89caf2967e5b481ea340ae7f1ac8e64e4c8542bab826fc84b8e6b730c9c(
    id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e2d29aae26c0ef16c0ca0062c88c8e1f2fae50f81e6943c792de0b7f7a82e26d(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cc841cff90db1da9ad8a0b282a945b0fd0e1d69ee78f0b93653061e19951dd1b(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2d65006b938169e53b186ae89d1aa564e84a5d882c3059c055a378cba2184d15(
    id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fae83eb3ea85ac923f74f36c70eb4da4c60bd1703197a0b0389fc1eeeacd38a1(
    id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d2afe0c585e45ce2b1f0a348fa06a6a6096f45ada007de965afb5a41d56707c2(
    id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ff6e6060086fd86d8ecdd76bcb5292d181f330a550048ebd951bf2734ceb1e5e(
    load_balancer_name: builtins.str,
    load_balancer_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5941ddfdc5f667a4168ababeaf1e23086457b5f83bd4d6e31376e37e7572cf77(
    id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__07397effba45535f45c8ec946ea83acc1e6395e0d02c31c6bd31d97a5474f358(
    id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__afaecd1bfc4b39c4c870e787d122c5957643c5ce64b5b76c9186c20a0c6391bc(
    id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4a7cfdd747a286447a5aac4e78d8634e62921b2444ae015d85c5f0e544792b59(
    id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8144f504b3e53084bf98b997a88eb99be203d03c1bfd2820a00a8f0e48109cd9(
    id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b2e8dbb15d653074a91eaadb8e477bd72a4234a8602af8074ccb48b954224e2b(
    id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f0eec7a748c88bfcb04edb7389536a4d9683b8ff3f243886ee03400b66dfce29(
    id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4262c224964314d9b5ff9c37cd11d31cfbb3015d99ee92476c32326c35c51b64(
    id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bff643d66050efaf5e8c58f018f8adadbcc3ffce8d3148c4efce913eff5afab1(
    id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__520e6238384bc42fc4bdc3972c026736c5394a00b96f635faff7b7f8feb19a58(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__77afe2c4e774b3931041a46e0e69b375422f9db3fc4253d065211099d62d98da(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__89cb2198b3175886e9884056b819480ea19773565b4796f56ae88d9a239f8938(
    api_id: builtins.str,
    stage_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ecd5636b9db99c2490c60c96682e2121dac6e86a51602a4f2981cf66d508cbc0(
    graph_qlapi_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__936375468dc7580eecfa9538d61bd98911b00fc6ae47c1539bc1b9601e891112(
    scope: builtins.str,
    name: builtins.str,
    id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__64f1d339d04272a7743c82c4764fefd097151937e61abd8828b78220f82c4f2c(
    load_balancer_name: builtins.str,
    load_balancer_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cac5401bcaa6cdc08fdb1642d62e861136f632cfce1accde60044598d7ff4ee0(
    scope: builtins.str,
    name: builtins.str,
    id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bd7fd8782c053fe9102a5c5102068c348b7594fa2e15772ec188ec12d08c6a34(
    scope: builtins.str,
    name: builtins.str,
    id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1b6dce75e44c7c8ea703422bcf09fab86847bd84c266e6ab2fc170baa5b190d1(
    scope: builtins.str,
    name: builtins.str,
    id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ff71cafe0f53ce8aca997e76d2c220c4e4e2601ca5a22b37b4c2aa16b23a4661(
    user_pool_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ca2d1199a61b5ac370190d3226c21fbb095e43708de83d74c5d3211eb233a13b(
    scope: builtins.str,
    name: builtins.str,
    id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2d8a852ced943578df863aabffaa47041d14be45a00885cb35fdeedcf3b5efc5(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f5bead9f41fdbeb8a2ad5ce5dcc8ad572d6d5c4c27a746b4ef2cd6cd3f5979d0(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__273aca2911dc9ce070dcbafabc645500550bcd8df7ad6eb5a58990cafb7a2cd0(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b14d2d93399d618ce7633b3b7f27b82236ec0ed24c9657b2cccef0c1fd25afb9(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0a9b6615d1fa83c148cb04e24b5cafc83b067da60a3b5a73e47a8e1c793e9712(
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ee951edaafd2d64937965d83943c50a9a65732ac92a61384702cf01c1b37f5ed(
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__54ac9ebc17beb13824dfc5aaf774ac49198130637b43206a68cf26f4f76906cc(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__97fbf4845fa86ed93ac2417b32ee854b6342a49bcbea4f52b1e80851b5e685e0(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4e0713cd32f8bef53e9e4a5a1e1fcf8ebbce3db18cac5d55efe3d52250b37dc8(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6d18c58daa5d367e518e07d306c7df5ba8fe6225efb6712957f696a8ed54c5c2(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4c6f9dbfb753537dde4e19542aec7b84a4be0c9a4b72226eba9c2b1ea887aecb(
    assistant_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__21e43f4eef88ed9761128c4979690bb6284e0fa5f0a4c9d666c2f212f0d79583(
    assistant_id: builtins.str,
    assistant_association_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__76d6c5677d39d4494d50ca8e11068423ee4f12d12011f874c2f82b8f99de6614(
    knowledge_base_id: builtins.str,
    content_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1b4f37732295839a3ce1d2c4cf78a54941bc2a6cda8c7facb83b9d84c7ce7671(
    knowledge_base_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e3ee43d869967d26dfcfb2217244b2b93bbd2f15008b0e71691261d0193ee9a3(
    assistant_id: builtins.str,
    session_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__331c4134916c6efab0f48c33424d262be30e1d2ea042269d889ad612623c2306(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a5ca4df6e15de9afcb93db9aca6d365757827f6d10da0525cf6d579ddce671c4(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__62945e054ad0ecd19f49bef5b2e860f4ebe8e6a1c29c6e78bf891c907ebd6c14(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e6a127f6a34ad8b2c2a8d9268eff9e251ce860053e258811ee00a3b09397cee1(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e3cdb8d0589dbde818b9af4ec8344c2ab6d16b33af199f9870ce2d392945856c(
    fleet_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6f24714649555ae2ee616a96e0f18e46c094d425fabb30feb93d33b1a4339e92(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__56b671a73f936c5fd00fbc4c1db5a00feece6443bc6c00ab6d0c955fa8ddc7cb(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__06899eeb1774d361c45d1f8ad1a3810f18b2309815c4a90dea187b5f119b9df6(
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__539e20888d42e55104a776fe69b7ab084aff1d998ab2008aa111138a9fb077a1(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__492041d5da269469aa18f0ea16a95b18a67ed48ad3a06a91b000040c1e3f1489(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e47bb82a2c138eac5ec45ffbd8a15a41ca9dfc344bcf167077836d162d2daceb(
    organization_id: builtins.str,
    context: builtins.str,
    message_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2b0794a2aa163e2736146a5511bab191c6417d030f29782a1656e82c8b8eed58(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__45c77c7a7a34dfdfa057614f891cdd71f9fd27c4606dbfa88bb4e848595cf463(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__be7dca1b491695c4f8ccf75bf614203cbfa154d46dc97419249c0362e1f57405(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__daf8c0ffcd4a7f152ab3b8bce68acbc84071b7858fa274924b32ced297dc3348(
    connection_alias_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__38a9d26afb12f55c0b89f4c35dea55fa22669390a1b4db32b96f02773332ee6e(
    directory_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__eec046e5f4517a9c30efe420e9c38405edd2e71677fa9ce3dbca6746d1675c55(
    bundle_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d3c800399ce8ea52d6741f25c02cbfd9e2584d03413bc5cf5bda2b2d1b337e1c(
    workspace_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1c0e265bb1590313aff6a192667aba8bbb71ea49835dabd4db66aae78e4f2346(
    image_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__985319aaa02da53533c80f9640eba9b4896696494a80677233ce0864fe93f443(
    group_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__56acab34efca7b88274db7f19646ad578dac75a4d96bb8a2e4273da7dc2feca4(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0a1a26277a60c9ca917f05c46815fb65e709fa961e1f45d12fe918ab3e77d280(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d246f38a1b07f4a0cd60aa268f7acf9dd499cf7be8a1f4542ea3c2a1675bea7f(
    browser_settings_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5534bea05f39e826cc04f83586cf239fddff1616603ea3df05f5f04ec072a140(
    network_settings_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c06fc6641cdc46d52ef733acb754a3932858f3d5927946e42d9c17bc67b039ee(
    portal_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e0beec7850656c3972dd51fa5949a5d65e6da6b979466eaec8037ea82d116ede(
    trust_store_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d0206bbe0d89194bb06d5377cc5670b5e27ef3ec8b4b7687742b3b60c038f7e0(
    user_access_logging_settings_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7fe37c06c207b6beb35fd565325787e0928071a15123d596c71df1ffb7ebdde5(
    user_settings_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6e3831b20c655e12f4851744ff2104d4870c1722a75ee88ddccc578cb37f31eb(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__73c75a025197ec7b3a3935ba1eaf39f035b5630889ac4b1fcd7c7ff209b6658d(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__56360d65d155fdd9b85f88757436d6711d4a08ff4cc12bc368b305b99fbe142d(
    group_name: builtins.str,
    id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6995b439f88218d8a353ad3708d066d6f4420039f9776796250dd9011dc26bd4(
    sampling_rule_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__083aed5f6aeadd3f00e8ff56c828e3d61f5280f55b73e714c4445de8611d6f99(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9fdde4dc3c6b1be8d2413ad8549b257c4ebca20996da004e4ec629dbf42145a9(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__12e81c3324c7bab9bbce77500f7e190d2bd79cc31bd797fcdf14fd127047d292(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__df42739d7ee4329f6325ff52d9b4698093385eefa9b4e3c01ae04e7609e85860(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__099176664d52cf1a0841199166efd4c267c5f182966e29ebddeabaf6badbbbbd(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5d2b571b22b6c37916b1d0af76232eb6f408a5d2939e22ee2a57adf5dff11393(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2786eba1789b876dcf68b18fb5209e3122357545c4d33cebc9d9008fdc180aee(
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c5d941c9eeaed909f315030d9c016c17369d65da3500f08eefa2c7949af86255(
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1e2b8a75dbbbba55fc243fb44e4d229eb5ca85f159d15c456bb016a9993825ea(
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0264cd4d9d6eb29b570ab89f20f30683bf219d9ba9374cfacd08c4d449101e8b(
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__abe75982b8c1932d972ce51cc783819f16bd0ace9d386889a0f225544956ec0d(
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ce862b63436362fa657c57d06c8364b9b414070f8696fc5153d4029e763186d6(
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f8c40448d4857cf9f7486cd3a847841dd59216a990a8fc608264946a10f8b870(
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5b2a139026115125016228775042f075cbb7a94552ca8679e44f8c3f75b03b4a(
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__47c0feb90e0da664319d1a7a47d57d6903104e425816da9782790b7206ab4632(
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__81d1b53130ca04866c3232e8f7696e7735f3bc1bd7c042278be909f5e0c63b6b(
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2380ef7e1105c820133c77c6f8ce88c5d3b81f005526c15a7e514773d8e3274f(
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__100b58dbd3acd4d18433f4f2ac145ae7ce8238e8ce7686568605d158049277e6(
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7a5da53e234837e185092405110d77cd2a020fea36dc674c9319412c1dd38fa7(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__da43c715a14a1236901f9911d9c3d5a8b9ee767897a1248dba9ec6c2af247ff2(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f6814119f6783ed3acb4ddc70123b66e749f68d4f854492d9b80bd50f1d70cc6(
    analyzer_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8a41f6d5627026f68efdfa40159ed80662bc8a70e83bf23f4898aa938624f5ff(
    analyzer_name: builtins.str,
    rule_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4349597f2aeca0967d4917b23b84ce2fdbf0529d3e09fe37ab9454aa5b47321a(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4a909d850378a895e0bd067eea116897a2ed8e2b260b06dc8e77d4906614bded(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f1b61620b551217185045d1bcbd34021e63c0c0e3b1a546616b6529b00e2bdf6(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__941199d13ff3caa325ea480de71bfec6a8efee94f272fbfada48143aadd91fa0(
    tag_key: builtins.str,
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2643b3a9fff1de165e36c095b89d5d8a73aa8eb7075a4d2526b7a28c8c675278(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9bd31900113c07f8d016da0ff542f899b25b4e8cf84bcc7c1c7c845641772679(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2df2dbf5f5525f25556901ed08e3e31cd2e5f3fe3e2c74fd0186d00899425485(
    account: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7c50710096876c8441151493cb672754ae2aa2c526b75ce549109cbfd7e75a16(
    management_account_id: builtins.str,
    organization_id: builtins.str,
    member_account_id: builtins.str,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ee481377d92f7f58759284641a9c8265a811b73d1e63dae9752176f9131f0f0c(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__37aadead19c69d55b20cc779c1f68f1a3056315f18885ffa9bfec295d9effbb9(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f4aa47aa9fbcdb1c41ad140ab4cbfc9a527de09bb53e6f730c3696685b5e641b(
    certificate_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__43731315834b1b6253d1e2917750daffe7a207253e405e57063d2ee885f5e05f(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7d27a7e85ead09c9994002df30544f8b05bcc59305aca4b155eb3cf5f877635a(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d85a98059a8149aa92465cdbaab161a8304e64b4e9d178f6ff37f9079cc1c5f2(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__14814049472060c583d4177d3b33aaf0a450c5e75ba37c691edc516e4f421d2d(
    certificate_authority_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4d59ec2cefc62cfb96fb1e9bdcdb2953069b4ef668ff75e5ae35aa2a4b0ae8f6(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a79a936dd6d638ddad4d8122dfa3cb1e216c97b801cdd43cdd8cd65e73cbe85a(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6041471496aa4ef4f4cc66a5a97d9f01a4527747f9074b68c29a50c859b15016(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__36279c6cc54d0d9a5e8b7d08d8c55eb0e3cd106fd8ddc4886edbd5655bb6bc13(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__de79b29cba93cb779e412376cc195666e8206fa0d174e13c7c58cc0216bd9e7c(
    environment_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7ef8481df6d95cb24fe8ba18db4e69814788a2cb2e9e860b50414b28bb04af00(
    environment_name: builtins.str,
    role_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6adafd7e4795f67696a3fbb38b6745cce1fb4f797efd69b2d0e1347b903e4e4d(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__02e427f093065ff324dca88d9bcc59548ffe5ead70182234be53c46845ea1792(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d530644189d7b2cde1a945f59bbbbfa3726b20863004756b081cd63643f88ef3(
    app_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ddf9aaed98f208bb8ce028947e7d765ed59a1be501cde1a023c9a4ce282617e7(
    app_id: builtins.str,
    branch_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__be3b229a5db0d37cdaac030b586160c999ac86c5c11fb89cecad4871c97dae8e(
    app_id: builtins.str,
    domain_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a4c71f59cf62b948b26667041837ff4cdc3e9fd62f12732e183dac6230de807f(
    app_id: builtins.str,
    branch_name: builtins.str,
    job_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c3492c9460852b76a8d51cf5e5932f87e5fa11a0ebd2fdf3148dc122fb013716(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bccbf40d004b8db72ee06479e931eaf7728c6d4587b2ec990205b38d23eb4874(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__059e24908074564faf0e2fb38eb458bf2c380b002ad1b86f24c3054131a73135(
    app_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8be44c0064d102c3e0ad7f7468dbffb3f3723b97658e7c6647fde84cd423e90f(
    app_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__79e0f90cdf91d0378fa013b8e20f646adbeef965073232df9dd8f353fe7c718c(
    app_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__345da9cb6fbff89662399e5120cbada6d9a643ac35cf209810f52867956704fc(
    app_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__70a9193aace0fd9a5e362a3543b1e6c4da8731de921ad62265f1fcf88886c8b3(
    app_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__16cdc213e9a03fde8c9f17c1229ae2628e8500bf66a7176a11e6d97412aef075(
    app_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ba15fdb1d0d87aa87ea70ad9cb38baf31194af3f9e61a9262ac2e19fba6b54f1(
    app_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9d7d7cc93a433c18425db639d92af1f2129387196fb54852831ac8f6464591bb(
    app_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6157c3c6b818849c2b8b07f539e42bbe3819a37a81daeafec222fd94cf1a145a(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6e23a978fd7b1666e2b4133221304ea233dc4e7caaf9cbb839c55e04b08d7079(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__790a1b732a71dfbd1b95650b8dd602ceb93bb73117b9a20d0347abc791ff4a08(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2157a067f52a04fc49667ae7d06f27e63d80a3b70f032fb06f565dd27f1a783d(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__75b361528f34d77565682ef1daa9705a9dc10420420d3cafb8f3eb656ca3ce87(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5649a82f51d1b2007b15f3809c0e921d7ac11c8b04ccede3ec21483504f1ab45(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__499c049561ba7ad370981bd14ce9c93497d702afcdcc7c936be179ac886fc517(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__38e798df152c13c33fc85dcc7e3feb29fad3a205ebe78606fe6064ddc416a21c(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__079c2c473c7ede40065bb03c8f1f75c9e75709aa42a0cfa4dd4946dab35c3e73(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6d813dcc9de161d03d3bf5ca7e1287ea7376884664910917603d0dc2d5b40c9b(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0b91c29a086b5ca70da1f239a0850e006aea40f844066d4cd538a3d624c75e45(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d419cee9625a03b1950182092bfafc73563901ef44e0e561ea4916fb009e0d7a(
    app_id: builtins.str,
    environment_name: builtins.str,
    id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0b7cbb2f9db9c65ecdd67d8ebc2efa47c12a0169aefcd294e5de5fb63f7d0e43(
    app_id: builtins.str,
    environment_name: builtins.str,
    id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__35cd6d4072d4fc40b5d7307e18b896c2560a792be62e0f1734b48f76dc527408(
    app_id: builtins.str,
    environment_name: builtins.str,
    id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__75db7bc3403b9ce28b68260bcf42061445dd3750f8427777105d1a079b792068(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c8c8d939fcf59b4999dbfd1f022e325a18bca6f3c2244adbbfb50e1afa7c080c(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0520ec7a8f07ffb88a7154ed656ad953d8ef429f91f4218cce03cef5bd465a41(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__daf0bee9cdffbaf93739d59a8913e27e1b9c32ac0072ee0f6f7750b6362dd585(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e8e22a8553973ecdedad75fa515cdf6bda1fb589eeb9ae45652fca49121cf903(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__59620958ad1cdbaae165c962363a90b0ebcbd51e801bd4a874474f114ec27347(
    collection_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5ec3e05591e36e4e026ceac030dcc22181fe4e96b8713b1e6709fcdb418b2c46(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d40f908dbb0ffdca8234cd0027e2800ed31e6cba9c59c6bbb4051a59fa9768fa(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__288bd55d2b49f78cd622c68dd466c77f7c314fb899d103ce75b0dda8a491efb7(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f90def41b71f696adf8a8abf88f6718cd99214f3a533bf4b746eeab89b5f50f9(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8f4f8e5ecfaa53ef21a6d2d58f46794bb61920a11de780396d5519980817c8d2(
    value: typing.Optional[builtins.bool] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dafaaab5603b9f3e962c609661e93d43f25ea940f1bef7456d65f17bcd84d701(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e1d4c2bc183c80d3cb92663353e40f8344d0dba7e8971b306cfa1a2c9972437f(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bedd9d24f25781c08b0a3ec8410f8315e873280b805a36b78c645135cdc99fd2(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__522fed4c0826fa278514cb0dbe8d704dc10d2b495f18d8c7875c73fae54b18ea(
    value: typing.Optional[builtins.bool] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c3557eb53037e756ee24a69c32d9b63dd20e2d9f58f03a925c69c8dee7fc9273(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__46524fbccea04b5ab7efa2a85010dc88a29ff8b57eb997f5dfa2bbc288e0837d(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4880fef66681c136eb580bd959379dbaad777f668af40e52367b7bb482365926(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__10b170d0a8f4403227cc951833983c34d9b79bad47f4ba5e3912938ba4edd44d(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e1b06dca5ce2d1f6e01a6b30db4c25ed527dda34579ff4069ac4bb9f1729d212(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6284edeb5e59d59c8a341fcf88027569fd49d9f61d2e953836474acedc1b1fe9(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7c0eed2ab55a7e36e5521083498e118bc430471efbea5deaca4ee4a36d97b801(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9377090531500f52e883062d8245fbe53aac1fb06b38dc87d18b45806a6e55ea(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0e0d20549ee97242c717eda1a8acabfd3f7a00263cc44e03301f7438403403aa(
    value: typing.Optional[builtins.bool] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9a69653a0fa34c6a39e4f6791395bb87a5235ed2b2f6d150c5cf37697c1e32bc(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cc7357074935b27133dfb10b672aee6e22da9e353db10007f5b85ef6d8217434(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1983b3f247f2218282140b880d087977cdda0b124918110d4edbc7126a546526(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__98cb24062ad95f5a684e792900bc35a58905888cb7f782930c9e9596a19423cd(
    value: typing.Optional[builtins.bool] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a6dd974392d8196f4b79d4401f917cf7afe5d8559b063bff85cccebe35ac77d9(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d7a11d04b287fee1b14a410c6576c728d8ff2e8270e3121adc077ba4fb3a86cf(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b91000805f9c02bfde183d1054cf996783626a0cc90e0b8f5dd3638d38c19c10(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d4b99ab451d333559980916109d69b469e6cac3b941622c0effdd2a4eb4ead28(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__96be8ea01279b891fcdc61db2d2ecd5b3d82feb207112a19402d86419c98cbd1(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ded7d4a34ec309d9aae88af69ecdf2930ce0ce95c8c2895e87c3f977e661702a(
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__be7cd1ef7238fd09c7178e8eea1bb2f7ddea019d77f8cf6a1c5952de540744bd(
    api_key_id: builtins.str,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6c7220aa15605707f9d13cea9d2e8b2e86a0306a92e9827d93c1163ceb148c9b(
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__399601807f0b12ee6ddc3f3777b371a19204e1aa04fad44ea4d5d90a7a9fd73f(
    rest_api_id: builtins.str,
    authorizer_id: builtins.str,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5faa821e51b35a2b14aabf9930e41658bf5698aa207a3695a6aadffb32f711ab(
    rest_api_id: builtins.str,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7209423e380a6d0ece70aa938174b157e8219a5c3dd6787fc5af77cd4fe3317c(
    domain_name: builtins.str,
    base_path: builtins.str,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ac1b4458c736f9e4d2400b7ca51a1e02c918b6c187988e9695bc0ae8f660d05c(
    domain_name: builtins.str,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__473d9cb9156b2ed0e815cd6a7bc1c2e54c3698a0924d9993803e454b65fe9508(
    client_certificate_id: builtins.str,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__25a23af57520cea45faa07f05237af280f99710a161aad94b51b75c65998bb96(
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9bf994f32fc73e715ea99d1ed917f1b595505195e2924aa5dc5541f993081b60(
    rest_api_id: builtins.str,
    deployment_id: builtins.str,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5ed76ba11dc7022bbf5b39bf07e5a953bd73fd3261da8e35b819804ee78210fb(
    rest_api_id: builtins.str,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a915f335b0c11558ba64cb141799977dc562c3b4f23a0a20841e595c5174b934(
    rest_api_id: builtins.str,
    documentation_part_id: builtins.str,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5e898f8b0283210b313bdf53607eb94ae7504885f571f3a80548d79b3d46673a(
    rest_api_id: builtins.str,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__31d536d1b7a2efdae068357516c042e9978790d8f730abe1b492cd7f69d74324(
    rest_api_id: builtins.str,
    documentation_version_id: builtins.str,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__30544719366ed85f366288f6e12fd7489a00b2a6f71427d9dbf7ff26bbed59b7(
    rest_api_id: builtins.str,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b0f0ce96e690729cb9006edf805546a88d3fef79e44d1f24887f46615b8928aa(
    domain_name: builtins.str,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2447ee12aec53d4a982836e93f28f4af366e2bb28b80dfb7ea59a564505d1ffb(
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4d087ebd0bd19b0ed3ec49a5eaa6642218a9d5f3032bfbeede3eaa4c945c9848(
    rest_api_id: builtins.str,
    response_type: builtins.str,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3ec8a0cbaf8ff8ee08ef9a4e52d1b42c315b29523323d3b6aab84738ec637010(
    rest_api_id: builtins.str,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dff3f0c3dd01f8072cbf1451ccea60b4b8771b81c67629bb8a8d6a53a27cbafe(
    rest_api_id: builtins.str,
    resource_id: builtins.str,
    http_method_type: builtins.str,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__eed00952cdb1a52d1640682adf3210690c15bc14e59e18917ba096d5a30784c5(
    rest_api_id: builtins.str,
    resource_id: builtins.str,
    http_method_type: builtins.str,
    status_code: builtins.str,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__599257c84ea901c14e37ca42aee68a2b9034a67e5e779aef95ef70f8e0141deb(
    rest_api_id: builtins.str,
    resource_id: builtins.str,
    http_method_type: builtins.str,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__37788b1b6fbf1ae70bf3ea201b70e355d59d8efae9b629be8dcde7f2c520e48c(
    rest_api_id: builtins.str,
    resource_id: builtins.str,
    http_method_type: builtins.str,
    status_code: builtins.str,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__efd25cdcbba55ccf7132eb86016f453caca91981582c0e8af6f97cf325942387(
    rest_api_id: builtins.str,
    model_name: builtins.str,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__021c673bc41b8ce104c52cbc20fa74a48af48fe20e9d48d07c4456a52ce77eaa(
    rest_api_id: builtins.str,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3bf753d07ee5cdf2414cbaf77df21c7b83d6427aad76f82e718aa2b844a28572(
    rest_api_id: builtins.str,
    request_validator_id: builtins.str,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a1a7f1b6aa18e4b72d5ce96ff069af2d1f1755f4aaa814565b27b00aad2cf613(
    rest_api_id: builtins.str,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cd6ff0a546000372415080bf968b25ddc7877da1eaffe14722d1d1f044edf75a(
    rest_api_id: builtins.str,
    resource_id: builtins.str,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2a27fe18d45cf6ee7b1af65aab55b1dab7c171d0c5bc531b906375c71024c2bc(
    rest_api_id: builtins.str,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8a4827cb885eae8a9668eaf25e04322f0f554943062c22f67849975c08471a29(
    rest_api_id: builtins.str,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0cc81c73e502a417546d36c10df166932aa2034e36f82ad3e77bf6667bc2c83b(
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7926202a8b855daede707e748d31c41c0d98e93832be25eed09127f26726f2a9(
    rest_api_id: builtins.str,
    stage_name: builtins.str,
    sdk_type: builtins.str,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2b2a1b6c92042d3555ce901a9436673588ff0635408b553ef161f3ecbb0d6ced(
    rest_api_id: builtins.str,
    stage_name: builtins.str,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8cbad33ea2d8e822af01e365fcc023b5026b3f72fb2b0ba90b1b433c2fc0b38f(
    rest_api_id: builtins.str,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e4cbcb2e263dce233c53b7d5ec9190c44150ec27dfbb152249cfeaba831357df(
    model_name: builtins.str,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9d309e5788b3995b084670c907690ee323657bd2e88e01d1a43c9a450b810d38(
    usage_plan_id: builtins.str,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__32b1977d8fd8e3b89456a557e37eaccaf27d93d5f19f1abdd1d96088109f6a3a(
    usage_plan_id: builtins.str,
    id: builtins.str,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f17190dcd27f7f10ac5c1ec27c579daad8a95132d480ed20c4982b5edb188d05(
    usage_plan_id: builtins.str,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__66275bcc17c2689faebfda4790a3481954f08a122f4c94d9cd75c5876eb91a61(
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__afa9440b8259f8ab0c858bc932912bcb557290fc419d6bcec6e7b417adf5bcfe(
    vpc_link_id: builtins.str,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7bce8d10a82b7224819cfd55f72e6e4aae4ab7383a8ef9ed4e65193039a36b38(
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__78d12e6093b0078092f83d65e86bc1682017750ed0bad8461c5f5362be7c7861(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e1b11b5183116680bd47f4ae5eb6156d12ee3db7ac53279e1ad1e1aa6f3105dd(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c6b09ddbbb0a9d28f7acc51696a0e84fcb3c6b11ea46f6679453eb6d001cf885(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a5863b25fd224b0a40c3b37b51c9a9606f14e8ecee13364b2e7061206f3bacc6(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1869b8627a0c75dd5bb054bbe4cf3c86fcf909b0bfae91d5dc7847f90dd4c562(
    value: typing.Optional[builtins.bool] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__38c864ac306cf22d32e758be6efc528cf44a289e615522f9049d3d6c88acfdf6(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b8a62f73d7c0055c603631f3699a58017d3f43a5ec8c0b0671e766f1981c72de(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c60a16028cb2acf26827c57c700b06f1135c4fd34a2b952f5652a6be6c56e7cc(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ed71d62a9984b742a1b070bc42ef6e32aa22846d574a60eac2eda7a37412ff77(
    value: typing.Optional[builtins.bool] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7ae1f9031129c4db89fe583df4b04ead1b9461a003a73be3baaeff3d7e65d23a(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__15e1ceeda04ddf356daa9192836994dd6405a36d23b5b5373b4b1216a5e930d4(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fddf4972542627bf833bb4a510d51af4afd530808b2db4a5b071becd43e18d88(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__449e45aad212bdb129426eaf160036d2493dd08f7f78fbdd8d2efcb003a34ddd(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__38b8ccfdc32f640b982f397c34a5b8be78f03e48ba794d6fec2416e9a7fe3933(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2a2844cb47bb767c52fc024c47bc40ccade430d968cb1ce39f059745059335fc(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e2b6b9472223ecf1a1f87fc49c237ed99bf2407aa806959bce964cc28f3301ac(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f0157dd15c1b3d9346792f19b0e750b96e45112e6a06da77fad14c60fa665f54(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__21419b51c127f266a5a98cf6e76f042c734860b0f28b0904291663950fc517c0(
    value: typing.Optional[builtins.bool] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ca157cefb2462578f84c8ba961f53aa0c28e640a8f31e6b136a332b6f010ac5a(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__56308a0715f4afc4fb9473bcbea9d8efc8cf7f2487d63ce8c818c50c126ccd27(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f3f34a3a0cf8e63f5c755722328f82ce7748588fecc266be030ff888f730bd0d(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a1d28155dceaab85b36d11e49e5c636645a6b71f58dcfccdc8ef5809cbe1d97a(
    value: typing.Optional[builtins.bool] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5a01f35bf0e3dceabe3265bef01cbec08d4c6adfacfcb4fc341beeab1e3c33a3(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c905430433f6024bca5160e2d4228a1984dd613bd6bac18c7726a23c0e9aa67f(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5381df5405aebce4c13901d343ea63861c45f952a3f4eef6b668db9706afb571(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__952e5c6ee15fc863443e634b6abba093742952255bb945086774fd2c446e28db(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9e2f9846480c840fea9f0cd8f1e4b44a1dbd663fcd4b04103b2fc2d28e2f61df(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a84e435e5c29b02cb3bfb31b942d2ede28a21614ab5614a85f0bfe1987a54951(
    api_id: builtins.str,
    stage_name: builtins.str,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cd518592fb23656b88697fe6b0eb7feb5bd737cacc6dec5f754799aac29c675e(
    api_id: builtins.str,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3864e4e4f4533b82119da8100b5f9ad8037e2793e7c5279e012a298e80778bdc(
    domain_name: builtins.str,
    api_mapping_id: builtins.str,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5b2604e095bd5ee07ed6ac73311f2ed0fcce59a0121ba182cc03bcf6f9b61cc1(
    domain_name: builtins.str,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f061e8d6d93a87943e9047d494bf912be28c7d38e911d1656e38ffeb70f7dcf9(
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__90872229f7b3a6815306d7fad6ad337efff25af6842b9944bc6008c1585a79c1(
    api_id: builtins.str,
    authorizer_id: builtins.str,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__69316163fbc1796075ae889128a9cbb83e246925d0dfb38435e4e00888975d30(
    api_id: builtins.str,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__709613228b08259d5dc7026658f7f4d641e8c889dcd647844689e43df0280a5c(
    api_id: builtins.str,
    stage_name: builtins.str,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3d40c372bcc45babb244e235a1cd4a2a16aa08de64fcb3161118344d2fa18264(
    api_id: builtins.str,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d34c861e185613566823cea274c1ac73811b0bf9727f6b8f811dc04e10c56bc0(
    api_id: builtins.str,
    deployment_id: builtins.str,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ca2c44e5c0f7a115e24bf344626e9e80b19fe2062fe4f430a473865570d6a644(
    api_id: builtins.str,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__abf2319d5b32943acc8e2d56790bc5d43096719b2d8496805c524491328f84bb(
    api_id: builtins.str,
    specification: builtins.str,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6dce252eb85908cabd710c9c0cf8a803df1a21b0237d7e871ad1673609ea1639(
    api_id: builtins.str,
    integration_id: builtins.str,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e47c1478c040b518604cc8f6acc8f403887ce24b84c4d6e29019eb22e5c180a9(
    api_id: builtins.str,
    integration_id: builtins.str,
    integration_response_id: builtins.str,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__db776678364f7907dceec69779c730469ee14c2dcda930bc9f91cff62a439b46(
    api_id: builtins.str,
    integration_id: builtins.str,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fae92def6014ef7a2d876cf145e63719b7815f463d3b7102cc5e0da5464afce4(
    api_id: builtins.str,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b1f1aec85c86f2c6c837617b1dd73421f0734675e22d466200ea3c8a07fc18b4(
    api_id: builtins.str,
    model_id: builtins.str,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f9d3355b8358b49d3e52fa92150574a175b77fb457ef29776e0ef785868f1540(
    api_id: builtins.str,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3205a00c2ac3a2cf8fd5b1d9c5b72ffccfc18ae7b4ebc02607a39978ecff5842(
    api_id: builtins.str,
    model_id: builtins.str,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__535cdf6bd645138e8bf4a936a0a7afb0e3b6c075c71da802bd114491aad90c71(
    api_id: builtins.str,
    route_id: builtins.str,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9f08791ff7ee244dac0f52c244ac971111ec41e37c786827a1f6641a87c43126(
    api_id: builtins.str,
    route_id: builtins.str,
    request_parameter_key: builtins.str,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d1bdc5064e2874d9bb381038a17f8eeb9c31b0a57b17bb9e43a9b0af893107c0(
    api_id: builtins.str,
    route_id: builtins.str,
    route_response_id: builtins.str,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__95ee59bb917b73265bf1fd7098747ff4ad3f70c60021ad3066090fdb0ec1757f(
    api_id: builtins.str,
    route_id: builtins.str,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__46db5922ba8d077575c8af2252ab6b745c62619bf3f59af664527bb68ff34b0d(
    api_id: builtins.str,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__444b046116d15f58fbbb28f3ae4e71a49103c9bb450c9e333b54b626f0124091(
    api_id: builtins.str,
    stage_name: builtins.str,
    route_key: builtins.str,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cd01afdb29da0c31b53d85aea6df7e8f4659ec3a35908b4c35e2b0ea5b2bc6c2(
    api_id: builtins.str,
    stage_name: builtins.str,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e824570fe0283f99fae4458abf511b7e27296bbe5d66ce4f56a13a7530c99873(
    api_id: builtins.str,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__154f65b36cb322ded9f12d9e27d80e29944fa00a5b6ca2e2710ad2426afa6dbd(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f2b0b208d1cdada7f9a72a71cbc0494e60572d23908e02a805b1b477d90f9a3c(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__48825ddd1115e5be0f8d01ee369671152b05a5a7b422b3758e0302212f3fe92d(
    data_integration_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7341df38f7c13c0f1c5dd50b7db7df11854d40d4937f9f64909d5176ad815cd7(
    data_integration_id: builtins.str,
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fcb71b71f866b231582352abffe8b2f4a4b7e7651b7c0f5343fb9de4cb42d9fa(
    event_integration_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2d4274fb63dfc16e1bb092be8171bcdb2adb63cb45bd3bd2cafa057d9bb324ea(
    event_integration_name: builtins.str,
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a57cfe335ca1877e0d07050b875c53bd9a26a2ba554527ff1d5be02dacd07324(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3a727de420c6e7f7c77245286d53be6e326aef9cac5018f8a75d909460517744(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__18cb28388a50635069d0f8c3f0b58a2dadf6ae75fec379ae250758940a14a451(
    application_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e941c92ba795683c876ce7e9f0aac78ec5a10d6dee33dbaee8bfc23ed0eafd0e(
    application_id: builtins.str,
    environment_id: builtins.str,
    configuration_profile_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__94e5269474420d3d7d06c06cdf8f0fa01da11ecf04e591923de7a8bb1e769785(
    application_id: builtins.str,
    configuration_profile_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__eeadfe41201e40133b471a16b5076bd971edadf0c60e70cf88341c8ea919e98a(
    application_id: builtins.str,
    environment_id: builtins.str,
    deployment_number: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6dfdf7c5d370b01f1d8b23ed270ad6db363ea2ea77441aba06c8e8dc180c35cb(
    deployment_strategy_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__77bdf8b5e7443a6782e7a8527c1b2abe9b7072040302d8f545794426c98ba8fc(
    application_id: builtins.str,
    environment_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cce90cb77f7eb6dc250e6f497a39e1057479c7f28a989a7dc500262698db17f3(
    extension_id: builtins.str,
    extension_version_number: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__513ecdfe1b465a9811541d93846af0b05ea9d08d125afd7ebd0b098bf24c8f30(
    extension_association_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ad4414be3391e54021057570c27345accb1ca08481eb90601ca9873f8b9870c9(
    application_id: builtins.str,
    configuration_profile_id: builtins.str,
    version_number: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__168652440e2b0d6c18057de24a3194c4c6ecdcbd56893f7b1f359cca515367b2(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__16c686283c261fae4f001b7e0516dc58123c586463f1bf4ee1ae9df74520439e(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cee38472dfd8279c6a9f54ff1e707b30825dedc0f7069c6382aa690958204e02(
    connector_label: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e6dbdf2d2d8736ee0ce25f75042d034e7f8cd12167ef5ba41d8460e8b2ca2229(
    profile_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__41a24bf717a5dcb14e601deb0c0299eada0b5502e426bb7a5737d8e78ae2de25(
    flow_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2920868cd4ba5b70e717d15b690b04ddd13ea92cb3b7761f64e24e609bb96179(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4124692277ebe800a6d0df4fd9cdc8ffe476d52bbabf00599368840250e40cde(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__01683d8b1354bb823bd87ec31d5e26676eed3bb3c42e2ff15034013a0ee0d9e7(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__55bd072152c03875196038590f1aa3af1e136edd17b862b19468180ee16d9ff9(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8221537e9c00ab89c1cdd9fee9f50cc5c52af10bfa17150613f3eb5c09dea3b9(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f8eb56d3b7bbf37040a98a8af9122bb18a1b998fca813211bebd38b221cfe174(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__713e8d583cf5ebe8be45b71437687fda9d1920064981fabe291de41ce95fb986(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__426faf2c6f45265b58ce4161b0212d940256e3ac6bf9db5d94c3162c0c22e5b1(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__231190776c5b848f6e9eeb1f208546606b4cf778ce236c16e07ea4caa8c0319d(
    mesh_name: builtins.str,
    virtual_gateway_name: builtins.str,
    gateway_route_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__00d456e1cf4aa014ad97a81b1a2b327fecfb1783ed7b39523961eac31bfdc05f(
    mesh_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__77071ffc2064aca8fd2c1e13899e4a69cdc694f5335e91bd515d35cc299db9cc(
    mesh_name: builtins.str,
    virtual_router_name: builtins.str,
    route_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6ff71a5a4e7bea822f3ebc01e7fc5769a8ddc0695738728b63fd1f46e57a0a64(
    mesh_name: builtins.str,
    virtual_gateway_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9e2d764bf0bc4a2518a182ed9e968ef84fb3030babcb08f5bec610046ee8ac2d(
    mesh_name: builtins.str,
    virtual_node_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b0ebb0e66bf1fe965e5af717341693e4065fe179ab16267e287766fe21dedcef(
    mesh_name: builtins.str,
    virtual_router_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__effde181ecfe382881074fee9e62d1bd4ae406b6c7f3eaf60db55e8e72e04c3a(
    mesh_name: builtins.str,
    virtual_service_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7824f4f644b7a08e78e6034c7fec845fe75027c5f0582fc667f25a3a27902b3e(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fd051012d1679e0b3fcf07cd5a97a20cc79ea3fef0e04cab8b5e8a2850e80ee4(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__95e493a98195ef2b7304ba19f9c142f3b5f3dd8533e2a3b52f3803e217e90957(
    mesh_name: builtins.str,
    virtual_gateway_name: builtins.str,
    gateway_route_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__65aa62d61b9eafaeb01b168495701d1e7da115b14b10e7cafee65314cf548305(
    mesh_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ff570f3272da801484e29ad23006b1f9f9678b7a7c95a5874b1417e56102427c(
    mesh_name: builtins.str,
    virtual_router_name: builtins.str,
    route_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8297d92aa120c47e02c1a6b82e42db65f9fa39e00c6f0ac971a342a3b6de28d6(
    mesh_name: builtins.str,
    virtual_gateway_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1c80b0cbfa1b311a14dd66128760348c52efa308bafcc832c13e797d25e32340(
    mesh_name: builtins.str,
    virtual_node_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__af78f582fdd78957c38b78be279e2069a84bbc2c907c1d7dfd1d9a245b9acef6(
    mesh_name: builtins.str,
    virtual_router_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1c1b5b7b2fbaed544271c33dc56c262de5ac8c3311314f23c2f89e4e7fbea8f2(
    mesh_name: builtins.str,
    virtual_service_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__732b05801e3cfa3b5ca8ece8e35b7c4722b0c47554a3147ee9ef347472bea928(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__98d2272136e936d02b9ed69bc41649129dc9ac33dc47fd24ed1f75c6ff9ab967(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__723606da005bb2ca8448503d4a8fd1a2085ceb8d39e8809cf70f5453ce8bb495(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__70b1aa18814c4026650b648217d549af3ba963b929d25e23e929e3bde5d34c5d(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__95022c2da974fee89ebae668314bcafc0ac938b822600cefa82939a13e732624(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e792a69d128138b2118f078a5ebd276c586020d17b894f2814767c042cd9dae8(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__54afc1e3bdcfb9e8f9653154f3d19f3633ddfb2f57a470f63777aa164def866b(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9926b60b6fe196e4f37245b1fa2dcb649da140da116ab63f5043dddabbf0a6a8(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__963e22b29305bd2c8e60c83678dd679bcfb31cf692c1e5dcf2c1a98615e9363e(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6c96bfbac031968e54d47051e5d7606b52c92c44e46eadd8d4e4aa8a80cb865f(
    autoscaling_configuration_name: builtins.str,
    autoscaling_configuration_version: builtins.str,
    autoscaling_configuration_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__026f94f1c259001b9a347e45a3e2e5d161cdcfe988ac31fc878b51279b7ff5a5(
    connection_name: builtins.str,
    connection_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ad35ac8fc0f3f747e9fa75a0d2d493d6029051b53c6c9fe1c66731998eba5644(
    observability_configuration_name: builtins.str,
    observability_configuration_version: builtins.str,
    observability_configuration_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ec362f6b350e00e74e711d55791fd60156bce778dc4f54b6f34006c4244296fe(
    service_name: builtins.str,
    service_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7b3dec8e71922f5195bbca25ca53dd246ae0061209db488c2f83a9001d306755(
    vpc_connector_name: builtins.str,
    vpc_connector_version: builtins.str,
    vpc_connector_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__19700bc2521a766c69c28c0714a1be4924cab7d003aa4102ea481caef9483c90(
    vpc_ingress_connection_name: builtins.str,
    vpc_ingress_connection_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__641edeee6bdac50886eeb1f06fee332e5423210d41e7057f6b45ab61c18aa9b4(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6908f18e29d3709a1df7e677584e8d1c364134af217a0bd1cfe7b977dea34e2d(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9c3103744b8b286dbca5e188a0c4868b11114f24465fbbd7d59c607aae4870bb(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c21a1dc7d85d755bdda462d51aa4f63369a1a6f72f73517218d7d15992fa94c3(
    app_block_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__296ab8aa7e35ebf5530cc5d540b51cd91d6e902439ec9bf9246f20fca2111837(
    application_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fe9c947bf7064ee29b81ad14301d2bcf59bf95791c14ca0c8b147c5b8ba3e76f(
    fleet_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a4e34b9d04809859742ad98bf03d9f7fdd4be26212803742301f6d2014959acf(
    image_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__35ae0922a44404aefac8dd4080fa0f029b21302e523c36c8d76d943ed501c319(
    image_builder_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6cfe5fd735aa0c13c5317576f2bd9145395789f6cbef08e7c20cad2346cb56dc(
    stack_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1158b42a888862e24f8331ca49b4b58e491885859f9f292b78df74b3a759243f(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c9ea8cfd9733773ccd2ba74ca028cc2622be45b6e824eb7459572442333fffa5(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5545765636ccf7df98006000d46560520bddd699936e4f96ac6c431dd7d089a5(
    graph_qlapi_id: builtins.str,
    datasource_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3c464b78c52e23cc8ed7656624e0826b0d417c8276b8e3d6154fd25cfa6b0d95(
    domain_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bd87d283796fade52f9b7c64a392e569227b8dd90aed806893df8a6b539095fe(
    graph_qlapi_id: builtins.str,
    type_name: builtins.str,
    field_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__52f6ffcdfa0c3ee3089d9ca8095d6466a480c2bd17c87feb5cb685c10d06a690(
    graph_qlapi_id: builtins.str,
    function_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__652cc30947f270177b163f2769ded3107a98a236c1984e08d58959735e0c47d3(
    graph_qlapi_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3224da927b36dcb6456f5e529598a9647241036b4448b41f30114ef4e6b66231(
    graph_qlapi_id: builtins.str,
    type_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ae49b1bd39a751b465dfa798386ff0bf4739802fd967b2a28ba6067b6e952281(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d283339709200385967ad6a551e062409fb9539ab59ad4d113eb644fe4823ff7(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7dda98093400e5c7c16e84eda1517f42dddf2973e3a546bf2e3775e3f84c1d48(
    workspace_id: builtins.str,
    namespace: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__57c461165999c190d4d73dd92dc48f574a1b261651036d94046d75420680fe9b(
    workspace_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__255a7421dab2d5f9969d2a11020be9739afd6330fefef6da573dd1b7c2eb7a2b(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0b78ce76eadbfa87498fb4a382f9cac0bcc47a3554c45d904faf5e9c7653e1f5(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4e22dc6e62aff04b91e0a83fc07d61c4816b11be9b695815d26beac5466f6382(
    load_balancer_name: builtins.str,
    load_balancer_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e483a3e47023ca24db30413aca9362739093f959137ab8cfc3d0be29f9ed25ed(
    load_balancer_name: builtins.str,
    load_balancer_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1a8aab5aef6ee5cecbbcae3eb50d7fe6a7b1137f14ebc0f0c03978fd4d8210d4(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b7872413ae4125b6c4b64bc888ac79acaf875742f6b4617d708e4cc8e5bc31dc(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a2048849b36957b0fa15793c94652c6f4bf03da3db2eb9447523d27226b654d8(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cca6206af160a6d071447c21eba797411892c30e0650e2c0be3a9880267c760b(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ebdef7b294c45db4b1c2c1b559f18f58231c682266e3529dfcbd2a6f72ab2ef6(
    resource_name: builtins.str,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b78889c197d62691954ec2572dc27accfc5684095b922dd82172974bdb355b63(
    resource_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d877b87288a3b13c0e2f9bea58723ebd8f44a61b3846b9565124469166ae73d6(
    resource_name: builtins.str,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8e70e7d4e2e093590806a75bd4de30962077bc4175d9b36ba6af65dafca5ea98(
    resource_name: builtins.str,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7e82817f22c32ed71499bd556342360833ce9dc38824d43716c868a485f03c03(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__152a65e65ce13144d1858e904c0e568a86ffdeb324af936700760a6106461c96(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__507559939d8ff3d2d12175b6a490570d69fd0e4faf6c37cc62b6f95dfaa8f039(
    data_catalog_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d5b301697ed23bb32899be3d4eec7052d3108bc583ba6386cac9646d9b32bc5f(
    work_group_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__185223d9842623268d27c844b190e30f0fdc3d2d6efdc9ead19d32fc560ce0fc(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__32bc5857c964bd858e634e845063afeb11a92affdd6e16b4777c9928e20b3f9b(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5a80fe5d938685637958643c8eba73f2821ec3c349fcf56f4b4cabe2b01b5206(
    assessment_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__23cac78af5852756e23ff1de65d4df0e0940f12b99f7e0378a0beab246979c88(
    assessment_id: builtins.str,
    control_set_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8a5681ca39c9a525a992d3da2c40165b2dbe4663cc27d45b429e2e275c0ef334(
    assessment_framework_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__35bfad0b5310233dc433e73e3cf66b9611f8732ef153effb9d8fbb2ae085f553(
    control_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__10fa9c3f184e3091bd78eb361d453db77f55cd3148de3233b3be1006b39db425(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__53a8891f32488827dad1d4ea94d5840e4348c2734c1dd31a027e9982c2b48a0c(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__278990318e91f29a273c3e1696c9809cce7937a93c7f5297066715f2beda85d8(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__892a29a7afb4c5e1ec9612396ec0f1bf4ebefea1843aeebb5bd06908e952601d(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0fd9c71f2f32efdb77f7170931c4bc6540ec76dcefe94b6ca156bef45f042ff3(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7c13382c8edbc37af107f9c21553bd1319e42e0ffc802b0bbab243309c1cca74(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2e368837242231bc1bdb020da60e1321f40989196409c0b28a585881b6d655a3(
    value: typing.Optional[builtins.bool] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__72e124d5302d01274c80196ca0b1576b7690f3f9061df79d90449370b85b6a84(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6a384b0a6d1cce6a2979517b2992910711dfef69ed5c3b89abce9389d5f6b086(
    value: typing.Union[jsii.Number, typing.Sequence[jsii.Number]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dfeb615a7f9708ee9081becf83bac67a1e3702cb6126c42f1e7978c173f172c0(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3b50ab304592ed29f7bd5909b7eb61eb3da2e2862bc0f71385b670beb8b49d29(
    value: typing.Union[jsii.Number, typing.Sequence[jsii.Number]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3145f9d9f357fcc27091adfbe8a02843101b845f6f8ff89e2e8df929123544e1(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c0477fdb10a3c4e3ae6d59807513c434157afe485a178f085f2fa987f1093ced(
    value: typing.Union[jsii.Number, typing.Sequence[jsii.Number]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f734d95a06604240774bfb2249e9c3adf797744fcee3c7a119446f1fdef58343(
    tag_key: builtins.str,
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c2187b0d17273e71c2a020c3324135bdbec70097e39c95b8a345d8f994d95bb1(
    value: typing.Union[jsii.Number, typing.Sequence[jsii.Number]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d2667d7d70d5b76c407954a43e326f168833565d687db39e6e29b9538e0cdcb8(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ea572588f7285e94450052b02644855ddc0c6928fe157695e1c57449e03aa620(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0705394887820eeaafbe4bb31c964b83bc3926764947db810492a7a716248875(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__02db601addd706684362faf432cf7dda84a734e16204423f492d2df332dda899(
    group_id: builtins.str,
    group_friendly_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__387508a700ffa3efa72d018636e8d9bba745a58eb556794077739edc7c791fa0(
    id: builtins.str,
    launch_configuration_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c0f3349e591669852418d1ddf9d835b333a85570688318b42700fcd28212b6f9(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__afc7e6f92e2fb55e2c3eab7937a6134f877ed9a1e17c525d2af1d3207ccf74af(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ef65902f4d4bd93f1fff15c2f6d16aea8f3e702c7a117208d62c0f0f003282a8(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__322995818d414e04b92a8a81de6cf03cd2ec04ca3c0bbecabadc2b9bb5ca2c15(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5d6eb67c470fea38431bc53c9b199bf9a73eb7c2e29558dd39743284b68626b6(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8f7cb695503a68b699b56424a90a8dad40e84491f699f0c0aba5028fad087d99(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d7aa35b8a3bf062e514c2e76ff78c13360fb7213b8871ef9f0d5b5a2bea9bda8(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__43218fe8506410bd23413804f2437ed3a6a10f33191e5359db1d0a3525629b6d(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f0635a779e59aca9ef2249f69488d6c4b2b32aa185206b1cc668ac5d01e6c682(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6898b15fcd3319f9f27fc06d2f9a3516d7d8d428c0f92272849a9a13fd1f4015(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8e730ffe403f5a3232e4352de625502d93f64d1311b2d3eaef2fe6f9347ffd76(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7a5d7f36d2dd7aaa8b0801b900ba26ba43e269d2cd79dbcfe08b1e955719bfd6(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c049b68dd8701ed259e2996342c152088fbc278d7b6eccb56613abc1855a1069(
    catalog: builtins.str,
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4938a65cc69afebb9a657919cfa8ab0672116bc7da54435a113b15b924381394(
    catalog: builtins.str,
    entity_type: builtins.str,
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7356e574fdf912254d7e55a34a7727513964db4ee5aa67d677cdd7917a620375(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__17aef19bb4324580e8bd58caebdab9471cbc30fd0590ad20b34ffff6b89851d2(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__22d24ea2001c9afd33e387b16ad775fd94d8835caf2c5dac5e1c2e6c661332c9(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__906a46617ab3894109235c86d604feec815a9a216ae370e285f94cebe2a12b7f(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__71452fa84da4e6cfdd761ffdc45ed662fa16145c42ff039bce945033bb7f019d(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__eefaee420a933ef35f82a0ead31d13f4a8cb23b1f974222d8144e951eaefb5c5(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fb6ce0a083a9c892675dc528a9a6681cff436c4fecfa147b0854ffac801b52eb(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9d0ee23eb56539bbca88568d40b59676545ad1742f5e7ce9d6f6ab6406a397e4(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__99e481844360e89723553ad7b3d61cd7e01bbd0e404b1808fa2ce6ccc69c477e(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__665d9c47d349e0a4707d9c754b51473d51f17c0c36e0a333062858bd3d9a7482(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__50ddb15f837a02e25126e0fe48f58bff295d8bfe9bfa2d7512146328ffe1a9ca(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__34c1bfbfba8b9fc89a5119a21bfc83d1cacbcfc5cbf57a0907efd82fa93e7ced(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a465026fd850e62c8fe5bb1c094ff3a36d18dc90eb247c105166a5e7189ae021(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__19728bba995efcc20fc199d69ca4ab7fc105a711567e82d5733bf24ea4ab250d(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__00868f5e2245fe2bca77c65596c0e0130f3b76105b8caae7e621e184f5c17a4e(
    catalog: builtins.str,
    dashboard_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b3d7e18aa9f1c2432c7176a6a0b66fb548f55c0f3e99eb082d68e7808480a7a2(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__78d45a5f8007235217136dcdbf5b472b8fcb41b634ec76f6b3f1f3f4bb81c9e9(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__502d8eadd8fbb771fa251cda854d78ca9e1de19162f98192e79bc14c4e543238(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a722ac9bcfe1539fc65a7a9925821d59f016d8f39530c11438c8f84699676caf(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__38d53b6153da45ab8b89d2502742a1240e7b581af8602a9689e1c9c704c8545c(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6aa0b076b16da7a89d75b9d777b1647b37ec9979abf8a15249714ccf87207066(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2c2acc7fc033df9f4c84292992501ba366525fc84d28ad73ea14c777f78bedad(
    value: typing.Union[jsii.Number, typing.Sequence[jsii.Number]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__591e4ccdd18c0898c31a270cbae35e760e05a28a8c752e04488065f1560180e2(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__11234e47953682915339da170e8f63d8465e6bc2e18666983359986a3c35a79d(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d42ece14d76d36c6308eaf85a395a0364ddebaef4f56b1dfdcbaebf6b862dbc0(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__22196c6228611590029cd23c313a5c1ddb4c4703836deec481414540bb216f73(
    backup_plan_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6ebe347c2928071ff0b68c4457d8f34bf1f74f3c277fb1b7b6b59328a788a149(
    backup_vault_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__62c5d53064ec37df92f547e7314ba967c019d9527d04d255ad7b5fbd6b005777(
    framework_name: builtins.str,
    framework_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2eeb987ea6519c2b0362cff2bca262eccbd4b4e04f24ad9377791b1bcf5f01f6(
    legal_hold_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__22ef8ba5478442b6fc7fc79600c885f3a6519e453058150f7d7348d77bc51857(
    recovery_point_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7c6385fdb691a7159620ccdf2877e7a432a29ecaa381b1d5a87ae2495a16597f(
    report_plan_name: builtins.str,
    report_plan_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4e063d2e37b15ad3959368f6e55603cf4634ee57bd59cebf5c73a42ab18f6cb9(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4b3ee415575c07b2cc4e00b5a75653a01e46ae747929e624bcd5c6fa0d81b55d(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c3dffb6576961af75b2b3c1a264ea970f2c0758e9657d4f1dc209b5d6f07a085(
    gateway_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__755f9de471279bf496b72720ee44d12b3e5e95b50f2f108dac2c2f9b06dc47cc(
    hypervisor_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bec66f3180016fdb5ab8be08a73d51c34418cf907998bb65fe95c4d4ba61c292(
    virtualmachine_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__49472f9a1c8d55770bb4d6e300a37efe6f4463c6bd23244e447f89a566fe9cd7(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ffaf83eb49b998ba0e9e5e89d3ea57a70bc90fefe9d3e612b923c91197f002e0(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__66a561d8730993d0d290cfe41e6317f6674b9e4c3efa069a5329db4eec3c0d47(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__43513d2f912f1391a6cde87aebabfce287a599a6fbb818000c4a20b8b6088332(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ec9608521bfb4e2f9123449aa92c6b542bb857e26e698cc3ce15892ddd6722c2(
    value: typing.Optional[builtins.bool] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9476b9d5a1dcf93b8c3503fb27fa72f0e459869a5bfa434f3f254954815e58b8(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6ad5b6c0cfa86e80db9e17d5d003cd75243483b3ff123141797203ad4f645c22(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__35e04f90f97ef447d8c13b0355b8707e87c3dd5ce414bb04fd1d0ee489f30207(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__48d4ba5060605dfe1ffc3fc643f7429684a19621f8fb8e3b7a08e86c1f0b3b31(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d6d943a26d48f2dc94c4f7fb4e78d01ac33f82c49be371755d27bd4c90e181b2(
    value: typing.Optional[builtins.bool] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__30caa91151734bb13a426f3172d80dca4ea228911de3222794c3ede03a49f52c(
    value: typing.Union[jsii.Number, typing.Sequence[jsii.Number]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__51b1e9737f75372c8878fe23943e3b60050f27b1efbe6ff6dc0f7e72b5ab69dc(
    value: typing.Union[jsii.Number, typing.Sequence[jsii.Number]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fd686527899790ffd578c3fe204cccdfb6682f4df4d63c39265359b3b2814b5a(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__94124a7e82a5eae047dafa9499726361ca368b2c6a41a264348fcc83cc41b603(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__704faf908872d9d2182c657b67e49f720915715d878863ce25ca453e50504f1b(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0f5162223e4a689a45f3590e83d5edfad9454e6920277ce44c05eedd922b9567(
    value: typing.Optional[builtins.bool] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__afe719b2f4d4c21e678785d2df8a6fbca5dedcda0b80bf4653d32397c8fdd90c(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__427bb7a7276d77e1c768e41c0522b72f55b0c8c9822762d7afc5947e3689e77f(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__aa34b991872f8e43785b5a018c48c74229fcfa8231c985efb14b314c94d1ddf6(
    compute_environment_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__77097cd25e90707a60bb38f38c580b6c14a437de96e5d108e17c4241d8f0571d(
    job_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c571b170a71237b146044766b701c54667637a1cee782e55f7df35649ab1a3c8(
    job_definition_name: builtins.str,
    revision: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0e9c9edd7d90d7d2a7a64ae7a3f27cf8c57532f1d7211aab262fab3de015a080(
    job_queue_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4bbb8b8ecf4c5bb21dcc213433e86daedf32feda7af6249c9cd840c2c97d4947(
    scheduling_policy_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c009528ec48afc716d31d35c4ca53e220cf46b8ffc692736579cd563240a4480(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__09a5c5af90f9e2c1181ddda9589e4ec0400d9ef7969643788ea89819fdb7ae9b(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0a2f2fc83e05fd0378d1971a3e75b8fa04ac735b9ca58f9d13d4672df59b799c(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d0bde701a5994f8113d61079fab496ec4d7916d15ca2595101ae619cf63cf936(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e16d948b63014dfb25de6526cabac9f825bb49d331a3337c76d331dc2f9d7ac4(
    billing_group_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5e82fcb645113169e0afeb52e7f94ae834fee4ed59f60631871ef336ee4b751c(
    custom_line_item_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b34320227b512212d3d385aa50d9ba0362227dec758401754d7acd09f47f416d(
    pricing_plan_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f46c715abf7cfce97a9ff94510217b83140c6a165a19fdbe204b81bbb09dde77(
    pricing_rule_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6ad3a628e2e211e9c22f7ed65b041bbadb72793f5097babd6f5085d2781ec24f(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1929a6ab19a8d8802150ba556f2c45e77103a78c1aa5e3a7b7886437a2baecb7(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__84ea013f7a29e531d24f2b414018258127ee867b069739d8ea59a59b4a9dd990(
    job_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__93145b095e055102ef55d008d14cf0ff585f7a70bb4717c5f178bd97dd665526(
    random_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f051de9fc20396e6425c8ca6c7c57b301d2304516a00e0b6899e5a24497fe16b(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5f0a05d6245a38be5318ca9cf8e09a4961de0253a2a207021f04484b999239f0(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3cf09fa4c3149dc8e163f254eae902d09e8a4bb605e5763664bbb2a74a572bd6(
    budget_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__87b90c80352693f239902b76c8c77adc94d2840cc89dc8bec4cf819c31719355(
    budget_name: builtins.str,
    action_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__eee2cfb0240e5f09217ee9ae71ea0d5fae4c09b2dbdee829a0afffb46b78c690(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fbb42c903fce7bd0558a66b914ea6d8b9e0bfafaf1aaa72d2604b1737d457bfb(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__80b883034db6a899b2cdf2956689aafbef46e031fc5eb9e2728d1a2d9c4ba383(
    event_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a1e3d42247f72fe4b57343e65585f2815ad0a89ff4864ffb538cb0252d2af2d8(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6742cdc0375bfcfcff078d766124059655d33d2d550f1e737a9cdac64d0e35f8(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__82d622e45154975ce1aa4aa653e9fa86152346816f01b43d2fb8207f064fcfda(
    domain_id: builtins.str,
    case_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bf71f92e40d47c6df214677fd64b38cf6d77a2cacfeac5f0e871cbd59c834c29(
    domain_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ea71d10265f0cbbb135be272dee958a7ea811586811b851e900a583d78b9b6a4(
    domain_id: builtins.str,
    field_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a2582290581d38c8086ec3162374e449c56eb3a082af47c1a658df78dd5ab739(
    domain_id: builtins.str,
    layout_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bc3a1afb2815347be635833a7db86e8057a14d81abb152902cd520205bb0397d(
    domain_id: builtins.str,
    case_id: builtins.str,
    related_item_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3e58b8923cf71d13964825bb7a5269ec02248f2be661a3a2c4ac20cb35658994(
    domain_id: builtins.str,
    template_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__26bcac8229069e1bb93ea414a885eeee80162c0bed42ab3c15bb0387fe96e9ab(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3e6c7bcf61f567de6a6e59b67acee16c533a8aae759e72f60dcbe460f2ee5286(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4066edb86df4aef17e13389b1e69d69ffcccb40522646b2c2211757d89befd05(
    keyspace_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c75e5d9ad92e304e07b1a06f76855698f79a33d737368162a24589defa4dff4d(
    keyspace_name: builtins.str,
    table_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2b422dae5a3e099423f4ba9e48dff7d31d0b800bbf55e66a7af7132f5ba07fb9(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2b2d1c3b1c496db2f3191175c543f14578aa3522dc029eff83f33e067cef2179(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__10a96358c45e19b6c6dba05c8bab61955c1b5b33d7348cb89d2ba2c157a40867(
    identifier: builtins.str,
    account: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__26ca11dc00cc9bea3e58fc539f1ba2dde16ba943ea3016c14c7b7c87ed62094b(
    identifier: builtins.str,
    account: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__36b4f7d3062d10949c846fc16402e07054c21e5e5af00e3a08d3bf59a722a5b9(
    identifier: builtins.str,
    account: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__503e3ae9a82b01bec357859604c920246d06f08bfb22b0f0bd919c699611cceb(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__53c5aaf3166ed981bedbeee841a8580b55b4530469e0c35d14669cd10857a6cc(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ad8ca404b74979d7e2910c6b5151b8c57c0d3f328c94abae95da1911bab1c7c3(
    configuration_type: builtins.str,
    chatbot_configuration_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__39fde3f56bd5c31a6268e693bf519d980ee4ce7c53bea280138291944acae643(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__efe7beec108407a08bb101b931c419203668061fd6d3303b778cad23f312bd47(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__eabbe76731fc6a1165359cbceab32e2d8f6ea3a9196e26ffd0c4c5658218241e(
    app_instance_id: builtins.str,
    account_id: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c2916683995def40f3fed18009d4ecf6f55377b77e90ba2b26c8f933ea5aa144(
    app_instance_id: builtins.str,
    app_instance_user_id: builtins.str,
    account_id: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0322f090dbffce340a28b2ed8d1838e0c23b620c19b20b7573e73e4b3fbf1012(
    app_instance_id: builtins.str,
    channel_id: builtins.str,
    account_id: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__75f44d8b451f7ee8b37bac22923755873637cac47fbbd44d64a18e058e92a669(
    app_instance_id: builtins.str,
    channel_flow_id: builtins.str,
    account_id: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6a524e3e7ee3e74abdf2485e28455b8dc6f7e861a30dc84d48feb59a5ce02c57(
    media_pipeline_id: builtins.str,
    account_id: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__88bad4e77fa476aeadf6deaa62a2f29018397cdd9b19e6e1f82d5df736600f9c(
    meeting_id: builtins.str,
    account_id: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__03463b206a0a92372dd39904dd26c63b1667516097b7bac1a3d4a7557dd0938c(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e31f4812b2d3e6650f7218a86c75be77b3c6e8bf12e1fb5fb0418194ad9008d5(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3bbf9cd1c9f7ded8c418188b00406b81e85b1f02b6d0d728a4227d3e569cc59c(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0b3a7aa6ff990d99fce1880f055353111c92b519584321e0934a2facd2f32b99(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__627a6701e7f4aa93df956b99ea45bdfae6d07a90bfff5d2fdb772cfdbcaf9727(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__47f332b927bf3546e9a47ed67373ee30200d2fbadb600cb82a16e4d9b9497b20(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__76d1cc2449e4fa3fb6fb19e87f20bab8b413603f229a6c5b64ed68489033e964(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4a35f1e3b35b13805369057d93f3ca20aeb39678f8bce8e10231a1fafe006399(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cfa930c64733f654237f8c3bcd6be3f917362965b07fb6ada27a05a14a62366c(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ea0034fd0e0dce48b888337e2644fb599c24f72dec71a4657e4b8ad1f86ca7c5(
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__216a7b6fda50e7d0219d8a323b52db8a5a67ce3923fadc1e43e2d04f531af860(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dff1d44cfdc9bf0dece99e50c2641bf689c92b5c73acca9c4812650fd26631c5(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2a9705755ecf2ac1ae6340785e0c5b21353217474415106f74c3c392553ef05f(
    directory_id: builtins.str,
    schema_name: builtins.str,
    version: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4020a9f0b1a11c3f3a78bd2d941e7ac7c2756f83cdae196df2d65eaa0f8cea06(
    schema_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__767fb02cf6fb053a24c1f61700b887cec2fac47707b94e4e2e7aab08b0fc334c(
    directory_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e04357e615b3f0b016a6aca5fe182e4cb6d275aff47c0b47b0756df781490adf(
    schema_name: builtins.str,
    version: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f0bc6ac737900300c0ed283505a2ee18e340993299d088143342dc3e1c76bd5a(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__059fbfc88e91d02ab49d879387bf84c1c4466b13ab0f308795cc27a1b57144ea(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fb83d8c7f52631ccc363572f6d0f76e20f584ea294345590bd29576e9240f8b9(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dac54665607aa4aef94591cc725ff81b830f5d318b1295e4b65aa21941a48c33(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9ff5c62423ea5ab7fc3e989461a96f041f1b07eee1c01787072cc8eaeb0f952b(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3476f8719e3a6a3269146467162a6c4f622cccbc454caf8005e34d11c891a310(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__57d72fff97bad35a63286f60bb7eab1a1d905d3e18be1debc6468056d900d88a(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fbc11cd87510518bb622a8e927e12308f5a49abdba70dba9e04907fa5cc0edab(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__99d6d8dbbcf232edad8fa1ec9a56725b4e02778f62ca272fb117d8132c8eb810(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2c55f20896a209a83b002e6cb3045d38297a47578422736b77bc90cde54480b0(
    change_set_name: builtins.str,
    id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b8f0041dc90eda1397c280f66c7289c9dcb1c5a0d293130ee3d3ff4633f5752e(
    stack_name: builtins.str,
    id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__65e2b0fd53c9343a81aa9634dc76f66b3b1c4cb130b0ec9f76c8d12c8a006386(
    stack_set_name: builtins.str,
    id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__724a8c9c90918a1bdc4f63a54dfe7aef1975b3a1e6b231d95dd9fb6f1ac029c9(
    stack_set_target: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c4004156fa1fbe29f91b7949fcd88585acfa0a646a35fe015eb9e6b3e21035a6(
    type: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9184e7273cba65f88aba26a5872f672d613014ea7d4cf9abb495d247a1b8ff09(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__db4f6191e51bce0a3f225582b3f925e8ba7bbb6f6fde7a928b410037cf907a18(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9e4d784fb2a6b80e510c2d261488aadae1be7e9fe5ef506a5eee1b191f45173e(
    id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b6c77c529a4e253c08a8ed6b64ea7ec739fc797aaf2e4951bd562f00e4c8c140(
    distribution_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8ed98fad34a019eb5a5c2596c3a384b8984fd7783777a78d67102b5dcaffecc5(
    id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b64b7b54dcf0db68a02ea6609a1c1383b7f80c5aee2b6c26e0b8c746ea5a53ce(
    id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cc0cfa798099c6e61971c9904731ff64c3a8615a53a0cf9abeb6fbdcd799d8ef(
    name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f56694671f143cca860b57903c974df90511ff8590d87864856ad60575eb09c8(
    id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1c55995f03fc4d139afc2b7da20e6e1b48e38fd16a4b77d1a2741090bb268e37(
    id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5a075dcd29df2195b898468a3119b220523f86bce5ebcb51bafcf10d8b7b7a71(
    id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bbdaadf676e9bea342f99701d05f458450c63ac8441d428518a55b76951ec2d5(
    name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4127cb32d3a7fc167a9aff57e1980a378e022f4775cd13804cb3777d8bb81ba7(
    id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ea15a4e8cd4b4d73fd5ec239f67b6f748b6e1d6392ed9af926d826e4393a63c0(
    distribution_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__731930ef38a36975a620fb8085ffd73a9d338a2b7cecfe734a3af1dc63887f59(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5dc4e361574402161642d2f28933be83e3a02dafd15725b8f8f32450dd052d2f(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4710a33e72efa977e90f7392500105dd26f6149560fe7561ed69e916f3e62651(
    cloud_hsm_backup_instance_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__04ce6e0d4af5ef2d48c966d32ac2077f640a7bf2dddc2d624b9d9c070b17f88a(
    cloud_hsm_cluster_instance_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7fe5e4eb9e2d5e19f471f14ca8c146832489bc42364b79c156cd9cdac766ecb2(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__de31d821daf26a2cbc266d554c736e094e0b2804aaff042fdd4c578102bbd802(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a08ee03376ead681a8e5564cef1b2a6cc85c29e88ec72e5103983247e763c847(
    domain_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3535349fff32c7d2ccc51a1c8011a249d21f2929654e4634937a617ab34603dc(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c86f070ea80315c5c7c9b0a152ff10cfe0437847940c6ad59f9ea2b32e2fbd36(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e6459b0625046edec80b7688321760b488271365c2f7218f560626a09124dcd0(
    environment_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e23741be7725ea55641b9e239c2c12964a770094c54ae3f1042365d8639eb804(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__50e27ff25a2c89279b7741b589ad6d9fe82d9cdff8935d6289784be66c4f170b(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__09d3d77d602b58278b71b2d53bfe951587bad14ec2955f824e577778c8cb2e39(
    channel_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3712bc7aee5c31905f5e6b613db87514d57f51e66a1fa5995173b54f9a9da468(
    event_data_store_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__423ba88f7d2b99d0765bca678ce4f81ada75fd01d2b3efc31379856803641b7e(
    trail_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__38c51a7b71186223fb1770d961109a77b24c409926c5416fd2477104f093d364(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a4dd0cb45161bb61a4b536d7ddbaab2bbf5ff9e40c8461eaf3cbe4bb5710aa3d(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d12389b52607ac133c240445de94195de0c651e9e9dcd7c95542ad2f010d0c1f(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__574ad7725ac096e99c1c1a8e1bc27afb58b7b3667a33c09a3d1cdf355ad83780(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f7336a8b8d22fedf8bc8ffe6a6ccf7d96cf7732cca9c9405015a67ea13c21ec5(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dbcf7628f24a2880258fb9d858fc1dcf8195c28c6dccf9679f4f6c503d3e00b5(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__53865719977d922f1e6cea6d1bf2c125991e07b5b5e37d26af78812eb0a495c4(
    alarm_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c39496a0f90a36067b176f648237cef8f6ab4a8662933d1b0f10e51016a31e22(
    dashboard_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ccf7a525b6c6019a521b0acab70ad9522e8e81804b7c391e944a1ced0e479977(
    insight_rule_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__41ff616502fd3986699214e8918ccbb7f2abdc1d5d55f3bcee8b6d973b862085(
    metric_stream_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e814360a249f13fdff653347c7797cac6899f5539440f91ce6eb77fa3cde6158(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bc2ea3a90da74c28175fcf780832039af653c6be93ebb639e5e81e4c2927391a(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__575bf4f8a11dca55aeded8601929deef04d481d6c62a6e359dcf316b548d4dc9(
    domain_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8c9799417925824051523aebfb370541612f2bbbfb7dcaccb4ddd5e34d9cf3ed(
    domain_name: builtins.str,
    repository_name: builtins.str,
    package_format: builtins.str,
    package_namespace: builtins.str,
    package_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f643880434c6276a03c4aab6c2da73f36d5ff15479e892b4868fc2fd4bbf3f4f(
    domain_name: builtins.str,
    repository_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6a6e041dac307408821e4e74d929c0532b0d4b41587a3a489a1e01578a6b42a8(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d108bbcf844414bea635391e480d587e9e53bfd1466b688d6a928bb9540a98a9(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__96f752218a68f897e12079e9ce0072a33f0e0e239440a4db976f752ba6f337f2(
    build_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1da8a80786167b20b28705804d63615a3045f9fc44236aab60ec3289254a645d(
    build_batch_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2d4ad75a20266323bb9b3d6a9cc0c9a65e601584da67a886f5532b0dabd34b32(
    project_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__baf2995e1408b227c8cd4ae4f803a151d68f415904081ea4a0fec2d5d5bc9d79(
    report_group_name: builtins.str,
    report_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3d14440742e541825ad995058d6e37cd40bb24d065bf6dfd8fb91348e58d7505(
    report_group_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__812b458698ec2091fe8adc7f6526803021561f4e4ca772a177f57c3f57f5db51(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1ed4cc794c73080a18584c58e75fb77579945fe6c92ebcf60fa27a675128a036(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7b24cae5d29e92b597f6d7ea370fff51fe0d5bc918f93ddf5d835ec67973d168(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__039f3b40eac0f021de8ba2a7b6d358541431fcf0d3f05cef485895ed4e731a97(
    repository_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__69a901675f5f1bf9fe9a9cb6114c10df4fd9144526b1a1a5c5ee10d778e210a7(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ff039d4660d3a014930db7a0aabce9b830ec23aba94ab7995334a79b272aafb9(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__438f46fc8f863a04359afe8fc30fec91a0a314b73ad471aa54a358a5ec401dd2(
    application_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a08db0be98fbcb0d8c08d87bac1ac398b63986ddad3ee8a47ff88efa7e1b8066(
    deployment_configuration_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5ee41f7b649527a04171be1f7a3885f83468fecfe511c8702600b8440b2ab78c(
    application_name: builtins.str,
    deployment_group_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cc5e0e96a490141b0ae3e803bbd98bfe69cfebb49c7ab1d09e7d3ed3f7508bee(
    instance_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ce485a74c1273a00d2f180d313e367f9b3748ca90dc0d4a6f51557f2304bea8e(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b0b560d854eb570daa461f59c964952a86db8ef8234fdedcc0259ab219bf712c(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bf319c277cf7e4ef46a93336a39d06546a815f124bad4f20e5903b0d1a037648(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7fc77303c722731700bf3bbf4dbc900a31211e62e392149eb46938c5eb864e0b(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0778e7910c102bfae9100d746ccd1232263edaa72d4eeae6043575ba6dd29ac2(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5d613fd5852bffeb049447381908a5a783dc70daa4948e42d519acc5fdb5b0b8(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4e32670c274d55e3610ae8daea99ebb6b8ab9d8303893334d0d7c94cabaca21d(
    profiling_group_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__48bb09de23a2ae7241fa60f5f6b3c5abb3a711ee0c85b3212f3afb67884ad35b(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ebc5817fc8504d689e582476af1edb99127077ca58919d68bd0b6a179c93d792(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__297d2d438c20fb6d15f7fd4edf0acad339dd3d38008cf8719c16028ca8ffca44(
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0f166cb14aad729b0d636f3c0d4da10d2657aa6b57ec31f52bb3e6083eff3280(
    code_review_uuid: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2b964bc72936b3938b10e060d8149832a889702eeb65049700edc0162dd6fc7e(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2bb9802ff1318d9219c55f607a5b78747eca6a6d1d6e8f98534b8747c43b36e8(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__56a6fa6c6ca1d37c54fda72a748da4beee59f86fd75102e0b7681e53d9f1d1a3(
    pipeline_name: builtins.str,
    stage_name: builtins.str,
    action_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1c48868a4052f22e91d9247114e1f12f2861b752457a32481af3ce3da2d81ea5(
    owner: builtins.str,
    category: builtins.str,
    provider: builtins.str,
    version: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__79ed5b5985da9bb5c197ace67db98669cf27afe5becdaf3b3e5b66319b4f09a3(
    pipeline_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fa324a22003a9b66b71037e86a90218aaf57c8b0061b95a95c9f43207a3c03f7(
    pipeline_name: builtins.str,
    stage_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__35d96c6f67496a0e6ebe8db7151cc8093e67e900fce682ebc5ff106f34455022(
    webhook_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f07b4b4e1e637a04c153b9de57d8afdd037e9dabf9a6c0cfd9a28585ae9fe5ae(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1a7a47fc32a152d29d42b5a686627dc9b1ce88990eaff26542483cbe5debc937(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d7d370140309a4be9c838d397a9491c1284be18df5f8cf4b615986ca39974729(
    tag_key: builtins.str,
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__33a28dd7dd37325a48ead9d402a3c3a5dd24abc76528d2ffd807975aeef5da52(
    project_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__42c01ffd53771e3248f5c26421439e2ebe8857bca865aba621591c69abb6522a(
    user_name_with_path: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__61166551349ad76ce5bd850ccbd765a30a9bf58e54ce4b0ce67501de00a5b7d9(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c8d9c8503331671a20048e183c255bd6590a3e1365ac9264ae747aaa7db1a931(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fd2858d6519143bd6fb4a9fc7edc3457ab1a583faf5b33947fdf40eb43872b7a(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8a4e224d126186081a89302b159abb9c60a4b8f3dea19b1f0737d29215a760f6(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3cc9753c5ff1ef582b0187d8b85e03ff0ce19be3fa295b6831cf547af7adf12b(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bc9bdbc287fbdf7f18f4082eae991462934d73cf71af1113f6f51acebe7f0115(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__62d19c8ea6e5e18d00111edea3d1ee3ccd2910833430982028e47492f2ffead5(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4d46d400dc98484b1d8d0620232cb3e07eb0876fb7c975c7f2f3b44406f5d5e7(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__743768bb3b9a85dd1bdb3a2a6641b80c8ad0da86b926b521cd46035fd44a77df(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8455d2d0e92e4f8d4d69c9610b01a527949e4641bc88d520e7bb2efd9fe30c6d(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__145add1dc34fb47eab0225a096105beea101675deb064aa0dd7c505904c23d02(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fb25ac304b230e4e12f655608be1eb0020ff053f46f7f92c6c3ca3fccfdae7f7(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__63f131d2c232d365265ad8a2b09bd6577f540b394ff7e876f4dae68e119e3d49(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__46eb233d8c1a1eb9ee9c060eb9c3d05d463f9ea637e644c42a20ab29c6d09145(
    connection_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cfef3705d0266472ce518cd0a0aa7bbb78fec8f8c27764e4b27c2bb9a439fb3f(
    host_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1200489d4924afb972456bd81d719eb7469d2d6ebf0ba96655e129f1a41f7db9(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d201537289fd7b1a20725169850a9f73abbcdd649f92abf96e0b749416f90935(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__15e3bfc15a2fb0a72d2e04cd93a0601c92fa9792f97df0567f9d574201c2df0f(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__70644ca165a196b0b2468b545e8cd81b71a3ee8a879c99fb659ced9f336e1865(
    notification_rule_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__75ca99649a6305827bc38f4b823c3e97eb179087a94fac52494b3e57a7773abc(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dbf368fb13beb651b4fe022869606e09194be0f8b30ee45131ce691cc992bfb6(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__670d43fb24604c3a782f78dddf9e688442ef50c023d2fb03cadbd50648855d55(
    identifier: builtins.str,
    account: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2829404fd4d6b127846161d39b62137be8db997ffe1aff5b89f1690b4191ccee(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__441120fe1657203fe4e4098db175f623c06a7cf9fda077e186ef87cff21a6077(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ff1d2dc2873d9582b5ecfe40fb681915f505c9d8c2fd5747c8765084de2c8388(
    identity_pool_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ad2d4bbca6159eeadc8af44202bd1105f3d22f5bec3ba29a9cfd3cd66bf45c2c(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8f5633bc4875449d67a071919581620028500b33f962a8df44fa2a3a6a542cad(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0776706c1c7e78c912cb9160515116504039ce5c7f95b76a6c8e451b941b7151(
    user_pool_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8bdc8fdf1d6b73d7d4ee292ecd4bfa1edb693f92ed9744eb6dbf689fdc9a409e(
    scope: builtins.str,
    name: builtins.str,
    id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ff92fb03172194d667c0bcfb721a3851e53aa78ec73cf0da5e7e8685aa48f178(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7570963ec7740e5ea8923e2c4332a28ce8f6086074e2e18e8a8b21cc999d1672(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__090fce3876ac3cf2e4c6706a231f004012e15562c8f51997e53a30814d2a95e7(
    identity_pool_id: builtins.str,
    identity_id: builtins.str,
    dataset_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5e5e5e4e0e288b1178573996a4993def746b1bbeb3e2912778219fa5485473df(
    identity_pool_id: builtins.str,
    identity_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cc3d3f2240765b3a07e12df32a2db4757cdaef21f6159ec1897c078bf1876f3d(
    identity_pool_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bb134a25d0cc4700ffe9f67a9bd6330f8282d7e751a58f82785b827785cf5ec5(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7ab637a91db007cd383e86e65bc322ba2adcd93a90e04f282e5614f7f0599719(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8fd7bffa0dce989c15e269d0b05f5f9cb5b30ec543458961989ad07fc3217f24(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dfae30fb140af96c49337eef9673e3e140e802394fa88986c97d670cc593c016(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__00378d348ea924dfbb6a8354ac95d0d8912e202b2b97eb0a82b626e38fcc8e53(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fac4abd5cf69daebb243e74c1c41b1a300ad26283d9fbd1d078dd713042c9fbe(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a15ff468b9ffcd1e9894785085847cd0f4763c1c17fe8e94a0d501f92ee8ac3b(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__35b568acca2c70800e63d9f9ecb5fe6f29e6dedfe9f9a1ae7e9c28804f95d595(
    job_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__567958365f80a5120730c0cec8cec37e41d6c09f05410a4d69879c1f866e7ea9(
    document_classifier_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__41e682ea5f9070cea55827b27a76d156078ca0bf9f2e8ee5f3d0050fa0b587bb(
    document_classifier_endpoint_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bfa1990ba67e883e0fd291bd82bf4a28f6b466cbe785ce559de7e110feee6368(
    job_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__99618a15b9d41d6979cf20d9f53b6f26fb46c3cc9adba8625c6f742040c256e6(
    job_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8f835863b7872133d31997a3153cdd17556a88d354f745b23f519851abbbde36(
    entity_recognizer_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__255256f0a6b80c249a34cc29708214f3d57be1e575d612dc600c9785b30bc66b(
    entity_recognizer_endpoint_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8f424fe983f350c8d6c3f2f81ea72a04627b311be759311438eb6b4d510a7990(
    job_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__910a577a94598644d24909f72a0284a7c6736e91477a70a1b2ade4842f3ec026(
    job_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f259ae364fe74ac73132be82baacebf7bb9bcdd7e10c9d6900a66b1cc0b13cb7(
    job_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7f0e00a59709e16099a1d5de8345a39d1a2b97ae3a7ee27cb4eb292175fabfe9(
    job_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a33142198af20ff9f0571a94ccb8d1c76465d47708fe13622ccd5e64b12ac0e7(
    job_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ab2a91cfec135bb27c70f53be66062a069fe75487205f24ece0b1b800661f55f(
    job_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__df3ef050dde28806456fec3654a79d21cf09c8c7dd25955e96475216a6f95550(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c308046e51f4269d4d87e49f534b029140f372008c68561de6e9cfffce8c531a(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7ec4aa90167650c7d17201b63948eaf91439e3f6f842b847245125ac99dbed29(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__776a349256b9d112cba90b7f65063ccd5ba9d7f53cfba870847dff235a36098c(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0f9e9f94831d6ec9c34cfe5483e419cd2ea3b0e104efcf504ba243a89be26016(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__53fc38943c86f12b2cc70a05dbfbe8b6ec2d5c4a700087ec46e0e6e9527152a3(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__199e167c66b6ec03647c2e46758b4945373012f23932c48b072cfa1046333fb5(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2daf6c4464d123183f72700b0405dd061424d372c619b7d2c6841d8fcd736959(
    aggregator_account: builtins.str,
    aggregator_region: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__57beb2901f06145c3534a65f07498bf75f9d9025c03e0be9d7f766d4f4ea0c8a(
    config_rule_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__35d051a7d6f9eaf2c9223120b1f5cebc0ca1a561187c577972ef598b110009eb(
    aggregator_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8dbdb87e5b92fb421bb98e482007d957ccac3ca0241c65a0a4add40950867a21(
    conformance_pack_name: builtins.str,
    conformance_pack_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dd23e3bf647197477656ecbf1a42fd327f94664563f2f854309c63407a8e5ff7(
    organization_config_rule_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d4af087c31893e8eae4c07449dea2414f79a19ffb95e0a5fc93d789ce7a01742(
    organization_conformance_pack_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__db30b4995c49c9de000ae598865bf9fb982c7e072018273ff41be9b2a2becb7d(
    remediation_configuration_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__856c932461fac121852105182ccdacc3e7380dbae7a26dab21da009aeef4f3fa(
    stored_query_name: builtins.str,
    stored_query_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__408d7597a8d7efc58ff0b646af71b433ffecb8bacd1c22a9198f0873a4ceb069(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e6f73dbf78f04b7763c2bc8f5a04eaed7483170fc6f1f2f224f0110dcde66a8f(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8a4a2000fb1513ca9b70534fb954fe170e22c49c53a0cbbf38e8db6b5dad1285(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__84c80c2830e4b613e21ac12e0b505ccc29eb363f0ad531c56234fb64f9ea67c7(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0e2d5943d68bf8042aa1d94675d04a81e4e3d8d4e3e786a656700034a1cd49b2(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1d08a082cdbe8e3163093026acb68a5931f24186416d2c7178c705d535a7f900(
    tag_key: builtins.str,
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e2ad9f807e7b42f90d4582a7ec93131b220252f54a1989092c64a6549b9c5e4e(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b19b26e1e2d23c01038fc8bdbffeee08aad1212e39e0aae2ecdf7e037ddf0c31(
    instance_id: builtins.str,
    agent_status_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__24ba8d4a0f71518fbb9a2412eef5ea776a78f25d1253f1d997557fac50d3723a(
    instance_id: builtins.str,
    contact_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dfa4e79596f69c8032106a6d3c3276d5f31a2a57fd156c37c551abf9d8141598(
    instance_id: builtins.str,
    contact_flow_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cad59033dfa59314e51c77e45b87cbd7a81fc4481952f1e392631ebf67941c84(
    instance_id: builtins.str,
    contact_flow_module_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f9ed16d32bca8c54b91ebef0d84fe4caf6b1be388d5b9a20b6b69ac6eceefc34(
    instance_id: builtins.str,
    hierarchy_group_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0e23b68686695568c9fd1bee0406acb7bd1f97ed6ac0ae815925ece488862651(
    instance_id: builtins.str,
    hours_of_operation_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__65cb9ad017d793a46f25746964e385d8276acd0b501e093f0674a4a2b70e54da(
    instance_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bf0293de7b155b422209b61f6304206a8c6a9cb24b6b17b110b3ceafe00a8d3e(
    instance_id: builtins.str,
    integration_association_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a6f3bfd1e99902b6bf562a9831aba3729c3b4db031acdb4f40c4859d1cf9419b(
    instance_id: builtins.str,
    phone_number_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bb25bf0b48dcb43f51bca689afc931451ad8cdb7878c1e67853f93d6ac564ed7(
    phone_number_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__072da95ebb15860d5faff9117bb1ff144b9f46bfe405c19d473af8ab15464ee2(
    instance_id: builtins.str,
    queue_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d904ae66717d00bfc7cda4014ac0b166058b56477984d24507157eac106da4e5(
    instance_id: builtins.str,
    quick_connect_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1b145835cd708dabf8e3d5ce0db002f27dc249cf6511e45c4d03d13899a71083(
    instance_id: builtins.str,
    routing_profile_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f5000a96ca8c16eb2a6eb9e6cbd34c776dd2f2dda611d10fb3f821ef07af0bbc(
    instance_id: builtins.str,
    rule_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__72a7572ab32f886885a43988a6a931042a58b3e0629280082feb9a8b1e1ff1e1(
    instance_id: builtins.str,
    security_profile_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__70caa2b8f36f6453de1c49a7358fc34617fc97db79f84b5b9272ee95943c657f(
    instance_id: builtins.str,
    task_template_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ba7b0bcebea1b7f801fced8bd4e4e6457fa1d10e72b9b938374a77fada81d24c(
    traffic_distribution_group_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__51c58b80323340bcefebfceeb3d30a9f8eaffefb6d81e1a509cf11ce840fb74f(
    instance_id: builtins.str,
    use_case_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3d0c1155d9166a1899a6c81efdf21f960b8779b9cf163fc44bb94ca5687dc759(
    instance_id: builtins.str,
    user_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ae552b15a125610dbabc9f2d66c61303484e9d653a3315a231b1e85c58a6f550(
    instance_id: builtins.str,
    vocabulary_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0f21692b737fd0367ac1792f83c9bfa99f8c1432e063312f6fbed62dc2ac771d(
    instance_id: builtins.str,
    resource_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0ef3dc8a7f592f4d469c5e7e6b7f1a707ee647617470e01e23e71e4bb04d1753(
    instance_id: builtins.str,
    resource_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2c81542869090fc436baa1e5e739712b265bf2c15e88091ebfd7cb5c7937dd89(
    instance_id: builtins.str,
    resource_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b57acb93481dd8d1f0f58dc7a48ff11ef997d3f6dbb3c425adfbb74dce6df06f(
    resource_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__725e367ed502b68e7111f5d6867ac41456f1aaf5d6af80e6115dfc830dfd2904(
    instance_id: builtins.str,
    resource_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__639f929016257dbec3ed6e3a89e66091350a8304521956dee289a19dd2c17ba7(
    instance_id: builtins.str,
    resource_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5d17653bb18d9ea73eef210150a2c7778f0c6f9f79e89551a53a430bf0363fc1(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__86d5500ff6d2851e435169e686660b061243ac70bf45b9ab405a424fca61fbca(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6abf64ddf0e73bcaa240571e030297c519c0350e41c6187ff3d2ac152318ba50(
    campaign_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6aea7dacca7f6cf9a6ea1656004c7b5781d45c2e7a7496acecec103aee1fa6db(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__427d4fa8ba5249ffc58c048fbf2b47a44197a68d921745c71f10f9a58bbb6e4d(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__792ed98adf3985a239cb7697a5757681f849e89b94764490dd531e39719d4580(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__82ac4604bce4c0bf09d0c4acb82b00f3f7d72304769ce44e196c7a1da3634510(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e7e0ecbf772ad2e900dd71ab3bde8cbeb321dd5e3037f309df7b2d52c70e7744(
    report_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8c993afd890026f10d3c11a74419194f4f01fbf78eafadbff7df8601ec475f24(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ceb0a2a85875b57d85ac6fa19847b003c8f1c1b4a5fb0e5ddf288df3066be496(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f6b06532dd055384e105385917f71bf649498dbe7ace4d4e6a73434599c04330(
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a9d32ba4b7439a97e67eac554706ed4cbb05a7c6879bd6aa30f3b572acb05329(
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d59ab1c1b71f98bb6323cbc99ed07a081f56513a24ab820b6fd2ad63ed47c4f6(
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c9688eefcc2ae3e99fd230c8cd451cec26b9ba0b648eef7def056a7959fd2f58(
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2f019579d54f5f37b2976a379665324d9d85ce611f5c61fdffc7a02b651c8146(
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3e14038ab98e86d367efca599c5fe3314540c35dd42a645bfae5b8f1486c9acf(
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__97783c4b73bc5a89ba67f645051a8722018cd26e281a28f700c05cda7af785ac(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__36ebcd9d2923d4180c2f35b7b2b8473a0887e725783bfc8ef2bcd54407f47714(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e26dce38427d43372da1233d722bbefb4aeef05763758a6146c97cc6dc550d9d(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3eaae1b77bf199b30452485831d8134d7b2d17e7f6b0d185086638d3f69f6414(
    data_set_id: builtins.str,
    revision_id: builtins.str,
    asset_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__954408eb9835dda8f6072fd77ac1562946ca76bf39b4a5a8e4afbde2d183c9ec(
    data_set_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__faed329dd0bc10c00f2578dbe0629be1160b3584ba1589760bd446ceea959f03(
    event_action_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__27765c2c60b145a5a2ef97ce7bd10627d7dd16fb87485c32c04bcf3f982f7bb7(
    job_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__077b4ffd2f4ce79c02ceea488de33512ef4ed84a20ca74bfe27c444ab8ae86b5(
    data_set_id: builtins.str,
    revision_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__56016a49e664930d1c8c5f0c33761452d30c53896e7ac00c0f69012ecd571ace(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__55d4597f9581f7c57a1dcf43873ceb917dec8d22de85d68dc6635c56d4001164(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__75fd5b4dbfd5372a2b1189466c7fb429f057aa4371451e5b9e61d32a2d2e6866(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8b9e5479d6e05e4676088105fb662e73d16f7a8632be7d4444ddf0b3284ec05c(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__afb442f93ee4257c1c3e50f348990a24596aa88e0dfa0f3aeb57f9eaa972909e(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__edae5d1607d3d3c5d409c0752a94cb9d1bed389c90d55a6bf0d7b6bc01d8c553(
    pipeline_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1227eb94fdefdd920868b8046e467e06ef07916002eb5ab0975166cdc98d6b38(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__58afce216a258a0996ae45c65e1dce58ce9131bcdd98380c4de7ee525618ff22(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__54a2a822ec3b38de84073cabd8e1ad861a62de10fcda3e2b8bc7fe4e6e5d32a2(
    agent_id: builtins.str,
    account_id: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7b93f0375218496e2cd462d79efbb96629bc085ca6f7b28fceafcb09980e3192(
    location_id: builtins.str,
    account_id: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c5628fc097441d28fb0d2e29ef33b80e9be280f83463307ce9f52c78da12501f(
    task_id: builtins.str,
    account_id: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__13e612203e44e3aa7ba6b8161b6ec84977d59ea6cb260fa0be7c1775313b9661(
    task_id: builtins.str,
    execution_id: builtins.str,
    account_id: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__83cb6ac250277a28dd8da25a0e54bc764ab94135a4187fe081f75d33e0076a1b(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5785fd762a201d481e1d821c7035199d97fc4fa279d9d448f4da88baa8834f40(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e47411505e93849c31429ebafb277d2f1e2bb0500c91aaa52c6936af6c5b3877(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b4076b6f88b21feefff4dc9e3fdd9de17662f8490e99c00a464c14ba666f52f5(
    cluster_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ac675cbf5a544d430f1d01530c15b55f895eda72da28f5a53b076c6e414847bc(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3bde1aa2c09531aa1f46d778e8b227c495790e32669d3d03643e717a22e1278c(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b80860b6ada0ea8c9c500c8e1ea5e25cc2a1e42cb853184ecb2719f7a2c9f368(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__090a06792186813f732a9b3266fcb49ad5ef744dc212c90851b83c5646ed6b56(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f31e329af39dcde394fe50dfc2366e3df3abc6473b034f50f96c78d54de1f97c(
    audio_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9bab151b2add5e5deda929194506c17ee86a4f9708a566cac9f32bb8b900f607(
    composition_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4df37c343be91031c108f50f4a597b6bf711a0aa5a9efc652e7d3392f5e531c4(
    model_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3ec5529244076e16b3101dfe011cb5708fcbe800392eca7a64fd46276b6a5780(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c2e748fb8f86c1cb25be894ab1e3a6f400b197e7d13c358664212eb8a9153df5(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c23e812f33b01867f121091465b3fd5822c233c615e746e69e04f99b4c9a8c8d(
    device_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__30211cc694483cc41c31fbe7abba189402e1b4e7819b41894bf0b36a54d98f66(
    model_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d4feca257aa57aabf8528426740dcbec6f4cc9ae9ddc23c73dc1e710c671a9ed(
    project_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b5ffdcc42b9e1eb2aff5d30270008e15e945691fa3cd46a402e08db567ee12f9(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9cc31b631c27269ab531d8d3e9d67556c1c17df0a50a4427ba8552f82e73eaa1(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b9134abe5c3a628d5a072aa2d7ec28f3c5260aa69a16aed5278c894fbf36784f(
    value: typing.Optional[builtins.bool] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__af25b3930d6585a8ab6a3cbcf27d273c6d93b50e638d8e54d545c3e1a528fe7b(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5c55b62c0fb6f50bb20a6a2aa869d3481bf9c329746a4d4610f79410daf59c3c(
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5c3b6628140b09ca6d6e207f6b458c8edd9a6d8546883d2ffdb4c335230a12cc(
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9c1208587d7a09354f23d2bd463320fcf3b68515f9dde1ab10cbab306f10e404(
    resource_id: builtins.str,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6ef80ced8238cb0938e411791a372cd56b975e95ee9891459392fb5a9849d6a4(
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__900c7803d7119f3ed9ae18fab539a1de5806fc573eb4d78d8c4abd14e5e4e95d(
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__86a216cb1639c5ec54f1562f08a176f10fe7266e436a3db458b70f3fef018c94(
    resource_id: builtins.str,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e1a464fc13ad17e83d0aa26ac34aa33f53f9ea3d45b0759fbec4fa61e4d71ffd(
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__72fc9121ae89f0c96e05a27d1ca51af319a84c2af90fb54b63716fba2371dc2a(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__22cb73c8250bd05c3af29c2b45db41d8896f3121e2a9272a1d82ba729b86a119(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a1b2d16e63209d9d837bc1e7464955af9597467f09a5f9009d54061e6cf2dfde(
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fdd62ff1589c1ecfdc2aaea627bfc41f627f1267b241f79089531d6e2138612c(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8f7dfabb3714f5812f3b49529fed78dcf36f93491c2292b40f8bfbfdf3172cea(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__27c47050d73f3596e65e02ab11ece0e6b46a09b78c9f94fecb204e62b377e71b(
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__41d3007cf8b3856c2e601113e38b1864a040a0d1159da3f07d46f40913ca2822(
    resource_id: builtins.str,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__60f53e6a2587d98156d6d689822a1b577149f3f0222f9041c5e47220e13820a6(
    resource_id: builtins.str,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__27a0144f99f38387fd594b6ee423e598e03882128e36d8d61588a9c23c0b7678(
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__942acb233a4d13def17d5d7e1310ae9e3422d1e879a5db1f02fbaade9f0297a2(
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fd61b5e2ed9c641c3711b55043360887f3f3af0431924b10c12b2bdeed59e1e9(
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a9a19499f0b4360fd4a6d813d79e6eb895198508937350111cd3a469d93b03a8(
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__45147aff8059a8764ac8d4cbd6cadca558686c186c88085c6e110f3d4903f370(
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__53267c2d91df2c3bf7f6ce6b5aaf432f8c2e49854b69843df0c883cbc6220763(
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d90cd2ac28354bf87b009dc7ed0ffc8a507391909c7328fa7c187ebc38cf65fb(
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4805c5714935f6fd1d6ab11582287b4a9d339ad47f8637744cc12cd23fcf8ec9(
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__691ca538e823e1f0b6037f17a63e021ca479e087c79511818c10fb5885199e37(
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f5f597fa6694fd1d9c42db42cc84b1c835fdbad88f80a65477657d21075c3286(
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1b36ce52195f421910b82b08b0cfe16701238a0550fc32150fddb34c84f137d2(
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ff685a508e375f46bec9f43b0caeef0e82961c634273dad465aed3dc59b4ccda(
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d79181b6283ae1bf921ac48afc920aa55a348df1a935b39830c46a4c25149cef(
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8b36c02c9e7938ebb5079ea0202a18e0028e41607fdfb78f206ab9a2576093c0(
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__df09e7a1bf45d3675dbf8b9b001f2272695cd5ed9626b519aa36169aa96af559(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8e2de2758aceb7e7ebeab53ff9ed0a1ae4f98ec6e66c4d15daefb3611792d80a(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5f3f6d89cf999ac0095a61f5b4bb7ba8465e750a4998daeef38f2663eddc6cb2(
    topic_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__91a429516291494461cb9bba39e3fe8ef0cb18f2e26bafa434620b52a3293acb(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a7c4f61555c5ec755bbfe28db8abb7c61952740490ef74118f504e6ea9c9d89f(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__34b61d7d18033e54916b7fa13384b91ee3323238b1c5f2ac46932cb34e6c3e14(
    connection_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__66e48d2afb7c5313d12509d13e8bd03361ac5f0741237c3d4b4896d77ecee94a(
    direct_connect_gateway_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f442681d2a4076b5a8e99e7d269d7f2c75065b7284c5628121e73a5bed6979c1(
    lag_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5679b50d0867b04badc8c54679a39c5281f36c75c45249093f03e182ff632a32(
    virtual_interface_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5ad850f7e7536943e77c11b7531b24d3bf4431cae51aa9eaeb851fdd065132f5(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8ecdfd05f8fe2905dd7694290ecb0cbd9acfededcb827273f762f2104460e6cc(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6bcb97e5c2e660d0afba42d436fe26b50ecdba3d9ccb4c066cf2186923dbd2df(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a2813455b818e4671a81f706d794783eef3df74b4d84653ef74cb78a4301ba64(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__45e8a99f69386caf2428e2d9b55264dfceac03caca6f8796d51e94498278f53a(
    resource_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ddaed32ea62bb45a533b3f04bcbd2453a8ec8fc4606d38a4d3f9d736d4f8254f(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c0618bb1408949107774e175f9baa7936e00d54b58381aa087c9faa9e7159f22(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a9a8780a8e30792b051dc5fdf8f47fdfb57a39e60e94f386299018b8170a8b12(
    tag_key: builtins.str,
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4ac6b829c3aee68304f739100cc0cfb549351810a3105efd28ff9c6c780e6a8c(
    tag_key: builtins.str,
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7a8e1ae887bc34dda8334d8dbefe7d752c48bf82e7b8f45fac453fa56a3a75c9(
    tag_key: builtins.str,
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6cd49adc880f8890dfae3bf3b9b6944b93bbc5f8feafc76332660d257acc76ec(
    tag_key: builtins.str,
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7944fc39494e530da1e43047ead2c7e7d3d84b7f0d4a2d51b3a31ba1feba95c0(
    tag_key: builtins.str,
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6cf3cf89cea6127f3e49153723dc418788aeb5ddc1c6a1845cf3ebcf31712ee3(
    tag_key: builtins.str,
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__838cd38b53af026722fa9f69856b62f690a076c525706eec337007ef4c7361a9(
    tag_key: builtins.str,
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c9edba34ace67d9bf0663cff9073ec40b01fae4d4114cce3fd556e0f8682decd(
    tag_key: builtins.str,
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7375f805dde60a281f10296cb33a2e9b69b524eed1eccd73f29c8dbc39fe5012(
    tag_key: builtins.str,
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4242060899c566cfa4c2605c5c8a8b3e257cdec2c1afbf24dc9bf3a308b98254(
    tag_key: builtins.str,
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__979a46e4b9acc7d816ac69cf6ef6c2caa122afae41f7f021018923f9a7368dd8(
    resource_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__178929aae43b25e1238bae50bfa3cbdc44d1242f1d311642c979bce67c1acddb(
    resource_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f0d15376802169154d1838f0c70411babbc3c8bc2ed4ee7b2bbcae952e8c6b80(
    resource_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a8da5ff7ecad7bbcd8bb112bcc1e9c61d35d7f82803d01115ca6d7a550c24840(
    resource_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__617d71d8079d120da3cc7f5863cfa5df244bf685895bdd3a58533d1233146b72(
    resource_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6509d5078b12a4321db779ae2331df5a7fb085399f9ef3abe05e68328c08e238(
    resource_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6583e2dba19e940ebb679e7da5a0cc53687bab80739b5f2bade05120944ece25(
    resource_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__73e7c3328c2db643648ee78e38a2929be4750219c79fb574452d11b8e9d830e8(
    resource_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d628658cdf3264e135e8a6ae0ec9039de3e9cd740d8d0fba8a7093bac6eb263d(
    resource_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0349cdf999d27c4a48d6ed9ed769b534bb6312126821f0f99b3484929f667612(
    resource_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8968b30f24e960badedbd07279d380aaeaf0dc48911f9c1d0947efde83d57561(
    resource_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4089374071b2aed6e910cefd94b39246fdc3e91e8050ef4b8beafbfdf0886232(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c53e9d8ec2ba9b2d424ee63b306dcf73f6039be18ac3b6147c1e372f7f631183(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__786ee16db6ee971b279e2502bf5879d4757482cb833a85923315de561ebb5b0a(
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ab0b01c19416edd4e5e2b3b16fe8a84e78935d5275c32198d00835f0b5270bac(
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b61ea483175cc6617e34f5ebdbd975011dc74b4090ce5ae4dee0056aa98a4534(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ff0982417bcb4280f45dfa24598c041fdcbf585321b7f45b89178c6cad84ae35(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1d8423bfbd4444d3b0420fafecee9b73475433350651707366dfd76e62ac0fff(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cda4d39264d8195471d5ffbd971ab52d2e6b3d1f8f1b98d03915d1c27da146a0(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1080cd962370304b58acd28bc635647a3a3d8bacd56b440fd29484cc17a7ee39(
    job_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__24b075c6ac56aa6c53593486341334e5111d2b0b44620dd28df7bc9b2c83ea7a(
    recovery_instance_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__665a40444d6192d2e39a6165247ca6153cb153f59c094471a3e73745276fe268(
    replication_configuration_template_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d24234c4e99b46228388b6796fb7462e10338bc54eb1f5587c0a2a9a4477f00a(
    source_server_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5f2d711f406fbc877afd19337c05236a9def7f5417627ee48d8d7ffe73cb7c54(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__439cd2aff3b488039d90bde9393f5e051de716fc4eb3bdc95e39ed1372b15977(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__56125b7f47133b6023d785b2665b5e66c557e86be724c498b220e9b3b106e849(
    directory_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__43db3845491e40d2525118d0d31ec876fd18dd3f0ca585fde9d9ec49b66d8f17(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bfd1457459910ce11af69af40172e317bf830f791e102053f04dfa8805b2f860(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0094abdd2847d992b0cee765c9687d5ba79d7cf0851e03ea6dc0d71f6e4ebb96(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d4a4e93ad2bc3b551d9c67ef55e3ff8a9a377a3e56d81b2644e887cd6cd797e1(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c0c00a530411385f52359216490558bd5c08e4669dafee3799211f5992f4096c(
    value: typing.Optional[builtins.bool] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5ecc503b3f40fdb0e678c08e280dee21c00366c8747aa5175f16c6fd841ec634(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ec933b1f83954768cc7ec3323dca7df240d68a6d53de6cb1a10e208a1dedefb4(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4b5731b027982b01dc477f5a013761658b5f78faa6f0cef3118953dc4ecf057c(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c883703965b56dae0d42137f4aea66cb41bf25273b2fe3c3dcb2c765a3849b28(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e6e30b0926358ec558b821e0ba16ab234f33ac553955bc8e74efa5958f26b2a6(
    table_name: builtins.str,
    backup_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__beba8f51f9af91f7bc8218b3f3f496765f1db6160f4ea62f2952ec5fc779b969(
    table_name: builtins.str,
    export_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__df516d509b2ad218b848098ac8730b9727a02350c0db1127a827ce68bcc276df(
    global_table_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__71e267f3829bc64f44088d63c04a8bc79156cd02b9595de65064c26f9956d7c4(
    table_name: builtins.str,
    import_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ec7356548561a8fe75d246d5fbff79aef1f69ece8f7f558f60a845d3f9e83df4(
    table_name: builtins.str,
    index_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6370a0b4b19154ba4480800e6eca20db413b542c46c8faa975a51a430a33303a(
    table_name: builtins.str,
    stream_label: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c95e9284d6a3e8fc4d58ef1fa8412cd8564c26c292cda15eb43eebf9701295ea(
    table_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ee579fa17e7e15ead802fb00485dee2707cb6981dee27d18fda4ea00665264e4(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6e0fe0a5b1a6c6f829c3a5a78c801308978bb7ca358fdf14d40c76bdec7d2fc6(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8420b12704870d60a9a94d97e5951eacb27036fce788c2a39d27c32c4ea73efb(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f6421034fcb4fb408fb15683e205e1e0e9f81315e26f531af3f38d4bad19ac59(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__690aafd91fca905136e49b9cf1616a1f94ade72096fed55c0b4aff1cbb1203cd(
    value: typing.Union[jsii.Number, typing.Sequence[jsii.Number]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6dee477c75c03781f77b895a068ce6cbed381825e498d8c630915056aecfd74a(
    snapshot_id: builtins.str,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6ab060e160a84ebfff9a656f457426a287f82d0b6ce4f8c7ada064505259c6a3(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7fd34649c3b261dcbe9d435c393aa108a0bd3d308c571d0baf289129826599f9(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f8f50c48ad04bc6ebfb4c4b5598ea8fadbaf1e6979bcabf0c90909675ad42125(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a4612ad2a34a50feddb99c5382d0af71c677a426f4300e2ff22bec328d69ae86(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__802f4d67d9f5a2b1721bd0e0bfab0075391d6c54ae0eb5da49c2a25803ef730e(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ad23ea40782284167e5f5047b975b1e3693b6dfe1762298659bf0e2049d4211d(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6286d544fd13ded719eab99b35593e0260c111c43085f7c48dcb7571fd606a2f(
    value: typing.Optional[builtins.bool] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__38359839899decd15fba858a2fe7fa7039a7fd1b762f79c9f8535db645216a05(
    attribute_name: builtins.str,
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ac4823f1f4a6e8291df54597ecd77e36b91f15910355e19d712bd2b6a6f1ea59(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__700f2974c34bd07143b8402ad7b5895c5240d03123a11bd2d824e0c3fa467742(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__925db782e3ff7aac23f0bcf89493a6f44ebfddbc2b971ebf547afd0c20f905d0(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f990078d513f84f2dc386c9b363a811b44e458624ff72059fbf6986ffe7aafc2(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3eae124cc4249d380102b52accb327c843cede9189f70c5f37713a07ae061e4e(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cfe8cef3548c616e0cc690a8875a4b09566108ee2fa4d0d9c62e77534a7d65fb(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__88a4f54443b19108c169fdd00ed2b495902f6707c7f75f72adb6cc1a6aa88d7c(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__35b424cef69cc9757237c2e8a0f48afbb7fe97553e384bcaaaef171d45c53444(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2e064486effed4e7294bedba31f304a46a92455e44d3d84ab2e30392acc28c54(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e5d941d1f4a3703147fca85449e69ccef3873230a42eabd0bd7ab5e619c0c0fe(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9f758c663ea71686011283c1ca2513cde21fa10e484f15298a8d687cf864514f(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__37f7f882ed78e818d901e898e03f767e8bcd1495a76f64bc3f3e6ce76e8bf02c(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7d9d35ba8baea3d5254e894833c77f9f88661c985c4536b5b7671ef580845911(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a1fd3898af63ffd3142a469a74168d838cf070551e1efd97a0f7b57cd38b4e13(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__12d38aa1eace71bfb9ba5b717facea9808c59734d0d59a17261df66cafc16287(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__36ee909fea1e05cc5168475754eef43b496bceef19f22bad6d43d0ee283bdf64(
    value: typing.Union[jsii.Number, typing.Sequence[jsii.Number]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d6a12b2fdfd96740db634204e10755b9a6baa2aadcff0582a902cac4a08cdb53(
    value: typing.Optional[builtins.bool] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__047d56c802da50b5c065a6438433fd1ea2889a0a8eea4e28d763e51c3af666f4(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__15e21d333e2b0f8bb3ab0b0828d305e1eaa95a0656b858f2d6314d4e23af17d3(
    value: typing.Optional[builtins.bool] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0415b8a3214a7780a06c5d4115db7a2def724bf4979e89cdf31e3d7f2021f965(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3827ab76800e793e5b6fd36c232275dd79fd35420542f33210067b5809602ca7(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a6f6fb70fad602f86dc1212cc3f5be5f0ddfe9a3a4bf683d4ccafe48a608641b(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e9673d4cc46195e8fca2cb68a7967fa2d72147194745dc2ce7c31923db1d216f(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f740993be93b043b135001f0f46dd12f625b7147095ad284fa817bd171533515(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__36ee5641e6af4fb0583b528ac01513364e2c4032393be1f59905c31db2125fe4(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__19f21b7bbe550ed695ea2a296cad35dc878bd55d2531e840afc9885c28bb954f(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__82d1eef9dbe0b86f8ab9ae733af258c255527a69c3d5bf11374222fe8542b20d(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__333732ea20168e808eb498e83979d0de73ea87a9a19e0ce4d05213ba4e297c61(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6f1169da7d40ba069a30b4580592f56f0e6c0e0318946f540822d809764268b5(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ec4072195f2a341bc429350819ee61690ae6a86b79774ae9098b1f69b8a52d70(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__60ef6ee8e9de0db3262a0f9a4f91c61ecfefd1368d88f226308d209659448735(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d0ccbea6543a54803f5476132fe86bac0a1dfac79c5b7c6fa579fb377d6e22ab(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7a96e3dd0963776680872b6f7d373213400213202de1401a5f87fee65db3c4da(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__744909111fd3745942b4a34156a4259efc52cd9f4bda68b78827c214a72bd4c7(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__989699a0b2daa2a369129d277980eb027374d2c3ae573195bee6bcb354de303a(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__19a5ed61b4f065269a360dffbf17bfd6e5515fb0fcaf9baf3fe97617c726a941(
    value: typing.Optional[builtins.bool] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9c8969b27ba178b9d4e39fb9ae660252f8c7f4f221d59b803ea185c24fa32ccd(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f9aa2d1d7b3eabe65c32ec35dd83be66e0df822d105ca8fdb42002fb8159873f(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__74322a963c73c20e7e304c0b97fc78a8fc21a5c2701043e8fdd1889ca70ad35d(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__28d1ed6dbf8ea017b547d99dd04c446b91632370da9e71ed12e53cead52f5414(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__719b3c6674919f4a7510872a3c38351183d8b47711b175ddf273cbbac4bd10dd(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d5e03acc1c2c0a9bd57d6d523e3aa2199072489f02c149c879f5f30be1263425(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__597fe5e5a5947c1b961bc50d3a572528c4d3195d6f200d6e87c8a466018bb586(
    value: typing.Union[jsii.Number, typing.Sequence[jsii.Number]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fb0d815ccec13ec83c0f19677807b9b8dade99d0d75c89d9410c27c523606e0d(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__51bf19b6d65720648bcba6d6ba8c3181fabdfa63728fdae5d906aec741215dae(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__266220e3276bb9566c3bb23f457e7db33f6e961539393f3fcf2c7fbdcff55115(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__307c861dc4e5cb0868655a64ac38da6d71fa4baf2b19d9c402a9ebaca7ec2400(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__aac6b27eb7663ff2a4f55124991af927882ef42d78b37f7699b39ed0f957852c(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6ad6bcb6cb10fd813f662a6dffc0d53874cef6acd7c9feb194806a73d0c92015(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f5dc567ddf96b17e83583e7246e0ec7e2b606ba8d0b3499c7933eada2d187920(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fdbf4a59f3ca63c5c338dd68bb745dbccd13124b27c3aa032a870c4db9bd4190(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0d46dc0f007e0d14be9d3cddc505761382ec31623641c023198b6f14c24871cf(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7c2ccf717d03cc99f6c3256e4466fed89f6cc95525fc39a52c693e245a53774b(
    value: typing.Union[jsii.Number, typing.Sequence[jsii.Number]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0066a1edbd928ed3e9ed4390a688975c63e49a10842a496e7d3fccd6a002c7d3(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__49108caedd2e2248a34c77de27c2cec889f740d7062f503b03fe8513460cf7bd(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c11142849641b07bd5b23f1411b3e75911fa61ad4281a6db3df02a8dfd697603(
    value: typing.Union[jsii.Number, typing.Sequence[jsii.Number]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c53bada1e6fbe04ff888517b90e8088f10df08f531c83064798f9670dd950dab(
    value: typing.Union[jsii.Number, typing.Sequence[jsii.Number]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bfeae2b3d57884115cda9453cbc8d9d5d3e8e3ace5e80c0123671217c3a6c14d(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__054fc6df4dee823c85bbcd351721899c0e221d442daa604c13d3ecaaededa4c2(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7e659b83d4606871b16579c89ed135f5154e788ab8235205d7268b466cdd30fd(
    value: typing.Union[jsii.Number, typing.Sequence[jsii.Number]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ebc2077b159606cbbae4dde37b90e73ec78012ddf1c5f8336faa5497fa2c5028(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3d63678cd13dc3800fb6c9899405d99a181c045082385917ea38fddf139d72f2(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c05bc1b229aca753b7e0fa43e18c3f66132e2cba3a9aa851d3ec000e1bd2c0c3(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0412c8c4e804a75b1ef9acc068f7ed63211aa724dcb401fc87718549f1ad994e(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4823539c3c1c3ff47ddd949e999f730039635a3ff6fff636fb5a423c04aa26fe(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3de4d6e9b9b7b137277b8dce374a06bdd6df76c6bf8b4c3a9d4c1c194efd2f4f(
    value: typing.Optional[builtins.bool] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__79ece51f24f1bbe98dc2a72051d7794e71831798f42ad21843df6db9d1026873(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a393844f6cff7c87a92759c72e23c429e11b36f5bf4e21c06c5faba0e34ffd02(
    value: typing.Union[jsii.Number, typing.Sequence[jsii.Number]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5c649950e43aeb69f47568aad21624c81ea13a87fa080fcf8bc60372eccc12c6(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__22cdae31aa3d8aa353f6e9edcd3fed766a6c8db874ccdea3287d7dd882d6196d(
    value: typing.Union[jsii.Number, typing.Sequence[jsii.Number]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5b6fc520d5441542943c0145e059cb6ec8bc3bf874b3114a103a68955051b651(
    value: typing.Union[jsii.Number, typing.Sequence[jsii.Number]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6cc01ab8aec76ef864b9ec256e2bb3faa95731125210fd69e7192f75a23f7e1b(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e563484649b3ac0c2889b15a1983c3630e0dc098f22f34590851b55f99c683fc(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0ecd4b19248898f758b1645422a4363c9c8611855655eadc2a8583d87ece7a21(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e7d709ac17f68cbf02b9949b904d418b3fdf9ce19a31330729346091ac912cd4(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2724814297c4d8ba3502542abdfabd6cdea9c16976a950289ae7a76440ab5314(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4ca9a8d6119194d149537190960966874f6894ad997749e17d612bc989cd7ed0(
    tag_key: builtins.str,
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__aee063e0e2c68b5cbae21527e58a849b722b23a84e230d17e369b2a603b4dc27(
    value: typing.Union[jsii.Number, typing.Sequence[jsii.Number]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fa222866d8796bff456f7b962403efc0775e271b3ef8f959a3ca5d5962314dbb(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__de957f1470af18893125781ebbaa49cfb68526e98f9737e4fadff26720ec9b72(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a6140454fa7d65f4b388dc915bf25198bcf7ce8d3911aefee16ccaa58e923202(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__78134d2500054346b464f7ef333d987097a942d7d15e52f3b9defa79beeb8f5d(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1cd0b11de26c4bfd57ca3c3d97267ca69cc67da5230711820032e9a452706b01(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8f1bcf35c0f8951516d76d7fd775e037019fa27c587ca44faf7d437813371d5e(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0049bbb38a384953d241d186a2ee059263d86b7a467a785747c4fd7924cbced1(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__28cc01687f0297685992aebc6837d303150ec95335f1a1c28bebcd0cbc9ba015(
    value: typing.Union[builtins.str, datetime.datetime, typing.Sequence[typing.Union[builtins.str, datetime.datetime]]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__62bb29ed5ea2d281f86f0966e8ce8bfcc429638556a147a9becf54b29486ea5f(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__28d9ab53f4c6aba85b6e25aa284f2eb5f99455469e04c9f76c857ddef63202b3(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1cd02df06b0efeb511a5dfc87e290a1bee847cb56c1a746c35acf1cad40478ef(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5e97ea1af7a101fd96b80cd8fe3cf40325b032a17f98596f073950112d071ef6(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a34f2bfdc092afd14d8cbe502a29a4db160e7ba22c58e33e032994d73efdee7a(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c6f72b493a175e206f70d9f8e5d6e872b30c362a34061acc0d0369ae3750ec03(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7fa122c6bb70603b16596b0b83e65ec36172ab969decd1bf29b9718edde434db(
    value: typing.Union[jsii.Number, typing.Sequence[jsii.Number]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4ac93f3e9ff2f38b1516d23ea82bedd54a55be7307cdf45031f8825265897a1a(
    value: typing.Union[jsii.Number, typing.Sequence[jsii.Number]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5959b521d09e5b79aeac0bddd14124cb07018d16b16f438c15af8f949e7a4f2f(
    value: typing.Union[jsii.Number, typing.Sequence[jsii.Number]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e0d32446c9ffcf63bc17a624a562ddafefdb29e4af69ca56c7ff437795dd012a(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__575fdc18cf3146273fe71065d4390862678dec38207d42dcbe6be73b0a20d034(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d17afabab6e5a6437f74e4c35ca1c27d03dcffe72a6e97e091f3894d7c2f9c2d(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c4d5ecae16e17b5b22a45839b0eac95e91a04035da5a082785721ff006c5927a(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0b6b2885e419f9b23294be86a99fdc1a3835363cad896f9012205b2beee31d3f(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d54edba9bda6da3804a1f39521c91346eea5eba5e1ee3eba92e245452f837d6e(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5974d812880e0f3c6b4a516156c4944982bcf1727875e7366b6d6e6303f08ada(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ff41c2fda110d642beafcabe0959bee533ab7f34133b5b0ee4af491c0845eb89(
    capacity_reservation_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__18a9f8bcc38d2985b3e4c861c7c1901029dfaf5350bde104e1dfb7bed1247979(
    capacity_reservation_fleet_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2fa6549d0ed21e190dd1379d31437bcdd4c95dd1de9d1f38c963885cae1cab67(
    carrier_gateway_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c53ee85556e4c23bbd3eaae5175dccaccb790cd2aeccee7e71bb9d5da9cff265(
    certificate_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bdfc5504a51a6bb3e700c5a351e872cc7ba1bf4887e68bed0e9138222bf38ed9(
    client_vpn_endpoint_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2b84e98b8f7f58ccfc91d4037c96f4b824a8d9c3d51a690024f94bf5be2ea277(
    ipv4_pool_coip_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1e98f25a25837837fa138116d82a10d071f582968a7f2eaedc7a575c0f28166d(
    customer_gateway_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0973eea738e20c9ffc5bbcbc015f8714a978c6d7638f9b9215b91aa550af305e(
    dedicated_host_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b894d8c356570c61a215632142176b6321dc9bf2e571cc80917f614cd41f4141(
    dhcp_options_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__995abe701aae34805dc1b6651d2f5c79434f51b4de9af528a2a93ef469b37031(
    egress_only_internet_gateway_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__87cf976d1fa0426f40c671ca4430a31fdabf28dca29f931a3d47ae3a4311d8dd(
    elastic_gpu_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1f3c513c9ff62edc0a24365309d5be574e75368458386c4f3affa1ba704d84aa(
    accelerator_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__24aeed9d5213ca35616a4f2327f855689daefce19ac0467202e288bf62fa66e0(
    allocation_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e2eae3918a9e040c46244054bf6a1199d06e1e09b52d3beea283f80f06726d6d(
    export_image_task_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0f27268da4274ab7856be2becb92226f4f6a593d605f72bf96df4187664813e2(
    export_task_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__275caffd2d9652619ad94eaa39f933045678a6ae1fbe423142c50aed695de1e3(
    fleet_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e74c3459ebd918e807dd15710b61e351d6b68fcb31c1d46c97469690271da2ae(
    fpga_image_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4fa2a071c2391bb20f846e520a79cef67f45bd0f02d36bedf1e13a8553033e01(
    group_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__038dd63a1f986bb810accf5de0868216e0d2222776f211b47ccdebf2a809c91a(
    host_reservation_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__128ac21d255a419cb7a8a693f27f83d549f5474a99231190ae68fc01533a63df(
    image_id: builtins.str,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cdc585105e2be50ba97bee94ed5661aa7c1d52d6dd7f4a5e866c8d4c4029f853(
    import_image_task_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__63988efb508ee2ee9f4f025d55de53052ab4431044c95805394e41162df7db25(
    import_snapshot_task_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7b5f4eb88c1597f515c0b0a7ad0f10eb95fcc48e82d0ef49a73e30f89735ef25(
    instance_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0ec9b0290c2ed8288635ee6e448cc007ace5af4338c153ad367c6f8dd8c5a793(
    instance_event_window_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5a0801f6d45778d30e0e349e736f662da1b28770d748d6cf585fb70db7c37f14(
    internet_gateway_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c016a91a5d7c594ea9112b01a048fa247501982f24b56a5f8e9b7377f98965bb(
    ipam_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__95d2ba0720d8f81bea195f380f4451deb650f34bf3d4ade943937a100a4e4da6(
    ipam_pool_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b97c815002439b0270e62e1f8473a9296d2d6cb8e23273027c9cc0d474db7efb(
    ipam_scope_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f54e2d29b01c2abbdd59cdc6be0cbe57c80eadb2a6ab670c3eadd353004033e2(
    ipv4_pool_ec2_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3bab84c9b8f13f56da1e325521e24ed6b54341d5d5126beea73af2e2010b5590(
    ipv6_pool_ec2_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__73d70858ca58eab66d0050b64cb2399b059e150334f64d8c3c5c87a76c3f38da(
    key_pair_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1a8c62ef57f9956fba2ecb10e98d603c6a1b38102720b484e149ca1799cb8f6d(
    launch_template_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__424eb3aa990ad23a68b94c9860791d37091fdd89761384ccf791498971804e02(
    license_configuration_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__03ab5ae72e9e5be4574eea33b8a3edc7021a36e28e7f2f66e18ea17a6d28a9e2(
    local_gateway_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__30fbccbab75eabbbbad4c0544bd4677f819a4766ecb5328f6605796724f74241(
    local_gateway_routetable_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ce037f4563039e3defdf363a0c615d5e2d5da1fc1fa8e0c7cc2c4c2c9fdc9187(
    local_gateway_route_table_virtual_interface_group_association_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__19c8196cd84705d97f2fb0752b8f8e8237b4803760daa20d0051b7529b59355a(
    local_gateway_route_table_vpc_association_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__eb0c62a8b3038430827cc91bce580bbadffb8d43cad27eaf44f805bc4c853aa2(
    local_gateway_virtual_interface_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ee9ad2a34c0aa428bb8e63950546726d819b573afe912a421e1da9790570088f(
    local_gateway_virtual_interface_group_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4a6ba0710c73a276eb3a0577e052d93fb874c8d3acc9979bf901f590386a55db(
    nat_gateway_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2297d70d95fcb4a8a2bee798daeae3bf6fecea7e260e7e1334e73ba71de8bc2f(
    nacl_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__625625649c6586dbd2b285e080d851ae6f9ceb23efc5aa0e7e83f8788386908b(
    network_insights_access_scope_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7518ae30f5475a57f32d381d2c12e9a32f0272a513c65d919465695c3f9b41f3(
    network_insights_access_scope_analysis_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cf65b4e38026f9af15c0d1de82423efef3cfc123a825ffbe2b1d1cca782cc917(
    network_insights_analysis_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b370e519b5f1f7652680f181edaa03cbc253d15df28fcfd1dbc9c6bf48d6359c(
    network_insights_path_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__24e03346a09440b995413651c44e476a2306029b9d9bab98cb91d749b48787e9(
    network_interface_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2d66f898c30cedb71d8d6a08af6166e275af30cc289cdd8811ed33cb1dfa170c(
    placement_group_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5680f6ef4446a8105815a2e17023cfbf5edc83e1b532773852de4dab8e8ea997(
    prefix_list_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4568185401d99542b0ef1faa06d51128bf755073b627a788a0813cb4a18e43c1(
    replace_root_volume_task_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4ef05aa95a51459f6dd53cd65ec57c43af8cd5e23d3c546eec11ef697eb08201(
    reservation_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1bfa444315b99a38ae93d4b607bfd70a7e20c3aa86ac91ca2fb6e323e9b01c5f(
    role_name_with_path: builtins.str,
    account: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__68d41184f7fa95f85ffef0bd1befc5952fa150a6b07aa6fb9c6eb9c361ac151a(
    route_table_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c4c992bb6bac8aabfb9c25bfd9cf3c637452901a39df4c5463eff3fc34dc5c34(
    security_group_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__408fe256e3cd5dbe6134e5985eb83f26adfa1b5e6dbef0197b87358ae96283d1(
    security_group_rule_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2f8d8ffe31aa417b5b25d257023b5f8ea7b14113f57e3c9bee04f37e128f63a1(
    snapshot_id: builtins.str,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b7d52f093f4d5219d007a81ea85afea701afb87c8f9553698684172942782de0(
    spot_fleet_request_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__565bc9e818a5fb8cd3fd989fb41f4f86b78b71bb7ebb6e86971e47ad76c8c5cd(
    spot_instance_request_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__774aaaa6249ed323fbbb90783e15ccf274cae6d466751ff3e84dd4224292ed80(
    subnet_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7170ce99ba88094d622d4e1285ec0ecbc147d00728e0ec092cc930a3ce552e6f(
    subnet_cidr_reservation_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__137c096ba3a00422a087ac9690bf8aa93bd9acf4bc4c66eb4c270b82cbb210ad(
    traffic_mirror_filter_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__90b4ee9fb5078b519fdca961d5f356d0840aa3acb9af81a879564f1039332864(
    traffic_mirror_filter_rule_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__556966a2a34d3225e7da938caca31b1c198da570e9c42459da187374b2dc9306(
    traffic_mirror_session_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3b986aa81ed3ed66e0cee53c9b8424ad2abf559f6156eb79e838a5bed3957702(
    traffic_mirror_target_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__49a1e2dfb021917a22d853b3c16f51d907a53dcb331b909faa33a87760604948(
    transit_gateway_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9dc2c3b44a22dc29b94a1a6e4b493522d07d5ea78e102e56492c656a9d9d9ed1(
    transit_gateway_attachment_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d7d588383c5bcba06545e9e0506bd05fd1f6dc26d88888b320060ba41f4dacad(
    transit_gateway_connect_peer_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b6704f8dcea088c9c5505a85cf5a99a87c5b550684ed7806025dcbb5059f0688(
    transit_gateway_multicast_domain_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fbfe4aaa682610173a46e4335605b04c498ef741e78bd10ed5238b48a6b4641b(
    transit_gateway_policy_table_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bcac3f97e0d8c151cec899ffa84ce744426e047a5204966589a02d2c40e1736a(
    transit_gateway_route_table_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8c29719f467d7be66d3d7a8731cd7ada92ad01d61f202eba62501f4be680f794(
    transit_gateway_route_table_announcement_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a63349803bbee55efe4acfd789f42092785bc2ef0a00c9cad1698700ae5017be(
    verified_access_endpoint_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ab985e108a6105bb4b4ef33d13593ac193a6c2ed1dd51e5fdbe23da0d803a67c(
    verified_access_group_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__31f3461b70c40ed85fe087ac8d33742565337055f91adcce48f54d71c5334d4f(
    verified_access_instance_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ba883fb23e433d9195557a1b9330df23af2dc17707374c0094cb870f507473ab(
    verified_access_policy_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1250788a1b44f73744b4ce9777426698bc61427df8f4df61e80b7ebc1ef7fb2d(
    verified_access_trust_provider_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e8ac5a869e885b41217b7ce236369205e759db96be229443a6b89801481dd6f1(
    volume_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__25ba96f8bfb7ca0225571cec2ce7042cb1bb21b668a0b0378681ee73c54eff2d(
    vpc_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5f6c1b111e57e99c6e733a99921d1b693dec04fa3cb85de3dd8c323902fa8f13(
    vpc_endpoint_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bdd4580372f0fc40ac2b7c4db1dba171ae78d80dec90b7671a572d5204b3e64d(
    vpc_endpoint_connection_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ee39392e59f04822de81372422e3b50c74699cad17581cd739c15cbeac325aa4(
    vpc_endpoint_service_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__72c824a33efc91a7e1bd7ec237acfdd6987ed136ba30752677f0c30696e97bd2(
    vpc_endpoint_service_permission_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5a7e8a45fa0132721ae99ff4c5e87c38f3131533e94b2ea49b3f077d49af2e96(
    vpc_flow_log_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__06365d1214510039b34c4e9d18fb8cc3696f2182adf0f8e57d4f5d06c8d37387(
    vpc_peering_connection_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1d929f4199cf5061cf65199bf9b9c030168a557a68d441c5a89079b654ac0ca7(
    vpn_connection_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8b1d23d14cee5fed3990249de75eeee97bee3178129f3ea7eca048edb2c8176f(
    vpn_connection_device_type_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__92c64d2bca9a7375052cc86af1c736625648f889867ec44ef81f786d4bedf995(
    vpn_gateway_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__934037fbaa163c3c48b4e6312318ea22d6db7bcc004feb143ab3b2f17f47dd71(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f426f94791b9de3a14746d9cd30b4d4c64ad648a8f5c46eb2e87e5cdbf5a4da1(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__eae3ac954eb3390081bbae9f93a5e468e81e10bd4ec969617cb96001197c3a02(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1e3017e2027eeb0ecb935ececd4d2e36dc82d42dc7eb0839c55f8076c4988da3(
    tag_key: builtins.str,
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__daf41b792ad9ae13292e3de0339a494a3815190867eac3a953b6a9a9e2d0d9a2(
    instance_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__33fe7fe208ff1bd6aefb43f8171995f5483ea9819beed597af82f225fd40e608(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8c386bae476d9f891da573d9700636fc8e06b6900b89662385f7117551223a23(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8abf628d70a5145dee6086bcb4075aa9b9006eae8c8979298f243bc6c97623fd(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bf1b0f754e4e017feb207e51773566d9ca5a3bd2e7a83e91710b0e43c1f1e92e(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7ba4889f0a3e7b0504ee75e9dd278ae12478acf931487d4e6ba9cce22d0dd0d0(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__92139a868bf4d6bd5a50a1dd2a8de6a0c9c61e2ee49d26dc7c29bbdbc5f048e6(
    tag_key: builtins.str,
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8a05455eb7d980b2f463b6ce6aa39b6eda81dc515ee7ccaa2c39bfc157d80290(
    repository_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0aa8078743b1b7ffb24a3f26294ef9f895511d79bc537ef660e64842c6519dcb(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2243377a86dd36a7a90dbe794efa0262f23177d22d4672f59f2e514fb2c726b6(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__659da8b62b1a343729c493e445d0d7d41b4c69f2148e7203f870b0142baa1971(
    tag_key: builtins.str,
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b187664643c8446b8020c6328ba73ecb3f7d3662d7e2ffa983779d06ac58837a(
    registry_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dcf3e2aa288eedaba36cc8786b12e8914757c5b51b24778edb99fc46dcd6b13c(
    repository_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__18dedbc65712202df1a92b10ff4ccbc3e11144e0e19de68d672fad3d83e7c80f(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9a2a0c67082e56de81ff4dc916c628f1e49ac720eefddede07266b9d12c0766b(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1a6e1271c981e154e6624ae3f634f08582ed7e0d531b18560e0e1718256757e8(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8fc53746a3aa57feabc246edc190d7d8b836d71145cf79364567d2575fbc89d1(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2f8898c7b9f06f7a4e64875e6fb2567913d69b79d1d6080d92cd3968cdda1c66(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__813e7535c90adacf401e71d8549da45e6eb13bffe697485c6ac782a0f2a3d737(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4112aeae2eaa543c52aafdb5944feeb8e1db6f351c6c829e945a311f2ebb85a5(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__73d6553d8e0dbc16de56444edbd65741ae781cb1bf23e65c3ce8e5d5d1f65934(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3828d03e165e1e934d4016d0d050d2234e9fb8f4070fea25a36100208838fbdc(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__de8cedd2bf64be021af1ef3e5ed6efbcf163a6c74c31b0527c6503a27c58fbce(
    tag_key: builtins.str,
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f3bf55f495c823835e1477dc3d616fddc3f39024da0f664d388cd695c028cb84(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__36e05dd7b01a95d726aadbd8593ba7948c1c4c6199eeccc57c13cf1cef76ae9b(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__befe98286e060b0504dbca133964faeca26f622b1ecd759afce4033921d7d55e(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1bc3498a41bab90aab11408ccbf3edfd189e724a9045044c8eef26fde83c4f95(
    capacity_provider_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__04a10e736fa25d2f2279afffcbf8e707e593efb86f85efcb18cad53d5a1f8ead(
    cluster_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a2924602e19a37f5378d772467e919e117d3990e46f3f196240000197c7056ad(
    cluster_name: builtins.str,
    container_instance_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__49e7b14897cbf2795acc7d89daa2f2f76325ffa40479f8bd01297e170c4a91cc(
    cluster_name: builtins.str,
    service_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__add31618cd9b5b5ae87161a1fe19926e20b1aafa2ae2087352ea4b8c2528d4bd(
    cluster_name: builtins.str,
    task_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__eabba7ca268ddda152db4635b97704b39c77c8cdbfc7a43de3d74fba91b54cd5(
    task_definition_family_name: builtins.str,
    task_definition_revision_number: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4cee2f38404fdaac5ca13090f70d66567136e9ed86d09008153cd0fc5b2cf110(
    cluster_name: builtins.str,
    service_name: builtins.str,
    task_set_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__58f6d8a08788c3f432c57a1708c69f4a10a65e6d6675f886f6ce6fb00abe6c0c(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b35443e45f47e33a6c50444f5573fed0a8f3663835848c1d4913d074e0d71ddf(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e82c7b902d6d2d43be10b74ec49f343c07c2b0d4d056beaa746b0ab7c9ecb2ea(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6c2933c5b14da3bf46f1248362ea8547bb26403962b2ed12a7050eb18ab00e89(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9ae32778e4314d268e8bc8a7cf70cca6f8aa556f5388763085dd0015e77352d8(
    cluster_name: builtins.str,
    addon_name: builtins.str,
    u_uid: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9f1826aa4b08d47232341ee48d1eb555dce722244ff25cb429d9f3aadc975cf4(
    cluster_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2423bcc9f9bcb834c52d4d73094159699d7e9b393159c8daba3e2dc37814a209(
    cluster_name: builtins.str,
    fargate_profile_name: builtins.str,
    u_uid: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1e553a7b8c66b2ff7b315d00ba5480c57606bdd67eb1ed11b30df42547343810(
    cluster_name: builtins.str,
    identity_provider_type: builtins.str,
    identity_provider_config_name: builtins.str,
    u_uid: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4b18c1ed890e4a14119e1486282bcfb0eee941dfc2438a432688780bee11f8c1(
    cluster_name: builtins.str,
    nodegroup_name: builtins.str,
    u_uid: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__63f441a42f90093ae340329085a9e4a668e292a2cc69b84a803e0fd8be6e9235(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f0d7716049faf0b47b23775ab3be5e07b777dba20db61a94e51eb4268e82dcc0(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0cbaae26bf5c741593cd6022213bc8ae0276d1d01be38715a3bfc7c353f17322(
    accelerator_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__943bd6f53e166e7969331fb8ca6cf46dcedf9e2ec2bd2eaffa4df06e9733a408(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2552e528898307836fd1e3578668a93e06771d3e61892f0ed768c0381b325889(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__963add2154c2b0d73199871d72c352073138b0999d2c216f0ed512026256648b(
    value: typing.Optional[builtins.bool] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__80d7095e4e1fb864367e246e95efeac4248e83e22bed95b4d51f132593e847e9(
    value: typing.Optional[builtins.bool] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c0fb04b2405ff9922cc07adf47c4e995053a79568808578db4abc0c6dd3a57ee(
    value: typing.Optional[builtins.bool] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c1bc9283cbec2f0353ea2e17b6f12d6a3c17c2c62ce92dc49d6176a8d066cc61(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8f78d5158078d0eaba779f775a994d15f65f29eb56779d4ac56470ebe8289e94(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__843ca009e66c8d2c54572ba6344058f4ec810cb259733b7270fc550938a76e98(
    value: typing.Optional[builtins.bool] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bfd939b1e37e42ddb7b8a14a485039bd432464edc309a9892e1a89f9d26bf332(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__51166d5ecdac368ef24a28dbdaaff9d764c12a56c2b2c687c77bd43b122b8013(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__11726947c5e06eda4b58d8fada5cc770319061001ee62c518138fa0d6f73139c(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a0adb4d74de9beb2c5110d64ec23f3f8dc44f641f06ad33de079ff5b9bbaa30d(
    value: typing.Optional[builtins.bool] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__774563aac950e5b77e966d9597f5b93c7129b3bced7a2d3c0eb246bdd27216de(
    value: typing.Union[jsii.Number, typing.Sequence[jsii.Number]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f88c4372275bdc5733126df5536df54f4628a0aff44ef9dff6c436e742fec1a5(
    value: typing.Union[jsii.Number, typing.Sequence[jsii.Number]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e4cfe7b2650043dbe34820f0e244258f9e9f51e2c7f69d0f60000845907fcb1d(
    value: typing.Union[jsii.Number, typing.Sequence[jsii.Number]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d42151a1f6545779a48da094feee4eae72ddf38003247cdd2edd27badce126cd(
    value: typing.Optional[builtins.bool] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__33c6968810c7b315ea50e43538fca57fb4e447e506dfbc5b47247264d3d9af9b(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__206494a77537414da56a8a8d95bb4c46fa0e2be1ddebbe3f78fb927fceb10f5a(
    cache_cluster_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__40565920bee846bec4d1f8549c35d98d0f97d3bbd03913479e696365f869e870(
    global_replication_group_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ed7ed72994d643b05b573a284d5475565928c007bfd9db439fff23dad9601794(
    cache_parameter_group_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__284e0dda55a80e1908cf6f8120647392e86324e688c0cb296fa3ba6ef398e082(
    replication_group_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d5ee6fbc27a1f20dae155e3b3a687ff144f76a6dd0bfe4c57899deeb1ff22442(
    reserved_cache_node_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b8a889d07c385cfe78dfe37c97be5d937b4e8b62268976a3f3d5d2d04054aff9(
    cache_security_group_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9eefe285efe0aa84e1b005b87a5a991d7256953ea342d708b0c81aa9063110e0(
    snapshot_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fe4041f1c485b1ad799d9d8c1f1576cf7322239ecae537bde857dfecf559b06b(
    cache_subnet_group_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6f0f2a9ec7e1dc7d181ab65607bfc44f6caf602502942abfecf6a06e1510eeb4(
    user_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5c916e02c1b48453a7d31f8a6b5cf24a32607478fee0c35a173b555d3c408f0b(
    user_group_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3f71a6da1056307b1ef4de1df3b131a2eb54105635fa0c427de367dc6ed85cde(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__98af9d0e0f3285c67fc05a441c7e02905737a3b1c61009543cec05b5394b54ad(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2011df58cf62c621ff013e91fd7aad29782efd8a2696a9c62202664d22fd79d2(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d76c73ed21ea7ad730e35ab7f1f2d2fc1e58ab80f4c43534bba2e79fe4a8334a(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e83817dfb14166fa6ea7aba13897dcb127eb4a0d2d0daa709c284dadd5120724(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__111f6b9019cb1f0b12d48fa9ec492163984db7f00079813eed7b4351a63be836(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__07bf47c7224058dc72cfa9ebab5369c7edc0c73b646a01c35e006f3bdf491d07(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7b55b4aba8e412aa41ceb2918c7438af64639f318237fa97e796d305f878ba03(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__18eadeceef791625b103bb6edc7ab13bde64bf06b5a9afa4f3b16cb74e9a5136(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__936993d5bd6842d66199f34726d366509e0bd18b6747e5bb615c8b9195368d00(
    application_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__30f4e6264e6695e51c78204fb4b11936d5f390e77baaa5c91c42debbcf9e43a1(
    application_name: builtins.str,
    version_label: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8037b4af3572c3e8a2d7b8ca3b8758b0c23c31742ec7255a2aa6379742c647d6(
    application_name: builtins.str,
    template_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8562f8d9604468025293d2d7cd145e5c95dfc46a00d4ceea60ccd1fd8e6562b3(
    application_name: builtins.str,
    environment_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c436402e4cc93c70a7d1621de0eeebb7974119d7281227dea97458bdd98d3700(
    platform_name_with_version: builtins.str,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__47c28976ab644b571f4edb464c4d0c76c1052af93d26faf8c3192e4d72eb7741(
    solution_stack_name: builtins.str,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b3df372293686453a4cd663fce609bf3b2ee0c9a2492d0295aeb99cfbacecef7(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5ffec6d1af9e2efd573049637f946ade360d961869b3e60b7e1542851d02d822(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__29e2907ebbf46520d1ad5cb529fb9877fa2762231e74c19537b39238c772137a(
    value: typing.Optional[builtins.bool] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__67f5a0193c1b2881bd82e10402bbf056d4f1f76bdcfcb33b5b8658e1dfb1a1ad(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ad515cfe78fe1ca67a6d14160e04d97e23fab51296a3abccb3b3083d2fb56c9a(
    value: typing.Optional[builtins.bool] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__747ff12390746bc038203b3dabf8876a73a498f0d00d85d87583bfb407273a7e(
    access_point_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__233e8627c3247c5165d833a6b7c604f7411531d79b497680c758cd68d3e4bf51(
    file_system_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f7590aadb5782e0484b9462e6b8f4a87b2b91d91eb2697cf5f3e8b09acbe5f3d(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3d10f0ae79373119dbac8600c6ecf92e6a8cfdb4825f7759753835a5367660af(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b9ff21dbda62427423edb12fdb5f35035a25b6b4678cc79eed8b4980875457b4(
    tag_key: builtins.str,
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ed8f08bf7206e73ec4430867cb33010dcf92ee9dd02d7e674560234b02be8c5b(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ab7532a7903dd6ed3901721a076300fbd89ac8adc5f538627c83695afdfe3456(
    load_balancer_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e3efd3565d5f771b9b1232658d5f50f376f065e13599a4f752ca12042b8a8e49(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__79a6af40dc8d322239ce088b149a8d5bbfc210403b1e91b47ed291e4f9e2569a(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fcfdc04d43df14a3729a9a902714c1f11afe728a2830f133b2a05ae5755b6416(
    tag_key: builtins.str,
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a62b7a527eef8275c168c94a5f135c72a4a8c6136c7f6bee4c6815bd3b94fb99(
    load_balancer_name: builtins.str,
    load_balancer_id: builtins.str,
    listener_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d6c856a0be69757e272f0e3eb8973a757047562272219da97ac535008c4748f5(
    load_balancer_name: builtins.str,
    load_balancer_id: builtins.str,
    listener_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__153bc26c619ed6176278d4929d0930c08e80e9c934f9b4734c0ac57ea36011d5(
    load_balancer_name: builtins.str,
    load_balancer_id: builtins.str,
    listener_id: builtins.str,
    listener_rule_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2195043758de34d79182db0278aedf161d4eef60b36c5b08ed67a40f759b870c(
    load_balancer_name: builtins.str,
    load_balancer_id: builtins.str,
    listener_id: builtins.str,
    listener_rule_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__47ca3b0c9f61e8c7ef8ed39a52f1566ea77cc03ee3b7fd15444b54db7a50a442(
    load_balancer_name: builtins.str,
    load_balancer_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b96664d929e1e7f26bdcae56651d0c8ffa97ab7e3f92b8a900ae8ef71bbc0954(
    load_balancer_name: builtins.str,
    load_balancer_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__29017740b879ce500ba27d999dc5d77ccb9f7a27a9c208f64babcd6fb2e3940c(
    target_group_name: builtins.str,
    target_group_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d201e6a2da5e5d8b4556c4b371aae7c5cc83bc6c3124823ba390024e4857358f(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2448acc8ce4ac22ba32fab0b45095c326ce3490cde73fd9913aec374bac49b0b(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6104a31f9170a249ff517e2a9fc655de5ac435438918a76ae6c792cab1556217(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2b12ea0c4f2d3c9de0f37287d816dbf5b6ad0169d429f5285107c80da3665d06(
    tag_key: builtins.str,
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1cbd9fec3bd855ad50d052b3058a6471aa971ebe28c41433b8c6ca043f87f59c(
    tag_key: builtins.str,
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__661b7b9c828e9d3f6de522f8c8bb456bf0c1102bb5eee38d91fd8c3090675bf0(
    cluster_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__388d529508539639f9f091e3b3b00858e3e008d74f484c21110fe0d123a1f18b(
    editor_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1a41a79ded636f77365677eb1501e74a3d577648e4f3b2ba3c83981e75d7854b(
    notebook_execution_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__62396292432362cb60a36530f48dd5849be053d3c29336f8e58630cae4d96f0e(
    studio_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4ca7125703b0a6a346c839ae83248b6b515347a2fa2bec7ca8626c658c3bda6d(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e5a3fd616a1900d7106b12e52a3a47f9e62e6a7179a4cc70ab0baab682c0dd1d(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a89d793b863568adddaf64b0a343b89101a533814fcfc4cc16cb31503853cfaf(
    job_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__92af13ebe78c7baf89062e744d5bdff280acebda330f3fd095c44dff964466fe(
    pipeline_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__aca9fc6be099103403beca3c2919b9fb10c21d0b0ca323583176e8afcb792117(
    preset_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c26bff5df588aa42555ba49400e3bda1a799b1d0d5f0a34ff32bf09797e9161a(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4ad17ca822bce6c6cfbccb9f3d524fcbe6600bce3c85c2751c2b288c48523552(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a8ad327aebf338309658f03c2207d19bc7be7f62fa033a2cfd39e597da94de58(
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__47b531f040b8333c863dfcdbbe3fb423f0995ecb932707dceae273c87b8b994a(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0b2edc6efcd1855ddfb4a3fe2c3a1d53479f4938e1901fbbcb8f33824f3df48e(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3726430a62433513b9d09a1aa387fe17396a5cffce24c59f3825be0ccf4dc195(
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ae22720ecc6790686bd579af64b1a8d12a4bb1add566a0d95c7e33e1e20982e7(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d4a75e13805734336f037d40ae34aab7ec2c281b1f72ad0160d33104131a9d42(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2158913393069dde7f720590760f7c079a7e116fd54e10b543e485b3498780b3(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d6eb4add344444b62ae4c046d429f0b20be421e7d7a278d91b4dadea22973f7d(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b02730acb3e81f68c0febab3bac40557a6869411b255480f012d4b9378b447d1(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7b6ffaaf04214e77c7ae71c00718f79acfcd3b623e5959235b5f12504fc61fb9(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__747f2ea1a47a5f91db7d7e43f6a0fd672bee416b9f0c4f1e6c6c035846483042(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a4e97ec79c48a9cbddccab27ccd92a5c35b3265fc9a9a07b71cef014cb977442(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1e93c23ae6f43d94999b0ec6728df950d801c6084e5a2e42b5a553f56252a946(
    virtual_cluster_id: builtins.str,
    job_run_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5919fdbba9647301211de3bd118cd5bca50ab9c0f3e109fcb82eebb905730e22(
    job_template_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dd650b03770c635ecdb5eb79af82772a8cdf2ad139c6387bae7f9d199328f25e(
    virtual_cluster_id: builtins.str,
    endpoint_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e609f6f5b9813124cc8466a0565b06a00f6ce4ae2f12401178e7e96b349bf37c(
    virtual_cluster_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ed4528bf93bd68332b5361c973a6100c396b96e7c3edba1521a5048b8eea6801(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e8b3e2d2ac9707ab23accc8546a992bce6e3435224434cb45fd24612c76cc81d(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5174d1a196a32ee1e8065ffbfe26e38a3cfda90c1e6f680f21577165fbe81efb(
    application_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6792e2eba86cc220f6ec49afb721f00e988c4809431cc3a0b785e1e209de71ef(
    application_id: builtins.str,
    job_run_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0899f5ee2f437d926b997ad3deb8869e3b415d16f7c0ecf102090ba672a4b7c2(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__01331fd056fd0209610fca3231639d5a86f0e51e6109527a7501c2b8f9aba937(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e774b9ff04a1d1b291b230274ee222f93eb84c695a69422d4ba1c23f66e73177(
    domain_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__99300366d58701f04351b7c6db3e47c4a7475f130c4f7cee2a3a1f2fbe5f72ea(
    account: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2d530e789baa385225837453152c3b704087f4acd282f0fa23b89c76707fddb4(
    account: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__afed259c3132f8659c26188474f90e7150c3dd3addb6bfde19ab85f793854f2b(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8482d7f9cf7bb183eb2475fc3e3fb351eed291d8681ee412156d9268913e2459(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9170865a8b6e7a8d5a00b893ae49c8e66f8cf57173a13e18cb85b215d3ce122d(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a588258b81abee2f9b6fa6f9f18ebc4a3204e171b14879b7716c7652bcf45d46(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__99e3bb7ee1c7f20161561a66cc507abcb63ca7c18c50410aa3b31bf369c4eb82(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1e7cf3f8e2f174d138ebea399274835d80a71c8ae9bd6d50e37a02a718728892(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__24b93bbf56d4c7418e53d36d1f8e0d94785aaf9221394b808dbe10156c4b429d(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e42672d6ae0854f2445c344cc45c8beff4b6219c9588795787f8ca16502c36c3(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f2f3fd8da1616a1f6f87ceff690abb070eaf5d9dad7240b6f9b0e6183961f3ec(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0f86b191e40d6042b07c139559f56b575c51186d87044f0600ff0505e03c6902(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ca685e877653f554af019590038a3517cfa065369e7d67d58e5e5f2ba159ee1a(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0ec2b950fa62e40201e574a73616dba555006de413ef449ea83ca61ac417db9c(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__362c7a87acc645d864906a919ee385c58907503d7a2255d346cf8ffae2af2297(
    api_destination_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__49688528c07850fe7db3e7289685aee4e0b482aece6166dff852e98721c89ec7(
    archive_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9cc143a93ecf3ef26256c122fa6ea57cd3ebf3744c820bc9786041d3dc09d842(
    connection_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ded4f20c37113e9b717ef7955d2d6bf48b2aa5beaa3bad73c4f146fcc844936c(
    endpoint_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7ae18fdaefb29e3cd05b77ff62602f2c6f6cd24db7479297675aab2fc248bb6e(
    event_bus_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__834c7270901ca0ba69e870abf4f38482682c192106f37c86ee0425c46e832500(
    event_source_name: builtins.str,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__29f254716ef9cd429a5461d5d964d0ca848e48fd1a22330e516a2b387a39fae4(
    replay_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5c07a869df536322937d2e53fb9383d3ef0a2d75dbdd65d29640c40605537f84(
    event_bus_name: builtins.str,
    rule_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8611e9b8a7d478c29750e26f8882206b7ec3127f80f043dcaa30d3a325a23a9e(
    rule_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e2160bd0b4857a26315a4ca0f3f7c2fe5c8bf70cff8f482fcb9c5961c299ad70(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0545f86efcdf0b23e449da7089b4b8d4d13fa274acfe34bdc8f35d1f1d95b3ac(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6edee63b6811a48ce7dcb74f8bbe4619ac5551f0233c862b7c23520c0c8a2447(
    project_name: builtins.str,
    experiment_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f583489fbefec580e099c80f28570a8b2ef1f1c450e20e9d7d744b0d8cd129fb(
    project_name: builtins.str,
    feature_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6af4a7e0be2433578accae3719938e992d9a0deb6ca1ccc2f00bb35dba332bf3(
    project_name: builtins.str,
    launch_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e6445fc11bf37de0f1e140afab05a8bbf87e5b77267c7b9108a887a26960e6e5(
    project_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__34177ac64ec87ce5cff594462412f23b2217fc3e98cd5b444862f5bc091aee3a(
    segment_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5d17b62698b5158fe13ac90565ec02aa73d41114521da32daa06fbd9805821aa(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1e85e0a651bda46a1125683cfc8f18ce7e841090234dd3e54de3dada41568c48(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9a117a7794e1ae9c51f2095230de8cd78f6dfc40d71ba33b7082e1cae32792ef(
    api_id: builtins.str,
    stage: builtins.str,
    method: builtins.str,
    api_specific_resource_path: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__92517d91cdf9fc9690a38f1a570bfead630696e54ac33d49c93318c2ce54a1dc(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bbc42eb0aa385a28d0ce99594c8e491651274b65a5fe9076dbd1bdde1f11eb54(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7a97c8f51920e4c39c4ba8de94dd475aae0fc10e70e1be1dde836f14a6c1af2c(
    environment_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0e8f91b6f7583b417182536bc5bd2bf4ec633c63b9b8a84c343c1122f4cdb45e(
    user_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2da3b1c366935d8fe64b87668fbab2533787c98bf56c31ebc7a0a79be3900e12(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ecba224902dbd345c6288b85ec86257345bba7f5f5f532370145dbb930f4068e(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e1230d4418d95d507d7b8f462b98039e52b5461ecb474df90709c3bd8f6a287d(
    delivery_stream_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7ba3549f1d6522e9d26d5e814e2e4d8831e989258a64d52d6af8d36fe38ee73a(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0e34c35e661d2ee2db4245f4ba0705fbe61ff9f158046630fe80ae71f43fcbfc(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cf009878962ecf69ec1b0de34de61f1696bba33d54568936c897ff0eec5405e7(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__76f17f4cae1716dc20a8297a7a82c2766102bcc76ad27d9d6b36fd619bb9dac8(
    value: typing.Union[jsii.Number, typing.Sequence[jsii.Number]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7a02f5bc9230658e7f0f0742ba08a28778ec6d78b475d2d4ad226cd564010333(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2bedab5f588fc70ed1c8652d7c6572a4c7948661d03e03cc3da82d01f8668ec8(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e6c51bfb97928062c415fd443e203309dce7f209cd56d087e8c2b2839de8c096(
    id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4b25f1df15fcaaa30a491599b5c9b34041161eb5842c80cdd9ddf26fbb6ec240(
    id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2d9e5c78273e7784b6b7dc323630b3e7bdadc7290532442ba1c1c26aa10bbce7(
    id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__29f82d9232ebeb0349f58469014571c7d9f757edd6c4c347c7fa100fb3b917fa(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a0da6b773ccb7afb8878b3a9ede560e4271cadc6c751f314ea5a636d2c2c77c5(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__02d4ea787813335ac55c32d0e3b330a77c0b530c7d6f8c6a3d32874b9dd92beb(
    id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e046583efbec001e98cad66044082a2731b428d8563963bdb60f6e6c68d542d6(
    id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0166fc75154ba8dbe31bf853c55beb5eca3f22358a51679650da0c8be2e92efc(
    id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f90238056374d9f2e8f15f6a47cf2b030da27fa262d405573884e9348ab21096(
    id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8f0df2a098414874c48ce8f4697641f54e284b3d1dd2c2d0226696ecaab79d4c(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8a81b88e42b095bd31df513e665061c3770e4fac310b72cb5a34fa56760d8c84(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d0461e7397d4f9e00f26b21ed8433b8d333ce5480c8ceb3ee15fcf0276c4e217(
    resource_id: builtins.str,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bac8e0539267dd1aed77231158fcb7a88efb5e66fe294caed8c47197fe247f2d(
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__53a48c6e09c5ebc2e7fd00f7d0df4e5f782c93a72d1c7400a1083d2a7a680b4a(
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9aeeb568cdfb8cb2736746a962ec0c5abff587202297c5f17abdd9777e47b264(
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c1e6ee22a3802aa14400b628c99c4126d57f635408ed82a09bf79ced0a2da979(
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dcd5960a3eb0b3977be0a8ec9b73f4497adbf34ce61435c690736d3913e90b25(
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7a6d73f87bd50dbea2c56f841370e60fd848c210dd45e6e34fc791bcacc60db5(
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__72fbb45bb96418ecc64daa839ad09f81b2dfcacd4cbdbdba66560d3bfaeee9a9(
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bda4e5b31abf87a2835566d64efc3767bad96a7f4ec8ae913a6642f743ba63cc(
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0241e29d4a1d7bd4ab4030faad810f7934154f6650e543d1c95cd78c107b9c94(
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b3d71d7e2bd82edbe454653b3c4d1c4318c6685167015f53e4faccf665a757c8(
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7b43f746bf9e4a2dae2cc3bf35279d8d590deb01ef9ab04aa1acb5da43a20e09(
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__039070a604c68c4e364e96c94bce2ea230bb7df3816ee4ac8b4d55fae65e83ec(
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__750ba9d0934c7fdedb79e6011b894abbf4236b42d7f97c180185d97bcc9ffd48(
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6b9990d4a439d5a3d0606658a727801d752923910f635456a27e5634cc296b2d(
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dbf7300a4dec07cdcb2eb9693a59d36ed730b208178b5dd451ccacc13ea1803b(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0d976ca44835f5cb1cdef7bd981b8399841a0e9f6c5d2f05ac7a746c246b3924(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a28161c889355fa5146322c4f8da12416086274cb4cc852743f56f3d4ff10c81(
    resource_path: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__649aec5de0afa9c3ef453cded8fffa3737d7fe231b932ff5c68300dde6a4a4ac(
    resource_path: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__14db85c2ad7c75cb40182d1df572a08cf5d79ddf47875541b11206f941075236(
    resource_path: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7100a09bdea27a2d7a77907cef9a4428e190cdb629ded71e9c97d4df00f1fe71(
    resource_path: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3fad7315236a2b3b42a9789ce1f152041032ded5d1c85a7d0a408c5ed1ab1151(
    resource_path: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__df397acc56197727983c4744b8ff0a93ad7f2de493ff79ddadd71ce87b268fa4(
    resource_path: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__933117273b5866566a1bcd2c5e5776bcbb4b919e2e5279e17c6a3ac35576e690(
    resource_path: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ee3eb3b42e77f968d12b2400c17d72c4fba11a8d4925f1a5ad73442ddcd704ac(
    resource_path: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3b9ccaac5b8f5e51c78eb5e02131d6079bc87b597a5571fbfba16523eb5e7036(
    resource_path: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__61e3a6cfa7587ddb043e19b0fb9b62659cbba83cc811b01fc49225ecb56a1602(
    resource_path: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8c9c10e8cc8c3e10ff8b51683220f17cab37ec6c34ffa9d09f8f28649c358edb(
    resource_path: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__187c41efea89cbe055ac5b7f247a243d4a9a3c7e5af59b8758f62c02ccb7bd8b(
    resource_path: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fea1b8c57ba233d7b4495d764bccc4f0e46b492b0a87a882ff257776b3194173(
    resource_path: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__34526e484ddf7e89731da4725419f81726f24f240981bd22e3c86fc2605dd765(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f959fce71652a8cb8fed2a40b2ea7da4d0cbaf499375760ff1b173ce01bf78b8(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__156d42df43a963c6ecce9dbace730c047c39982326a5c7b4b81da3aadb837e28(
    configuration_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7f5732a5d91a99f83a772a9f3fb5247f85beb1a71448aed801a5516bdd4bb571(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__44bcad1f8a4364a446d54804c7effd7feb29991db072451dc4c0060443050c5f(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c79c01b4ff535df5bd6b8451d222b0911ee58ecfd5639212b888ac64ec125d65(
    value: typing.Optional[builtins.bool] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1d51a2e520a7df2f95ce9d981427cfa1d7a5cb72993751ae6350a736d3621c9c(
    value: typing.Optional[builtins.bool] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e5b03bb2bd7ea8df1afd7279b560e2b2e6812b6fddb0d9429e7cbaf8060bc249(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__502c528a66df81196249b11b20246c0fc7cebce822b6545b54287a37447569f8(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6c4d52ba321e702e1351829fea6344d5ea2acb0214a3f78f95a9d2a6677097fe(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__13c475ec548b4d05743cc6c546b26c462565e15f1871d4cf0bef0e99cce4d922(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dfdc9859f5cb10592bacd64517e90ffad6e702f41ba13ced4f78f4acba43555f(
    file_system_id_or_file_cache_id: builtins.str,
    data_repository_association_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a079a04dffb591dbdf4f3c51144e164a94ded9526bf2bc25576b710a6e69e936(
    backup_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8dab6f903f7904914c550035af0a220d1c173adcb769ac4035170cb10625704f(
    file_cache_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__72b386c9ba840401b1bf47d48faf9834ffbaca60f7b0e843e4b53929193468ef(
    file_system_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__aa8c78ac644df1972a0e26276e3318dc619d438b22682267eb9ca7decf963567(
    volume_id: builtins.str,
    snapshot_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c94faf3548eb6b569b69163f2794af87364ddbbc546d711527cf2af2d17d30d2(
    file_system_id: builtins.str,
    storage_virtual_machine_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dd8514f6da428d4ca021c9fed66233a6133cdbe3381db2f5b060d7d5a7be9f18(
    task_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bde3042b6ddb9bd40f2f5ba6b670d2946dd5baba971d0bf762dafd768d069778(
    file_system_id: builtins.str,
    volume_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__496467f7cbdc8e21cea58a7dcb92283dace9d489b6a329db9dc01dd22baed2b0(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__65d590585eaa0520f1c8be9db32f95721ad0767e8ce3b71584c86a8feb8d5bd7(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a0f1a4311ae8c9721165721acfc2198c70f027cb0fd0346708597841b3ad8036(
    alias_id: builtins.str,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b44088498e4c6f72bed429972e2ee52b7110c1c3e37ecf41c7d36d0895498ff1(
    build_id: builtins.str,
    account_id: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7b94ba1098be79d592a5ae0327335dc667fac4aeef5b8d9c11027ae4bee0cd66(
    fleet_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__abf1de3960cddcbef1905bf1a7b6491c9e0072d3fb7f1cf64bc93a6fafab6f85(
    game_server_group_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__52ea4d3ecbb453973f06a4ffabb69be59da479e63c42193846937e0679e3cde9(
    game_session_queue_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__929c834604eed8ebe8998469a72cee0cc03c8f79ab723de17166aa359ce3b3cb(
    location_id: builtins.str,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__647ecf601dc27fc5139cf0cfefaa37896ffac0da6366c91797367d123e097011(
    matchmaking_configuration_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__554f01d5ca130df84126d5fd21dea6975d476f22c870b02fa4d33e433222e216(
    matchmaking_rule_set_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c64462d2631ab1a95de34782c80857be8715630f5824c02458f5590a94844333(
    script_id: builtins.str,
    account_id: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5954a84fddcc1ce275befc7671759e4822b5a2d35919e65bd1ef698b0a04ec80(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__02b2c258dd58a2e05b2dd5d54d8c7cae4cf64b90f31327e797583f852ddc4f1a(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bd40cfe76be966a0372ad1b86778ea19822fcc1415cbc70f6ca00fcaa9d9675a(
    game_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d2b68af1ee6c587bc8fbd4e46f249e279ffa810f642082fff735206f51161211(
    game_id: builtins.str,
    stage_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d06f94bbdb50f8de7d699b880282cfb14c49f16690d8438e77f677e2cdf7b839(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__483afefb5c8ba5d0b6c62df2b9c06071194af2cec3061fd40d6e2af4013a5d8a(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__18ed1ba5a64bb55fb38342552a512bda4dd9dfc4c4d1c230c895dac11fe61e44(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d8b2a3b114ee920a1c8543dfa66a9200efcd63249d712fa8e048614e52ddbae4(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__842009f3ffd0b6d7e6394efb820446b14ad96687888610ef133a3a2a8239385a(
    geofence_collection_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d0f598af99d8718689539244d09a90d5c4914a26f921016ab6a025432035db95(
    map_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6a1ed38a5b86aefad86b55f1f8dd1c28c9ef927c760bfc0d077cbfba15075b1c(
    index_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d8231577db4f55e9d6a58b02af3f34af66e60581bfd34a4c6b67caecfc2f4f97(
    calculator_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bd84384248f51bddb6241bf1e3ee9cf9ca09f727c396166a315ee6e65a3eb126(
    tracker_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__69547006d5b1e40fe709003c1a443c87a478f77d1a661901376f50aa6b2f995b(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__830c0bca08316c01cf5971bb2c16496d0d9776d302365231b0adf70d51e28fbf(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b1bfa95f6dcc1c055ff72de74b6ac90be1ec02bf6219d1beffc2eac588d40724(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__02de830d2c7b45d5f0522953684e09224bb9ec92ee39b225c30acfbd4238ebf4(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__81e38eda4ea46404cfdb0b770eabfd5c7572c8e6607b54da264f3646f323a1a5(
    vault_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__af74120182f63df7206f8ef537537e946323248cc4334a9d0ff12d0cbfa3d2a6(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__33521ce4206ae4319ac61b5bf79caf18b8984c661fc4fbb3f2e99bc64a7cc76b(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7ca45d712d4dae11fc81207aec4002a50034d32a7e9fd20a573f026dd1f172db(
    accelerator_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3844e9017be6242275489541a6b625f253c8720f516d11b7af39d140188e459c(
    accelerator_id: builtins.str,
    listener_id: builtins.str,
    endpoint_group_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5245bff08951426b1b7a61fb7358da784b977b18b703ac69353a585e2ed5710a(
    accelerator_id: builtins.str,
    listener_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d846330db72e0e99af3c5019e0276a81e4aefc20c396543de243577df2a5c6de(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__91816cfca0a9e0d7f3567a2052a2c1530665ddd90d29b5f3e5259ae98cf6f6ba(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__594d4107737f6394155eab5b8689d9cfb6dfb9fbf8633331e17366f4a70ae9ae(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e158d4d302aca08c385c1eb71ddb7ea066ad9d49b63040d79028763630bda9f6(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__29627e9eac8787ca29df4fb430eb065dbd55f39430ebb500e2770ff2161b697d(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fd179a452f3d82989c02fe54c0d6531678458a3b9134ec0676a4cf9289b25be6(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d44baf9984cb1095ecf93c60e79ba1d4b0a97303b4ce0b851e9725777c5e8d4d(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__84734956c2f1a093b5936ce5df7b36d12af7597951de961d502ccdc423107393(
    blueprint_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6e7dbe56cdb6221f3133256b50b76b9c0cd1f37eb31e0d72a1cd6ca88ff2c403(
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__05d14a8314e27f1effbac4dd4d7e3da52bc211cb958e0645c0b65eee30e3ef56(
    connection_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0d501e904c1b5eeba9398709cfa36ffaa8e13750d6ee19b59b3ce9639577ecad(
    crawler_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fe1d471969f84094c292060cd45e8f42625909d71db1f8a0758a9eccf5c4e57d(
    database_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ed1026510456bf34f5b5cacad4222cd49e51d8aa0f8f0585eb5a1204c3ac5c51(
    ruleset_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dc03bda395fd3b08bf4def032a9ebbe38ee0564b746f8f29ce0d2f6da6bba45b(
    dev_endpoint_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9e9fbad932d8fd7dbdd2d087595ac7c731226e788fdb58b77a1f73ca21905156(
    job_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__96ca014a1632f3836294139f16c9fb7236fcef88af8025ae0c0029ced45a660f(
    transform_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6ec3f41078000585a46b5048d113829c6c753770b832a08abb0e51403a9d8047(
    registry_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bc779a78319f6159f68037c58dffe7302f4c723120563132c78d0b0b78978eda(
    schema_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__54c0c550779644ac1b1bb2056419ecdfbbcfb19a5a9970302001e82a011ee8a7(
    session_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c1ec30a907e1988fff5decbf4e021bd60c230dc19f05b6e3d55f75890d7a2ad1(
    database_name: builtins.str,
    table_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ce12a982648c20988fdf806cb8e7c3d5388e56d2acd23de9f19c073966390d16(
    database_name: builtins.str,
    table_name: builtins.str,
    table_version_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__48c0448abb501d9a37def1fd138bab41e8d03d9803063d651f2be25b310ef962(
    trigger_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__94057aee04dddea3e576d201934f976f055ae1729097c324a11557f36440b712(
    database_name: builtins.str,
    user_defined_function_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__42c32f6969fc9b42d518a507fccfcafaf4e82fd7c3d8dc151e81150d05b7b08f(
    workflow_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__71b36c44d259763bd51bd5ab0610898b6bbcbfe958a9f8f9f836321be841f5f4(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c0d69e162087cbdb0cd97ee85cca3e4be82a3cc3cc4cadf11c21da0e923e2259(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__28c13f99b5a8cc5cdf0e0a1381bd527ea05af7cbbaad53ca00f05723e20d15fe(
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__92e4ca72b77dcdcd4d7d2be023278985a148df8b62387694891a2f5b25c809e9(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c67dd6684581e17f7c4b5ec4de32dc6f4799098042b28c48e41dae1551f588b7(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__12afa0afbf9c76e91fc9a7118b95a89f354aefdb3645caef745ea272f314b38f(
    bulk_deployment_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c768cf9f733731bd1fca8599d602dc826b401a39abdd595f3ffcaa2a41a5dfb5(
    group_id: builtins.str,
    certificate_authority_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__901edd8cb8f2020bba2e3b9c01a555523c2568c2665f36b50778bcd681cce7c6(
    thing_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5fd074d70b114abbaeea4bb9cb2f1d249e3a5df393559e331453352b6e7dd5f3(
    connector_definition_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7a132b47b48c4bdca7a9c224fc0ec5ba450282b53e40c9e2746dc28d5b667a14(
    connector_definition_id: builtins.str,
    version_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4a500d1d6093e9c3ab9517e5c67f018117572a9e6d9b573c55a8c3467441f358(
    core_definition_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0481831d3ede6b739deef95fbb451662f03f842f449fd213b934535b24ced152(
    core_definition_id: builtins.str,
    version_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__294b73d1aa15ee0dbf213d60e28889c0b01d749b58efd1cfb237e476c0bf9741(
    group_id: builtins.str,
    deployment_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ae92cbc469a6d7034595efc2c22212f7a5f4d69f8ae75e5380c5fe69c43f6ca0(
    device_definition_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1ed5d0d9b8ea84a5da1dde288fed180e307c50ab0cae19a21260c9bc1453f7d3(
    device_definition_id: builtins.str,
    version_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__48b1e4090d70d753241e7127ed2eb9b9ede14ab9b3f48710de169636bdbb4489(
    function_definition_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8947a2ca38435ac5830cc4a751e6100915d813f7b0a4052cf8480cd89fd7f2a1(
    function_definition_id: builtins.str,
    version_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d58b9374b01f08bd9a9321e8af2956818fe4bb2d7a446917a7fc0e5ec18ae481(
    group_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__19d63a4d18ac101242a0403b540b37399fe273ababe2ffb634aac5a1ddc255f3(
    group_id: builtins.str,
    version_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0bb74cdfc337fc3b536a7a2b7056b3d2a7cdea0d93858307153ba1f9d71e218e(
    logger_definition_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bcbf6de500691d506ad4d20dd88d13cde40ba5590709a8baa16c7b4108c0b588(
    logger_definition_id: builtins.str,
    version_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__be0a202fe121bbc7f3c9efea5765393e4b6c034ca0974713f9b3aeb454200f67(
    resource_definition_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__da6da26cfcffdcdfd1466b98c7124f0a94ffc6bcc0a8d70152e61edbc9fa8166(
    resource_definition_id: builtins.str,
    version_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__401afc84b94f9d31b20a3592e725b4dcded8d0e1638eda0dc2bc23b483c9392f(
    subscription_definition_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__09c0a1c4565f843089dd0abb0d4415eb3b3ab0b8d77057f480a4ae9f8086abb7(
    subscription_definition_id: builtins.str,
    version_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__20af4c7e7afc59c436610edcc1f56ce05aebce0b698730b23ee9fad6f870d482(
    thing_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b81488801f146991ae8ee67bc46c2fb4ff8824aa227fe8e9166ab0c87f7cd850(
    thing_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ab24f0cdcda6dad9685a30056f3e80c2b8558d7451e0f2172bf1a9757a95631a(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__951c8f8a36e765a2658f3a736a68be6f6c17e61f0e560383e94b3f69afa0fb7b(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7492ceb6efd68e34bb36b1779e2e2cb9df1832b43a14dec6372671c8a1b00b33(
    component_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__52a1250e1fa52cf2c69a5259d25e9bf8275ae2ccc5fb8557ae578284e87da440(
    component_name: builtins.str,
    component_version: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__91e7213ffa0c857ccc2a2f855e8e9f284588df5976a762d5a4af54f967937a76(
    thing_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b75da0151276e074ecbb716c3d03e5850980ba992aa82cc2626933c3cd18a2f9(
    core_device_thing_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cf140bce90752de9ee4e58607ac80865aeb1647d7f2efa8b26231867aa52d572(
    deployment_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4c0f3c405c5dceca4771cafda0a7e178b3d0f85cbf631491a983111cb0e55eda(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ebb70652d0bc19763bcd0bb347655c98564d08fc19bf9357e9a5cd06169a431e(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5ecc52419c4e0e32080614e488984183ecbe363409785b7ef81e4b5d74339270(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__aa16de2fe94279756fdec80634470eebe2782f8733c9d9e1180d6db2e0024810(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c276ab5b9af52df248bd0223449799f9341fce56614f698073a6f28b63eec9fa(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__54f61a0d767d6c87ea41209131afd282c06fec0e2091ae663b2fb9e8e0ee691e(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8be15834a248ad26d046d838bb5ad038474a083f39595893e6d82dc74eb1a04c(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dd3a2688bd00e5b4145e14fa3e9c9b5bb44f55b539cf4e350c05960701f14c0d(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2c69e9c8648b8dbf33f7a60834b410972beb744193a6783382e8efec6fa96187(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0d50340f48d773cabe2f5f4ef0c0317ce945c0138a129183751d479432ccdbc4(
    config_type: builtins.str,
    config_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ff0837f771bec3d920613dfe21834cd4265d7c5813014b21d02a889aff982922(
    contact_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bd1da9220d4ae8eac4d555c9cdaa00cfa2dcd33de155798f2746204bc90cf0ab(
    dataflow_endpoint_group_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__274b99d114d58b1450baed068b71d041e91473d4478cc02877f9460985c7b2f4(
    ground_station_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__df1baf626cad71cd92aff8d24a3858ee192a2b2cd654ceebe451675c486f269c(
    mission_profile_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__42e38978678c1fd62b224c673b192fd6843281c79b41c3a081de570784bb7863(
    satellite_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ca17e5cfcd355a07b28ff1f725c1ee1bebd71e2e87e8bd2a70e839d68b597ee8(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b48613eaee2fd6d9d66fc5ed75dd3138be7f7311eb18719847ed79b2dcd571e9(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ad2096ec42d0cac6f047797ba51946b00fe6e2f5b8422f96df0089da4b1d408f(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__91d4b6a70693726320325a877e4400d3963d8ada7263986890daf8421b5b8f19(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cea7df3a9955fe5ee0e9955e1c50f525aebc8a62c3f2d3fe6821b7b0727d3e28(
    detector_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ad1d5f712064010f8743e32126c9d8a2ffa7efb2ea14e762edcbb2bb41ccbec0(
    detector_id: builtins.str,
    filter_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e86ec17e7ea8bf805b5873c87938d8772a58f9551aadc86c1814646a1364f00a(
    detector_id: builtins.str,
    i_p_set_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__241896856ec8e8c1302db39f1e7243d8fd8edb66749c390d136f502faaec8055(
    detector_id: builtins.str,
    publishing_destination_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b022d497353262a2a3eea251c14c61c1520e94121492ba7fce2f150f3eef4574(
    detector_id: builtins.str,
    threat_intel_set_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b59cc1ee56f62e2297187a34c05880638ad8c7efed70a3913ac80c53001800d1(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__db3c3faa002a37d3c6c64cf99ed84cf177097a7fcc86c15d709b7f3297f23403(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ed2b9e6fe81e77bc3a334b82977ca12e9c116b1211ad3cebf403493a505fa538(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__90e8f091eb959c13ac07e8c56ff964578ece8d96e40ebe594406126681f54f68(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3e38addd14f6f1a732bab1ef75e148ea5f95df77cf348cc99ff9955156b7110d(
    service: builtins.str,
    event_type_code: builtins.str,
    event_type_plus_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__814141424fba7e509c5f1bc263258f2c15cc65311b313d7019039f421f4ab7a5(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d2294861476b93993fd10109e41c2790fd0bc956656a8b0a6d90816818663010(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e280f3904761000c5913190a8d8646994b943e6ce0b1d78e3e3a923d4170b91e(
    datastore_id: builtins.str,
    account_id: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__785651f980e7dcdc78cd68e3d0bd9746a4f4b0e140ecb7e1749abdd7db37b5e5(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__630625f0bd01709f34c439e1b3214a0a44df209fdf92511431562e67ab331153(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__29ae07ad81c31fc614607dc7a6fa710bee52886e283f51680028c43b1b22f560(
    workbook_id: builtins.str,
    app_id: builtins.str,
    screen_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__55da74dffe8799e6d14428dd81477c38830b3436294b679c0d330b1508fa4192(
    workbook_id: builtins.str,
    app_id: builtins.str,
    screen_id: builtins.str,
    automation_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f5aa918baa2e694a70e1c712d5e870f45e9c5db1a4141976700839cfc9ff370f(
    workbook_id: builtins.str,
    table_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__54529182e221efadd7f646fc909769128113d65edc8e2851ddbe5565be07bb9b(
    workbook_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__22fbb6eba27728e9e94b9690c613d7e4f26de23deb8b00cf34bbf43d0ede1ef8(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2565d5a59189267f4c803679ca6940b3da85059775f45f56a8ff006a113b82dc(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__51e01b91ede806824f359c55c3986afb8a8b3bb03714ec4127cfb4f4113faa53(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__24ad06f0753e2dcedf79c30a4cea688e01f0844aa55c9f006ec46c4567293ff8(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ebce342636fc71b0039cd86d5ad3caa74b9151aa8685e9a19d57d62c1e86c1dc(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__371b943df67bd0b89d1a67f7cd2842abde2a09124adbd92dc94d2f5d821bd02a(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3b2ff01862ce573e05c55d351c7341885252782818a7ca90788bd7c4ff3fa4f0(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b86aa61a6706e1c6d3a0562158cf95e9cf0127d6e1c71dd6c88affde1a63c3ea(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c4a968fca0c559b4f4822b0c0dd9dced8db39c16ce64b13a7ac6dbc61f4624af(
    tag_key: builtins.str,
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9cef621b4babd9880979ff2b2f0da6776154d404c4cbefd50de7339d2f3d8d3e(
    entity_path: builtins.str,
    account: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__36efb7f4fc7145a93262fb97ba537d40991061b00059b10f032baed7d593dfaf(
    role_name: builtins.str,
    role_session_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__72face6d5d5f6d899d1e7612634824cf8a13c7ee8d94855df9e1c9f5379760bd(
    user_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f976829733e677182b2c843cb77d21525cb8923a3eb4be394e8c25467462df46(
    group_name_with_path: builtins.str,
    account: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__23e8c92178ca78781348df3b98e580f3c7cee919987904054e32fadf54ea6093(
    instance_profile_name_with_path: builtins.str,
    account: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__818c067fb16fbf6833b8c31310d23be617ac89e852c4e8168848f4e51ba04609(
    mfa_token_id_with_path: builtins.str,
    account: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6a32b7ba0b0a7d515d160ccd1ac451a13362276a709e2e33433b1784b9ff005f(
    oidc_provider_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e5ab53fc1f061c825741fc6963a4fa031c652e758d73c05558e2960db7e0fdfb(
    policy_name_with_path: builtins.str,
    account: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__767105fd34e8827cb3f620a3c67cbbab6f50a64e828cf7aba74662123f4cd57c(
    role_name_with_path: builtins.str,
    account: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2579af43a304503e0c46a59394073bd9f48ba6c4578237022bf19b7df6e3945d(
    saml_provider_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1f95d7c6ce27bfc3cdc177609bdb83845c8a330bf393ea5b12b3e19256e7e662(
    certificate_name_with_path: builtins.str,
    account: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__85d366a8ba3636b9091fc068129fda47ae616cbbecf81f6bffd3b72cad634383(
    mfa_token_id_with_path: builtins.str,
    account: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b8eb83663b02be981cd113d543100a718dc49594ef80fa943a1b65aa82e489d7(
    user_name_with_path: builtins.str,
    account: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c270c965af986565ecd35d4500f767ea910599fc83a2d171f1d78764c9f7dad7(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__29cc7835040fa92b08dc30e091e5b97f845228809637ad377cdf40da2414232c(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__25f375fd47557b0fa07ec1293b88234f5a9ad9f55e422a954ff4150d0e62de2d(
    sync_profile_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__df8da733d03dae714bfbb4d0a6694231ad627c77fed324f45a098ff419887232(
    sync_profile_name: builtins.str,
    sync_target_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2d23f22ef8fff5c9e0ca75ec85342f483f15b7e43187f66e75a2777f5c7b6aab(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__953d28cb15042c3eb3519acb2b6025e1ec30f763079b98a3319138b1a6a45990(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6bbb46a3fcc95159a4ba2216eb37f0cd4863efeba7fc5b46ddc4f9cb0ae88d40(
    resource_name: builtins.str,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__70335b8e53f2de7f5266a5fa3d7a52991648ca3423ea5cc3f05ab45d4df5fa23(
    resource_name: builtins.str,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7019cfd465a7f9f30c6b995b3eedff47e1657cc7c2b579bdc5602ab3cc54657c(
    resource_name: builtins.str,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5417b9654823a3b52c4663f8fa37058ce2d93040e16aa9b2e2d941b7e65a7334(
    group_id: builtins.str,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f3f7d17f6a07a2a3d4db5aa9759e5167414bf08ba680170d0d2d9fa2f01c99f1(
    membership_id: builtins.str,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c4f1073908ab6d91e0b2462519175a6cf32dbbda8acc71b63520014924a272b4(
    identity_store_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__15e5131a0408e4c821beb578e55688970dd6aadc8debaf2a2bd6c7dc526140ff(
    user_id: builtins.str,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8e7f8db8b9ee8f0c6060cfaee47820b2b8d94f32715583cd13f8e771a8a5b967(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ce1f63b4785f2db14686d8990bf549b94411b1c6c7f3b89a24ce7f049b2643a3(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c22ba346b5ce9e41789e4a045267db59a8345d3b44f35e63be1f13dd50792878(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5d1654ab1bbad6de8e6fc66142ba70a803a4e931594eb707e2a006e24657910b(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d4b99ec0f7a38e90dc79de0b078d62a35906e3f7ad7716fc8ac0a9f99f2823d0(
    key: builtins.str,
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__70fdea28e97fffbde9d0f9659ea44ed6135edadb80d825f1ea34f34852690ab8(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3656da77f76423b6dc7b057fcdd1aaa240b419b200ad90e383c04350a31a7672(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__035a6bbb49aee966e25aebc06096509aaa549bef6c708485ef3f006cc9e94408(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ad04b7944d04f00090732ce5958c5458392c7b43ef0061fb411c3f0b9d7e65e9(
    component_name: builtins.str,
    component_version: builtins.str,
    component_build_version: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5b1fb701911dbde185c9fa58400bb5a0c8a99281a023990c01a2b9c6705cce8e(
    component_name: builtins.str,
    component_version: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__669ad431acdf803e07c5d3b93a1bfdab4b32a5fe0ffc19dc9a7eb105c1349502(
    container_recipe_name: builtins.str,
    container_recipe_version: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2df50790657388520b29a11089692a3c2a2b77a221f5231949a8eeae5cb4c68d(
    distribution_configuration_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__38381d3fbd5ddbb532d5548a5e887803d9fcf1ae7df5c58f37f429109871f0a0(
    image_name: builtins.str,
    image_version: builtins.str,
    image_build_version: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0794fbee8dd0815650fdc9367f4db890d9b5674572c20a1e3f41e1b707f0ec05(
    image_pipeline_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a42d74c9638776833370907637c2381c7c83cb38404c66052d2a89661ba5d76b(
    image_recipe_name: builtins.str,
    image_recipe_version: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c716688ce5746348a93d00db1ab0e2045938afa7ec61fac9807b1880ba72d97b(
    image_name: builtins.str,
    image_version: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__222fc29bdfff9a4864b79bcb68b3b51fd18997ca433c9f56235742cd837c3e74(
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__20b3eb10d7858eb003f981aa373e49f58c2d79d63f66da48ba1360a9c8a86491(
    key_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e970c10f6e79d1dc90dea95cc3df8e1b85668d916130f993cb0d76789d15d8dd(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4beb41163296e4ce1c193bfd0bdbbcddcf2be67c5d07e656ecc3ff942fc8dbf2(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6be903d13071598c2e0ec526efeb600c1963d6216d4cf965b952c59735b916ca(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c2bd4b8895ae02366fea0121d676c8ef556bc45fa3b2d818b41b216d25b3e364(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__52e8f4cd6fb98ebeaf9c24175268bba828a5b9a73cd38a1e96e1806891a94bd1(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bdb469de99614a888d061e0a804cf319b24e84b054675b1f811fad06edbcc74e(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6b7000ccdd077dd557b49732d6439877394aa88cd7922ca7f6ad0180ebd04750(
    owner_id: builtins.str,
    filter_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fa66cb6fe5ddc51f27006ea238aefedbe5115bb0b242881410e105892c72e72d(
    finding_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e0f53ceeb84c12c72187f071deadffa8e0ecd57549d2c74bdbc5e320054ede49(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__817d81e8f4b787b445f3eb89ed3fa04a7bb5099d3f9b45df9fc1cb6f61733fb8(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1b115bd7dff4f5a6789e5247c226ec3ec0a770c9b4deddb99d67574fd4b23eb0(
    monitor_name: builtins.str,
    event_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__681d01e0d32cd3a839b2741f5409475bb12206bb3ccfaab86c5a23203fbd5cf0(
    monitor_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__91c15c399c4d8f48bfbd83fb312a8e7da3993b2d0dcc735871d2a7946c3935f9(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a7c5e8b98312a59f28b0d8e4de5715766904a061979fb42a0dbabe66a084475b(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2a678deeb7c6ef286cfaef54b9eee189146be9341876cc9a50bd6bc34cae497b(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__73d0d7d3c3a0cd05e71cb2cf597d0275b18564c1c75d51bb09baaab0ffb5e856(
    value: typing.Optional[builtins.bool] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bdf519f6ba12122a251cf3bc7d8b45292c55a8dae7677c83e4bfc6011898b548(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c35841a9bf114c6f082cd63e6358c4ab148a34d078b51966a65997ff6bfd9d04(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9dd84ad6218151d20b15443bce782aff508f06205616f8302f11ba656b63656a(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ca60255f270bfd87fdcdb7038513ee1ab2f88a08f53224c1e6f878ca2d7e6275(
    authorizer_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7da516d998962c94089ac0f51af40cebba36743c60eed17c116b2fe91ef68198(
    billing_group_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__37cba9ebf0ed6af20bc96379a315231c6fc74f484009d59406672f8429d9f63f(
    c_a_certificate: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__eb00be10d9b699780d4ec12fe6957b29c67d2fa6f6e9127d9e042139ac95d5ac(
    certificate: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4db9b012e05495416af3535b8b518a7523ce35289a856d0a7df929ed286d162d(
    client_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4410d3000ba1807ef6d99ddf96658bf54a951b02fc11f3de99322380e1a99e53(
    metric_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__38fddfd3cc2ce3c82061daaa9df89bea6c739a1d7d68802863455b2cf9d52ab3(
    destination_type: builtins.str,
    uuid: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8fe7c4ccdb5d857f3e4f9e3f1e61c13e3b6fca65d7ff5ce52ce67661468414c1(
    dimension_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__43c10fad0723de9336ed527ad5879aff7d6bf4de83f73b66673c2c18ec1c5a89(
    domain_configuration_name: builtins.str,
    id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4415ca7570c0174ef263cb35e474936c5bffe4b74bcb478fea201be13a1a25d2(
    thing_group_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__860388947b420377e26aa59edf0db6bff26d13c534d72a60205377c121a64070(
    fleet_metric_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a6900ee00f159019fda7f27229a8c047ef83fefbf9e8ee9285d3a31807c42f1e(
    index_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bad5b3c2166893c0c89ff2f97bf41d7929a0d195a47bf3d552e9a0f02bd0488d(
    job_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2cabf1463a818eceaa00dfd99e2e93957ba0baf236b2d4c2e149815ea4c83b1c(
    job_template_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__31a2ac4ca88d1afd5b1a9046e21fb4ba0a373629496ba2451d816e7f4d39a895(
    mitigation_action_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e2cc07f44fc1c35aa2c5e7b53d66dd8e7be63278485f6f6daefcb8777dbf4480(
    ota_update_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__02a8c051eba42be9a8e2c8c2658c581027f757909241804a78e1ca825b6654f8(
    policy_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6715ba4c2c7427f4f582864db5bba16902250c28efe91bcf071a7e72d87509fc(
    provisioning_template: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__030dca3f2e808c7390a0205174e8a8b4839bd2c7bda1ac6dbfe7dd4815087b91(
    role_alias: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1b184cdbc6d6abce3163edcb3138f23074377c1fd326980bdbb736b65adc3eef(
    rule_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__283d9872f8ec28426dea3b9a5932505eb0d0b72867233d580e77fd6cfa1c766b(
    schedule_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__999ac758bfe37a00e2899d6a12ac9df3a453323db1649f6b03543f68c50198a9(
    security_profile_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ba063d0eb76965c5a5d62f4d930604f1731d36bea0c18de855e3e060af874b8f(
    stream_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c1064b2e6da4d185dedfd67822efb09baca3764f615f6fd57c0c91cb7ddf5c01(
    thing_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__28347f799e70c93c4299d9f1a5b10dd65d973818fe864be08cbb806cd96bfff2(
    thing_group_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b9f2e5bdde0d3354c68466b91fdbd7740bc80955951ef4aa82612d2cb296a0b8(
    thing_type_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fbe29c7b31d800925ec5e01643540bb36064cdc2819c4de019714654b6c11685(
    topic_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ce97f087f536b10d1e1179fb112435eafebb53a1e92dcef936ba0300d4195690(
    topic_filter: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3fb4b588335c66d5ce0b1bb62bedfabbb71e6276ced69128f9edff200083bad2(
    tunnel_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c63140d528698e0571d7ca60155c036136be15000f668548ce4b9bccbf819cad(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__144f0312868ff065a1c99ef045fc2863732e327cf4dafc6131312d7f11439397(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c278466e0f1a624d01926a3ad1949067795ef21171e8d16ece084a1934f20e5f(
    device_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__80d2eae19ba42a76673f5192bfd67b45f63812e565f0c806bc121a50cae58973(
    project_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__559b4a751c02c9a7189a423dade1f57f60dbe17ead270133dec0571e55783cb7(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__40c5a38bbfbc6e13e9351797c718faa7aeb2dec75b944101fcc922120232b54f(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__639d4ec4a259e3e8f828a2c0a906b57ef48cf64b4c056c3ff30d97d104df0b6a(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c9c4186dbb89989b6dc8cdadc65a77dee695544b92d066063f4035ea84158fb7(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9ce96b57783cbf03457f051479b29768b211c9d912a1bd14acae24bb77805e62(
    tag_key: builtins.str,
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__35786c03b88d61b92d8b0056d6d3e640fc5e7c519802e3fad5479c2f4fce2847(
    channel_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__843ec61daf24d604d52c2d8f8a4fb2015601322794d2e7a11e5a5b213c24e188(
    dataset_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f7c1ffc39df3f8b9d5842fda71b1ee05c5242ca48079159a2a52c4a69beaeba4(
    datastore_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b545b4e3ace20d9671a009c8acad80799ffaea797d55b0be463d566c532115d7(
    pipeline_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0cbc35f845f9a2392fe6b00a304b1966f32a9396554fceef79cb669bfc7352e6(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a7fa2411144c92c4364a7bc032231ced70bffc224d35c91caa6011d694b9d7fa(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__26498995465f382ca81c9fbbc83c61cbc259dc41ae024b8b8d104cc3f48954e3(
    suite_definition_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dba29940ec294714c32e0ec84a2a35fdaabeae3d4bc0e45780e95bfaf4e6e989(
    suite_definition_id: builtins.str,
    suite_run_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fe2faea11b37c67490547642c17f755c25f372007e13b7e7a4bf3f2b726044bf(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a9e1d04413c70dd8f5e7eeb178bba4582ab1b06d24c1a14466ea878b4ed74c9d(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5c2d117d63c1c8981fbf1fb5e3ebe5011e910ab0ebabb2870f000b7bc2742efd(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__40f00f543088f7d046fbd66211ba68a6c5f67fc7bbcc4250693afdb78f9fa027(
    alarm_model_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bd81e60c67a1879cb56fa949f631838ae5b366f6f8cbace7b496faec84d65f6b(
    detector_model_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8651265098a6231873ee04ef71db43a2fadc1248d2650a87d0012a493c272d2b(
    input_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8d953be9257b4c2113792e76f965715d068d20ec1056f1898bacf6e9bb39f935(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9ddd589fece652954a841f1829fc7836d11f8ce848b75fa5efcd67ac5f416876(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__266d3d8bdd15f87c2ac7758b5fdd21ee347127b81ca61cd41ba7db01d360a671(
    application_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b6d7ebbd23c61f714e212cf9c410cd863973c2122b225dba8353533c6e7a1b50(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1d4eb8c3b58062d80bf2924b7121d887d95a46d4ce1b2d03922d340cf0a2d47c(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9ca388bb6e4a425713de2539ea17ae0af8d44659800ff560ef3ef7048d3f9a0a(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e74b42aff11fc894b29f92bcca8481cfb6eca97e8562aab3845c2528f03e3f5d(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c232dfea50a092e8a1d21151ff3910fba324004212ea65bfd7f92c66931c2c66(
    campaign_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__da36a3330ed4cbabc404dc451cc4e96c0aa41daa567cbaddc80b1fa46673fb18(
    name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__36531c889c04afbde1311ab455f4315c3a39ec60cebef2f03951d04660854fe0(
    fleet_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2f82986e9d49ff84ab4679eba9c8c9351ebb459ac49034e892e988dc8d9da7a3(
    name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__574ffbcb6206e50a14e993fcae5e97579b60386d776d3f698f757cdb8da7fbfd(
    name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c8dda316b862089163b773db7cd134a3f6b3041a8896af459514e0dda22e409c(
    vehicle_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b2ef629aad768fb5cffbc06e198b09ddb3db5a3d53302a58f2de40249a6ba413(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f0212ba34e1b01a60d1baec3e1fc9d05593758ed40f102c9a27f7968f01d6f26(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cfc8fc8bacd0274fdb93dc33fbc9bc7d9731fe77df7fc2fe921bdbc42de75aa5(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3f15929c5aee86772654f6ef2e1673469aaa811f5cd69e9de59c9d594606de41(
    thing_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cfaac904cd8b8fbde1c0455c4befb3fc9a15617a24a5984fd7bf7a814b086363(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__679ee6d31580092c8808f9f7fbb66866b6877da85a56e78a8bb115f04b9048e4(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b0dfd15bd37fd9f88b6a7cc5e810d0fc7baf321f9268208f76d1cd56a63402ed(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d6a5a3de1ae3e3c354a04e3b425335efb7624d7091b862ad696603f58cda83e8(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__448316af219e9e041066eb77969d2763c9ce5bbd18a9469b73530cef4a77f79b(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0817e75503ad7b1fd4a6993ee4f038de5aa053c8e802086a7008cfe6eaf8d0d2(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a32a2619b2df0a02a247f6c8d3428e91d6dd08d0f16bcdc65d771486b6d3a64f(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__53ab49f7f85fd9a3394067f35850c5bd58811289ad3c4824dbc74127088cd0a8(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f8553a396ca28a57ecce47ba50edf434fc25eae15c09744e640578ebf7946ab2(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8160a6762bd857b869640764b4d84a203cd77e7e0490aedffcb766f9c8c42127(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__74e5d285e0c1f7cf81be349ceda4c7141a21096ee0b3c8063c91d4550212d7ad(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6c09794caad7940d938221e15f9b4b047703a7589494d8e2e83eb7f38c973c8f(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__76461ac7a643525e88e79006f5f12cdbcf1d4e58a60f6a1e5a399dd6280402f9(
    action_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c9961e787367c376dc00b1d4a2556f642632185217c03848507d6b64a5af2eff(
    action_template_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ff875a6304984f6a201e402b1c5d97ec461e3c1531415d34f26a766508a32d79(
    activity_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b1d2e7de629b2749144da1aef39595cca4322a3246948f58a622fa21fb6ad5a9(
    destination_relationship_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__335b43db6ee09cf4e415e0e131ad9a400825b37a3249c6d98fa9c2511148b29d(
    site_id: builtins.str,
    destination_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e516db3eda110deaa8e9d8b8bbaf185fa37387760b89db5bf56d13af10f7f205(
    site_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__67aa020c9c8c53be0f226f20bc55ef99d08b35f50f0b8cd3fcc82d59f7c656a6(
    tag_key: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a85247d8e0847ea69ed06332fb94a0be4dd80d9144fec4c3bbf1bd6927addffd(
    task_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7839c3ac016f4f08400b041c929208025f8a25bf0b7532be3d869043b9d83930(
    site_id: builtins.str,
    worker_fleet_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3e0c81ad7c938d4b6eb1c3e3318e7d69265f0d4fecfe86ef3349e9590240908d(
    site_id: builtins.str,
    worker_fleet_id: builtins.str,
    worker_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4284aa283d42ed77c9ee56ed71cd98eb6384e0ecfa698355c1646c605e05201c(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dabbbe93ce9e9cb7e66d42e4eb1bb1babbafc40c9a681972c1836a8296583d07(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fd03653ae5032a16c43b4aa5cf0a9774e332632bfd32338547201c1c26078d60(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1674f05ab51b9bba4a4e826ced16236354ba9482bdb292d88c9de21947b871dc(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e536f526919bacc1eec63b6dbfc5951a9663488eb28a78ba0c0fc7b8c2b1b01f(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f4de5e678efb461515fe63bd9dbaa0a1739f59e16e4425fa8b99b85ff1be52a7(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8877ad534b326708930759dc5ba22d425feb3f5412d7d760503abaeeff8cd9bb(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b009904e7ffd08d7031cbd7c3a183a00d77a4a2e6ed06fb1db5d381c8b7880c8(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e7cfec82d03c1ac8ec9c3bfcd4c2fd323e36927770387729496ba47a0434595c(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ce7aa42c79ea37e2a1a6ff7fe305aa47a7c8cf7c2609b5a29524a05f075128cb(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__72b28b9b4260ef694ebcc5412a90a68811863d2352585f07fa079265480e2ddf(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__df4c5ef2d77df4c242c65ddfe400ae198f7cf3bcf30a364aacde02cf86e88396(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ca2372f34e51337e8962d2ac60403af4bdbe9139998843edf733cdcbfede807f(
    access_policy_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__18bcbafab073af9d988c2782ad9ad5d53b5ebaf43a1aba09a19b1e79dfa74f4b(
    asset_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__900c15ed8785d39259dcab4f6ab4182cb901bb0c5cc2610bde74da2c891e8d91(
    asset_model_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e854a824354f582a2b57aed3fbe7ab8c74a020fdc1b983e079560957eac35323(
    dashboard_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6655d6fe3fd71b73bf9c7341e3cc86d548389fe113608b96c3af675d8e63e1de(
    gateway_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__68a0933478402b818eb8eb95dc70844da834128dd9b1a3f52667c6c8fd67641c(
    portal_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ca1e915f9c2b541beea931c7b17553a73bc6b8a9f92f5038e1f2f00f3613e189(
    project_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3cafc7498e4509764b2bc43adb07e7e4576715485d2ba0cd42c51a39d68b1822(
    time_series_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e75d29f189776cfb14d0067cb3acb21cb5d3233d4626425e50f8e04eff0d6d2f(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a193eeee3605ea4c1742b32ca86fe32983bac3ed1e07a51bcc5911727b91a7b4(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7ec9c9c8619cd8c5bb05da8ef4da3768f698ff53fdf7c6046dcc260eac2576bd(
    workspace_id: builtins.str,
    component_type_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6f1f71e9761b412c5cfec36cab3175bacb4fa5402576e2b87caa15ba6b5acdb1(
    workspace_id: builtins.str,
    entity_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6ca2bd6194ae29569332580a481def766d93290ec93c792aff632dd2f53ea54a(
    workspace_id: builtins.str,
    scene_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__378c9edf5c03461e55598a116d9d12bbd218b1ca77260dfe9fd5e7b65b19fa8e(
    workspace_id: builtins.str,
    sync_job_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__574da2497b0f29b452278429a5ad113f8cd5e9f917fe236ebe4e68539c3b226e(
    workspace_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__94d8bd58b7a2c9840b21b8d5a0486b06a2802cd066ee1a639facc4358f0790e9(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__27f65a700eec0efe01b237f6d082a1fa0125d74ef2c4681e2644fc55e3e9e0c8(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__448e3cd92b4d9adbdb7e1bf087d7005e4a1bb2ae7729496836a1cda3f3a2d928(
    certificate: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__87d1e0478a387ea81ad3fa2852be3d7233401f9cf888aa387e52db6da4aaeb14(
    destination_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2c83e3de0c60d0e238e50e8b186ba3dfd8f2cdb6d3f1aff8cab970d9cbf1d41d(
    device_profile_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__33e616a4e73e5504dc43845d6f4ce6e96f0334fea13048f4da2b219ddafd4720(
    fuota_task_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__835a58e7522806eaeaa4dc1c981ca9e375933c92dc0be857d90119ff7d0e109d(
    multicast_group_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ee9652b53db5918a20178798768e31cc1fb8493cc0e4271191d4e3f61e153c9f(
    network_analyzer_configuration_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__04d6a8a06f66823ae78b6a86677a42abc4c622b43ff36e099708033ae027c9cf(
    service_profile_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__94b9561c1726640d4b891e434ffa056f22c6669df456d409808f6e8e94c4e21a(
    sidewalk_account_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e3af9a36a61ba15435c484b806c3f3a7abf9e9553a3b94e56b638e278384ed65(
    thing_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5bcd9ac0f00a9cf47660943624e3070aef2d98eda2e3168f1083033e2bd44908(
    wireless_device_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__06e0c68ddee558260d5786ccea364aa0dae847207b9db9cd297ad29e30b50fbb(
    wireless_gateway_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__271e527fdde83a730b848ffe7a364ae9092ba349c4ba30cf417ec2400a2ea2b8(
    wireless_gateway_task_definition_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7b100525db1545f30b6c61f88bb452d0ed54e0241e447b437995c9ea4021a1d9(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__df9af84393e1fdfaaf16d8adcf1819675745d40dbaf8568902488f6c919c23fb(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a75eb8d6499e8b3e111a848ea7d052e4bf98d59b3da87029dfd101b6b4b8eeaf(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5ef485f3d2316180ff0a9941f072f70893107eea5cb00f0378f0b96051695d2e(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8bf7f05b545fec9a82b6c6d5801bd38c8bcbbc3f66e39a2fb6bf71669b33f960(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f81b477404a81c85301ffaffb120b4d6c9c50d2eeda71e2e66691c103160dcab(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__245e87b073e72e4d96fc49c1bedbf9453b761c08305e547cec752a669ad29ce8(
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__647f9fa47147319ab1e1b94a36a62bfc1ccdf0f60b4f977af4531bfdb513a1d9(
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2148df429f27d3ccf07cf0197e10db3a0394da5dc7a86ad14fd5f6902de0f468(
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ad4e6311a182cb29b4459dd3bc8f44faac7557d3067489b10a897939093ec630(
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6c37b6a642a2b5b05ca7d26df269143cb6fa52a5ba91d91f12623f7fc1992980(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__97a1b1ab82bf00abb8028d1e7add1790869090005957685f0f70014f90aaa472(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ad05c11b46c561ea92a8615a1fac9497952b3390e5d2848f814cc26bf8a1c7c6(
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d14540aae4ca5aa1e970affb5f2cca4a077dc0d4ba455908b5a68ee55f707659(
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__02522b7755d6c263aff0c1cd680ad7d32e1abd355b04277a7dcadc08d644f5c9(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ad53a875cee0a1918692d2ed212593f95a554a6714b1fae7d2282bc808385a1d(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__37119204a0c0a46594649b653d6c45cd7fc4b55fe4f6e1758478f472e99b719a(
    cluster_name: builtins.str,
    uuid: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2e5eade4f749d4c8d5d9eb033cee0c0c5026cc22b97b90a667c20bedc0051edb(
    configuration_name: builtins.str,
    uuid: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7fd6dd53cb179eb03c05b3ce1a4b2a48712eda6875f3b31e3bfa6af99a745938(
    cluster_name: builtins.str,
    cluster_uuid: builtins.str,
    group_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f236eaf563e52cffad2ecdb772d59d959664eecc11564048e6db47cb0a1ec926(
    cluster_name: builtins.str,
    cluster_uuid: builtins.str,
    topic_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b6d433e115cf59a8d4cdf64e5156370501f97648b8fdb6c6507157ce5036d3b9(
    cluster_name: builtins.str,
    cluster_uuid: builtins.str,
    transactional_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ad4e45e46f4e4a762f62a853bc6f982a958c47730961067df7763dafbaddb084(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__94a16bfb6bee663b631220c0e793fdfe3ff11cb5d484e75a237761e17ed3bcff(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2d5a9cfa1c9ce4f273182cf078cddf6d4af0b81e146dec6f07e6e77225253497(
    cluster_name: builtins.str,
    cluster_uuid: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__93dc711492812324b97f36d6f8461dd4f43a5ed0f6a25e8fe1a78a8a3d51eda1(
    cluster_name: builtins.str,
    cluster_uuid: builtins.str,
    group_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__90e24c2ba708ab746b770c45ed1219308c370f2177a8d2bc166776cb08799720(
    cluster_name: builtins.str,
    cluster_uuid: builtins.str,
    topic_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__87a4edbf07e1c853c38ab08946120cba128e9abba90914a93d301ef0e4f45571(
    cluster_name: builtins.str,
    cluster_uuid: builtins.str,
    transactional_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c5abf54761fd4bfb068617a7f3c91af5bff9bf509bd8d587f980198f85669904(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__538baa165e4cd015bb64c35f243884b0d7615e7c95098f326d94119200d2fc52(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f090b968493bd396995e0967de945c904aebb63c55a769a908cada067a325f07(
    connector_name: builtins.str,
    u_uid: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__142ddd34b1249e564178e848f3e93c8afebf54fe9637fe173e2c75ad84b2aad4(
    custom_plugin_name: builtins.str,
    u_uid: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7121def064542a5fe3f8985dcb6ef101fa3d8098f8e49bf8ad85dc930e22d717(
    worker_configuration_name: builtins.str,
    u_uid: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0bfe6417f8fd7be4637ed3c86dd59cb86ac9e6e15f613f4cf7ef88672a304eac(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__984426b036ee9c205002bb77256ccee799dbeab5a852772257c6e0d7d1f1ea09(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d441fe6f1f79f46797fac8de8713a27cf80ea1289aa57ba6266e06d66d5c06b6(
    index_id: builtins.str,
    data_source_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8b7b1a8814575a83bd41044948492a48d384cc0c2b2818c20ea703d8334c6167(
    index_id: builtins.str,
    experience_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ec4927752c6781a26998063169d0757e6aa4a884efaf54e554c09fdf8f1cf4f3(
    index_id: builtins.str,
    faq_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5f107993cc714e0ef3377b105b26ea68e3458e9ea16d5d53ec3af1891e2463f6(
    index_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ad0570b04a43a325461041d750b47fa7752caeb0e30acd07c55766fb274bc95b(
    index_id: builtins.str,
    query_suggestions_block_list_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2207f4043a9adc17889257a06c92d726de78b9d3ee8965f50b91c4cd2c9e17e7(
    index_id: builtins.str,
    thesaurus_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__749ca5e36f2432905034f2414214d0f8a1a87be07ea16191578952e2869528d5(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__25834b8e0aa37ec920417c70a8e701b896130a20c4df813decbb35cb9b8a609c(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__740a7da4cf7ecf997dd75e44ec17653cce9c1322d030eea6950f45f5a6fa3bc8(
    stream_type: builtins.str,
    stream_name: builtins.str,
    consumer_name: builtins.str,
    consumer_creation_timpstamp: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9beab84cfcdbd21b4aac2d73b316e74fd44db5d496d9d4824cee9eb04daf23ad(
    key_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8383bf77f0a210a51d28e0dd1899ec57204445ea45616c6b6c876848ad52359b(
    stream_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fb033f5ae97e82e3e967c614552c76406b059dc67ba5afde78a85eb644fe1f7c(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__52212f4d6a9f0972f35ef56f101ef9ae28e6ff724cb2b4c6b653dd2a006487cc(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d73bf648557a283d0523290857719addf6283eed837479b7b45cd36d5491ab31(
    application_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__765155d6a9fe26046d3c2436de9dbf057c16612c653ecbeca584f3aee6660602(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a63237ff55aa2553bc32304dd367027b949410ef0efbae687ec20cde342a20c5(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3507db8a37321b67638d070e6ddff8da38de6da70dedca3d96f1035724075677(
    application_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ff7a43675aef5cc54aab38963cf57ecc74038eb0f53f0d0a7fb0b960771649a3(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fab60e02f6c0400813e4e423391d557a5801b22b5b7ecf47a28c023c0ec49c79(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8b92168d050706476f4cdcd4e0af5205f0a58e2a62c56a2acb7df0ed4757ed3c(
    channel_name: builtins.str,
    creation_time: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1bb0eaf7a4f98e6b66475b55183a2a46a341b907f40d60d1e285dfe38f0cd0d0(
    stream_name: builtins.str,
    creation_time: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__20a50553258eaa2c8e6fc3262c99cd694cf6c0d6062766fd3679dfcdbb8e67c1(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2148fcd9e60e772957a97ba39ee92fb809e4c0936281dcd7ce44463275ad3682(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__876bfe7ed8ac84cd3571d192ef0fc9076938e1fcd7dcdc22a07cbda41b2a2f26(
    value: typing.Optional[builtins.bool] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ecf2246c37bc05e2169b467908f8e9ae28d704bf9920df3cd78c2909707e49c0(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__29c11f1739acd2ddf5e29a311f0087ebe401ff18d13e349f5ee779c1cf471c3f(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9b2cfba12bfb768c57e0858dd68e9818001ee84cf8de710738bed8ce7a1375b0(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fd2fac97bd7e3c378ac4f8b38ce0817b773039e083f6f31c328b0c6291bcaa29(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3578bd6dc21f27e49266d7f4084a97b6f2f8cd4760c369f064e9014da0430c6b(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__048dd2c731904d85ed7414bda83e7eeeeab77d9b961f67256071087a25244867(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__27e723ec14aaee9351736015444a1fc7b9c4524eb0feff57cc52209fa96ff94b(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e1ce0dfad2d1bb3d706d1fbefd6ef2b48ddb5d6f80c049791c986607e96b9a7e(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7c886d67449c69f6a447d23fd0ba211e66f77e0f5d34851b71a417cc5997ca58(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__54281da5c435b8b10bc9b57235bab8ec6a1be12d0079251acfb79605172c6e1b(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e6cc4a45c9dde758919c7a37b37957f02b10cbd41017c5cc7c80e4adadee4578(
    value: typing.Optional[builtins.bool] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d05fa8ce8a11b048b2a9d0ef500f40ec94a3e3d17472051397e7dcd8ab7f5167(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a156f6ba3756efde67a040793eda81a68a863f8ef06099daae7522da13b316b4(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__197e83cc2a60dfb8d36e5dbe92ccfdee4fd2eb5b5f9786f104bb1c5de8054042(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e8afe45f37770484ce16f08c88910e7c58841a0ccea473aff3a63f43217d870e(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d3a706d32ae14ddce95fcd9421a7b21b2d569cf0c818ccd8ece35b305d32c918(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5ad82f239fd3a22af14a5c8c1cd683a1349e51f71cf2c8249e0e188515f3ffc8(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__57ae3008367cc817889973e74d8d41a98e0548a7a767a5514ca51a5aafb96ca7(
    value: typing.Optional[builtins.bool] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5207c2a63e3e9bff85e9493a5a6ffe0ac7a782ecd96d1ad11a7e1e0d73427dac(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5efec41e22d85e465bdfc857ef7deeecf61a46cd16d40bb97347fea9661b75b7(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f3d007a832fa1935b1e16b1e64bde4b9fde306e7ea3517aed59505b71f6c03db(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__107213557782de7fc1f02538a4b64dbe34c9101bf96b2995c5a1f02978d22e25(
    value: typing.Optional[builtins.bool] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__945c53affdeb0810c4bb48b417a8e34606a2b0968ca02fc9db5c18e5ca7230a0(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__606002d57093448162ceb917eb1d7b46669047b45eb5b140bb74967836c28df7(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d6a5e0555cbcc5fac0830ba38bcb08479dcf272be7b7f563f680521ec78323cd(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0c6b548977a01172557352fa120a3c26bf83d57193b9a22d562a2fb0b1f23fd5(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1f2803c3142a593dc19ed357266a5d41bb943cca38d1bae23cc69f9f2bb7c3d6(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__89c842c873b72888ec48597f76a5594e62fcc27c20246b9d5cbf135534226e20(
    value: typing.Union[builtins.str, datetime.datetime, typing.Sequence[typing.Union[builtins.str, datetime.datetime]]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f3a472e33056dc7f6419476b46acc1a1aa677213ccc13c1b3badf8bfe9e53a54(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b251c0029ff392a81c608d81d1f9e65bd15761559c62ce24faae46b364dc8ab4(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7a846098309d43511381313e6eec7f35d04100e05582410eaa79ff3d2ef96837(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__96d3973b71f6531377a73c799ad5bb9dfc7c211f5d22a3fef8939bf5b809c551(
    alias: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bc6fcad930c73ef810a6ceda66c5f827d22a9a72c9122b001de8f09955a8bf06(
    key_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__557b4124a80534680bcfa1a43bbe9e0445f21cd5177c2a70941f31860edb7d79(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__20cf584aa788f30d056fd8c602dbc54b1163e1f26d707e4edbf96028efd6ab81(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__645d66561d4282e87d4497cb84e6e72ec886291940243b97d3d18df96355f0b4(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8c78631a688eab5e8ec869111b2d502f30835e5a2502e979f3660d6e8bdee9c3(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__769f86ce31dee0fae76d7469a1eeb974c14c8bc96a3296f71d1a16bf8f74fe3d(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f652cc13d3ebfaebfdb435a183dc716cfeabd87377e383ea377b4fe9fba7c637(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9fe938029e33251acb34cb7c721e12d54465bc3006859962bf48dc17938010f9(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__da9c8c3c4a68bb4292e6146b68a4d20ef996ac763beef813774a1c0e56bec606(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9dfd9befa17d270167695cde12a8b77704e82d3649ad1fdaeaa4db9cbf22a2be(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f7e522985c9ec1f61b39ded1000d0d1ec488391801ea66aca7fb70da8402a948(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a1fdcc32279abe1cd49804bf6533633936a5a0a81ae7ef402a6608552737872a(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8e083f01db235c89bca545f1809c360be1f94a36f2e183d223d53345b1609bc2(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7ce4bab254ad97a0f0fa5af0b032e6c2b9dd382b9275c9959273dec77366f668(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ebac1ff0968a23664f59d5e8a6441e003934dd3f8e8d9c2d643cda8e0ef4c22f(
    code_signing_config_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7f534f3849e9cf840c8b353cbd771fc2a3711363b6c9618ab0231a013e924301(
    u_uid: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__765214e7369929cac77b4df2561ca87df19dd8d4a74141ba16a8c6ba4f0a5e93(
    function_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2f02f0cb9d77b12d420b9a5e33237b4a6abdaec0aae16f2a49eed97ee379868c(
    function_name: builtins.str,
    alias: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__78bbd83e27dfc2ce2b189e3809dc45452bbfb910c5f150bf07b3cbd970176f0f(
    function_name: builtins.str,
    version: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__52540b4820039eebd656ef2ba02e0a7341db4c09c5d4c65b5f5aa58e7b037f37(
    layer_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__27926fc5fe87ac14087cf36107cdcaf81549f3e7b0c7134e1d6aabc721b5baac(
    layer_name: builtins.str,
    layer_version: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__118b83771aa49de3badbd21bf6d46462cb1d2e31b99014d91c73e99813af80c7(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5a640b064f962fe1e9eeb0ddd8d689f6dc0d053d05d944167802f1cbf9e4ed77(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__359496a58d30e09b570ddc0f15feac91bdc746e1b126449d00d899adcd69f175(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e03d77fbb9a614ba95f260d8c88b53d3e18543bc0e45d44bb8a620a60466960b(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6da6bed4aa7f6dc159270f29ed3c6d6cdf4f19af394516c203f9a5109e8b45fc(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1960ada759f559324a099c671c09a366b2b2a7e8e5e7542ee5870a1db53e3f01(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fdc28d7895f86ce5f27f0a8a8e1c4f39eb9f00ce3eee4e905cbc2ab839a4e184(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__62d2fcc8725f7d197ed6b89df0831eef201260714d5cc84fc6defa66e80ea9a7(
    bot_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5cc3d8ff2e7d538222e0748abddef20c2145e2c14d05395040f8fd76a06974b4(
    bot_name: builtins.str,
    bot_alias: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1ee3675f179c08556819ced22806b447741cdb52f7a927e73733e7af93bf461b(
    bot_name: builtins.str,
    bot_version: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4d2128df0fe3efc8a36bddf8c15ea715bcc3f764324d145ff9edf22eac5c9356(
    bot_name: builtins.str,
    bot_alias: builtins.str,
    channel_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__89b87618b5b45c25a2a64959901a4f109322b22028a910f4a1e1d9c6f9d25d79(
    intent_name: builtins.str,
    intent_version: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__81c790a870def4dced85af58d0c138febe7a0c109b7854bd00bdb95e9eb1c14e(
    slot_name: builtins.str,
    slot_version: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a794fbc30c1ea6060a01b9a8558ce1f0691076194403dfe93de05213ef386109(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a1f9b4d060b995e84fdf147eead71cb4449d566d3ddb8aa70c83b6d127d18ab6(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__375b3aaac47ce0301fb5b4c32d8797690e2eeaf91d428fc907246ceed9f4a433(
    bot_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__58cd49ce0508e2ed0f74f84d7c7344b732dc70188c5b5b2f8658ed0f38c4825d(
    bot_id: builtins.str,
    bot_alias_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__53ecf92774f850348b7985a4dadb8dcee557848e23702691c3434a5a7a88339b(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0cdf86f660fdedda95728c68cc9548e45cfe910acf52bc58e67d8cdf40685aaf(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a06416cb5b144c144eea6b9b3f240cc2efb62c6a31eec630cdc43ff959b197fa(
    tag_key: builtins.str,
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b3bd28fbce7eb014a62380c98c1b0a78b66ff2dbc19478bb0117e6cdb504fc89(
    grant_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ad82a6b497e2bbbb12e72726fe72ebc40b93db43e45f6282d1a20881bf8b7a0a(
    license_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fa556e1040be985898d1367b2a119f62e7c8f30342b0c69c0a9b91cc921392ce(
    license_configuration_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f2c999921f3c2987757901e29eb58157d334ddca2e73dde6b57be86ada6d93e3(
    report_generator_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c704090f94d7b6b5ecd07d999cef6118936deacd8dd5066ae3a9ba666e7d6dec(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cea42467a8b93f55a70e2d6ffa8b000ec3c10613e828c69404eaf9fef80dd53a(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fd51e23e77e7c8f79d99094838f2108450c872a04bf1eb5f9517cd971fffaecc(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c91c73ce57c5466a8d7cc13978cf6ac99a10ca4612025038309bac3098949cea(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__28a2729e14095bfa525a661391f3ecd8da62363651c604521ec349edf1bc3c6e(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__192c6120ef7f71764b9eba5499650a3ce1ff87b6f509ef7264511208ee7e76d9(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c94f365b2d463a8a81e4e5f51dfef2166232da609782f966cd44cc8a26ffccbb(
    id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a2a33a9547aabc076b78ca215b6cd025160a26a92faad438a401a189d64ac646(
    id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4457418c4d0f02532b3df0ca344e01d0b0c5ac781499ea6809f4c30e045e8a08(
    id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__964523e1f98ff9147d28c0424fcf739b8d36b6d1ff6449a8aa07a41e16548259(
    id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__36286a50e90f5136206c28fcfcc3a24636884abc6f8cb42cdcce61a428fbf6de(
    id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3c77aa591d54796ee86640b733404fc4b9beb4a64c47e7b4bbe071a80b30b2e8(
    id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a1b32b7a76b44efeae33a22f978a0033d432f751ddb2889e48db94c62609155b(
    id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__08dbc7935bc9a6bb2a6d770ec2c7f5878838d3229a3d54a949d39249f643cb2e(
    id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0aa9e73b2f63b5c796ca5166cc8024bc8bdef95091a97472bdd0db49de5d8f74(
    id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__571cf8c35f3b31da07f76f0b72984e9aec3203a351e1c4995060c238e995cdda(
    id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c9535141118064f46b681c98b4f9d086aedeb06d628cade7ac68fdb0bef318d3(
    id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bf237e9660cfb791fd15f9822dd15eefacdd8448117bb12daac796af39caa75e(
    id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0242a7c87d5fc20a6cc7f0d1b98ea93b55ff5851776f1cc59c19d95e76a65755(
    id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7f7eea478dec74998fd5bd31ea8dd2b18e56aca888aa76f08e74a328e60ef3ed(
    id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5de29c62c7a3a3528ff754c87c764f37b8e6a5785152bd348437264c48c98af1(
    id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2c02ed03860917a1066961aacb8896c9299e526c29c62961133d6b42cfb3b1d1(
    id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__37001cc96e803297e02b91e3d7868854bf9003037bff95c2ca0f12e84ebdef94(
    id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__143232513c70551ae647422633b55bb968a45d5d3ff41529f14a69eb0d72f744(
    id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__53f90de9c8b5874b7f46332ca8e18c0473d90b2ab7ce0553397c58f550c78926(
    id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c154e593172fd2cbf4a2bfb4b3dde88f9dbd8b4897d5bbf0db114eea0af73103(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__66b4c96ab8f50365e33b90acc4351b1add34928efb9da0ebef4e39de260e5545(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4aa5aafd229941a7d9179199f228df79f712e5e80c4b3bb2c7f6f34697383357(
    destination_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__39779120fcd84596438ab6fc1a5c4e0806025c5efe38f1010b2c7d9019f709fa(
    log_group_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__26117259ce4a59988e5801ae286d36f5770345154ba4695ff3e1763aa04aa541(
    log_group_name: builtins.str,
    log_stream_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1ee0763d439e49ea3aff2a40efb9c10eb6a76b058c6d9a19309778561378b982(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e8f7da847e87e7f57b7a256613106d9be15565c32c7b9b4d014241ab8d6d02a9(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4ecb4d5c78e00bc771edf596cae6f486b3150ec6440c2eab14f40951d8c6f9bf(
    dataset_name: builtins.str,
    dataset_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__08f2987ff7cf6b971e96da8b81dacfa47e89b6ecca96af6ae612761b696afa7f(
    inference_scheduler_name: builtins.str,
    inference_scheduler_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3b2127147f22f67fdfec14359c3a8dd79b909ece89368077e4268750e38f0ba8(
    label_group_name: builtins.str,
    label_group_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ce208d666a2f7d88707bd0f7eaed24072ee5107e7e1e6055afb411029d8c2f3e(
    model_name: builtins.str,
    model_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__58bb1905a2ba1baa5d460b0b1141b564a0f7431031931ea798f546aacafedf68(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2fba1e27fa5a81dab702e9853d8380d294744d58112075b67920f82d23ca14e7(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f76a6baf9ab34bfc8c785e18109e1b4f677eb1815e572fe6edd914a1272f0937(
    alert_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c5d08a093e09858b4bc62c1a2cbe4dcd9baec2eb34a29c0824762152ec9b227a(
    anomaly_detector_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e4eb4fb701a133a4dc3af717de4266efc288af4150eacdd115c8db8d431817c4(
    anomaly_detector_name: builtins.str,
    metric_set_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2ab5d8367ae7ca23f3411852fed9b4a486325b2aa67081c2e4d29d9572149875(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b9ec995b9d5df6fad4beb69477da7fd1950462372c73e6d1246bf3808fada3dc(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__78806266bc91f68f4a4b8833e17797dd7e2499649ae861bddf5e0abe12e3daee(
    project_name: builtins.str,
    model_version: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1edab672f98b5e60592fecf0a56c422ece4be6b369b243f9e42c76049c0a5f11(
    project_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c0c86f75b689da710afc8e3a1b79348728bf78b97048ffeb85c02f6eb6f4b88f(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__54671bdee0d283baabf6b8f534f123e467d295e1e9bb1e192ac38020a8628d54(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f117c4e2c4bb07fe4dedaa1bd995cfbec8c7c7b01f55ba55470ff5e8c57a7c42(
    application_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dc288dc2cfb4a9bd1d61040703ed12588210da8514f83175bdd7965f22fadfdb(
    environment_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__36dcfc1981ea6ee5733904f986992ac785d7860371601c22614ab8f3fa934311(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4fa5d81c7e569491212acdec572caae8d2a71752c3551f350808bb9a34423234(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__957a893f93c8eabb186e11aaff0edec2e2b9747346205cc030092b292ead3b57(
    batch_prediction_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2c5b52a55a45d95264cec322f9ccb902621ee44b37012102dd6a9a7e30a08f75(
    datasource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__305545a7adbb8338a538ebc2ed3ddf530bfa06c11d3b52ed2fcea2859a76d2ea(
    evaluation_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2e4476c62663ca9c1b13a7d8e751e774570650941bbbe6b5a7eccf2cb29ae737(
    ml_model_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a4aac8d9ce51b6f6f74ceafdfb0392e2846e25c3ea9944d95ba3b4e9e890c338(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__feff7c908d15f6637da11004962011ef7a34d5315e10e50d5b425bf8a4c628b2(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7283452c44609ac06735ccc13b94d6de9bf2ab6971c50c8c97322345f7186bd3(
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__87bc6ccbc4cbcd99c7fa5046024251c18da491283bd712b2016d07c8a20aa392(
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__27f92d5e618d64f09dd68a53c6df8f291c82a705a50265b3cb78ade64cc97d96(
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__af2667f951f61e9bf4185cd53966e9fbb8f6644f31293d14fe9f7928d16e9d9f(
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c4d9b6101e4ef20a30a467301746fa8a773d46143d968a36f77c0e7a0df86261(
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6e67a06038939b8c0b6f7ed9c8de782dd3027209653458fedaa0e7d20ade08b0(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__47710abcf11efb715eaf0ecf01716ffad520127b5a3298520a00a556f689ab46(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__923f246947c84342c1bd0e80fdd2736d6382c6ac6316d8205aa3b49d1abf6840(
    invitation_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6a5e9a110ce89918a90e16646a408f7b64b6603a18879a90b7da7b1adc9dfc91(
    member_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b4acffb2e3d0ec4d4dbb84f11e85d9dc6d7baf4cd524a3fd0391dc4b585b0ae3(
    network_id: builtins.str,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f1c08125b7a9feed91c28a4230acc24dea5eed904c2588cb5e9d45d11a73b5fe(
    node_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d092be3c3e820f1e50612933f1e97bbe736ac767e4b5c33cbd0fcc68e1a9ef66(
    proposal_id: builtins.str,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bdbf45386a00576deb1e1311ffdb47bc11f76b04126e1d9cfc2d6932e2b554f2(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6a2b749653b361849cc97e16798a325dee9a8bae04bc7f9d9fabf7e880aba174(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0eb67dc6d0c87e5e8bd4f2cc1806f194bb95b7d0b86d9b1c926f7ce63a8e9bd9(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__55297913362d63f40f12d76fb393adb61926ea7d50837afbcef84fe542049e2c(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b879b7fdbd3784434cba76c03982053e59912c9f0a27fb21f481ef9a3f4bfc8b(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d3aa1627ed34d1dc0ffec4117b2807ffad18496bec0bde55d64375fe14f5745d(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__63c2afd7145d63433bbd8879254026428981a97828a86ccbe026f87d8310d3b6(
    flow_id: builtins.str,
    entitlement_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a3b5c86c7ca5a4f20b1bbc83ff464b218ecff608fe351cb5e54ce0d2a74925d4(
    flow_id: builtins.str,
    flow_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a667a9cbfc8c4cb226d7597e31a74b945c48d330bdfe876ce4ce967907ad7a82(
    output_id: builtins.str,
    output_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2a49d8dbd627fd91e25204030caebb8aab20a0e5423300fbeb6b33eb2ceafaf1(
    source_id: builtins.str,
    source_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d6670897044e7f903f6686bb9deac5f7fd376a8355ed53a0b78b26253b8a7101(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f0326fe1638967b232ad1536522fb2646dda0e4b6ff3c37240d9d9b98304509d(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5d17fdd2dc6d2ad898dd906539ffb520699155302fce9bcd8a85db05ab5399b4(
    certificate_arn: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__af8f3b256c1954c6de828c2f371fdfaddd5e452c1ed267613e6787973ea9cfa6(
    job_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b3ce0b81b8ebf07e847cc82a44253041f9875083d96d264f8c62b12f2384a5e4(
    job_template_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5dd99f74fbe9bab9782dfb71d16b9e67b627f57ee2311a7d31cbf88371be6742(
    preset_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c1568d303dcb6712339900e1f58436cc66135b95f9d7905f2bbc3f59476f9911(
    queue_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__428b983398b0912c70bda8eadc955ffc3617d992e2fb4bc627bc6b15f93b6f77(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6679c2a932dcf1776c5d3acf09cf1bf797b37806a5e23febebf34fab5e8c9fcb(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8f1185730c470a978aa8851b2fc923f69030c48f75386ec0042397983a482b47(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2b8db10a456585422a098672e2eb81376eec50f87e8b913e5a2b42a3cbd4607b(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f2472d4a47f786364ea57eec053b829253e97ddba9242e48aafb61a9ac6bb76a(
    channel_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__078baea5878cfcbc57c88fb033b5716a433605a79912b556a3608b95c943e4ec(
    input_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bda9546bcb38df22671cf1f4094aa107b14af8bc31232f57055d2eba75911e4d(
    device_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ae3b18f2e3818f3c4c82c64a056da25b1a89a607e66c9c183c5e0394b9468320(
    input_security_group_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__71958a80b41e29b19d71daa3a80c757f7335795eeeda2e59f7d94e9dba3d21ed(
    multiplex_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__89f475dafcf235986ec1895bffba7434fa7659691d09e5d59b7b6e36f9609e5c(
    offering_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__37d5700330c48890072e5f9471a85677885720a28035685d3aef8077899ab410(
    reservation_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9b7ed36330703b18adf8c98d07238012d4c886df115e3d37d9c7238be21481c8(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5f92a493b07a1b25f37f16e5290947b21078a9f876218fad03000bea87dbbf0f(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d158aba54810950e818f7b7b5936ff0b5a8a7ad0907c4da7c07458eb08eb1afa(
    channel_identifier: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fb27212969c8aeb4cd29870d280423983e8403aa3dc0eaecde1c9ed75f74327e(
    harvest_job_identifier: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fccda338622735e5c5cd396e665534f043cb4ad11a516bc66b3e4917e07dbc88(
    origin_endpoint_identifier: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3eedcd23f21f979c7da52747b6a54aa7983204dd0f18763b16aff4e4efccccf8(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__58ca4e5bd2aafe72f8a8ab609124cda9601e66b63f226eba728f5d370b0a6748(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__297b72d08402ff53a0c815f87de8b5d8521d77f25d3baaa803ea812048adb917(
    asset_identifier: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__59fcd98f0cdc7ac3c8ad3a1fa323030a778763d8c93aa042c80754c5ac3103fe(
    packaging_configuration_identifier: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b0d284dff34c8b057e854b9263acdd4da3fb46d9992d0d8d3e9c830352359f5b(
    packaging_group_identifier: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1ba91c3bd9e618bfe54e96af350c3966b08e0dfbe1b2c3f3b58f20ea3c9b40ad(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b6893d00a21e111ec0d00bfadc118de4dc4cda241991832b7cd72f9d7f66ff95(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__31e4424a03b75ea8e6516ba7438ed003c23c5d7180095cdeb5ce4cb2819877ed(
    container_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9e202cf9b1b86d2e3a096209cfe0271ec5f283ed4d52b48aaff54d400bd5238b(
    container_name: builtins.str,
    folder_path: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__341b6bd918deed38d545388e261dbf4a3a43c1f982c71a3cace735d48ce38d90(
    container_name: builtins.str,
    object_path: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c18e34ae347848d24b618eb871577a6247fd748bf885a683e07155482f908e7e(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2580916c9a5259c74e97e222dd075ae67d52c07d7304a5b6ac24f61f742fb47a(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a5d0a97a3ee9d0dbccd596eddf442ff1c23e4111f954f392518db50a4ffc5571(
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7f3819a6545fd51ad9af62e64e93dc8f70eca11a0c5dcb901e7b66e680530573(
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__71523bfde26b383811344b4af13303e0b3a7213cb8ee9ab2e1bfc9f9d2796be4(
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5404e82b6abd754f88a8250eefe2313d75acb61d408bd071b4a72d33609c8eb7(
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ade52afd83ae273ae5853034180fb67eabe0fc43c857edad4479bba962fb4f81(
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__67da46699391675c9052f719f54597a68cc005822b6fb0a346e10f0224c1d182(
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__44d3d4ea23760277d22f7d3c53e4423595f1a3c99484974eb803b32e24030200(
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b4887deb6b7dc1065feaf34712618580a7ec05aae7b2a79f40a1dda03babb1a0(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5c0452c7a0c70e5821dc61b0ccfc889919a4cebafdf0d62b13562f2ea5252c1a(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__09f44752b36922d38ecf075355f4c9d03da85ba9e422edcba1392816339c26dd(
    acl_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1fb8b319a6154e1be0106eee55db2155b98ce61a20d82aadf0d017cd7a97f05a(
    cluster_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7d4d01a85fb04da799dd44211ebb6593460535184186be481f62c138816a6798(
    parameter_group_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9ed14ece7ad7f03cc48782bb03ca41881f1ba307aaadfa35ab115b7e8410dec7(
    snapshot_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fc3dbad76ebbc00e8479a439f1ab86eb44084ed84d540b7315cb151f41e90edd(
    subnet_group_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1b8b3856e523c510a5f1fc9e2a8abb63bc9e8c8a93933430f4c3acad7c4eec58(
    user_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__64131d348b61ba0f507a4bdf4e009044a4202e4e8e531923cc5724c73cf6f465(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dc587d1c0fd418c1f2a2ae2a4bb30a7ba0c7e1b4a362988677d0120ab7f0ea7e(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__26da996bf45dcda78a26a0a71b1fda84ee701dd7fa0b0ff834745e80fdd213a3(
    stream: builtins.str,
    task: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c417cc931f14cacd9454ed93c0a4f41c13536c16912ae32efb0e8df58bc1a825(
    stream: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b666b68b6eeed9a0acef055df6bb5bd890aae89f358fb0ff0cdc537837c3f7a3(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0692fb398de8e1f577174a4002b976553b6b46649ca97540386c71f96410d3e7(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fb5a889bc25e4f69b82201906a5d504efeae80fdef670d00631e0d6807a77e07(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__93ccc011d34f96ddef68f428621b8f56f4370b5b97d87f9463efeb29ae65ae33(
    application_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d6e2742a7d5b3d86da9e919b79e4c93bd72559cdeecd4c8e44796b53327c45ea(
    job_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__77a14e90db57c6a58c450c23210fea942fda0865c7380e1a2e94fd3a8cce61a1(
    launch_configuration_template_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ca9faaf4dc56d3c40d43c17f95b8d1fc63418043c3d391645ad3b3ba9e610480(
    replication_configuration_template_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__67abdd4abb82882ca8229593d3ba93bf2b8dffca9d5cdcd7287debd795f41e23(
    source_server_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cb6bc6e1e5a83b380bde820e1950201881b08b8f83f5b4d130f83036c4682dd9(
    vcenter_client_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__121053f082880bac584795c6697f995f522c2cb08e4abec30263139592e8dd3b(
    wave_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e387e57359b53f8308361df5bc4911dadb409d7e6913baecc0b20a355e9d28fd(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b863a562261f360799fceea77a87431d82a6cc5878adfe806c60eb3079821d7e(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__486fbc5677107e8afa89f4e88ef439c0b325d13434d32362d3c5ca6c8ab18367(
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__443a783184c6428eac466574e5f9cd8f6fc876c3663f7577556a577934191453(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__80e901e6c6aaedb196755986b5f6a5a5743ead6c8144bdeba4359ca90659cd35(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__92104193c142cf9f3390ce560e60c91403a8e35ca19e4bbd081b1a2b71055645(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2d6a75c4af4011cef00e28877f214ba2f28bd862c672b1a8b6c4066ddf8adbae(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__867ae0795e3c36157075153530262d8a8e8fea0bc9bc3d13d34d7c3fce741e5d(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f6892a4702d5a249e542fd71b4f89be9727e203c642bacd166280f7efcb0951f(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1562eed8196fa22c7ed36e4fdb0a766681b289e43458a57a2a504dfbfcd8c0c4(
    project_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__adccc007844501768194d0d1c4f8b299ca64b1e7957cd0911ae7571d6f9b4ae0(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2e51f368356e73925c947be6e22b519fe4daaa0ad6faafc7b6757bbd0197de59(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d27d5e7c00f42fda568fdf398e4564a631537373354af8fd632b95788344e073(
    app_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cc8daaefe6d1622e9f3c3122525c23d5b64b3706d9bd7edaa997a5f1ef2ebc7a(
    app_id: builtins.str,
    campaign_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9dd8cfd1363011d410f2b434ad22fb191d5195edb59dcd84ba3332320b23c19f(
    app_id: builtins.str,
    journey_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e5929a266a84b14292bc81943fb70c358b666c6490b0227f6e6330e98044e001(
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c27b46d4b928805471bbc14df4d11368da7963f40c0aeaceb8b8a9f446822828(
    recommender_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1fea37c9f424c4549ae29e247f832893b6117d27ffa39b0d12e8b9a3538cbb61(
    app_id: builtins.str,
    segment_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dc7f84eb12e8825eb5ca4de8bd614d34097172931a1800d6606f834f7143da19(
    template_name: builtins.str,
    channel_type: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5b9d71c7cdcdac19b13b5ffc626448208fc23a28e94165610e6e692919b121c8(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__21f637e77fa1893e8b6b6761f44139fcd2a15c1921bd9e611ffd3ddcbf66e6b0(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a34a5aaeac052b20883afc38b614ba43c6b010e27424bfefe4462569e37cd148(
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b7a9a9c8d95dc4942bfc4476a247576189beb19029b0fb75403628b9d964d820(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__72a413440a264d53533c0c35bbc14652aa08d777d8e0c353febf63b8ce6a1b6e(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5a49655c6915d9af3918ba9c7d3df204770f4b763c856b1204d54215650333bb(
    broker_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0e5e4a03e42f6b792d927da48d12af3d4514162b329a28ebc44031601bb472ae(
    configuration_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8334e1266391d10dae8c9710b7d05351292e02fc5d31471dd398ed38c9157d09(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__720e72e44079287d0c918b7b70ff593faf2919ade29629daa768651d672c23db(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8c8e43f91f6c1edb459ca7724ad630c74fc951f253bbd89798731a12c4d7946f(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5d04767d72dfcd1974fc48fb21ecb820d485e694ac2c7339650943536010c0a0(
    cluster: builtins.str,
    database: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__61454920f63ab5cfd4836ffbfdbcc70128b015261aab86ee8f992c60edcca41a(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__459a806786e48dac585f816aca0dce746b01b068faf4e5b9f0d6bd101d37b108(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6d80b14971c468c1e01cb3ce6153603f424933ea45be312a1ceeb65fc0c3dd0e(
    name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5d196a5d2da2c0fd60c329ed895f13b3e3cc74e4ef9f2f9629412e204b899479(
    name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__04d4dd426edf9e353cd9bc03f24ca4a8e0c3b52f4c3536a67a63aa4b7ec6d61f(
    name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__038a7b578e08dabb9ebd2784c5347a63251c0be66b02017b30905768b50492ef(
    name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4c84281f2fb3851747d3089f871b53241143d19e0260213e27976e35b3d26ea2(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__987c811ac65f43f579e3235927f690070963b2e8fb98beecd0260fe335a0cd28(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__708e31b0540a47b1c11a3f83a24b3a235b00206322b2bfbc8bdc82d63ff4dbae(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__073e67904272b2c0a769d324a8e2a54e7b9e2cad92e2fcea2c20e0e2ccc0ba77(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e7a8ed033ea21c7622d86a323cf4818c955596830a2d5c06708f3dcef022b014(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__44b03e62227e63913603c3a962f965828f2b858c2b984d725de7c2c6e59f90f8(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f4ba624855214f3f57bc89a536ad22528f93c2f5612674b37f767a90cf2524b2(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__36d7b013d35ae83ffe348df9c48847fb5bd6ddf15df395516b843354c81b4b13(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7021db8d765ca1c3e3e097829644f61e204c92c80414aa44300d91d9667027bc(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a991a7f093e8829bbff23ef10e2170c56333f91b3715f7532c4a2445adf25ea7(
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2db4aca01257970d14ab37d39b4ba7b6e1d41312d80948af918642e9068b04f1(
    global_network_id: builtins.str,
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2cc8aef40cb67de663867261f8774ea673f6df43cfc45604974df3afb4c95142(
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b237383bb09b2137338691ae2538133b5ba7a843bc259cfa02c33c17cd16cd4a(
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__461b6d83168b5cb4790b7379247e8607263ec99e2c086cd2549a73a0452702ff(
    global_network_id: builtins.str,
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0feaf7ccfa789049cb83f50bfc2e4b224e039650aa7fc03f1c9793fd94695985(
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b7b83adcd3b53fd20e9eb98c08ce5e59cb07b8f789cd59d69706b0e21b486ebb(
    global_network_id: builtins.str,
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6bfe30a627f44e0aab1066f37f22ab6e945400aaf03d83b46c2898aacba2cb09(
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5af7be99280fa7b02ac98b39b0bb3afa7f941426a0305d5ae0db3596492604c0(
    global_network_id: builtins.str,
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7c48a09c1572cd5e715dd51d609e7c05a22bc251f375d75e5afd2567f93a3426(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f5a14e0864bcd0a942b06c9fb17e8d240dc446446fef9776d15ba185bce6ff6c(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5ec32263543cd03d40d8de7ff12f4e02aff35dc470bb4e4ebee8c0139c5c42df(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fbbc769e09ef4ba45f3cb6e65fc7d0d40e942d6d4fac13b071951246d0525ef3(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1543989927cb50deb5d069abad08aec471408f6a03986ad15e7781d5cc87180a(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b8fb97a1e40d34c288df1bc75c7e210b37750fadbe3fe3669afa1bf5b1c0278a(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9ff2353bb5858730584cfb3f590079731c8a32ad2303272c5052abe9d145abf6(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__41080f76c6bcc6ed61337f6fe51253b4e5777240c9d1b05dde6f627dc1eebe0a(
    eula_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6154ec0c2a46eeb21be81cd47ce9e9449eefc1bfef339bf84f5453f32bc17e91(
    eula_acceptance_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5b8e8f22fa24ab9030ff008d0182a1fc97b7539e4787168453b31112bfb82e19(
    launch_profile_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8cc70e0b65ff97effbea4d691fad14ceda535bb476b288c431fd156c95c02cf7(
    streaming_image_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a1b63e6fcbbb2a4f44da8b19dd9d745f12cee254ee1137182e036121227562f9(
    streaming_session_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ac49ec6708975e2b69e55dba9d0f43c5b19bc2be2f12a9eb4ecafc32497231b9(
    streaming_session_backup_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__03579e7d62838832324a61fa9cf5d4476b122e51fa033f88e8a8d550b4820ae3(
    studio_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1f82fd3a36e627efb1c2c5752a53dff7c398b1bb9d6115dc6db0768ccd4d5fef(
    studio_component_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e2f8335a78e6724fbdd630d2a1865d69aaf89082e69319c3c7b919db2e6b6d10(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__afe5fb5653d4c5b7b51444881261b4495c768da4de45316ea1ab47d07c9bd439(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ae2e0dddd9a16bb321cfb663c33149b98b4def79d361f3cb32cb2c187456f441(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9d603be22aa35eb779f66e6f9d877ea828422aafc1419c295403723c703b9589(
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e7d95af87e1e56c97c24e968001da96203216f4d5a6e561bfd4684b26d141f2d(
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__aa2e31c4040f1ffdc3eee408a471f8878bb7450922e1e86abc9973d22a705c87(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0c23cb8abde0efae00b897084139b42b092eec6dee7872f3affe9528aa3b9256(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a170ec6c1f9c944cc602f8fe5eda851c6ba4a2f48665b97b05ca6d13a3419787(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fa364cd5d9e3ca1303e3ccf9630682925f45e4834ce3fe48d4bdecdaf083fd4e(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__aa120c12fb321ec0876747349f2e3b215c30391618bebb79a8c797851984b439(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c45bcb30e99c995cddebef374991ed14b40711d1b217419f3331ce297f73238f(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__65246fe7a71174190d5eab61cb9cff283f4ceb33e956414bdf8321c5fa90a931(
    annotation_import_job_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__41a935a7d63fd4a543ee2fa5bc07cbbb4e183024625dd12257519516c7129778(
    annotation_store_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3868f1756f2102422cf996a00801d854dd8712b6bc319c41cc296689a1c0b2a5(
    sequence_store_id: builtins.str,
    read_set_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__09dd6fe55fe718c1bce160cc941c10bfcf8d51d4ed353adb1b73a95952ba2be9(
    reference_store_id: builtins.str,
    reference_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e46263e25212ed3803a2c8862ff13e90dca485454dbd2e7b45504b66853e3d1a(
    reference_store_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6dd97422812522dfdd93d6cf7ec25b27c051dc62addb75cf75094bbb311d0cdd(
    id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__09c8c2d17cc3999b90b346baef6a4456eba7aa6c7174c8559370cd5b189b559b(
    id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__eda25d32fce215b50769b873dd601c2d29b433ebc9365617cca6875ef8d5c415(
    sequence_store_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__81f178a648e6c18053651e75c16b6939a892c8d13530166326b9b4131ec640de(
    tag_key: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4e682ccbcd4d65c7cf66d813e8a42d960c54cf29fb71721f801b508394bbf4a8(
    id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0612040a3ab9d20cc0e27e4f1a10cf881d16d6f2e09d5d5a8375a8cbfcf44da3(
    variant_import_job_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c2d4f11815171ea601817f63eabe384d1092405096c7867e2ec7e8f0befe1a13(
    variant_store_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7346a1e199cf1c9883390a53cd81c1e9c9018c15376c9461decb689d7b0b28b4(
    id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__231e33fd3e3b78b8790bfc581709868e948091840bc2a2edb180c0c167ed1918(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1bf6c46117504b1f769bd2d865dbac001954b2df207392844a299823176fca2e(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__398466ef3c5449392d8d5c33d2d8c0ada36bd308e02a7d336c68e68efe273c1c(
    stack_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bcb119369e16f6599061934a6e24beed02cf589f1e1e2e12b3d037f8b72a02bc(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e99d489d658082c79138770e252842ec637a73cc7c6432c72eaf687d549a5371(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4c5482fcba25094285576d26f5c1efe4b62b9ef47f19640010c39a3c23ea8c86(
    server_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9795735ee99f2de5c5e24119b5cd71abe25248bd99897b2202bb67948be18a6e(
    server_name: builtins.str,
    unique_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f90c3ea53d411f50a84481e0d78cf484828c6bbd6489c9694362ea3890d4fc18(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8cc148f34ce3c4ecc4044d1618450c4279df4ca209c44e9e43a1df1f01df969f(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f139b6b23e2f72992d29a5903293300caffc7d75229e710744e2e0bfc789a934(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5ef11a89f902d89cbc3c55bf7b986da5ede2b0b6afe41306aa1e04afb1f8831c(
    value: typing.Union[builtins.str, typing.Sequence[builtins.str]],
    operator: typing.Optional[typing.Union[builtins.str, Operator]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bf8ff1c2ea2bb919452739f595275d484cc06683b37b6c82164d1570c96fd346(
    organization_id: builtins.str,
    account_id: typing.Optional[builtins.str] = None,
    account: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__33cc02b27c7dc5f4c7fcb6807b0fece39d932e77902973dea0a7d02a55953cbf(
    policy_type: builtins.str,
    policy_id: builtins.str,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d84c799e38e824fc49ddf611acacaea459e82c5eb45f5e3a2f07eb2db777f698(
    organization_id: builtins.str,
    handshake_type: builtins.str,
    handshake_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f289aca29353bb42722682f394f4c6c886bc103f8bbe22cb96a495255c595a77(
    organization_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__14704a64edfaa9cfa0cc0576c120d3c75e73db8f70f03f01104b9f2f6e773c11(
    organization_id: builtins.str,
    organizational_unit_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9b9fc2c0eb73f3a63ddf6e53e4d39ac4a7cc685c75c8e00235e53df2a3486496(
    organization_id: builtins.str,
    policy_type: builtins.str,
    policy_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8c1b19fe28c427856d6c1120feeb3a07a3b0e93f3696fea33a2a59082b94bb9f(
    organization_id: builtins.str,
    root_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__af29ce63d26cb84905105e8c1a6a045a2f14f4cf54c616d960b9059008567e10(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__339eefc6adbd36ef47e75c34585cdd169c0bf99934a9fc56c087ee98a954be5b(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f1d7de9820473779681e97d774c0e7ada086babbdef4cb1516d5f344b0069bad(
    outpost_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6309048e59bb653498a09619bd256bfd5fdbe2e42d6c525eff4fb5594deddb18(
    site_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0fefc6610c93fb836b61bb19bf4d63b7e3505391527bca543bbe33f69f6de159(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4b2aa2a6eeaecf9112477132de856fe5c151024f2af0445073d602acccc7b9c5(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1e53f4b78dfae7a174cd105b4308efb7fa6b1558186511f8d466a6ce16f4359d(
    app_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4ed00a07e1290990fdf3127020fdb6da6fe39cc9c37220a81837fe6f1dea5234(
    application_instance_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cca02018c785ee4d05ac4528f609af39dc5d237257c7ee3b7b5dfd15d9a0ab92(
    app_name: builtins.str,
    app_version: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__60d7dd56c280aadce8fa09f50f3b8de899ef572dc72b470ca5a98b18de53ee0f(
    device_id: builtins.str,
    data_source_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4e26d2ea02f9300348865fd97d99244264e501ac5ec2af34128a05cea86ee72a(
    device_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1071b4af180838840eae427fb0d18e78e8bdc994ac1f8caed14806617c7d9776(
    model_name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__99672c6195181e6d0c384bc826b4ef8e3cf2c77833f6fe82fc80d8c2e4382115(
    package_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4522c891183f320c41c27dfdde01a81aa0333822c16e23dd9ce5b38d0eb43bcf(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4a87e75b02dcb8c04e172e22e854e507f92bdf3aa46dd0ea6112e6dd15dc6d44(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__abca39c02caa0db7ae8194d407c6250195ee4e3ed8835b94af0e98c7eb4b93ce(
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c238a5dc24ba9bf93b27d14d8b4b0dcb249c295c1fee6f9acac2e631c20e1de8(
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__44657f6979da485a29001eadb2c31012e21a2cd3120fbd467fda195b26b2abb9(
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0f15307ac719216a36b8e4b8a0b74f21584c52402a505f2604fe5236dfc9c50c(
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__aba684460debdcd292f1ffe56e2dbf49adbf5373b3f64dbf6527ccc8b7848fae(
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d6eb24957ac99942e113a117c92ea2ecd9c29c2aa838a375671e94e428bf43cf(
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6266421a88ba941ddc8bc21844cc0e75469c1fc640d9bcd60587e049c1194174(
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d63971716964c0adfe94bd375bc5ae7415b2f66b4b3a12567b59220bbd6e967e(
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b2a688515b7fc285d7d899dbb648ebc763e01c3d13f35b70347e515b6c745718(
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fbe51e274d7c67d719a70f08bc95048fac6be4a1368b45a7d7abaa9e5338e19a(
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4b07aeca62c1e485072a8a09ef428a5521a85d8c1ec4a790afd11647c3745704(
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2ee3261bec7e446341fa6e3f4969f2b89747c845e75fc918e36a31fb802bdf70(
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6beb104cf919cb798a1274ee7da3b3bcec35ea4774070cd208e985dfd265c934(
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__153e363485e98f40274512fa8781e2660dfdf1badad9c3d14068f1fbb3e0d360(
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__06dd8623f9a78e85340c614815369ef184e798a31e070b028335c0d9b34e6712(
    resource_id: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3d8c5e88f78402e13b3fba4533ff03f36329bd353802005dafee1ea4048359f8(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e11ca457d912b8ff90407d6cbc53adb549aa21eda542c70df4dc8fc6ce86cdd8(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4766e6a4578c95570f67448f46037ff0ec67d6fdf3e198e74aab6f96add2f4e5(
    service_type: builtins.str,
    identifier: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e43a2b9fb79db8178ef8146c220f665ee6ac0e14c613d8a765bb4b218fa33acb(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__189f9659caef6ade76ef3bd363313ee1eead3d42f9d7b2c3038599708bb391ee(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dc08115323eb54c655be417618607833e168711de671fb7c8607ee7e72f77ff6(
    name: builtins.str,
    account: typing.Optional[builtins.str] = None,
    region: typing.Optional[builtins.str] = None,
    partition: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ed3b08734e0d4273778155f5fbdf9772dd9358fe864e420bdbbd7ace33c0a29a(
    value: AccessLevelList,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ffa892c746d7d95e11c74491c2a20fce98d2da3c8444887af17af74466015986(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass
